(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    928526,      24214]*)
(*NotebookOutlinePosition[    974604,      25736]*)
(*  CellTagsIndexPosition[    974560,      25732]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The cosine function", "Section"],

Cell[CellGroupData[{

Cell["Defining the cosine function", "Subsection"],

Cell[TextData[{
  "The cosine function is one of the oldest mathematical functions. It was \
first used in ancient Egypt in the book of Ahmes (c. 2000 B.C.). Much later \
F. Viete (1590) evaluated some values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", 
          RowBox[{"n", " ", "z"}], ")"}], TraditionalForm]]],
  ", E. Gunter (1636) introduced the notation \"Cosi\" and the word \"cosinus\
\" (replacing \"complementi sinus\"), and I. Newton (1658, 1665) found series \
expansion for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The classical definition of the cosine function for real arguments is: \
\"the cosine of an angle ",
  Cell[BoxData[
      FormBox["\[Alpha]", TraditionalForm]]],
  " in a right\[Hyphen]angle triangle is the ratio of lengths of the adjacent \
leg to the hypotenuse\". This description of",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"cos", "(", "\[Alpha]", ")"}]}], TraditionalForm]]],
  " is valid for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "\[Alpha]", "<", 
          RowBox[{"\[Pi]", "/", "2"}]}], TraditionalForm]]],
  " when the triangle nondegenerate. This approach to cosine can be expanded \
on the arbitrary real values of ",
  Cell[BoxData[
      FormBox["\[Alpha]", TraditionalForm]]],
  " if one considers the arbitrary point ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}], TraditionalForm]]],
  " in the ",
  Cell[BoxData[
      FormBox["x", TraditionalForm]]],
  ",",
  Cell[BoxData[
      FormBox["y", TraditionalForm]]],
  "\[Hyphen]Cartesian plane and defines ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "\[Alpha]", ")"}], TraditionalForm]]],
  " as the ratio ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "/", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"]}], ")"}], 
            RowBox[{"1", "/", "2"}]]}], TraditionalForm]]],
  " assuming that \[Alpha] is the value of the angle between the positive \
direction of the ",
  Cell[BoxData[
      FormBox["x", TraditionalForm]]],
  "\[Hyphen]axis and the direction from the origin to the point ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}], TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
The following formula can be also used as a definition of the \
cosine function:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{"1", "-", 
          FractionBox[
            SuperscriptBox["z", "2"], "2"], "+", 
          FractionBox[
            SuperscriptBox["z", "4"], "24"], "-", "\[Ellipsis]"}], "\[Equal]",
         
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "\[Infinity]"], 
          RowBox[{
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "k"], " ", 
                SuperscriptBox["z", 
                  RowBox[{"2", " ", "k"}]]}], 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"2", " ", "k"}], ")"}], "!"}]], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "This series converges for all finite numbers ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["A quick look at the cosine function", "Subsection"],

Cell[TextData[{
  "Here is a graphic of the cosine function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"f", "(", "x", ")"}], "=", 
          RowBox[{"cos", "(", "x", ")"}]}], TraditionalForm]]],
  " for real values of its argument ",
  Cell[BoxData[
      FormBox["x", TraditionalForm]]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0505254 0.25 0.123762 [
[.02381 -0.0125 -12 -11.1875 ]
[.02381 -0.0125 12 0 ]
[.18254 -0.0125 -12.0312 -11.1875 ]
[.18254 -0.0125 12.0312 0 ]
[.34127 -0.0125 -8.03125 -11.1875 ]
[.34127 -0.0125 8.03125 0 ]
[.5 -0.0125 -5.03125 -11.1875 ]
[.5 -0.0125 5.03125 0 ]
[.65873 -0.0125 -4.59375 -11.1875 ]
[.65873 -0.0125 4.59375 0 ]
[.81746 -0.0125 -8.59375 -11.1875 ]
[.81746 -0.0125 8.59375 0 ]
[.97619 -0.0125 -8.5625 -11.1875 ]
[.97619 -0.0125 8.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.96875 -22.375 ]
[.5 -0.0125 4.96875 -11.1875 ]
[-0.0125 .00248 -17 -5.59375 ]
[-0.0125 .00248 0 5.59375 ]
[-0.0125 .12624 -16.375 -5.59375 ]
[-0.0125 .12624 0 5.59375 ]
[-0.0125 .25 -10.0625 -5.59375 ]
[-0.0125 .25 0 5.59375 ]
[-0.0125 .37376 -9.5 -5.59375 ]
[-0.0125 .37376 0 5.59375 ]
[-0.0125 .49752 -10.125 -5.59375 ]
[-0.0125 .49752 0 5.59375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .25 -28.3125 -4.0625 ]
[-0.01875 .25 -17 4.0625 ]
[ 0 .5 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -73 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
77.812 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -73.0312 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
77.875 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -69.0312 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.0312 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -65.5938 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -69.5938 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
71.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69.5625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
70.938 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9688 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 .00248 m
.00625 .00248 L
s
gsave
-0.0125 .00248 -78 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .12624 m
.00625 .12624 L
s
gsave
-0.0125 .12624 -77.375 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .25 m
.00625 .25 L
s
gsave
-0.0125 .25 -71.0625 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .37376 m
.00625 .37376 L
s
gsave
-0.0125 .37376 -70.5 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .49752 m
.00625 .49752 L
s
gsave
-0.0125 .49752 -71.125 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 0 m
0 .5 L
s
gsave
-0.01875 .25 -87.7188 -9.65625 Mabsadd m
1 1 Mabs scale
currentpoint translate
65.0625 9.65625 translate
90 rotate
-65.0625 -9.65625 translate
0 19.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
1.000 setlinewidth
grestore
0 .5 m
1 .5 L
s
1 0 m
1 .5 L
s
0 .25 m
1 .25 L
s
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.002 w
.02381 .12624 m
.02383 .12624 L
.02385 .12624 L
.02387 .12624 L
.02389 .12624 L
.02392 .12624 L
.02396 .12624 L
.024 .12624 L
.02405 .12624 L
.02413 .12624 L
.02421 .12624 L
.02428 .12624 L
.02446 .12625 L
.02464 .12625 L
.0248 .12626 L
.02517 .12628 L
.02549 .12631 L
.02583 .12634 L
.02652 .12642 L
.02718 .12651 L
.02787 .12664 L
.02855 .12678 L
.0292 .12694 L
.02988 .12713 L
.03055 .12734 L
.03119 .12755 L
.03187 .12781 L
.03252 .12807 L
.03321 .12838 L
.03388 .12869 L
.03453 .12901 L
.03521 .12938 L
.03587 .12975 L
.03651 .13013 L
.03718 .13055 L
.03783 .13098 L
.03853 .13145 L
.03919 .13193 L
.03983 .13241 L
.04051 .13294 L
.04117 .13347 L
.04187 .13406 L
.04254 .13464 L
.04319 .13523 L
.04387 .13587 L
.04454 .13651 L
.04517 .13714 L
.04585 .13783 L
.0465 .13851 L
.0472 .13926 L
Mistroke
.04787 .14 L
.04851 .14073 L
.04919 .14153 L
.04985 .14232 L
.05055 .14317 L
.05122 .14401 L
.05187 .14484 L
.05256 .14574 L
.05323 .14663 L
.05387 .1475 L
.05455 .14844 L
.0552 .14937 L
.0559 .15037 L
.05657 .15135 L
.05721 .15231 L
.0579 .15336 L
.05856 .15438 L
.0592 .15537 L
.05987 .15645 L
.06052 .1575 L
.06122 .15863 L
.06188 .15974 L
.06252 .16083 L
.06321 .16199 L
.06386 .16313 L
.06456 .16436 L
.06523 .16556 L
.06588 .16672 L
.06657 .16798 L
.06723 .1692 L
.06787 .17039 L
.06855 .17167 L
.0692 .17292 L
.0699 .17426 L
.07057 .17556 L
.07121 .17682 L
.0719 .17818 L
.07256 .17951 L
.07319 .18079 L
.07386 .18216 L
.07451 .1835 L
.07521 .18493 L
.07587 .18633 L
.07651 .18768 L
.07719 .18912 L
.07785 .19053 L
.07854 .19203 L
.07922 .19349 L
.07986 .1949 L
.08055 .19641 L
Mistroke
.08121 .19788 L
.08185 .19929 L
.08252 .20081 L
.08318 .20228 L
.08387 .20385 L
.08454 .20538 L
.08518 .20685 L
.08586 .20842 L
.08652 .20994 L
.08722 .21156 L
.08789 .21314 L
.08854 .21466 L
.08923 .21628 L
.0899 .21785 L
.09053 .21936 L
.09121 .22097 L
.09187 .22253 L
.09256 .2242 L
.09323 .22581 L
.09388 .22736 L
.09456 .22901 L
.09522 .2306 L
.09586 .23214 L
.09653 .23378 L
.09719 .23536 L
.09788 .23705 L
.09854 .23867 L
.09918 .24024 L
.09987 .2419 L
.10052 .24351 L
.10122 .24521 L
.10189 .24686 L
.10254 .24844 L
.10317 .25 L
Mfstroke
.10317 .25 m
.10382 .25159 L
.10453 .25332 L
.1052 .25495 L
.10584 .25652 L
.10652 .25818 L
.10717 .25978 L
.10787 .26148 L
.10854 .26312 L
.10919 .26469 L
.10987 .26636 L
.11053 .26796 L
.11117 .2695 L
.11185 .27114 L
.1125 .27271 L
.11319 .27438 L
.11386 .27598 L
.1145 .27751 L
.11518 .27914 L
.11584 .2807 L
.11654 .28236 L
.11721 .28395 L
.11786 .28547 L
.11855 .28709 L
.11921 .28863 L
.11985 .29012 L
.12053 .29169 L
.12119 .29319 L
.12188 .29478 L
.12255 .29631 L
.1232 .29777 L
.12388 .29931 L
.12454 .30079 L
.12518 .3022 L
.12585 .3037 L
.1265 .30513 L
.12719 .30664 L
.12786 .30809 L
.1285 .30947 L
.12918 .31093 L
.12984 .31232 L
.13053 .31379 L
.13121 .3152 L
.13185 .31654 L
.13254 .31795 L
.1332 .3193 L
.13384 .32059 L
.13452 .32194 L
.13517 .32324 L
.13586 .3246 L
Mistroke
.13653 .3259 L
.13717 .32714 L
.13786 .32844 L
.13852 .32968 L
.13922 .33099 L
.13989 .33223 L
.14054 .33341 L
.14123 .33465 L
.14189 .33583 L
.14253 .33695 L
.14321 .33813 L
.14387 .33925 L
.14456 .34042 L
.14524 .34153 L
.14588 .34259 L
.14657 .3437 L
.14723 .34475 L
.14786 .34574 L
.14854 .34678 L
.14919 .34777 L
.14988 .3488 L
.15055 .34977 L
.15119 .35069 L
.15187 .35166 L
.15253 .35257 L
.15323 .35351 L
.1539 .35441 L
.15455 .35525 L
.15524 .35613 L
.1559 .35696 L
.15654 .35773 L
.15722 .35854 L
.15787 .3593 L
.15857 .36009 L
.15923 .36083 L
.15988 .36152 L
.16056 .36224 L
.16122 .36291 L
.16186 .36354 L
.16253 .36418 L
.16318 .36479 L
.16387 .36541 L
.16454 .36599 L
.16518 .36653 L
.16586 .36708 L
.16651 .36759 L
.16721 .36811 L
.16788 .36859 L
.16853 .36903 L
.16922 .36948 L
Mistroke
.16988 .3699 L
.17051 .37027 L
.17119 .37065 L
.17184 .371 L
.17254 .37134 L
.1732 .37166 L
.17385 .37193 L
.17453 .37221 L
.17519 .37245 L
.17589 .37269 L
.17656 .3729 L
.17721 .37307 L
.1779 .37324 L
.17856 .37338 L
.1792 .37349 L
.17988 .37359 L
.18053 .37366 L
.18087 .37369 L
.18123 .37372 L
.18158 .37374 L
.18174 .37375 L
.1819 .37375 L
.18205 .37376 L
.1822 .37376 L
.18229 .37376 L
.18233 .37376 L
.18238 .37376 L
.18242 .37376 L
.18244 .37376 L
.18246 .37376 L
.18248 .37376 L
.1825 .37376 L
.18252 .37376 L
.18254 .37376 L
Mfstroke
.18254 .37376 m
.18256 .37376 L
.18258 .37376 L
.1826 .37376 L
.18262 .37376 L
.18265 .37376 L
.18269 .37376 L
.18273 .37376 L
.18278 .37376 L
.18286 .37376 L
.18294 .37376 L
.18301 .37376 L
.18319 .37375 L
.18337 .37375 L
.18353 .37374 L
.1839 .37372 L
.18422 .37369 L
.18456 .37366 L
.18525 .37358 L
.18591 .37349 L
.1866 .37336 L
.18728 .37322 L
.18793 .37306 L
.18861 .37287 L
.18928 .37266 L
.18992 .37245 L
.1906 .37219 L
.19125 .37193 L
.19194 .37162 L
.19261 .37131 L
.19326 .37099 L
.19394 .37062 L
.1946 .37025 L
.19524 .36987 L
.19591 .36945 L
.19656 .36902 L
.19726 .36855 L
.19792 .36807 L
.19856 .36759 L
.19924 .36706 L
.1999 .36653 L
.2006 .36594 L
.20127 .36536 L
.20192 .36477 L
.2026 .36413 L
.20327 .36349 L
.2039 .36286 L
.20458 .36217 L
.20523 .36149 L
.20593 .36074 L
Mistroke
.2066 .36 L
.20724 .35927 L
.20792 .35847 L
.20858 .35768 L
.20928 .35683 L
.20995 .35599 L
.2106 .35516 L
.21129 .35426 L
.21196 .35337 L
.2126 .3525 L
.21328 .35156 L
.21393 .35063 L
.21463 .34963 L
.2153 .34865 L
.21594 .34769 L
.21663 .34664 L
.21729 .34562 L
.21793 .34463 L
.2186 .34355 L
.21925 .3425 L
.21995 .34137 L
.22061 .34026 L
.22125 .33917 L
.22194 .33801 L
.22259 .33687 L
.22329 .33564 L
.22397 .33444 L
.22461 .33328 L
.2253 .33202 L
.22596 .3308 L
.2266 .32961 L
.22728 .32833 L
.22793 .32708 L
.22863 .32574 L
.2293 .32444 L
.22994 .32318 L
.23063 .32182 L
.23129 .32049 L
.23192 .31921 L
.23259 .31784 L
.23324 .3165 L
.23394 .31507 L
.2346 .31367 L
.23524 .31232 L
.23592 .31088 L
.23658 .30947 L
.23727 .30797 L
.23795 .30651 L
.23859 .3051 L
.23928 .30359 L
Mistroke
.23994 .30212 L
.24058 .30071 L
.24125 .29919 L
.24191 .29772 L
.2426 .29615 L
.24327 .29462 L
.24391 .29315 L
.24459 .29158 L
.24525 .29006 L
.24595 .28844 L
.24662 .28686 L
.24727 .28534 L
.24796 .28372 L
.24863 .28215 L
.24926 .28064 L
.24994 .27903 L
.2506 .27747 L
.25129 .2758 L
.25196 .27419 L
.25261 .27264 L
.25329 .27099 L
.25395 .2694 L
.25459 .26786 L
.25526 .26622 L
.25592 .26464 L
.25661 .26295 L
.25727 .26133 L
.25791 .25976 L
.2586 .2581 L
.25925 .25649 L
.25995 .25479 L
.26062 .25314 L
.26127 .25156 L
.2619 .25 L
Mfstroke
.2619 .25 m
.26255 .24841 L
.26326 .24668 L
.26393 .24505 L
.26457 .24348 L
.26525 .24182 L
.2659 .24022 L
.2666 .23852 L
.26727 .23688 L
.26792 .23531 L
.2686 .23364 L
.26926 .23204 L
.2699 .2305 L
.27058 .22886 L
.27123 .22729 L
.27192 .22562 L
.27259 .22402 L
.27323 .22249 L
.27391 .22086 L
.27457 .2193 L
.27527 .21764 L
.27594 .21605 L
.27659 .21453 L
.27728 .21291 L
.27794 .21137 L
.27858 .20988 L
.27926 .20831 L
.27992 .20681 L
.28061 .20522 L
.28128 .20369 L
.28193 .20223 L
.28261 .20069 L
.28327 .19921 L
.28391 .1978 L
.28458 .1963 L
.28523 .19487 L
.28592 .19336 L
.28659 .19191 L
.28723 .19053 L
.28791 .18907 L
.28857 .18768 L
.28926 .18621 L
.28994 .1848 L
.29058 .18346 L
.29127 .18205 L
.29193 .1807 L
.29257 .17941 L
.29325 .17806 L
.2939 .17676 L
.29459 .1754 L
Mistroke
.29526 .1741 L
.2959 .17286 L
.29659 .17156 L
.29725 .17032 L
.29795 .16901 L
.29862 .16777 L
.29927 .16659 L
.29996 .16535 L
.30062 .16417 L
.30126 .16305 L
.30194 .16187 L
.3026 .16075 L
.30329 .15958 L
.30397 .15847 L
.30461 .15741 L
.3053 .1563 L
.30596 .15525 L
.30659 .15426 L
.30727 .15322 L
.30792 .15223 L
.30861 .1512 L
.30928 .15023 L
.30992 .14931 L
.3106 .14834 L
.31126 .14743 L
.31196 .14649 L
.31263 .14559 L
.31328 .14475 L
.31397 .14387 L
.31463 .14304 L
.31527 .14227 L
.31595 .14146 L
.3166 .1407 L
.3173 .13991 L
.31796 .13917 L
.31861 .13848 L
.31929 .13776 L
.31995 .13709 L
.32059 .13646 L
.32126 .13582 L
.32191 .13521 L
.3226 .13459 L
.32327 .13401 L
.32391 .13347 L
.32459 .13292 L
.32524 .13241 L
.32594 .13189 L
.32661 .13141 L
.32726 .13097 L
.32795 .13052 L
Mistroke
.32861 .1301 L
.32924 .12973 L
.32992 .12935 L
.33057 .129 L
.33127 .12866 L
.33193 .12834 L
.33258 .12807 L
.33326 .12779 L
.33392 .12755 L
.33462 .12731 L
.33529 .1271 L
.33594 .12693 L
.33663 .12676 L
.33729 .12662 L
.33793 .12651 L
.33861 .12641 L
.33926 .12634 L
.3396 .12631 L
.33996 .12628 L
.34031 .12626 L
.34047 .12625 L
.34063 .12625 L
.34078 .12624 L
.34093 .12624 L
.34102 .12624 L
.34106 .12624 L
.34111 .12624 L
.34115 .12624 L
.34117 .12624 L
.34119 .12624 L
.34121 .12624 L
.34123 .12624 L
.34125 .12624 L
.34127 .12624 L
Mfstroke
.34127 .12624 m
.34129 .12624 L
.34131 .12624 L
.34133 .12624 L
.34135 .12624 L
.34138 .12624 L
.34142 .12624 L
.34146 .12624 L
.34151 .12624 L
.34159 .12624 L
.34167 .12624 L
.34174 .12624 L
.34192 .12625 L
.3421 .12625 L
.34226 .12626 L
.34263 .12628 L
.34295 .12631 L
.34329 .12634 L
.34398 .12642 L
.34464 .12651 L
.34533 .12664 L
.34601 .12678 L
.34666 .12694 L
.34734 .12713 L
.34801 .12734 L
.34865 .12755 L
.34933 .12781 L
.34998 .12807 L
.35068 .12838 L
.35134 .12869 L
.35199 .12901 L
.35267 .12938 L
.35333 .12975 L
.35397 .13013 L
.35464 .13055 L
.35529 .13098 L
.35599 .13145 L
.35665 .13193 L
.35729 .13241 L
.35797 .13294 L
.35863 .13347 L
.35933 .13406 L
.36 .13464 L
.36065 .13523 L
.36133 .13587 L
.362 .13651 L
.36263 .13714 L
.36331 .13783 L
.36396 .13851 L
.36466 .13926 L
Mistroke
.36533 .14 L
.36597 .14073 L
.36665 .14153 L
.36731 .14232 L
.36801 .14317 L
.36868 .14401 L
.36933 .14484 L
.37002 .14574 L
.37069 .14663 L
.37133 .1475 L
.37201 .14844 L
.37266 .14937 L
.37336 .15037 L
.37403 .15135 L
.37467 .15231 L
.37536 .15336 L
.37602 .15438 L
.37666 .15537 L
.37733 .15645 L
.37798 .1575 L
.37868 .15863 L
.37934 .15974 L
.37998 .16083 L
.38067 .16199 L
.38132 .16313 L
.38202 .16436 L
.3827 .16556 L
.38334 .16672 L
.38403 .16798 L
.38469 .1692 L
.38533 .17039 L
.38601 .17167 L
.38666 .17292 L
.38736 .17426 L
.38803 .17556 L
.38867 .17682 L
.38936 .17818 L
.39002 .17951 L
.39065 .18079 L
.39132 .18216 L
.39197 .1835 L
.39267 .18493 L
.39333 .18633 L
.39397 .18768 L
.39465 .18912 L
.39531 .19053 L
.396 .19203 L
.39668 .19349 L
.39732 .1949 L
.39801 .19641 L
Mistroke
.39867 .19788 L
.39931 .19929 L
.39998 .20081 L
.40064 .20228 L
.40133 .20385 L
.402 .20538 L
.40264 .20685 L
.40332 .20842 L
.40398 .20994 L
.40468 .21156 L
.40535 .21314 L
.406 .21466 L
.40669 .21628 L
.40736 .21785 L
.40799 .21936 L
.40867 .22097 L
.40933 .22253 L
.41002 .2242 L
.41069 .22581 L
.41134 .22736 L
.41202 .22901 L
.41268 .2306 L
.41332 .23214 L
.41399 .23378 L
.41465 .23536 L
.41534 .23705 L
.416 .23867 L
.41664 .24024 L
.41733 .2419 L
.41798 .24351 L
.41868 .24521 L
.41935 .24686 L
.42 .24844 L
.42063 .25 L
Mfstroke
.42063 .25 m
.42128 .25159 L
.42199 .25332 L
.42266 .25495 L
.4233 .25652 L
.42398 .25818 L
.42463 .25978 L
.42533 .26148 L
.426 .26312 L
.42665 .26469 L
.42733 .26636 L
.42799 .26796 L
.42863 .2695 L
.42931 .27114 L
.42996 .27271 L
.43065 .27438 L
.43132 .27598 L
.43196 .27751 L
.43264 .27914 L
.4333 .2807 L
.434 .28236 L
.43467 .28395 L
.43532 .28547 L
.43601 .28709 L
.43668 .28863 L
.43731 .29012 L
.43799 .29169 L
.43865 .29319 L
.43934 .29478 L
.44001 .29631 L
.44066 .29777 L
.44134 .29931 L
.442 .30079 L
.44264 .3022 L
.44331 .3037 L
.44396 .30513 L
.44465 .30664 L
.44532 .30809 L
.44596 .30947 L
.44664 .31093 L
.4473 .31232 L
.44799 .31379 L
.44867 .3152 L
.44931 .31654 L
.45 .31795 L
.45066 .3193 L
.4513 .32059 L
.45198 .32194 L
.45263 .32324 L
.45332 .3246 L
Mistroke
.45399 .3259 L
.45463 .32714 L
.45532 .32844 L
.45598 .32968 L
.45668 .33099 L
.45735 .33223 L
.458 .33341 L
.45869 .33465 L
.45935 .33583 L
.45999 .33695 L
.46067 .33813 L
.46133 .33925 L
.46202 .34042 L
.4627 .34153 L
.46334 .34259 L
.46403 .3437 L
.46469 .34475 L
.46532 .34574 L
.466 .34678 L
.46665 .34777 L
.46734 .3488 L
.46801 .34977 L
.46865 .35069 L
.46933 .35166 L
.46999 .35257 L
.47069 .35351 L
.47136 .35441 L
.47201 .35525 L
.4727 .35613 L
.47336 .35696 L
.474 .35773 L
.47468 .35854 L
.47533 .3593 L
.47603 .36009 L
.47669 .36083 L
.47734 .36152 L
.47802 .36224 L
.47868 .36291 L
.47932 .36354 L
.47999 .36418 L
.48064 .36479 L
.48133 .36541 L
.482 .36599 L
.48264 .36653 L
.48332 .36708 L
.48397 .36759 L
.48467 .36811 L
.48534 .36859 L
.48599 .36903 L
.48668 .36948 L
Mistroke
.48734 .3699 L
.48797 .37027 L
.48865 .37065 L
.4893 .371 L
.49 .37134 L
.49066 .37166 L
.49131 .37193 L
.49199 .37221 L
.49265 .37245 L
.49335 .37269 L
.49402 .3729 L
.49467 .37307 L
.49536 .37324 L
.49602 .37338 L
.49666 .37349 L
.49734 .37359 L
.49799 .37366 L
.49833 .37369 L
.49869 .37372 L
.49904 .37374 L
.4992 .37375 L
.49936 .37375 L
.49951 .37376 L
.49966 .37376 L
.49975 .37376 L
.49979 .37376 L
.49984 .37376 L
.49988 .37376 L
.4999 .37376 L
.49992 .37376 L
.49994 .37376 L
.49996 .37376 L
.49998 .37376 L
.5 .37376 L
Mfstroke
.5 .37376 m
.50002 .37376 L
.50004 .37376 L
.50006 .37376 L
.50008 .37376 L
.50011 .37376 L
.50015 .37376 L
.50019 .37376 L
.50024 .37376 L
.50032 .37376 L
.5004 .37376 L
.50047 .37376 L
.50065 .37375 L
.50083 .37375 L
.50099 .37374 L
.50136 .37372 L
.50168 .37369 L
.50202 .37366 L
.50271 .37358 L
.50337 .37349 L
.50406 .37336 L
.50474 .37322 L
.50539 .37306 L
.50607 .37287 L
.50674 .37266 L
.50738 .37245 L
.50806 .37219 L
.50871 .37193 L
.50941 .37162 L
.51007 .37131 L
.51072 .37099 L
.5114 .37062 L
.51206 .37025 L
.5127 .36987 L
.51337 .36945 L
.51402 .36902 L
.51472 .36855 L
.51538 .36807 L
.51602 .36759 L
.5167 .36706 L
.51736 .36653 L
.51806 .36594 L
.51873 .36536 L
.51938 .36477 L
.52006 .36413 L
.52073 .36349 L
.52136 .36286 L
.52204 .36217 L
.52269 .36149 L
.52339 .36074 L
Mistroke
.52406 .36 L
.5247 .35927 L
.52538 .35847 L
.52604 .35768 L
.52674 .35683 L
.52741 .35599 L
.52806 .35516 L
.52875 .35426 L
.52942 .35337 L
.53006 .3525 L
.53074 .35156 L
.53139 .35063 L
.53209 .34963 L
.53276 .34865 L
.5334 .34769 L
.53409 .34664 L
.53475 .34562 L
.53539 .34463 L
.53606 .34355 L
.53671 .3425 L
.53741 .34137 L
.53807 .34026 L
.53871 .33917 L
.5394 .33801 L
.54005 .33687 L
.54075 .33564 L
.54143 .33444 L
.54207 .33328 L
.54276 .33202 L
.54342 .3308 L
.54406 .32961 L
.54474 .32833 L
.54539 .32708 L
.54609 .32574 L
.54676 .32444 L
.5474 .32318 L
.54809 .32182 L
.54875 .32049 L
.54938 .31921 L
.55006 .31784 L
.5507 .3165 L
.5514 .31507 L
.55206 .31367 L
.5527 .31232 L
.55338 .31088 L
.55404 .30947 L
.55473 .30797 L
.55541 .30651 L
.55605 .3051 L
.55674 .30359 L
Mistroke
.5574 .30212 L
.55804 .30071 L
.55871 .29919 L
.55937 .29772 L
.56006 .29615 L
.56073 .29462 L
.56137 .29315 L
.56205 .29158 L
.56271 .29006 L
.56341 .28844 L
.56408 .28686 L
.56473 .28534 L
.56542 .28372 L
.56609 .28215 L
.56672 .28064 L
.5674 .27903 L
.56806 .27747 L
.56875 .2758 L
.56942 .27419 L
.57007 .27264 L
.57075 .27099 L
.57141 .2694 L
.57205 .26786 L
.57273 .26622 L
.57338 .26464 L
.57407 .26295 L
.57473 .26133 L
.57537 .25976 L
.57606 .2581 L
.57671 .25649 L
.57741 .25479 L
.57808 .25314 L
.57873 .25156 L
.57937 .25 L
Mfstroke
.57937 .25 m
.58001 .24841 L
.58072 .24668 L
.58139 .24505 L
.58203 .24348 L
.58271 .24182 L
.58336 .24022 L
.58406 .23852 L
.58473 .23688 L
.58538 .23531 L
.58606 .23364 L
.58672 .23204 L
.58736 .2305 L
.58804 .22886 L
.58869 .22729 L
.58938 .22562 L
.59005 .22402 L
.59069 .22249 L
.59137 .22086 L
.59203 .2193 L
.59273 .21764 L
.5934 .21605 L
.59405 .21453 L
.59474 .21291 L
.59541 .21137 L
.59604 .20988 L
.59672 .20831 L
.59738 .20681 L
.59807 .20522 L
.59874 .20369 L
.59939 .20223 L
.60007 .20069 L
.60073 .19921 L
.60137 .1978 L
.60204 .1963 L
.60269 .19487 L
.60338 .19336 L
.60405 .19191 L
.60469 .19053 L
.60537 .18907 L
.60603 .18768 L
.60672 .18621 L
.6074 .1848 L
.60804 .18346 L
.60873 .18205 L
.60939 .1807 L
.61003 .17941 L
.61071 .17806 L
.61136 .17676 L
.61205 .1754 L
Mistroke
.61272 .1741 L
.61337 .17286 L
.61405 .17156 L
.61471 .17032 L
.61541 .16901 L
.61608 .16777 L
.61673 .16659 L
.61742 .16535 L
.61808 .16417 L
.61872 .16305 L
.6194 .16187 L
.62006 .16075 L
.62076 .15958 L
.62143 .15847 L
.62207 .15741 L
.62276 .1563 L
.62342 .15525 L
.62405 .15426 L
.62473 .15322 L
.62538 .15223 L
.62607 .1512 L
.62674 .15023 L
.62738 .14931 L
.62806 .14834 L
.62872 .14743 L
.62942 .14649 L
.63009 .14559 L
.63074 .14475 L
.63143 .14387 L
.63209 .14304 L
.63273 .14227 L
.63341 .14146 L
.63406 .1407 L
.63476 .13991 L
.63542 .13917 L
.63607 .13848 L
.63675 .13776 L
.63741 .13709 L
.63805 .13646 L
.63872 .13582 L
.63937 .13521 L
.64006 .13459 L
.64073 .13401 L
.64137 .13347 L
.64205 .13292 L
.6427 .13241 L
.6434 .13189 L
.64407 .13141 L
.64472 .13097 L
.64541 .13052 L
Mistroke
.64607 .1301 L
.6467 .12973 L
.64738 .12935 L
.64803 .129 L
.64873 .12866 L
.64939 .12834 L
.65004 .12807 L
.65072 .12779 L
.65138 .12755 L
.65208 .12731 L
.65275 .1271 L
.6534 .12693 L
.65409 .12676 L
.65475 .12662 L
.65539 .12651 L
.65607 .12641 L
.65672 .12634 L
.65706 .12631 L
.65742 .12628 L
.65777 .12626 L
.65793 .12625 L
.65809 .12625 L
.65824 .12624 L
.65839 .12624 L
.65848 .12624 L
.65852 .12624 L
.65857 .12624 L
.65861 .12624 L
.65863 .12624 L
.65865 .12624 L
.65867 .12624 L
.65869 .12624 L
.65871 .12624 L
.65873 .12624 L
Mfstroke
.65873 .12624 m
.65875 .12624 L
.65877 .12624 L
.65879 .12624 L
.65881 .12624 L
.65884 .12624 L
.65888 .12624 L
.65892 .12624 L
.65897 .12624 L
.65905 .12624 L
.65913 .12624 L
.6592 .12624 L
.65938 .12625 L
.65956 .12625 L
.65972 .12626 L
.66009 .12628 L
.66041 .12631 L
.66076 .12634 L
.66144 .12642 L
.6621 .12651 L
.66279 .12664 L
.66347 .12678 L
.66412 .12694 L
.66481 .12713 L
.66547 .12734 L
.66611 .12755 L
.66679 .12781 L
.66744 .12807 L
.66814 .12838 L
.66881 .12869 L
.66945 .12901 L
.67013 .12938 L
.67079 .12975 L
.67143 .13013 L
.6721 .13055 L
.67275 .13098 L
.67345 .13145 L
.67411 .13193 L
.67475 .13241 L
.67543 .13294 L
.67609 .13347 L
.67679 .13406 L
.67746 .13464 L
.67811 .13523 L
.67879 .13587 L
.67946 .13651 L
.68009 .13714 L
.68077 .13783 L
.68142 .13851 L
.68212 .13926 L
Mistroke
.68279 .14 L
.68343 .14073 L
.68411 .14153 L
.68477 .14232 L
.68547 .14317 L
.68615 .14401 L
.68679 .14484 L
.68748 .14574 L
.68815 .14663 L
.68879 .1475 L
.68947 .14844 L
.69012 .14937 L
.69082 .15037 L
.69149 .15135 L
.69213 .15231 L
.69282 .15336 L
.69348 .15438 L
.69412 .15537 L
.69479 .15645 L
.69544 .1575 L
.69614 .15863 L
.6968 .15974 L
.69744 .16083 L
.69813 .16199 L
.69878 .16313 L
.69948 .16436 L
.70016 .16556 L
.7008 .16672 L
.70149 .16798 L
.70215 .1692 L
.70279 .17039 L
.70347 .17167 L
.70412 .17292 L
.70482 .17426 L
.70549 .17556 L
.70613 .17682 L
.70682 .17818 L
.70748 .17951 L
.70811 .18079 L
.70879 .18216 L
.70943 .1835 L
.71013 .18493 L
.71079 .18633 L
.71143 .18768 L
.71211 .18912 L
.71277 .19053 L
.71346 .19203 L
.71414 .19349 L
.71478 .1949 L
.71547 .19641 L
Mistroke
.71613 .19788 L
.71677 .19929 L
.71744 .20081 L
.7181 .20228 L
.71879 .20385 L
.71946 .20538 L
.7201 .20685 L
.72078 .20842 L
.72144 .20994 L
.72214 .21156 L
.72281 .21314 L
.72346 .21466 L
.72415 .21628 L
.72482 .21785 L
.72545 .21936 L
.72613 .22097 L
.72679 .22253 L
.72748 .2242 L
.72815 .22581 L
.7288 .22736 L
.72948 .22901 L
.73014 .2306 L
.73078 .23214 L
.73146 .23378 L
.73211 .23536 L
.7328 .23705 L
.73346 .23867 L
.7341 .24024 L
.73479 .2419 L
.73544 .24351 L
.73614 .24521 L
.73681 .24686 L
.73746 .24844 L
.7381 .25 L
Mfstroke
.7381 .25 m
.73874 .25159 L
.73945 .25332 L
.74012 .25495 L
.74076 .25652 L
.74144 .25818 L
.74209 .25978 L
.74279 .26148 L
.74346 .26312 L
.74411 .26469 L
.74479 .26636 L
.74546 .26796 L
.74609 .2695 L
.74677 .27114 L
.74742 .27271 L
.74811 .27438 L
.74878 .27598 L
.74942 .27751 L
.7501 .27914 L
.75076 .2807 L
.75146 .28236 L
.75213 .28395 L
.75278 .28547 L
.75347 .28709 L
.75414 .28863 L
.75477 .29012 L
.75545 .29169 L
.75611 .29319 L
.7568 .29478 L
.75747 .29631 L
.75812 .29777 L
.7588 .29931 L
.75946 .30079 L
.7601 .3022 L
.76077 .3037 L
.76142 .30513 L
.76211 .30664 L
.76278 .30809 L
.76342 .30947 L
.7641 .31093 L
.76476 .31232 L
.76545 .31379 L
.76613 .3152 L
.76677 .31654 L
.76746 .31795 L
.76812 .3193 L
.76876 .32059 L
.76944 .32194 L
.77009 .32324 L
.77078 .3246 L
Mistroke
.77145 .3259 L
.7721 .32714 L
.77278 .32844 L
.77344 .32968 L
.77414 .33099 L
.77481 .33223 L
.77546 .33341 L
.77615 .33465 L
.77682 .33583 L
.77745 .33695 L
.77813 .33813 L
.77879 .33925 L
.77949 .34042 L
.78016 .34153 L
.7808 .34259 L
.78149 .3437 L
.78215 .34475 L
.78278 .34574 L
.78346 .34678 L
.78411 .34777 L
.7848 .3488 L
.78547 .34977 L
.78611 .35069 L
.78679 .35166 L
.78745 .35257 L
.78815 .35351 L
.78882 .35441 L
.78947 .35525 L
.79016 .35613 L
.79082 .35696 L
.79146 .35773 L
.79214 .35854 L
.79279 .3593 L
.79349 .36009 L
.79416 .36083 L
.7948 .36152 L
.79548 .36224 L
.79614 .36291 L
.79678 .36354 L
.79745 .36418 L
.7981 .36479 L
.79879 .36541 L
.79946 .36599 L
.8001 .36653 L
.80078 .36708 L
.80143 .36759 L
.80213 .36811 L
.8028 .36859 L
.80345 .36903 L
.80414 .36948 L
Mistroke
.8048 .3699 L
.80543 .37027 L
.80611 .37065 L
.80676 .371 L
.80746 .37134 L
.80812 .37166 L
.80877 .37193 L
.80945 .37221 L
.81011 .37245 L
.81081 .37269 L
.81148 .3729 L
.81213 .37307 L
.81282 .37324 L
.81348 .37338 L
.81412 .37349 L
.8148 .37359 L
.81546 .37366 L
.81579 .37369 L
.81615 .37372 L
.8165 .37374 L
.81666 .37375 L
.81682 .37375 L
.81697 .37376 L
.81712 .37376 L
.81721 .37376 L
.81725 .37376 L
.8173 .37376 L
.81734 .37376 L
.81736 .37376 L
.81738 .37376 L
.8174 .37376 L
.81742 .37376 L
.81744 .37376 L
.81746 .37376 L
Mfstroke
.81746 .37376 m
.81748 .37376 L
.8175 .37376 L
.81752 .37376 L
.81754 .37376 L
.81757 .37376 L
.81761 .37376 L
.81765 .37376 L
.8177 .37376 L
.81778 .37376 L
.81786 .37376 L
.81793 .37376 L
.81811 .37375 L
.81829 .37375 L
.81845 .37374 L
.81882 .37372 L
.81914 .37369 L
.81949 .37366 L
.82017 .37358 L
.82083 .37349 L
.82152 .37336 L
.8222 .37322 L
.82285 .37306 L
.82354 .37287 L
.8242 .37266 L
.82484 .37245 L
.82552 .37219 L
.82617 .37193 L
.82687 .37162 L
.82754 .37131 L
.82818 .37099 L
.82886 .37062 L
.82952 .37025 L
.83016 .36987 L
.83083 .36945 L
.83149 .36902 L
.83218 .36855 L
.83284 .36807 L
.83348 .36759 L
.83416 .36706 L
.83482 .36653 L
.83552 .36594 L
.83619 .36536 L
.83684 .36477 L
.83752 .36413 L
.83819 .36349 L
.83882 .36286 L
.8395 .36217 L
.84015 .36149 L
.84085 .36074 L
Mistroke
.84152 .36 L
.84216 .35927 L
.84284 .35847 L
.8435 .35768 L
.8442 .35683 L
.84488 .35599 L
.84552 .35516 L
.84621 .35426 L
.84688 .35337 L
.84752 .3525 L
.8482 .35156 L
.84885 .35063 L
.84955 .34963 L
.85022 .34865 L
.85086 .34769 L
.85155 .34664 L
.85221 .34562 L
.85285 .34463 L
.85352 .34355 L
.85417 .3425 L
.85487 .34137 L
.85553 .34026 L
.85617 .33917 L
.85686 .33801 L
.85751 .33687 L
.85821 .33564 L
.85889 .33444 L
.85953 .33328 L
.86022 .33202 L
.86088 .3308 L
.86152 .32961 L
.8622 .32833 L
.86285 .32708 L
.86355 .32574 L
.86422 .32444 L
.86486 .32318 L
.86555 .32182 L
.86621 .32049 L
.86684 .31921 L
.86752 .31784 L
.86817 .3165 L
.86886 .31507 L
.86952 .31367 L
.87016 .31232 L
.87084 .31088 L
.8715 .30947 L
.8722 .30797 L
.87287 .30651 L
.87351 .3051 L
.8742 .30359 L
Mistroke
.87486 .30212 L
.8755 .30071 L
.87617 .29919 L
.87683 .29772 L
.87752 .29615 L
.87819 .29462 L
.87883 .29315 L
.87951 .29158 L
.88017 .29006 L
.88087 .28844 L
.88154 .28686 L
.88219 .28534 L
.88288 .28372 L
.88355 .28215 L
.88418 .28064 L
.88486 .27903 L
.88552 .27747 L
.88621 .2758 L
.88688 .27419 L
.88753 .27264 L
.88821 .27099 L
.88887 .2694 L
.88951 .26786 L
.89019 .26622 L
.89084 .26464 L
.89153 .26295 L
.89219 .26133 L
.89283 .25976 L
.89352 .2581 L
.89417 .25649 L
.89487 .25479 L
.89554 .25314 L
.89619 .25156 L
.89683 .25 L
Mfstroke
.89683 .25 m
.89747 .24841 L
.89818 .24668 L
.89885 .24505 L
.89949 .24348 L
.90017 .24182 L
.90082 .24022 L
.90152 .23852 L
.90219 .23688 L
.90284 .23531 L
.90352 .23364 L
.90419 .23204 L
.90482 .2305 L
.9055 .22886 L
.90615 .22729 L
.90684 .22562 L
.90751 .22402 L
.90815 .22249 L
.90884 .22086 L
.90949 .2193 L
.91019 .21764 L
.91086 .21605 L
.91151 .21453 L
.9122 .21291 L
.91287 .21137 L
.9135 .20988 L
.91418 .20831 L
.91484 .20681 L
.91553 .20522 L
.9162 .20369 L
.91685 .20223 L
.91753 .20069 L
.91819 .19921 L
.91883 .1978 L
.9195 .1963 L
.92015 .19487 L
.92084 .19336 L
.92151 .19191 L
.92215 .19053 L
.92283 .18907 L
.92349 .18768 L
.92419 .18621 L
.92486 .1848 L
.9255 .18346 L
.92619 .18205 L
.92685 .1807 L
.92749 .17941 L
.92817 .17806 L
.92882 .17676 L
.92951 .1754 L
Mistroke
.93018 .1741 L
.93083 .17286 L
.93151 .17156 L
.93217 .17032 L
.93287 .16901 L
.93354 .16777 L
.93419 .16659 L
.93488 .16535 L
.93555 .16417 L
.93618 .16305 L
.93686 .16187 L
.93752 .16075 L
.93822 .15958 L
.93889 .15847 L
.93953 .15741 L
.94022 .1563 L
.94088 .15525 L
.94151 .15426 L
.94219 .15322 L
.94284 .15223 L
.94353 .1512 L
.9442 .15023 L
.94484 .14931 L
.94552 .14834 L
.94618 .14743 L
.94688 .14649 L
.94755 .14559 L
.9482 .14475 L
.94889 .14387 L
.94955 .14304 L
.95019 .14227 L
.95087 .14146 L
.95152 .1407 L
.95222 .13991 L
.95289 .13917 L
.95353 .13848 L
.95421 .13776 L
.95487 .13709 L
.95551 .13646 L
.95618 .13582 L
.95683 .13521 L
.95752 .13459 L
.95819 .13401 L
.95883 .13347 L
.95951 .13292 L
.96016 .13241 L
.96086 .13189 L
.96153 .13141 L
.96218 .13097 L
.96287 .13052 L
Mistroke
.96353 .1301 L
.96416 .12973 L
.96484 .12935 L
.96549 .129 L
.96619 .12866 L
.96685 .12834 L
.9675 .12807 L
.96818 .12779 L
.96884 .12755 L
.96954 .12731 L
.97021 .1271 L
.97086 .12693 L
.97155 .12676 L
.97221 .12662 L
.97285 .12651 L
.97353 .12641 L
.97419 .12634 L
.97452 .12631 L
.97488 .12628 L
.97523 .12626 L
.97539 .12625 L
.97555 .12625 L
.9757 .12624 L
.97585 .12624 L
.97594 .12624 L
.97598 .12624 L
.97603 .12624 L
.97607 .12624 L
.97609 .12624 L
.97611 .12624 L
.97613 .12624 L
.97615 .12624 L
.97617 .12624 L
.97619 .12624 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{500, 250},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000nR000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3oool9
0?ooo`050000003oool0oooo0?ooo`000000i`3oool00?l0oooo2P3oool010000000oooo0?ooo`00
003W0?ooo`00o`3oool;0?ooo`800000j03oool00?l0oooo303oool00`000000oooo0?ooo`3V0?oo
o`00o`3oool;0?ooo`030000003oool000000>L0oooo003o0?ooo`/0oooo00@000000?ooo`3oool0
0000iP3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0
oooom@3oool003/0oooo0`0000040?ooo`040000003oool0oooo000003P0oooo1@0000030?ooo`04
0000003oool0oooo000003d0oooo00@000000?ooo`3oool00000?P3oool300000440oooo00@00000
0?ooo`3oool00000?@3oool5000000<0oooo00@000000?ooo`3oool00000>P3oool3000000@0oooo
00@000000?ooo`3oool000005@3oool003X0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0000003P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000n0?ooo`03
0000003oool0000003d0oooo00<000000?ooo`3oool00P0000110?ooo`030000003oool0000003d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000i0?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0000000E0?ooo`00=03oool5000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0000000c0?ooo`D0000000<0oooo0000003oool01P3oool00`000000
oooo0000000g0?ooo`D000000P3oool00`000000oooo0000000m0?ooo`050000003oool0oooo0?oo
o`000000@@3oool00`000000oooo0000000n0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`000000?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001D0oooo000n0?ooo`04
0000003oool0oooo0?ooo`80000000<0oooo0000003oool0>@3oool2000000@0oooo0P0000000`3o
ool000000?ooo`0l0?ooo`80000000<0oooo0000003oool0?03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03d0oooo0P0000000`3oool000000?ooo`0n0?ooo`800000103oool20000
00030?ooo`000000oooo03`0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`0D
0?ooo`00?03oool3000000@0oooo1000000k0?ooo`030000003oool0oooo0080oooo1000000m0?oo
o`@00000?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo100000100?oo
o`030000003oool0oooo0080oooo1000000j0?ooo`<00000103oool4000001@0oooo000o0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0P`3oool01@000000oooo0?ooo`3oool00000
08D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0I0?ooo`00>`3oool01@000000
oooo0?ooo`3oool0000003l0oooo00D000000?ooo`3oool0oooo000000250?ooo`8000000P3oool0
0`000000oooo0?ooo`1o0?ooo`050000003oool0oooo0?ooo`000000@03oool01@000000oooo0?oo
o`3oool0000001/0oooo000l0?ooo`<00000@@3oool3000008L0oooo0`0000230?ooo`<00000@P3o
ool3000001`0oooo003o0?ooooD0oooo003o0?ooooD0oooo003o0?ooooD0oooo003o0?ooooD0oooo
000U0?ooo`D00000203ooooo00000;@000003`3oool002D0oooo00<000000?ooo`3oool02P3oool4
000000L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool50000
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool002L0oooo0P0000090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00:@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo
0?ooo`0=0?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=H0oooo00<0
00000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`009P3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003o
ool0oooo00d0oooo000W0?ooo`<00000203oool00`000000oooo0?ooo`3F0?ooo`030000003oool0
oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`00
0000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0
oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo
0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<0
00000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b
0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=
0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?oo
o`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`03
0000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0
eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003o
ool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool0
0`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo
0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000
oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo
00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo
000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?oo
o`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<00000
0?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?oo
o`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3o
ool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3o
ool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0
oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`00
0000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380
oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0
oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo
0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<0
00000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F
0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?oo
o`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`03
0000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0
eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003o
ool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool0
0`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool0
0380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo
00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000
oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo
00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?oo
o`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<00000
0?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?oo
o`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3o
ool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000
003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3o
ool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3o
ool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0
oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`00
0000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0
oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo
0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<0
00000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F
0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool002P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?oo
o`3oool03@3oool002P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3F0?ooo`03
0000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00200oooo1@0000030?ooo`030000
003oool0oooo00L0oooo100000070?ooo`@0o`00PP3oool70?l00440oooo00<000000?ooo`3oool0
?`3oool70?l008<0oooo103o00090?ooo`030000003oool0oooo00d0oooo000Y0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02`3oool30?l007h0oooo0`3o00060?ooo`80o`00?`3o
ool00`000000oooo0?ooo`0m0?ooo`<0o`001@3oool30?l007l0oooo0P3o000=0?ooo`030000003o
ool0oooo00d0oooo000Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool2
0?l007`0oooo0P3o000:0?ooo`80o`00?@3oool00`000000oooo0?ooo`0k0?ooo`<0o`002@3oool3
0?l007/0oooo0P3o000?0?ooo`030000003oool0oooo00d0oooo000Y0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool03`3oool20?l007T0oooo00<0o`000?ooo`3oool02`3oool20?l0
03`0oooo00<000000?ooo`3oool0>P3oool20?l000d0oooo0P3o001i0?ooo`80o`00403oool00`00
0000oooo0?ooo`0=0?ooo`00:03oool3000000L0oooo00<000000?ooo`3oool0403oool20?l007H0
oooo0P3o000?0?ooo`80o`00>`3oool00`000000oooo0?ooo`0i0?ooo`80o`003`3oool20?l007L0
oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`00:P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0140oooo0P3o001e0?ooo`030?l0003oool0oooo0100oooo
00<0o`000?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`80o`004@3oool20?l007D0oooo
00<0o`000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?oo
o`0B0?ooo`030?l0003oool0oooo0780oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?oo
o`0g0?ooo`030000003oool0oooo03L0oooo0P3o000C0?ooo`80o`00L`3oool00`3o0000oooo0?oo
o`0B0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo01<0oooo00<0o`00
0?ooo`3oool0L03oool00`3o0000oooo0?ooo`0C0?ooo`80o`00>03oool00`000000oooo0?ooo`0f
0?ooo`80o`005@3oool20?l00740oooo0P3o000D0?ooo`030000003oool0oooo00d0oooo000b0?oo
o`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0KP3oool20?l001H0oooo0P3o000g0?oo
o`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`1^0?oo
o`80o`005@3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0E0?ooo`03
0?l0003oool0oooo06`0oooo0P3o000H0?ooo`030?l0003oool0oooo03D0oooo00<000000?ooo`3o
ool0=@3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo06d0oooo00<0o`000?ooo`3o
ool0503oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0E0?ooo`80o`00
K@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool0
=03oool20?l001T0oooo0P3o001]0?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool0
3@3oool00380oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`1Z0?ooo`030?l0003o
ool0oooo01X0oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`80o`006`3o
ool00`3o0000oooo0?ooo`1Z0?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool03@3o
ool00380oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`1X0?ooo`80o`00703oool0
0`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3oool06`3oool0
0`3o0000oooo0?ooo`1X0?ooo`80o`00603oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`00
0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo06P0oooo00<0o`000?ooo`3oool0703oool00`3o
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo0P3o000M0?ooo`80o`00J@3oool00`3o
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo01P0
oooo00<0o`000?ooo`3oool0IP3oool00`3o0000oooo0?ooo`0M0?ooo`80o`00<`3oool00`000000
oooo0?ooo`0a0?ooo`80o`007`3oool00`3o0000oooo0?ooo`1V0?ooo`80o`006@3oool00`000000
oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0H0?ooo`80o`00IP3oool20?l00200oooo
00<0o`000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo01h0oooo
0P3o001V0?ooo`80o`006P3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?oo
o`0I0?ooo`030?l0003oool0oooo06@0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?oo
o`0`0?ooo`030000003oool0oooo0300oooo0P3o000Q0?ooo`030?l0003oool0oooo06@0oooo00<0
o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0I
0?ooo`80o`00I03oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0300oooo00<00000
0?ooo`3oool0<03oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0680oooo0P3o000K
0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo01X0oooo00<0o`000?oo
o`3oool0HP3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo02l0oooo00<000000?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0680oooo00<0o`000?oo
o`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo0600oooo0P3o000T0?ooo`030?l0003oool0oooo02l0oooo00<000000?ooo`3o
ool0;`3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0600oooo0P3o000L0?ooo`03
0000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool0
H03oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool0
;P3oool20?l002D0oooo0P3o001Q0?ooo`030?l0003oool0oooo01/0oooo00<000000?ooo`3oool0
3@3oool00380oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`1N0?ooo`030?l0003o
ool0oooo02D0oooo0P3o000_0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool09@3o
ool00`3o0000oooo0?ooo`1N0?ooo`80o`007@3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool0
0`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo05h0oooo00<0o`000?ooo`3oool09P3oool0
0`3o0000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool09P3oool0
0`3o0000oooo0?ooo`1N0?ooo`030?l0003oool0oooo01`0oooo00<000000?ooo`3oool03@3oool0
0380oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`1L0?ooo`030?l0003oool0oooo
02L0oooo00<0o`000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030?l0003oool0oooo
02L0oooo00<0o`000?ooo`3oool0G03oool00`3o0000oooo0?ooo`0M0?ooo`030000003oool0oooo
00d0oooo000b0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0G03oool00`3o0000
oooo0?ooo`0X0?ooo`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool0;03oool20?l002T0
oooo0P3o001M0?ooo`030?l0003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00380oooo
00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`1J0?ooo`030?l0003oool0oooo02T0oooo
0P3o000]0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo
0?ooo`1J0?ooo`80o`007`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?oo
o`0N0?ooo`030?l0003oool0oooo05X0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`0[0?ooo`030000003oool0oooo02/0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?oo
o`1I0?ooo`030?l0003oool0oooo01h0oooo00<000000?ooo`3oool03@3oool00380oooo00<00000
0?ooo`3oool07`3oool00`3o0000oooo0?ooo`1H0?ooo`80o`00;03oool20?l002`0oooo00<00000
0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo05P0oooo0P3o000P
0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo01l0oooo00<0o`000?oo
o`3oool0F03oool00`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo02X0oooo00<000000?oo
o`3oool0:P3oool20?l002d0oooo00<0o`000?ooo`3oool0F03oool00`3o0000oooo0?ooo`0O0?oo
o`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3o
ool0:P3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0oooo05L0oooo00<0o`000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0P0?ooo`030?l0
003oool0oooo05H0oooo00<0o`000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02T0oooo0P3o000_0?ooo`80o`00E`3oool00`3o0000oooo0?ooo`0P0?ooo`030000
003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0E@3o
ool00`3o0000oooo0?ooo`0^0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`0_0?ooo`030?l0003oool0oooo05D0oooo00<0o`000?ooo`3oool0803o
ool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0
oooo05@0oooo00<0o`000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0X0?ooo`030000003oool0
oooo02T0oooo00<0o`000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`1D0?ooo`030?l0003oool0
oooo0240oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool08P3oool00`3o
0000oooo0?ooo`1C0?ooo`030?l0003oool0oooo0300oooo00<0o`000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool0D`3oool00`3o
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0280
oooo00<0o`000?ooo`3oool0DP3oool00`3o0000oooo0?ooo`0a0?ooo`80o`00:@3oool00`000000
oooo0?ooo`0X0?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool0DP3oool20?l002<0
oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool08P3oool00`3o0000oooo
0?ooo`1B0?ooo`030?l0003oool0oooo0380oooo00<0o`000?ooo`3oool09`3oool00`000000oooo
0?ooo`0W0?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool0D@3oool00`3o0000oooo
0?ooo`0R0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo02<0oooo00<0
o`000?ooo`3oool0D03oool00`3o0000oooo0?ooo`0c0?ooo`80o`00:03oool00`000000oooo0?oo
o`0W0?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool0D03oool20?l002@0oooo00<0
00000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`1@
0?ooo`030?l0003oool0oooo03@0oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`0W
0?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool0D03oool00`3o0000oooo0?ooo`0S
0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo02@0oooo00<0o`000?oo
o`3oool0CP3oool20?l003H0oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?oo
o`030?l0003oool0oooo03D0oooo00<0o`000?ooo`3oool0CP3oool20?l002D0oooo00<000000?oo
o`3oool03@3oool00380oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`1>0?ooo`03
0?l0003oool0oooo03H0oooo00<0o`000?ooo`3oool09@3oool00`000000oooo0?ooo`0V0?ooo`03
0?l0003oool0oooo03D0oooo00<0o`000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo02@0oooo0P3o001>0?ooo`80o`00
>03oool00`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool0
=`3oool00`3o0000oooo0?ooo`1=0?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool0
3@3oool00380oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`1<0?ooo`030?l0003o
ool0oooo03P0oooo00<0o`000?ooo`3oool0903oool00`000000oooo0?ooo`0U0?ooo`030?l0003o
ool0oooo03L0oooo00<0o`000?ooo`3oool0C03oool00`3o0000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00d0oooo000b0?ooo`030000003oool0oooo02D0oooo0P3o001=0?ooo`030?l0003oool0
oooo03P0oooo00<0o`000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0
oooo03P0oooo0P3o001=0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool03@3oool0
0380oooo00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`1:0?ooo`030?l0003oool0oooo
03T0oooo00<0o`000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo
03T0oooo00<0o`000?ooo`3oool0BP3oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo
00d0oooo000b0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool0BP3oool00`3o0000
oooo0?ooo`0j0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool20?l003/0
oooo00<0o`000?ooo`3oool0BP3oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo00d0
oooo000b0?ooo`030000003oool0oooo02H0oooo0P3o001:0?ooo`030?l0003oool0oooo03/0oooo
00<0o`000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo03/0oooo
00<0o`000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo00d0oooo
000b0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool0B03oool00`3o0000oooo0?oo
o`0l0?ooo`030?l0003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?oo
o`0k0?ooo`030?l0003oool0oooo04P0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0?oo
o`0=0?ooo`00<P3oool00`000000oooo0?ooo`0W0?ooo`80o`00B@3oool00`3o0000oooo0?ooo`0l
0?ooo`030?l0003oool0oooo0280oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0l
0?ooo`80o`00B@3oool00`3o0000oooo0?ooo`0W0?ooo`030000003oool0oooo00d0oooo000b0?oo
o`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool0AP3oool00`3o0000oooo0?ooo`0m0?oo
o`030?l0003oool0oooo0280oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0m0?oo
o`030?l0003oool0oooo04H0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0?ooo`0=0?oo
o`00<P3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo04H0oooo00<0o`000?ooo`3o
ool0?P3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo0P3o000o0?ooo`80
o`00A`3oool00`3o0000oooo0?ooo`0X0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000
003oool0oooo02T0oooo00<0o`000?ooo`3oool0A03oool00`3o0000oooo0?ooo`0o0?ooo`030?l0
003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0o0?ooo`030?l0
003oool0oooo04D0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0?ooo`0=0?ooo`00<P3o
ool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo04@0oooo00<0o`000?ooo`3oool0@03o
ool00`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo0P3o00110?ooo`030?l0003o
ool0oooo04@0oooo00<0o`000?ooo`3oool0:@3oool00`000000oooo0?ooo`0=0?ooo`009P3oool3
000000T0oooo00<000000?ooo`3oool0:@3oool20?l004D0oooo00<0o`000?ooo`3oool0@03oool0
0`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0@03oool2
0?l004D0oooo00<0o`000?ooo`3oool0:@3oool00`000000oooo0?ooo`0=0?ooo`005`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00800000203oool00`000000oooo0?ooo`0Z0?oo
o`030?l0003oool0oooo0480oooo00<0o`000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0P0?oo
o`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`120?oo
o`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool03@3oool001L0oooo00<000000?ooo`3o
ool02`3oool01@000000oooo0?ooo`3oool0000000P0oooo;@0000000`3o00000000000000120000
00030?l00000000000000480000000<0o`00000000000000@@0000020?l004<000000P3o00130000
00030?l000000000000002/000003`3oool001L0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`3o0000
oooo0?ooo`100?ooo`030?l0003oool0oooo04<0oooo00<0o`000?ooo`3oool07`3oool00`000000
oooo0?ooo`0O0?ooo`030?l0003oool0oooo04<0oooo00<0o`000?ooo`3oool0@@3oool00`3o0000
oooo0?ooo`0Z0?ooo`030000003oool0oooo00d0oooo000H0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo
00<0o`000?ooo`3oool0@03oool00`3o0000oooo0?ooo`140?ooo`030?l0003oool0oooo01h0oooo
00<000000?ooo`3oool07P3oool20?l004D0oooo00<0o`000?ooo`3oool0@03oool00`3o0000oooo
0?ooo`0[0?ooo`030000003oool0oooo00d0oooo000H0?ooo`030000003oool0oooo00/0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0
?`3oool00`3o0000oooo0?ooo`140?ooo`030?l0003oool0oooo01h0oooo00<000000?ooo`3oool0
7P3oool00`3o0000oooo0?ooo`150?ooo`030?l0003oool0oooo03l0oooo00<0o`000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0=0?ooo`005`3oool3000000`0oooo0P0000020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0;03oool00`3o0000oooo0?ooo`0n0?ooo`030?l0003o
ool0oooo04D0oooo00<0o`000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030?l0003o
ool0oooo04D0oooo00<0o`000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00d0oooo000H0?ooo`030000003oool0oooo00`0oooo0`0000080?ooo`030000003oool0
oooo02`0oooo0P3o000o0?ooo`030?l0003oool0oooo04H0oooo00<0o`000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0M0?ooo`80o`00A`3oool20?l003l0oooo00<0o`000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0=0?ooo`006@3oool2000001L0oooo00<000000?ooo`3oool0;@3oool00`3o
0000oooo0?ooo`0l0?ooo`030?l0003oool0oooo04L0oooo00<0o`000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo04L0oooo00<0o`000?ooo`3oool0?@3oool00`3o
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo02d0
oooo00<0o`000?ooo`3oool0?03oool00`3o0000oooo0?ooo`180?ooo`030?l0003oool0oooo01`0
oooo00<000000?ooo`3oool0703oool20?l004T0oooo0P3o000m0?ooo`030?l0003oool0oooo02d0
oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo
0?ooo`0k0?ooo`030?l0003oool0oooo04P0oooo00<0o`000?ooo`3oool0703oool00`000000oooo
0?ooo`0L0?ooo`030?l0003oool0oooo04T0oooo00<0o`000?ooo`3oool0>`3oool00`3o0000oooo
0?ooo`0]0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo02h0oooo00<0
o`000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`1:0?ooo`030?l0003oool0oooo01/0oooo00<0
00000?ooo`3oool0703oool00`3o0000oooo0?ooo`190?ooo`030?l0003oool0oooo03X0oooo00<0
o`000?ooo`3oool0;P3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0_
0?ooo`030?l0003oool0oooo03T0oooo00<0o`000?ooo`3oool0BP3oool00`3o0000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool0B`3oool00`3o0000oooo0?ooo`0i
0?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0oooo04/0oooo00<0o`000?oo
o`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo04/0oooo00<0o`000?oo
o`3oool0>@3oool00`3o0000oooo0?ooo`0^0?ooo`030000003oool0oooo00d0oooo000b0?ooo`03
0000003oool0oooo02l0oooo00<0o`000?ooo`3oool0>03oool00`3o0000oooo0?ooo`1<0?ooo`03
0?l0003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool20?l004d0oooo0P3o000i0?ooo`03
0?l0003oool0oooo02l0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0
<03oool00`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo04d0oooo00<0o`000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo04d0oooo00<0o`000?ooo`3oool0
=`3oool00`3o0000oooo0?ooo`0_0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003o
ool0oooo0300oooo00<0o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`1>0?ooo`030?l0003o
ool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`1=0?ooo`030?l0003o
ool0oooo03H0oooo00<0o`000?ooo`3oool0<03oool00`000000oooo0?ooo`0=0?ooo`00<P3oool0
0`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo03D0oooo00<0o`000?ooo`3oool0CP3oool0
0`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0C`3oool0
0`3o0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo0300oooo00<000000?ooo`3oool03@3oool0
0380oooo00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0d0?ooo`030?l0003oool0oooo
04l0oooo0P3o000J0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0C`3oool00`3o
0000oooo0?ooo`0d0?ooo`80o`00<P3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000
oooo0?ooo`0a0?ooo`030?l0003oool0oooo03@0oooo00<0o`000?ooo`3oool0D03oool00`3o0000
oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0D@3oool00`3o0000
oooo0?ooo`0c0?ooo`030?l0003oool0oooo0340oooo00<000000?ooo`3oool03@3oool00380oooo
00<000000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0b0?ooo`030?l0003oool0oooo0540oooo
0P3o000I0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0D@3oool00`3o0000oooo
0?ooo`0b0?ooo`80o`00<`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?oo
o`0b0?ooo`030?l0003oool0oooo0380oooo00<0o`000?ooo`3oool0DP3oool00`3o0000oooo0?oo
o`0G0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0DP3oool00`3o0000oooo0?oo
o`0b0?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool03@3oool00380oooo00<00000
0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0`0?ooo`80o`00E03oool00`3o0000oooo0?ooo`0G
0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`0`
0?ooo`80o`00=03oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0c0?oo
o`030?l0003oool0oooo0300oooo00<0o`000?ooo`3oool0E03oool00`3o0000oooo0?ooo`0F0?oo
o`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`0`0?oo
o`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3o
ool0<`3oool20?l00300oooo0P3o001F0?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3o
ool05P3oool00`3o0000oooo0?ooo`1E0?ooo`030?l0003oool0oooo02l0oooo00<0o`000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0d0?ooo`030?l0
003oool0oooo02h0oooo00<0o`000?ooo`3oool0EP3oool00`3o0000oooo0?ooo`0E0?ooo`030000
003oool0oooo01H0oooo00<0o`000?ooo`3oool0E@3oool00`3o0000oooo0?ooo`0^0?ooo`030?l0
003oool0oooo03@0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0=03o
ool20?l002l0oooo00<0o`000?ooo`3oool0EP3oool00`3o0000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01D0oooo00<0o`000?ooo`3oool0EP3oool20?l002l0oooo00<0o`000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0e0?ooo`030?l0003oool0
oooo02`0oooo00<0o`000?ooo`3oool0E`3oool20?l001H0oooo00<000000?ooo`3oool05@3oool0
0`3o0000oooo0?ooo`1G0?ooo`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0e0?ooo`030?l0003oool0oooo
02`0oooo00<0o`000?ooo`3oool0F03oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo
01@0oooo00<0o`000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo
03D0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0=P3oool00`3o0000
oooo0?ooo`0Z0?ooo`030?l0003oool0oooo05T0oooo0P3o000E0?ooo`030000003oool0oooo01@0
oooo00<0o`000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`0Z0?ooo`80o`00=`3oool00`000000
oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0f0?ooo`80o`00:`3oool00`3o0000oooo
0?ooo`1J0?ooo`030?l0003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo
0?ooo`1J0?ooo`80o`00:`3oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo00d0oooo
000b0?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?oo
o`1K0?ooo`030?l0003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?oo
o`1K0?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0=0?ooo`00<P3oool00`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo02P0oooo00<0o`00
0?ooo`3oool0G03oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo0P3o001M
0?ooo`80o`00:@3oool00`3o0000oooo0?ooo`0g0?ooo`030000003oool0oooo00d0oooo000b0?oo
o`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`1M0?oo
o`80o`004`3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo05d0oooo00<0o`000?oo
o`3oool09P3oool20?l003T0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3o
ool0>03oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo05h0oooo00<0o`000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo05l0oooo00<0o`000?ooo`3o
ool09@3oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000
003oool0oooo03T0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`1O0?ooo`030?l0
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`1O0?ooo`030?l0
003oool0oooo02@0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0=0?ooo`00<P3o
ool00`000000oooo0?ooo`0i0?ooo`80o`009@3oool00`3o0000oooo0?ooo`1P0?ooo`030?l0003o
ool0oooo0100oooo00<000000?ooo`3oool0403oool20?l00640oooo0P3o000U0?ooo`030?l0003o
ool0oooo03T0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0>P3oool0
0`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0640oooo0P3o000A0?ooo`030000003oool0
oooo0100oooo00<0o`000?ooo`3oool0H@3oool00`3o0000oooo0?ooo`0R0?ooo`80o`00>`3oool0
0`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0j0?ooo`80o`008`3oool00`3o
0000oooo0?ooo`1R0?ooo`030?l0003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`1S0?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0200
oooo00<0o`000?ooo`3oool0I03oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0
oooo00<0o`000?ooo`3oool0H`3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo03/0
oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0?03oool00`3o0000oooo
0?ooo`0N0?ooo`80o`00IP3oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<0o`000?ooo`3oool0I@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo03/0oooo
00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?oo
o`0N0?ooo`030?l0003oool0oooo06H0oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`80o`00I`3oool20?l001l0oooo00<0o`000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`00<P3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo01`0oooo00<0o`00
0?ooo`3oool0I`3oool20?l000h0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`1W
0?ooo`030?l0003oool0oooo01`0oooo0P3o000n0?ooo`030000003oool0oooo00d0oooo000b0?oo
o`030000003oool0oooo03d0oooo0P3o000M0?ooo`030?l0003oool0oooo06P0oooo00<0o`000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo06P0oooo0P3o000M0?oo
o`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3o
ool0?P3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo06T0oooo0P3o000=0?ooo`03
0000003oool0oooo00/0oooo0P3o001[0?ooo`80o`006`3oool20?l003l0oooo00<000000?ooo`3o
ool03@3oool00380oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo06/0oooo0P3o000<0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool0
J`3oool00`3o0000oooo0?ooo`0H0?ooo`80o`00@03oool00`000000oooo0?ooo`0=0?ooo`00<P3o
ool00`000000oooo0?ooo`0o0?ooo`80o`00603oool20?l006h0oooo00<0o`000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo06`0oooo0P3o000H0?ooo`80o`00@@3o
ool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0
oooo01H0oooo00<0o`000?ooo`3oool0KP3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo0P3o001_0?ooo`80o`005`3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0
oooo00d0oooo000b0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool0503oool00`3o
0000oooo0?ooo`1_0?ooo`80o`002P3oool00`000000oooo0?ooo`080?ooo`80o`00L@3oool00`3o
0000oooo0?ooo`0D0?ooo`80o`00@P3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000
oooo0?ooo`120?ooo`030?l0003oool0oooo0180oooo0P3o001b0?ooo`80o`002@3oool00`000000
oooo0?ooo`080?ooo`030?l0003oool0oooo0740oooo00<0o`000?ooo`3oool04P3oool20?l004<0
oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0@P3oool20?l00180oooo
0P3o001d0?ooo`80o`00203oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo07<0oooo
00<0o`000?ooo`3oool0403oool20?l004@0oooo00<000000?ooo`3oool03@3oool00380oooo00<0
00000?ooo`3oool0@`3oool20?l00100oooo0P3o001f0?ooo`80o`001`3oool00`000000oooo0?oo
o`060?ooo`030?l0003oool0oooo07@0oooo0P3o000@0?ooo`80o`00A@3oool00`000000oooo0?oo
o`0=0?ooo`00<P3oool00`000000oooo0?ooo`140?ooo`80o`003P3oool20?l007P0oooo0P3o0006
0?ooo`030000003oool0oooo00@0oooo0P3o001i0?ooo`80o`003@3oool20?l004H0oooo00<00000
0?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0AP3oool20?l000X0oooo0`3o001j0?oo
o`80o`001@3oool00`000000oooo0?ooo`030?ooo`80o`00N`3oool20?l000/0oooo0P3o00170?oo
o`030000003oool0oooo00d0oooo000X0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool30?l000H0oooo0`3o001n0?ooo`80o`000`3oool010000000oooo0?ooo`3oool30?l0
07d0oooo0`3o00070?ooo`80o`00B@3oool00`000000oooo0?ooo`0=0?ooo`00:03oool00`000000
oooo0?ooo`070?ooo`@00000B03oool80?l00880oooo203o00210?ooo`P0o`00B`3oool00`000000
oooo0?ooo`0=0?ooo`00:03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=H0oooo
00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00:@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?oo
o`0=0?ooo`00:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0=H0oooo00<00000
0?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00:@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?oo
o`00:03oool3000000L0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`03
0000003oool0oooo00d0oooo000Z0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003o
ool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool0
0`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool0
0380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo
00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000
oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo
00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?oo
o`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<00000
0?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?oo
o`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3o
ool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000
003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3o
ool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3o
ool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0
oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`00
0000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0
oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo
0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<0
00000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F
0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?oo
o`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`03
0000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00
<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0
3@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003o
ool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool0
0`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo
0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000
oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo
00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?oo
o`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<00000
0?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?oo
o`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?oo
o`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3o
ool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3o
ool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0
oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`00
0000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0
oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo
0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<0
00000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b
0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=
0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?oo
o`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`03
0000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0
eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`030000003o
ool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0eP3oool0
0`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo
0=H0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000
oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool00380oooo
00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00d0oooo
000U0?ooo`D00000203oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<0
00000?ooo`3oool03@3oool002D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3F
0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool03@3oool002H0oooo00<000000?oo
o`3oool02@3oool400000=D0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0=0?oo
o`009`3oool2000000T0ooooo`00002d000000l0oooo000Y0?ooo`030000003oool0oooo0?l0oooo
b@3oool002X0oooo00<000000?ooo`3oool0o`3oooo80?ooo`009P3oool01@000000oooo0?ooo`3o
ool000000?l0oooobP3oool002L0oooo0`00003o0?oool/0oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {249, 0}} -> {-12.2238, -2.5382, 0.0456697, \
0.0186445}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Representation through more general functions", "Subsection"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " is a particular case of more complicated mathematical functions. For \
example, it is a special case of the generalized hypergeometric function ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["0",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox["\[Null]",
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      HypergeometricPFQ,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["a",
                          HypergeometricPFQ,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      HypergeometricPFQ,
                      Editable->False], ";", 
                    TagBox["w",
                      HypergeometricPFQ,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            HypergeometricPFQ]}], TraditionalForm]]],
  " with the parameter ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "\[Equal]", 
          FractionBox["1", "2"]}], TraditionalForm]]],
  " at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"w", "\[Equal]", 
          TagBox[
            RowBox[{"-", 
              FractionBox[
                SuperscriptBox["z", "2"], "4"]}],
            HypergeometricPFQ,
            Editable->True]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["0",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox["\[Null]",
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      HypergeometricPFQ,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          FractionBox["1", "2"],
                          HypergeometricPFQ,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      HypergeometricPFQ,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", 
                        FractionBox[
                          SuperscriptBox["z", "2"], "4"]}],
                      HypergeometricPFQ,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            HypergeometricPFQ], "."}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "It is also a particular case ",
  "of the Bessel f",
  "unction ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["J", "\[Nu]"], "(", "z", ")"}], TraditionalForm]]],
  "with the parameter ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Nu]", "\[Equal]", 
          RowBox[{"-", 
            FractionBox["1", "2"]}]}], TraditionalForm]]],
  ", multiplied on ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          FractionBox[
            RowBox[{"\[Pi]", " ", "z"}], "2"]], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{
          SqrtBox[
            FractionBox[
              RowBox[{"\[Pi]", " ", "z"}], "2"]], " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["J", 
                RowBox[{"-", 
                  FractionBox["1", "2"]}]], "(", "z", ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell["\<\
Other Bessel functions also can be expressed through cosine \
functions for similar values of the parameter:\
\>", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              RowBox[{
                SqrtBox[
                  FractionBox[
                    RowBox[{"\[Pi]", " ", "\[ImaginaryI]", " ", "z"}], "2"]], 
                " ", 
                RowBox[{
                  SubscriptBox["I", 
                    RowBox[{"-", 
                      FractionBox["1", "2"]}]], "(", 
                  RowBox[{"\[ImaginaryI]", " ", "z"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              RowBox[{
                RowBox[{"-", 
                  SqrtBox[
                    FractionBox[
                      RowBox[{"\[Pi]", " ", "z"}], "2"]]}], " ", 
                RowBox[{
                  SubscriptBox["Y", 
                    FractionBox["1", "2"]], "(", "z", ")"}]}]}], 
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              RowBox[{
                FractionBox[
                  RowBox[{"1", " "}], 
                  SqrtBox[
                    RowBox[{"2", " ", "\[Pi]"}]]], 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        SqrtBox[
                          RowBox[{"\[ImaginaryI]", " ", "z"}]], " ", 
                        RowBox[{
                          SubscriptBox["K", 
                            FractionBox["1", "2"]], "(", 
                          RowBox[{"\[ImaginaryI]", " ", "z"}], ")"}]}], "+", 
                      RowBox[{
                        SqrtBox[
                          RowBox[{
                            RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]], " ", 
                        
                        RowBox[{
                          SubscriptBox["K", 
                            FractionBox["1", "2"]], "(", 
                          RowBox[{
                            RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}], 
                          ")"}]}]}], ")"}], "."}]}]}]}
          }], TraditionalForm]], "TraditionalFormEquation"],

Cell["\<\
Struve functions also can degenerate into the cosine function for \
similar value of the parameter:\
\>", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              RowBox[{"1", "-", 
                RowBox[{
                  SqrtBox[
                    FractionBox[
                      RowBox[{"\[Pi]", " ", "z"}], "2"]], " ", 
                  SubscriptBox[
                    StyleBox[
                      InterpretationBox["H",
                        StruveH,
                        Editable->False,
                        Selectable->False],
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    FractionBox["1", "2"]], 
                  RowBox[{"(", "z", ")"}]}]}]}], 
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              RowBox[{"1", "+", 
                RowBox[{
                  SqrtBox[
                    FractionBox[
                      RowBox[{"\[Pi]", " ", "\[ImaginaryI]", " ", "z"}], 
                      "2"]], " ", 
                  SubscriptBox[
                    StyleBox[
                      InterpretationBox["L",
                        StruveL,
                        Editable->False,
                        Selectable->False],
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    FractionBox["1", "2"]], 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"\[ImaginaryI]", " ", "z"}], ")"}], 
                    "."}]}]}]}]}
          }], TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "But the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " is also a degenerate case of the doubly periodic Jacobi elliptic \
functions when their second parameter is equal to ",
  Cell[BoxData[
      FormBox["0", TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox["1", TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "0"}], ")"}], "\[Equal]", 
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "0"}], ")"}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{"nc", "(", 
          RowBox[{
            RowBox[{"\[ImaginaryI]", " ", "z"}], "\[VerticalSeparator]", 
            "1"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{"nd", "(", 
            RowBox[{
              RowBox[{"\[ImaginaryI]", " ", "z"}], "\[VerticalSeparator]", 
              "1"}], ")"}], "."}]}], 
      TraditionalForm]}], "TraditionalFormEquation"],

Cell[TextData[{
  "Finally, the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " is the particular case of one more class of function",
  "s\[LongDash]t",
  "he Mathieu functions:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", "\[ThinSpace]", 
        RowBox[{
          RowBox[{"Ce", "(", 
            RowBox[{"1", ",", "0", ",", "z"}], ")"}], "."}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of cosine function for complex argument", "Subsection"],

Cell[TextData[{
  "In the complex ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "\[Hyphen]plane, the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " is defined using the exponential function ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[ExponentialE]", "w"], TraditionalForm]]],
  " in the point",
  "s ",
  Cell[BoxData[
      FormBox[
        RowBox[{"w", "=", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"w", "=", 
          RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]}], TraditionalForm]]],
  " through the formula"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", " ", "z"}]], "+", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], "2"], 
          "."}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The key role in this definition of",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"cos", "(", "z", ")"}]}], TraditionalForm]]],
  " belongs to the famous Euler formula connecting the exponential, the sine, \
and the cosine functions:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]], "\[Equal]", " ", 
        RowBox[{
          RowBox[{"cos", "(", "z", ")"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              RowBox[{"sin", "(", "z", ")"}], "."}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "Changing ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  " to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", "z"}], TraditionalForm]]],
  ", the Euler formula can be converted into the following modification:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]], "\[Equal]", " ", 
        RowBox[{
          RowBox[{"cos", "(", "z", ")"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              RowBox[{"sin", "(", "z", ")"}], "."}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell["\<\
Adding and subtracting the preceding formulas gives the following \
result:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", " ", "z"}]], "+", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], "2"], 
          "."}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell["\<\
Here are two graphics showing the real and imaginary parts of the \
cosine function over the complex plane.\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.27429e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -22.0625 -9.91147 ]
[.02757 .24618 0 .33853 ]
[.17646 .18758 -14.6257 -10.25 ]
[.17646 .18758 .24931 0 ]
[.3345 .12542 -8.78742 -10.25 ]
[.3345 .12542 .65008 0 ]
[.50253 .05935 -7.63626 -10.25 ]
[.50253 .05935 1.05124 0 ]
[.68156 -0.01098 -13.1266 -10.25 ]
[.68156 -0.01098 2.74843 0 ]
[.29165 .07573 -8.67103 -10.25 ]
[.29165 .07573 .64147 0 ]
[.76162 .0881 0 -7.02759 ]
[.76162 .0881 15.6875 3.22241 ]
[.81073 .16331 0 -6.94482 ]
[.81073 .16331 15.1875 3.30518 ]
[.8565 .23339 0 -6.86895 ]
[.8565 .23339 9.4375 3.38105 ]
[.89924 .29884 0 -6.79915 ]
[.89924 .29884 9 3.45085 ]
[.93925 .36012 0 -6.73472 ]
[.93925 .36012 9.5 3.51528 ]
[.91861 .21225 0 -6.91083 ]
[.91861 .21225 9.375 3.40167 ]
[.02185 .2793 -20.625 -3.13685 ]
[.02185 .2793 0 7.11315 ]
[.01452 .32524 -15.75 -3.18111 ]
[.01452 .32524 0 7.06889 ]
[.00697 .37256 -9.4375 -3.22684 ]
[.00697 .37256 0 7.02316 ]
[-0.00081 .42133 -9.5625 -3.27412 ]
[-0.00081 .42133 0 6.97588 ]
[-0.00883 .47161 -14.4375 -3.32302 ]
[-0.00883 .47161 0 6.92698 ]
[-0.05457 .39542 -15.625 -3.22692 ]
[-0.05457 .39542 0 7.02308 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -83.0625 -13.9115 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
76.375 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -75.6257 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -69.7874 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.6363 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -74.1266 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.188 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
gsave
.29165 .07573 -69.671 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.312 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
gsave
.76162 .0881 -61 -11.0276 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.79837 .1677 m
.79219 .16989 L
s
gsave
.81073 .16331 -61 -10.9448 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -10.8689 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.88677 .30292 m
.88053 .30496 L
s
gsave
.89924 .29884 -61 -10.7991 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.92673 .36405 m
.92047 .36602 L
s
gsave
.93925 .36012 -61 -10.7347 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.91861 .21225 -61 -10.9108 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
68.375 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03716 .25514 m
0 .48963 L
s
.03408 .27456 m
.0402 .27219 L
s
gsave
.02185 .2793 -81.625 -7.13685 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02679 .32059 m
.03292 .31826 L
s
gsave
.01452 .32524 -76.75 -7.18111 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.01927 .368 m
.02543 .36572 L
s
gsave
.00697 .37256 -70.4375 -7.22684 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01153 .41687 m
.0177 .41464 L
s
gsave
-0.00081 .42133 -70.5625 -7.27412 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.00355 .46726 m
.00973 .46508 L
s
gsave
-0.00883 .47161 -75.4375 -7.32302 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.03264 .28366 m
.03631 .28224 L
s
.03119 .29281 m
.03486 .29139 L
s
.02973 .30201 m
.03341 .3006 L
s
.02826 .31127 m
.03194 .30987 L
s
.0253 .32996 m
.02899 .32857 L
s
.02381 .33938 m
.02749 .338 L
s
.02231 .34886 m
.02599 .34749 L
s
.0208 .3584 m
.02448 .35703 L
s
.01774 .37766 m
.02144 .3763 L
s
.0162 .38737 m
.0199 .38602 L
s
.01466 .39714 m
.01835 .39579 L
s
.0131 .40698 m
.0168 .40563 L
s
.00995 .42682 m
.01366 .42549 L
s
.00837 .43684 m
.01207 .43551 L
s
.00677 .44692 m
.01048 .4456 L
s
.00516 .45705 m
.00887 .45574 L
s
.03552 .26551 m
.03918 .26409 L
s
.03694 .25652 m
.04061 .25509 L
s
.00192 .47752 m
.00563 .47622 L
s
.00028 .48785 m
.004 .48656 L
s
gsave
-0.05457 .39542 -76.625 -7.22692 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.662 .557 .725 r
.39295 .79056 .39806 .80578 .40732 .80095 .4022 .78595 Mtetra
.715 .587 .712 r
.4022 .78595 .40732 .80095 .41674 .79138 .4116 .7771 Mtetra
.754 .613 .702 r
.4116 .7771 .41674 .79138 .42627 .77745 .42111 .76433 Mtetra
.787 .636 .694 r
.42111 .76433 .42627 .77745 .43587 .75973 .43069 .74816 Mtetra
.815 .659 .69 r
.43069 .74816 .43587 .75973 .44549 .739 .4403 .72926 Mtetra
.84 .683 .688 r
.4403 .72926 .44549 .739 .45509 .71614 .44989 .70844 Mtetra
.864 .709 .688 r
.44989 .70844 .45509 .71614 .46464 .69213 .45944 .68656 Mtetra
.887 .738 .692 r
.45944 .68656 .46464 .69213 .4741 .66796 .46893 .66451 Mtetra
.91 .774 .699 r
.46893 .66451 .4741 .66796 .48348 .64461 .47833 .64318 Mtetra
.932 .819 .712 r
.47833 .64318 .48348 .64461 .49276 .62298 .48765 .62337 Mtetra
.949 .877 .73 r
.48765 .62337 .49276 .62298 .50196 .60386 .49689 .60582 Mtetra
.944 .947 .749 r
.49689 .60582 .50196 .60386 .51109 .58792 .50607 .59114 Mtetra
.845 .992 .735 r
.50607 .59114 .51109 .58792 .52017 .5757 .5152 .57981 Mtetra
.46 .819 .549 r
.5152 .57981 .52017 .5757 .52923 .56757 .52432 .57218 Mtetra
.098 0 0 r
.52432 .57218 .52923 .56757 .53831 .56376 .53345 .56846 Mtetra
.441 0 .04 r
.53345 .56846 .53831 .56376 .54745 .5643 .54262 .56868 Mtetra
.614 .161 .153 r
.54262 .56868 .54745 .5643 .55667 .56909 .55188 .57275 Mtetra
.711 .27 .201 r
.55188 .57275 .55667 .56909 .56602 .57785 .56124 .58042 Mtetra
.774 .337 .211 r
.56124 .58042 .56602 .57785 .57551 .59014 .57073 .59127 Mtetra
.818 .377 .194 r
.57073 .59127 .57551 .59014 .58516 .60539 .58037 .60477 Mtetra
.845 .397 .148 r
.58037 .60477 .58516 .60539 .59499 .62286 .59017 .62026 Mtetra
.852 .393 .063 r
.59017 .62026 .59499 .62286 .605 .6417 .60013 .63696 Mtetra
.815 .35 0 r
.60013 .63696 .605 .6417 .61517 .66096 .61024 .65402 Mtetra
.682 .24 0 r
.61024 .65402 .61517 .66096 .62549 .67966 .62048 .67055 Mtetra
0 0 .532 r
.62048 .67055 .62549 .67966 .6359 .69677 .63082 .68562 Mtetra
0 .171 .699 r
.63082 .68562 .6359 .69677 .64638 .71132 .64122 .69838 Mtetra
.234 .33 .759 r
.64122 .69838 .64638 .71132 .65686 .72244 .65164 .70805 Mtetra
.422 .43 .763 r
.65164 .70805 .65686 .72244 .66729 .7294 .66201 .71398 Mtetra
.544 .493 .749 r
.66201 .71398 .66729 .7294 .67761 .73168 .6723 .71572 Mtetra
.628 .538 .733 r
.6723 .71572 .67761 .73168 .68777 .72901 .68245 .71302 Mtetra
.69 .573 .719 r
.68245 .71302 .68777 .72901 .69773 .72137 .69243 .70587 Mtetra
.738 .602 .706 r
.69243 .70587 .69773 .72137 .70744 .70901 .7022 .69448 Mtetra
.777 .629 .696 r
.7022 .69448 .70744 .70901 .71691 .69242 .71176 .6793 Mtetra
.812 .656 .689 r
.71176 .6793 .71691 .69242 .72613 .67231 .7211 .66095 Mtetra
.843 .683 .683 r
.7211 .66095 .72613 .67231 .73512 .64955 .73025 .64019 Mtetra
.872 .712 .68 r
.73025 .64019 .73512 .64955 .74393 .62511 .73923 .61791 Mtetra
.9 .745 .68 r
.73923 .61791 .74393 .62511 .7526 .60001 .74809 .59501 Mtetra
.927 .784 .682 r
.74809 .59501 .7526 .60001 .76119 .57527 .75688 .5724 Mtetra
.952 .83 .687 r
.75688 .5724 .76119 .57527 .76979 .55185 .76568 .55096 Mtetra
.968 .886 .695 r
.76568 .55096 .76979 .55185 .77846 .53063 .77455 .53149 Mtetra
.958 .946 .698 r
.77455 .53149 .77846 .53063 .78729 .51236 .78355 .51467 Mtetra
.862 .975 .669 r
.78355 .51467 .78729 .51236 .79635 .49765 .79277 .50106 Mtetra
.559 .853 .534 r
.79277 .50106 .79635 .49765 .80572 .48697 .80225 .49109 Mtetra
0 0 0 r
.80225 .49109 .80572 .48697 .81546 .48061 .81208 .48504 Mtetra
.284 0 0 r
.81208 .48504 .81546 .48061 .82561 .47872 .82228 .48302 Mtetra
.503 .015 .029 r
.82228 .48302 .82561 .47872 .83623 .48126 .8329 .48503 Mtetra
.633 .143 .072 r
.8329 .48503 .83623 .48126 .84733 .48803 .84396 .49086 Mtetra
.713 .221 .071 r
.84396 .49086 .84733 .48803 .85892 .49867 .85546 .50019 Mtetra
.762 .263 .034 r
.85546 .50019 .85892 .49867 .87098 .51266 .86738 .51254 Mtetra
.779 .275 0 r
.86738 .51254 .87098 .51266 .88348 .52933 .8797 .52729 Mtetra
.755 .251 0 r
.8797 .52729 .88348 .52933 .89634 .54787 .89235 .54371 Mtetra
.663 .181 0 r
.89235 .54371 .89634 .54787 .9095 .56736 .90526 .56095 Mtetra
0 0 .499 r
.90526 .56095 .9095 .56736 .92283 .58679 .91834 .57811 Mtetra
0 .093 .651 r
.91834 .57811 .92283 .58679 .93622 .60512 .93147 .59426 Mtetra
.033 .234 .736 r
.93147 .59426 .93622 .60512 .94952 .62133 .94452 .60847 Mtetra
.241 .341 .766 r
.94452 .60847 .94952 .62133 .96261 .63443 .95739 .61989 Mtetra
.395 .418 .767 r
.95739 .61989 .96261 .63443 .97533 .64361 .96994 .62778 Mtetra
.508 .475 .755 r
.96994 .62778 .97533 .64361 .98757 .64821 .98206 .63155 Mtetra
.593 .519 .741 r
.98206 .63155 .98757 .64821 .99922 .6478 .99367 .63085 Mtetra
.664 .566 .736 r
.38781 .77641 .39295 .79056 .4022 .78595 .39704 .77201 Mtetra
.714 .595 .721 r
.39704 .77201 .4022 .78595 .4116 .7771 .40643 .7638 Mtetra
.753 .619 .711 r
.40643 .7638 .4116 .7771 .42111 .76433 .41592 .75206 Mtetra
.785 .642 .704 r
.41592 .75206 .42111 .76433 .43069 .74816 .42548 .73727 Mtetra
.812 .664 .699 r
.42548 .73727 .43069 .74816 .4403 .72926 .43508 .72002 Mtetra
.836 .687 .698 r
.43508 .72002 .4403 .72926 .44989 .70844 .44467 .70101 Mtetra
.859 .713 .699 r
.44467 .70101 .44989 .70844 .45944 .68656 .45422 .68104 Mtetra
.881 .742 .703 r
.45422 .68104 .45944 .68656 .46893 .66451 .46372 .6609 Mtetra
.903 .777 .712 r
.46372 .6609 .46893 .66451 .47833 .64318 .47314 .64139 Mtetra
.923 .82 .726 r
.47314 .64139 .47833 .64318 .48765 .62337 .4825 .62323 Mtetra
.938 .876 .748 r
.4825 .62323 .48765 .62337 .49689 .60582 .49178 .6071 Mtetra
.934 .943 .775 r
.49178 .6071 .49689 .60582 .50607 .59114 .501 .59355 Mtetra
.854 .997 .783 r
.501 .59355 .50607 .59114 .5152 .57981 .51018 .58303 Mtetra
.54 .891 .663 r
.51018 .58303 .5152 .57981 .52432 .57218 .51935 .57586 Mtetra
0 0 0 r
.51935 .57586 .52432 .57218 .53345 .56846 .52852 .57222 Mtetra
.381 0 0 r
.52852 .57222 .53345 .56846 .54262 .56868 .53774 .57216 Mtetra
.579 .094 .069 r
.53774 .57216 .54262 .56868 .55188 .57275 .54702 .57557 Mtetra
.688 .218 .131 r
.54702 .57557 .55188 .57275 .56124 .58042 .5564 .58223 Mtetra
.755 .292 .147 r
.5564 .58223 .56124 .58042 .57073 .59127 .56589 .59177 Mtetra
.799 .334 .13 r
.56589 .59177 .57073 .59127 .58037 .60477 .57552 .60369 Mtetra
.823 .352 .08 r
.57552 .60369 .58037 .60477 .59017 .62026 .5853 .61739 Mtetra
.82 .341 0 r
.5853 .61739 .59017 .62026 .60013 .63696 .59522 .63216 Mtetra
.765 .285 0 r
.59522 .63216 .60013 .63696 .61024 .65402 .60528 .64724 Mtetra
.608 .16 0 r
.60528 .64724 .61024 .65402 .62048 .67055 .61547 .66181 Mtetra
0 .032 .599 r
.61547 .66181 .62048 .67055 .63082 .68562 .62575 .67507 Mtetra
.007 .225 .735 r
.62575 .67507 .63082 .68562 .64122 .69838 .63608 .68623 Mtetra
.265 .363 .778 r
.63608 .68623 .64122 .69838 .65164 .70805 .64644 .6946 Mtetra
.437 .451 .776 r
.64644 .6946 .65164 .70805 .66201 .71398 .65677 .69961 Mtetra
.551 .508 .761 r
.65677 .69961 .66201 .71398 .6723 .71572 .66703 .70086 Mtetra
.631 .549 .744 r
.66703 .70086 .6723 .71572 .68245 .71302 .67717 .69813 Mtetra
.69 .582 .729 r
.67717 .69813 .68245 .71302 .69243 .70587 .68717 .69141 Mtetra
.737 .61 .716 r
.68717 .69141 .69243 .70587 .7022 .69448 .697 .6809 Mtetra
.775 .636 .707 r
.697 .6809 .7022 .69448 .71176 .6793 .70664 .66697 Mtetra
.809 .661 .699 r
.70664 .66697 .71176 .6793 .7211 .66095 .7161 .65018 Mtetra
.839 .688 .695 r
.7161 .65018 .7211 .66095 .73025 .64019 .72538 .63122 Mtetra
.867 .717 .693 r
.72538 .63122 .73025 .64019 .73923 .61791 .73452 .61087 Mtetra
.894 .749 .693 r
.73452 .61087 .73923 .61791 .74809 .59501 .74355 .58994 Mtetra
.92 .787 .698 r
.74355 .58994 .74809 .59501 .75688 .5724 .75252 .56926 Mtetra
.942 .832 .706 r
.75252 .56926 .75688 .5724 .76568 .55096 .7615 .54961 Mtetra
.958 .886 .719 r
.7615 .54961 .76568 .55096 .77455 .53149 .77054 .53171 Mtetra
.95 .947 .732 r
.77054 .53171 .77455 .53149 .78355 .51467 .77971 .5162 Mtetra
.874 .989 .727 r
.77971 .5162 .78355 .51467 .79277 .50106 .78906 .50359 Mtetra
.629 .918 .642 r
.78906 .50359 .79277 .50106 .80225 .49109 .79866 .49427 Mtetra
0 0 0 r
.79866 .49427 .80225 .49109 .81208 .48504 .80857 .48849 Mtetra
.201 0 0 r
.80857 .48849 .81208 .48504 .82228 .48302 .81881 .48637 Mtetra
.447 0 0 r
.81881 .48637 .82228 .48302 .8329 .48503 .82944 .48789 Mtetra
.591 .07 0 r
.82944 .48789 .8329 .48503 .84396 .49086 .84046 .49287 Mtetra
.677 .156 0 r
.84046 .49287 .84396 .49086 .85546 .50019 .85188 .501 Mtetra
.725 .201 0 r
.85188 .501 .85546 .50019 .86738 .51254 .86369 .51186 Mtetra
.735 .21 0 r
.86369 .51186 .86738 .51254 .8797 .52729 .87585 .52487 Mtetra
.698 .18 0 r
.87585 .52487 .8797 .52729 .89235 .54371 .88831 .53936 Mtetra
.589 .104 0 r
.88831 .53936 .89235 .54371 .90526 .56095 .90101 .55458 Mtetra
0 .017 .57 r
.90101 .55458 .90526 .56095 .91834 .57811 .91386 .56971 Mtetra
0 .155 .697 r
.91386 .56971 .91834 .57811 .93147 .59426 .92676 .5839 Mtetra
.081 .278 .763 r
.92676 .5839 .93147 .59426 .94452 .60847 .9396 .59633 Mtetra
.269 .371 .783 r
.9396 .59633 .94452 .60847 .95739 .61989 .95228 .60624 Mtetra
.411 .439 .779 r
.95228 .60624 .95739 .61989 .96994 .62778 .96467 .61297 Mtetra
.516 .49 .767 r
.96467 .61297 .96994 .62778 .98206 .63155 .9767 .61601 Mtetra
.597 .531 .751 r
.9767 .61601 .98206 .63155 .99367 .63085 .98826 .61503 Mtetra
.665 .576 .746 r
.38262 .76323 .38781 .77641 .39704 .77201 .39185 .759 Mtetra
.714 .603 .731 r
.39185 .759 .39704 .77201 .40643 .7638 .40122 .75135 Mtetra
.752 .626 .721 r
.40122 .75135 .40643 .7638 .41592 .75206 .41069 .74054 Mtetra
.783 .648 .713 r
.41069 .74054 .41592 .75206 .42548 .73727 .42024 .72698 Mtetra
.809 .669 .709 r
.42024 .72698 .42548 .73727 .43508 .72002 .42982 .71119 Mtetra
.833 .692 .708 r
.42982 .71119 .43508 .72002 .44467 .70101 .43941 .69383 Mtetra
.855 .717 .709 r
.43941 .69383 .44467 .70101 .45422 .68104 .44896 .67557 Mtetra
.876 .745 .715 r
.44896 .67557 .45422 .68104 .46372 .6609 .45847 .65714 Mtetra
.896 .779 .725 r
.45847 .65714 .46372 .6609 .47314 .64139 .46792 .63927 Mtetra
.914 .821 .741 r
.46792 .63927 .47314 .64139 .4825 .62323 .4773 .6226 Mtetra
.927 .873 .765 r
.4773 .6226 .4825 .62323 .49178 .6071 .48662 .60775 Mtetra
.922 .938 .797 r
.48662 .60775 .49178 .6071 .501 .59355 .49589 .59523 Mtetra
.855 .995 .821 r
.49589 .59523 .501 .59355 .51018 .58303 .50511 .58544 Mtetra
.605 .941 .757 r
.50511 .58544 .51018 .58303 .51935 .57586 .51432 .57868 Mtetra
0 0 0 r
.51432 .57868 .51935 .57586 .52852 .57222 .52354 .57512 Mtetra
.302 0 0 r
.52354 .57512 .52852 .57222 .53774 .57216 .53279 .57479 Mtetra
.53 .012 0 r
.53279 .57479 .53774 .57216 .54702 .57557 .54211 .57761 Mtetra
.654 .153 .044 r
.54211 .57761 .54702 .57557 .5564 .58223 .5515 .58336 Mtetra
.728 .235 .068 r
.5515 .58336 .5564 .58223 .56589 .59177 .56101 .5917 Mtetra
.772 .281 .053 r
.56101 .5917 .56589 .59177 .57552 .60369 .57063 .60219 Mtetra
.792 .296 0 r
.57063 .60219 .57552 .60369 .5853 .61739 .58039 .61427 Mtetra
.777 .276 0 r
.58039 .61427 .5853 .61739 .59522 .63216 .59028 .62731 Mtetra
.701 .208 0 r
.59028 .62731 .59522 .63216 .60528 .64724 .60031 .6406 Mtetra
0 0 .469 r
.60031 .6406 .60528 .64724 .61547 .66181 .61044 .65342 Mtetra
0 .109 .661 r
.61044 .65342 .61547 .66181 .62575 .67507 .62067 .66504 Mtetra
.065 .278 .767 r
.62067 .66504 .62575 .67507 .63608 .68623 .63095 .67477 Mtetra
.295 .395 .795 r
.63095 .67477 .63608 .68623 .64644 .6946 .64126 .68198 Mtetra
.452 .472 .789 r
.64126 .68198 .64644 .6946 .65677 .69961 .65155 .68617 Mtetra
.558 .523 .772 r
.65155 .68617 .65677 .69961 .66703 .70086 .66179 .68698 Mtetra
.634 .56 .755 r
.66179 .68698 .66703 .70086 .67717 .69813 .67194 .68423 Mtetra
.69 .591 .739 r
.67194 .68423 .67717 .69813 .68717 .69141 .68196 .67789 Mtetra
.736 .617 .727 r
.68196 .67789 .68717 .69141 .697 .6809 .69183 .66815 Mtetra
.773 .642 .717 r
.69183 .66815 .697 .6809 .70664 .66697 .70155 .65533 Mtetra
.806 .667 .71 r
.70155 .65533 .70664 .66697 .7161 .65018 .7111 .63995 Mtetra
.835 .693 .706 r
.7111 .63995 .7161 .65018 .72538 .63122 .72051 .6226 Mtetra
.862 .721 .705 r
.72051 .6226 .72538 .63122 .73452 .61087 .72979 .60397 Mtetra
.888 .753 .707 r
.72979 .60397 .73452 .61087 .74355 .58994 .73898 .58481 Mtetra
.912 .79 .713 r
.73898 .58481 .74355 .58994 .75252 .56926 .74811 .56586 Mtetra
.932 .833 .724 r
.74811 .56586 .75252 .56926 .7615 .54961 .75726 .54782 Mtetra
.946 .886 .741 r
.75726 .54782 .7615 .54961 .77054 .53171 .76645 .53136 Mtetra
.94 .945 .761 r
.76645 .53136 .77054 .53171 .77971 .5162 .77577 .51703 Mtetra
.879 .993 .774 r
.77577 .51703 .77971 .5162 .78906 .50359 .78525 .50532 Mtetra
.683 .962 .733 r
.78525 .50532 .78906 .50359 .79866 .49427 .79496 .49659 Mtetra
0 0 0 r
.79496 .49659 .79866 .49427 .80857 .48849 .80494 .49105 Mtetra
.099 0 0 r
.80494 .49105 .80857 .48849 .81881 .48637 .81523 .48884 Mtetra
.372 0 0 r
.81523 .48884 .81881 .48637 .82944 .48789 .82586 .48991 Mtetra
.534 0 0 r
.82586 .48991 .82944 .48789 .84046 .49287 .83685 .49411 Mtetra
.627 .077 0 r
.83685 .49411 .84046 .49287 .85188 .501 .8482 .50116 Mtetra
.673 .124 0 r
.8482 .50116 .85188 .501 .86369 .51186 .85991 .51067 Mtetra
.676 .132 0 r
.85991 .51067 .86369 .51186 .87585 .52487 .87193 .5221 Mtetra
.625 .097 0 r
.87193 .5221 .87585 .52487 .88831 .53936 .88423 .53486 Mtetra
0 0 .496 r
.88423 .53486 .88831 .53936 .90101 .55458 .89674 .54825 Mtetra
0 .094 .638 r
.89674 .54825 .90101 .55458 .91386 .56971 .90939 .56155 Mtetra
0 .215 .739 r
.90939 .56155 .91386 .56971 .92676 .5839 .92209 .57398 Mtetra
.128 .32 .787 r
.92209 .57398 .92676 .5839 .9396 .59633 .93475 .58482 Mtetra
.297 .4 .799 r
.93475 .58482 .9396 .59633 .95228 .60624 .94725 .59338 Mtetra
.426 .46 .792 r
.94725 .59338 .95228 .60624 .96467 .61297 .95952 .59907 Mtetra
.525 .506 .778 r
.95952 .59907 .96467 .61297 .9767 .61601 .97146 .60146 Mtetra
.601 .544 .762 r
.97146 .60146 .9767 .61601 .98826 .61503 .98299 .60024 Mtetra
.666 .586 .756 r
.37738 .7509 .38262 .76323 .39185 .759 .38661 .74682 Mtetra
.713 .611 .742 r
.38661 .74682 .39185 .759 .40122 .75135 .39597 .73968 Mtetra
.75 .633 .731 r
.39597 .73968 .40122 .75135 .41069 .74054 .40543 .72969 Mtetra
.78 .654 .723 r
.40543 .72969 .41069 .74054 .42024 .72698 .41497 .71723 Mtetra
.806 .675 .719 r
.41497 .71723 .42024 .72698 .42982 .71119 .42454 .70276 Mtetra
.829 .696 .718 r
.42454 .70276 .42982 .71119 .43941 .69383 .43412 .68685 Mtetra
.85 .721 .72 r
.43412 .68685 .43941 .69383 .44896 .67557 .44368 .67013 Mtetra
.87 .748 .726 r
.44368 .67013 .44896 .67557 .45847 .65714 .45319 .65325 Mtetra
.888 .781 .737 r
.45319 .65325 .45847 .65714 .46792 .63927 .46266 .63684 Mtetra
.904 .821 .755 r
.46266 .63684 .46792 .63927 .4773 .6226 .47207 .62152 Mtetra
.914 .871 .781 r
.47207 .62152 .4773 .6226 .48662 .60775 .48142 .60783 Mtetra
.908 .931 .816 r
.48142 .60783 .48662 .60775 .49589 .59523 .49073 .59624 Mtetra
.852 .988 .851 r
.49073 .59624 .49589 .59523 .50511 .58544 .49999 .58712 Mtetra
.652 .969 .83 r
.49999 .58712 .50511 .58544 .51432 .57868 .50925 .58073 Mtetra
0 0 0 r
.50925 .58073 .51432 .57868 .52354 .57512 .51851 .57723 Mtetra
.202 0 0 r
.51851 .57723 .52354 .57512 .53279 .57479 .52779 .57666 Mtetra
.464 0 0 r
.52779 .57666 .53279 .57479 .54211 .57761 .53714 .57893 Mtetra
.607 .073 0 r
.53714 .57893 .54211 .57761 .5515 .58336 .54656 .58385 Mtetra
.689 .165 0 r
.54656 .58385 .5515 .58336 .56101 .5917 .55607 .59112 Mtetra
.734 .214 0 r
.55607 .59112 .56101 .5917 .57063 .60219 .5657 .60031 Mtetra
.747 .226 0 r
.5657 .60031 .57063 .60219 .58039 .61427 .57544 .61093 Mtetra
.719 .199 0 r
.57544 .61093 .58039 .61427 .59028 .62731 .58531 .6224 Mtetra
.621 .12 0 r
.58531 .6224 .59028 .62731 .60031 .6406 .5953 .63408 Mtetra
0 .017 .559 r
.5953 .63408 .60031 .6406 .61044 .65342 .6054 .64533 Mtetra
0 .183 .717 r
.6054 .64533 .61044 .65342 .62067 .66504 .61558 .65548 Mtetra
.12 .327 .795 r
.61558 .65548 .62067 .66504 .63095 .67477 .62582 .66392 Mtetra
.324 .426 .812 r
.62582 .66392 .63095 .67477 .64126 .68198 .63609 .6701 Mtetra
.466 .492 .801 r
.63609 .6701 .64126 .68198 .65155 .68617 .64635 .67355 Mtetra
.565 .537 .783 r
.64635 .67355 .65155 .68617 .66179 .68698 .65658 .67398 Mtetra
.636 .572 .765 r
.65658 .67398 .66179 .68698 .67194 .68423 .66672 .6712 Mtetra
.691 .6 .75 r
.66672 .6712 .67194 .68423 .68196 .67789 .67677 .6652 Mtetra
.734 .625 .737 r
.67677 .6652 .68196 .67789 .69183 .66815 .68669 .65614 Mtetra
.771 .649 .728 r
.68669 .65614 .69183 .66815 .70155 .65533 .69647 .64432 Mtetra
.802 .673 .721 r
.69647 .64432 .70155 .65533 .7111 .63995 .70612 .63018 Mtetra
.831 .698 .718 r
.70612 .63018 .7111 .63995 .72051 .6226 .71564 .61427 Mtetra
.857 .726 .717 r
.71564 .61427 .72051 .6226 .72979 .60397 .72504 .5972 Mtetra
.881 .756 .721 r
.72504 .5972 .72979 .60397 .73898 .58481 .73437 .57963 Mtetra
.903 .792 .728 r
.73437 .57963 .73898 .58481 .74811 .56586 .74366 .56223 Mtetra
.922 .834 .741 r
.74366 .56223 .74811 .56586 .75726 .54782 .75295 .54565 Mtetra
.933 .883 .761 r
.75295 .54565 .75726 .54782 .76645 .53136 .76229 .53047 Mtetra
.927 .94 .787 r
.76229 .53047 .76645 .53136 .77577 .51703 .77174 .51722 Mtetra
.877 .99 .812 r
.77174 .51722 .77577 .51703 .78525 .50532 .78134 .50633 Mtetra
.72 .986 .804 r
.78134 .50633 .78525 .50532 .79496 .49659 .79114 .49812 Mtetra
.403 .838 .702 r
.79114 .49812 .79496 .49659 .80494 .49105 .80119 .49281 Mtetra
0 0 0 r
.80119 .49281 .80494 .49105 .81523 .48884 .81153 .4905 Mtetra
.276 0 0 r
.81153 .4905 .81523 .48884 .82586 .48991 .82217 .49116 Mtetra
.457 0 0 r
.82217 .49116 .82586 .48991 .83685 .49411 .83314 .49466 Mtetra
.559 0 0 r
.83314 .49466 .83685 .49411 .8482 .50116 .84443 .50073 Mtetra
.605 .034 0 r
.84443 .50073 .8482 .50116 .85991 .51067 .85605 .509 Mtetra
.6 .042 0 r
.85605 .509 .85991 .51067 .87193 .5221 .86795 .51902 Mtetra
.537 .006 0 r
.86795 .51902 .87193 .5221 .88423 .53486 .8801 .53021 Mtetra
0 .069 .584 r
.8801 .53021 .88423 .53486 .89674 .54825 .89245 .54196 Mtetra
0 .17 .7 r
.89245 .54196 .89674 .54825 .90939 .56155 .90493 .5536 Mtetra
0 .273 .776 r
.90493 .5536 .90939 .56155 .92209 .57398 .91746 .56445 Mtetra
.173 .36 .809 r
.91746 .56445 .92209 .57398 .93475 .58482 .92994 .57386 Mtetra
.324 .428 .814 r
.92994 .57386 .93475 .58482 .94725 .59338 .94231 .58121 Mtetra
.442 .48 .804 r
.94231 .58121 .94725 .59338 .95952 .59907 .95446 .58599 Mtetra
.533 .522 .789 r
.95446 .58599 .95952 .59907 .97146 .60146 .96632 .58778 Mtetra
.605 .556 .773 r
.96632 .58778 .97146 .60146 .98299 .60024 .97784 .58634 Mtetra
.667 .596 .767 r
.3721 .73933 .37738 .7509 .38661 .74682 .38133 .73539 Mtetra
.712 .619 .752 r
.38133 .73539 .38661 .74682 .39597 .73968 .39068 .72869 Mtetra
.748 .64 .741 r
.39068 .72869 .39597 .73968 .40543 .72969 .40013 .71944 Mtetra
.777 .66 .733 r
.40013 .71944 .40543 .72969 .41497 .71723 .40966 .70795 Mtetra
.802 .68 .729 r
.40966 .70795 .41497 .71723 .42454 .70276 .41922 .69466 Mtetra
.824 .701 .728 r
.41922 .69466 .42454 .70276 .43412 .68685 .42879 .68006 Mtetra
.844 .725 .731 r
.42879 .68006 .43412 .68685 .44368 .67013 .43835 .66472 Mtetra
.863 .751 .738 r
.43835 .66472 .44368 .67013 .45319 .65325 .44788 .64922 Mtetra
.88 .783 .75 r
.44788 .64922 .45319 .65325 .46266 .63684 .45737 .63415 Mtetra
.894 .821 .768 r
.45737 .63415 .46266 .63684 .47207 .62152 .4668 .62004 Mtetra
.902 .867 .795 r
.4668 .62004 .47207 .62152 .48142 .60783 .47618 .6074 Mtetra
.894 .922 .832 r
.47618 .6074 .48142 .60783 .49073 .59624 .48552 .59664 Mtetra
.844 .976 .874 r
.48552 .59664 .49073 .59624 .49999 .58712 .49483 .58812 Mtetra
.685 .979 .882 r
.49483 .58812 .49999 .58712 .50925 .58073 .50412 .58206 Mtetra
.336 .813 .761 r
.50412 .58206 .50925 .58073 .51851 .57723 .51342 .57862 Mtetra
.083 0 0 r
.51342 .57862 .51851 .57723 .52779 .57666 .52274 .57783 Mtetra
.375 0 0 r
.52274 .57783 .52779 .57666 .53714 .57893 .53212 .57961 Mtetra
.541 0 0 r
.53212 .57961 .53714 .57893 .54656 .58385 .54156 .58378 Mtetra
.633 .079 0 r
.54156 .58378 .54656 .58385 .55607 .59112 .55108 .59007 Mtetra
.679 .132 0 r
.55108 .59007 .55607 .59112 .5657 .60031 .56071 .59808 Mtetra
.686 .142 0 r
.56071 .59808 .5657 .60031 .57544 .61093 .57046 .60738 Mtetra
.642 .108 0 r
.57046 .60738 .57544 .61093 .58531 .6224 .58031 .61744 Mtetra
.525 .023 0 r
.58031 .61744 .58531 .6224 .5953 .63408 .59027 .62768 Mtetra
0 .108 .642 r
.59027 .62768 .5953 .63408 .6054 .64533 .60034 .63751 Mtetra
0 .253 .765 r
.60034 .63751 .6054 .64533 .61558 .65548 .61049 .64634 Mtetra
.172 .372 .82 r
.61049 .64634 .61558 .65548 .62582 .66392 .62069 .65363 Mtetra
.352 .455 .826 r
.62069 .65363 .62582 .66392 .63609 .6701 .63093 .65887 Mtetra
.48 .511 .813 r
.63093 .65887 .63609 .6701 .64635 .67355 .64117 .66167 Mtetra
.571 .552 .794 r
.64117 .66167 .64635 .67355 .65658 .67398 .65138 .66174 Mtetra
.638 .583 .776 r
.65138 .66174 .65658 .67398 .66672 .6712 .66153 .65894 Mtetra
.691 .609 .76 r
.66153 .65894 .66672 .6712 .67677 .6652 .6716 .65324 Mtetra
.733 .633 .748 r
.6716 .65324 .67677 .6652 .68669 .65614 .68156 .64479 Mtetra
.768 .656 .739 r
.68156 .64479 .68669 .65614 .69647 .64432 .69141 .63386 Mtetra
.798 .679 .733 r
.69141 .63386 .69647 .64432 .70612 .63018 .70114 .62084 Mtetra
.826 .703 .73 r
.70114 .62084 .70612 .63018 .71564 .61427 .71075 .60621 Mtetra
.85 .73 .73 r
.71075 .60621 .71564 .61427 .72504 .5972 .72028 .59053 Mtetra
.873 .76 .734 r
.72028 .59053 .72504 .5972 .73437 .57963 .72973 .57439 Mtetra
.894 .794 .743 r
.72973 .57439 .73437 .57963 .74366 .56223 .73915 .55839 Mtetra
.91 .834 .757 r
.73915 .55839 .74366 .56223 .75295 .54565 .74858 .54312 Mtetra
.92 .88 .779 r
.74858 .54312 .75295 .54565 .76229 .53047 .75806 .5291 Mtetra
.913 .933 .809 r
.75806 .5291 .76229 .53047 .77174 .51722 .76763 .51682 Mtetra
.87 .982 .842 r
.76763 .51682 .77174 .51722 .78134 .50633 .77734 .50667 Mtetra
.744 .993 .857 r
.77734 .50667 .78134 .50633 .79114 .49812 .78723 .49894 Mtetra
.486 .898 .805 r
.78723 .49894 .79114 .49812 .80119 .49281 .79735 .49383 Mtetra
0 0 0 r
.79735 .49383 .80119 .49281 .81153 .4905 .80772 .49143 Mtetra
.16 0 0 r
.80772 .49143 .81153 .4905 .82217 .49116 .81838 .49172 Mtetra
.357 0 0 r
.81838 .49172 .82217 .49116 .83314 .49466 .82933 .49458 Mtetra
.469 0 0 r
.82933 .49458 .83314 .49466 .84443 .50073 .84057 .49975 Mtetra
.516 0 0 r
.84057 .49975 .84443 .50073 .85605 .509 .85211 .50691 Mtetra
.506 0 0 r
.85211 .50691 .85605 .509 .86795 .51902 .86391 .51564 Mtetra
0 .091 .559 r
.86391 .51564 .86795 .51902 .8801 .53021 .87594 .52541 Mtetra
0 .157 .666 r
.87594 .52541 .8801 .53021 .89245 .54196 .88814 .53568 Mtetra
0 .242 .755 r
.88814 .53568 .89245 .54196 .90493 .5536 .90047 .54584 Mtetra
.051 .326 .809 r
.90047 .54584 .90493 .5536 .91746 .56445 .91284 .55528 Mtetra
.215 .398 .829 r
.91284 .55528 .91746 .56445 .92994 .57386 .92519 .5634 Mtetra
.35 .455 .827 r
.92519 .5634 .92994 .57386 .94231 .58121 .93743 .56967 Mtetra
.457 .5 .815 r
.93743 .56967 .94231 .58121 .95446 .58599 .94948 .57362 Mtetra
.541 .537 .799 r
.94948 .57362 .95446 .58599 .96632 .58778 .96128 .57489 Mtetra
.609 .568 .783 r
.96128 .57489 .96632 .58778 .97784 .58634 .97278 .57325 Mtetra
.668 .606 .777 r
.36678 .72843 .3721 .73933 .38133 .73539 .376 .72461 Mtetra
.711 .628 .762 r
.376 .72461 .38133 .73539 .39068 .72869 .38535 .71832 Mtetra
.746 .647 .751 r
.38535 .71832 .39068 .72869 .40013 .71944 .39479 .70972 Mtetra
.774 .666 .743 r
.39479 .70972 .40013 .71944 .40966 .70795 .40431 .6991 Mtetra
.798 .685 .74 r
.40431 .6991 .40966 .70795 .41922 .69466 .41386 .68686 Mtetra
.82 .706 .739 r
.41386 .68686 .41922 .69466 .42879 .68006 .42343 .67343 Mtetra
.839 .728 .742 r
.42343 .67343 .42879 .68006 .43835 .66472 .433 .65933 Mtetra
.856 .754 .749 r
.433 .65933 .43835 .66472 .44788 .64922 .44254 .64508 Mtetra
.871 .784 .762 r
.44254 .64508 .44788 .64922 .45737 .63415 .45204 .6312 Mtetra
.883 .82 .781 r
.45204 .6312 .45737 .63415 .4668 .62004 .46149 .61818 Mtetra
.888 .863 .809 r
.46149 .61818 .4668 .62004 .47618 .6074 .47091 .60648 Mtetra
.879 .913 .846 r
.47091 .60648 .47618 .6074 .48552 .59664 .48028 .59649 Mtetra
.834 .962 .891 r
.48028 .59649 .48552 .59664 .49483 .58812 .48962 .5885 Mtetra
.705 .976 .917 r
.48962 .5885 .49483 .58812 .50412 .58206 .49895 .58275 Mtetra
.425 .869 .854 r
.49895 .58275 .50412 .58206 .51342 .57862 .50829 .57936 Mtetra
0 0 0 r
.50829 .57936 .51342 .57862 .52274 .57783 .51764 .57836 Mtetra
.264 0 0 r
.51764 .57836 .52274 .57783 .53212 .57961 .52705 .57969 Mtetra
.452 0 0 r
.52705 .57969 .53212 .57961 .54156 .58378 .53651 .58319 Mtetra
.557 0 0 r
.53651 .58319 .54156 .58378 .55108 .59007 .54605 .58858 Mtetra
.605 .034 0 r
.54605 .58858 .55108 .59007 .56071 .59808 .55569 .59554 Mtetra
.604 .044 0 r
.55569 .59554 .56071 .59808 .57046 .60738 .56543 .60365 Mtetra
.547 .007 0 r
.56543 .60365 .57046 .60738 .58031 .61744 .57527 .61242 Mtetra
0 .078 .578 r
.57527 .61242 .58031 .61744 .59027 .62768 .58522 .62136 Mtetra
0 .196 .715 r
.58522 .62136 .59027 .62768 .60034 .63751 .59526 .62992 Mtetra
.014 .317 .806 r
.59526 .62992 .60034 .63751 .61049 .64634 .60538 .63757 Mtetra
.22 .414 .84 r
.60538 .63757 .61049 .64634 .62069 .65363 .61556 .64383 Mtetra
.378 .482 .84 r
.61556 .64383 .62069 .65363 .63093 .65887 .62577 .64824 Mtetra
.493 .53 .824 r
.62577 .64824 .63093 .65887 .64117 .66167 .636 .65045 Mtetra
.577 .566 .804 r
.636 .65045 .64117 .66167 .65138 .66174 .6462 .6502 Mtetra
.641 .594 .786 r
.6462 .6502 .65138 .66174 .66153 .65894 .65636 .64737 Mtetra
.69 .618 .771 r
.65636 .64737 .66153 .65894 .6716 .65324 .66644 .64194 Mtetra
.731 .641 .759 r
.66644 .64194 .6716 .65324 .68156 .64479 .67645 .63404 Mtetra
.765 .663 .75 r
.67645 .63404 .68156 .64479 .69141 .63386 .68635 .6239 Mtetra
.794 .685 .744 r
.68635 .6239 .69141 .63386 .70114 .62084 .69615 .61187 Mtetra
.82 .708 .741 r
.69615 .61187 .70114 .62084 .71075 .60621 .70586 .59839 Mtetra
.844 .734 .742 r
.70586 .59839 .71075 .60621 .72028 .59053 .71549 .58396 Mtetra
.865 .762 .747 r
.71549 .58396 .72028 .59053 .72973 .57439 .72506 .5691 Mtetra
.884 .795 .757 r
.72506 .5691 .72973 .57439 .73915 .55839 .73461 .55436 Mtetra
.898 .833 .773 r
.73461 .55436 .73915 .55839 .74858 .54312 .74416 .54026 Mtetra
.906 .876 .796 r
.74416 .54026 .74858 .54312 .75806 .5291 .75375 .52729 Mtetra
.898 .924 .828 r
.75375 .52729 .75806 .5291 .76763 .51682 .76344 .51589 Mtetra
.859 .97 .865 r
.76344 .51589 .76763 .51682 .77734 .50667 .77325 .5064 Mtetra
.756 .989 .894 r
.77325 .5064 .77734 .50667 .78723 .49894 .78322 .4991 Mtetra
.55 .931 .878 r
.78322 .4991 .78723 .49894 .79735 .49383 .79341 .49417 Mtetra
.255 .766 .789 r
.79341 .49417 .79735 .49383 .80772 .49143 .80382 .49169 Mtetra
.032 0 0 r
.80382 .49169 .80772 .49143 .81838 .49172 .81449 .49164 Mtetra
.238 0 0 r
.81449 .49164 .81838 .49172 .82933 .49458 .82542 .49391 Mtetra
.358 0 0 r
.82542 .49391 .82933 .49458 .84057 .49975 .83663 .49828 Mtetra
.408 0 0 r
.83663 .49828 .84057 .49975 .85211 .50691 .8481 .50443 Mtetra
.396 0 0 r
.8481 .50443 .85211 .50691 .86391 .51564 .85981 .51199 Mtetra
0 .188 .657 r
.85981 .51199 .86391 .51564 .87594 .52541 .87173 .52049 Mtetra
0 .241 .737 r
.87173 .52049 .87594 .52541 .88814 .53568 .88381 .52942 Mtetra
0 .309 .801 r
.88381 .52942 .88814 .53568 .90047 .54584 .89601 .53825 Mtetra
.112 .376 .836 r
.89601 .53825 .90047 .54584 .91284 .55528 .90825 .54641 Mtetra
.256 .434 .846 r
.90825 .54641 .91284 .55528 .92519 .5634 .92047 .55339 Mtetra
.375 .481 .839 r
.92047 .55339 .92519 .5634 .93743 .56967 .9326 .55868 Mtetra
.472 .519 .826 r
.9326 .55868 .93743 .56967 .94948 .57362 .94457 .56189 Mtetra
.549 .552 .809 r
.94457 .56189 .94948 .57362 .96128 .57489 .95632 .56268 Mtetra
.613 .581 .794 r
.95632 .56268 .96128 .57489 .97278 .57325 .9678 .56087 Mtetra
.668 .616 .787 r
.36141 .71814 .36678 .72843 .376 .72461 .37064 .71443 Mtetra
.71 .636 .772 r
.37064 .71443 .376 .72461 .38535 .71832 .37998 .70848 Mtetra
.744 .654 .761 r
.37998 .70848 .38535 .71832 .39479 .70972 .38942 .70047 Mtetra
.771 .672 .754 r
.38942 .70047 .39479 .70972 .40431 .6991 .39893 .69063 Mtetra
.794 .69 .75 r
.39893 .69063 .40431 .6991 .41386 .68686 .40847 .67933 Mtetra
.815 .71 .75 r
.40847 .67933 .41386 .68686 .42343 .67343 .41804 .66695 Mtetra
.833 .732 .753 r
.41804 .66695 .42343 .67343 .433 .65933 .42761 .65396 Mtetra
.849 .756 .761 r
.42761 .65396 .433 .65933 .44254 .64508 .43716 .64083 Mtetra
.862 .785 .774 r
.43716 .64083 .44254 .64508 .45204 .6312 .44667 .62802 Mtetra
.872 .819 .793 r
.44667 .62802 .45204 .6312 .46149 .61818 .45615 .61599 Mtetra
.875 .858 .821 r
.45615 .61599 .46149 .61818 .47091 .60648 .46559 .60514 Mtetra
.864 .903 .858 r
.46559 .60514 .47091 .60648 .48028 .59649 .47499 .59582 Mtetra
.823 .947 .903 r
.47499 .59582 .48028 .59649 .48962 .5885 .48437 .58832 Mtetra
.716 .966 .939 r
.48437 .58832 .48962 .5885 .49895 .58275 .49374 .58284 Mtetra
.493 .9 .917 r
.49374 .58284 .49895 .58275 .50829 .57936 .50311 .5795 Mtetra
.169 .707 .793 r
.50311 .5795 .50829 .57936 .51764 .57836 .5125 .57832 Mtetra
.134 0 0 r
.5125 .57832 .51764 .57836 .52705 .57969 .52193 .57924 Mtetra
.34 0 0 r
.52193 .57924 .52705 .57969 .53651 .58319 .53142 .58211 Mtetra
.457 0 0 r
.53142 .58211 .53651 .58319 .54605 .58858 .54098 .5867 Mtetra
.508 0 0 r
.54098 .5867 .54605 .58858 .55569 .59554 .55062 .5927 Mtetra
.502 0 0 r
.55062 .5927 .55569 .59554 .56543 .60365 .56036 .59973 Mtetra
.435 0 0 r
.56036 .59973 .56543 .60365 .57527 .61242 .5702 .60736 Mtetra
0 .178 .673 r
.5702 .60736 .57527 .61242 .58522 .62136 .58014 .61512 Mtetra
0 .278 .776 r
.58014 .61512 .58522 .62136 .59526 .62992 .59016 .62254 Mtetra
.087 .375 .838 r
.59016 .62254 .59526 .62992 .60538 .63757 .60026 .62913 Mtetra
.264 .452 .858 r
.60026 .62913 .60538 .63757 .61556 .64383 .61042 .63446 Mtetra
.402 .508 .851 r
.61042 .63446 .61556 .64383 .62577 .64824 .62061 .63812 Mtetra
.506 .548 .834 r
.62061 .63812 .62577 .64824 .636 .65045 .63082 .6398 Mtetra
.583 .579 .814 r
.63082 .6398 .636 .65045 .6462 .6502 .64102 .63927 Mtetra
.643 .605 .796 r
.64102 .63927 .6462 .6502 .65636 .64737 .65119 .63641 Mtetra
.69 .628 .781 r
.65119 .63641 .65636 .64737 .66644 .64194 .6613 .63122 Mtetra
.729 .649 .769 r
.6613 .63122 .66644 .64194 .67645 .63404 .67134 .6238 Mtetra
.762 .669 .761 r
.67134 .6238 .67645 .63404 .68635 .6239 .68129 .61437 Mtetra
.79 .691 .755 r
.68129 .61437 .68635 .6239 .69615 .61187 .69117 .60323 Mtetra
.815 .713 .753 r
.69117 .60323 .69615 .61187 .70586 .59839 .70096 .59078 Mtetra
.837 .738 .754 r
.70096 .59078 .70586 .59839 .71549 .58396 .71068 .57746 Mtetra
.857 .765 .76 r
.71068 .57746 .71549 .58396 .72506 .5691 .72036 .56375 Mtetra
.874 .796 .77 r
.72036 .56375 .72506 .5691 .73461 .55436 .73002 .55014 Mtetra
.886 .831 .787 r
.73002 .55014 .73461 .55436 .74416 .54026 .73968 .5371 Mtetra
.891 .871 .811 r
.73968 .5371 .74416 .54026 .75375 .52729 .74939 .52508 Mtetra
.883 .915 .843 r
.74939 .52508 .75375 .52729 .76344 .51589 .75917 .51446 Mtetra
.847 .956 .882 r
.75917 .51446 .76344 .51589 .77325 .5064 .76908 .50557 Mtetra
.761 .977 .918 r
.76908 .50557 .77325 .5064 .78322 .4991 .77913 .49866 Mtetra
.596 .943 .926 r
.77913 .49866 .78322 .4991 .79341 .49417 .78937 .49389 Mtetra
.353 .826 .878 r
.78937 .49389 .79341 .49417 .80382 .49169 .79982 .49133 Mtetra
.095 .651 .788 r
.79982 .49133 .80382 .49169 .81449 .49164 .81051 .49098 Mtetra
0 .483 .703 r
.81051 .49098 .81449 .49164 .82542 .49391 .82144 .49272 Mtetra
.232 0 0 r
.82144 .49272 .82542 .49391 .83663 .49828 .83261 .49635 Mtetra
0 .291 .654 r
.83261 .49635 .83663 .49828 .8481 .50443 .84402 .5016 Mtetra
0 .267 .687 r
.84402 .5016 .8481 .50443 .85981 .51199 .85566 .5081 Mtetra
0 .28 .741 r
.85566 .5081 .85981 .51199 .87173 .52049 .86748 .51545 Mtetra
0 .319 .797 r
.86748 .51545 .87173 .52049 .88381 .52942 .87946 .52318 Mtetra
.032 .369 .838 r
.87946 .52318 .88381 .52942 .89601 .53825 .89154 .5308 Mtetra
.169 .42 .858 r
.89154 .5308 .89601 .53825 .90825 .54641 .90367 .53782 Mtetra
.293 .466 .86 r
.90367 .53782 .90825 .54641 .92047 .55339 .91578 .54376 Mtetra
.399 .505 .851 r
.91578 .54376 .92047 .55339 .9326 .55868 .92782 .54819 Mtetra
.486 .538 .836 r
.92782 .54819 .9326 .55868 .94457 .56189 .93972 .55073 Mtetra
.557 .567 .819 r
.93972 .55073 .94457 .56189 .95632 .56268 .95143 .55109 Mtetra
.617 .593 .803 r
.95143 .55109 .95632 .56268 .9678 .56087 .9629 .54911 Mtetra
.669 .626 .797 r
.356 .70838 .36141 .71814 .37064 .71443 .36523 .70476 Mtetra
.709 .644 .782 r
.36523 .70476 .37064 .71443 .37998 .70848 .37457 .69913 Mtetra
.741 .661 .771 r
.37457 .69913 .37998 .70848 .38942 .70047 .384 .69164 Mtetra
.767 .678 .764 r
.384 .69164 .38942 .70047 .39893 .69063 .39351 .6825 Mtetra
.79 .695 .76 r
.39351 .6825 .39893 .69063 .40847 .67933 .40305 .67204 Mtetra
.809 .714 .76 r
.40305 .67204 .40847 .67933 .41804 .66695 .41262 .6606 Mtetra
.826 .735 .764 r
.41262 .6606 .41804 .66695 .42761 .65396 .42219 .64861 Mtetra
.841 .759 .772 r
.42219 .64861 .42761 .65396 .43716 .64083 .43174 .63647 Mtetra
.853 .786 .785 r
.43174 .63647 .43716 .64083 .44667 .62802 .44127 .62463 Mtetra
.861 .817 .804 r
.44127 .62463 .44667 .62802 .45615 .61599 .45077 .61348 Mtetra
.862 .853 .832 r
.45077 .61348 .45615 .61599 .46559 .60514 .46023 .6034 Mtetra
.85 .893 .868 r
.46023 .6034 .46559 .60514 .47499 .59582 .46967 .59469 Mtetra
.811 .931 .912 r
.46967 .59469 .47499 .59582 .48437 .58832 .47908 .58763 Mtetra
.721 .951 .951 r
.47908 .58763 .48437 .58832 .49374 .58284 .48848 .58239 Mtetra
.543 .911 .955 r
.48848 .58239 .49374 .58284 .50311 .5795 .49788 .57909 Mtetra
.278 .775 .884 r
.49788 .57909 .50311 .5795 .5125 .57832 .50731 .57774 Mtetra
0 .575 .754 r
.50731 .57774 .5125 .57832 .52193 .57924 .51677 .57829 Mtetra
.209 0 0 r
.51677 .57829 .52193 .57924 .53142 .58211 .52628 .5806 Mtetra
.335 0 0 r
.52628 .5806 .53142 .58211 .54098 .5867 .53586 .58447 Mtetra
.39 0 0 r
.53586 .58447 .54098 .5867 .55062 .5927 .54552 .5896 Mtetra
.382 0 0 r
.54552 .5896 .55062 .5927 .56036 .59973 .55526 .59566 Mtetra
0 .209 .665 r
.55526 .59566 .56036 .59973 .5702 .60736 .5651 .60225 Mtetra
0 .272 .753 r
.5651 .60225 .5702 .60736 .58014 .61512 .57502 .60896 Mtetra
0 .35 .825 r
.57502 .60896 .58014 .61512 .59016 .62254 .58504 .61534 Mtetra
.154 .426 .865 r
.58504 .61534 .59016 .62254 .60026 .62913 .59512 .62098 Mtetra
.305 .486 .872 r
.59512 .62098 .60026 .62913 .61042 .63446 .60526 .62548 Mtetra
.425 .531 .862 r
.60526 .62548 .61042 .63446 .62061 .63812 .61545 .62847 Mtetra
.518 .565 .843 r
.61545 .62847 .62061 .63812 .63082 .6398 .62565 .62967 Mtetra
.589 .593 .824 r
.62565 .62967 .63082 .6398 .64102 .63927 .63585 .62889 Mtetra
.645 .616 .806 r
.63585 .62889 .64102 .63927 .65119 .63641 .64602 .626 Mtetra
.69 .636 .791 r
.64602 .626 .65119 .63641 .6613 .63122 .65615 .62102 Mtetra
.727 .656 .78 r
.65615 .62102 .6613 .63122 .67134 .6238 .66623 .61403 Mtetra
.758 .676 .771 r
.66623 .61403 .67134 .6238 .68129 .61437 .67623 .60522 Mtetra
.785 .696 .766 r
.67623 .60522 .68129 .61437 .69117 .60323 .68617 .59488 Mtetra
.809 .718 .764 r
.68617 .59488 .69117 .60323 .70096 .59078 .69604 .58335 Mtetra
.83 .741 .766 r
.69604 .58335 .70096 .59078 .71068 .57746 .70585 .57103 Mtetra
.848 .767 .772 r
.70585 .57103 .71068 .57746 .72036 .56375 .71563 .55836 Mtetra
.863 .796 .783 r
.71563 .55836 .72036 .56375 .73002 .55014 .72538 .54576 Mtetra
.874 .829 .8 r
.72538 .54576 .73002 .55014 .73968 .5371 .73515 .53367 Mtetra
.877 .866 .824 r
.73515 .53367 .73968 .5371 .74939 .52508 .74496 .5225 Mtetra
.867 .905 .856 r
.74496 .5225 .74939 .52508 .75917 .51446 .75484 .51259 Mtetra
.834 .941 .895 r
.75484 .51259 .75917 .51446 .76908 .50557 .76483 .50423 Mtetra
.76 .961 .933 r
.76483 .50423 .76908 .50557 .77913 .49866 .77496 .49767 Mtetra
.626 .942 .954 r
.77496 .49767 .77913 .49866 .78937 .49389 .78525 .49304 Mtetra
.43 .86 .936 r
.78525 .49304 .78937 .49389 .79982 .49133 .79574 .49042 Mtetra
.21 .725 .88 r
.79574 .49042 .79982 .49133 .81051 .49098 .80645 .48979 Mtetra
.023 .58 .814 r
.80645 .48979 .81051 .49098 .82144 .49272 .81737 .49104 Mtetra
0 .465 .77 r
.81737 .49104 .82144 .49272 .83261 .49635 .82852 .49401 Mtetra
0 .393 .759 r
.82852 .49401 .83261 .49635 .84402 .5016 .83988 .49843 Mtetra
0 .362 .777 r
.83988 .49843 .84402 .5016 .85566 .5081 .85145 .50398 Mtetra
0 .363 .81 r
.85145 .50398 .85566 .5081 .86748 .51545 .8632 .51029 Mtetra
0 .387 .844 r
.8632 .51029 .86748 .51545 .87946 .52318 .87508 .51693 Mtetra
.106 .422 .868 r
.87508 .51693 .87946 .52318 .89154 .5308 .88706 .52348 Mtetra
.221 .46 .876 r
.88706 .52348 .89154 .5308 .90367 .53782 .89909 .52947 Mtetra
.328 .496 .872 r
.89909 .52947 .90367 .53782 .91578 .54376 .91111 .53448 Mtetra
.421 .527 .86 r
.91111 .53448 .91578 .54376 .92782 .54819 .92307 .53812 Mtetra
.499 .555 .845 r
.92307 .53812 .92782 .54819 .93972 .55073 .93491 .54007 Mtetra
.565 .581 .828 r
.93491 .54007 .93972 .55073 .95143 .55109 .94659 .54005 Mtetra
.62 .604 .813 r
.94659 .54005 .95143 .55109 .9629 .54911 .95806 .53792 Mtetra
.669 .635 .807 r
.35054 .69911 .356 .70838 .36523 .70476 .35978 .69556 Mtetra
.708 .652 .792 r
.35978 .69556 .36523 .70476 .37457 .69913 .36912 .69021 Mtetra
.738 .668 .781 r
.36912 .69021 .37457 .69913 .384 .69164 .37855 .68318 Mtetra
.764 .684 .774 r
.37855 .68318 .384 .69164 .39351 .6825 .38805 .67467 Mtetra
.785 .7 .771 r
.38805 .67467 .39351 .6825 .40305 .67204 .39759 .66495 Mtetra
.804 .718 .771 r
.39759 .66495 .40305 .67204 .41262 .6606 .40716 .65436 Mtetra
.82 .738 .774 r
.40716 .65436 .41262 .6606 .42219 .64861 .41673 .64326 Mtetra
.833 .761 .783 r
.41673 .64326 .42219 .64861 .43174 .63647 .42629 .63202 Mtetra
.844 .786 .796 r
.42629 .63202 .43174 .63647 .44127 .62463 .43583 .62104 Mtetra
.85 .815 .815 r
.43583 .62104 .44127 .62463 .45077 .61348 .44535 .61069 Mtetra
.849 .847 .841 r
.44535 .61069 .45077 .61348 .46023 .6034 .45484 .60129 Mtetra
.836 .883 .876 r
.45484 .60129 .46023 .6034 .46967 .59469 .4643 .59314 Mtetra
.799 .916 .918 r
.4643 .59314 .46967 .59469 .47908 .58763 .47374 .58647 Mtetra
.722 .934 .958 r
.47374 .58647 .47908 .58763 .48848 .58239 .48318 .58145 Mtetra
.579 .91 .976 r
.48318 .58145 .48848 .58239 .49788 .57909 .49261 .57818 Mtetra
.365 .816 .942 r
.49261 .57818 .49788 .57909 .50731 .57774 .50207 .57667 Mtetra
.126 .662 .857 r
.50207 .57667 .50731 .57774 .51677 .57829 .51156 .57689 Mtetra
0 .503 .762 r
.51156 .57689 .51677 .57829 .52628 .5806 .5211 .5787 Mtetra
0 .382 .698 r
.5211 .5787 .52628 .5806 .53586 .58447 .53069 .5819 Mtetra
0 .312 .68 r
.53069 .5819 .53586 .58447 .54552 .5896 .54037 .58625 Mtetra
0 .29 .704 r
.54037 .58625 .54552 .5896 .55526 .59566 .55012 .59143 Mtetra
0 .308 .756 r
.55012 .59143 .55526 .59566 .5651 .60225 .55996 .59709 Mtetra
0 .355 .817 r
.55996 .59709 .5651 .60225 .57502 .60896 .56988 .60285 Mtetra
.068 .413 .863 r
.56988 .60285 .57502 .60896 .58504 .61534 .57989 .60831 Mtetra
.213 .47 .885 r
.57989 .60831 .58504 .61534 .59512 .62098 .58996 .61309 Mtetra
.341 .516 .884 r
.58996 .61309 .59512 .62098 .60526 .62548 .60009 .61684 Mtetra
.446 .553 .871 r
.60009 .61684 .60526 .62548 .61545 .62847 .61027 .61923 Mtetra
.529 .582 .852 r
.61027 .61923 .61545 .62847 .62565 .62967 .62047 .62 Mtetra
.594 .605 .833 r
.62047 .62 .62565 .62967 .63585 .62889 .63067 .61899 Mtetra
.646 .626 .815 r
.63067 .61899 .63585 .62889 .64602 .626 .64085 .61608 Mtetra
.689 .645 .801 r
.64085 .61608 .64602 .626 .65615 .62102 .65101 .61128 Mtetra
.724 .664 .79 r
.65101 .61128 .65615 .62102 .66623 .61403 .66111 .60467 Mtetra
.754 .682 .782 r
.66111 .60467 .66623 .61403 .67623 .60522 .67117 .59643 Mtetra
.78 .702 .777 r
.67117 .59643 .67623 .60522 .68617 .59488 .68116 .5868 Mtetra
.803 .722 .775 r
.68116 .5868 .68617 .59488 .69604 .58335 .6911 .57609 Mtetra
.823 .744 .778 r
.6911 .57609 .69604 .58335 .70585 .57103 .701 .56466 Mtetra
.839 .769 .784 r
.701 .56466 .70585 .57103 .71563 .55836 .71086 .55291 Mtetra
.853 .796 .795 r
.71086 .55291 .71563 .55836 .72538 .54576 .72071 .54122 Mtetra
.861 .827 .812 r
.72071 .54122 .72538 .54576 .73515 .53367 .73057 .52999 Mtetra
.862 .86 .836 r
.73057 .52999 .73515 .53367 .74496 .5225 .74047 .51958 Mtetra
.852 .894 .867 r
.74047 .51958 .74496 .5225 .75484 .51259 .75044 .5103 Mtetra
.821 .926 .904 r
.75044 .5103 .75484 .51259 .76483 .50423 .76051 .50243 Mtetra
.757 .944 .942 r
.76051 .50243 .76483 .50423 .77496 .49767 .77071 .49618 Mtetra
.646 .932 .97 r
.77071 .49618 .77496 .49767 .78525 .49304 .78106 .49168 Mtetra
.488 .874 .97 r
.78106 .49168 .78525 .49304 .79574 .49042 .79158 .48899 Mtetra
.305 .772 .94 r
.79158 .48899 .79574 .49042 .80645 .48979 .8023 .48811 Mtetra
.14 .654 .894 r
.8023 .48811 .80645 .48979 .81737 .49104 .81323 .48892 Mtetra
.024 .551 .857 r
.81323 .48892 .81737 .49104 .82852 .49401 .82436 .49129 Mtetra
0 .48 .842 r
.82436 .49129 .82852 .49401 .83988 .49843 .83568 .49496 Mtetra
0 .443 .846 r
.83568 .49496 .83988 .49843 .85145 .50398 .8472 .49965 Mtetra
.004 .435 .863 r
.8472 .49965 .85145 .50398 .8632 .51029 .85887 .50502 Mtetra
.078 .446 .88 r
.85887 .50502 .8632 .51029 .87508 .51693 .87068 .51069 Mtetra
.171 .469 .89 r
.87068 .51069 .87508 .51693 .88706 .52348 .88258 .51626 Mtetra
.268 .496 .891 r
.88258 .51626 .88706 .52348 .89909 .52947 .89452 .52133 Mtetra
.36 .523 .883 r
.89452 .52133 .89909 .52947 .91111 .53448 .90646 .52551 Mtetra
.441 .548 .869 r
.90646 .52551 .91111 .53448 .92307 .53812 .91835 .52845 Mtetra
.511 .572 .853 r
.91835 .52845 .92307 .53812 .93491 .54007 .93015 .52985 Mtetra
.572 .594 .837 r
.93015 .52985 .93491 .54007 .94659 .54005 .9418 .5295 Mtetra
.623 .616 .822 r
.9418 .5295 .94659 .54005 .95806 .53792 .95327 .52723 Mtetra
.67 .644 .816 r
.34504 .69025 .35054 .69911 .35978 .69556 .35428 .68678 Mtetra
.706 .659 .801 r
.35428 .68678 .35978 .69556 .36912 .69021 .36363 .68168 Mtetra
.735 .674 .791 r
.36363 .68168 .36912 .69021 .37855 .68318 .37306 .67506 Mtetra
.76 .689 .784 r
.37306 .67506 .37855 .68318 .38805 .67467 .38255 .6671 Mtetra
.78 .705 .781 r
.38255 .6671 .38805 .67467 .39759 .66495 .39209 .65805 Mtetra
.798 .722 .781 r
.39209 .65805 .39759 .66495 .40716 .65436 .40166 .64821 Mtetra
.813 .741 .785 r
.40166 .64821 .40716 .65436 .41673 .64326 .41124 .63791 Mtetra
.825 .762 .793 r
.41124 .63791 .41673 .64326 .42629 .63202 .42081 .62748 Mtetra
.834 .786 .806 r
.42081 .62748 .42629 .63202 .43583 .62104 .43036 .61728 Mtetra
.839 .812 .825 r
.43036 .61728 .43583 .62104 .44535 .61069 .4399 .60764 Mtetra
.836 .842 .85 r
.4399 .60764 .44535 .61069 .45484 .60129 .44941 .59886 Mtetra
.822 .873 .883 r
.44941 .59886 .45484 .60129 .4643 .59314 .4589 .5912 Mtetra
.788 .901 .922 r
.4589 .5912 .4643 .59314 .47374 .58647 .46837 .58488 Mtetra
.72 .917 .961 r
.46837 .58488 .47374 .58647 .48318 .58145 .47783 .58006 Mtetra
.603 .902 .986 r
.47783 .58006 .48318 .58145 .49261 .57818 .4873 .57681 Mtetra
.432 .836 .976 r
.4873 .57681 .49261 .57818 .50207 .57667 .49679 .57517 Mtetra
.234 .722 .926 r
.49679 .57517 .50207 .57667 .51156 .57689 .50631 .57508 Mtetra
.057 .592 .858 r
.50631 .57508 .51156 .57689 .5211 .5787 .51587 .57643 Mtetra
0 .484 .805 r
.51587 .57643 .5211 .5787 .53069 .5819 .52549 .57904 Mtetra
0 .415 .784 r
.52549 .57904 .53069 .5819 .54037 .58625 .53518 .58268 Mtetra
0 .388 .795 r
.53518 .58268 .54037 .58625 .55012 .59143 .54494 .58707 Mtetra
0 .395 .828 r
.54494 .58707 .55012 .59143 .55996 .59709 .55479 .59189 Mtetra
.026 .426 .865 r
.55479 .59189 .55996 .59709 .56988 .60285 .56471 .59679 Mtetra
.145 .467 .891 r
.56471 .59679 .56988 .60285 .57989 .60831 .57471 .60142 Mtetra
.265 .508 .9 r
.57471 .60142 .57989 .60831 .58996 .61309 .58478 .60543 Mtetra
.374 .543 .894 r
.58478 .60543 .58996 .61309 .60009 .61684 .59491 .6085 Mtetra
.466 .573 .879 r
.59491 .6085 .60009 .61684 .61027 .61923 .60508 .61035 Mtetra
.54 .597 .86 r
.60508 .61035 .61027 .61923 .62047 .62 .61528 .61074 Mtetra
.599 .617 .841 r
.61528 .61074 .62047 .62 .63067 .61899 .62548 .60952 Mtetra
.648 .636 .824 r
.62548 .60952 .63067 .61899 .64085 .61608 .63568 .60659 Mtetra
.688 .654 .81 r
.63568 .60659 .64085 .61608 .65101 .61128 .64586 .60195 Mtetra
.722 .671 .8 r
.64586 .60195 .65101 .61128 .66111 .60467 .656 .59568 Mtetra
.75 .688 .792 r
.656 .59568 .66111 .60467 .67117 .59643 .66609 .58794 Mtetra
.775 .707 .787 r
.66609 .58794 .67117 .59643 .68116 .5868 .67614 .57894 Mtetra
.797 .726 .786 r
.67614 .57894 .68116 .5868 .6911 .57609 .68615 .56896 Mtetra
.815 .747 .789 r
.68615 .56896 .6911 .57609 .701 .56466 .69612 .55834 Mtetra
.83 .77 .795 r
.69612 .55834 .701 .56466 .71086 .55291 .70606 .54741 Mtetra
.842 .796 .807 r
.70606 .54741 .71086 .55291 .72071 .54122 .71599 .53654 Mtetra
.849 .824 .823 r
.71599 .53654 .72071 .54122 .73057 .52999 .72594 .52608 Mtetra
.848 .853 .846 r
.72594 .52608 .73057 .52999 .74047 .51958 .73593 .51634 Mtetra
.837 .884 .876 r
.73593 .51634 .74047 .51958 .75044 .5103 .74598 .50764 Mtetra
.807 .911 .911 r
.74598 .50764 .75044 .5103 .76051 .50243 .75612 .50021 Mtetra
.751 .926 .947 r
.75612 .50021 .76051 .50243 .77071 .49618 .76638 .49424 Mtetra
.659 .919 .977 r
.76638 .49424 .77071 .49618 .78106 .49168 .77679 .48985 Mtetra
.53 .877 .988 r
.77679 .48985 .78106 .49168 .79158 .48899 .78735 .4871 Mtetra
.38 .8 .975 r
.78735 .4871 .79158 .48899 .8023 .48811 .79809 .48598 Mtetra
.239 .705 .946 r
.79809 .48598 .8023 .48811 .81323 .48892 .80901 .4864 Mtetra
.134 .616 .917 r
.80901 .4864 .81323 .48892 .82436 .49129 .82013 .48822 Mtetra
.076 .55 .9 r
.82013 .48822 .82436 .49129 .83568 .49496 .83143 .49122 Mtetra
.066 .51 .896 r
.83143 .49122 .83568 .49496 .8472 .49965 .84289 .49513 Mtetra
.095 .494 .901 r
.84289 .49513 .8472 .49965 .85887 .50502 .85451 .49966 Mtetra
.154 .496 .906 r
.85451 .49966 .85887 .50502 .87068 .51069 .86625 .50445 Mtetra
.23 .509 .907 r
.86625 .50445 .87068 .51069 .88258 .51626 .87808 .50914 Mtetra
.31 .527 .902 r
.87808 .50914 .88258 .51626 .89452 .52133 .88995 .51338 Mtetra
.389 .547 .891 r
.88995 .51338 .89452 .52133 .90646 .52551 .90182 .51681 Mtetra
.46 .568 .877 r
.90182 .51681 .90646 .52551 .91835 .52845 .91366 .51912 Mtetra
.523 .588 .861 r
.91366 .51912 .91835 .52845 .93015 .52985 .92541 .52004 Mtetra
.578 .607 .845 r
.92541 .52004 .93015 .52985 .9418 .5295 .93704 .51937 Mtetra
.626 .626 .831 r
.93704 .51937 .9418 .5295 .95327 .52723 .94852 .51698 Mtetra
.67 .653 .824 r
.33949 .68178 .34504 .69025 .35428 .68678 .34874 .67837 Mtetra
.704 .667 .811 r
.34874 .67837 .35428 .68678 .36363 .68168 .35809 .67349 Mtetra
.732 .681 .8 r
.35809 .67349 .36363 .68168 .37306 .67506 .36752 .66723 Mtetra
.756 .695 .794 r
.36752 .66723 .37306 .67506 .38255 .6671 .37702 .65977 Mtetra
.775 .71 .79 r
.37702 .65977 .38255 .6671 .39209 .65805 .38656 .65132 Mtetra
.792 .726 .791 r
.38656 .65132 .39209 .65805 .40166 .64821 .39613 .64215 Mtetra
.806 .744 .795 r
.39613 .64215 .40166 .64821 .41124 .63791 .40571 .63256 Mtetra
.817 .764 .803 r
.40571 .63256 .41124 .63791 .42081 .62748 .41529 .62285 Mtetra
.825 .786 .816 r
.41529 .62285 .42081 .62748 .43036 .61728 .42486 .61335 Mtetra
.828 .81 .834 r
.42486 .61335 .43036 .61728 .4399 .60764 .43441 .60434 Mtetra
.824 .836 .858 r
.43441 .60434 .4399 .60764 .44941 .59886 .44394 .59612 Mtetra
.809 .863 .888 r
.44394 .59612 .44941 .59886 .4589 .5912 .45346 .5889 Mtetra
.777 .887 .924 r
.45346 .5889 .4589 .5912 .46837 .58488 .46296 .5829 Mtetra
.717 .901 .961 r
.46296 .5829 .46837 .58488 .47783 .58006 .47245 .57825 Mtetra
.62 .89 .988 r
.47245 .57825 .47783 .58006 .4873 .57681 .48195 .57503 Mtetra
.483 .844 .992 r
.48195 .57503 .4873 .57681 .49679 .57517 .49147 .57325 Mtetra
.321 .759 .967 r
.49147 .57325 .49679 .57517 .50631 .57508 .50101 .57289 Mtetra
.17 .657 .923 r
.50101 .57289 .50631 .57508 .51587 .57643 .5106 .57382 Mtetra
.058 .565 .883 r
.5106 .57382 .51587 .57643 .52549 .57904 .52024 .5759 Mtetra
0 .501 .862 r
.52024 .5759 .52549 .57904 .53518 .58268 .52995 .5789 Mtetra
0 .47 .864 r
.52995 .5789 .53518 .58268 .54494 .58707 .53973 .58258 Mtetra
.037 .467 .88 r
.53973 .58258 .54494 .58707 .55479 .59189 .54958 .58664 Mtetra
.115 .484 .899 r
.54958 .58664 .55479 .59189 .56471 .59679 .55951 .59077 Mtetra
.211 .511 .911 r
.55951 .59077 .56471 .59679 .57471 .60142 .56951 .59465 Mtetra
.311 .541 .912 r
.56951 .59465 .57471 .60142 .58478 .60543 .57958 .59797 Mtetra
.404 .567 .902 r
.57958 .59797 .58478 .60543 .59491 .6085 .5897 .60044 Mtetra
.483 .591 .885 r
.5897 .60044 .59491 .6085 .60508 .61035 .59987 .6018 Mtetra
.549 .611 .867 r
.59987 .6018 .60508 .61035 .61528 .61074 .61007 .60185 Mtetra
.604 .629 .849 r
.61007 .60185 .61528 .61074 .62548 .60952 .62028 .60044 Mtetra
.649 .646 .833 r
.62028 .60044 .62548 .60952 .63568 .60659 .6305 .59748 Mtetra
.687 .662 .819 r
.6305 .59748 .63568 .60659 .64586 .60195 .64069 .59299 Mtetra
.719 .678 .809 r
.64069 .59299 .64586 .60195 .656 .59568 .65087 .58702 Mtetra
.746 .694 .802 r
.65087 .58702 .656 .59568 .66609 .58794 .661 .57972 Mtetra
.77 .712 .797 r
.661 .57972 .66609 .58794 .67614 .57894 .67111 .57128 Mtetra
.79 .73 .797 r
.67111 .57128 .67614 .57894 .68615 .56896 .68117 .56197 Mtetra
.807 .75 .799 r
.68117 .56197 .68615 .56896 .69612 .55834 .69121 .55205 Mtetra
.821 .772 .806 r
.69121 .55205 .69612 .55834 .70606 .54741 .70122 .54187 Mtetra
.831 .795 .817 r
.70122 .54187 .70606 .54741 .71599 .53654 .71124 .53172 Mtetra
.837 .82 .833 r
.71124 .53172 .71599 .53654 .72594 .52608 .72127 .52195 Mtetra
.835 .847 .855 r
.72127 .52195 .72594 .52608 .73593 .51634 .73133 .51283 Mtetra
.822 .873 .883 r
.73133 .51283 .73593 .51634 .74598 .50764 .74146 .50464 Mtetra
.795 .896 .915 r
.74146 .50464 .74598 .50764 .75612 .50021 .75167 .49759 Mtetra
.745 .909 .949 r
.75167 .49759 .75612 .50021 .76638 .49424 .76199 .49187 Mtetra
.667 .904 .978 r
.76199 .49187 .76638 .49424 .77679 .48985 .77244 .48758 Mtetra
.561 .872 .994 r
.77244 .48758 .77679 .48985 .78735 .4871 .78304 .48477 Mtetra
.438 .813 .992 r
.78304 .48477 .78735 .4871 .79809 .48598 .7938 .48344 Mtetra
.319 .738 .976 r
.7938 .48344 .79809 .48598 .80901 .4864 .80474 .4835 Mtetra
.226 .663 .955 r
.80474 .4835 .80901 .4864 .82013 .48822 .81584 .48483 Mtetra
.171 .603 .939 r
.81584 .48483 .82013 .48822 .83143 .49122 .82711 .48722 Mtetra
.156 .563 .93 r
.82711 .48722 .83143 .49122 .84289 .49513 .83854 .49043 Mtetra
.175 .542 .927 r
.83854 .49043 .84289 .49513 .85451 .49966 .85011 .4942 Mtetra
.22 .537 .925 r
.85011 .4942 .85451 .49966 .86625 .50445 .8618 .49819 Mtetra
.281 .542 .92 r
.8618 .49819 .86625 .50445 .87808 .50914 .87356 .5021 Mtetra
.348 .554 .911 r
.87356 .5021 .87808 .50914 .88995 .51338 .88537 .50559 Mtetra
.415 .569 .898 r
.88537 .50559 .88995 .51338 .90182 .51681 .89719 .50835 Mtetra
.477 .585 .884 r
.89719 .50835 .90182 .51681 .91366 .51912 .90898 .51009 Mtetra
.534 .602 .868 r
.90898 .51009 .91366 .51912 .92541 .52004 .9207 .51058 Mtetra
.584 .619 .853 r
.9207 .51058 .92541 .52004 .93704 .51937 .93232 .50963 Mtetra
.629 .637 .839 r
.93232 .50963 .93704 .51937 .94852 .51698 .9438 .50713 Mtetra
.67 .661 .833 r
.3339 .67365 .33949 .68178 .34874 .67837 .34316 .67029 Mtetra
.702 .674 .819 r
.34316 .67029 .34874 .67837 .35809 .67349 .35251 .6656 Mtetra
.729 .687 .809 r
.35251 .6656 .35809 .67349 .36752 .66723 .36195 .65967 Mtetra
.752 .7 .803 r
.36195 .65967 .36752 .66723 .37702 .65977 .37144 .65265 Mtetra
.77 .714 .8 r
.37144 .65265 .37702 .65977 .38656 .65132 .38098 .64473 Mtetra
.786 .73 .8 r
.38098 .64473 .38656 .65132 .39613 .64215 .39056 .63616 Mtetra
.799 .746 .804 r
.39056 .63616 .39613 .64215 .40571 .63256 .40014 .62721 Mtetra
.809 .765 .812 r
.40014 .62721 .40571 .63256 .41529 .62285 .40973 .61815 Mtetra
.815 .785 .824 r
.40973 .61815 .41529 .62285 .42486 .61335 .41932 .60926 Mtetra
.817 .807 .842 r
.41932 .60926 .42486 .61335 .43441 .60434 .42889 .60083 Mtetra
.812 .83 .865 r
.42889 .60083 .43441 .60434 .44394 .59612 .43844 .5931 Mtetra
.797 .854 .893 r
.43844 .5931 .44394 .59612 .45346 .5889 .44798 .58628 Mtetra
.766 .874 .926 r
.44798 .58628 .45346 .5889 .46296 .5829 .45751 .58056 Mtetra
.714 .885 .96 r
.45751 .58056 .46296 .5829 .47245 .57825 .46703 .57607 Mtetra
.632 .878 .987 r
.46703 .57607 .47245 .57825 .48195 .57503 .47656 .57286 Mtetra
.52 .843 .998 r
.47656 .57286 .48195 .57503 .49147 .57325 .48611 .57097 Mtetra
.389 .78 .988 r
.48611 .57097 .49147 .57325 .50101 .57289 .49568 .57035 Mtetra
.262 .701 .962 r
.49568 .57035 .50101 .57289 .5106 .57382 .50529 .57091 Mtetra
.164 .625 .934 r
.50529 .57091 .5106 .57382 .52024 .5759 .51496 .5725 Mtetra
.109 .567 .915 r
.51496 .5725 .52024 .5759 .52995 .5789 .52468 .57493 Mtetra
.1 .534 .911 r
.52468 .57493 .52995 .5789 .53973 .58258 .53448 .57796 Mtetra
.13 .525 .916 r
.53448 .57796 .53973 .58258 .54958 .58664 .54434 .58134 Mtetra
.191 .532 .923 r
.54434 .58134 .54958 .58664 .55951 .59077 .55427 .58478 Mtetra
.269 .548 .926 r
.55427 .58478 .55951 .59077 .56951 .59465 .56428 .58799 Mtetra
.352 .569 .92 r
.56428 .58799 .56951 .59465 .57958 .59797 .57435 .59069 Mtetra
.43 .589 .908 r
.57435 .59069 .57958 .59797 .5897 .60044 .58448 .59262 Mtetra
.499 .607 .891 r
.58448 .59262 .5897 .60044 .59987 .6018 .59465 .59355 Mtetra
.558 .624 .873 r
.59465 .59355 .59987 .6018 .61007 .60185 .60485 .59328 Mtetra
.608 .64 .856 r
.60485 .59328 .61007 .60185 .62028 .60044 .61507 .59169 Mtetra
.65 .655 .841 r
.61507 .59169 .62028 .60044 .6305 .59748 .6253 .58872 Mtetra
.686 .669 .828 r
.6253 .58872 .6305 .59748 .64069 .59299 .63552 .58435 Mtetra
.716 .684 .818 r
.63552 .58435 .64069 .59299 .65087 .58702 .64572 .57865 Mtetra
.742 .7 .811 r
.64572 .57865 .65087 .58702 .661 .57972 .6559 .57174 Mtetra
.765 .716 .807 r
.6559 .57174 .661 .57972 .67111 .57128 .66605 .56381 Mtetra
.784 .734 .806 r
.66605 .56381 .67111 .57128 .68117 .56197 .67617 .55507 Mtetra
.8 .752 .809 r
.67617 .55507 .68117 .56197 .69121 .55205 .68627 .5458 Mtetra
.812 .772 .816 r
.68627 .5458 .69121 .55205 .70122 .54187 .69636 .53627 Mtetra
.821 .794 .827 r
.69636 .53627 .70122 .54187 .71124 .53172 .70644 .52678 Mtetra
.825 .817 .842 r
.70644 .52678 .71124 .53172 .72127 .52195 .71655 .51762 Mtetra
.822 .841 .863 r
.71655 .51762 .72127 .52195 .73133 .51283 .72669 .50905 Mtetra
.809 .863 .889 r
.72669 .50905 .73133 .51283 .74146 .50464 .73688 .50132 Mtetra
.783 .883 .918 r
.73688 .50132 .74146 .50464 .75167 .49759 .74716 .49462 Mtetra
.738 .893 .95 r
.74716 .49462 .75167 .49759 .76199 .49187 .75754 .48912 Mtetra
.671 .889 .977 r
.75754 .48912 .76199 .49187 .77244 .48758 .76803 .48491 Mtetra
.583 .864 .995 r
.76803 .48491 .77244 .48758 .78304 .48477 .77867 .48205 Mtetra
.481 .818 .999 r
.77867 .48205 .78304 .48477 .7938 .48344 .78945 .48053 Mtetra
.382 .757 .991 r
.78945 .48053 .7938 .48344 .80474 .4835 .80039 .48026 Mtetra
.301 .695 .976 r
.80039 .48026 .80474 .4835 .81584 .48483 .81149 .48114 Mtetra
.25 .642 .962 r
.81149 .48114 .81584 .48483 .82711 .48722 .82275 .48298 Mtetra
.232 .603 .952 r
.82275 .48298 .82711 .48722 .83854 .49043 .83415 .48557 Mtetra
.243 .58 .944 r
.83415 .48557 .83854 .49043 .85011 .4942 .84568 .48864 Mtetra
.277 .571 .937 r
.84568 .48864 .85011 .4942 .8618 .49819 .85731 .49193 Mtetra
.325 .571 .929 r
.85731 .49193 .8618 .49819 .87356 .5021 .86903 .49513 Mtetra
.381 .578 .918 r
.86903 .49513 .87356 .5021 .88537 .50559 .88079 .49794 Mtetra
.438 .589 .904 r
.88079 .49794 .88537 .50559 .89719 .50835 .89257 .5001 Mtetra
.493 .602 .889 r
.89257 .5001 .89719 .50835 .90898 .51009 .90432 .50133 Mtetra
.544 .616 .874 r
.90432 .50133 .90898 .51009 .9207 .51058 .91601 .50143 Mtetra
.59 .631 .86 r
.91601 .50143 .9207 .51058 .93232 .50963 .92762 .50023 Mtetra
.632 .647 .847 r
.92762 .50023 .93232 .50963 .9438 .50713 .93911 .49762 Mtetra
.669 .669 .841 r
.32827 .66582 .3339 .67365 .34316 .67029 .33754 .6625 Mtetra
.7 .681 .828 r
.33754 .6625 .34316 .67029 .35251 .6656 .3469 .65799 Mtetra
.726 .693 .818 r
.3469 .65799 .35251 .6656 .36195 .65967 .35633 .65234 Mtetra
.747 .705 .812 r
.35633 .65234 .36195 .65967 .37144 .65265 .36583 .64571 Mtetra
.765 .719 .809 r
.36583 .64571 .37144 .65265 .38098 .64473 .37537 .63827 Mtetra
.78 .733 .809 r
.37537 .63827 .38098 .64473 .39056 .63616 .38495 .63024 Mtetra
.792 .749 .813 r
.38495 .63024 .39056 .63616 .40014 .62721 .39454 .62185 Mtetra
.801 .766 .821 r
.39454 .62185 .40014 .62721 .40973 .61815 .40414 .61336 Mtetra
.806 .784 .833 r
.40414 .61336 .40973 .61815 .41932 .60926 .41374 .60503 Mtetra
.806 .804 .849 r
.41374 .60503 .41932 .60926 .42889 .60083 .42333 .59711 Mtetra
.8 .825 .87 r
.42333 .59711 .42889 .60083 .43844 .5931 .4329 .58982 Mtetra
.785 .845 .897 r
.4329 .58982 .43844 .5931 .44798 .58628 .44246 .58336 Mtetra
.757 .862 .926 r
.44246 .58336 .44798 .58628 .45751 .58056 .45202 .5779 Mtetra
.71 .871 .957 r
.45202 .5779 .45751 .58056 .46703 .57607 .46157 .57353 Mtetra
.64 .865 .984 r
.46157 .57353 .46703 .57607 .47656 .57286 .47113 .57034 Mtetra
.548 .839 .998 r
.47113 .57034 .47656 .57286 .48611 .57097 .4807 .56834 Mtetra
.441 .791 .997 r
.4807 .56834 .48611 .57097 .49568 .57035 .49031 .56749 Mtetra
.336 .729 .983 r
.49031 .56749 .49568 .57035 .50529 .57091 .49995 .56771 Mtetra
.252 .667 .964 r
.49995 .56771 .50529 .57091 .51496 .5725 .50963 .56887 Mtetra
.201 .616 .949 r
.50963 .56887 .51496 .5725 .52468 .57493 .51938 .57078 Mtetra
.188 .584 .941 r
.51938 .57078 .52468 .57493 .53448 .57796 .52919 .57324 Mtetra
.209 .57 .939 r
.52919 .57324 .53448 .57796 .54434 .58134 .53906 .576 Mtetra
.256 .57 .939 r
.53906 .576 .54434 .58134 .55427 .58478 .54901 .57882 Mtetra
.318 .579 .935 r
.54901 .57882 .55427 .58478 .56428 .58799 .55902 .58143 Mtetra
.386 .592 .926 r
.55902 .58143 .56428 .58799 .57435 .59069 .56909 .58357 Mtetra
.453 .607 .913 r
.56909 .58357 .57435 .59069 .58448 .59262 .57923 .58501 Mtetra
.514 .622 .896 r
.57923 .58501 .58448 .59262 .59465 .59355 .5894 .58554 Mtetra
.567 .636 .879 r
.5894 .58554 .59465 .59355 .60485 .59328 .59961 .585 Mtetra
.612 .65 .863 r
.59961 .585 .60485 .59328 .61507 .59169 .60985 .58326 Mtetra
.651 .663 .848 r
.60985 .58326 .61507 .59169 .6253 .58872 .62009 .58026 Mtetra
.685 .677 .836 r
.62009 .58026 .6253 .58872 .63552 .58435 .63033 .576 Mtetra
.714 .691 .827 r
.63033 .576 .63552 .58435 .64572 .57865 .64056 .57054 Mtetra
.738 .705 .82 r
.64056 .57054 .64572 .57865 .6559 .57174 .65078 .56398 Mtetra
.759 .72 .816 r
.65078 .56398 .6559 .57174 .66605 .56381 .66097 .55649 Mtetra
.777 .737 .816 r
.66097 .55649 .66605 .56381 .67617 .55507 .67115 .54827 Mtetra
.792 .754 .819 r
.67115 .54827 .67617 .55507 .68627 .5458 .6813 .53957 Mtetra
.803 .773 .825 r
.6813 .53957 .68627 .5458 .69636 .53627 .69145 .53063 Mtetra
.811 .793 .835 r
.69145 .53063 .69636 .53627 .70644 .52678 .70161 .52172 Mtetra
.813 .813 .85 r
.70161 .52172 .70644 .52678 .71655 .51762 .71178 .51311 Mtetra
.809 .834 .87 r
.71178 .51311 .71655 .51762 .72669 .50905 .72199 .50503 Mtetra
.796 .854 .893 r
.72199 .50503 .72669 .50905 .73688 .50132 .73225 .4977 Mtetra
.772 .87 .92 r
.73225 .4977 .73688 .50132 .74716 .49462 .74259 .49132 Mtetra
.732 .878 .949 r
.74259 .49132 .74716 .49462 .75754 .48912 .75302 .48601 Mtetra
.674 .874 .974 r
.75302 .48601 .75754 .48912 .76803 .48491 .76356 .48188 Mtetra
.599 .854 .992 r
.76356 .48188 .76803 .48491 .77867 .48205 .77423 .47897 Mtetra
.515 .817 1 r
.77423 .47897 .77867 .48205 .78945 .48053 .78504 .47727 Mtetra
.431 .768 .997 r
.78504 .47727 .78945 .48053 .80039 .48026 .79599 .47671 Mtetra
.362 .716 .987 r
.79599 .47671 .80039 .48026 .81149 .48114 .80709 .47718 Mtetra
.315 .67 .975 r
.80709 .47718 .81149 .48114 .82275 .48298 .81833 .47853 Mtetra
.295 .634 .964 r
.81833 .47853 .82275 .48298 .83415 .48557 .82971 .48055 Mtetra
.3 .61 .954 r
.82971 .48055 .83415 .48557 .84568 .48864 .84121 .48301 Mtetra
.326 .598 .945 r
.84121 .48301 .84568 .48864 .85731 .49193 .8528 .48565 Mtetra
.364 .595 .935 r
.8528 .48565 .85731 .49193 .86903 .49513 .86448 .48821 Mtetra
.411 .598 .923 r
.86448 .48821 .86903 .49513 .88079 .49794 .8762 .49043 Mtetra
.46 .606 .909 r
.8762 .49043 .88079 .49794 .89257 .5001 .88794 .49204 Mtetra
.508 .616 .895 r
.88794 .49204 .89257 .5001 .90432 .50133 .89966 .49281 Mtetra
.554 .628 .88 r
.89966 .49281 .90432 .50133 .91601 .50143 .91133 .49256 Mtetra
.596 .642 .866 r
.91133 .49256 .91601 .50143 .92762 .50023 .92294 .49113 Mtetra
.634 .656 .854 r
.92294 .49113 .92762 .50023 .93911 .49762 .93444 .48843 Mtetra
.669 .677 .848 r
.32259 .65826 .32827 .66582 .33754 .6625 .33187 .65498 Mtetra
.698 .687 .836 r
.33187 .65498 .33754 .6625 .3469 .65799 .34123 .65061 Mtetra
.723 .698 .827 r
.34123 .65061 .3469 .65799 .35633 .65234 .35067 .64523 Mtetra
.743 .71 .82 r
.35067 .64523 .35633 .65234 .36583 .64571 .36018 .63894 Mtetra
.76 .722 .818 r
.36018 .63894 .36583 .64571 .37537 .63827 .36973 .63192 Mtetra
.774 .736 .818 r
.36973 .63192 .37537 .63827 .38495 .63024 .37931 .62436 Mtetra
.785 .75 .822 r
.37931 .62436 .38495 .63024 .39454 .62185 .38891 .61648 Mtetra
.793 .766 .829 r
.38891 .61648 .39454 .62185 .40414 .61336 .39852 .60851 Mtetra
.797 .783 .84 r
.39852 .60851 .40414 .61336 .41374 .60503 .40813 .60067 Mtetra
.796 .801 .856 r
.40813 .60067 .41374 .60503 .42333 .59711 .41773 .59321 Mtetra
.79 .819 .875 r
.41773 .59321 .42333 .59711 .4329 .58982 .42732 .58631 Mtetra
.775 .837 .899 r
.42732 .58631 .4329 .58982 .44246 .58336 .43691 .58017 Mtetra
.748 .851 .927 r
.43691 .58017 .44246 .58336 .45202 .5779 .44649 .57492 Mtetra
.706 .858 .954 r
.44649 .57492 .45202 .5779 .46157 .57353 .45607 .57068 Mtetra
.646 .853 .979 r
.45607 .57068 .46157 .57353 .47113 .57034 .46566 .5675 Mtetra
.569 .832 .995 r
.46566 .5675 .47113 .57034 .4807 .56834 .47526 .5654 Mtetra
.48 .795 .999 r
.47526 .5654 .4807 .56834 .49031 .56749 .48489 .56435 Mtetra
.393 .746 .993 r
.48489 .56435 .49031 .56749 .49995 .56771 .49456 .56426 Mtetra
.321 .695 .98 r
.49456 .56426 .49995 .56771 .50963 .56887 .50427 .56502 Mtetra
.276 .651 .968 r
.50427 .56502 .50963 .56887 .51938 .57078 .51403 .56647 Mtetra
.261 .621 .959 r
.51403 .56647 .51938 .57078 .52919 .57324 .52386 .5684 Mtetra
.274 .605 .953 r
.52386 .5684 .52919 .57324 .53906 .576 .53375 .57062 Mtetra
.31 .6 .948 r
.53375 .57062 .53906 .576 .54901 .57882 .54371 .57288 Mtetra
.36 .604 .941 r
.54371 .57288 .54901 .57882 .55902 .58143 .55373 .57495 Mtetra
.417 .613 .931 r
.55373 .57495 .55902 .58143 .56909 .58357 .56381 .57659 Mtetra
.473 .624 .917 r
.56381 .57659 .56909 .58357 .57923 .58501 .57395 .57759 Mtetra
.527 .635 .901 r
.57395 .57759 .57923 .58501 .5894 .58554 .58413 .57777 Mtetra
.574 .647 .885 r
.58413 .57777 .5894 .58554 .59961 .585 .59435 .57697 Mtetra
.616 .659 .869 r
.59435 .57697 .59961 .585 .60985 .58326 .6046 .57509 Mtetra
.652 .671 .855 r
.6046 .57509 .60985 .58326 .62009 .58026 .61486 .57207 Mtetra
.684 .684 .844 r
.61486 .57207 .62009 .58026 .63033 .576 .62513 .56791 Mtetra
.711 .697 .835 r
.62513 .56791 .63033 .576 .64056 .57054 .63539 .56265 Mtetra
.734 .71 .829 r
.63539 .56265 .64056 .57054 .65078 .56398 .64564 .5564 Mtetra
.754 .725 .825 r
.64564 .5564 .65078 .56398 .66097 .55649 .65587 .54931 Mtetra
.771 .74 .825 r
.65587 .54931 .66097 .55649 .67115 .54827 .6661 .54156 Mtetra
.784 .756 .827 r
.6661 .54156 .67115 .54827 .6813 .53957 .67631 .53336 Mtetra
.794 .773 .834 r
.67631 .53336 .6813 .53957 .69145 .53063 .68652 .52494 Mtetra
.801 .791 .843 r
.68652 .52494 .69145 .53063 .70161 .52172 .69673 .51655 Mtetra
.802 .81 .857 r
.69673 .51655 .70161 .52172 .71178 .51311 .70697 .50842 Mtetra
.798 .828 .875 r
.70697 .50842 .71178 .51311 .72199 .50503 .71724 .50078 Mtetra
.785 .845 .897 r
.71724 .50078 .72199 .50503 .73225 .4977 .72757 .49382 Mtetra
.762 .858 .921 r
.72757 .49382 .73225 .4977 .74259 .49132 .73796 .48771 Mtetra
.725 .865 .947 r
.73796 .48771 .74259 .49132 .75302 .48601 .74844 .48258 Mtetra
.675 .861 .97 r
.74844 .48258 .75302 .48601 .76356 .48188 .75903 .47852 Mtetra
.612 .844 .988 r
.75903 .47852 .76356 .48188 .77423 .47897 .76973 .47556 Mtetra
.54 .814 .996 r
.76973 .47556 .77423 .47897 .78504 .47727 .78056 .47369 Mtetra
.47 .774 .997 r
.78056 .47369 .78504 .47727 .79599 .47671 .79153 .47287 Mtetra
.41 .73 .99 r
.79153 .47287 .79599 .47671 .80709 .47718 .80263 .47298 Mtetra
.368 .69 .981 r
.80263 .47298 .80709 .47718 .81833 .47853 .81386 .47387 Mtetra
.348 .657 .97 r
.81386 .47387 .81833 .47853 .82971 .48055 .82522 .47538 Mtetra
.349 .634 .96 r
.82522 .47538 .82971 .48055 .84121 .48301 .8367 .47728 Mtetra
.367 .621 .95 r
.8367 .47728 .84121 .48301 .8528 .48565 .84827 .47935 Mtetra
.398 .616 .938 r
.84827 .47935 .8528 .48565 .86448 .48821 .85991 .48134 Mtetra
.436 .616 .926 r
.85991 .48134 .86448 .48821 .8762 .49043 .8716 .48301 Mtetra
.479 .622 .913 r
.8716 .48301 .8762 .49043 .88794 .49204 .8833 .48414 Mtetra
.521 .63 .899 r
.8833 .48414 .88794 .49204 .89966 .49281 .895 .4845 Mtetra
.562 .64 .885 r
.895 .4845 .89966 .49281 .91133 .49256 .90667 .48393 Mtetra
.601 .652 .872 r
.90667 .48393 .91133 .49256 .92294 .49113 .91827 .4823 Mtetra
.636 .665 .861 r
.91827 .4823 .92294 .49113 .93444 .48843 .92979 .47951 Mtetra
.669 .684 .855 r
.31686 .65093 .32259 .65826 .33187 .65498 .32615 .64769 Mtetra
.696 .694 .843 r
.32615 .64769 .33187 .65498 .34123 .65061 .33553 .64345 Mtetra
.72 .704 .834 r
.33553 .64345 .34123 .65061 .35067 .64523 .34498 .63829 Mtetra
.739 .715 .829 r
.34498 .63829 .35067 .64523 .36018 .63894 .35448 .63232 Mtetra
.755 .726 .826 r
.35448 .63232 .36018 .63894 .36973 .63192 .36404 .62567 Mtetra
.768 .739 .826 r
.36404 .62567 .36973 .63192 .37931 .62436 .37363 .61853 Mtetra
.778 .752 .83 r
.37363 .61853 .37931 .62436 .38891 .61648 .38323 .6111 Mtetra
.785 .767 .837 r
.38323 .6111 .38891 .61648 .39852 .60851 .39285 .60358 Mtetra
.788 .782 .847 r
.39285 .60358 .39852 .60851 .40813 .60067 .40248 .59619 Mtetra
.787 .798 .862 r
.40248 .59619 .40813 .60067 .41773 .59321 .4121 .58913 Mtetra
.78 .814 .88 r
.4121 .58913 .41773 .59321 .42732 .58631 .42171 .58258 Mtetra
.765 .829 .902 r
.42171 .58258 .42732 .58631 .43691 .58017 .43132 .57672 Mtetra
.74 .84 .926 r
.43132 .57672 .43691 .58017 .44649 .57492 .44093 .57167 Mtetra
.702 .846 .951 r
.44093 .57167 .44649 .57492 .45607 .57068 .45053 .56754 Mtetra
.65 .842 .974 r
.45053 .56754 .45607 .57068 .46566 .5675 .46015 .56437 Mtetra
.585 .825 .99 r
.46015 .56437 .46566 .5675 .47526 .5654 .46978 .56217 Mtetra
.511 .795 .997 r
.46978 .56217 .47526 .5654 .48489 .56435 .47944 .56093 Mtetra
.438 .756 .995 r
.47944 .56093 .48489 .56435 .49456 .56426 .48913 .56057 Mtetra
.377 .714 .987 r
.48913 .56057 .49456 .56426 .50427 .56502 .49886 .56097 Mtetra
.336 .677 .978 r
.49886 .56097 .50427 .56502 .51403 .56647 .50865 .562 Mtetra
.32 .649 .969 r
.50865 .562 .51403 .56647 .52386 .5684 .5185 .56347 Mtetra
.328 .632 .961 r
.5185 .56347 .52386 .5684 .53375 .57062 .5284 .56519 Mtetra
.355 .625 .954 r
.5284 .56519 .53375 .57062 .54371 .57288 .53837 .56695 Mtetra
.396 .625 .945 r
.53837 .56695 .54371 .57288 .55373 .57495 .54841 .56853 Mtetra
.443 .63 .934 r
.54841 .56853 .55373 .57495 .56381 .57659 .5585 .56973 Mtetra
.492 .638 .92 r
.5585 .56973 .56381 .57659 .57395 .57759 .56865 .57034 Mtetra
.538 .647 .905 r
.56865 .57034 .57395 .57759 .58413 .57777 .57884 .5702 Mtetra
.581 .657 .889 r
.57884 .5702 .58413 .57777 .59435 .57697 .58907 .56918 Mtetra
.619 .668 .875 r
.58907 .56918 .59435 .57697 .6046 .57509 .59933 .56717 Mtetra
.653 .679 .862 r
.59933 .56717 .6046 .57509 .61486 .57207 .60961 .56413 Mtetra
.682 .69 .851 r
.60961 .56413 .61486 .57207 .62513 .56791 .6199 .56004 Mtetra
.708 .702 .843 r
.6199 .56004 .62513 .56791 .63539 .56265 .63019 .55497 Mtetra
.73 .715 .837 r
.63019 .55497 .63539 .56265 .64564 .5564 .64047 .549 Mtetra
.749 .728 .833 r
.64047 .549 .64564 .5564 .65587 .54931 .65075 .54225 Mtetra
.764 .742 .833 r
.65075 .54225 .65587 .54931 .6661 .54156 .66102 .53491 Mtetra
.777 .757 .835 r
.66102 .53491 .6661 .54156 .67631 .53336 .67128 .52716 Mtetra
.786 .773 .841 r
.67128 .52716 .67631 .53336 .68652 .52494 .68155 .51921 Mtetra
.791 .79 .851 r
.68155 .51921 .68652 .52494 .69673 .51655 .69182 .51128 Mtetra
.792 .806 .864 r
.69182 .51128 .69673 .51655 .70697 .50842 .70212 .50358 Mtetra
.787 .822 .88 r
.70212 .50358 .70697 .50842 .71724 .50078 .71245 .49633 Mtetra
.774 .837 .9 r
.71245 .49633 .71724 .50078 .72757 .49382 .72283 .48969 Mtetra
.752 .847 .922 r
.72283 .48969 .72757 .49382 .73796 .48771 .73328 .48383 Mtetra
.72 .852 .945 r
.73328 .48383 .73796 .48771 .74844 .48258 .74381 .47885 Mtetra
.675 .848 .966 r
.74381 .47885 .74844 .48258 .75903 .47852 .75444 .47484 Mtetra
.621 .834 .982 r
.75444 .47484 .75903 .47852 .76973 .47556 .76517 .47184 Mtetra
.56 .809 .992 r
.76517 .47184 .76973 .47556 .78056 .47369 .77603 .46983 Mtetra
.5 .776 .994 r
.77603 .46983 .78056 .47369 .79153 .47287 .78701 .46876 Mtetra
.448 .739 .99 r
.78701 .46876 .79153 .47287 .80263 .47298 .79812 .46854 Mtetra
.411 .704 .982 r
.79812 .46854 .80263 .47298 .81386 .47387 .80935 .46903 Mtetra
.391 .675 .973 r
.80935 .46903 .81386 .47387 .82522 .47538 .8207 .47008 Mtetra
.389 .653 .963 r
.8207 .47008 .82522 .47538 .8367 .47728 .83215 .47148 Mtetra
.402 .639 .952 r
.83215 .47148 .8367 .47728 .84827 .47935 .8437 .47303 Mtetra
.427 .633 .941 r
.8437 .47303 .84827 .47935 .85991 .48134 .85531 .47451 Mtetra
.459 .632 .929 r
.85531 .47451 .85991 .48134 .8716 .48301 .86698 .4757 Mtetra
.495 .635 .916 r
.86698 .4757 .8716 .48301 .8833 .48414 .87866 .47638 Mtetra
.533 .642 .903 r
.87866 .47638 .8833 .48414 .895 .4845 .89035 .47638 Mtetra
.57 .651 .89 r
.89035 .47638 .895 .4845 .90667 .48393 .902 .47552 Mtetra
.605 .661 .878 r
.902 .47552 .90667 .48393 .91827 .4823 .91361 .4737 Mtetra
.638 .673 .867 r
.91361 .4737 .91827 .4823 .92979 .47951 .92514 .47083 Mtetra
.668 .691 .862 r
.31109 .64383 .31686 .65093 .32615 .64769 .3204 .64061 Mtetra
.694 .699 .85 r
.3204 .64061 .32615 .64769 .33553 .64345 .32978 .63649 Mtetra
.716 .709 .842 r
.32978 .63649 .33553 .64345 .34498 .63829 .33924 .63152 Mtetra
.735 .719 .836 r
.33924 .63152 .34498 .63829 .35448 .63232 .34875 .62582 Mtetra
.75 .73 .834 r
.34875 .62582 .35448 .63232 .36404 .62567 .35831 .61951 Mtetra
.762 .741 .834 r
.35831 .61951 .36404 .62567 .37363 .61853 .36791 .61274 Mtetra
.771 .754 .837 r
.36791 .61274 .37363 .61853 .38323 .6111 .37752 .60571 Mtetra
.777 .767 .844 r
.37752 .60571 .38323 .6111 .39285 .60358 .38716 .59859 Mtetra
.78 .781 .853 r
.38716 .59859 .39285 .60358 .40248 .59619 .39679 .59159 Mtetra
.778 .795 .867 r
.39679 .59159 .40248 .59619 .4121 .58913 .40643 .58489 Mtetra
.771 .809 .884 r
.40643 .58489 .4121 .58913 .42171 .58258 .41606 .57865 Mtetra
.756 .822 .903 r
.41606 .57865 .42171 .58258 .43132 .57672 .42569 .57304 Mtetra
.733 .831 .926 r
.42569 .57304 .43132 .57672 .44093 .57167 .43532 .56817 Mtetra
.699 .835 .948 r
.43532 .56817 .44093 .57167 .45053 .56754 .44496 .56412 Mtetra
.653 .831 .968 r
.44496 .56412 .45053 .56754 .46015 .56437 .4546 .56095 Mtetra
.597 .817 .984 r
.4546 .56095 .46015 .56437 .46978 .56217 .46426 .55868 Mtetra
.535 .793 .992 r
.46426 .55868 .46978 .56217 .47944 .56093 .47394 .55727 Mtetra
.473 .761 .993 r
.47394 .55727 .47944 .56093 .48913 .56057 .48366 .55666 Mtetra
.421 .726 .989 r
.48366 .55666 .48913 .56057 .49886 .56097 .49342 .55674 Mtetra
.385 .694 .981 r
.49342 .55674 .49886 .56097 .50865 .562 .50323 .55739 Mtetra
.369 .669 .973 r
.50323 .55739 .50865 .562 .5185 .56347 .5131 .55844 Mtetra
.373 .652 .965 r
.5131 .55844 .5185 .56347 .5284 .56519 .52302 .55972 Mtetra
.393 .644 .957 r
.52302 .55972 .5284 .56519 .53837 .56695 .533 .56103 Mtetra
.426 .642 .947 r
.533 .56103 .53837 .56695 .54841 .56853 .54305 .56218 Mtetra
.465 .645 .936 r
.54305 .56218 .54841 .56853 .5585 .56973 .55316 .56297 Mtetra
.507 .651 .922 r
.55316 .56297 .5585 .56973 .56865 .57034 .56331 .56324 Mtetra
.549 .658 .908 r
.56331 .56324 .56865 .57034 .57884 .5702 .57352 .56281 Mtetra
.587 .667 .894 r
.57352 .56281 .57884 .5702 .58907 .56918 .58377 .56158 Mtetra
.622 .676 .88 r
.58377 .56158 .58907 .56918 .59933 .56717 .59404 .55946 Mtetra
.654 .686 .868 r
.59404 .55946 .59933 .56717 .60961 .56413 .60434 .55639 Mtetra
.681 .697 .858 r
.60434 .55639 .60961 .56413 .6199 .56004 .61465 .55238 Mtetra
.705 .708 .85 r
.61465 .55238 .6199 .56004 .63019 .55497 .62497 .54747 Mtetra
.726 .719 .844 r
.62497 .54747 .63019 .55497 .64047 .549 .63529 .54173 Mtetra
.744 .732 .841 r
.63529 .54173 .64047 .549 .65075 .54225 .6456 .5353 Mtetra
.758 .745 .84 r
.6456 .5353 .65075 .54225 .66102 .53491 .65592 .52832 Mtetra
.77 .759 .843 r
.65592 .52832 .66102 .53491 .67128 .52716 .66623 .52096 Mtetra
.778 .773 .848 r
.66623 .52096 .67128 .52716 .68155 .51921 .67654 .51342 Mtetra
.782 .788 .857 r
.67654 .51342 .68155 .51921 .69182 .51128 .68687 .5059 Mtetra
.782 .803 .869 r
.68687 .5059 .69182 .51128 .70212 .50358 .69722 .49859 Mtetra
.777 .817 .884 r
.69722 .49859 .70212 .50358 .71245 .49633 .70761 .49168 Mtetra
.764 .829 .902 r
.70761 .49168 .71245 .49633 .72283 .48969 .71805 .48533 Mtetra
.744 .838 .922 r
.71805 .48533 .72283 .48969 .73328 .48383 .72855 .47968 Mtetra
.714 .841 .942 r
.72855 .47968 .73328 .48383 .74381 .47885 .73913 .47484 Mtetra
.675 .837 .961 r
.73913 .47484 .74381 .47885 .75444 .47484 .74979 .47088 Mtetra
.628 .825 .976 r
.74979 .47088 .75444 .47484 .76517 .47184 .76056 .46783 Mtetra
.576 .804 .986 r
.76056 .46783 .76517 .47184 .77603 .46983 .77144 .46569 Mtetra
.524 .776 .989 r
.77144 .46569 .77603 .46983 .78701 .46876 .78244 .4644 Mtetra
.479 .744 .987 r
.78244 .4644 .78701 .46876 .79812 .46854 .79355 .46388 Mtetra
.446 .714 .981 r
.79355 .46388 .79812 .46854 .80935 .46903 .80479 .46402 Mtetra
.427 .688 .973 r
.80479 .46402 .80935 .46903 .8207 .47008 .81613 .46465 Mtetra
.423 .668 .963 r
.81613 .46465 .8207 .47008 .83215 .47148 .82757 .4656 Mtetra
.432 .655 .953 r
.82757 .4656 .83215 .47148 .8437 .47303 .8391 .46669 Mtetra
.452 .647 .942 r
.8391 .46669 .8437 .47303 .85531 .47451 .8507 .46771 Mtetra
.479 .645 .931 r
.8507 .46771 .85531 .47451 .86698 .4757 .86234 .46846 Mtetra
.51 .648 .919 r
.86234 .46846 .86698 .4757 .87866 .47638 .87401 .46875 Mtetra
.544 .653 .906 r
.87401 .46875 .87866 .47638 .89035 .47638 .88568 .46842 Mtetra
.577 .66 .894 r
.88568 .46842 .89035 .47638 .902 .47552 .89734 .46731 Mtetra
.609 .67 .883 r
.89734 .46731 .902 .47552 .91361 .4737 .90895 .46532 Mtetra
.639 .68 .873 r
.90895 .46532 .91361 .4737 .92514 .47083 .9205 .46238 Mtetra
.668 .697 .868 r
.30528 .63691 .31109 .64383 .3204 .64061 .31459 .63371 Mtetra
.693 .705 .857 r
.31459 .63371 .3204 .64061 .32978 .63649 .32399 .62969 Mtetra
.713 .714 .849 r
.32399 .62969 .32978 .63649 .33924 .63152 .33345 .6249 Mtetra
.731 .723 .843 r
.33345 .6249 .33924 .63152 .34875 .62582 .34298 .61944 Mtetra
.745 .733 .841 r
.34298 .61944 .34875 .62582 .35831 .61951 .35254 .61341 Mtetra
.756 .744 .841 r
.35254 .61341 .35831 .61951 .36791 .61274 .36215 .60698 Mtetra
.765 .755 .844 r
.36215 .60698 .36791 .61274 .37752 .60571 .37178 .60029 Mtetra
.77 .767 .85 r
.37178 .60029 .37752 .60571 .38716 .59859 .38142 .59354 Mtetra
.772 .779 .859 r
.38142 .59354 .38716 .59859 .39679 .59159 .39107 .58688 Mtetra
.769 .792 .871 r
.39107 .58688 .39679 .59159 .40643 .58489 .40072 .58049 Mtetra
.762 .804 .887 r
.40072 .58049 .40643 .58489 .41606 .57865 .41038 .57454 Mtetra
.748 .815 .905 r
.41038 .57454 .41606 .57865 .42569 .57304 .42003 .56914 Mtetra
.726 .823 .925 r
.42003 .56914 .42569 .57304 .43532 .56817 .42968 .56442 Mtetra
.696 .826 .945 r
.42968 .56442 .43532 .56817 .44496 .56412 .43934 .56045 Mtetra
.655 .822 .963 r
.43934 .56045 .44496 .56412 .4546 .56095 .44901 .55729 Mtetra
.607 .81 .978 r
.44901 .55729 .4546 .56095 .46426 .55868 .4587 .55494 Mtetra
.554 .79 .987 r
.4587 .55494 .46426 .55868 .47394 .55727 .46841 .55337 Mtetra
.501 .763 .989 r
.46841 .55337 .47394 .55727 .48366 .55666 .47815 .55254 Mtetra
.456 .734 .987 r
.47815 .55254 .48366 .55666 .49342 .55674 .48794 .55234 Mtetra
.424 .707 .981 r
.48794 .55234 .49342 .55674 .50323 .55739 .49777 .55265 Mtetra
.409 .684 .974 r
.49777 .55265 .50323 .55739 .5131 .55844 .50766 .55333 Mtetra
.41 .669 .967 r
.50766 .55333 .5131 .55844 .52302 .55972 .5176 .55421 Mtetra
.425 .66 .958 r
.5176 .55421 .52302 .55972 .533 .56103 .5276 .55512 Mtetra
.452 .656 .948 r
.5276 .55512 .533 .56103 .54305 .56218 .53766 .55588 Mtetra
.485 .658 .937 r
.53766 .55588 .54305 .56218 .55316 .56297 .54778 .55631 Mtetra
.521 .662 .924 r
.54778 .55631 .55316 .56297 .56331 .56324 .55795 .55626 Mtetra
.558 .668 .911 r
.55795 .55626 .56331 .56324 .57352 .56281 .56817 .55558 Mtetra
.593 .676 .898 r
.56817 .55558 .57352 .56281 .58377 .56158 .57843 .55417 Mtetra
.625 .684 .885 r
.57843 .55417 .58377 .56158 .59404 .55946 .58873 .55194 Mtetra
.654 .693 .874 r
.58873 .55194 .59404 .55946 .60434 .55639 .59904 .54885 Mtetra
.68 .703 .864 r
.59904 .54885 .60434 .55639 .61465 .55238 .60938 .5449 Mtetra
.703 .713 .856 r
.60938 .5449 .61465 .55238 .62497 .54747 .61972 .54013 Mtetra
.722 .724 .851 r
.61972 .54013 .62497 .54747 .63529 .54173 .63007 .5346 Mtetra
.739 .735 .848 r
.63007 .5346 .63529 .54173 .6456 .5353 .64043 .52844 Mtetra
.752 .747 .848 r
.64043 .52844 .6456 .5353 .65592 .52832 .65078 .52178 Mtetra
.763 .76 .85 r
.65078 .52178 .65592 .52832 .66623 .52096 .66114 .51477 Mtetra
.77 .773 .855 r
.66114 .51477 .66623 .52096 .67654 .51342 .6715 .5076 Mtetra
.774 .786 .863 r
.6715 .5076 .67654 .51342 .68687 .5059 .68188 .50044 Mtetra
.773 .799 .874 r
.68188 .50044 .68687 .5059 .69722 .49859 .69229 .49347 Mtetra
.767 .811 .888 r
.69229 .49347 .69722 .49859 .70761 .49168 .70273 .48686 Mtetra
.755 .821 .904 r
.70273 .48686 .70761 .49168 .71805 .48533 .71322 .48076 Mtetra
.736 .829 .922 r
.71322 .48076 .71805 .48533 .72855 .47968 .72376 .4753 Mtetra
.709 .831 .94 r
.72376 .4753 .72855 .47968 .73913 .47484 .73439 .47057 Mtetra
.675 .827 .957 r
.73439 .47057 .73913 .47484 .74979 .47088 .74509 .46665 Mtetra
.633 .816 .97 r
.74509 .46665 .74979 .47088 .76056 .46783 .75589 .46356 Mtetra
.588 .798 .98 r
.75589 .46356 .76056 .46783 .77144 .46569 .7668 .46129 Mtetra
.543 .774 .984 r
.7668 .46129 .77144 .46569 .78244 .4644 .77782 .45981 Mtetra
.504 .747 .983 r
.77782 .45981 .78244 .4644 .79355 .46388 .78894 .45903 Mtetra
.474 .721 .978 r
.78894 .45903 .79355 .46388 .80479 .46402 .80018 .45884 Mtetra
.456 .698 .971 r
.80018 .45884 .80479 .46402 .81613 .46465 .81152 .4591 Mtetra
.451 .68 .963 r
.81152 .4591 .81613 .46465 .82757 .4656 .82295 .45965 Mtetra
.457 .667 .953 r
.82295 .45965 .82757 .4656 .8391 .46669 .83447 .46033 Mtetra
.473 .66 .943 r
.83447 .46033 .8391 .46669 .8507 .46771 .84606 .46093 Mtetra
.496 .657 .932 r
.84606 .46093 .8507 .46771 .86234 .46846 .85769 .46129 Mtetra
.524 .658 .921 r
.85769 .46129 .86234 .46846 .87401 .46875 .86935 .46124 Mtetra
.553 .663 .909 r
.86935 .46124 .87401 .46875 .88568 .46842 .88102 .4606 Mtetra
.583 .669 .898 r
.88102 .4606 .88568 .46842 .89734 .46731 .89267 .45926 Mtetra
.613 .678 .888 r
.89267 .45926 .89734 .46731 .90895 .46532 .90429 .45712 Mtetra
.641 .688 .878 r
.90429 .45712 .90895 .46532 .9205 .46238 .91586 .45411 Mtetra
.668 .703 .873 r
.29942 .63016 .30528 .63691 .31459 .63371 .30875 .62698 Mtetra
.691 .71 .863 r
.30875 .62698 .31459 .63371 .32399 .62969 .31815 .62305 Mtetra
.71 .718 .855 r
.31815 .62305 .32399 .62969 .33345 .6249 .32763 .61841 Mtetra
.727 .727 .85 r
.32763 .61841 .33345 .6249 .34298 .61944 .33716 .61315 Mtetra
.74 .736 .848 r
.33716 .61315 .34298 .61944 .35254 .61341 .34674 .60739 Mtetra
.751 .746 .847 r
.34674 .60739 .35254 .61341 .36215 .60698 .35635 .60124 Mtetra
.759 .756 .85 r
.35635 .60124 .36215 .60698 .37178 .60029 .36599 .59487 Mtetra
.763 .767 .856 r
.36599 .59487 .37178 .60029 .38142 .59354 .37565 .58842 Mtetra
.764 .778 .864 r
.37565 .58842 .38142 .59354 .39107 .58688 .38531 .58207 Mtetra
.762 .789 .875 r
.38531 .58207 .39107 .58688 .40072 .58049 .39498 .57596 Mtetra
.754 .8 .889 r
.39498 .57596 .40072 .58049 .41038 .57454 .40466 .57024 Mtetra
.741 .808 .906 r
.40466 .57024 .41038 .57454 .42003 .56914 .41433 .56504 Mtetra
.72 .815 .924 r
.41433 .56504 .42003 .56914 .42968 .56442 .42401 .56045 Mtetra
.693 .817 .942 r
.42401 .56045 .42968 .56442 .43934 .56045 .43369 .55655 Mtetra
.657 .813 .958 r
.43369 .55655 .43934 .56045 .44901 .55729 .44339 .55339 Mtetra
.615 .803 .972 r
.44339 .55339 .44901 .55729 .4587 .55494 .4531 .55097 Mtetra
.569 .786 .981 r
.4531 .55097 .4587 .55494 .46841 .55337 .46284 .54926 Mtetra
.524 .764 .984 r
.46284 .54926 .46841 .55337 .47815 .55254 .47261 .54823 Mtetra
.484 .739 .984 r
.47261 .54823 .47815 .55254 .48794 .55234 .48242 .54777 Mtetra
.456 .716 .98 r
.48242 .54777 .48794 .55234 .49777 .55265 .49227 .54778 Mtetra
.441 .696 .973 r
.49227 .54778 .49777 .55265 .50766 .55333 .50218 .54812 Mtetra
.44 .681 .966 r
.50218 .54812 .50766 .55333 .5176 .55421 .51214 .54865 Mtetra
.452 .672 .958 r
.51214 .54865 .5176 .55421 .5276 .55512 .52216 .5492 Mtetra
.474 .668 .948 r
.52216 .5492 .5276 .55512 .53766 .55588 .53224 .54962 Mtetra
.502 .669 .938 r
.53224 .54962 .53766 .55588 .54778 .55631 .54237 .54973 Mtetra
.534 .672 .926 r
.54237 .54973 .54778 .55631 .55795 .55626 .55256 .5494 Mtetra
.566 .677 .914 r
.55256 .5494 .55795 .55626 .56817 .55558 .5628 .5485 Mtetra
.598 .683 .901 r
.5628 .5485 .56817 .55558 .57843 .55417 .57307 .54692 Mtetra
.628 .691 .89 r
.57307 .54692 .57843 .55417 .58873 .55194 .58338 .54459 Mtetra
.655 .699 .879 r
.58338 .54459 .58873 .55194 .59904 .54885 .59372 .54148 Mtetra
.679 .708 .87 r
.59372 .54148 .59904 .54885 .60938 .5449 .60408 .53758 Mtetra
.7 .718 .863 r
.60408 .53758 .60938 .5449 .61972 .54013 .61445 .53293 Mtetra
.719 .728 .858 r
.61445 .53293 .61972 .54013 .63007 .5346 .62483 .52759 Mtetra
.734 .738 .855 r
.62483 .52759 .63007 .5346 .64043 .52844 .63522 .52166 Mtetra
.747 .749 .854 r
.63522 .52166 .64043 .52844 .65078 .52178 .64562 .51528 Mtetra
.757 .761 .856 r
.64562 .51528 .65078 .52178 .66114 .51477 .65602 .50858 Mtetra
.763 .773 .861 r
.65602 .50858 .66114 .51477 .6715 .5076 .66643 .50172 Mtetra
.766 .784 .868 r
.66643 .50172 .6715 .5076 .68188 .50044 .67686 .49488 Mtetra
.765 .796 .878 r
.67686 .49488 .68188 .50044 .69229 .49347 .68731 .48821 Mtetra
.759 .806 .891 r
.68731 .48821 .69229 .49347 .70273 .48686 .6978 .48186 Mtetra
.747 .815 .905 r
.6978 .48186 .70273 .48686 .71322 .48076 .70834 .47598 Mtetra
.73 .82 .921 r
.70834 .47598 .71322 .48076 .72376 .4753 .71893 .47069 Mtetra
.705 .822 .937 r
.71893 .47069 .72376 .4753 .73439 .47057 .7296 .46606 Mtetra
.674 .818 .953 r
.7296 .46606 .73439 .47057 .74509 .46665 .74034 .46217 Mtetra
.637 .808 .965 r
.74034 .46217 .74509 .46665 .75589 .46356 .75117 .45904 Mtetra
.598 .792 .974 r
.75117 .45904 .75589 .46356 .7668 .46129 .76211 .45667 Mtetra
.559 .772 .978 r
.76211 .45667 .7668 .46129 .77782 .45981 .77314 .45501 Mtetra
.524 .749 .978 r
.77314 .45501 .77782 .45981 .78894 .45903 .78428 .45398 Mtetra
.497 .726 .974 r
.78428 .45398 .78894 .45903 .80018 .45884 .79553 .4535 Mtetra
.48 .706 .968 r
.79553 .4535 .80018 .45884 .81152 .4591 .80687 .45343 Mtetra
.475 .689 .961 r
.80687 .45343 .81152 .4591 .82295 .45965 .8183 .45363 Mtetra
.479 .677 .952 r
.8183 .45363 .82295 .45965 .83447 .46033 .82981 .45393 Mtetra
.492 .67 .943 r
.82981 .45393 .83447 .46033 .84606 .46093 .84139 .45417 Mtetra
.511 .667 .933 r
.84139 .45417 .84606 .46093 .85769 .46129 .85302 .45419 Mtetra
.535 .668 .923 r
.85302 .45419 .85769 .46129 .86935 .46124 .86467 .45381 Mtetra
.562 .672 .912 r
.86467 .45381 .86935 .46124 .88102 .4606 .87634 .45292 Mtetra
.589 .678 .902 r
.87634 .45292 .88102 .4606 .89267 .45926 .88799 .45137 Mtetra
.616 .685 .892 r
.88799 .45137 .89267 .45926 .90429 .45712 .89963 .44909 Mtetra
.642 .694 .883 r
.89963 .44909 .90429 .45712 .91586 .45411 .91122 .44601 Mtetra
.667 .708 .878 r
.29351 .62357 .29942 .63016 .30875 .62698 .30286 .6204 Mtetra
.689 .715 .869 r
.30286 .6204 .30875 .62698 .31815 .62305 .31228 .61654 Mtetra
.708 .723 .862 r
.31228 .61654 .31815 .62305 .32763 .61841 .32176 .61203 Mtetra
.723 .73 .856 r
.32176 .61203 .32763 .61841 .33716 .61315 .3313 .60696 Mtetra
.736 .739 .854 r
.3313 .60696 .33716 .61315 .34674 .60739 .34089 .60141 Mtetra
.746 .748 .854 r
.34089 .60141 .34674 .60739 .35635 .60124 .35051 .59552 Mtetra
.753 .757 .856 r
.35051 .59552 .35635 .60124 .36599 .59487 .36017 .58942 Mtetra
.757 .767 .861 r
.36017 .58942 .36599 .59487 .37565 .58842 .36984 .58325 Mtetra
.758 .777 .869 r
.36984 .58325 .37565 .58842 .38531 .58207 .37952 .57716 Mtetra
.755 .786 .879 r
.37952 .57716 .38531 .58207 .39498 .57596 .38921 .57129 Mtetra
.747 .795 .892 r
.38921 .57129 .39498 .57596 .40466 .57024 .3989 .56579 Mtetra
.734 .803 .906 r
.3989 .56579 .40466 .57024 .41433 .56504 .4086 .56075 Mtetra
.715 .808 .922 r
.4086 .56075 .41433 .56504 .42401 .56045 .4183 .55628 Mtetra
.69 .809 .939 r
.4183 .55628 .42401 .56045 .43369 .55655 .42801 .55244 Mtetra
.658 .805 .954 r
.42801 .55244 .43369 .55655 .44339 .55339 .43773 .54927 Mtetra
.621 .796 .966 r
.43773 .54927 .44339 .55339 .4531 .55097 .44747 .54678 Mtetra
.581 .782 .975 r
.44747 .54678 .4531 .55097 .46284 .54926 .45723 .54495 Mtetra
.541 .763 .979 r
.45723 .54495 .46284 .54926 .47261 .54823 .46703 .54374 Mtetra
.507 .742 .979 r
.46703 .54374 .47261 .54823 .48242 .54777 .47686 .54305 Mtetra
.482 .722 .976 r
.47686 .54305 .48242 .54777 .49227 .54778 .48674 .54279 Mtetra
.467 .704 .971 r
.48674 .54279 .49227 .54778 .50218 .54812 .49667 .54284 Mtetra
.465 .691 .965 r
.49667 .54284 .50218 .54812 .51214 .54865 .50665 .54305 Mtetra
.474 .682 .957 r
.50665 .54305 .51214 .54865 .52216 .5492 .51669 .54329 Mtetra
.492 .678 .948 r
.51669 .54329 .52216 .5492 .53224 .54962 .52678 .54339 Mtetra
.516 .678 .938 r
.52678 .54339 .53224 .54962 .54237 .54973 .53693 .54322 Mtetra
.544 .68 .927 r
.53693 .54322 .54237 .54973 .55256 .5494 .54714 .54264 Mtetra
.573 .685 .916 r
.54714 .54264 .55256 .5494 .5628 .5485 .55739 .54153 Mtetra
.602 .691 .905 r
.55739 .54153 .5628 .5485 .57307 .54692 .56768 .53981 Mtetra
.63 .697 .894 r
.56768 .53981 .57307 .54692 .58338 .54459 .57801 .53739 Mtetra
.655 .705 .884 r
.57801 .53739 .58338 .54459 .59372 .54148 .58837 .53426 Mtetra
.678 .713 .875 r
.58837 .53426 .59372 .54148 .60408 .53758 .59875 .5304 Mtetra
.698 .722 .868 r
.59875 .5304 .60408 .53758 .61445 .53293 .60915 .52585 Mtetra
.715 .731 .864 r
.60915 .52585 .61445 .53293 .62483 .52759 .61957 .52067 Mtetra
.73 .741 .861 r
.61957 .52067 .62483 .52759 .63522 .52166 .62999 .51495 Mtetra
.742 .751 .86 r
.62999 .51495 .63522 .52166 .64562 .51528 .64042 .50881 Mtetra
.751 .762 .862 r
.64042 .50881 .64562 .51528 .65602 .50858 .65086 .50238 Mtetra
.756 .772 .866 r
.65086 .50238 .65602 .50858 .66643 .50172 .66132 .4958 Mtetra
.759 .783 .873 r
.66132 .4958 .66643 .50172 .67686 .49488 .67179 .48923 Mtetra
.757 .793 .882 r
.67179 .48923 .67686 .49488 .68731 .48821 .68229 .48282 Mtetra
.751 .802 .893 r
.68229 .48282 .68731 .48821 .6978 .48186 .69283 .47671 Mtetra
.74 .809 .906 r
.69283 .47671 .6978 .48186 .70834 .47598 .70341 .47102 Mtetra
.724 .813 .92 r
.70341 .47102 .70834 .47598 .71893 .47069 .71405 .46587 Mtetra
.701 .814 .935 r
.71405 .46587 .71893 .47069 .7296 .46606 .72476 .46133 Mtetra
.673 .81 .948 r
.72476 .46133 .7296 .46606 .74034 .46217 .73554 .45747 Mtetra
.641 .801 .96 r
.73554 .45747 .74034 .46217 .75117 .45904 .7464 .4543 Mtetra
.606 .787 .968 r
.7464 .4543 .75117 .45904 .76211 .45667 .75736 .45182 Mtetra
.571 .769 .972 r
.75736 .45182 .76211 .45667 .77314 .45501 .76842 .45 Mtetra
.541 .749 .973 r
.76842 .45 .77314 .45501 .78428 .45398 .77958 .44876 Mtetra
.516 .729 .97 r
.77958 .44876 .78428 .45398 .79553 .4535 .79083 .44802 Mtetra
.501 .711 .965 r
.79083 .44802 .79553 .4535 .80687 .45343 .80218 .44766 Mtetra
.494 .696 .959 r
.80218 .44766 .80687 .45343 .8183 .45363 .81361 .44753 Mtetra
.497 .686 .951 r
.81361 .44753 .8183 .45363 .82981 .45393 .82512 .44751 Mtetra
.508 .679 .943 r
.82512 .44751 .82981 .45393 .84139 .45417 .8367 .44742 Mtetra
.524 .676 .933 r
.8367 .44742 .84139 .45417 .85302 .45419 .84832 .44713 Mtetra
.546 .677 .924 r
.84832 .44713 .85302 .45419 .86467 .45381 .85997 .44647 Mtetra
.569 .68 .914 r
.85997 .44647 .86467 .45381 .87634 .45292 .87164 .44534 Mtetra
.594 .685 .905 r
.87164 .44534 .87634 .45292 .88799 .45137 .88331 .44361 Mtetra
.619 .692 .896 r
.88331 .44361 .88799 .45137 .89963 .44909 .89496 .4412 Mtetra
.643 .7 .888 r
.89496 .4412 .89963 .44909 .91122 .44601 .90658 .43807 Mtetra
.667 .714 .883 r
.28756 .61711 .29351 .62357 .30286 .6204 .29692 .61395 Mtetra
.687 .72 .874 r
.29692 .61395 .30286 .6204 .31228 .61654 .30635 .61015 Mtetra
.705 .727 .867 r
.30635 .61015 .31228 .61654 .32176 .61203 .31585 .60576 Mtetra
.72 .734 .862 r
.31585 .60576 .32176 .61203 .3313 .60696 .3254 .60084 Mtetra
.732 .741 .859 r
.3254 .60084 .3313 .60696 .34089 .60141 .335 .59549 Mtetra
.741 .75 .859 r
.335 .59549 .34089 .60141 .35051 .59552 .34464 .58981 Mtetra
.747 .758 .861 r
.34464 .58981 .35051 .59552 .36017 .58942 .3543 .58394 Mtetra
.751 .767 .866 r
.3543 .58394 .36017 .58942 .36984 .58325 .36399 .57801 Mtetra
.751 .775 .873 r
.36399 .57801 .36984 .58325 .37952 .57716 .37368 .57215 Mtetra
.748 .784 .882 r
.37368 .57215 .37952 .57716 .38921 .57129 .38339 .5665 Mtetra
.74 .791 .893 r
.38339 .5665 .38921 .57129 .3989 .56579 .3931 .56118 Mtetra
.728 .797 .907 r
.3931 .56118 .3989 .56579 .4086 .56075 .40282 .55628 Mtetra
.711 .801 .921 r
.40282 .55628 .4086 .56075 .4183 .55628 .41255 .55191 Mtetra
.687 .802 .936 r
.41255 .55191 .4183 .55628 .42801 .55244 .42228 .54812 Mtetra
.659 .798 .949 r
.42228 .54812 .42801 .55244 .43773 .54927 .43203 .54494 Mtetra
.626 .79 .961 r
.43203 .54494 .43773 .54927 .44747 .54678 .44179 .5424 Mtetra
.59 .778 .969 r
.44179 .5424 .44747 .54678 .45723 .54495 .45158 .54046 Mtetra
.556 .761 .974 r
.45158 .54046 .45723 .54495 .46703 .54374 .4614 .53908 Mtetra
.526 .743 .975 r
.4614 .53908 .46703 .54374 .47686 .54305 .47126 .53819 Mtetra
.503 .726 .973 r
.47126 .53819 .47686 .54305 .48674 .54279 .48117 .53769 Mtetra
.489 .71 .968 r
.48117 .53769 .48674 .54279 .49667 .54284 .49112 .53748 Mtetra
.486 .699 .963 r
.49112 .53748 .49667 .54284 .50665 .54305 .50112 .53741 Mtetra
.493 .691 .956 r
.50112 .53741 .50665 .54305 .51669 .54329 .51118 .53736 Mtetra
.508 .687 .948 r
.51118 .53736 .51669 .54329 .52678 .54339 .52129 .5372 Mtetra
.529 .686 .939 r
.52129 .5372 .52678 .54339 .53693 .54322 .53146 .53677 Mtetra
.553 .688 .929 r
.53146 .53677 .53693 .54322 .54714 .54264 .54168 .53597 Mtetra
.58 .692 .918 r
.54168 .53597 .54714 .54264 .55739 .54153 .55195 .53468 Mtetra
.606 .697 .908 r
.55195 .53468 .55739 .54153 .56768 .53981 .56226 .53282 Mtetra
.632 .703 .898 r
.56226 .53282 .56768 .53981 .57801 .53739 .57261 .53033 Mtetra
.655 .711 .888 r
.57261 .53033 .57801 .53739 .58837 .53426 .58299 .52717 Mtetra
.677 .718 .88 r
.58299 .52717 .58837 .53426 .59875 .5304 .5934 .52335 Mtetra
.695 .726 .874 r
.5934 .52335 .59875 .5304 .60915 .52585 .60383 .51889 Mtetra
.712 .735 .869 r
.60383 .51889 .60915 .52585 .61957 .52067 .61427 .51384 Mtetra
.726 .744 .866 r
.61427 .51384 .61957 .52067 .62999 .51495 .62472 .5083 Mtetra
.737 .753 .865 r
.62472 .5083 .62999 .51495 .64042 .50881 .63519 .50237 Mtetra
.745 .762 .867 r
.63519 .50237 .64042 .50881 .65086 .50238 .64567 .49617 Mtetra
.75 .772 .871 r
.64567 .49617 .65086 .50238 .66132 .4958 .65617 .48983 Mtetra
.752 .781 .877 r
.65617 .48983 .66132 .4958 .67179 .48923 .66669 .48351 Mtetra
.75 .79 .885 r
.66669 .48351 .67179 .48923 .68229 .48282 .67724 .47732 Mtetra
.744 .797 .895 r
.67724 .47732 .68229 .48282 .69283 .47671 .68782 .47141 Mtetra
.734 .803 .907 r
.68782 .47141 .69283 .47671 .70341 .47102 .69844 .46589 Mtetra
.718 .806 .92 r
.69844 .46589 .70341 .47102 .71405 .46587 .70912 .46086 Mtetra
.698 .806 .932 r
.70912 .46086 .71405 .46587 .72476 .46133 .71987 .45639 Mtetra
.672 .802 .945 r
.71987 .45639 .72476 .46133 .73554 .45747 .73069 .45255 Mtetra
.643 .794 .955 r
.73069 .45255 .73554 .45747 .7464 .4543 .74158 .44934 Mtetra
.612 .782 .962 r
.74158 .44934 .7464 .4543 .75736 .45182 .75257 .44677 Mtetra
.582 .766 .967 r
.75257 .44677 .75736 .45182 .76842 .45 .76365 .44481 Mtetra
.554 .749 .968 r
.76365 .44481 .76842 .45 .77958 .44876 .77482 .44338 Mtetra
.532 .732 .966 r
.77482 .44338 .77958 .44876 .79083 .44802 .78609 .44241 Mtetra
.518 .716 .962 r
.78609 .44241 .79083 .44802 .80218 .44766 .79745 .44178 Mtetra
.511 .702 .956 r
.79745 .44178 .80218 .44766 .81361 .44753 .80889 .44137 Mtetra
.513 .693 .95 r
.80889 .44137 .81361 .44753 .82512 .44751 .8204 .44105 Mtetra
.521 .686 .942 r
.8204 .44105 .82512 .44751 .8367 .44742 .83198 .44068 Mtetra
.536 .684 .934 r
.83198 .44068 .8367 .44742 .84832 .44713 .8436 .44011 Mtetra
.554 .684 .925 r
.8436 .44011 .84832 .44713 .85997 .44647 .85526 .43921 Mtetra
.576 .687 .917 r
.85526 .43921 .85997 .44647 .87164 .44534 .86693 .43786 Mtetra
.599 .692 .908 r
.86693 .43786 .87164 .44534 .88331 .44361 .87861 .43597 Mtetra
.622 .698 .9 r
.87861 .43597 .88331 .44361 .89496 .4412 .89028 .43345 Mtetra
.644 .706 .892 r
.89028 .43345 .89496 .4412 .90658 .43807 .90192 .43025 Mtetra
.666 .718 .888 r
.28156 .61078 .28756 .61711 .29692 .61395 .29094 .60763 Mtetra
.686 .724 .879 r
.29094 .60763 .29692 .61395 .30635 .61015 .30039 .60388 Mtetra
.702 .731 .872 r
.30039 .60388 .30635 .61015 .31585 .60576 .3099 .59958 Mtetra
.717 .737 .867 r
.3099 .59958 .31585 .60576 .3254 .60084 .31946 .59479 Mtetra
.728 .744 .865 r
.31946 .59479 .3254 .60084 .335 .59549 .32907 .5896 Mtetra
.737 .751 .864 r
.32907 .5896 .335 .59549 .34464 .58981 .33872 .58412 Mtetra
.743 .759 .866 r
.33872 .58412 .34464 .58981 .3543 .58394 .3484 .57845 Mtetra
.746 .766 .87 r
.3484 .57845 .3543 .58394 .36399 .57801 .3581 .57272 Mtetra
.746 .774 .876 r
.3581 .57272 .36399 .57801 .37368 .57215 .36781 .56706 Mtetra
.742 .781 .884 r
.36781 .56706 .37368 .57215 .38339 .5665 .37754 .56159 Mtetra
.735 .787 .895 r
.37754 .56159 .38339 .5665 .3931 .56118 .38727 .55642 Mtetra
.723 .792 .907 r
.38727 .55642 .3931 .56118 .40282 .55628 .39701 .55165 Mtetra
.707 .795 .92 r
.39701 .55165 .40282 .55628 .41255 .55191 .40676 .54736 Mtetra
.685 .795 .933 r
.40676 .54736 .41255 .55191 .42228 .54812 .41652 .54361 Mtetra
.659 .792 .945 r
.41652 .54361 .42228 .54812 .43203 .54494 .42629 .54043 Mtetra
.63 .785 .956 r
.42629 .54043 .43203 .54494 .44179 .5424 .43608 .53783 Mtetra
.598 .773 .964 r
.43608 .53783 .44179 .5424 .45158 .54046 .4459 .53579 Mtetra
.568 .759 .968 r
.4459 .53579 .45158 .54046 .4614 .53908 .45574 .53426 Mtetra
.541 .744 .97 r
.45574 .53426 .4614 .53908 .47126 .53819 .46563 .53319 Mtetra
.52 .729 .969 r
.46563 .53319 .47126 .53819 .48117 .53769 .47555 .53249 Mtetra
.507 .715 .965 r
.47555 .53249 .48117 .53769 .49112 .53748 .48553 .53204 Mtetra
.503 .704 .96 r
.48553 .53204 .49112 .53748 .50112 .53741 .49555 .53173 Mtetra
.509 .697 .954 r
.49555 .53173 .50112 .53741 .51118 .53736 .50563 .53143 Mtetra
.521 .694 .947 r
.50563 .53143 .51118 .53736 .52129 .5372 .51576 .53102 Mtetra
.539 .693 .939 r
.51576 .53102 .52129 .5372 .53146 .53677 .52595 .53038 Mtetra
.561 .695 .93 r
.52595 .53038 .53146 .53677 .54168 .53597 .53619 .52938 Mtetra
.585 .698 .92 r
.53619 .52938 .54168 .53597 .55195 .53468 .54648 .52793 Mtetra
.61 .703 .911 r
.54648 .52793 .55195 .53468 .56226 .53282 .55681 .52595 Mtetra
.633 .709 .901 r
.55681 .52595 .56226 .53282 .57261 .53033 .56718 .52339 Mtetra
.655 .716 .893 r
.56718 .52339 .57261 .53033 .58299 .52717 .57758 .52021 Mtetra
.675 .723 .885 r
.57758 .52021 .58299 .52717 .5934 .52335 .58801 .51641 Mtetra
.693 .73 .879 r
.58801 .51641 .5934 .52335 .60383 .51889 .59847 .51202 Mtetra
.709 .738 .874 r
.59847 .51202 .60383 .51889 .61427 .51384 .60894 .50709 Mtetra
.722 .746 .871 r
.60894 .50709 .61427 .51384 .62472 .5083 .61943 .5017 Mtetra
.732 .755 .87 r
.61943 .5017 .62472 .5083 .63519 .50237 .62993 .49595 Mtetra
.74 .763 .871 r
.62993 .49595 .63519 .50237 .64567 .49617 .64045 .48995 Mtetra
.745 .771 .875 r
.64045 .48995 .64567 .49617 .65617 .48983 .65099 .48382 Mtetra
.746 .779 .88 r
.65099 .48382 .65617 .48983 .66669 .48351 .66155 .4777 Mtetra
.744 .787 .887 r
.66155 .4777 .66669 .48351 .67724 .47732 .67214 .4717 Mtetra
.738 .793 .896 r
.67214 .4717 .67724 .47732 .68782 .47141 .68276 .46596 Mtetra
.728 .798 .907 r
.68276 .46596 .68782 .47141 .69844 .46589 .69343 .46058 Mtetra
.714 .8 .918 r
.69343 .46058 .69844 .46589 .70912 .46086 .70415 .45566 Mtetra
.695 .8 .93 r
.70415 .45566 .70912 .46086 .71987 .45639 .71493 .45125 Mtetra
.672 .796 .941 r
.71493 .45125 .71987 .45639 .73069 .45255 .72578 .44742 Mtetra
.645 .788 .95 r
.72578 .44742 .73069 .45255 .74158 .44934 .73672 .44418 Mtetra
.618 .777 .957 r
.73672 .44418 .74158 .44934 .75257 .44677 .74773 .44153 Mtetra
.59 .764 .962 r
.74773 .44153 .75257 .44677 .76365 .44481 .75883 .43943 Mtetra
.565 .748 .963 r
.75883 .43943 .76365 .44481 .77482 .44338 .77003 .43784 Mtetra
.545 .733 .962 r
.77003 .43784 .77482 .44338 .78609 .44241 .78131 .43666 Mtetra
.532 .719 .959 r
.78131 .43666 .78609 .44241 .79745 .44178 .79268 .4358 Mtetra
.525 .707 .954 r
.79268 .4358 .79745 .44178 .80889 .44137 .80413 .43514 Mtetra
.526 .698 .948 r
.80413 .43514 .80889 .44137 .8204 .44105 .81565 .43456 Mtetra
.533 .693 .941 r
.81565 .43456 .8204 .44105 .83198 .44068 .82723 .43393 Mtetra
.545 .69 .934 r
.82723 .43393 .83198 .44068 .8436 .44011 .83886 .43312 Mtetra
.562 .691 .926 r
.83886 .43312 .8436 .44011 .85526 .43921 .85052 .432 Mtetra
.582 .693 .919 r
.85052 .432 .85526 .43921 .86693 .43786 .86221 .43047 Mtetra
.603 .698 .911 r
.86221 .43047 .86693 .43786 .87861 .43597 .8739 .42843 Mtetra
.624 .704 .903 r
.8739 .42843 .87861 .43597 .89028 .43345 .88559 .4258 Mtetra
.645 .712 .896 r
.88559 .4258 .89028 .43345 .90192 .43025 .89726 .42256 Mtetra
.666 .723 .892 r
.27551 .60456 .28156 .61078 .29094 .60763 .28491 .6014 Mtetra
.684 .729 .884 r
.28491 .6014 .29094 .60763 .30039 .60388 .29437 .5977 Mtetra
.7 .734 .877 r
.29437 .5977 .30039 .60388 .3099 .59958 .3039 .59348 Mtetra
.714 .74 .872 r
.3039 .59348 .3099 .59958 .31946 .59479 .31348 .58881 Mtetra
.724 .746 .869 r
.31348 .58881 .31946 .59479 .32907 .5896 .3231 .58376 Mtetra
.733 .753 .869 r
.3231 .58376 .32907 .5896 .33872 .58412 .33277 .57843 Mtetra
.738 .759 .87 r
.33277 .57843 .33872 .58412 .3484 .57845 .34246 .57293 Mtetra
.741 .766 .873 r
.34246 .57293 .3484 .57845 .3581 .57272 .35217 .56738 Mtetra
.741 .773 .879 r
.35217 .56738 .3581 .57272 .36781 .56706 .36191 .56188 Mtetra
.737 .779 .886 r
.36191 .56188 .36781 .56706 .37754 .56159 .37165 .55657 Mtetra
.73 .784 .896 r
.37165 .55657 .37754 .56159 .38727 .55642 .3814 .55153 Mtetra
.719 .788 .907 r
.3814 .55153 .38727 .55642 .39701 .55165 .39117 .54686 Mtetra
.703 .79 .918 r
.39117 .54686 .39701 .55165 .40676 .54736 .40094 .54264 Mtetra
.683 .79 .93 r
.40094 .54264 .40676 .54736 .41652 .54361 .41072 .53892 Mtetra
.66 .786 .942 r
.41072 .53892 .41652 .54361 .42629 .54043 .42052 .53573 Mtetra
.633 .779 .951 r
.42052 .53573 .42629 .54043 .43608 .53783 .43033 .53308 Mtetra
.605 .77 .959 r
.43033 .53308 .43608 .53783 .4459 .53579 .44017 .53095 Mtetra
.577 .757 .963 r
.44017 .53095 .4459 .53579 .45574 .53426 .45004 .5293 Mtetra
.553 .744 .965 r
.45004 .5293 .45574 .53426 .46563 .53319 .45995 .52807 Mtetra
.534 .73 .965 r
.45995 .52807 .46563 .53319 .47555 .53249 .4699 .52718 Mtetra
.522 .718 .962 r
.4699 .52718 .47555 .53249 .48553 .53204 .4799 .52652 Mtetra
.518 .709 .958 r
.4799 .52652 .48553 .53204 .49555 .53173 .48995 .526 Mtetra
.522 .703 .953 r
.48995 .526 .49555 .53173 .50563 .53143 .50004 .52549 Mtetra
.532 .699 .946 r
.50004 .52549 .50563 .53143 .51576 .53102 .5102 .52487 Mtetra
.548 .699 .939 r
.5102 .52487 .51576 .53102 .52595 .53038 .5204 .52403 Mtetra
.568 .701 .931 r
.5204 .52403 .52595 .53038 .53619 .52938 .53066 .52286 Mtetra
.59 .704 .922 r
.53066 .52286 .53619 .52938 .54648 .52793 .54097 .52127 Mtetra
.612 .709 .913 r
.54097 .52127 .54648 .52793 .55681 .52595 .55132 .51919 Mtetra
.635 .714 .905 r
.55132 .51919 .55681 .52595 .56718 .52339 .56171 .51656 Mtetra
.655 .721 .897 r
.56171 .51656 .56718 .52339 .57758 .52021 .57214 .51335 Mtetra
.675 .727 .889 r
.57214 .51335 .57758 .52021 .58801 .51641 .5826 .50957 Mtetra
.692 .734 .883 r
.5826 .50957 .58801 .51641 .59847 .51202 .59308 .50524 Mtetra
.706 .741 .879 r
.59308 .50524 .59847 .51202 .60894 .50709 .60358 .50041 Mtetra
.719 .749 .876 r
.60358 .50041 .60894 .50709 .61943 .5017 .6141 .49515 Mtetra
.728 .756 .875 r
.6141 .49515 .61943 .5017 .62993 .49595 .62464 .48955 Mtetra
.736 .764 .876 r
.62464 .48955 .62993 .49595 .64045 .48995 .63519 .48371 Mtetra
.74 .771 .878 r
.63519 .48371 .64045 .48995 .65099 .48382 .64577 .47776 Mtetra
.741 .778 .883 r
.64577 .47776 .65099 .48382 .66155 .4777 .65637 .47181 Mtetra
.739 .784 .889 r
.65637 .47181 .66155 .4777 .67214 .4717 .667 .46598 Mtetra
.733 .789 .898 r
.667 .46598 .67214 .4717 .68276 .46596 .67766 .46039 Mtetra
.723 .793 .907 r
.67766 .46039 .68276 .46596 .69343 .46058 .68837 .45512 Mtetra
.71 .795 .917 r
.68837 .45512 .69343 .46058 .70415 .45566 .69913 .45028 Mtetra
.692 .794 .928 r
.69913 .45028 .70415 .45566 .71493 .45125 .70995 .44593 Mtetra
.671 .79 .938 r
.70995 .44593 .71493 .45125 .72578 .44742 .72084 .4421 Mtetra
.647 .783 .946 r
.72084 .4421 .72578 .44742 .73672 .44418 .7318 .43883 Mtetra
.622 .773 .953 r
.7318 .43883 .73672 .44418 .74773 .44153 .74284 .4361 Mtetra
.597 .761 .957 r
.74284 .4361 .74773 .44153 .75883 .43943 .75397 .43389 Mtetra
.575 .747 .959 r
.75397 .43389 .75883 .43943 .77003 .43784 .76518 .43215 Mtetra
.556 .734 .958 r
.76518 .43215 .77003 .43784 .78131 .43666 .77648 .43079 Mtetra
.543 .721 .956 r
.77648 .43079 .78131 .43666 .79268 .4358 .78787 .42972 Mtetra
.537 .711 .952 r
.78787 .42972 .79268 .4358 .80413 .43514 .79933 .42885 Mtetra
.537 .703 .947 r
.79933 .42885 .80413 .43514 .81565 .43456 .81086 .42804 Mtetra
.543 .698 .941 r
.81086 .42804 .81565 .43456 .82723 .43393 .82245 .42719 Mtetra
.554 .696 .934 r
.82245 .42719 .82723 .43393 .83886 .43312 .83409 .42616 Mtetra
.569 .697 .927 r
.83409 .42616 .83886 .43312 .85052 .432 .84577 .42485 Mtetra
.586 .699 .92 r
.84577 .42485 .85052 .432 .86221 .43047 .85747 .42315 Mtetra
.606 .704 .913 r
.85747 .42315 .86221 .43047 .8739 .42843 .86918 .42098 Mtetra
.626 .71 .906 r
.86918 .42098 .8739 .42843 .88559 .4258 .88088 .41827 Mtetra
.646 .717 .9 r
.88088 .41827 .88559 .4258 .89726 .42256 .89258 .41497 Mtetra
.665 .728 .896 r
.26942 .59844 .27551 .60456 .28491 .6014 .27883 .59528 Mtetra
.683 .733 .888 r
.27883 .59528 .28491 .6014 .29437 .5977 .28831 .59161 Mtetra
.698 .738 .882 r
.28831 .59161 .29437 .5977 .3039 .59348 .29785 .58745 Mtetra
.711 .743 .877 r
.29785 .58745 .3039 .59348 .31348 .58881 .30745 .58287 Mtetra
.721 .749 .874 r
.30745 .58287 .31348 .58881 .3231 .58376 .31709 .57794 Mtetra
.729 .754 .873 r
.31709 .57794 .3231 .58376 .33277 .57843 .32677 .57274 Mtetra
.734 .76 .874 r
.32677 .57274 .33277 .57843 .34246 .57293 .33648 .56739 Mtetra
.737 .766 .876 r
.33648 .56739 .34246 .57293 .35217 .56738 .34621 .56198 Mtetra
.736 .771 .881 r
.34621 .56198 .35217 .56738 .36191 .56188 .35596 .55662 Mtetra
.732 .776 .888 r
.35596 .55662 .36191 .56188 .37165 .55657 .36572 .55143 Mtetra
.725 .781 .897 r
.36572 .55143 .37165 .55657 .3814 .55153 .3755 .5465 Mtetra
.715 .784 .906 r
.3755 .5465 .3814 .55153 .39117 .54686 .38528 .54192 Mtetra
.7 .785 .917 r
.38528 .54192 .39117 .54686 .40094 .54264 .39508 .53776 Mtetra
.682 .784 .928 r
.39508 .53776 .40094 .54264 .41072 .53892 .40488 .53406 Mtetra
.66 .781 .938 r
.40488 .53406 .41072 .53892 .42052 .53573 .4147 .53086 Mtetra
.636 .775 .947 r
.4147 .53086 .42052 .53573 .43033 .53308 .42454 .52816 Mtetra
.61 .766 .954 r
.42454 .52816 .43033 .53308 .44017 .53095 .43441 .52595 Mtetra
.585 .755 .959 r
.43441 .52595 .44017 .53095 .45004 .5293 .44431 .52419 Mtetra
.563 .743 .961 r
.44431 .52419 .45004 .5293 .45995 .52807 .45424 .52282 Mtetra
.545 .731 .961 r
.45424 .52282 .45995 .52807 .4699 .52718 .46421 .52177 Mtetra
.534 .721 .959 r
.46421 .52177 .4699 .52718 .4799 .52652 .47423 .52094 Mtetra
.53 .713 .956 r
.47423 .52094 .4799 .52652 .48995 .526 .4843 .52023 Mtetra
.532 .707 .951 r
.4843 .52023 .48995 .526 .50004 .52549 .49442 .51953 Mtetra
.541 .704 .946 r
.49442 .51953 .50004 .52549 .5102 .52487 .5046 .51873 Mtetra
.556 .704 .939 r
.5046 .51873 .5102 .52487 .5204 .52403 .51482 .51772 Mtetra
.574 .706 .932 r
.51482 .51772 .5204 .52403 .53066 .52286 .5251 .5164 Mtetra
.594 .709 .924 r
.5251 .5164 .53066 .52286 .54097 .52127 .53543 .51469 Mtetra
.615 .714 .916 r
.53543 .51469 .54097 .52127 .55132 .51919 .5458 .51251 Mtetra
.636 .719 .908 r
.5458 .51251 .55132 .51919 .56171 .51656 .55622 .50982 Mtetra
.655 .725 .9 r
.55622 .50982 .56171 .51656 .57214 .51335 .56667 .5066 Mtetra
.674 .731 .893 r
.56667 .5066 .57214 .51335 .5826 .50957 .57715 .50283 Mtetra
.69 .738 .888 r
.57715 .50283 .5826 .50957 .59308 .50524 .58765 .49855 Mtetra
.704 .745 .883 r
.58765 .49855 .59308 .50524 .60358 .50041 .59819 .49379 Mtetra
.716 .751 .88 r
.59819 .49379 .60358 .50041 .6141 .49515 .60874 .48863 Mtetra
.725 .758 .879 r
.60874 .48863 .6141 .49515 .62464 .48955 .61931 .48316 Mtetra
.732 .765 .879 r
.61931 .48316 .62464 .48955 .63519 .48371 .6299 .47746 Mtetra
.735 .771 .881 r
.6299 .47746 .63519 .48371 .64577 .47776 .64051 .47166 Mtetra
.736 .777 .885 r
.64051 .47166 .64577 .47776 .65637 .47181 .65115 .46585 Mtetra
.734 .782 .891 r
.65115 .46585 .65637 .47181 .667 .46598 .66182 .46016 Mtetra
.728 .786 .898 r
.66182 .46016 .667 .46598 .67766 .46039 .67252 .45468 Mtetra
.719 .789 .907 r
.67252 .45468 .67766 .46039 .68837 .45512 .68327 .44951 Mtetra
.706 .79 .916 r
.68327 .44951 .68837 .45512 .69913 .45028 .69407 .44474 Mtetra
.69 .788 .926 r
.69407 .44474 .69913 .45028 .70995 .44593 .70492 .44042 Mtetra
.67 .784 .934 r
.70492 .44042 .70995 .44593 .72084 .4421 .71584 .4366 Mtetra
.648 .778 .942 r
.71584 .4366 .72084 .4421 .7318 .43883 .72684 .4333 Mtetra
.625 .768 .948 r
.72684 .4333 .7318 .43883 .74284 .4361 .73791 .4305 Mtetra
.603 .758 .953 r
.73791 .4305 .74284 .4361 .75397 .43389 .74906 .42819 Mtetra
.582 .746 .954 r
.74906 .42819 .75397 .43389 .76518 .43215 .7603 .42631 Mtetra
.565 .734 .954 r
.7603 .42631 .76518 .43215 .77648 .43079 .77162 .42479 Mtetra
.553 .723 .953 r
.77162 .42479 .77648 .43079 .78787 .42972 .78302 .42355 Mtetra
.547 .713 .949 r
.78302 .42355 .78787 .42972 .79933 .42885 .79449 .42249 Mtetra
.546 .707 .945 r
.79449 .42249 .79933 .42885 .81086 .42804 .80604 .42149 Mtetra
.551 .702 .94 r
.80604 .42149 .81086 .42804 .82245 .42719 .81764 .42044 Mtetra
.561 .701 .935 r
.81764 .42044 .82245 .42719 .83409 .42616 .8293 .41923 Mtetra
.574 .702 .928 r
.8293 .41923 .83409 .42616 .84577 .42485 .84099 .41775 Mtetra
.591 .704 .922 r
.84099 .41775 .84577 .42485 .85747 .42315 .8527 .4159 Mtetra
.609 .709 .916 r
.8527 .4159 .85747 .42315 .86918 .42098 .86443 .41361 Mtetra
.628 .715 .909 r
.86443 .41361 .86918 .42098 .88088 .41827 .87616 .41082 Mtetra
.646 .721 .903 r
.87616 .41082 .88088 .41827 .89258 .41497 .88789 .40748 Mtetra
.665 .732 .899 r
.26328 .59241 .26942 .59844 .27883 .59528 .27271 .58925 Mtetra
.682 .736 .892 r
.27271 .58925 .27883 .59528 .28831 .59161 .28221 .5856 Mtetra
.697 .741 .886 r
.28221 .5856 .28831 .59161 .29785 .58745 .29177 .58149 Mtetra
.709 .746 .881 r
.29177 .58149 .29785 .58745 .30745 .58287 .30138 .57699 Mtetra
.719 .751 .878 r
.30138 .57699 .30745 .58287 .31709 .57794 .31103 .57214 Mtetra
.726 .756 .876 r
.31103 .57214 .31709 .57794 .32677 .57274 .32073 .56706 Mtetra
.731 .761 .877 r
.32073 .56706 .32677 .57274 .33648 .56739 .33045 .56181 Mtetra
.733 .766 .879 r
.33045 .56181 .33648 .56739 .34621 .56198 .3402 .55652 Mtetra
.732 .77 .883 r
.3402 .55652 .34621 .56198 .35596 .55662 .34997 .55128 Mtetra
.728 .774 .889 r
.34997 .55128 .35596 .55662 .36572 .55143 .35976 .5462 Mtetra
.722 .778 .897 r
.35976 .5462 .36572 .55143 .3755 .5465 .36955 .54135 Mtetra
.711 .78 .906 r
.36955 .54135 .3755 .5465 .38528 .54192 .37936 .53684 Mtetra
.697 .781 .915 r
.37936 .53684 .38528 .54192 .39508 .53776 .38918 .53272 Mtetra
.68 .779 .925 r
.38918 .53272 .39508 .53776 .40488 .53406 .39901 .52903 Mtetra
.66 .776 .935 r
.39901 .52903 .40488 .53406 .4147 .53086 .40885 .52582 Mtetra
.638 .77 .943 r
.40885 .52582 .4147 .53086 .42454 .52816 .41872 .52308 Mtetra
.614 .762 .95 r
.41872 .52308 .42454 .52816 .43441 .52595 .42861 .5208 Mtetra
.591 .752 .955 r
.42861 .5208 .43441 .52595 .44431 .52419 .43853 .51894 Mtetra
.571 .742 .957 r
.43853 .51894 .44431 .52419 .45424 .52282 .44849 .51746 Mtetra
.554 .732 .958 r
.44849 .51746 .45424 .52282 .46421 .52177 .45848 .51627 Mtetra
.544 .723 .956 r
.45848 .51627 .46421 .52177 .47423 .52094 .46853 .51528 Mtetra
.539 .715 .954 r
.46853 .51528 .47423 .52094 .4843 .52023 .47862 .51441 Mtetra
.541 .711 .95 r
.47862 .51441 .4843 .52023 .49442 .51953 .48876 .51355 Mtetra
.549 .708 .945 r
.48876 .51355 .49442 .51953 .5046 .51873 .49895 .5126 Mtetra
.562 .708 .939 r
.49895 .5126 .5046 .51873 .51482 .51772 .5092 .51144 Mtetra
.578 .71 .933 r
.5092 .51144 .51482 .51772 .5251 .5164 .5195 .50999 Mtetra
.597 .714 .926 r
.5195 .50999 .5251 .5164 .53543 .51469 .52985 .50817 Mtetra
.617 .718 .918 r
.52985 .50817 .53543 .51469 .5458 .51251 .54025 .50592 Mtetra
.637 .724 .911 r
.54025 .50592 .5458 .51251 .55622 .50982 .55068 .50318 Mtetra
.655 .729 .904 r
.55068 .50318 .55622 .50982 .56667 .5066 .56116 .49993 Mtetra
.673 .735 .897 r
.56116 .49993 .56667 .5066 .57715 .50283 .57166 .49617 Mtetra
.689 .741 .891 r
.57166 .49617 .57715 .50283 .58765 .49855 .5822 .49192 Mtetra
.702 .748 .887 r
.5822 .49192 .58765 .49855 .59819 .49379 .59276 .48723 Mtetra
.713 .754 .884 r
.59276 .48723 .59819 .49379 .60874 .48863 .60334 .48215 Mtetra
.722 .76 .882 r
.60334 .48215 .60874 .48863 .61931 .48316 .61395 .47678 Mtetra
.728 .765 .882 r
.61395 .47678 .61931 .48316 .6299 .47746 .62457 .47119 Mtetra
.732 .771 .884 r
.62457 .47119 .6299 .47746 .64051 .47166 .63522 .4655 Mtetra
.732 .776 .887 r
.63522 .4655 .64051 .47166 .65115 .46585 .64589 .45981 Mtetra
.73 .78 .893 r
.64589 .45981 .65115 .46585 .66182 .46016 .6566 .45423 Mtetra
.724 .783 .899 r
.6566 .45423 .66182 .46016 .67252 .45468 .66734 .44885 Mtetra
.715 .785 .907 r
.66734 .44885 .67252 .45468 .68327 .44951 .67812 .44376 Mtetra
.703 .785 .915 r
.67812 .44376 .68327 .44951 .69407 .44474 .68896 .43904 Mtetra
.688 .783 .923 r
.68896 .43904 .69407 .44474 .70492 .44042 .69985 .43475 Mtetra
.67 .779 .931 r
.69985 .43475 .70492 .44042 .71584 .4366 .7108 .43093 Mtetra
.649 .773 .939 r
.7108 .43093 .71584 .4366 .72684 .4333 .72183 .42759 Mtetra
.628 .764 .944 r
.72183 .42759 .72684 .4333 .73791 .4305 .73293 .42474 Mtetra
.607 .755 .948 r
.73293 .42474 .73791 .4305 .74906 .42819 .74411 .42233 Mtetra
.588 .744 .951 r
.74411 .42233 .74906 .42819 .7603 .42631 .75537 .42034 Mtetra
.572 .733 .951 r
.75537 .42034 .7603 .42631 .77162 .42479 .76671 .41869 Mtetra
.561 .723 .95 r
.76671 .41869 .77162 .42479 .78302 .42355 .77813 .41729 Mtetra
.555 .715 .947 r
.77813 .41729 .78302 .42355 .79449 .42249 .78962 .41606 Mtetra
.554 .71 .944 r
.78962 .41606 .79449 .42249 .80604 .42149 .80118 .41489 Mtetra
.558 .706 .94 r
.80118 .41489 .80604 .42149 .81764 .42044 .8128 .41368 Mtetra
.566 .705 .935 r
.8128 .41368 .81764 .42044 .8293 .41923 .82447 .41231 Mtetra
.579 .706 .929 r
.82447 .41231 .8293 .41923 .84099 .41775 .83618 .41068 Mtetra
.594 .709 .924 r
.83618 .41068 .84099 .41775 .8527 .4159 .84791 .40871 Mtetra
.611 .714 .918 r
.84791 .40871 .8527 .4159 .86443 .41361 .85967 .40632 Mtetra
.629 .719 .912 r
.85967 .40632 .86443 .41361 .87616 .41082 .87142 .40345 Mtetra
.647 .726 .906 r
.87142 .40345 .87616 .41082 .88789 .40748 .88318 .40007 Mtetra
.665 .736 .903 r
.2571 .58647 .26328 .59241 .27271 .58925 .26654 .5833 Mtetra
.681 .74 .896 r
.26654 .5833 .27271 .58925 .28221 .5856 .27606 .57966 Mtetra
.695 .744 .889 r
.27606 .57966 .28221 .5856 .29177 .58149 .28563 .57559 Mtetra
.707 .749 .884 r
.28563 .57559 .29177 .58149 .30138 .57699 .29526 .57114 Mtetra
.717 .753 .881 r
.29526 .57114 .30138 .57699 .31103 .57214 .30493 .56637 Mtetra
.724 .757 .879 r
.30493 .56637 .31103 .57214 .32073 .56706 .31465 .56137 Mtetra
.728 .762 .879 r
.31465 .56137 .32073 .56706 .33045 .56181 .32439 .55622 Mtetra
.73 .766 .881 r
.32439 .55622 .33045 .56181 .3402 .55652 .33416 .55102 Mtetra
.729 .769 .885 r
.33416 .55102 .3402 .55652 .34997 .55128 .34395 .54586 Mtetra
.725 .772 .89 r
.34395 .54586 .34997 .55128 .35976 .5462 .35376 .54086 Mtetra
.718 .775 .897 r
.35376 .54086 .35976 .5462 .36955 .54135 .36357 .53608 Mtetra
.708 .776 .905 r
.36357 .53608 .36955 .54135 .37936 .53684 .3734 .53162 Mtetra
.695 .776 .914 r
.3734 .53162 .37936 .53684 .38918 .53272 .38324 .52753 Mtetra
.679 .775 .923 r
.38324 .52753 .38918 .53272 .39901 .52903 .3931 .52385 Mtetra
.66 .771 .932 r
.3931 .52385 .39901 .52903 .40885 .52582 .40297 .52062 Mtetra
.639 .766 .939 r
.40297 .52062 .40885 .52582 .41872 .52308 .41286 .51785 Mtetra
.618 .758 .946 r
.41286 .51785 .41872 .52308 .42861 .5208 .42277 .51551 Mtetra
.596 .75 .951 r
.42277 .51551 .42861 .5208 .43853 .51894 .43272 .51357 Mtetra
.577 .74 .954 r
.43272 .51357 .43853 .51894 .44849 .51746 .4427 .51198 Mtetra
.562 .731 .955 r
.4427 .51198 .44849 .51746 .45848 .51627 .45272 .51067 Mtetra
.551 .723 .954 r
.45272 .51067 .45848 .51627 .46853 .51528 .46278 .50956 Mtetra
.547 .717 .952 r
.46278 .50956 .46853 .51528 .47862 .51441 .47289 .50856 Mtetra
.548 .713 .949 r
.47289 .50856 .47862 .51441 .48876 .51355 .48306 .50756 Mtetra
.555 .712 .945 r
.48306 .50756 .48876 .51355 .49895 .5126 .49328 .50647 Mtetra
.567 .712 .94 r
.49328 .50647 .49895 .5126 .5092 .51144 .50355 .50519 Mtetra
.582 .714 .934 r
.50355 .50519 .5092 .51144 .5195 .50999 .51387 .50364 Mtetra
.6 .718 .927 r
.51387 .50364 .5195 .50999 .52985 .50817 .52424 .50173 Mtetra
.618 .723 .921 r
.52424 .50173 .52985 .50817 .54025 .50592 .53465 .4994 Mtetra
.637 .728 .914 r
.53465 .4994 .54025 .50592 .55068 .50318 .54511 .49661 Mtetra
.655 .734 .907 r
.54511 .49661 .55068 .50318 .56116 .49993 .55561 .49334 Mtetra
.672 .739 .901 r
.55561 .49334 .56116 .49993 .57166 .49617 .56614 .48958 Mtetra
.687 .745 .895 r
.56614 .48958 .57166 .49617 .5822 .49192 .57671 .48535 Mtetra
.7 .75 .891 r
.57671 .48535 .5822 .49192 .59276 .48723 .5873 .48071 Mtetra
.711 .756 .887 r
.5873 .48071 .59276 .48723 .60334 .48215 .59791 .4757 Mtetra
.72 .761 .885 r
.59791 .4757 .60334 .48215 .61395 .47678 .60855 .4704 Mtetra
.725 .766 .885 r
.60855 .4704 .61395 .47678 .62457 .47119 .6192 .4649 Mtetra
.729 .771 .886 r
.6192 .4649 .62457 .47119 .63522 .4655 .62989 .4593 Mtetra
.729 .775 .889 r
.62989 .4593 .63522 .4655 .64589 .45981 .6406 .4537 Mtetra
.727 .778 .894 r
.6406 .4537 .64589 .45981 .6566 .45423 .65134 .4482 Mtetra
.721 .78 .899 r
.65134 .4482 .6566 .45423 .66734 .44885 .66212 .44289 Mtetra
.712 .781 .906 r
.66212 .44289 .66734 .44885 .67812 .44376 .67294 .43786 Mtetra
.701 .781 .913 r
.67294 .43786 .67812 .44376 .68896 .43904 .68381 .43319 Mtetra
.686 .779 .921 r
.68381 .43319 .68896 .43904 .69985 .43475 .69473 .42891 Mtetra
.669 .774 .929 r
.69473 .42891 .69985 .43475 .7108 .43093 .70572 .42509 Mtetra
.65 .768 .935 r
.70572 .42509 .7108 .43093 .72183 .42759 .71678 .42172 Mtetra
.631 .761 .941 r
.71678 .42172 .72183 .42759 .73293 .42474 .7279 .41881 Mtetra
.611 .752 .945 r
.7279 .41881 .73293 .42474 .74411 .42233 .73911 .41633 Mtetra
.593 .742 .947 r
.73911 .41633 .74411 .42233 .75537 .42034 .7504 .41423 Mtetra
.578 .732 .948 r
.7504 .41423 .75537 .42034 .76671 .41869 .76176 .41246 Mtetra
.567 .724 .947 r
.76176 .41246 .76671 .41869 .77813 .41729 .7732 .41094 Mtetra
.561 .717 .945 r
.7732 .41094 .77813 .41729 .78962 .41606 .78471 .40957 Mtetra
.56 .712 .943 r
.78471 .40957 .78962 .41606 .80118 .41489 .79629 .40826 Mtetra
.563 .709 .939 r
.79629 .40826 .80118 .41489 .8128 .41368 .80793 .4069 Mtetra
.571 .708 .935 r
.80793 .4069 .8128 .41368 .82447 .41231 .81962 .4054 Mtetra
.582 .71 .93 r
.81962 .4054 .82447 .41231 .83618 .41068 .83135 .40365 Mtetra
.597 .713 .925 r
.83135 .40365 .83618 .41068 .84791 .40871 .8431 .40157 Mtetra
.613 .718 .92 r
.8431 .40157 .84791 .40871 .85967 .40632 .85488 .3991 Mtetra
.63 .724 .915 r
.85488 .3991 .85967 .40632 .87142 .40345 .86666 .39616 Mtetra
.647 .73 .909 r
.86666 .39616 .87142 .40345 .88318 .40007 .87845 .39274 Mtetra
.664 .74 .906 r
.25086 .5806 .2571 .58647 .26654 .5833 .26033 .57742 Mtetra
.68 .744 .899 r
.26033 .57742 .26654 .5833 .27606 .57966 .26986 .57379 Mtetra
.694 .748 .893 r
.26986 .57379 .27606 .57966 .28563 .57559 .27945 .56975 Mtetra
.706 .752 .888 r
.27945 .56975 .28563 .57559 .29526 .57114 .2891 .56534 Mtetra
.715 .755 .884 r
.2891 .56534 .29526 .57114 .30493 .56637 .29879 .56062 Mtetra
.722 .759 .882 r
.29879 .56062 .30493 .56637 .31465 .56137 .30852 .55568 Mtetra
.726 .762 .882 r
.30852 .55568 .31465 .56137 .32439 .55622 .31829 .55059 Mtetra
.727 .765 .883 r
.31829 .55059 .32439 .55622 .33416 .55102 .32808 .54546 Mtetra
.726 .768 .886 r
.32808 .54546 .33416 .55102 .34395 .54586 .33789 .54037 Mtetra
.723 .771 .891 r
.33789 .54037 .34395 .54586 .35376 .54086 .34771 .53542 Mtetra
.716 .772 .897 r
.34771 .53542 .35376 .54086 .36357 .53608 .35755 .53069 Mtetra
.706 .773 .904 r
.35755 .53069 .36357 .53608 .3734 .53162 .36741 .52627 Mtetra
.694 .772 .912 r
.36741 .52627 .3734 .53162 .38324 .52753 .37727 .52219 Mtetra
.678 .771 .92 r
.37727 .52219 .38324 .52753 .3931 .52385 .38715 .51852 Mtetra
.66 .767 .929 r
.38715 .51852 .3931 .52385 .40297 .52062 .39704 .51528 Mtetra
.641 .762 .936 r
.39704 .51528 .40297 .52062 .41286 .51785 .40695 .51246 Mtetra
.62 .755 .942 r
.40695 .51246 .41286 .51785 .42277 .51551 .41689 .51007 Mtetra
.6 .747 .947 r
.41689 .51007 .42277 .51551 .43272 .51357 .42686 .50806 Mtetra
.582 .739 .95 r
.42686 .50806 .43272 .51357 .4427 .51198 .43687 .50639 Mtetra
.567 .731 .952 r
.43687 .50639 .4427 .51198 .45272 .51067 .44691 .50498 Mtetra
.557 .724 .952 r
.44691 .50498 .45272 .51067 .46278 .50956 .457 .50377 Mtetra
.553 .719 .95 r
.457 .50377 .46278 .50956 .47289 .50856 .46713 .50266 Mtetra
.553 .715 .948 r
.46713 .50266 .47289 .50856 .48306 .50756 .47732 .50155 Mtetra
.56 .714 .944 r
.47732 .50155 .48306 .50756 .49328 .50647 .48756 .50035 Mtetra
.57 .715 .94 r
.48756 .50035 .49328 .50647 .50355 .50519 .49785 .49897 Mtetra
.585 .718 .935 r
.49785 .49897 .50355 .50519 .51387 .50364 .50819 .49733 Mtetra
.602 .722 .929 r
.50819 .49733 .51387 .50364 .52424 .50173 .51858 .49534 Mtetra
.62 .727 .923 r
.51858 .49534 .52424 .50173 .53465 .4994 .52902 .49295 Mtetra
.638 .732 .916 r
.52902 .49295 .53465 .4994 .54511 .49661 .53951 .49012 Mtetra
.655 .737 .91 r
.53951 .49012 .54511 .49661 .55561 .49334 .55003 .48682 Mtetra
.672 .743 .904 r
.55003 .48682 .55561 .49334 .56614 .48958 .56059 .48306 Mtetra
.687 .748 .898 r
.56059 .48306 .56614 .48958 .57671 .48535 .57118 .47885 Mtetra
.699 .753 .894 r
.57118 .47885 .57671 .48535 .5873 .48071 .5818 .47423 Mtetra
.71 .758 .89 r
.5818 .47423 .5873 .48071 .59791 .4757 .59244 .46927 Mtetra
.718 .763 .888 r
.59244 .46927 .59791 .4757 .60855 .4704 .60311 .46402 Mtetra
.723 .767 .887 r
.60311 .46402 .60855 .4704 .6192 .4649 .6138 .45859 Mtetra
.726 .771 .888 r
.6138 .45859 .6192 .4649 .62989 .4593 .62452 .45306 Mtetra
.726 .774 .89 r
.62452 .45306 .62989 .4593 .6406 .4537 .63526 .44752 Mtetra
.724 .776 .894 r
.63526 .44752 .6406 .4537 .65134 .4482 .64604 .44208 Mtetra
.718 .778 .899 r
.64604 .44208 .65134 .4482 .66212 .44289 .65685 .43682 Mtetra
.71 .778 .905 r
.65685 .43682 .66212 .44289 .67294 .43786 .66771 .43183 Mtetra
.699 .777 .912 r
.66771 .43183 .67294 .43786 .68381 .43319 .67861 .42718 Mtetra
.685 .774 .919 r
.67861 .42718 .68381 .43319 .69473 .42891 .68957 .42292 Mtetra
.669 .77 .926 r
.68957 .42292 .69473 .42891 .70572 .42509 .70059 .41908 Mtetra
.651 .764 .932 r
.70059 .41908 .70572 .42509 .71678 .42172 .71168 .41568 Mtetra
.632 .757 .937 r
.71168 .41568 .71678 .42172 .7279 .41881 .72284 .41272 Mtetra
.614 .749 .941 r
.72284 .41272 .7279 .41881 .73911 .41633 .73407 .41017 Mtetra
.597 .74 .944 r
.73407 .41017 .73911 .41633 .7504 .41423 .74538 .408 Mtetra
.583 .731 .945 r
.74538 .408 .7504 .41423 .76176 .41246 .75677 .40613 Mtetra
.572 .724 .945 r
.75677 .40613 .76176 .41246 .7732 .41094 .76823 .4045 Mtetra
.566 .718 .944 r
.76823 .4045 .7732 .41094 .78471 .40957 .77977 .40302 Mtetra
.564 .713 .942 r
.77977 .40302 .78471 .40957 .79629 .40826 .79137 .40159 Mtetra
.567 .711 .939 r
.79137 .40159 .79629 .40826 .80793 .4069 .80303 .40012 Mtetra
.574 .711 .935 r
.80303 .40012 .80793 .4069 .81962 .4054 .81474 .3985 Mtetra
.585 .713 .931 r
.81474 .3985 .81962 .4054 .83135 .40365 .82649 .39665 Mtetra
.599 .717 .927 r
.82649 .39665 .83135 .40365 .8431 .40157 .83827 .39448 Mtetra
.614 .722 .922 r
.83827 .39448 .8431 .40157 .85488 .3991 .85007 .39193 Mtetra
.631 .728 .917 r
.85007 .39193 .85488 .3991 .86666 .39616 .86188 .38894 Mtetra
.647 .734 .912 r
.86188 .38894 .86666 .39616 .87845 .39274 .8737 .38548 Mtetra
.664 .743 .909 r
.24458 .57481 .25086 .5806 .26033 .57742 .25406 .57162 Mtetra
.68 .747 .902 r
.25406 .57162 .26033 .57742 .26986 .57379 .26361 .56799 Mtetra
.694 .751 .896 r
.26361 .56799 .26986 .57379 .27945 .56975 .27323 .56396 Mtetra
.705 .754 .89 r
.27323 .56396 .27945 .56975 .2891 .56534 .28289 .55957 Mtetra
.714 .757 .887 r
.28289 .55957 .2891 .56534 .29879 .56062 .2926 .55488 Mtetra
.72 .76 .884 r
.2926 .55488 .29879 .56062 .30852 .55568 .30236 .54998 Mtetra
.724 .763 .884 r
.30236 .54998 .30852 .55568 .31829 .55059 .31214 .54493 Mtetra
.726 .765 .884 r
.31214 .54493 .31829 .55059 .32808 .54546 .32195 .53984 Mtetra
.724 .767 .887 r
.32195 .53984 .32808 .54546 .33789 .54037 .33179 .5348 Mtetra
.721 .769 .891 r
.33179 .5348 .33789 .54037 .34771 .53542 .34163 .52989 Mtetra
.714 .77 .896 r
.34163 .52989 .34771 .53542 .35755 .53069 .3515 .52519 Mtetra
.705 .77 .903 r
.3515 .52519 .35755 .53069 .36741 .52627 .36137 .52078 Mtetra
.692 .769 .91 r
.36137 .52078 .36741 .52627 .37727 .52219 .37126 .51672 Mtetra
.678 .767 .918 r
.37126 .51672 .37727 .52219 .38715 .51852 .38116 .51304 Mtetra
.66 .763 .926 r
.38116 .51304 .38715 .51852 .39704 .51528 .39108 .50978 Mtetra
.642 .758 .933 r
.39108 .50978 .39704 .51528 .40695 .51246 .40102 .50693 Mtetra
.622 .751 .939 r
.40102 .50693 .40695 .51246 .41689 .51007 .41098 .5045 Mtetra
.603 .744 .944 r
.41098 .5045 .41689 .51007 .42686 .50806 .42097 .50243 Mtetra
.586 .737 .947 r
.42097 .50243 .42686 .50806 .43687 .50639 .431 .50069 Mtetra
.572 .73 .949 r
.431 .50069 .43687 .50639 .44691 .50498 .44106 .49921 Mtetra
.562 .724 .95 r
.44106 .49921 .44691 .50498 .457 .50377 .45117 .49791 Mtetra
.557 .719 .949 r
.45117 .49791 .457 .50377 .46713 .50266 .46133 .49671 Mtetra
.557 .717 .947 r
.46133 .49671 .46713 .50266 .47732 .50155 .47154 .49552 Mtetra
.563 .717 .944 r
.47154 .49552 .47732 .50155 .48756 .50035 .4818 .49423 Mtetra
.573 .718 .941 r
.4818 .49423 .48756 .50035 .49785 .49897 .49211 .49278 Mtetra
.587 .721 .936 r
.49211 .49278 .49785 .49897 .50819 .49733 .50248 .49106 Mtetra
.603 .725 .931 r
.50248 .49106 .50819 .49733 .51858 .49534 .51289 .48901 Mtetra
.62 .73 .925 r
.51289 .48901 .51858 .49534 .52902 .49295 .52336 .48657 Mtetra
.638 .736 .919 r
.52336 .48657 .52902 .49295 .53951 .49012 .53387 .4837 Mtetra
.655 .741 .913 r
.53387 .4837 .53951 .49012 .55003 .48682 .54441 .48038 Mtetra
.671 .747 .907 r
.54441 .48038 .55003 .48682 .56059 .48306 .555 .47661 Mtetra
.686 .752 .901 r
.555 .47661 .56059 .48306 .57118 .47885 .56562 .4724 Mtetra
.698 .756 .897 r
.56562 .4724 .57118 .47885 .5818 .47423 .57626 .4678 Mtetra
.708 .761 .893 r
.57626 .4678 .5818 .47423 .59244 .46927 .58694 .46286 Mtetra
.716 .765 .891 r
.58694 .46286 .59244 .46927 .60311 .46402 .59764 .45765 Mtetra
.722 .768 .889 r
.59764 .45765 .60311 .46402 .6138 .45859 .60836 .45225 Mtetra
.724 .771 .89 r
.60836 .45225 .6138 .45859 .62452 .45306 .61911 .44676 Mtetra
.724 .773 .891 r
.61911 .44676 .62452 .45306 .63526 .44752 .62989 .44127 Mtetra
.722 .775 .895 r
.62989 .44127 .63526 .44752 .64604 .44208 .6407 .43586 Mtetra
.716 .775 .899 r
.6407 .43586 .64604 .44208 .65685 .43682 .65155 .43064 Mtetra
.708 .775 .904 r
.65155 .43064 .65685 .43682 .66771 .43183 .66244 .42567 Mtetra
.697 .773 .91 r
.66244 .42567 .66771 .43183 .67861 .42718 .67337 .42103 Mtetra
.684 .77 .917 r
.67337 .42103 .67861 .42718 .68957 .42292 .68436 .41676 Mtetra
.669 .766 .923 r
.68436 .41676 .68957 .42292 .70059 .41908 .69542 .41291 Mtetra
.652 .76 .929 r
.69542 .41291 .70059 .41908 .71168 .41568 .70653 .40948 Mtetra
.634 .753 .934 r
.70653 .40948 .71168 .41568 .72284 .41272 .71772 .40648 Mtetra
.616 .745 .938 r
.71772 .40648 .72284 .41272 .73407 .41017 .72898 .40388 Mtetra
.6 .737 .941 r
.72898 .40388 .73407 .41017 .74538 .408 .74032 .40164 Mtetra
.586 .73 .942 r
.74032 .40164 .74538 .408 .75677 .40613 .75174 .39969 Mtetra
.576 .723 .943 r
.75174 .39969 .75677 .40613 .76823 .4045 .76322 .39798 Mtetra
.57 .718 .942 r
.76322 .39798 .76823 .4045 .77977 .40302 .77478 .3964 Mtetra
.568 .715 .941 r
.77478 .3964 .77977 .40302 .79137 .40159 .78641 .39488 Mtetra
.57 .713 .939 r
.78641 .39488 .79137 .40159 .80303 .40012 .79809 .39331 Mtetra
.577 .714 .936 r
.79809 .39331 .80303 .40012 .81474 .3985 .80983 .39161 Mtetra
.587 .716 .933 r
.80983 .39161 .81474 .3985 .82649 .39665 .8216 .38968 Mtetra
.6 .72 .929 r
.8216 .38968 .82649 .39665 .83827 .39448 .83341 .38744 Mtetra
.615 .726 .925 r
.83341 .38744 .83827 .39448 .85007 .39193 .84524 .38482 Mtetra
.631 .732 .92 r
.84524 .38482 .85007 .39193 .86188 .38894 .85708 .38178 Mtetra
.647 .738 .915 r
.85708 .38178 .86188 .38894 .8737 .38548 .86893 .37829 Mtetra
.664 .747 .912 r
.23824 .56909 .24458 .57481 .25406 .57162 .24775 .56588 Mtetra
.68 .751 .905 r
.24775 .56588 .25406 .57162 .26361 .56799 .25732 .56224 Mtetra
.693 .754 .898 r
.25732 .56224 .26361 .56799 .27323 .56396 .26695 .55821 Mtetra
.704 .757 .893 r
.26695 .55821 .27323 .56396 .28289 .55957 .27664 .55383 Mtetra
.713 .76 .889 r
.27664 .55383 .28289 .55957 .2926 .55488 .28637 .54916 Mtetra
.719 .762 .886 r
.28637 .54916 .2926 .55488 .30236 .54998 .29615 .54427 Mtetra
.723 .764 .885 r
.29615 .54427 .30236 .54998 .31214 .54493 .30595 .53925 Mtetra
.724 .766 .885 r
.30595 .53925 .31214 .54493 .32195 .53984 .31579 .53418 Mtetra
.723 .767 .887 r
.31579 .53418 .32195 .53984 .33179 .5348 .32564 .52915 Mtetra
.719 .768 .891 r
.32564 .52915 .33179 .5348 .34163 .52989 .33552 .52426 Mtetra
.713 .768 .896 r
.33552 .52426 .34163 .52989 .3515 .52519 .3454 .51957 Mtetra
.703 .767 .902 r
.3454 .51957 .3515 .52519 .36137 .52078 .3553 .51517 Mtetra
.691 .766 .908 r
.3553 .51517 .36137 .52078 .37126 .51672 .36521 .5111 Mtetra
.677 .763 .916 r
.36521 .5111 .37126 .51672 .38116 .51304 .37514 .50741 Mtetra
.661 .759 .923 r
.37514 .50741 .38116 .51304 .39108 .50978 .38508 .50413 Mtetra
.643 .754 .93 r
.38508 .50413 .39108 .50978 .40102 .50693 .39504 .50126 Mtetra
.624 .748 .936 r
.39504 .50126 .40102 .50693 .41098 .5045 .40502 .49879 Mtetra
.606 .741 .941 r
.40502 .49879 .41098 .5045 .42097 .50243 .41504 .49668 Mtetra
.589 .735 .944 r
.41504 .49668 .42097 .50243 .431 .50069 .42509 .49488 Mtetra
.575 .728 .947 r
.42509 .49488 .431 .50069 .44106 .49921 .43518 .49335 Mtetra
.565 .723 .948 r
.43518 .49335 .44106 .49921 .45117 .49791 .44531 .49199 Mtetra
.56 .719 .948 r
.44531 .49199 .45117 .49791 .46133 .49671 .45549 .49072 Mtetra
.56 .718 .946 r
.45549 .49072 .46133 .49671 .47154 .49552 .46572 .48946 Mtetra
.565 .718 .944 r
.46572 .48946 .47154 .49552 .4818 .49423 .476 .48812 Mtetra
.575 .72 .941 r
.476 .48812 .4818 .49423 .49211 .49278 .48634 .4866 Mtetra
.588 .724 .938 r
.48634 .4866 .49211 .49278 .50248 .49106 .49672 .48483 Mtetra
.603 .729 .933 r
.49672 .48483 .50248 .49106 .51289 .48901 .50716 .48273 Mtetra
.621 .734 .928 r
.50716 .48273 .51289 .48901 .52336 .48657 .51765 .48025 Mtetra
.638 .739 .922 r
.51765 .48025 .52336 .48657 .53387 .4837 .52818 .47734 Mtetra
.655 .745 .916 r
.52818 .47734 .53387 .4837 .54441 .48038 .53876 .474 Mtetra
.671 .75 .91 r
.53876 .474 .54441 .48038 .555 .47661 .54937 .47021 Mtetra
.686 .755 .904 r
.54937 .47021 .555 .47661 .56562 .4724 .56001 .466 Mtetra
.698 .759 .899 r
.56001 .466 .56562 .4724 .57626 .4678 .57069 .4614 Mtetra
.708 .763 .895 r
.57069 .4614 .57626 .4678 .58694 .46286 .58139 .45647 Mtetra
.715 .766 .893 r
.58139 .45647 .58694 .46286 .59764 .45765 .59212 .45127 Mtetra
.721 .769 .891 r
.59212 .45127 .59764 .45765 .60836 .45225 .60288 .44589 Mtetra
.723 .771 .891 r
.60288 .44589 .60836 .45225 .61911 .44676 .61366 .44042 Mtetra
.723 .773 .892 r
.61366 .44042 .61911 .44676 .62989 .44127 .62447 .43494 Mtetra
.72 .773 .895 r
.62447 .43494 .62989 .44127 .6407 .43586 .63532 .42955 Mtetra
.715 .773 .898 r
.63532 .42955 .6407 .43586 .65155 .43064 .6462 .42434 Mtetra
.707 .772 .903 r
.6462 .42434 .65155 .43064 .66244 .42567 .65712 .41938 Mtetra
.696 .77 .909 r
.65712 .41938 .66244 .42567 .67337 .42103 .66809 .41473 Mtetra
.683 .767 .914 r
.66809 .41473 .67337 .42103 .68436 .41676 .67911 .41046 Mtetra
.668 .762 .92 r
.67911 .41046 .68436 .41676 .69542 .41291 .6902 .40659 Mtetra
.652 .756 .926 r
.6902 .40659 .69542 .41291 .70653 .40948 .70135 .40313 Mtetra
.635 .75 .931 r
.70135 .40313 .70653 .40948 .71772 .40648 .71256 .40009 Mtetra
.618 .742 .935 r
.71256 .40009 .71772 .40648 .72898 .40388 .72385 .39745 Mtetra
.602 .735 .938 r
.72385 .39745 .72898 .40388 .74032 .40164 .73522 .39515 Mtetra
.589 .728 .94 r
.73522 .39515 .74032 .40164 .75174 .39969 .74666 .39315 Mtetra
.579 .722 .941 r
.74666 .39315 .75174 .39969 .76322 .39798 .75818 .39136 Mtetra
.572 .718 .941 r
.75818 .39136 .76322 .39798 .77478 .3964 .76976 .38972 Mtetra
.57 .715 .94 r
.76976 .38972 .77478 .3964 .78641 .39488 .78141 .38813 Mtetra
.572 .714 .939 r
.78141 .38813 .78641 .39488 .79809 .39331 .79312 .38649 Mtetra
.579 .716 .936 r
.79312 .38649 .79809 .39331 .80983 .39161 .80488 .38472 Mtetra
.588 .719 .934 r
.80488 .38472 .80983 .39161 .8216 .38968 .81669 .38273 Mtetra
.601 .723 .93 r
.81669 .38273 .8216 .38968 .83341 .38744 .82852 .38043 Mtetra
.616 .729 .927 r
.82852 .38043 .83341 .38744 .84524 .38482 .84038 .37776 Mtetra
.631 .735 .923 r
.84038 .37776 .84524 .38482 .85708 .38178 .85225 .37468 Mtetra
.647 .742 .918 r
.85225 .37468 .85708 .38178 .86893 .37829 .86413 .37116 Mtetra
.664 .751 .915 r
.23185 .56344 .23824 .56909 .24775 .56588 .24138 .56021 Mtetra
.68 .754 .908 r
.24138 .56021 .24775 .56588 .25732 .56224 .25097 .55656 Mtetra
.693 .757 .901 r
.25097 .55656 .25732 .56224 .26695 .55821 .26063 .55252 Mtetra
.704 .76 .895 r
.26063 .55252 .26695 .55821 .27664 .55383 .27034 .54813 Mtetra
.713 .762 .891 r
.27034 .54813 .27664 .55383 .28637 .54916 .28009 .54345 Mtetra
.719 .764 .888 r
.28009 .54345 .28637 .54916 .29615 .54427 .28989 .53856 Mtetra
.723 .765 .886 r
.28989 .53856 .29615 .54427 .30595 .53925 .29972 .53353 Mtetra
.724 .766 .886 r
.29972 .53353 .30595 .53925 .31579 .53418 .30958 .52846 Mtetra
.722 .766 .887 r
.30958 .52846 .31579 .53418 .32564 .52915 .31946 .52343 Mtetra
.718 .766 .89 r
.31946 .52343 .32564 .52915 .33552 .52426 .32936 .51853 Mtetra
.712 .766 .895 r
.32936 .51853 .33552 .52426 .3454 .51957 .33927 .51384 Mtetra
.703 .764 .9 r
.33927 .51384 .3454 .51957 .3553 .51517 .34919 .50943 Mtetra
.691 .762 .906 r
.34919 .50943 .3553 .51517 .36521 .5111 .35913 .50535 Mtetra
.677 .759 .913 r
.35913 .50535 .36521 .5111 .37514 .50741 .36908 .50165 Mtetra
.661 .755 .92 r
.36908 .50165 .37514 .50741 .38508 .50413 .37904 .49834 Mtetra
.643 .75 .927 r
.37904 .49834 .38508 .50413 .39504 .50126 .38902 .49544 Mtetra
.625 .745 .933 r
.38902 .49544 .39504 .50126 .40502 .49879 .39903 .49294 Mtetra
.607 .738 .938 r
.39903 .49294 .40502 .49879 .41504 .49668 .40907 .4908 Mtetra
.591 .732 .942 r
.40907 .4908 .41504 .49668 .42509 .49488 .41914 .48897 Mtetra
.577 .726 .945 r
.41914 .48897 .42509 .49488 .43518 .49335 .42925 .48739 Mtetra
.567 .722 .946 r
.42925 .48739 .43518 .49335 .44531 .49199 .4394 .48599 Mtetra
.562 .719 .947 r
.4394 .48599 .44531 .49199 .45549 .49072 .4496 .48469 Mtetra
.561 .718 .946 r
.4496 .48469 .45549 .49072 .46572 .48946 .45986 .48339 Mtetra
.566 .719 .945 r
.45986 .48339 .46572 .48946 .476 .48812 .47016 .482 Mtetra
.575 .722 .942 r
.47016 .482 .476 .48812 .48634 .4866 .48052 .48044 Mtetra
.588 .726 .939 r
.48052 .48044 .48634 .4866 .49672 .48483 .49093 .47863 Mtetra
.603 .731 .935 r
.49093 .47863 .49672 .48483 .50716 .48273 .50139 .4765 Mtetra
.621 .737 .93 r
.50139 .4765 .50716 .48273 .51765 .48025 .5119 .47398 Mtetra
.638 .743 .925 r
.5119 .47398 .51765 .48025 .52818 .47734 .52246 .47105 Mtetra
.655 .749 .919 r
.52246 .47105 .52818 .47734 .53876 .474 .53306 .46769 Mtetra
.671 .754 .913 r
.53306 .46769 .53876 .474 .54937 .47021 .5437 .46388 Mtetra
.685 .758 .907 r
.5437 .46388 .54937 .47021 .56001 .466 .55437 .45965 Mtetra
.698 .762 .902 r
.55437 .45965 .56001 .466 .57069 .4614 .56508 .45504 Mtetra
.708 .766 .898 r
.56508 .45504 .57069 .4614 .58139 .45647 .57581 .45009 Mtetra
.715 .768 .894 r
.57581 .45009 .58139 .45647 .59212 .45127 .58657 .44489 Mtetra
.72 .77 .892 r
.58657 .44489 .59212 .45127 .60288 .44589 .59736 .43951 Mtetra
.723 .772 .892 r
.59736 .43951 .60288 .44589 .61366 .44042 .60818 .43403 Mtetra
.722 .772 .892 r
.60818 .43403 .61366 .44042 .62447 .43494 .61902 .42854 Mtetra
.72 .772 .894 r
.61902 .42854 .62447 .43494 .63532 .42955 .6299 .42315 Mtetra
.714 .772 .897 r
.6299 .42315 .63532 .42955 .6462 .42434 .64081 .41793 Mtetra
.706 .77 .902 r
.64081 .41793 .6462 .42434 .65712 .41938 .65176 .41295 Mtetra
.696 .767 .907 r
.65176 .41295 .65712 .41938 .66809 .41473 .66277 .40829 Mtetra
.683 .763 .912 r
.66277 .40829 .66809 .41473 .67911 .41046 .67382 .404 Mtetra
.668 .758 .918 r
.67382 .404 .67911 .41046 .6902 .40659 .68493 .40011 Mtetra
.652 .753 .923 r
.68493 .40011 .6902 .40659 .70135 .40313 .69611 .39663 Mtetra
.636 .746 .928 r
.69611 .39663 .70135 .40313 .71256 .40009 .70736 .39356 Mtetra
.619 .739 .932 r
.70736 .39356 .71256 .40009 .72385 .39745 .71868 .39087 Mtetra
.604 .732 .935 r
.71868 .39087 .72385 .39745 .73522 .39515 .73008 .38854 Mtetra
.591 .726 .938 r
.73008 .38854 .73522 .39515 .74666 .39315 .74154 .38649 Mtetra
.58 .721 .939 r
.74154 .38649 .74666 .39315 .75818 .39136 .75309 .38467 Mtetra
.574 .717 .94 r
.75309 .38467 .75818 .39136 .76976 .38972 .7647 .38298 Mtetra
.571 .715 .939 r
.7647 .38298 .76976 .38972 .78141 .38813 .77638 .38134 Mtetra
.573 .715 .939 r
.77638 .38134 .78141 .38813 .79312 .38649 .78812 .37965 Mtetra
.579 .717 .937 r
.78812 .37965 .79312 .38649 .80488 .38472 .79991 .37784 Mtetra
.589 .721 .935 r
.79991 .37784 .80488 .38472 .81669 .38273 .81174 .3758 Mtetra
.601 .726 .932 r
.81174 .3758 .81669 .38273 .82852 .38043 .82361 .37346 Mtetra
.616 .732 .929 r
.82361 .37346 .82852 .38043 .84038 .37776 .8355 .37076 Mtetra
.631 .739 .925 r
.8355 .37076 .84038 .37776 .85225 .37468 .8474 .36764 Mtetra
.647 .745 .921 r
.8474 .36764 .85225 .37468 .86413 .37116 .85932 .36408 Mtetra
.664 .754 .918 r
.22542 .55785 .23185 .56344 .24138 .56021 .23496 .5546 Mtetra
.68 .758 .91 r
.23496 .5546 .24138 .56021 .25097 .55656 .24458 .55093 Mtetra
.693 .761 .903 r
.24458 .55093 .25097 .55656 .26063 .55252 .25425 .54687 Mtetra
.705 .763 .897 r
.25425 .54687 .26063 .55252 .27034 .54813 .26399 .54245 Mtetra
.713 .764 .892 r
.26399 .54245 .27034 .54813 .28009 .54345 .27377 .53775 Mtetra
.719 .765 .889 r
.27377 .53775 .28009 .54345 .28989 .53856 .28359 .53284 Mtetra
.723 .766 .887 r
.28359 .53284 .28989 .53856 .29972 .53353 .29345 .52779 Mtetra
.724 .766 .886 r
.29345 .52779 .29972 .53353 .30958 .52846 .30333 .52269 Mtetra
.722 .766 .887 r
.30333 .52269 .30958 .52846 .31946 .52343 .31324 .51764 Mtetra
.718 .765 .89 r
.31324 .51764 .31946 .52343 .32936 .51853 .32316 .51271 Mtetra
.711 .764 .893 r
.32316 .51271 .32936 .51853 .33927 .51384 .3331 .508 Mtetra
.702 .762 .898 r
.3331 .508 .33927 .51384 .34919 .50943 .34305 .50356 Mtetra
.691 .759 .904 r
.34305 .50356 .34919 .50943 .35913 .50535 .35301 .49946 Mtetra
.677 .756 .911 r
.35301 .49946 .35913 .50535 .36908 .50165 .36298 .49573 Mtetra
.661 .752 .917 r
.36298 .49573 .36908 .50165 .37904 .49834 .37297 .49241 Mtetra
.643 .747 .924 r
.37297 .49241 .37904 .49834 .38902 .49544 .38297 .48949 Mtetra
.625 .741 .93 r
.38297 .48949 .38902 .49544 .39903 .49294 .393 .48696 Mtetra
.608 .735 .935 r
.393 .48696 .39903 .49294 .40907 .4908 .40306 .4848 Mtetra
.591 .729 .94 r
.40306 .4848 .40907 .4908 .41914 .48897 .41315 .48295 Mtetra
.578 .724 .943 r
.41315 .48295 .41914 .48897 .42925 .48739 .42328 .48135 Mtetra
.568 .721 .945 r
.42328 .48135 .42925 .48739 .4394 .48599 .43346 .47993 Mtetra
.562 .718 .946 r
.43346 .47993 .4394 .48599 .4496 .48469 .44368 .47861 Mtetra
.561 .718 .946 r
.44368 .47861 .4496 .48469 .45986 .48339 .45395 .47729 Mtetra
.566 .72 .945 r
.45395 .47729 .45986 .48339 .47016 .482 .46428 .47588 Mtetra
.575 .723 .944 r
.46428 .47588 .47016 .482 .48052 .48044 .47466 .4743 Mtetra
.587 .728 .941 r
.47466 .4743 .48052 .48044 .49093 .47863 .48509 .47247 Mtetra
.603 .734 .937 r
.48509 .47247 .49093 .47863 .50139 .4765 .49558 .47031 Mtetra
.62 .74 .933 r
.49558 .47031 .50139 .4765 .5119 .47398 .50611 .46778 Mtetra
.638 .746 .927 r
.50611 .46778 .5119 .47398 .52246 .47105 .5167 .46483 Mtetra
.655 .752 .921 r
.5167 .46483 .52246 .47105 .53306 .46769 .52733 .46143 Mtetra
.671 .757 .915 r
.52733 .46143 .53306 .46769 .5437 .46388 .53799 .4576 Mtetra
.686 .762 .909 r
.53799 .4576 .5437 .46388 .55437 .45965 .54869 .45335 Mtetra
.698 .766 .904 r
.54869 .45335 .55437 .45965 .56508 .45504 .55943 .44871 Mtetra
.708 .768 .899 r
.55943 .44871 .56508 .45504 .57581 .45009 .57019 .44374 Mtetra
.716 .77 .896 r
.57019 .44374 .57581 .45009 .58657 .44489 .58099 .43851 Mtetra
.72 .772 .893 r
.58099 .43851 .58657 .44489 .59736 .43951 .5918 .43309 Mtetra
.723 .772 .892 r
.5918 .43309 .59736 .43951 .60818 .43403 .60265 .42759 Mtetra
.722 .772 .892 r
.60265 .42759 .60818 .43403 .61902 .42854 .61353 .42208 Mtetra
.719 .772 .894 r
.61353 .42208 .61902 .42854 .6299 .42315 .62443 .41665 Mtetra
.714 .77 .896 r
.62443 .41665 .6299 .42315 .64081 .41793 .63538 .4114 Mtetra
.706 .767 .9 r
.63538 .4114 .64081 .41793 .65176 .41295 .64637 .4064 Mtetra
.695 .764 .905 r
.64637 .4064 .65176 .41295 .66277 .40829 .6574 .40171 Mtetra
.683 .76 .91 r
.6574 .40171 .66277 .40829 .67382 .404 .66848 .39739 Mtetra
.668 .755 .915 r
.66848 .39739 .67382 .404 .68493 .40011 .67963 .39347 Mtetra
.652 .749 .92 r
.67963 .39347 .68493 .40011 .69611 .39663 .69084 .38997 Mtetra
.636 .743 .925 r
.69084 .38997 .69611 .39663 .70736 .39356 .70211 .38687 Mtetra
.62 .736 .93 r
.70211 .38687 .70736 .39356 .71868 .39087 .71346 .38416 Mtetra
.605 .729 .933 r
.71346 .38416 .71868 .39087 .73008 .38854 .72489 .3818 Mtetra
.591 .724 .936 r
.72489 .3818 .73008 .38854 .74154 .38649 .73639 .37973 Mtetra
.581 .719 .938 r
.73639 .37973 .74154 .38649 .75309 .38467 .74796 .37788 Mtetra
.574 .716 .939 r
.74796 .37788 .75309 .38467 .7647 .38298 .7596 .37617 Mtetra
.572 .715 .939 r
.7596 .37617 .7647 .38298 .77638 .38134 .77131 .3745 Mtetra
.573 .715 .939 r
.77131 .3745 .77638 .38134 .78812 .37965 .78308 .3728 Mtetra
.579 .718 .938 r
.78308 .3728 .78812 .37965 .79991 .37784 .7949 .37095 Mtetra
.588 .722 .936 r
.7949 .37095 .79991 .37784 .81174 .3758 .80676 .36889 Mtetra
.601 .728 .934 r
.80676 .36889 .81174 .3758 .82361 .37346 .81866 .36652 Mtetra
.615 .735 .931 r
.81866 .36652 .82361 .37346 .8355 .37076 .83059 .3638 Mtetra
.631 .742 .928 r
.83059 .3638 .8355 .37076 .8474 .36764 .84253 .36065 Mtetra
.647 .749 .924 r
.84253 .36065 .8474 .36764 .85932 .36408 .85448 .35707 Mtetra
.664 .758 .92 r
.21892 .55233 .22542 .55785 .23496 .5546 .22849 .54906 Mtetra
.68 .762 .913 r
.22849 .54906 .23496 .5546 .24458 .55093 .23813 .54536 Mtetra
.694 .764 .905 r
.23813 .54536 .24458 .55093 .25425 .54687 .24783 .54126 Mtetra
.706 .766 .899 r
.24783 .54126 .25425 .54687 .26399 .54245 .25759 .53681 Mtetra
.714 .767 .894 r
.25759 .53681 .26399 .54245 .27377 .53775 .2674 .53207 Mtetra
.72 .767 .89 r
.2674 .53207 .27377 .53775 .28359 .53284 .27725 .52711 Mtetra
.724 .767 .887 r
.27725 .52711 .28359 .53284 .29345 .52779 .28713 .52201 Mtetra
.725 .766 .886 r
.28713 .52201 .29345 .52779 .30333 .52269 .29704 .51687 Mtetra
.723 .765 .886 r
.29704 .51687 .30333 .52269 .31324 .51764 .30698 .51177 Mtetra
.718 .764 .888 r
.30698 .51177 .31324 .51764 .32316 .51271 .31693 .5068 Mtetra
.712 .762 .892 r
.31693 .5068 .32316 .51271 .3331 .508 .32689 .50204 Mtetra
.702 .759 .896 r
.32689 .50204 .3331 .508 .34305 .50356 .33686 .49756 Mtetra
.691 .756 .902 r
.33686 .49756 .34305 .50356 .35301 .49946 .34685 .49343 Mtetra
.677 .753 .908 r
.34685 .49343 .35301 .49946 .36298 .49573 .35684 .48967 Mtetra
.661 .748 .915 r
.35684 .48967 .36298 .49573 .37297 .49241 .36685 .48632 Mtetra
.644 .743 .921 r
.36685 .48632 .37297 .49241 .38297 .48949 .37688 .48339 Mtetra
.626 .737 .928 r
.37688 .48339 .38297 .48949 .393 .48696 .38693 .48085 Mtetra
.608 .732 .933 r
.38693 .48085 .393 .48696 .40306 .4848 .39701 .47868 Mtetra
.591 .726 .938 r
.39701 .47868 .40306 .4848 .41315 .48295 .40713 .47682 Mtetra
.577 .722 .941 r
.40713 .47682 .41315 .48295 .42328 .48135 .41728 .47522 Mtetra
.567 .719 .944 r
.41728 .47522 .42328 .48135 .43346 .47993 .42747 .47381 Mtetra
.561 .717 .946 r
.42747 .47381 .43346 .47993 .44368 .47861 .43771 .47248 Mtetra
.56 .718 .946 r
.43771 .47248 .44368 .47861 .45395 .47729 .44801 .47116 Mtetra
.564 .72 .946 r
.44801 .47116 .45395 .47729 .46428 .47588 .45835 .46976 Mtetra
.573 .724 .945 r
.45835 .46976 .46428 .47588 .47466 .4743 .46876 .46818 Mtetra
.586 .73 .943 r
.46876 .46818 .47466 .4743 .48509 .47247 .47921 .46634 Mtetra
.601 .736 .939 r
.47921 .46634 .48509 .47247 .49558 .47031 .48972 .46418 Mtetra
.619 .743 .935 r
.48972 .46418 .49558 .47031 .50611 .46778 .50028 .46163 Mtetra
.637 .75 .93 r
.50028 .46163 .50611 .46778 .5167 .46483 .51089 .45866 Mtetra
.655 .756 .924 r
.51089 .45866 .5167 .46483 .52733 .46143 .52155 .45524 Mtetra
.671 .761 .918 r
.52155 .45524 .52733 .46143 .53799 .4576 .53224 .45138 Mtetra
.686 .766 .912 r
.53224 .45138 .53799 .4576 .54869 .45335 .54298 .44709 Mtetra
.699 .769 .906 r
.54298 .44709 .54869 .45335 .55943 .44871 .55374 .44241 Mtetra
.709 .771 .901 r
.55374 .44241 .55943 .44871 .57019 .44374 .56453 .4374 Mtetra
.716 .773 .897 r
.56453 .4374 .57019 .44374 .58099 .43851 .57536 .43212 Mtetra
.721 .773 .894 r
.57536 .43212 .58099 .43851 .5918 .43309 .58621 .42665 Mtetra
.724 .773 .892 r
.58621 .42665 .5918 .43309 .60265 .42759 .59708 .4211 Mtetra
.723 .772 .892 r
.59708 .4211 .60265 .42759 .61353 .42208 .60799 .41553 Mtetra
.72 .771 .893 r
.60799 .41553 .61353 .42208 .62443 .41665 .61893 .41006 Mtetra
.714 .768 .895 r
.61893 .41006 .62443 .41665 .63538 .4114 .62991 .40476 Mtetra
.706 .765 .898 r
.62991 .40476 .63538 .4114 .64637 .4064 .64092 .39972 Mtetra
.696 .761 .903 r
.64092 .39972 .64637 .4064 .6574 .40171 .65199 .39499 Mtetra
.683 .757 .907 r
.65199 .39499 .6574 .40171 .66848 .39739 .6631 .39063 Mtetra
.668 .751 .913 r
.6631 .39063 .66848 .39739 .67963 .39347 .67428 .38668 Mtetra
.653 .745 .918 r
.67428 .38668 .67963 .39347 .69084 .38997 .68552 .38315 Mtetra
.636 .739 .923 r
.68552 .38315 .69084 .38997 .70211 .38687 .69682 .38003 Mtetra
.62 .732 .927 r
.69682 .38003 .70211 .38687 .71346 .38416 .7082 .37731 Mtetra
.605 .726 .931 r
.7082 .37731 .71346 .38416 .72489 .3818 .71966 .37494 Mtetra
.591 .721 .934 r
.71966 .37494 .72489 .3818 .73639 .37973 .73119 .37286 Mtetra
.581 .717 .936 r
.73119 .37286 .73639 .37973 .74796 .37788 .74279 .37101 Mtetra
.574 .714 .938 r
.74279 .37101 .74796 .37788 .7596 .37617 .75446 .36929 Mtetra
.571 .714 .939 r
.75446 .36929 .7596 .37617 .77131 .3745 .76621 .36763 Mtetra
.572 .715 .939 r
.76621 .36763 .77131 .3745 .78308 .3728 .77801 .36592 Mtetra
.578 .719 .939 r
.77801 .36592 .78308 .3728 .7949 .37095 .78986 .36407 Mtetra
.587 .724 .938 r
.78986 .36407 .7949 .37095 .80676 .36889 .80176 .362 Mtetra
.599 .73 .936 r
.80176 .362 .80676 .36889 .81866 .36652 .81369 .35963 Mtetra
.614 .737 .934 r
.81369 .35963 .81866 .36652 .83059 .3638 .82565 .35688 Mtetra
.63 .745 .93 r
.82565 .35688 .83059 .3638 .84253 .36065 .83762 .35372 Mtetra
.647 .752 .926 r
.83762 .35372 .84253 .36065 .85448 .35707 .84961 .35011 Mtetra
.664 .762 .923 r
.21238 .54688 .21892 .55233 .22849 .54906 .22197 .54358 Mtetra
.681 .765 .915 r
.22197 .54358 .22849 .54906 .23813 .54536 .23163 .53985 Mtetra
.695 .768 .907 r
.23163 .53985 .23813 .54536 .24783 .54126 .24136 .5357 Mtetra
.707 .769 .9 r
.24136 .5357 .24783 .54126 .25759 .53681 .25114 .5312 Mtetra
.716 .769 .895 r
.25114 .5312 .25759 .53681 .2674 .53207 .26098 .5264 Mtetra
.722 .769 .89 r
.26098 .5264 .2674 .53207 .27725 .52711 .27086 .52137 Mtetra
.725 .768 .887 r
.27086 .52137 .27725 .52711 .28713 .52201 .28077 .5162 Mtetra
.726 .767 .885 r
.28077 .5162 .28713 .52201 .29704 .51687 .29071 .51099 Mtetra
.724 .765 .885 r
.29071 .51099 .29704 .51687 .30698 .51177 .30067 .50582 Mtetra
.719 .763 .887 r
.30067 .50582 .30698 .51177 .31693 .5068 .31065 .50079 Mtetra
.712 .76 .89 r
.31065 .50079 .31693 .5068 .32689 .50204 .32064 .49597 Mtetra
.703 .757 .894 r
.32064 .49597 .32689 .50204 .33686 .49756 .33064 .49144 Mtetra
.691 .754 .899 r
.33064 .49144 .33686 .49756 .34685 .49343 .34065 .48726 Mtetra
.677 .749 .906 r
.34065 .48726 .34685 .49343 .35684 .48967 .35067 .48347 Mtetra
.661 .745 .912 r
.35067 .48347 .35684 .48967 .36685 .48632 .36071 .48009 Mtetra
.643 .739 .919 r
.36071 .48009 .36685 .48632 .37688 .48339 .37076 .47714 Mtetra
.625 .734 .925 r
.37076 .47714 .37688 .48339 .38693 .48085 .38083 .4746 Mtetra
.607 .728 .931 r
.38083 .4746 .38693 .48085 .39701 .47868 .39093 .47243 Mtetra
.59 .723 .936 r
.39093 .47243 .39701 .47868 .40713 .47682 .40106 .47059 Mtetra
.576 .719 .94 r
.40106 .47059 .40713 .47682 .41728 .47522 .41123 .46901 Mtetra
.565 .716 .943 r
.41123 .46901 .41728 .47522 .42747 .47381 .42144 .46761 Mtetra
.559 .715 .945 r
.42144 .46761 .42747 .47381 .43771 .47248 .4317 .46631 Mtetra
.558 .716 .947 r
.4317 .46631 .43771 .47248 .44801 .47116 .44202 .46502 Mtetra
.562 .72 .947 r
.44202 .46502 .44801 .47116 .45835 .46976 .45239 .46364 Mtetra
.57 .725 .946 r
.45239 .46364 .45835 .46976 .46876 .46818 .46281 .46208 Mtetra
.583 .731 .945 r
.46281 .46208 .46876 .46818 .47921 .46634 .47329 .46025 Mtetra
.599 .739 .942 r
.47329 .46025 .47921 .46634 .48972 .46418 .48382 .4581 Mtetra
.617 .746 .938 r
.48382 .4581 .48972 .46418 .50028 .46163 .49441 .45554 Mtetra
.636 .753 .933 r
.49441 .45554 .50028 .46163 .51089 .45866 .50505 .45256 Mtetra
.655 .76 .927 r
.50505 .45256 .51089 .45866 .52155 .45524 .51573 .44912 Mtetra
.672 .765 .921 r
.51573 .44912 .52155 .45524 .53224 .45138 .52645 .44522 Mtetra
.687 .769 .914 r
.52645 .44522 .53224 .45138 .54298 .44709 .53721 .44089 Mtetra
.7 .772 .908 r
.53721 .44089 .54298 .44709 .55374 .44241 .54801 .43615 Mtetra
.71 .774 .902 r
.54801 .43615 .55374 .44241 .56453 .4374 .55883 .43107 Mtetra
.718 .775 .898 r
.55883 .43107 .56453 .4374 .57536 .43212 .56969 .42573 Mtetra
.723 .775 .894 r
.56969 .42573 .57536 .43212 .58621 .42665 .58057 .42019 Mtetra
.725 .774 .892 r
.58057 .42019 .58621 .42665 .59708 .4211 .59148 .41456 Mtetra
.724 .773 .891 r
.59148 .41456 .59708 .4211 .60799 .41553 .60242 .40892 Mtetra
.721 .77 .892 r
.60242 .40892 .60799 .41553 .61893 .41006 .61339 .40337 Mtetra
.715 .767 .893 r
.61339 .40337 .61893 .41006 .62991 .40476 .62439 .39801 Mtetra
.707 .763 .896 r
.62439 .39801 .62991 .40476 .64092 .39972 .63544 .3929 Mtetra
.696 .759 .9 r
.63544 .3929 .64092 .39972 .65199 .39499 .64653 .38812 Mtetra
.683 .754 .905 r
.64653 .38812 .65199 .39499 .6631 .39063 .65768 .38372 Mtetra
.669 .748 .91 r
.65768 .38372 .6631 .39063 .67428 .38668 .66888 .37973 Mtetra
.653 .742 .915 r
.66888 .37973 .67428 .38668 .68552 .38315 .68015 .37617 Mtetra
.636 .735 .92 r
.68015 .37617 .68552 .38315 .69682 .38003 .69149 .37304 Mtetra
.619 .729 .925 r
.69149 .37304 .69682 .38003 .7082 .37731 .7029 .37032 Mtetra
.604 .723 .929 r
.7029 .37032 .7082 .37731 .71966 .37494 .71438 .36795 Mtetra
.59 .718 .932 r
.71438 .36795 .71966 .37494 .73119 .37286 .72595 .36588 Mtetra
.579 .714 .935 r
.72595 .36588 .73119 .37286 .74279 .37101 .73758 .36405 Mtetra
.572 .712 .937 r
.73758 .36405 .74279 .37101 .75446 .36929 .74929 .36235 Mtetra
.569 .712 .939 r
.74929 .36235 .75446 .36929 .76621 .36763 .76106 .36071 Mtetra
.57 .714 .94 r
.76106 .36071 .76621 .36763 .77801 .36592 .7729 .35902 Mtetra
.575 .719 .94 r
.7729 .35902 .77801 .36592 .78986 .36407 .78479 .35719 Mtetra
.585 .725 .94 r
.78479 .35719 .78986 .36407 .80176 .362 .79672 .35514 Mtetra
.597 .732 .938 r
.79672 .35514 .80176 .362 .81369 .35963 .80869 .35277 Mtetra
.612 .74 .936 r
.80869 .35277 .81369 .35963 .82565 .35688 .82068 .35002 Mtetra
.629 .748 .933 r
.82068 .35002 .82565 .35688 .83762 .35372 .83269 .34684 Mtetra
.646 .756 .929 r
.83269 .34684 .83762 .35372 .84961 .35011 .84471 .34321 Mtetra
.664 .766 .926 r
.20578 .5415 .21238 .54688 .22197 .54358 .21539 .53818 Mtetra
.682 .769 .917 r
.21539 .53818 .22197 .54358 .23163 .53985 .22508 .5344 Mtetra
.697 .771 .909 r
.22508 .5344 .23163 .53985 .24136 .5357 .23483 .5302 Mtetra
.709 .772 .902 r
.23483 .5302 .24136 .5357 .25114 .5312 .24464 .52562 Mtetra
.718 .772 .895 r
.24464 .52562 .25114 .5312 .26098 .5264 .25451 .52074 Mtetra
.724 .771 .89 r
.25451 .52074 .26098 .5264 .27086 .52137 .26442 .51562 Mtetra
.727 .77 .886 r
.26442 .51562 .27086 .52137 .28077 .5162 .27437 .51036 Mtetra
.728 .767 .884 r
.27437 .51036 .28077 .5162 .29071 .51099 .28434 .50506 Mtetra
.726 .765 .884 r
.28434 .50506 .29071 .51099 .30067 .50582 .29433 .4998 Mtetra
.721 .762 .885 r
.29433 .4998 .30067 .50582 .31065 .50079 .30434 .49467 Mtetra
.714 .759 .888 r
.30434 .49467 .31065 .50079 .32064 .49597 .31436 .48978 Mtetra
.704 .755 .892 r
.31436 .48978 .32064 .49597 .33064 .49144 .32438 .48518 Mtetra
.692 .751 .897 r
.32438 .48518 .33064 .49144 .34065 .48726 .33442 .48094 Mtetra
.677 .746 .903 r
.33442 .48094 .34065 .48726 .35067 .48347 .34446 .47711 Mtetra
.661 .741 .909 r
.34446 .47711 .35067 .48347 .36071 .48009 .35452 .47371 Mtetra
.643 .736 .916 r
.35452 .47371 .36071 .48009 .37076 .47714 .36459 .47075 Mtetra
.625 .73 .923 r
.36459 .47075 .37076 .47714 .38083 .4746 .37468 .4682 Mtetra
.606 .724 .929 r
.37468 .4682 .38083 .4746 .39093 .47243 .3848 .46605 Mtetra
.589 .72 .934 r
.3848 .46605 .39093 .47243 .40106 .47059 .39495 .46424 Mtetra
.574 .716 .939 r
.39495 .46424 .40106 .47059 .41123 .46901 .40514 .4627 Mtetra
.562 .713 .942 r
.40514 .4627 .41123 .46901 .42144 .46761 .41537 .46134 Mtetra
.555 .713 .945 r
.41537 .46134 .42144 .46761 .4317 .46631 .42565 .46009 Mtetra
.554 .715 .947 r
.42565 .46009 .4317 .46631 .44202 .46502 .43599 .45885 Mtetra
.558 .719 .948 r
.43599 .45885 .44202 .46502 .45239 .46364 .44637 .45751 Mtetra
.566 .725 .948 r
.44637 .45751 .45239 .46364 .46281 .46208 .45682 .45599 Mtetra
.58 .732 .947 r
.45682 .45599 .46281 .46208 .47329 .46025 .46732 .4542 Mtetra
.597 .74 .945 r
.46732 .4542 .47329 .46025 .48382 .4581 .47788 .45206 Mtetra
.615 .749 .941 r
.47788 .45206 .48382 .4581 .49441 .45554 .48849 .44952 Mtetra
.635 .757 .936 r
.48849 .44952 .49441 .45554 .50505 .45256 .49916 .44652 Mtetra
.654 .764 .93 r
.49916 .44652 .50505 .45256 .51573 .44912 .50987 .44306 Mtetra
.672 .769 .923 r
.50987 .44306 .51573 .44912 .52645 .44522 .52062 .43912 Mtetra
.688 .773 .916 r
.52062 .43912 .52645 .44522 .53721 .44089 .53141 .43473 Mtetra
.702 .776 .909 r
.53141 .43473 .53721 .44089 .54801 .43615 .54224 .42993 Mtetra
.712 .778 .903 r
.54224 .42993 .54801 .43615 .55883 .43107 .55309 .42477 Mtetra
.72 .778 .898 r
.55309 .42477 .55883 .43107 .56969 .42573 .56398 .41933 Mtetra
.725 .777 .894 r
.56398 .41933 .56969 .42573 .58057 .42019 .57489 .4137 Mtetra
.727 .776 .891 r
.57489 .4137 .58057 .42019 .59148 .41456 .58583 .40796 Mtetra
.726 .773 .89 r
.58583 .40796 .59148 .41456 .60242 .40892 .5968 .40223 Mtetra
.723 .77 .89 r
.5968 .40223 .60242 .40892 .61339 .40337 .6078 .39659 Mtetra
.717 .766 .891 r
.6078 .39659 .61339 .40337 .62439 .39801 .61884 .39113 Mtetra
.708 .762 .894 r
.61884 .39113 .62439 .39801 .63544 .3929 .62991 .38594 Mtetra
.697 .756 .898 r
.62991 .38594 .63544 .3929 .64653 .38812 .64104 .3811 Mtetra
.684 .751 .902 r
.64104 .3811 .64653 .38812 .65768 .38372 .65221 .37664 Mtetra
.669 .745 .907 r
.65221 .37664 .65768 .38372 .66888 .37973 .66345 .37262 Mtetra
.653 .738 .912 r
.66345 .37262 .66888 .37973 .68015 .37617 .67474 .36904 Mtetra
.636 .731 .917 r
.67474 .36904 .68015 .37617 .69149 .37304 .68611 .3659 Mtetra
.619 .725 .922 r
.68611 .3659 .69149 .37304 .7029 .37032 .69755 .36318 Mtetra
.603 .719 .927 r
.69755 .36318 .7029 .37032 .71438 .36795 .70907 .36083 Mtetra
.588 .714 .931 r
.70907 .36083 .71438 .36795 .72595 .36588 .72066 .35879 Mtetra
.577 .711 .934 r
.72066 .35879 .72595 .36588 .73758 .36405 .73233 .357 Mtetra
.569 .71 .937 r
.73233 .357 .73758 .36405 .74929 .36235 .74407 .35535 Mtetra
.566 .71 .939 r
.74407 .35535 .74929 .36235 .76106 .36071 .75588 .35375 Mtetra
.567 .713 .94 r
.75588 .35375 .76106 .36071 .7729 .35902 .76775 .3521 Mtetra
.572 .718 .941 r
.76775 .3521 .7729 .35902 .78479 .35719 .77968 .35032 Mtetra
.581 .725 .941 r
.77968 .35032 .78479 .35719 .79672 .35514 .79165 .34829 Mtetra
.595 .733 .941 r
.79165 .34829 .79672 .35514 .80869 .35277 .80365 .34594 Mtetra
.61 .742 .939 r
.80365 .34594 .80869 .35277 .82068 .35002 .81569 .34321 Mtetra
.628 .751 .936 r
.81569 .34321 .82068 .35002 .83269 .34684 .82774 .34003 Mtetra
.646 .76 .932 r
.82774 .34003 .83269 .34684 .84471 .34321 .83979 .33637 Mtetra
.664 .77 .928 r
.19912 .5362 .20578 .5415 .21539 .53818 .20875 .53284 Mtetra
.683 .773 .919 r
.20875 .53284 .21539 .53818 .22508 .5344 .21847 .52901 Mtetra
.699 .775 .911 r
.21847 .52901 .22508 .5344 .23483 .5302 .22825 .52474 Mtetra
.711 .776 .903 r
.22825 .52474 .23483 .5302 .24464 .52562 .23809 .52008 Mtetra
.721 .775 .896 r
.23809 .52008 .24464 .52562 .25451 .52074 .24799 .51509 Mtetra
.727 .773 .89 r
.24799 .51509 .25451 .52074 .26442 .51562 .25794 .50987 Mtetra
.73 .771 .886 r
.25794 .50987 .26442 .51562 .27437 .51036 .26791 .50449 Mtetra
.73 .768 .883 r
.26791 .50449 .27437 .51036 .28434 .50506 .27792 .49907 Mtetra
.728 .765 .882 r
.27792 .49907 .28434 .50506 .29433 .4998 .28795 .49369 Mtetra
.723 .761 .883 r
.28795 .49369 .29433 .4998 .30434 .49467 .29799 .48846 Mtetra
.715 .757 .885 r
.29799 .48846 .30434 .49467 .31436 .48978 .30803 .48347 Mtetra
.705 .753 .889 r
.30803 .48347 .31436 .48978 .32438 .48518 .31809 .47878 Mtetra
.693 .748 .894 r
.31809 .47878 .32438 .48518 .33442 .48094 .32815 .47448 Mtetra
.678 .743 .9 r
.32815 .47448 .33442 .48094 .34446 .47711 .33822 .4706 Mtetra
.661 .737 .906 r
.33822 .4706 .34446 .47711 .35452 .47371 .3483 .46717 Mtetra
.643 .732 .913 r
.3483 .46717 .35452 .47371 .36459 .47075 .35839 .4642 Mtetra
.624 .726 .92 r
.35839 .4642 .36459 .47075 .37468 .4682 .3685 .46167 Mtetra
.604 .72 .927 r
.3685 .46167 .37468 .4682 .3848 .46605 .37864 .45954 Mtetra
.586 .716 .933 r
.37864 .45954 .3848 .46605 .39495 .46424 .38881 .45778 Mtetra
.57 .712 .938 r
.38881 .45778 .39495 .46424 .40514 .4627 .39901 .45629 Mtetra
.558 .71 .942 r
.39901 .45629 .40514 .4627 .41537 .46134 .40926 .45501 Mtetra
.551 .71 .945 r
.40926 .45501 .41537 .46134 .42565 .46009 .41956 .45383 Mtetra
.548 .713 .948 r
.41956 .45383 .42565 .46009 .43599 .45885 .42991 .45266 Mtetra
.552 .717 .95 r
.42991 .45266 .43599 .45885 .44637 .45751 .44032 .45139 Mtetra
.561 .724 .95 r
.44032 .45139 .44637 .45751 .45682 .45599 .45078 .44993 Mtetra
.575 .733 .95 r
.45078 .44993 .45682 .45599 .46732 .4542 .46131 .44819 Mtetra
.593 .742 .947 r
.46131 .44819 .46732 .4542 .47788 .45206 .47189 .44609 Mtetra
.613 .752 .944 r
.47189 .44609 .47788 .45206 .48849 .44952 .48253 .44356 Mtetra
.634 .76 .939 r
.48253 .44356 .48849 .44952 .49916 .44652 .49322 .44056 Mtetra
.654 .768 .933 r
.49322 .44056 .49916 .44652 .50987 .44306 .50396 .43707 Mtetra
.673 .773 .926 r
.50396 .43707 .50987 .44306 .52062 .43912 .51474 .43309 Mtetra
.69 .778 .918 r
.51474 .43309 .52062 .43912 .53141 .43473 .52556 .42863 Mtetra
.704 .78 .911 r
.52556 .42863 .53141 .43473 .54224 .42993 .53642 .42374 Mtetra
.715 .781 .904 r
.53642 .42374 .54224 .42993 .55309 .42477 .54731 .41848 Mtetra
.723 .781 .898 r
.54731 .41848 .55309 .42477 .56398 .41933 .55823 .41293 Mtetra
.728 .779 .894 r
.55823 .41293 .56398 .41933 .57489 .4137 .56917 .40718 Mtetra
.73 .777 .89 r
.56917 .40718 .57489 .4137 .58583 .40796 .58014 .40132 Mtetra
.729 .774 .889 r
.58014 .40132 .58583 .40796 .5968 .40223 .59114 .39546 Mtetra
.725 .77 .888 r
.59114 .39546 .5968 .40223 .6078 .39659 .60217 .3897 Mtetra
.719 .765 .889 r
.60217 .3897 .6078 .39659 .61884 .39113 .61324 .38414 Mtetra
.71 .76 .892 r
.61324 .38414 .61884 .39113 .62991 .38594 .62434 .37885 Mtetra
.698 .754 .895 r
.62434 .37885 .62991 .38594 .64104 .3811 .6355 .37392 Mtetra
.685 .748 .899 r
.6355 .37392 .64104 .3811 .65221 .37664 .6467 .36941 Mtetra
.669 .741 .904 r
.6467 .36941 .65221 .37664 .66345 .37262 .65796 .36534 Mtetra
.652 .734 .909 r
.65796 .36534 .66345 .37262 .67474 .36904 .66929 .36174 Mtetra
.635 .727 .915 r
.66929 .36174 .67474 .36904 .68611 .3659 .68069 .35859 Mtetra
.617 .721 .92 r
.68069 .35859 .68611 .3659 .69755 .36318 .69216 .35589 Mtetra
.601 .715 .925 r
.69216 .35589 .69755 .36318 .70907 .36083 .70371 .35358 Mtetra
.586 .71 .929 r
.70371 .35358 .70907 .36083 .72066 .35879 .71533 .35159 Mtetra
.574 .707 .933 r
.71533 .35159 .72066 .35879 .73233 .357 .72704 .34985 Mtetra
.565 .706 .936 r
.72704 .34985 .73233 .357 .74407 .35535 .73881 .34827 Mtetra
.561 .708 .939 r
.73881 .34827 .74407 .35535 .75588 .35375 .75066 .34674 Mtetra
.562 .711 .941 r
.75066 .34674 .75588 .35375 .76775 .3521 .76257 .34517 Mtetra
.567 .717 .943 r
.76257 .34517 .76775 .3521 .77968 .35032 .77453 .34344 Mtetra
.577 .725 .944 r
.77453 .34344 .77968 .35032 .79165 .34829 .78654 .34147 Mtetra
.591 .734 .943 r
.78654 .34147 .79165 .34829 .80365 .34594 .79859 .33917 Mtetra
.607 .744 .942 r
.79859 .33917 .80365 .34594 .81569 .34321 .81066 .33645 Mtetra
.626 .754 .939 r
.81066 .33645 .81569 .34321 .82774 .34003 .82275 .33327 Mtetra
.645 .763 .935 r
.82275 .33327 .82774 .34003 .83979 .33637 .83485 .32959 Mtetra
.665 .774 .931 r
.1924 .53098 .19912 .5362 .20875 .53284 .20206 .52758 Mtetra
.685 .778 .922 r
.20206 .52758 .20875 .53284 .21847 .52901 .2118 .52369 Mtetra
.701 .779 .912 r
.2118 .52369 .21847 .52901 .22825 .52474 .22161 .51934 Mtetra
.714 .779 .903 r
.22161 .51934 .22825 .52474 .23809 .52008 .23149 .51457 Mtetra
.724 .778 .895 r
.23149 .51457 .23809 .52008 .24799 .51509 .24142 .50947 Mtetra
.73 .776 .889 r
.24142 .50947 .24799 .51509 .25794 .50987 .2514 .50411 Mtetra
.733 .773 .884 r
.2514 .50411 .25794 .50987 .26791 .50449 .26142 .49859 Mtetra
.734 .769 .881 r
.26142 .49859 .26791 .50449 .27792 .49907 .27146 .49302 Mtetra
.731 .765 .88 r
.27146 .49302 .27792 .49907 .28795 .49369 .28152 .4875 Mtetra
.726 .76 .88 r
.28152 .4875 .28795 .49369 .29799 .48846 .29159 .48214 Mtetra
.718 .756 .882 r
.29159 .48214 .29799 .48846 .30803 .48347 .30167 .47703 Mtetra
.707 .751 .886 r
.30167 .47703 .30803 .48347 .31809 .47878 .31176 .47225 Mtetra
.694 .745 .891 r
.31176 .47225 .31809 .47878 .32815 .47448 .32185 .46786 Mtetra
.679 .74 .897 r
.32185 .46786 .32815 .47448 .33822 .4706 .33194 .46393 Mtetra
.661 .734 .903 r
.33194 .46393 .33822 .4706 .3483 .46717 .34204 .46047 Mtetra
.642 .728 .911 r
.34204 .46047 .3483 .46717 .35839 .4642 .35216 .45749 Mtetra
.622 .722 .918 r
.35216 .45749 .35839 .4642 .3685 .46167 .36229 .45498 Mtetra
.602 .716 .925 r
.36229 .45498 .3685 .46167 .37864 .45954 .37244 .4529 Mtetra
.583 .711 .931 r
.37244 .4529 .37864 .45954 .38881 .45778 .38262 .4512 Mtetra
.566 .707 .937 r
.38262 .4512 .38881 .45778 .39901 .45629 .39284 .44979 Mtetra
.553 .706 .942 r
.39284 .44979 .39901 .45629 .40926 .45501 .40311 .4486 Mtetra
.544 .706 .946 r
.40311 .4486 .40926 .45501 .41956 .45383 .41342 .44752 Mtetra
.542 .71 .949 r
.41342 .44752 .41956 .45383 .42991 .45266 .42379 .44644 Mtetra
.545 .715 .951 r
.42379 .44644 .42991 .45266 .44032 .45139 .43422 .44527 Mtetra
.555 .724 .953 r
.43422 .44527 .44032 .45139 .45078 .44993 .4447 .4439 Mtetra
.569 .733 .952 r
.4447 .4439 .45078 .44993 .46131 .44819 .45525 .44222 Mtetra
.588 .744 .951 r
.45525 .44222 .46131 .44819 .47189 .44609 .46586 .44017 Mtetra
.61 .754 .947 r
.46586 .44017 .47189 .44609 .48253 .44356 .47652 .43767 Mtetra
.632 .764 .942 r
.47652 .43767 .48253 .44356 .49322 .44056 .48724 .43467 Mtetra
.654 .772 .936 r
.48724 .43467 .49322 .44056 .50396 .43707 .49801 .43116 Mtetra
.674 .778 .928 r
.49801 .43116 .50396 .43707 .51474 .43309 .50882 .42712 Mtetra
.692 .782 .92 r
.50882 .42712 .51474 .43309 .52556 .42863 .51967 .42259 Mtetra
.707 .784 .912 r
.51967 .42259 .52556 .42863 .53642 .42374 .53056 .4176 Mtetra
.718 .785 .905 r
.53056 .4176 .53642 .42374 .54731 .41848 .54148 .41222 Mtetra
.726 .784 .898 r
.54148 .41222 .54731 .41848 .55823 .41293 .55243 .40653 Mtetra
.731 .782 .893 r
.55243 .40653 .55823 .41293 .56917 .40718 .56341 .40064 Mtetra
.733 .779 .889 r
.56341 .40064 .56917 .40718 .58014 .40132 .57441 .39463 Mtetra
.732 .774 .887 r
.57441 .39463 .58014 .40132 .59114 .39546 .58544 .38862 Mtetra
.728 .77 .886 r
.58544 .38862 .59114 .39546 .60217 .3897 .5965 .38271 Mtetra
.721 .764 .887 r
.5965 .38271 .60217 .3897 .61324 .38414 .6076 .37702 Mtetra
.712 .758 .889 r
.6076 .37702 .61324 .38414 .62434 .37885 .61873 .37162 Mtetra
.7 .752 .892 r
.61873 .37162 .62434 .37885 .6355 .37392 .62991 .36659 Mtetra
.686 .745 .896 r
.62991 .36659 .6355 .37392 .6467 .36941 .64115 .362 Mtetra
.67 .738 .901 r
.64115 .362 .6467 .36941 .65796 .36534 .65244 .35788 Mtetra
.652 .73 .907 r
.65244 .35788 .65796 .36534 .66929 .36174 .66379 .35426 Mtetra
.634 .723 .912 r
.66379 .35426 .66929 .36174 .68069 .35859 .67522 .35112 Mtetra
.616 .716 .918 r
.67522 .35112 .68069 .35859 .69216 .35589 .68672 .34845 Mtetra
.598 .711 .923 r
.68672 .34845 .69216 .35589 .70371 .35358 .6983 .34619 Mtetra
.582 .706 .928 r
.6983 .34619 .70371 .35358 .71533 .35159 .70996 .34427 Mtetra
.569 .703 .932 r
.70996 .34427 .71533 .35159 .72704 .34985 .7217 .34261 Mtetra
.56 .703 .936 r
.7217 .34261 .72704 .34985 .73881 .34827 .73352 .34112 Mtetra
.556 .705 .939 r
.73352 .34112 .73881 .34827 .75066 .34674 .7454 .33969 Mtetra
.556 .709 .942 r
.7454 .33969 .75066 .34674 .76257 .34517 .75735 .33822 Mtetra
.562 .716 .944 r
.75735 .33822 .76257 .34517 .77453 .34344 .76935 .33658 Mtetra
.572 .725 .946 r
.76935 .33658 .77453 .34344 .78654 .34147 .78141 .33468 Mtetra
.586 .735 .946 r
.78141 .33468 .78654 .34147 .79859 .33917 .79349 .33243 Mtetra
.604 .746 .945 r
.79349 .33243 .79859 .33917 .81066 .33645 .80561 .32975 Mtetra
.623 .757 .942 r
.80561 .32975 .81066 .33645 .82275 .33327 .81773 .32658 Mtetra
.644 .767 .938 r
.81773 .32658 .82275 .33327 .83485 .32959 .82987 .32289 Mtetra
.665 .779 .934 r
.18562 .52584 .1924 .53098 .20206 .52758 .19531 .52241 Mtetra
.686 .782 .924 r
.19531 .52241 .20206 .52758 .2118 .52369 .20507 .51845 Mtetra
.704 .784 .913 r
.20507 .51845 .2118 .52369 .22161 .51934 .21492 .514 Mtetra
.718 .783 .904 r
.21492 .514 .22161 .51934 .23149 .51457 .22483 .50911 Mtetra
.728 .781 .895 r
.22483 .50911 .23149 .51457 .24142 .50947 .2348 .50386 Mtetra
.734 .778 .888 r
.2348 .50386 .24142 .50947 .2514 .50411 .24482 .49834 Mtetra
.737 .774 .883 r
.24482 .49834 .2514 .50411 .26142 .49859 .25488 .49266 Mtetra
.737 .77 .879 r
.25488 .49266 .26142 .49859 .27146 .49302 .26496 .48692 Mtetra
.735 .765 .877 r
.26496 .48692 .27146 .49302 .28152 .4875 .27505 .48123 Mtetra
.729 .76 .877 r
.27505 .48123 .28152 .4875 .29159 .48214 .28516 .47571 Mtetra
.72 .754 .879 r
.28516 .47571 .29159 .48214 .30167 .47703 .29528 .47046 Mtetra
.709 .748 .882 r
.29528 .47046 .30167 .47703 .31176 .47225 .30539 .46556 Mtetra
.696 .742 .887 r
.30539 .46556 .31176 .47225 .32185 .46786 .31551 .46109 Mtetra
.68 .736 .893 r
.31551 .46109 .32185 .46786 .33194 .46393 .32563 .45709 Mtetra
.661 .73 .9 r
.32563 .45709 .33194 .46393 .34204 .46047 .33575 .4536 Mtetra
.641 .723 .908 r
.33575 .4536 .34204 .46047 .35216 .45749 .34588 .45062 Mtetra
.62 .717 .915 r
.34588 .45062 .35216 .45749 .36229 .45498 .35603 .44814 Mtetra
.599 .711 .923 r
.35603 .44814 .36229 .45498 .37244 .4529 .3662 .44612 Mtetra
.578 .706 .93 r
.3662 .44612 .37244 .4529 .38262 .4512 .3764 .44449 Mtetra
.56 .703 .936 r
.3764 .44449 .38262 .4512 .39284 .44979 .38663 .44319 Mtetra
.546 .701 .942 r
.38663 .44319 .39284 .44979 .40311 .4486 .39691 .44211 Mtetra
.536 .702 .946 r
.39691 .44211 .40311 .4486 .41342 .44752 .40724 .44115 Mtetra
.533 .706 .95 r
.40724 .44115 .41342 .44752 .42379 .44644 .41763 .44021 Mtetra
.536 .713 .953 r
.41763 .44021 .42379 .44644 .43422 .44527 .42807 .43915 Mtetra
.546 .722 .955 r
.42807 .43915 .43422 .44527 .4447 .4439 .43858 .43789 Mtetra
.562 .733 .955 r
.43858 .43789 .4447 .4439 .45525 .44222 .44914 .4363 Mtetra
.582 .745 .954 r
.44914 .4363 .45525 .44222 .46586 .44017 .45977 .43432 Mtetra
.605 .757 .951 r
.45977 .43432 .46586 .44017 .47652 .43767 .47046 .43185 Mtetra
.63 .767 .946 r
.47046 .43185 .47652 .43767 .48724 .43467 .48121 .42886 Mtetra
.653 .776 .939 r
.48121 .42886 .48724 .43467 .49801 .43116 .49201 .42532 Mtetra
.675 .783 .931 r
.49201 .42532 .49801 .43116 .50882 .42712 .50285 .42123 Mtetra
.694 .787 .922 r
.50285 .42123 .50882 .42712 .51967 .42259 .51374 .41661 Mtetra
.71 .789 .913 r
.51374 .41661 .51967 .42259 .53056 .4176 .52466 .4115 Mtetra
.722 .789 .905 r
.52466 .4115 .53056 .4176 .54148 .41222 .53561 .40598 Mtetra
.731 .787 .898 r
.53561 .40598 .54148 .41222 .55243 .40653 .54659 .40014 Mtetra
.736 .784 .892 r
.54659 .40014 .55243 .40653 .56341 .40064 .5576 .39407 Mtetra
.737 .78 .887 r
.5576 .39407 .56341 .40064 .57441 .39463 .56864 .38788 Mtetra
.736 .775 .885 r
.56864 .38788 .57441 .39463 .58544 .38862 .5797 .38169 Mtetra
.732 .77 .883 r
.5797 .38169 .58544 .38862 .5965 .38271 .59079 .37562 Mtetra
.724 .763 .884 r
.59079 .37562 .5965 .38271 .6076 .37702 .60191 .36977 Mtetra
.714 .757 .886 r
.60191 .36977 .6076 .37702 .61873 .37162 .61308 .36423 Mtetra
.702 .749 .889 r
.61308 .36423 .61873 .37162 .62991 .36659 .62429 .35909 Mtetra
.687 .742 .893 r
.62429 .35909 .62991 .36659 .64115 .362 .63555 .35442 Mtetra
.67 .734 .898 r
.63555 .35442 .64115 .362 .65244 .35788 .64687 .35025 Mtetra
.652 .726 .903 r
.64687 .35025 .65244 .35788 .66379 .35426 .65825 .34661 Mtetra
.633 .719 .909 r
.65825 .34661 .66379 .35426 .67522 .35112 .66971 .34348 Mtetra
.613 .712 .915 r
.66971 .34348 .67522 .35112 .68672 .34845 .68124 .34085 Mtetra
.595 .706 .921 r
.68124 .34085 .68672 .34845 .6983 .34619 .69286 .33865 Mtetra
.578 .701 .926 r
.69286 .33865 .6983 .34619 .70996 .34427 .70455 .33683 Mtetra
.564 .698 .931 r
.70455 .33683 .70996 .34427 .7217 .34261 .71632 .33528 Mtetra
.554 .698 .936 r
.71632 .33528 .7217 .34261 .73352 .34112 .72818 .33391 Mtetra
.549 .701 .94 r
.72818 .33391 .73352 .34112 .7454 .33969 .7401 .3326 Mtetra
.549 .706 .943 r
.7401 .3326 .7454 .33969 .75735 .33822 .75209 .33125 Mtetra
.555 .714 .946 r
.75209 .33125 .75735 .33822 .76935 .33658 .76414 .32972 Mtetra
.566 .724 .948 r
.76414 .32972 .76935 .33658 .78141 .33468 .77623 .32792 Mtetra
.581 .736 .949 r
.77623 .32792 .78141 .33468 .79349 .33243 .78836 .32575 Mtetra
.6 .748 .948 r
.78836 .32575 .79349 .33243 .80561 .32975 .80052 .32312 Mtetra
.621 .76 .945 r
.80052 .32312 .80561 .32975 .81773 .32658 .81269 .31997 Mtetra
.642 .771 .941 r
.81269 .31997 .81773 .32658 .82987 .32289 .82487 .31626 Mtetra
.666 .784 .937 r
.17878 .5208 .18562 .52584 .19531 .52241 .18849 .51733 Mtetra
.689 .787 .926 r
.18849 .51733 .19531 .52241 .20507 .51845 .19829 .51329 Mtetra
.707 .788 .914 r
.19829 .51329 .20507 .51845 .21492 .514 .20817 .50873 Mtetra
.722 .787 .904 r
.20817 .50873 .21492 .514 .22483 .50911 .21812 .5037 Mtetra
.732 .785 .894 r
.21812 .5037 .22483 .50911 .2348 .50386 .22813 .49828 Mtetra
.739 .781 .886 r
.22813 .49828 .2348 .50386 .24482 .49834 .23819 .49257 Mtetra
.742 .776 .88 r
.23819 .49257 .24482 .49834 .25488 .49266 .24829 .48669 Mtetra
.742 .771 .876 r
.24829 .48669 .25488 .49266 .26496 .48692 .25841 .48075 Mtetra
.739 .765 .874 r
.25841 .48075 .26496 .48692 .27505 .48123 .26855 .47487 Mtetra
.733 .759 .874 r
.26855 .47487 .27505 .48123 .28516 .47571 .27869 .46917 Mtetra
.724 .753 .875 r
.27869 .46917 .28516 .47571 .29528 .47046 .28884 .46376 Mtetra
.712 .746 .879 r
.28884 .46376 .29528 .47046 .30539 .46556 .29899 .45872 Mtetra
.698 .74 .884 r
.29899 .45872 .30539 .46556 .31551 .46109 .30914 .45414 Mtetra
.681 .733 .89 r
.30914 .45414 .31551 .46109 .32563 .45709 .31928 .45008 Mtetra
.661 .726 .897 r
.31928 .45008 .32563 .45709 .33575 .4536 .32943 .44655 Mtetra
.64 .719 .905 r
.32943 .44655 .33575 .4536 .34588 .45062 .33958 .44358 Mtetra
.618 .712 .913 r
.33958 .44358 .34588 .45062 .35603 .44814 .34974 .44113 Mtetra
.595 .706 .921 r
.34974 .44113 .35603 .44814 .3662 .44612 .35992 .43918 Mtetra
.573 .7 .928 r
.35992 .43918 .3662 .44612 .3764 .44449 .37014 .43766 Mtetra
.553 .697 .935 r
.37014 .43766 .3764 .44449 .38663 .44319 .38038 .43648 Mtetra
.537 .695 .941 r
.38038 .43648 .38663 .44319 .39691 .44211 .39067 .43555 Mtetra
.527 .697 .947 r
.39067 .43555 .39691 .44211 .40724 .44115 .40102 .43474 Mtetra
.523 .701 .951 r
.40102 .43474 .40724 .44115 .41763 .44021 .41141 .43395 Mtetra
.526 .709 .955 r
.41141 .43395 .41763 .44021 .42807 .43915 .42187 .43305 Mtetra
.536 .72 .958 r
.42187 .43305 .42807 .43915 .43858 .43789 .4324 .43191 Mtetra
.553 .733 .959 r
.4324 .43191 .43858 .43789 .44914 .4363 .44299 .43044 Mtetra
.575 .746 .958 r
.44299 .43044 .44914 .4363 .45977 .43432 .45364 .42854 Mtetra
.601 .759 .955 r
.45364 .42854 .45977 .43432 .47046 .43185 .46436 .42612 Mtetra
.627 .771 .949 r
.46436 .42612 .47046 .43185 .48121 .42886 .47513 .42315 Mtetra
.653 .781 .942 r
.47513 .42315 .48121 .42886 .49201 .42532 .48596 .41958 Mtetra
.676 .788 .933 r
.48596 .41958 .49201 .42532 .50285 .42123 .49684 .41543 Mtetra
.697 .792 .924 r
.49684 .41543 .50285 .42123 .51374 .41661 .50775 .4107 Mtetra
.714 .794 .914 r
.50775 .4107 .51374 .41661 .52466 .4115 .51871 .40546 Mtetra
.726 .793 .905 r
.51871 .40546 .52466 .4115 .53561 .40598 .5297 .39978 Mtetra
.735 .791 .897 r
.5297 .39978 .53561 .40598 .54659 .40014 .54071 .39375 Mtetra
.741 .787 .89 r
.54071 .39375 .54659 .40014 .5576 .39407 .55176 .38747 Mtetra
.742 .782 .885 r
.55176 .38747 .5576 .39407 .56864 .38788 .56282 .38108 Mtetra
.741 .776 .882 r
.56282 .38108 .56864 .38788 .5797 .38169 .57391 .37469 Mtetra
.736 .77 .88 r
.57391 .37469 .5797 .38169 .59079 .37562 .58504 .36841 Mtetra
.728 .763 .88 r
.58504 .36841 .59079 .37562 .60191 .36977 .59619 .36238 Mtetra
.717 .755 .882 r
.59619 .36238 .60191 .36977 .61308 .36423 .60738 .35669 Mtetra
.704 .747 .885 r
.60738 .35669 .61308 .36423 .62429 .35909 .61862 .35142 Mtetra
.688 .739 .889 r
.61862 .35142 .62429 .35909 .63555 .35442 .62991 .34666 Mtetra
.671 .73 .895 r
.62991 .34666 .63555 .35442 .64687 .35025 .64125 .34243 Mtetra
.651 .722 .9 r
.64125 .34243 .64687 .35025 .65825 .34661 .65267 .33876 Mtetra
.631 .714 .906 r
.65267 .33876 .65825 .34661 .66971 .34348 .66415 .33566 Mtetra
.61 .706 .913 r
.66415 .33566 .66971 .34348 .68124 .34085 .67572 .33308 Mtetra
.591 .7 .919 r
.67572 .33308 .68124 .34085 .69286 .33865 .68736 .33097 Mtetra
.573 .696 .925 r
.68736 .33097 .69286 .33865 .70455 .33683 .69909 .32925 Mtetra
.558 .693 .93 r
.69909 .32925 .70455 .33683 .71632 .33528 .7109 .32784 Mtetra
.547 .693 .936 r
.7109 .32784 .71632 .33528 .72818 .33391 .7228 .32662 Mtetra
.541 .696 .94 r
.7228 .32662 .72818 .33391 .7401 .3326 .73476 .32547 Mtetra
.54 .702 .945 r
.73476 .32547 .7401 .3326 .75209 .33125 .7468 .32426 Mtetra
.546 .711 .948 r
.7468 .32426 .75209 .33125 .76414 .32972 .75889 .32288 Mtetra
.558 .723 .951 r
.75889 .32288 .76414 .32972 .77623 .32792 .77103 .3212 Mtetra
.574 .736 .952 r
.77103 .3212 .77623 .32792 .78836 .32575 .7832 .31912 Mtetra
.594 .75 .951 r
.7832 .31912 .78836 .32575 .80052 .32312 .7954 .31656 Mtetra
.617 .763 .949 r
.7954 .31656 .80052 .32312 .81269 .31997 .80762 .31344 Mtetra
.641 .775 .945 r
.80762 .31344 .81269 .31997 .82487 .31626 .81984 .30972 Mtetra
.666 .789 .94 r
.17187 .51586 .17878 .5208 .18849 .51733 .18161 .51235 Mtetra
.691 .793 .928 r
.18161 .51235 .18849 .51733 .19829 .51329 .19144 .50822 Mtetra
.711 .793 .915 r
.19144 .50822 .19829 .51329 .20817 .50873 .20135 .50353 Mtetra
.727 .792 .904 r
.20135 .50353 .20817 .50873 .21812 .5037 .21135 .49834 Mtetra
.738 .788 .893 r
.21135 .49834 .21812 .5037 .22813 .49828 .2214 .49272 Mtetra
.744 .783 .884 r
.2214 .49272 .22813 .49828 .23819 .49257 .23151 .4868 Mtetra
.747 .778 .878 r
.23151 .4868 .23819 .49257 .24829 .48669 .24165 .48069 Mtetra
.747 .772 .873 r
.24165 .48069 .24829 .48669 .25841 .48075 .25182 .47452 Mtetra
.743 .765 .87 r
.25182 .47452 .25841 .48075 .26855 .47487 .262 .46842 Mtetra
.737 .758 .87 r
.262 .46842 .26855 .47487 .27869 .46917 .27219 .46251 Mtetra
.727 .751 .871 r
.27219 .46251 .27869 .46917 .28884 .46376 .28237 .45691 Mtetra
.715 .744 .875 r
.28237 .45691 .28884 .46376 .29899 .45872 .29256 .45172 Mtetra
.7 .737 .88 r
.29256 .45172 .29899 .45872 .30914 .45414 .30273 .44702 Mtetra
.682 .729 .886 r
.30273 .44702 .30914 .45414 .31928 .45008 .3129 .44287 Mtetra
.662 .722 .893 r
.3129 .44287 .31928 .45008 .32943 .44655 .32307 .43931 Mtetra
.639 .714 .902 r
.32307 .43931 .32943 .44655 .33958 .44358 .33324 .43635 Mtetra
.615 .707 .91 r
.33324 .43635 .33958 .44358 .34974 .44113 .34342 .43395 Mtetra
.59 .7 .919 r
.34342 .43395 .34974 .44113 .35992 .43918 .35361 .43209 Mtetra
.566 .694 .927 r
.35361 .43209 .35992 .43918 .37014 .43766 .36383 .4307 Mtetra
.545 .69 .935 r
.36383 .4307 .37014 .43766 .38038 .43648 .37409 .42967 Mtetra
.527 .689 .941 r
.37409 .42967 .38038 .43648 .39067 .43555 .38439 .4289 Mtetra
.515 .691 .947 r
.38439 .4289 .39067 .43555 .40102 .43474 .39475 .42828 Mtetra
.51 .696 .953 r
.39475 .42828 .40102 .43474 .41141 .43395 .40516 .42767 Mtetra
.513 .705 .957 r
.40516 .42767 .41141 .43395 .42187 .43305 .41563 .42695 Mtetra
.524 .717 .96 r
.41563 .42695 .42187 .43305 .4324 .43191 .42617 .42598 Mtetra
.543 .731 .962 r
.42617 .42598 .4324 .43191 .44299 .43044 .43678 .42464 Mtetra
.567 .747 .962 r
.43678 .42464 .44299 .43044 .45364 .42854 .44746 .42284 Mtetra
.595 .762 .959 r
.44746 .42284 .45364 .42854 .46436 .42612 .4582 .42049 Mtetra
.624 .775 .953 r
.4582 .42049 .46436 .42612 .47513 .42315 .469 .41753 Mtetra
.652 .786 .946 r
.469 .41753 .47513 .42315 .48596 .41958 .47986 .41394 Mtetra
.678 .793 .936 r
.47986 .41394 .48596 .41958 .49684 .41543 .49077 .40971 Mtetra
.7 .798 .926 r
.49077 .40971 .49684 .41543 .50775 .4107 .50172 .40487 Mtetra
.718 .799 .915 r
.50172 .40487 .50775 .4107 .51871 .40546 .51271 .39948 Mtetra
.732 .798 .905 r
.51271 .39948 .51871 .40546 .5297 .39978 .52374 .39361 Mtetra
.741 .795 .896 r
.52374 .39361 .5297 .39978 .54071 .39375 .53479 .38736 Mtetra
.746 .79 .888 r
.53479 .38736 .54071 .39375 .55176 .38747 .54586 .38086 Mtetra
.748 .784 .883 r
.54586 .38086 .55176 .38747 .56282 .38108 .55696 .37422 Mtetra
.746 .778 .879 r
.55696 .37422 .56282 .38108 .57391 .37469 .56809 .36759 Mtetra
.74 .77 .877 r
.56809 .36759 .57391 .37469 .58504 .36841 .57924 .36109 Mtetra
.732 .762 .877 r
.57924 .36109 .58504 .36841 .59619 .36238 .59042 .35485 Mtetra
.721 .754 .878 r
.59042 .35485 .59619 .36238 .60738 .35669 .60164 .34898 Mtetra
.707 .745 .881 r
.60164 .34898 .60738 .35669 .61862 .35142 .6129 .34357 Mtetra
.69 .736 .886 r
.6129 .34357 .61862 .35142 .62991 .34666 .62422 .3387 Mtetra
.671 .727 .891 r
.62422 .3387 .62991 .34666 .64125 .34243 .63559 .33441 Mtetra
.651 .717 .897 r
.63559 .33441 .64125 .34243 .65267 .33876 .64704 .33072 Mtetra
.629 .709 .904 r
.64704 .33072 .65267 .33876 .66415 .33566 .65855 .32764 Mtetra
.607 .701 .91 r
.65855 .32764 .66415 .33566 .67572 .33308 .67015 .32513 Mtetra
.586 .694 .917 r
.67015 .32513 .67572 .33308 .68736 .33097 .68183 .32313 Mtetra
.566 .689 .923 r
.68183 .32313 .68736 .33097 .69909 .32925 .69359 .32155 Mtetra
.55 .687 .929 r
.69359 .32155 .69909 .32925 .7109 .32784 .70544 .3203 Mtetra
.538 .687 .935 r
.70544 .3203 .7109 .32784 .7228 .32662 .71737 .31925 Mtetra
.531 .69 .941 r
.71737 .31925 .7228 .32662 .73476 .32547 .72938 .31829 Mtetra
.53 .697 .946 r
.72938 .31829 .73476 .32547 .7468 .32426 .74146 .31727 Mtetra
.536 .708 .95 r
.74146 .31727 .7468 .32426 .75889 .32288 .7536 .31605 Mtetra
.548 .721 .953 r
.7536 .31605 .75889 .32288 .77103 .3212 .76579 .31452 Mtetra
.566 .736 .955 r
.76579 .31452 .77103 .3212 .7832 .31912 .77801 .31257 Mtetra
.588 .751 .955 r
.77801 .31257 .7832 .31912 .7954 .31656 .79026 .31008 Mtetra
.613 .766 .953 r
.79026 .31008 .7954 .31656 .80762 .31344 .80252 .307 Mtetra
.639 .78 .949 r
.80252 .307 .80762 .31344 .81984 .30972 .81478 .30328 Mtetra
.667 .795 .943 r
.16489 .51104 .17187 .51586 .18161 .51235 .17466 .50748 Mtetra
.694 .798 .93 r
.17466 .50748 .18161 .51235 .19144 .50822 .18452 .50326 Mtetra
.716 .799 .916 r
.18452 .50326 .19144 .50822 .20135 .50353 .19448 .49842 Mtetra
.732 .796 .903 r
.19448 .49842 .20135 .50353 .21135 .49834 .20451 .49304 Mtetra
.744 .792 .892 r
.20451 .49304 .21135 .49834 .2214 .49272 .21462 .4872 Mtetra
.751 .786 .882 r
.21462 .4872 .2214 .49272 .23151 .4868 .22477 .48104 Mtetra
.753 .78 .875 r
.22477 .48104 .23151 .4868 .24165 .48069 .23496 .47467 Mtetra
.753 .773 .869 r
.23496 .47467 .24165 .48069 .25182 .47452 .24518 .46823 Mtetra
.749 .765 .866 r
.24518 .46823 .25182 .47452 .262 .46842 .25541 .46187 Mtetra
.741 .757 .866 r
.25541 .46187 .262 .46842 .27219 .46251 .26564 .45573 Mtetra
.731 .75 .867 r
.26564 .45573 .27219 .46251 .28237 .45691 .27587 .44991 Mtetra
.718 .742 .87 r
.27587 .44991 .28237 .45691 .29256 .45172 .28609 .44455 Mtetra
.702 .734 .875 r
.28609 .44455 .29256 .45172 .30273 .44702 .29629 .43971 Mtetra
.683 .725 .882 r
.29629 .43971 .30273 .44702 .3129 .44287 .30649 .43548 Mtetra
.662 .717 .89 r
.30649 .43548 .3129 .44287 .32307 .43931 .31668 .43188 Mtetra
.638 .709 .898 r
.31668 .43188 .32307 .43931 .33324 .43635 .32687 .42892 Mtetra
.612 .701 .908 r
.32687 .42892 .33324 .43635 .34342 .43395 .33706 .42659 Mtetra
.585 .694 .917 r
.33706 .42659 .34342 .43395 .35361 .43209 .34726 .42484 Mtetra
.559 .687 .926 r
.34726 .42484 .35361 .43209 .36383 .4307 .3575 .42359 Mtetra
.535 .683 .934 r
.3575 .42359 .36383 .4307 .37409 .42967 .36776 .42274 Mtetra
.515 .681 .941 r
.36776 .42274 .37409 .42967 .38439 .4289 .37807 .42218 Mtetra
.501 .683 .948 r
.37807 .42218 .38439 .4289 .39475 .42828 .38843 .42177 Mtetra
.495 .689 .954 r
.38843 .42177 .39475 .42828 .40516 .42767 .39885 .42138 Mtetra
.497 .699 .959 r
.39885 .42138 .40516 .42767 .41563 .42695 .40934 .42086 Mtetra
.509 .713 .963 r
.40934 .42086 .41563 .42695 .42617 .42598 .4199 .42008 Mtetra
.53 .729 .966 r
.4199 .42008 .42617 .42598 .43678 .42464 .43053 .41891 Mtetra
.557 .747 .966 r
.43053 .41891 .43678 .42464 .44746 .42284 .44122 .41723 Mtetra
.587 .764 .963 r
.44122 .41723 .44746 .42284 .4582 .42049 .45199 .41496 Mtetra
.62 .78 .958 r
.45199 .41496 .4582 .42049 .469 .41753 .46282 .41203 Mtetra
.651 .791 .949 r
.46282 .41203 .469 .41753 .47986 .41394 .47371 .40841 Mtetra
.68 .8 .939 r
.47371 .40841 .47986 .41394 .49077 .40971 .48466 .40411 Mtetra
.704 .804 .927 r
.48466 .40411 .49077 .40971 .50172 .40487 .49564 .39914 Mtetra
.723 .805 .915 r
.49564 .39914 .50172 .40487 .51271 .39948 .50667 .39357 Mtetra
.738 .803 .904 r
.50667 .39357 .51271 .39948 .52374 .39361 .51773 .38748 Mtetra
.747 .799 .894 r
.51773 .38748 .52374 .39361 .53479 .38736 .52882 .38099 Mtetra
.753 .794 .886 r
.52882 .38099 .53479 .38736 .54586 .38086 .53993 .37422 Mtetra
.754 .787 .88 r
.53993 .37422 .54586 .38086 .55696 .37422 .55106 .36731 Mtetra
.752 .779 .875 r
.55106 .36731 .55696 .37422 .56809 .36759 .56222 .36041 Mtetra
.746 .77 .873 r
.56222 .36041 .56809 .36759 .57924 .36109 .5734 .35365 Mtetra
.737 .761 .873 r
.5734 .35365 .57924 .36109 .59042 .35485 .58461 .34717 Mtetra
.725 .752 .874 r
.58461 .34717 .59042 .35485 .60164 .34898 .59586 .3411 Mtetra
.71 .742 .877 r
.59586 .3411 .60164 .34898 .6129 .34357 .60715 .33552 Mtetra
.692 .732 .882 r
.60715 .33552 .6129 .34357 .62422 .3387 .61849 .33053 Mtetra
.672 .722 .887 r
.61849 .33053 .62422 .3387 .63559 .33441 .62989 .32617 Mtetra
.65 .713 .893 r
.62989 .32617 .63559 .33441 .64704 .33072 .64136 .32247 Mtetra
.627 .703 .9 r
.64136 .32247 .64704 .33072 .65855 .32764 .65291 .31943 Mtetra
.603 .695 .908 r
.65291 .31943 .65855 .32764 .67015 .32513 .66453 .31699 Mtetra
.58 .688 .915 r
.66453 .31699 .67015 .32513 .68183 .32313 .67624 .31512 Mtetra
.559 .682 .922 r
.67624 .31512 .68183 .32313 .69359 .32155 .68805 .31371 Mtetra
.541 .679 .929 r
.68805 .31371 .69359 .32155 .70544 .3203 .69993 .31265 Mtetra
.527 .68 .935 r
.69993 .31265 .70544 .3203 .71737 .31925 .71191 .31181 Mtetra
.519 .684 .941 r
.71191 .31181 .71737 .31925 .72938 .31829 .72396 .31107 Mtetra
.518 .692 .947 r
.72396 .31107 .72938 .31829 .74146 .31727 .73609 .31026 Mtetra
.524 .703 .952 r
.73609 .31026 .74146 .31727 .7536 .31605 .74828 .30925 Mtetra
.537 .718 .956 r
.74828 .30925 .7536 .31605 .76579 .31452 .76051 .3079 Mtetra
.556 .735 .959 r
.76051 .3079 .76579 .31452 .77801 .31257 .77279 .30608 Mtetra
.581 .752 .959 r
.77279 .30608 .77801 .31257 .79026 .31008 .78508 .3037 Mtetra
.608 .77 .957 r
.78508 .3037 .79026 .31008 .80252 .307 .79739 .30066 Mtetra
.637 .785 .953 r
.79739 .30066 .80252 .307 .81478 .30328 .80969 .29694 Mtetra
.667 .801 .946 r
.15784 .50635 .16489 .51104 .17466 .50748 .16763 .50274 Mtetra
.697 .805 .932 r
.16763 .50274 .17466 .50748 .18452 .50326 .17754 .49841 Mtetra
.721 .805 .917 r
.17754 .49841 .18452 .50326 .19448 .49842 .18753 .4934 Mtetra
.738 .801 .902 r
.18753 .4934 .19448 .49842 .20451 .49304 .19762 .48781 Mtetra
.75 .796 .89 r
.19762 .48781 .20451 .49304 .21462 .4872 .20777 .48173 Mtetra
.757 .789 .879 r
.20777 .48173 .21462 .4872 .22477 .48104 .21798 .47528 Mtetra
.76 .782 .871 r
.21798 .47528 .22477 .48104 .23496 .47467 .22823 .46861 Mtetra
.759 .774 .865 r
.22823 .46861 .23496 .47467 .24518 .46823 .2385 .46188 Mtetra
.754 .765 .862 r
.2385 .46188 .24518 .46823 .25541 .46187 .24878 .45523 Mtetra
.747 .757 .861 r
.24878 .45523 .25541 .46187 .26564 .45573 .25906 .44881 Mtetra
.736 .748 .862 r
.25906 .44881 .26564 .45573 .27587 .44991 .26933 .44275 Mtetra
.722 .739 .865 r
.26933 .44275 .27587 .44991 .28609 .44455 .27959 .43718 Mtetra
.705 .73 .871 r
.27959 .43718 .28609 .44455 .29629 .43971 .28983 .4322 Mtetra
.685 .721 .877 r
.28983 .4322 .29629 .43971 .30649 .43548 .30005 .42787 Mtetra
.662 .712 .886 r
.30005 .42787 .30649 .43548 .31668 .43188 .31026 .42423 Mtetra
.636 .703 .895 r
.31026 .42423 .31668 .43188 .32687 .42892 .32046 .42129 Mtetra
.608 .695 .905 r
.32046 .42129 .32687 .42892 .33706 .42659 .33067 .41903 Mtetra
.579 .686 .915 r
.33067 .41903 .33706 .42659 .34726 .42484 .34088 .41741 Mtetra
.55 .679 .924 r
.34088 .41741 .34726 .42484 .3575 .42359 .35112 .41633 Mtetra
.523 .674 .933 r
.35112 .41633 .3575 .42359 .36776 .42274 .36139 .41569 Mtetra
.5 .672 .941 r
.36139 .41569 .36776 .42274 .37807 .42218 .3717 .41536 Mtetra
.484 .674 .948 r
.3717 .41536 .37807 .42218 .38843 .42177 .38207 .41521 Mtetra
.476 .68 .955 r
.38207 .41521 .38843 .42177 .39885 .42138 .3925 .41507 Mtetra
.479 .692 .961 r
.3925 .41507 .39885 .42138 .40934 .42086 .403 .4148 Mtetra
.492 .708 .966 r
.403 .4148 .40934 .42086 .4199 .42008 .41357 .41424 Mtetra
.514 .727 .969 r
.41357 .41424 .4199 .42008 .43053 .41891 .42421 .41326 Mtetra
.544 .747 .97 r
.42421 .41326 .43053 .41891 .44122 .41723 .43494 .41172 Mtetra
.579 .767 .968 r
.43494 .41172 .44122 .41723 .45199 .41496 .44573 .40954 Mtetra
.615 .784 .962 r
.44573 .40954 .45199 .41496 .46282 .41203 .45659 .40665 Mtetra
.65 .797 .953 r
.45659 .40665 .46282 .41203 .47371 .40841 .46751 .40301 Mtetra
.682 .806 .942 r
.46751 .40301 .47371 .40841 .48466 .40411 .47849 .39861 Mtetra
.708 .811 .929 r
.47849 .39861 .48466 .40411 .49564 .39914 .48951 .3935 Mtetra
.729 .811 .916 r
.48951 .3935 .49564 .39914 .50667 .39357 .50058 .38773 Mtetra
.744 .809 .903 r
.50058 .38773 .50667 .39357 .51773 .38748 .51167 .38141 Mtetra
.754 .804 .892 r
.51167 .38141 .51773 .38748 .52882 .38099 .5228 .37464 Mtetra
.76 .797 .883 r
.5228 .37464 .52882 .38099 .53993 .37422 .53395 .36757 Mtetra
.761 .789 .876 r
.53395 .36757 .53993 .37422 .55106 .36731 .54511 .36035 Mtetra
.758 .78 .871 r
.54511 .36035 .55106 .36731 .56222 .36041 .5563 .35313 Mtetra
.752 .771 .868 r
.5563 .35313 .56222 .36041 .5734 .35365 .56751 .34608 Mtetra
.742 .761 .868 r
.56751 .34608 .5734 .35365 .58461 .34717 .57876 .33933 Mtetra
.729 .75 .869 r
.57876 .33933 .58461 .34717 .59586 .3411 .59003 .33303 Mtetra
.713 .74 .873 r
.59003 .33303 .59586 .3411 .60715 .33552 .60135 .32727 Mtetra
.694 .729 .877 r
.60135 .32727 .60715 .33552 .61849 .33053 .61272 .32214 Mtetra
.673 .718 .883 r
.61272 .32214 .61849 .33053 .62989 .32617 .62414 .31771 Mtetra
.649 .708 .89 r
.62414 .31771 .62989 .32617 .64136 .32247 .63564 .314 Mtetra
.624 .697 .897 r
.63564 .314 .64136 .32247 .65291 .31943 .64721 .31099 Mtetra
.599 .688 .905 r
.64721 .31099 .65291 .31943 .66453 .31699 .65887 .30866 Mtetra
.574 .68 .912 r
.65887 .30866 .66453 .31699 .67624 .31512 .67062 .30693 Mtetra
.55 .674 .92 r
.67062 .30693 .67624 .31512 .68805 .31371 .68245 .30571 Mtetra
.53 .671 .927 r
.68245 .30571 .68805 .31371 .69993 .31265 .69438 .30488 Mtetra
.514 .672 .935 r
.69438 .30488 .69993 .31265 .71191 .31181 .7064 .30429 Mtetra
.505 .676 .942 r
.7064 .30429 .71191 .31181 .72396 .31107 .7185 .3038 Mtetra
.503 .685 .948 r
.7185 .3038 .72396 .31107 .73609 .31026 .73068 .30325 Mtetra
.509 .698 .954 r
.73068 .30325 .73609 .31026 .74828 .30925 .74291 .30248 Mtetra
.523 .714 .959 r
.74291 .30248 .74828 .30925 .76051 .3079 .7552 .30133 Mtetra
.545 .733 .962 r
.7552 .30133 .76051 .3079 .77279 .30608 .76753 .29968 Mtetra
.572 .754 .963 r
.76753 .29968 .77279 .30608 .78508 .3037 .77987 .29741 Mtetra
.603 .773 .962 r
.77987 .29741 .78508 .3037 .79739 .30066 .79223 .29444 Mtetra
.635 .79 .957 r
.79223 .29444 .79739 .30066 .80969 .29694 .80458 .29072 Mtetra
.668 .808 .95 r
.15072 .5018 .15784 .50635 .16763 .50274 .16054 .49814 Mtetra
.701 .812 .934 r
.16054 .49814 .16763 .50274 .17754 .49841 .17048 .49368 Mtetra
.727 .811 .917 r
.17048 .49368 .17754 .49841 .18753 .4934 .18052 .4885 Mtetra
.745 .807 .901 r
.18052 .4885 .18753 .4934 .19762 .48781 .19066 .48266 Mtetra
.758 .8 .887 r
.19066 .48266 .19762 .48781 .20777 .48173 .20087 .47629 Mtetra
.765 .792 .876 r
.20087 .47629 .20777 .48173 .21798 .47528 .21114 .46953 Mtetra
.767 .784 .867 r
.21114 .46953 .21798 .47528 .22823 .46861 .22145 .46253 Mtetra
.766 .775 .86 r
.22145 .46253 .22823 .46861 .2385 .46188 .23178 .45545 Mtetra
.761 .765 .857 r
.23178 .45545 .2385 .46188 .24878 .45523 .24211 .44847 Mtetra
.752 .756 .855 r
.24211 .44847 .24878 .45523 .25906 .44881 .25244 .44174 Mtetra
.741 .746 .857 r
.25244 .44174 .25906 .44881 .26933 .44275 .26276 .43542 Mtetra
.726 .737 .86 r
.26276 .43542 .26933 .44275 .27959 .43718 .27306 .42963 Mtetra
.708 .727 .865 r
.27306 .42963 .27959 .43718 .28983 .4322 .28333 .42447 Mtetra
.686 .717 .873 r
.28333 .42447 .28983 .4322 .30005 .42787 .29358 .42003 Mtetra
.662 .707 .881 r
.29358 .42003 .30005 .42787 .31026 .42423 .30381 .41635 Mtetra
.634 .698 .891 r
.30381 .41635 .31026 .42423 .32046 .42129 .31403 .41343 Mtetra
.604 .688 .902 r
.31403 .41343 .32046 .42129 .33067 .41903 .32424 .41127 Mtetra
.572 .679 .912 r
.32424 .41127 .33067 .41903 .34088 .41741 .33446 .40979 Mtetra
.539 .671 .922 r
.33446 .40979 .34088 .41741 .35112 .41633 .3447 .40891 Mtetra
.509 .665 .932 r
.3447 .40891 .35112 .41633 .36139 .41569 .35498 .40851 Mtetra
.483 .662 .941 r
.35498 .40851 .36139 .41569 .3717 .41536 .36529 .40846 Mtetra
.464 .663 .948 r
.36529 .40846 .3717 .41536 .38207 .41521 .37566 .40859 Mtetra
.455 .67 .956 r
.37566 .40859 .38207 .41521 .3925 .41507 .3861 .40875 Mtetra
.456 .683 .963 r
.3861 .40875 .3925 .41507 .403 .4148 .3966 .40876 Mtetra
.47 .701 .969 r
.3966 .40876 .403 .4148 .41357 .41424 .40719 .40846 Mtetra
.495 .723 .973 r
.40719 .40846 .41357 .41424 .42421 .41326 .41785 .40769 Mtetra
.529 .746 .975 r
.41785 .40769 .42421 .41326 .43494 .41172 .42859 .40633 Mtetra
.569 .769 .973 r
.42859 .40633 .43494 .41172 .44573 .40954 .43941 .40426 Mtetra
.61 .789 .967 r
.43941 .40426 .44573 .40954 .45659 .40665 .4503 .40141 Mtetra
.649 .804 .957 r
.4503 .40141 .45659 .40665 .46751 .40301 .46126 .39774 Mtetra
.684 .813 .945 r
.46126 .39774 .46751 .40301 .47849 .39861 .47227 .39326 Mtetra
.713 .818 .93 r
.47227 .39326 .47849 .39861 .48951 .3935 .48333 .38798 Mtetra
.735 .818 .916 r
.48333 .38798 .48951 .3935 .50058 .38773 .49443 .38199 Mtetra
.752 .815 .902 r
.49443 .38199 .50058 .38773 .51167 .38141 .50557 .37539 Mtetra
.762 .809 .89 r
.50557 .37539 .51167 .38141 .5228 .37464 .51673 .36831 Mtetra
.768 .801 .88 r
.51673 .36831 .5228 .37464 .53395 .36757 .52792 .3609 Mtetra
.769 .792 .872 r
.52792 .3609 .53395 .36757 .54511 .36035 .53912 .35332 Mtetra
.765 .782 .866 r
.53912 .35332 .54511 .36035 .5563 .35313 .55034 .34576 Mtetra
.758 .771 .863 r
.55034 .34576 .5563 .35313 .56751 .34608 .56159 .33838 Mtetra
.748 .76 .863 r
.56159 .33838 .56751 .34608 .57876 .33933 .57286 .33133 Mtetra
.734 .749 .864 r
.57286 .33133 .57876 .33933 .59003 .33303 .58416 .32476 Mtetra
.716 .737 .867 r
.58416 .32476 .59003 .33303 .60135 .32727 .5955 .31879 Mtetra
.696 .725 .872 r
.5955 .31879 .60135 .32727 .61272 .32214 .6069 .31352 Mtetra
.674 .714 .879 r
.6069 .31352 .61272 .32214 .62414 .31771 .61835 .30901 Mtetra
.648 .702 .886 r
.61835 .30901 .62414 .31771 .63564 .314 .62987 .30528 Mtetra
.622 .691 .894 r
.62987 .30528 .63564 .314 .64721 .31099 .64148 .30233 Mtetra
.594 .681 .902 r
.64148 .30233 .64721 .31099 .65887 .30866 .65316 .30012 Mtetra
.566 .672 .91 r
.65316 .30012 .65887 .30866 .67062 .30693 .66494 .29856 Mtetra
.54 .665 .918 r
.66494 .29856 .67062 .30693 .68245 .30571 .67682 .29756 Mtetra
.517 .662 .926 r
.67682 .29756 .68245 .30571 .69438 .30488 .68879 .29699 Mtetra
.5 .662 .934 r
.68879 .29699 .69438 .30488 .7064 .30429 .70085 .29669 Mtetra
.489 .667 .942 r
.70085 .29669 .7064 .30429 .7185 .3038 .713 .2965 Mtetra
.486 .676 .949 r
.713 .2965 .7185 .3038 .73068 .30325 .72522 .29624 Mtetra
.492 .691 .956 r
.72522 .29624 .73068 .30325 .74291 .30248 .73751 .29574 Mtetra
.508 .71 .962 r
.73751 .29574 .74291 .30248 .7552 .30133 .74986 .29483 Mtetra
.531 .731 .966 r
.74986 .29483 .7552 .30133 .76753 .29968 .76223 .29338 Mtetra
.561 .754 .968 r
.76223 .29338 .76753 .29968 .77987 .29741 .77463 .29125 Mtetra
.596 .776 .966 r
.77463 .29125 .77987 .29741 .79223 .29444 .78704 .28836 Mtetra
.631 .796 .961 r
.78704 .28836 .79223 .29444 .80458 .29072 .79943 .28463 Mtetra
.669 .815 .954 r
.14351 .49742 .15072 .5018 .16054 .49814 .15337 .49369 Mtetra
.706 .819 .935 r
.15337 .49369 .16054 .49814 .17048 .49368 .16335 .4891 Mtetra
.733 .818 .917 r
.16335 .4891 .17048 .49368 .18052 .4885 .17344 .48371 Mtetra
.753 .812 .9 r
.17344 .48371 .18052 .4885 .19066 .48266 .18363 .4776 Mtetra
.766 .805 .884 r
.18363 .4776 .19066 .48266 .20087 .47629 .19391 .47092 Mtetra
.773 .796 .872 r
.19391 .47092 .20087 .47629 .21114 .46953 .20424 .4638 Mtetra
.775 .786 .862 r
.20424 .4638 .21114 .46953 .22145 .46253 .21461 .45642 Mtetra
.773 .775 .855 r
.21461 .45642 .22145 .46253 .23178 .45545 .22501 .44896 Mtetra
.767 .765 .851 r
.22501 .44896 .23178 .45545 .24211 .44847 .2354 .4416 Mtetra
.758 .755 .849 r
.2354 .4416 .24211 .44847 .25244 .44174 .24579 .43453 Mtetra
.746 .744 .851 r
.24579 .43453 .25244 .44174 .26276 .43542 .25616 .4279 Mtetra
.73 .734 .854 r
.25616 .4279 .26276 .43542 .27306 .42963 .2665 .42185 Mtetra
.711 .724 .86 r
.2665 .42185 .27306 .42963 .28333 .42447 .27681 .41651 Mtetra
.688 .713 .868 r
.27681 .41651 .28333 .42447 .29358 .42003 .28708 .41195 Mtetra
.662 .702 .877 r
.28708 .41195 .29358 .42003 .30381 .41635 .29733 .40822 Mtetra
.632 .691 .887 r
.29733 .40822 .30381 .41635 .31403 .41343 .30757 .40534 Mtetra
.599 .68 .898 r
.30757 .40534 .31403 .41343 .32424 .41127 .31779 .40327 Mtetra
.563 .67 .91 r
.31779 .40327 .32424 .41127 .33446 .40979 .32801 .40196 Mtetra
.527 .661 .921 r
.32801 .40196 .33446 .40979 .3447 .40891 .33826 .40131 Mtetra
.493 .653 .931 r
.33826 .40131 .3447 .40891 .35498 .40851 .34853 .40119 Mtetra
.463 .649 .94 r
.34853 .40119 .35498 .40851 .36529 .40846 .35884 .40145 Mtetra
.441 .65 .948 r
.35884 .40145 .36529 .40846 .37566 .40859 .36921 .40192 Mtetra
.429 .658 .956 r
.36921 .40192 .37566 .40859 .3861 .40875 .37965 .40242 Mtetra
.43 .671 .963 r
.37965 .40242 .3861 .40875 .3966 .40876 .39016 .40276 Mtetra
.445 .692 .971 r
.39016 .40276 .3966 .40876 .40719 .40846 .40075 .40275 Mtetra
.473 .717 .976 r
.40075 .40275 .40719 .40846 .41785 .40769 .41143 .40224 Mtetra
.511 .744 .979 r
.41143 .40224 .41785 .40769 .42859 .40633 .42219 .40107 Mtetra
.556 .771 .978 r
.42219 .40107 .42859 .40633 .43941 .40426 .43303 .39913 Mtetra
.603 .794 .972 r
.43303 .39913 .43941 .40426 .4503 .40141 .44395 .39633 Mtetra
.647 .811 .962 r
.44395 .39633 .4503 .40141 .46126 .39774 .45494 .39264 Mtetra
.686 .821 .948 r
.45494 .39264 .46126 .39774 .47227 .39326 .46599 .38805 Mtetra
.718 .826 .932 r
.46599 .38805 .47227 .39326 .48333 .38798 .4771 .38259 Mtetra
.743 .825 .915 r
.4771 .38259 .48333 .38798 .49443 .38199 .48824 .37635 Mtetra
.76 .821 .9 r
.48824 .37635 .49443 .38199 .50557 .37539 .49942 .36944 Mtetra
.771 .814 .887 r
.49942 .36944 .50557 .37539 .51673 .36831 .51062 .362 Mtetra
.776 .805 .875 r
.51062 .362 .51673 .36831 .52792 .3609 .52184 .35421 Mtetra
.777 .794 .867 r
.52184 .35421 .52792 .3609 .53912 .35332 .53309 .34624 Mtetra
.773 .783 .861 r
.53309 .34624 .53912 .35332 .55034 .34576 .54434 .33829 Mtetra
.765 .771 .858 r
.54434 .33829 .55034 .34576 .56159 .33838 .55562 .33053 Mtetra
.754 .759 .857 r
.55562 .33053 .56159 .33838 .57286 .33133 .56692 .32314 Mtetra
.739 .747 .859 r
.56692 .32314 .57286 .33133 .58416 .32476 .57825 .31628 Mtetra
.72 .734 .862 r
.57825 .31628 .58416 .32476 .5955 .31879 .58962 .31009 Mtetra
.699 .722 .867 r
.58962 .31009 .5955 .31879 .6069 .31352 .60104 .30465 Mtetra
.674 .709 .874 r
.60104 .30465 .6069 .31352 .61835 .30901 .61252 .30005 Mtetra
.647 .696 .881 r
.61252 .30005 .61835 .30901 .62987 .30528 .62406 .29631 Mtetra
.618 .684 .89 r
.62406 .29631 .62987 .30528 .64148 .30233 .63569 .29342 Mtetra
.588 .673 .898 r
.63569 .29342 .64148 .30233 .65316 .30012 .64741 .29134 Mtetra
.558 .663 .907 r
.64741 .29134 .65316 .30012 .66494 .29856 .65922 .28999 Mtetra
.529 .656 .916 r
.65922 .28999 .66494 .29856 .67682 .29756 .67114 .28925 Mtetra
.503 .651 .925 r
.67114 .28925 .67682 .29756 .68879 .29699 .68315 .28898 Mtetra
.483 .651 .933 r
.68315 .28898 .68879 .29699 .70085 .29669 .69525 .289 Mtetra
.47 .656 .942 r
.69525 .289 .70085 .29669 .713 .2965 .70745 .28915 Mtetra
.466 .666 .95 r
.70745 .28915 .713 .2965 .72522 .29624 .71973 .28923 Mtetra
.472 .683 .958 r
.71973 .28923 .72522 .29624 .73751 .29574 .73207 .28904 Mtetra
.489 .704 .965 r
.73207 .28904 .73751 .29574 .74986 .29483 .74447 .28842 Mtetra
.515 .728 .97 r
.74447 .28842 .74986 .29483 .76223 .29338 .75691 .28719 Mtetra
.549 .755 .973 r
.75691 .28719 .76223 .29338 .77463 .29125 .76936 .28523 Mtetra
.588 .78 .971 r
.76936 .28523 .77463 .29125 .78704 .28836 .78182 .28242 Mtetra
.628 .802 .966 r
.78182 .28242 .78704 .28836 .79943 .28463 .79426 .27871 Mtetra
.67 .823 .957 r
.13622 .49322 .14351 .49742 .15337 .49369 .14611 .48943 Mtetra
.71 .827 .937 r
.14611 .48943 .15337 .49369 .16335 .4891 .15613 .48468 Mtetra
.74 .825 .917 r
.15613 .48468 .16335 .4891 .17344 .48371 .16628 .47906 Mtetra
.761 .818 .897 r
.16628 .47906 .17344 .48371 .18363 .4776 .17654 .47265 Mtetra
.774 .809 .881 r
.17654 .47265 .18363 .4776 .19391 .47092 .18688 .4656 Mtetra
.781 .799 .867 r
.18688 .4656 .19391 .47092 .20424 .4638 .19728 .45808 Mtetra
.783 .788 .856 r
.19728 .45808 .20424 .4638 .21461 .45642 .20773 .45028 Mtetra
.781 .776 .849 r
.20773 .45028 .21461 .45642 .22501 .44896 .21819 .44239 Mtetra
.774 .765 .844 r
.21819 .44239 .22501 .44896 .2354 .4416 .22866 .43462 Mtetra
.764 .754 .843 r
.22866 .43462 .2354 .4416 .24579 .43453 .2391 .42715 Mtetra
.751 .742 .844 r
.2391 .42715 .24579 .43453 .25616 .4279 .24953 .42018 Mtetra
.734 .731 .848 r
.24953 .42018 .25616 .4279 .2665 .42185 .25991 .41385 Mtetra
.714 .72 .854 r
.25991 .41385 .2665 .42185 .27681 .41651 .27026 .4083 Mtetra
.69 .708 .862 r
.27026 .4083 .27681 .41651 .28708 .41195 .28056 .40361 Mtetra
.661 .696 .872 r
.28056 .40361 .28708 .41195 .29733 .40822 .29083 .39983 Mtetra
.629 .684 .883 r
.29083 .39983 .29733 .40822 .30757 .40534 .30108 .39699 Mtetra
.593 .672 .895 r
.30108 .39699 .30757 .40534 .31779 .40327 .31131 .39504 Mtetra
.554 .66 .907 r
.31131 .39504 .31779 .40327 .32801 .40196 .32153 .39392 Mtetra
.514 .649 .918 r
.32153 .39392 .32801 .40196 .33826 .40131 .33177 .39353 Mtetra
.474 .64 .929 r
.33177 .39353 .33826 .40131 .34853 .40119 .34204 .39373 Mtetra
.44 .635 .938 r
.34204 .39373 .34853 .40119 .35884 .40145 .35234 .39435 Mtetra
.413 .635 .947 r
.35234 .39435 .35884 .40145 .36921 .40192 .36271 .3952 Mtetra
.398 .642 .955 r
.36271 .3952 .36921 .40192 .37965 .40242 .37314 .39608 Mtetra
.398 .657 .963 r
.37314 .39608 .37965 .40242 .39016 .40276 .38366 .39679 Mtetra
.414 .68 .972 r
.38366 .39679 .39016 .40276 .40075 .40275 .39426 .39712 Mtetra
.445 .709 .979 r
.39426 .39712 .40075 .40275 .41143 .40224 .40495 .3969 Mtetra
.489 .741 .983 r
.40495 .3969 .41143 .40224 .42219 .40107 .41573 .39596 Mtetra
.541 .772 .983 r
.41573 .39596 .42219 .40107 .43303 .39913 .42659 .39417 Mtetra
.595 .799 .978 r
.42659 .39417 .43303 .39913 .44395 .39633 .43754 .39143 Mtetra
.645 .819 .966 r
.43754 .39143 .44395 .39633 .45494 .39264 .44857 .38771 Mtetra
.689 .83 .951 r
.44857 .38771 .45494 .39264 .46599 .38805 .45966 .383 Mtetra
.724 .835 .933 r
.45966 .383 .46599 .38805 .4771 .38259 .4708 .37734 Mtetra
.751 .833 .915 r
.4708 .37734 .4771 .38259 .48824 .37635 .48199 .37082 Mtetra
.769 .828 .898 r
.48199 .37082 .48824 .37635 .49942 .36944 .49321 .36357 Mtetra
.781 .819 .883 r
.49321 .36357 .49942 .36944 .51062 .362 .50446 .35574 Mtetra
.786 .809 .871 r
.50446 .35574 .51062 .362 .52184 .35421 .51572 .34752 Mtetra
.786 .797 .862 r
.51572 .34752 .52184 .35421 .53309 .34624 .527 .3391 Mtetra
.781 .784 .855 r
.527 .3391 .53309 .34624 .54434 .33829 .5383 .3307 Mtetra
.773 .772 .852 r
.5383 .3307 .54434 .33829 .55562 .33053 .54961 .32252 Mtetra
.76 .758 .851 r
.54961 .32252 .55562 .33053 .56692 .32314 .56094 .31476 Mtetra
.744 .745 .852 r
.56094 .31476 .56692 .32314 .57825 .31628 .57229 .30758 Mtetra
.724 .731 .856 r
.57229 .30758 .57825 .31628 .58962 .31009 .58369 .30112 Mtetra
.702 .718 .862 r
.58369 .30112 .58962 .31009 .60104 .30465 .59513 .29551 Mtetra
.675 .704 .869 r
.59513 .29551 .60104 .30465 .61252 .30005 .60664 .29081 Mtetra
.646 .69 .877 r
.60664 .29081 .61252 .30005 .62406 .29631 .61821 .28706 Mtetra
.615 .677 .886 r
.61821 .28706 .62406 .29631 .63569 .29342 .62987 .28425 Mtetra
.581 .664 .895 r
.62987 .28425 .63569 .29342 .64741 .29134 .64161 .28232 Mtetra
.548 .653 .904 r
.64161 .28232 .64741 .29134 .65922 .28999 .65346 .2812 Mtetra
.516 .644 .914 r
.65346 .2812 .65922 .28999 .67114 .28925 .66541 .28076 Mtetra
.487 .639 .923 r
.66541 .28076 .67114 .28925 .68315 .28898 .67746 .28082 Mtetra
.463 .638 .932 r
.67746 .28082 .68315 .28898 .69525 .289 .68962 .28123 Mtetra
.448 .643 .941 r
.68962 .28123 .69525 .289 .70745 .28915 .70186 .28176 Mtetra
.443 .654 .95 r
.70186 .28176 .70745 .28915 .71973 .28923 .7142 .28222 Mtetra
.449 .672 .959 r
.7142 .28222 .71973 .28923 .73207 .28904 .7266 .2824 Mtetra
.467 .696 .967 r
.7266 .2824 .73207 .28904 .74447 .28842 .73905 .2821 Mtetra
.496 .724 .974 r
.73905 .2821 .74447 .28842 .75691 .28719 .75155 .28113 Mtetra
.534 .754 .977 r
.75155 .28113 .75691 .28719 .76936 .28523 .76406 .27936 Mtetra
.578 .783 .977 r
.76406 .27936 .76936 .28523 .78182 .28242 .77657 .27665 Mtetra
.623 .808 .971 r
.77657 .27665 .78182 .28242 .79426 .27871 .78906 .27296 Mtetra
.67 .832 .961 r
.12885 .48923 .13622 .49322 .14611 .48943 .13877 .48536 Mtetra
.716 .836 .939 r
.13877 .48536 .14611 .48943 .15613 .48468 .14884 .48045 Mtetra
.748 .833 .916 r
.14884 .48045 .15613 .48468 .16628 .47906 .15905 .47456 Mtetra
.77 .825 .895 r
.15905 .47456 .16628 .47906 .17654 .47265 .16937 .46782 Mtetra
.784 .814 .877 r
.16937 .46782 .17654 .47265 .18688 .4656 .17979 .46037 Mtetra
.79 .802 .862 r
.17979 .46037 .18688 .4656 .19728 .45808 .19027 .45239 Mtetra
.792 .79 .85 r
.19027 .45239 .19728 .45808 .20773 .45028 .20079 .44411 Mtetra
.789 .777 .842 r
.20079 .44411 .20773 .45028 .21819 .44239 .21133 .43574 Mtetra
.782 .765 .838 r
.21133 .43574 .21819 .44239 .22866 .43462 .22187 .4275 Mtetra
.771 .752 .836 r
.22187 .4275 .22866 .43462 .2391 .42715 .23239 .4196 Mtetra
.757 .74 .837 r
.23239 .4196 .2391 .42715 .24953 .42018 .24287 .41225 Mtetra
.739 .728 .841 r
.24287 .41225 .24953 .42018 .25991 .41385 .2533 .40561 Mtetra
.717 .716 .848 r
.2533 .40561 .25991 .41385 .27026 .4083 .26369 .39982 Mtetra
.692 .703 .856 r
.26369 .39982 .27026 .4083 .28056 .40361 .27402 .39498 Mtetra
.661 .69 .867 r
.27402 .39498 .28056 .40361 .29083 .39983 .28431 .39115 Mtetra
.626 .677 .878 r
.28431 .39115 .29083 .39983 .30108 .39699 .29457 .38835 Mtetra
.587 .663 .891 r
.29457 .38835 .30108 .39699 .31131 .39504 .3048 .38654 Mtetra
.543 .649 .904 r
.3048 .38654 .31131 .39504 .32153 .39392 .31502 .38565 Mtetra
.498 .636 .916 r
.31502 .38565 .32153 .39392 .33177 .39353 .32525 .38556 Mtetra
.453 .625 .926 r
.32525 .38556 .33177 .39353 .34204 .39373 .33551 .38611 Mtetra
.412 .618 .935 r
.33551 .38611 .34204 .39373 .35234 .39435 .34581 .38714 Mtetra
.38 .616 .944 r
.34581 .38714 .35234 .39435 .36271 .3952 .35616 .38842 Mtetra
.361 .623 .952 r
.35616 .38842 .36271 .3952 .37314 .39608 .36659 .38974 Mtetra
.359 .639 .961 r
.36659 .38974 .37314 .39608 .38366 .39679 .3771 .39087 Mtetra
.376 .665 .971 r
.3771 .39087 .38366 .39679 .39426 .39712 .3877 .39159 Mtetra
.412 .699 .98 r
.3877 .39159 .39426 .39712 .40495 .3969 .3984 .3917 Mtetra
.463 .736 .987 r
.3984 .3917 .40495 .3969 .41573 .39596 .4092 .39101 Mtetra
.523 .773 .988 r
.4092 .39101 .41573 .39596 .42659 .39417 .42009 .38939 Mtetra
.585 .804 .983 r
.42009 .38939 .42659 .39417 .43754 .39143 .43107 .38674 Mtetra
.643 .827 .971 r
.43107 .38674 .43754 .39143 .44857 .38771 .44213 .38299 Mtetra
.692 .84 .954 r
.44213 .38299 .44857 .38771 .45966 .383 .45326 .37815 Mtetra
.731 .844 .934 r
.45326 .37815 .45966 .383 .4708 .37734 .46445 .37227 Mtetra
.76 .842 .914 r
.46445 .37227 .4708 .37734 .48199 .37082 .47568 .36543 Mtetra
.779 .835 .895 r
.47568 .36543 .48199 .37082 .49321 .36357 .48695 .35779 Mtetra
.791 .825 .879 r
.48695 .35779 .49321 .36357 .50446 .35574 .49824 .34952 Mtetra
.796 .813 .865 r
.49824 .34952 .50446 .35574 .51572 .34752 .50955 .34081 Mtetra
.795 .799 .855 r
.50955 .34081 .51572 .34752 .527 .3391 .52087 .3319 Mtetra
.79 .786 .849 r
.52087 .3319 .527 .3391 .5383 .3307 .53221 .32301 Mtetra
.781 .772 .845 r
.53221 .32301 .5383 .3307 .54961 .32252 .54355 .31436 Mtetra
.767 .757 .844 r
.54355 .31436 .54961 .32252 .56094 .31476 .55491 .30617 Mtetra
.75 .743 .846 r
.55491 .30617 .56094 .31476 .57229 .30758 .5663 .29862 Mtetra
.729 .728 .85 r
.5663 .29862 .57229 .30758 .58369 .30112 .57772 .29188 Mtetra
.704 .713 .856 r
.57772 .29188 .58369 .30112 .59513 .29551 .58919 .28607 Mtetra
.676 .698 .863 r
.58919 .28607 .59513 .29551 .60664 .29081 .60071 .28127 Mtetra
.645 .683 .872 r
.60071 .28127 .60664 .29081 .61821 .28706 .61231 .27751 Mtetra
.61 .669 .881 r
.61231 .27751 .61821 .28706 .62987 .28425 .62399 .27479 Mtetra
.574 .654 .891 r
.62399 .27479 .62987 .28425 .64161 .28232 .63577 .27304 Mtetra
.537 .642 .901 r
.63577 .27304 .64161 .28232 .65346 .2812 .64765 .27219 Mtetra
.501 .632 .911 r
.64765 .27219 .65346 .2812 .66541 .28076 .65963 .27207 Mtetra
.468 .625 .92 r
.65963 .27207 .66541 .28076 .67746 .28082 .67173 .27253 Mtetra
.441 .623 .929 r
.67173 .27253 .67746 .28082 .68962 .28123 .68393 .27336 Mtetra
.422 .628 .939 r
.68393 .27336 .68962 .28123 .70186 .28176 .69623 .27434 Mtetra
.415 .64 .949 r
.69623 .27434 .70186 .28176 .7142 .28222 .70862 .27524 Mtetra
.421 .66 .959 r
.70862 .27524 .7142 .28222 .7266 .2824 .72108 .27583 Mtetra
.44 .686 .969 r
.72108 .27583 .7266 .2824 .73905 .2821 .7336 .27589 Mtetra
.473 .719 .977 r
.7336 .27589 .73905 .2821 .75155 .28113 .74615 .27522 Mtetra
.516 .753 .982 r
.74615 .27522 .75155 .28113 .76406 .27936 .75872 .27366 Mtetra
.566 .786 .982 r
.75872 .27366 .76406 .27936 .77657 .27665 .77129 .27108 Mtetra
.618 .815 .976 r
.77129 .27108 .77657 .27665 .78906 .27296 .78383 .2674 Mtetra
.671 .842 .965 r
.12138 .48546 .12885 .48923 .13877 .48536 .13133 .48152 Mtetra
.722 .846 .94 r
.13133 .48152 .13877 .48536 .14884 .48045 .14145 .47642 Mtetra
.757 .841 .915 r
.14145 .47642 .14884 .48045 .15905 .47456 .15173 .47024 Mtetra
.78 .831 .892 r
.15173 .47024 .15905 .47456 .16937 .46782 .16212 .46312 Mtetra
.794 .819 .872 r
.16212 .46312 .16937 .46782 .17979 .46037 .17262 .45521 Mtetra
.8 .805 .856 r
.17262 .45521 .17979 .46037 .19027 .45239 .18319 .44674 Mtetra
.801 .791 .843 r
.18319 .44674 .19027 .45239 .20079 .44411 .1938 .43792 Mtetra
.797 .778 .835 r
.1938 .43792 .20079 .44411 .21133 .43574 .20443 .42901 Mtetra
.789 .764 .83 r
.20443 .42901 .21133 .43574 .22187 .4275 .21505 .42025 Mtetra
.778 .751 .828 r
.21505 .42025 .22187 .4275 .23239 .4196 .22564 .41186 Mtetra
.763 .738 .83 r
.22564 .41186 .23239 .4196 .24287 .41225 .23618 .40408 Mtetra
.744 .725 .834 r
.23618 .40408 .24287 .41225 .2533 .40561 .24667 .39709 Mtetra
.721 .712 .841 r
.24667 .39709 .2533 .40561 .26369 .39982 .2571 .39104 Mtetra
.693 .698 .85 r
.2571 .39104 .26369 .39982 .27402 .39498 .26746 .38605 Mtetra
.661 .684 .861 r
.26746 .38605 .27402 .39498 .28431 .39115 .27777 .38216 Mtetra
.623 .669 .873 r
.27777 .38216 .28431 .39115 .29457 .38835 .28804 .37941 Mtetra
.58 .653 .887 r
.28804 .37941 .29457 .38835 .3048 .38654 .29827 .37776 Mtetra
.531 .637 .9 r
.29827 .37776 .3048 .38654 .31502 .38565 .30849 .37712 Mtetra
.48 .622 .912 r
.30849 .37712 .31502 .38565 .32525 .38556 .3187 .37737 Mtetra
.428 .607 .923 r
.3187 .37737 .32525 .38556 .33551 .38611 .32894 .37833 Mtetra
.38 .597 .931 r
.32894 .37833 .33551 .38611 .34581 .38714 .33923 .37981 Mtetra
.341 .593 .939 r
.33923 .37981 .34581 .38714 .35616 .38842 .34957 .38158 Mtetra
.317 .599 .947 r
.34957 .38158 .35616 .38842 .36659 .38974 .35998 .3834 Mtetra
.313 .616 .956 r
.35998 .3834 .36659 .38974 .3771 .39087 .37049 .385 Mtetra
.331 .645 .967 r
.37049 .385 .3771 .39087 .3877 .39159 .38109 .38616 Mtetra
.372 .684 .979 r
.38109 .38616 .3877 .39159 .3984 .3917 .3918 .38665 Mtetra
.43 .729 .989 r
.3918 .38665 .3984 .3917 .4092 .39101 .40261 .38626 Mtetra
.5 .773 .993 r
.40261 .38626 .4092 .39101 .42009 .38939 .41352 .38484 Mtetra
.573 .81 .989 r
.41352 .38484 .42009 .38939 .43107 .38674 .42453 .38227 Mtetra
.639 .836 .976 r
.42453 .38227 .43107 .38674 .44213 .38299 .43563 .3785 Mtetra
.695 .85 .957 r
.43563 .3785 .44213 .38299 .45326 .37815 .44681 .37352 Mtetra
.738 .854 .935 r
.44681 .37352 .45326 .37815 .46445 .37227 .45804 .36738 Mtetra
.769 .851 .912 r
.45804 .36738 .46445 .37227 .47568 .36543 .46932 .3602 Mtetra
.79 .842 .891 r
.46932 .3602 .47568 .36543 .48695 .35779 .48064 .35212 Mtetra
.802 .83 .873 r
.48064 .35212 .48695 .35779 .49824 .34952 .49198 .34335 Mtetra
.806 .817 .859 r
.49198 .34335 .49824 .34952 .50955 .34081 .50334 .33411 Mtetra
.805 .802 .848 r
.50334 .33411 .50955 .34081 .52087 .3319 .5147 .32464 Mtetra
.799 .787 .841 r
.5147 .32464 .52087 .3319 .53221 .32301 .52607 .31519 Mtetra
.789 .772 .837 r
.52607 .31519 .53221 .32301 .54355 .31436 .53745 .30602 Mtetra
.774 .756 .837 r
.53745 .30602 .54355 .31436 .55491 .30617 .54884 .29736 Mtetra
.756 .741 .839 r
.54884 .29736 .55491 .30617 .5663 .29862 .56026 .28941 Mtetra
.734 .725 .843 r
.56026 .28941 .5663 .29862 .57772 .29188 .5717 .28235 Mtetra
.707 .709 .849 r
.5717 .28235 .57772 .29188 .58919 .28607 .5832 .27632 Mtetra
.677 .692 .857 r
.5832 .27632 .58919 .28607 .60071 .28127 .59474 .2714 Mtetra
.643 .676 .866 r
.59474 .2714 .60071 .28127 .61231 .27751 .60637 .26763 Mtetra
.606 .66 .876 r
.60637 .26763 .61231 .27751 .62399 .27479 .61807 .26501 Mtetra
.566 .644 .887 r
.61807 .26501 .62399 .27479 .63577 .27304 .62988 .26348 Mtetra
.525 .629 .897 r
.62988 .26348 .63577 .27304 .64765 .27219 .64179 .26292 Mtetra
.484 .617 .907 r
.64179 .26292 .64765 .27219 .65963 .27207 .65381 .26318 Mtetra
.447 .609 .917 r
.65381 .26318 .65963 .27207 .67173 .27253 .66595 .26408 Mtetra
.415 .606 .926 r
.66595 .26408 .67173 .27253 .68393 .27336 .6782 .26539 Mtetra
.393 .61 .936 r
.6782 .26539 .68393 .27336 .69623 .27434 .69056 .26687 Mtetra
.383 .622 .947 r
.69056 .26687 .69623 .27434 .70862 .27524 .703 .26827 Mtetra
.388 .644 .958 r
.703 .26827 .70862 .27524 .72108 .27583 .71553 .26933 Mtetra
.409 .674 .97 r
.71553 .26933 .72108 .27583 .7336 .27589 .72811 .2698 Mtetra
.445 .711 .98 r
.72811 .2698 .7336 .27589 .74615 .27522 .74073 .26948 Mtetra
.494 .751 .986 r
.74073 .26948 .74615 .27522 .75872 .27366 .75336 .26817 Mtetra
.551 .789 .987 r
.75336 .26817 .75872 .27366 .77129 .27108 .76598 .26573 Mtetra
.611 .823 .981 r
.76598 .26573 .77129 .27108 .78383 .2674 .77858 .26208 Mtetra
.671 .853 .969 r
.1138 .48196 .12138 .48546 .13133 .48152 .1238 .47793 Mtetra
.728 .856 .942 r
.1238 .47793 .13133 .48152 .14145 .47642 .13397 .47263 Mtetra
.766 .85 .914 r
.13397 .47263 .14145 .47642 .15173 .47024 .14432 .46612 Mtetra
.791 .838 .888 r
.14432 .46612 .15173 .47024 .16212 .46312 .1548 .45857 Mtetra
.804 .824 .866 r
.1548 .45857 .16212 .46312 .17262 .45521 .16539 .45017 Mtetra
.81 .808 .849 r
.16539 .45017 .17262 .45521 .18319 .44674 .17605 .44113 Mtetra
.81 .793 .836 r
.17605 .44113 .18319 .44674 .1938 .43792 .18676 .43171 Mtetra
.806 .778 .827 r
.18676 .43171 .1938 .43792 .20443 .42901 .19748 .4222 Mtetra
.797 .763 .822 r
.19748 .4222 .20443 .42901 .21505 .42025 .20819 .41285 Mtetra
.785 .749 .82 r
.20819 .41285 .21505 .42025 .22564 .41186 .21886 .40392 Mtetra
.769 .735 .822 r
.21886 .40392 .22564 .41186 .23618 .40408 .22947 .39567 Mtetra
.749 .721 .826 r
.22947 .39567 .23618 .40408 .24667 .39709 .24002 .38829 Mtetra
.725 .707 .833 r
.24002 .38829 .24667 .39709 .2571 .39104 .25049 .38195 Mtetra
.695 .692 .843 r
.25049 .38195 .2571 .39104 .26746 .38605 .26089 .37678 Mtetra
.661 .677 .855 r
.26089 .37678 .26746 .38605 .27777 .38216 .27122 .37284 Mtetra
.619 .66 .868 r
.27122 .37284 .27777 .38216 .28804 .37941 .28149 .37015 Mtetra
.572 .643 .882 r
.28149 .37015 .28804 .37941 .29827 .37776 .29172 .36867 Mtetra
.518 .624 .896 r
.29172 .36867 .29827 .37776 .30849 .37712 .30192 .36831 Mtetra
.459 .605 .908 r
.30192 .36831 .30849 .37712 .3187 .37737 .31212 .36894 Mtetra
.399 .587 .918 r
.31212 .36894 .3187 .37737 .32894 .37833 .32234 .37037 Mtetra
.342 .573 .926 r
.32234 .37037 .32894 .37833 .33923 .37981 .3326 .37236 Mtetra
.295 .565 .931 r
.3326 .37236 .33923 .37981 .34957 .38158 .34292 .37469 Mtetra
.265 .569 .938 r
.34292 .37469 .34957 .38158 .35998 .3834 .35332 .37706 Mtetra
.258 .587 .946 r
.35332 .37706 .35998 .3834 .37049 .385 .36381 .37921 Mtetra
.276 .619 .959 r
.36381 .37921 .37049 .385 .38109 .38616 .37441 .38087 Mtetra
.322 .664 .974 r
.37441 .38087 .38109 .38616 .3918 .38665 .38512 .38178 Mtetra
.39 .718 .988 r
.38512 .38178 .3918 .38665 .40261 .38626 .39595 .38172 Mtetra
.472 .77 .996 r
.39595 .38172 .40261 .38626 .41352 .38484 .40689 .38053 Mtetra
.557 .815 .994 r
.40689 .38053 .41352 .38484 .42453 .38227 .41793 .37806 Mtetra
.635 .846 .981 r
.41793 .37806 .42453 .38227 .43563 .3785 .42906 .37426 Mtetra
.699 .862 .96 r
.42906 .37426 .43563 .3785 .44681 .37352 .44028 .36913 Mtetra
.747 .866 .935 r
.44028 .36913 .44681 .37352 .45804 .36738 .45156 .36271 Mtetra
.78 .861 .91 r
.45156 .36271 .45804 .36738 .46932 .3602 .4629 .35514 Mtetra
.802 .85 .887 r
.4629 .35514 .46932 .3602 .48064 .35212 .47427 .34658 Mtetra
.813 .836 .867 r
.47427 .34658 .48064 .35212 .49198 .34335 .48566 .33725 Mtetra
.818 .821 .852 r
.48566 .33725 .49198 .34335 .50334 .33411 .49707 .3274 Mtetra
.816 .805 .841 r
.49707 .3274 .50334 .33411 .5147 .32464 .50848 .31731 Mtetra
.809 .788 .833 r
.50848 .31731 .5147 .32464 .52607 .31519 .51989 .30725 Mtetra
.797 .772 .829 r
.51989 .30725 .52607 .31519 .53745 .30602 .53131 .29749 Mtetra
.782 .755 .829 r
.53131 .29749 .53745 .30602 .54884 .29736 .54274 .2883 Mtetra
.762 .738 .831 r
.54274 .2883 .54884 .29736 .56026 .28941 .55418 .27991 Mtetra
.738 .721 .835 r
.55418 .27991 .56026 .28941 .5717 .28235 .56565 .2725 Mtetra
.71 .704 .842 r
.56565 .2725 .5717 .28235 .5832 .27632 .57716 .26622 Mtetra
.678 .686 .851 r
.57716 .26622 .5832 .27632 .59474 .2714 .58873 .26118 Mtetra
.641 .668 .86 r
.58873 .26118 .59474 .2714 .60637 .26763 .60038 .25741 Mtetra
.601 .65 .871 r
.60038 .25741 .60637 .26763 .61807 .26501 .61211 .25491 Mtetra
.557 .632 .882 r
.61211 .25491 .61807 .26501 .62988 .26348 .62394 .2536 Mtetra
.511 .616 .893 r
.62394 .2536 .62988 .26348 .64179 .26292 .63589 .25338 Mtetra
.465 .601 .903 r
.63589 .25338 .64179 .26292 .65381 .26318 .64795 .25407 Mtetra
.422 .591 .912 r
.64795 .25407 .65381 .26318 .66595 .26408 .66013 .25547 Mtetra
.385 .586 .922 r
.66013 .25547 .66595 .26408 .6782 .26539 .67243 .25733 Mtetra
.359 .589 .932 r
.67243 .25733 .6782 .26539 .69056 .26687 .68484 .25937 Mtetra
.345 .601 .943 r
.68484 .25937 .69056 .26687 .703 .26827 .69734 .26133 Mtetra
.349 .625 .955 r
.69734 .26133 .703 .26827 .71553 .26933 .70993 .26292 Mtetra
.371 .658 .968 r
.70993 .26292 .71553 .26933 .72811 .2698 .72258 .26386 Mtetra
.412 .7 .981 r
.72258 .26386 .72811 .2698 .74073 .26948 .73527 .26393 Mtetra
.468 .747 .99 r
.73527 .26393 .74073 .26948 .75336 .26817 .74796 .2629 Mtetra
.534 .792 .992 r
.74796 .2629 .75336 .26817 .76598 .26573 .76065 .26063 Mtetra
.602 .83 .987 r
.76065 .26063 .76598 .26573 .77858 .26208 .7733 .25701 Mtetra
.671 .864 .973 r
.10612 .47876 .1138 .48196 .1238 .47793 .11615 .47463 Mtetra
.735 .868 .943 r
.11615 .47463 .1238 .47793 .13397 .47263 .12639 .46909 Mtetra
.777 .859 .911 r
.12639 .46909 .13397 .47263 .14432 .46612 .13681 .46223 Mtetra
.802 .845 .883 r
.13681 .46223 .14432 .46612 .1548 .45857 .14738 .45421 Mtetra
.815 .828 .86 r
.14738 .45421 .1548 .45857 .16539 .45017 .15807 .44523 Mtetra
.821 .811 .841 r
.15807 .44523 .16539 .45017 .17605 .44113 .16884 .43556 Mtetra
.82 .794 .828 r
.16884 .43556 .17605 .44113 .18676 .43171 .17966 .42548 Mtetra
.815 .778 .819 r
.17966 .42548 .18676 .43171 .19748 .4222 .19049 .41529 Mtetra
.805 .762 .813 r
.19049 .41529 .19748 .4222 .20819 .41285 .20129 .40529 Mtetra
.792 .747 .812 r
.20129 .40529 .20819 .41285 .21886 .40392 .21205 .39576 Mtetra
.775 .732 .813 r
.21205 .39576 .21886 .40392 .22947 .39567 .22274 .38698 Mtetra
.754 .717 .818 r
.22274 .38698 .22947 .39567 .24002 .38829 .23335 .37916 Mtetra
.729 .702 .825 r
.23335 .37916 .24002 .38829 .25049 .38195 .24387 .37251 Mtetra
.697 .686 .836 r
.24387 .37251 .25049 .38195 .26089 .37678 .2543 .36714 Mtetra
.66 .669 .848 r
.2543 .36714 .26089 .37678 .27122 .37284 .26465 .36314 Mtetra
.615 .651 .862 r
.26465 .36314 .27122 .37284 .28149 .37015 .27493 .36052 Mtetra
.563 .631 .877 r
.27493 .36052 .28149 .37015 .29172 .36867 .28515 .35924 Mtetra
.502 .609 .891 r
.28515 .35924 .29172 .36867 .30192 .36831 .29534 .35921 Mtetra
.435 .586 .903 r
.29534 .35921 .30192 .36831 .31212 .36894 .30552 .36027 Mtetra
.365 .563 .912 r
.30552 .36027 .31212 .36894 .32234 .37037 .31571 .36221 Mtetra
.298 .543 .917 r
.31571 .36221 .32234 .37037 .3326 .37236 .32594 .36479 Mtetra
.241 .532 .92 r
.32594 .36479 .3326 .37236 .34292 .37469 .33623 .36773 Mtetra
.203 .532 .923 r
.33623 .36773 .34292 .37469 .35332 .37706 .34661 .37074 Mtetra
.191 .549 .931 r
.34661 .37074 .35332 .37706 .36381 .37921 .35708 .3735 Mtetra
.21 .585 .944 r
.35708 .3735 .36381 .37921 .37441 .38087 .36767 .37571 Mtetra
.262 .638 .963 r
.36767 .37571 .37441 .38087 .38512 .38178 .37838 .37711 Mtetra
.341 .701 .983 r
.37838 .37711 .38512 .38178 .39595 .38172 .38922 .37743 Mtetra
.438 .765 .996 r
.38922 .37743 .39595 .38172 .40689 .38053 .40017 .37649 Mtetra
.538 .819 .998 r
.40017 .37649 .40689 .38053 .41793 .37806 .41125 .37415 Mtetra
.629 .856 .985 r
.41125 .37415 .41793 .37806 .42906 .37426 .42242 .37032 Mtetra
.702 .874 .962 r
.42242 .37032 .42906 .37426 .44028 .36913 .43369 .36501 Mtetra
.755 .878 .934 r
.43369 .36501 .44028 .36913 .45156 .36271 .44502 .35829 Mtetra
.792 .871 .906 r
.44502 .35829 .45156 .36271 .4629 .35514 .45641 .35028 Mtetra
.814 .858 .881 r
.45641 .35028 .4629 .35514 .47427 .34658 .46784 .34118 Mtetra
.826 .842 .86 r
.46784 .34118 .47427 .34658 .48566 .33725 .47929 .33123 Mtetra
.829 .825 .844 r
.47929 .33123 .48566 .33725 .49707 .3274 .49075 .32071 Mtetra
.827 .807 .832 r
.49075 .32071 .49707 .3274 .50848 .31731 .50221 .30992 Mtetra
.819 .789 .824 r
.50221 .30992 .50848 .31731 .51989 .30725 .51367 .29917 Mtetra
.806 .771 .82 r
.51367 .29917 .51989 .30725 .53131 .29749 .52513 .28876 Mtetra
.79 .753 .82 r
.52513 .28876 .53131 .29749 .54274 .2883 .53659 .27899 Mtetra
.769 .735 .822 r
.53659 .27899 .54274 .2883 .55418 .27991 .54806 .27009 Mtetra
.743 .717 .827 r
.54806 .27009 .55418 .27991 .56565 .2725 .55956 .26229 Mtetra
.713 .699 .835 r
.55956 .26229 .56565 .2725 .57716 .26622 .57109 .25575 Mtetra
.679 .68 .844 r
.57109 .25575 .57716 .26622 .58873 .26118 .58268 .25057 Mtetra
.639 .66 .854 r
.58268 .25057 .58873 .26118 .60038 .25741 .59435 .2468 Mtetra
.595 .64 .865 r
.59435 .2468 .60038 .25741 .61211 .25491 .6061 .24443 Mtetra
.547 .62 .877 r
.6061 .24443 .61211 .25491 .62394 .2536 .61796 .2434 Mtetra
.496 .601 .887 r
.61796 .2434 .62394 .2536 .63589 .25338 .62993 .24355 Mtetra
.444 .583 .898 r
.62993 .24355 .63589 .25338 .64795 .25407 .64203 .24473 Mtetra
.394 .57 .907 r
.64203 .24473 .64795 .25407 .66013 .25547 .65426 .24668 Mtetra
.351 .562 .916 r
.65426 .24668 .66013 .25547 .67243 .25733 .6666 .24915 Mtetra
.319 .564 .925 r
.6666 .24915 .67243 .25733 .68484 .25937 .67907 .25184 Mtetra
.302 .576 .936 r
.67907 .25184 .68484 .25937 .69734 .26133 .69164 .25443 Mtetra
.303 .601 .949 r
.69164 .25443 .69734 .26133 .70993 .26292 .7043 .25662 Mtetra
.327 .638 .964 r
.7043 .25662 .70993 .26292 .72258 .26386 .71701 .2581 Mtetra
.372 .686 .979 r
.71701 .2581 .72258 .26386 .73527 .26393 .72977 .2586 Mtetra
.436 .74 .991 r
.72977 .2586 .73527 .26393 .74796 .2629 .74254 .25789 Mtetra
.512 .793 .996 r
.74254 .25789 .74796 .2629 .76065 .26063 .75529 .25581 Mtetra
.591 .838 .991 r
.75529 .25581 .76065 .26063 .7733 .25701 .768 .25223 Mtetra
.671 .877 .976 r
.09832 .47588 .10612 .47876 .11615 .47463 .1084 .47166 Mtetra
.743 .88 .943 r
.1084 .47166 .11615 .47463 .12639 .46909 .1187 .46586 Mtetra
.788 .869 .908 r
.1187 .46586 .12639 .46909 .13681 .46223 .12921 .4586 Mtetra
.814 .852 .878 r
.12921 .4586 .13681 .46223 .14738 .45421 .13988 .45004 Mtetra
.827 .833 .853 r
.13988 .45004 .14738 .45421 .15807 .44523 .15068 .44043 Mtetra
.831 .814 .833 r
.15068 .44043 .15807 .44523 .16884 .43556 .16157 .43006 Mtetra
.83 .796 .819 r
.16157 .43006 .16884 .43556 .17966 .42548 .17251 .41923 Mtetra
.824 .778 .809 r
.17251 .41923 .17966 .42548 .19049 .41529 .18345 .40829 Mtetra
.813 .761 .804 r
.18345 .40829 .19049 .41529 .20129 .40529 .19436 .39756 Mtetra
.799 .745 .802 r
.19436 .39756 .20129 .40529 .21205 .39576 .20522 .38736 Mtetra
.782 .729 .804 r
.20522 .38736 .21205 .39576 .22274 .38698 .216 .37799 Mtetra
.759 .713 .809 r
.216 .37799 .22274 .38698 .23335 .37916 .22667 .3697 Mtetra
.732 .697 .817 r
.22667 .3697 .23335 .37916 .24387 .37251 .23725 .36269 Mtetra
.699 .68 .828 r
.23725 .36269 .24387 .37251 .2543 .36714 .24771 .3571 Mtetra
.659 .662 .841 r
.24771 .3571 .2543 .36714 .26465 .36314 .25808 .35303 Mtetra
.611 .641 .856 r
.25808 .35303 .26465 .36314 .27493 .36052 .26836 .3505 Mtetra
.553 .618 .871 r
.26836 .3505 .27493 .36052 .28515 .35924 .27857 .34945 Mtetra
.485 .592 .885 r
.27857 .34945 .28515 .35924 .29534 .35921 .28874 .34978 Mtetra
.409 .564 .897 r
.28874 .34978 .29534 .35921 .30552 .36027 .29888 .35132 Mtetra
.327 .535 .903 r
.29888 .35132 .30552 .36027 .31571 .36221 .30904 .35384 Mtetra
.247 .508 .904 r
.30904 .35384 .31571 .36221 .32594 .36479 .31923 .35707 Mtetra
.178 .49 .902 r
.31923 .35707 .32594 .36479 .33623 .36773 .32949 .36071 Mtetra
.13 .486 .901 r
.32949 .36071 .33623 .36773 .34661 .37074 .33983 .36443 Mtetra
.113 .502 .906 r
.33983 .36443 .34661 .37074 .35708 .3735 .35028 .36788 Mtetra
.131 .541 .92 r
.35028 .36788 .35708 .3735 .36767 .37571 .36086 .37073 Mtetra
.188 .601 .944 r
.36086 .37073 .36767 .37571 .37838 .37711 .37156 .37267 Mtetra
.28 .677 .971 r
.37156 .37267 .37838 .37711 .38922 .37743 .38241 .37342 Mtetra
.395 .756 .993 r
.38241 .37342 .38922 .37743 .40017 .37649 .39338 .37277 Mtetra
.514 .822 1 r
.39338 .37277 .40017 .37649 .41125 .37415 .40449 .37056 Mtetra
.621 .867 .989 r
.40449 .37056 .41125 .37415 .42242 .37032 .4157 .36671 Mtetra
.705 .888 .964 r
.4157 .36671 .42242 .37032 .43369 .36501 .42702 .36121 Mtetra
.765 .89 .933 r
.42702 .36121 .43369 .36501 .44502 .35829 .43841 .35414 Mtetra
.804 .881 .902 r
.43841 .35414 .44502 .35829 .45641 .35028 .44986 .34565 Mtetra
.827 .866 .875 r
.44986 .34565 .45641 .35028 .46784 .34118 .46135 .33594 Mtetra
.838 .848 .852 r
.46135 .33594 .46784 .34118 .47929 .33123 .47286 .3253 Mtetra
.841 .828 .835 r
.47286 .3253 .47929 .33123 .49075 .32071 .48438 .31402 Mtetra
.838 .809 .822 r
.48438 .31402 .49075 .32071 .50221 .30992 .49589 .30246 Mtetra
.829 .79 .815 r
.49589 .30246 .50221 .30992 .51367 .29917 .5074 .29094 Mtetra
.815 .771 .811 r
.5074 .29094 .51367 .29917 .52513 .28876 .5189 .27981 Mtetra
.798 .752 .811 r
.5189 .27981 .52513 .28876 .53659 .27899 .5304 .26939 Mtetra
.775 .733 .813 r
.5304 .26939 .53659 .27899 .54806 .27009 .5419 .25994 Mtetra
.748 .713 .819 r
.5419 .25994 .54806 .27009 .55956 .26229 .55342 .25171 Mtetra
.717 .693 .827 r
.55342 .25171 .55956 .26229 .57109 .25575 .56498 .24487 Mtetra
.679 .673 .836 r
.56498 .24487 .57109 .25575 .58268 .25057 .57659 .23954 Mtetra
.637 .651 .847 r
.57659 .23954 .58268 .25057 .59435 .2468 .58827 .23577 Mtetra
.589 .629 .859 r
.58827 .23577 .59435 .2468 .6061 .24443 .60005 .23356 Mtetra
.536 .606 .871 r
.60005 .23356 .6061 .24443 .61796 .2434 .61193 .23282 Mtetra
.478 .584 .882 r
.61193 .23282 .61796 .2434 .62993 .24355 .62394 .23341 Mtetra
.42 .563 .891 r
.62394 .23341 .62993 .24355 .64203 .24473 .63607 .23512 Mtetra
.363 .546 .9 r
.63607 .23512 .64203 .24473 .65426 .24668 .64834 .23771 Mtetra
.312 .535 .908 r
.64834 .23771 .65426 .24668 .6666 .24915 .66074 .24087 Mtetra
.273 .534 .916 r
.66074 .24087 .6666 .24915 .67907 .25184 .67326 .24427 Mtetra
.251 .545 .926 r
.67326 .24427 .67907 .25184 .69164 .25443 .68589 .24758 Mtetra
.25 .571 .94 r
.68589 .24758 .69164 .25443 .7043 .25662 .69862 .25044 Mtetra
.274 .612 .956 r
.69862 .25044 .7043 .25662 .71701 .2581 .71141 .25252 Mtetra
.324 .667 .975 r
.71141 .25252 .71701 .2581 .72977 .2586 .72424 .25352 Mtetra
.397 .73 .991 r
.72424 .25352 .72977 .2586 .74254 .25789 .73708 .25318 Mtetra
.485 .793 .999 r
.73708 .25318 .74254 .25789 .75529 .25581 .7499 .25131 Mtetra
.578 .846 .995 r
.7499 .25131 .75529 .25581 .768 .25223 .76267 .24779 Mtetra
.669 .89 .978 r
.0904 .47339 .09832 .47588 .1084 .47166 .10052 .46905 Mtetra
.751 .893 .942 r
.10052 .46905 .1084 .47166 .1187 .46586 .1109 .46296 Mtetra
.799 .879 .905 r
.1109 .46296 .1187 .46586 .12921 .4586 .1215 .45525 Mtetra
.826 .859 .871 r
.1215 .45525 .12921 .4586 .13988 .45004 .13228 .4461 Mtetra
.839 .838 .845 r
.13228 .4461 .13988 .45004 .15068 .44043 .14321 .43579 Mtetra
.842 .816 .824 r
.14321 .43579 .15068 .44043 .16157 .43006 .15423 .42463 Mtetra
.84 .796 .809 r
.15423 .42463 .16157 .43006 .17251 .41923 .1653 .41297 Mtetra
.833 .778 .8 r
.1653 .41297 .17251 .41923 .18345 .40829 .17637 .40119 Mtetra
.822 .76 .794 r
.17637 .40119 .18345 .40829 .19436 .39756 .18741 .38964 Mtetra
.807 .743 .793 r
.18741 .38964 .19436 .39756 .20522 .38736 .19837 .3787 Mtetra
.788 .726 .795 r
.19837 .3787 .20522 .38736 .216 .37799 .20924 .36868 Mtetra
.765 .709 .8 r
.20924 .36868 .216 .37799 .22667 .3697 .21999 .35985 Mtetra
.736 .692 .808 r
.21999 .35985 .22667 .3697 .23725 .36269 .23062 .35245 Mtetra
.701 .673 .82 r
.23062 .35245 .23725 .36269 .24771 .3571 .24112 .34663 Mtetra
.658 .653 .833 r
.24112 .34663 .24771 .3571 .25808 .35303 .25151 .34249 Mtetra
.606 .63 .849 r
.25151 .34249 .25808 .35303 .26836 .3505 .26179 .34005 Mtetra
.542 .604 .865 r
.26179 .34005 .26836 .3505 .27857 .34945 .27198 .33926 Mtetra
.466 .573 .879 r
.27198 .33926 .27857 .34945 .28874 .34978 .28212 .33999 Mtetra
.378 .539 .889 r
.28212 .33999 .28874 .34978 .29888 .35132 .29223 .34207 Mtetra
.282 .502 .892 r
.29223 .34207 .29888 .35132 .30904 .35384 .30234 .34524 Mtetra
.187 .467 .887 r
.30234 .34524 .30904 .35384 .31923 .35707 .31249 .34921 Mtetra
.104 .44 .878 r
.31249 .34921 .31923 .35707 .32949 .36071 .3227 .35363 Mtetra
.045 .43 .87 r
.3227 .35363 .32949 .36071 .33983 .36443 .333 .35815 Mtetra
.021 .443 .87 r
.333 .35815 .33983 .36443 .35028 .36788 .34342 .36237 Mtetra
.038 .484 .883 r
.34342 .36237 .35028 .36788 .36086 .37073 .35397 .36593 Mtetra
.101 .553 .912 r
.35397 .36593 .36086 .37073 .37156 .37267 .36467 .36848 Mtetra
.206 .643 .949 r
.36467 .36848 .37156 .37267 .38241 .37342 .37551 .36972 Mtetra
.341 .74 .983 r
.37551 .36972 .38241 .37342 .39338 .37277 .38651 .36941 Mtetra
.484 .823 .999 r
.38651 .36941 .39338 .37277 .40449 .37056 .39764 .36736 Mtetra
.611 .878 .991 r
.39764 .36736 .40449 .37056 .4157 .36671 .4089 .36348 Mtetra
.709 .902 .965 r
.4089 .36348 .4157 .36671 .42702 .36121 .42027 .35777 Mtetra
.775 .904 .931 r
.42027 .35777 .42702 .36121 .43841 .35414 .43172 .35031 Mtetra
.817 .892 .897 r
.43172 .35031 .43841 .35414 .44986 .34565 .44324 .34127 Mtetra
.841 .874 .867 r
.44324 .34127 .44986 .34565 .46135 .33594 .45479 .33089 Mtetra
.852 .853 .843 r
.45479 .33089 .46135 .33594 .47286 .3253 .46637 .31947 Mtetra
.854 .832 .825 r
.46637 .31947 .47286 .3253 .48438 .31402 .47795 .30736 Mtetra
.849 .811 .812 r
.47795 .30736 .48438 .31402 .49589 .30246 .48953 .29493 Mtetra
.839 .79 .804 r
.48953 .29493 .49589 .30246 .5074 .29094 .50109 .28256 Mtetra
.825 .77 .801 r
.50109 .28256 .5074 .29094 .5189 .27981 .51263 .27063 Mtetra
.806 .749 .801 r
.51263 .27063 .5189 .27981 .5304 .26939 .52417 .25948 Mtetra
.782 .729 .804 r
.52417 .25948 .5304 .26939 .5419 .25994 .5357 .24942 Mtetra
.753 .709 .81 r
.5357 .24942 .5419 .25994 .55342 .25171 .54725 .24071 Mtetra
.72 .687 .818 r
.54725 .24071 .55342 .25171 .56498 .24487 .55883 .23354 Mtetra
.68 .665 .829 r
.55883 .23354 .56498 .24487 .57659 .23954 .57046 .22805 Mtetra
.634 .642 .84 r
.57046 .22805 .57659 .23954 .58827 .23577 .58216 .22429 Mtetra
.582 .617 .852 r
.58216 .22429 .58827 .23577 .60005 .23356 .59396 .22226 Mtetra
.523 .591 .864 r
.59396 .22226 .60005 .23356 .61193 .23282 .60586 .22185 Mtetra
.459 .565 .875 r
.60586 .22185 .61193 .23282 .62394 .23341 .61789 .22292 Mtetra
.393 .54 .884 r
.61789 .22292 .62394 .23341 .63607 .23512 .63006 .22524 Mtetra
.327 .519 .891 r
.63006 .22524 .63607 .23512 .64834 .23771 .64237 .22853 Mtetra
.268 .504 .897 r
.64237 .22853 .64834 .23771 .66074 .24087 .65482 .23247 Mtetra
.221 .499 .903 r
.65482 .23247 .66074 .24087 .67326 .24427 .6674 .23668 Mtetra
.192 .508 .911 r
.6674 .23668 .67326 .24427 .68589 .24758 .6801 .24079 Mtetra
.187 .534 .924 r
.6801 .24079 .68589 .24758 .69862 .25044 .6929 .24441 Mtetra
.211 .579 .943 r
.6929 .24441 .69862 .25044 .71141 .25252 .70577 .24717 Mtetra
.266 .642 .965 r
.70577 .24717 .71141 .25252 .72424 .25352 .71868 .24873 Mtetra
.35 .715 .986 r
.71868 .24873 .72424 .25352 .73708 .25318 .73159 .24881 Mtetra
.452 .79 .999 r
.73159 .24881 .73708 .25318 .7499 .25131 .74448 .24718 Mtetra
.56 .853 .997 r
.74448 .24718 .7499 .25131 .76267 .24779 .75731 .24372 Mtetra
.666 .903 .979 r
.08234 .47131 .0904 .47339 .10052 .46905 .09251 .46685 Mtetra
.76 .907 .941 r
.09251 .46685 .10052 .46905 .1109 .46296 .10296 .46045 Mtetra
.812 .89 .9 r
.10296 .46045 .1109 .46296 .1215 .45525 .11367 .45223 Mtetra
.839 .866 .864 r
.11367 .45223 .1215 .45525 .13228 .4461 .12458 .44242 Mtetra
.851 .842 .836 r
.12458 .44242 .13228 .4461 .14321 .43579 .13564 .43132 Mtetra
.853 .819 .814 r
.13564 .43132 .14321 .43579 .15423 .42463 .14681 .41928 Mtetra
.85 .797 .799 r
.14681 .41928 .15423 .42463 .1653 .41297 .15803 .40669 Mtetra
.842 .777 .789 r
.15803 .40669 .1653 .41297 .17637 .40119 .16925 .39397 Mtetra
.83 .758 .784 r
.16925 .39397 .17637 .40119 .18741 .38964 .18042 .38153 Mtetra
.814 .74 .783 r
.18042 .38153 .18741 .38964 .19837 .3787 .1915 .36976 Mtetra
.794 .723 .785 r
.1915 .36976 .19837 .3787 .20924 .36868 .20247 .35901 Mtetra
.77 .705 .79 r
.20247 .35901 .20924 .36868 .21999 .35985 .21331 .34959 Mtetra
.74 .686 .799 r
.21331 .34959 .21999 .35985 .23062 .35245 .224 .34176 Mtetra
.703 .666 .811 r
.224 .34176 .23062 .35245 .24112 .34663 .23454 .33568 Mtetra
.657 .644 .825 r
.23454 .33568 .24112 .34663 .25151 .34249 .24494 .33146 Mtetra
.601 .619 .841 r
.24494 .33146 .25151 .34249 .26179 .34005 .25521 .32913 Mtetra
.53 .588 .858 r
.25521 .32913 .26179 .34005 .27198 .33926 .26539 .32862 Mtetra
.444 .552 .871 r
.26539 .32862 .27198 .33926 .28212 .33999 .27549 .32982 Mtetra
.343 .51 .878 r
.27549 .32982 .28212 .33999 .29223 .34207 .28555 .3325 Mtetra
.231 .463 .876 r
.28555 .3325 .29223 .34207 .30234 .34524 .29561 .3364 Mtetra
.118 .418 .864 r
.29561 .3364 .30234 .34524 .31249 .34921 .3057 .34119 Mtetra
.019 .381 .844 r
.3057 .34119 .31249 .34921 .3227 .35363 .31586 .34649 Mtetra
0 .362 .825 r
.31586 .34649 .3227 .35363 .333 .35815 .32611 .35189 Mtetra
0 .371 .818 r
.32611 .35189 .333 .35815 .34342 .36237 .33649 .35699 Mtetra
0 .413 .83 r
.33649 .35699 .34342 .36237 .35397 .36593 .34701 .36135 Mtetra
0 .49 .863 r
.34701 .36135 .35397 .36593 .36467 .36848 .35769 .3646 Mtetra
.116 .596 .913 r
.35769 .3646 .36467 .36848 .37551 .36972 .36853 .36639 Mtetra
.274 .715 .963 r
.36853 .36639 .37551 .36972 .38651 .36941 .37955 .36644 Mtetra
.445 .819 .992 r
.37955 .36644 .38651 .36941 .39764 .36736 .39071 .36457 Mtetra
.598 .888 .991 r
.39071 .36457 .39764 .36736 .4089 .36348 .40201 .36067 Mtetra
.711 .917 .964 r
.40201 .36067 .4089 .36348 .42027 .35777 .41344 .35472 Mtetra
.786 .918 .927 r
.41344 .35472 .42027 .35777 .43172 .35031 .42496 .34684 Mtetra
.831 .904 .89 r
.42496 .34684 .43172 .35031 .44324 .34127 .43654 .33719 Mtetra
.855 .882 .858 r
.43654 .33719 .44324 .34127 .45479 .33089 .44817 .32606 Mtetra
.865 .859 .832 r
.44817 .32606 .45479 .33089 .46637 .31947 .45982 .31378 Mtetra
.866 .835 .814 r
.45982 .31378 .46637 .31947 .47795 .30736 .47147 .30073 Mtetra
.861 .812 .801 r
.47147 .30073 .47795 .30736 .48953 .29493 .48311 .28734 Mtetra
.85 .79 .793 r
.48311 .28734 .48953 .29493 .50109 .28256 .49473 .27402 Mtetra
.834 .768 .79 r
.49473 .27402 .50109 .28256 .51263 .27063 .50632 .26119 Mtetra
.814 .747 .79 r
.50632 .26119 .51263 .27063 .52417 .25948 .5179 .24923 Mtetra
.789 .726 .794 r
.5179 .24923 .52417 .25948 .5357 .24942 .52947 .2385 Mtetra
.759 .704 .8 r
.52947 .2385 .5357 .24942 .54725 .24071 .54104 .22925 Mtetra
.723 .681 .809 r
.54104 .22925 .54725 .24071 .55883 .23354 .55264 .22173 Mtetra
.681 .657 .82 r
.55264 .22173 .55883 .23354 .57046 .22805 .56429 .21606 Mtetra
.631 .632 .832 r
.56429 .21606 .57046 .22805 .58216 .22429 .57601 .21232 Mtetra
.574 .604 .845 r
.57601 .21232 .58216 .22429 .59396 .22226 .58782 .21048 Mtetra
.51 .575 .857 r
.58782 .21048 .59396 .22226 .60586 .22185 .59974 .21045 Mtetra
.438 .544 .867 r
.59974 .21045 .60586 .22185 .61789 .22292 .6118 .21206 Mtetra
.363 .514 .875 r
.6118 .21206 .61789 .22292 .63006 .22524 .624 .21506 Mtetra
.287 .488 .879 r
.624 .21506 .63006 .22524 .64237 .22853 .63635 .21914 Mtetra
.218 .467 .882 r
.63635 .21914 .64237 .22853 .65482 .23247 .64886 .22394 Mtetra
.161 .458 .885 r
.64886 .22394 .65482 .23247 .6674 .23668 .6615 .22906 Mtetra
.124 .464 .89 r
.6615 .22906 .6674 .23668 .6801 .24079 .67427 .23407 Mtetra
.115 .49 .902 r
.67427 .23407 .6801 .24079 .6929 .24441 .68714 .23854 Mtetra
.138 .538 .921 r
.68714 .23854 .6929 .24441 .70577 .24717 .70009 .24207 Mtetra
.198 .608 .947 r
.70009 .24207 .70577 .24717 .71868 .24873 .71308 .24426 Mtetra
.292 .694 .974 r
.71308 .24426 .71868 .24873 .73159 .24881 .72607 .24481 Mtetra
.411 .783 .994 r
.72607 .24481 .73159 .24881 .74448 .24718 .73904 .24347 Mtetra
.538 .859 .996 r
.73904 .24347 .74448 .24718 .75731 .24372 .75193 .24008 Mtetra
.661 .917 .977 r
.07413 .46972 .08234 .47131 .09251 .46685 .08435 .46512 Mtetra
.769 .921 .938 r
.08435 .46512 .09251 .46685 .10296 .46045 .09489 .45836 Mtetra
.825 .9 .894 r
.09489 .45836 .10296 .46045 .11367 .45223 .10571 .44958 Mtetra
.852 .873 .855 r
.10571 .44958 .11367 .45223 .12458 .44242 .11676 .43903 Mtetra
.863 .846 .826 r
.11676 .43903 .12458 .44242 .13564 .43132 .12798 .42705 Mtetra
.864 .82 .804 r
.12798 .42705 .13564 .43132 .14681 .41928 .13931 .41403 Mtetra
.859 .797 .789 r
.13931 .41403 .14681 .41928 .15803 .40669 .1507 .40041 Mtetra
.85 .776 .779 r
.1507 .40041 .15803 .40669 .16925 .39397 .16208 .38665 Mtetra
.837 .756 .773 r
.16208 .38665 .16925 .39397 .18042 .38153 .1734 .3732 Mtetra
.821 .737 .772 r
.1734 .3732 .18042 .38153 .1915 .36976 .18462 .36051 Mtetra
.8 .719 .775 r
.18462 .36051 .1915 .36976 .20247 .35901 .1957 .34895 Mtetra
.775 .7 .781 r
.1957 .34895 .20247 .35901 .21331 .34959 .20663 .33889 Mtetra
.744 .681 .79 r
.20663 .33889 .21331 .34959 .224 .34176 .21739 .33057 Mtetra
.705 .659 .802 r
.21739 .33057 .224 .34176 .23454 .33568 .22797 .32421 Mtetra
.656 .635 .817 r
.22797 .32421 .23454 .33568 .24494 .33146 .23838 .31991 Mtetra
.595 .606 .833 r
.23838 .31991 .24494 .33146 .25521 .32913 .24865 .3177 Mtetra
.517 .572 .85 r
.24865 .3177 .25521 .32913 .26539 .32862 .2588 .31751 Mtetra
.42 .529 .862 r
.2588 .31751 .26539 .32862 .27549 .32982 .26886 .31922 Mtetra
.303 .477 .866 r
.26886 .31922 .27549 .32982 .28555 .3325 .27886 .32258 Mtetra
.173 .419 .856 r
.27886 .32258 .28555 .3325 .29561 .3364 .28886 .32729 Mtetra
.04 .36 .832 r
.28886 .32729 .29561 .3364 .3057 .34119 .29888 .333 Mtetra
0 .31 .798 r
.29888 .333 .3057 .34119 .31586 .34649 .30896 .33928 Mtetra
0 .282 .766 r
.30896 .33928 .31586 .34649 .32611 .35189 .31916 .34569 Mtetra
0 .286 .749 r
.31916 .34569 .32611 .35189 .33649 .35699 .32948 .35175 Mtetra
0 .327 .757 r
.32948 .35175 .33649 .35699 .34701 .36135 .33996 .35701 Mtetra
0 .41 .794 r
.33996 .35701 .34701 .36135 .35769 .3646 .35062 .36104 Mtetra
.011 .532 .857 r
.35062 .36104 .35769 .3646 .36853 .36639 .36146 .36345 Mtetra
.192 .676 .928 r
.36146 .36345 .36853 .36639 .37955 .36644 .37249 .36393 Mtetra
.396 .809 .977 r
.37249 .36393 .37955 .36644 .39071 .36457 .38368 .36227 Mtetra
.579 .896 .986 r
.38368 .36227 .39071 .36457 .40201 .36067 .39503 .35834 Mtetra
.713 .932 .961 r
.39503 .35834 .40201 .36067 .41344 .35472 .40652 .35214 Mtetra
.797 .933 .922 r
.40652 .35214 .41344 .35472 .42496 .34684 .41811 .34377 Mtetra
.845 .915 .881 r
.41811 .34377 .42496 .34684 .43654 .33719 .42977 .33345 Mtetra
.869 .89 .847 r
.42977 .33345 .43654 .33719 .44817 .32606 .44148 .32147 Mtetra
.879 .864 .821 r
.44148 .32147 .44817 .32606 .45982 .31378 .45321 .30823 Mtetra
.879 .838 .801 r
.45321 .30823 .45982 .31378 .47147 .30073 .46494 .29414 Mtetra
.872 .813 .789 r
.46494 .29414 .47147 .30073 .48311 .28734 .47665 .27967 Mtetra
.86 .79 .781 r
.47665 .27967 .48311 .28734 .49473 .27402 .48833 .26529 Mtetra
.843 .767 .778 r
.48833 .26529 .49473 .27402 .50632 .26119 .49997 .25147 Mtetra
.822 .744 .779 r
.49997 .25147 .50632 .26119 .5179 .24923 .51159 .23862 Mtetra
.795 .722 .783 r
.51159 .23862 .5179 .24923 .52947 .2385 .5232 .22713 Mtetra
.764 .699 .79 r
.5232 .22713 .52947 .2385 .54104 .22925 .5348 .21731 Mtetra
.726 .675 .8 r
.5348 .21731 .54104 .22925 .55264 .22173 .54642 .20939 Mtetra
.681 .649 .811 r
.54642 .20939 .55264 .22173 .56429 .21606 .55808 .20353 Mtetra
.628 .621 .824 r
.55808 .20353 .56429 .21606 .57601 .21232 .56981 .1998 Mtetra
.566 .59 .837 r
.56981 .1998 .57601 .21232 .58782 .21048 .58164 .19818 Mtetra
.495 .557 .849 r
.58164 .19818 .58782 .21048 .59974 .21045 .59358 .19858 Mtetra
.415 .522 .858 r
.59358 .19858 .59974 .21045 .6118 .21206 .60567 .20079 Mtetra
.33 .486 .863 r
.60567 .20079 .6118 .21206 .624 .21506 .6179 .20454 Mtetra
.243 .452 .865 r
.6179 .20454 .624 .21506 .63635 .21914 .63029 .20951 Mtetra
.161 .425 .863 r
.63029 .20951 .63635 .21914 .64886 .22394 .64284 .21528 Mtetra
.094 .41 .861 r
.64284 .21528 .64886 .22394 .6615 .22906 .65555 .22142 Mtetra
.048 .412 .861 r
.65555 .22142 .6615 .22906 .67427 .23407 .66839 .22744 Mtetra
.032 .436 .87 r
.66839 .22744 .67427 .23407 .68714 .23854 .68134 .23287 Mtetra
.053 .486 .889 r
.68134 .23287 .68714 .23854 .70009 .24207 .69437 .23726 Mtetra
.116 .564 .918 r
.69437 .23726 .70009 .24207 .71308 .24426 .70745 .24017 Mtetra
.221 .663 .953 r
.70745 .24017 .71308 .24426 .72607 .24481 .72053 .24125 Mtetra
.359 .769 .981 r
.72053 .24125 .72607 .24481 .73904 .24347 .73357 .24023 Mtetra
.508 .861 .991 r
.73357 .24023 .73904 .24347 .75193 .24008 .74653 .23693 Mtetra
.653 .93 .972 r
.06575 .46866 .07413 .46972 .08435 .46512 .07604 .46392 Mtetra
.778 .935 .933 r
.07604 .46392 .08435 .46512 .09489 .45836 .08667 .45676 Mtetra
.838 .911 .886 r
.08667 .45676 .09489 .45836 .10571 .44958 .09762 .44735 Mtetra
.865 .88 .846 r
.09762 .44735 .10571 .44958 .11676 .43903 .10883 .43598 Mtetra
.875 .849 .815 r
.10883 .43598 .11676 .43903 .12798 .42705 .12022 .42301 Mtetra
.875 .822 .793 r
.12022 .42301 .12798 .42705 .13931 .41403 .13174 .4089 Mtetra
.869 .797 .777 r
.13174 .4089 .13931 .41403 .1507 .40041 .14331 .39412 Mtetra
.859 .775 .767 r
.14331 .39412 .1507 .40041 .16208 .38665 .15487 .3792 Mtetra
.845 .754 .762 r
.15487 .3792 .16208 .38665 .1734 .3732 .16636 .36464 Mtetra
.828 .734 .761 r
.16636 .36464 .1734 .3732 .18462 .36051 .17773 .35092 Mtetra
.806 .715 .764 r
.17773 .35092 .18462 .36051 .1957 .34895 .18894 .33847 Mtetra
.78 .695 .77 r
.18894 .33847 .1957 .34895 .20663 .33889 .19997 .32768 Mtetra
.747 .674 .78 r
.19997 .32768 .20663 .33889 .21739 .33057 .21079 .31884 Mtetra
.707 .652 .793 r
.21079 .31884 .21739 .33057 .22797 .32421 .22142 .31216 Mtetra
.655 .625 .808 r
.22142 .31216 .22797 .32421 .23838 .31991 .23185 .30777 Mtetra
.588 .593 .825 r
.23185 .30777 .23838 .31991 .24865 .3177 .24211 .3057 Mtetra
.502 .553 .841 r
.24211 .3057 .24865 .3177 .2588 .31751 .25222 .30588 Mtetra
.393 .503 .851 r
.25222 .30588 .2588 .31751 .26886 .31922 .26222 .30815 Mtetra
.259 .44 .85 r
.26222 .30815 .26886 .31922 .27886 .32258 .27216 .31226 Mtetra
.107 .367 .83 r
.27216 .31226 .27886 .32258 .28886 .32729 .28208 .31789 Mtetra
0 .292 .791 r
.28208 .31789 .28886 .32729 .29888 .333 .29202 .32462 Mtetra
0 .23 .74 r
.29202 .32462 .29888 .333 .30896 .33928 .30202 .332 Mtetra
0 .192 .692 r
.30202 .332 .30896 .33928 .31916 .34569 .31214 .33953 Mtetra
0 .19 .663 r
.31214 .33953 .31916 .34569 .32948 .35175 .3224 .34669 Mtetra
0 .23 .665 r
.3224 .34669 .32948 .35175 .33996 .35701 .33283 .35296 Mtetra
0 .316 .704 r
.33283 .35296 .33996 .35701 .35062 .36104 .34346 .35787 Mtetra
0 .451 .778 r
.34346 .35787 .35062 .36104 .36146 .36345 .35429 .36098 Mtetra
.094 .622 .872 r
.35429 .36098 .36146 .36345 .37249 .36393 .36532 .36194 Mtetra
.334 .788 .949 r
.36532 .36194 .37249 .36393 .38368 .36227 .37655 .36051 Mtetra
.554 .901 .976 r
.37655 .36051 .38368 .36227 .39503 .35834 .38795 .35655 Mtetra
.713 .947 .955 r
.38795 .35655 .39503 .35834 .40652 .35214 .3995 .35006 Mtetra
.808 .947 .914 r
.3995 .35006 .40652 .35214 .41811 .34377 .41116 .34116 Mtetra
.859 .926 .871 r
.41116 .34116 .41811 .34377 .42977 .33345 .42291 .33008 Mtetra
.884 .898 .835 r
.42291 .33008 .42977 .33345 .44148 .32147 .43471 .31717 Mtetra
.892 .868 .808 r
.43471 .31717 .44148 .32147 .45321 .30823 .44653 .30284 Mtetra
.891 .84 .788 r
.44653 .30284 .45321 .30823 .46494 .29414 .45835 .28759 Mtetra
.883 .814 .775 r
.45835 .28759 .46494 .29414 .47665 .27967 .47013 .27192 Mtetra
.87 .789 .768 r
.47013 .27192 .47665 .27967 .48833 .26529 .48188 .25637 Mtetra
.852 .765 .766 r
.48188 .25637 .48833 .26529 .49997 .25147 .49359 .24145 Mtetra
.829 .741 .767 r
.49359 .24145 .49997 .25147 .51159 .23862 .50525 .22762 Mtetra
.802 .718 .772 r
.50525 .22762 .51159 .23862 .5232 .22713 .51689 .21529 Mtetra
.769 .694 .78 r
.51689 .21529 .5232 .22713 .5348 .21731 .52852 .20482 Mtetra
.729 .668 .79 r
.52852 .20482 .5348 .21731 .54642 .20939 .54016 .19647 Mtetra
.681 .64 .802 r
.54016 .19647 .54642 .20939 .55808 .20353 .55184 .19039 Mtetra
.624 .61 .815 r
.55184 .19039 .55808 .20353 .56981 .1998 .56358 .18669 Mtetra
.557 .576 .828 r
.56358 .18669 .56981 .1998 .58164 .19818 .57542 .18532 Mtetra
.479 .538 .84 r
.57542 .18532 .58164 .19818 .59358 .19858 .58738 .18619 Mtetra
.39 .497 .847 r
.58738 .18619 .59358 .19858 .60567 .20079 .59949 .18907 Mtetra
.293 .454 .85 r
.59949 .18907 .60567 .20079 .6179 .20454 .61175 .19367 Mtetra
.193 .413 .847 r
.61175 .19367 .6179 .20454 .63029 .20951 .62418 .19963 Mtetra
.099 .378 .839 r
.62418 .19963 .63029 .20951 .64284 .21528 .63678 .20648 Mtetra
.019 .355 .829 r
.63678 .20648 .64284 .21528 .65555 .22142 .64955 .21375 Mtetra
0 .351 .823 r
.64955 .21375 .65555 .22142 .66839 .22744 .66246 .22091 Mtetra
0 .372 .827 r
.66246 .22091 .66839 .22744 .68134 .23287 .67549 .22742 Mtetra
0 .423 .844 r
.67549 .22742 .68134 .23287 .69437 .23726 .68861 .23278 Mtetra
.023 .507 .876 r
.68861 .23278 .69437 .23726 .70745 .24017 .70178 .2365 Mtetra
.138 .62 .919 r
.70178 .2365 .70745 .24017 .72053 .24125 .71495 .23818 Mtetra
.295 .746 .958 r
.71495 .23818 .72053 .24125 .73357 .24023 .72807 .23752 Mtetra
.471 .858 .977 r
.72807 .23752 .73357 .24023 .74653 .23693 .74111 .23432 Mtetra
.641 .94 .961 r
.0572 .46822 .06575 .46866 .07604 .46392 .06755 .46331 Mtetra
.786 .95 .926 r
.06755 .46331 .07604 .46392 .08667 .45676 .07829 .45571 Mtetra
.852 .922 .877 r
.07829 .45571 .08667 .45676 .09762 .44735 .08938 .4456 Mtetra
.878 .886 .835 r
.08938 .4456 .09762 .44735 .10883 .43598 .10076 .4333 Mtetra
.887 .852 .803 r
.10076 .4333 .10883 .43598 .12022 .42301 .11235 .41923 Mtetra
.885 .823 .781 r
.11235 .41923 .12022 .42301 .13174 .4089 .12408 .40389 Mtetra
.878 .796 .765 r
.12408 .40389 .13174 .4089 .14331 .39412 .13586 .38783 Mtetra
.867 .773 .756 r
.13586 .38783 .14331 .39412 .15487 .3792 .14762 .37162 Mtetra
.852 .751 .751 r
.14762 .37162 .15487 .3792 .16636 .36464 .1593 .35582 Mtetra
.834 .731 .75 r
.1593 .35582 .16636 .36464 .17773 .35092 .17083 .34096 Mtetra
.812 .711 .753 r
.17083 .34096 .17773 .35092 .18894 .33847 .18219 .32753 Mtetra
.785 .69 .76 r
.18219 .32753 .18894 .33847 .19997 .32768 .19332 .31594 Mtetra
.751 .668 .77 r
.19332 .31594 .19997 .32768 .21079 .31884 .20423 .30651 Mtetra
.708 .644 .783 r
.20423 .30651 .21079 .31884 .22142 .31216 .2149 .29949 Mtetra
.653 .615 .798 r
.2149 .29949 .22142 .31216 .23185 .30777 .22534 .29501 Mtetra
.581 .579 .815 r
.22534 .29501 .23185 .30777 .24211 .3057 .23558 .29309 Mtetra
.486 .533 .831 r
.23558 .29309 .24211 .3057 .25222 .30588 .24566 .29367 Mtetra
.363 .474 .839 r
.24566 .29367 .25222 .30588 .26222 .30815 .2556 .29657 Mtetra
.209 .398 .83 r
.2556 .29657 .26222 .30815 .27216 .31226 .26545 .30153 Mtetra
.033 .308 .797 r
.26545 .30153 .27216 .31226 .28208 .31789 .27528 .30816 Mtetra
0 .216 .739 r
.27528 .30816 .28208 .31789 .29202 .32462 .28512 .31604 Mtetra
0 .14 .667 r
.28512 .31604 .29202 .32462 .30202 .332 .29503 .32465 Mtetra
0 .095 .603 r
.29503 .32465 .30202 .332 .31214 .33953 .30505 .33343 Mtetra
0 .088 .563 r
.30505 .33343 .31214 .33953 .3224 .34669 .31524 .34182 Mtetra
.427 0 0 r
.31524 .34182 .3224 .34669 .33283 .35296 .32561 .34923 Mtetra
.363 0 0 r
.32561 .34923 .33283 .35296 .34346 .35787 .3362 .35513 Mtetra
0 .354 .677 r
.3362 .35513 .34346 .35787 .35429 .36098 .34701 .35902 Mtetra
0 .548 .793 r
.34701 .35902 .35429 .36098 .36532 .36194 .35805 .36053 Mtetra
.256 .753 .903 r
.35805 .36053 .36532 .36194 .37655 .36051 .36931 .35936 Mtetra
.521 .901 .956 r
.36931 .35936 .37655 .36051 .38795 .35655 .38076 .35538 Mtetra
.71 .961 .944 r
.38076 .35538 .38795 .35655 .3995 .35006 .39238 .34857 Mtetra
.819 .961 .903 r
.39238 .34857 .3995 .35006 .41116 .34116 .40413 .33907 Mtetra
.874 .936 .858 r
.40413 .33907 .41116 .34116 .42291 .33008 .41597 .32715 Mtetra
.898 .904 .821 r
.41597 .32715 .42291 .33008 .43471 .31717 .42787 .31318 Mtetra
.906 .872 .793 r
.42787 .31318 .43471 .31717 .44653 .30284 .43979 .29765 Mtetra
.903 .842 .774 r
.43979 .29765 .44653 .30284 .45835 .28759 .4517 .2811 Mtetra
.894 .814 .762 r
.4517 .2811 .45835 .28759 .47013 .27192 .46357 .2641 Mtetra
.88 .787 .755 r
.46357 .2641 .47013 .27192 .48188 .25637 .47539 .24725 Mtetra
.861 .763 .753 r
.47539 .24725 .48188 .25637 .49359 .24145 .48716 .2311 Mtetra
.837 .738 .755 r
.48716 .2311 .49359 .24145 .50525 .22762 .49888 .21617 Mtetra
.808 .714 .76 r
.49888 .21617 .50525 .22762 .51689 .21529 .51056 .20293 Mtetra
.774 .688 .769 r
.51056 .20293 .51689 .21529 .52852 .20482 .52222 .19175 Mtetra
.732 .661 .78 r
.52222 .19175 .52852 .20482 .54016 .19647 .53388 .18291 Mtetra
.682 .631 .792 r
.53388 .18291 .54016 .19647 .55184 .19039 .54557 .17661 Mtetra
.621 .598 .806 r
.54557 .17661 .55184 .19039 .56358 .18669 .55732 .17293 Mtetra
.547 .56 .819 r
.55732 .17293 .56358 .18669 .57542 .18532 .56917 .17184 Mtetra
.461 .517 .83 r
.56917 .17184 .57542 .18532 .58738 .18619 .58114 .17323 Mtetra
.362 .47 .835 r
.58114 .17323 .58738 .18619 .59949 .18907 .59326 .17686 Mtetra
.252 .419 .834 r
.59326 .17686 .59949 .18907 .61175 .19367 .60555 .18241 Mtetra
.138 .368 .825 r
.60555 .18241 .61175 .19367 .62418 .19963 .61802 .18946 Mtetra
.03 .324 .809 r
.61802 .18946 .62418 .19963 .63678 .20648 .63067 .19753 Mtetra
0 .293 .79 r
.63067 .19753 .63678 .20648 .64955 .21375 .6435 .20607 Mtetra
0 .282 .775 r
.6435 .20607 .64955 .21375 .66246 .22091 .65649 .2145 Mtetra
0 .299 .771 r
.65649 .2145 .66246 .22091 .67549 .22742 .66961 .22223 Mtetra
0 .349 .784 r
.66961 .22223 .67549 .22742 .68861 .23278 .68282 .22867 Mtetra
0 .437 .817 r
.68282 .22867 .68861 .23278 .70178 .2365 .69608 .2333 Mtetra
.041 .563 .867 r
.69608 .2333 .70178 .2365 .71495 .23818 .70934 .23567 Mtetra
.218 .71 .92 r
.70934 .23567 .71495 .23818 .72807 .23752 .72255 .23542 Mtetra
.423 .847 .953 r
.72255 .23542 .72807 .23752 .74111 .23432 .73566 .23234 Mtetra
.624 .947 .944 r
.04846 .46846 .0572 .46822 .06755 .46331 .05887 .46337 Mtetra
.794 .964 .916 r
.05887 .46337 .06755 .46331 .07829 .45571 .06973 .45527 Mtetra
.865 .932 .866 r
.06973 .45527 .07829 .45571 .08938 .4456 .08098 .44438 Mtetra
.892 .892 .823 r
.08098 .44438 .08938 .4456 .10076 .4333 .09256 .43105 Mtetra
.898 .855 .791 r
.09256 .43105 .10076 .4333 .11235 .41923 .10437 .41575 Mtetra
.895 .823 .768 r
.10437 .41575 .11235 .41923 .12408 .40389 .11633 .39904 Mtetra
.887 .796 .753 r
.11633 .39904 .12408 .40389 .13586 .38783 .12834 .38155 Mtetra
.875 .771 .744 r
.12834 .38155 .13586 .38783 .14762 .37162 .14033 .3639 Mtetra
.859 .749 .739 r
.14033 .3639 .14762 .37162 .1593 .35582 .15222 .34672 Mtetra
.841 .727 .739 r
.15222 .34672 .1593 .35582 .17083 .34096 .16394 .3306 Mtetra
.818 .706 .742 r
.16394 .3306 .17083 .34096 .18219 .32753 .17545 .31608 Mtetra
.789 .685 .749 r
.17545 .31608 .18219 .32753 .19332 .31594 .18671 .3036 Mtetra
.754 .662 .759 r
.18671 .3036 .19332 .31594 .20423 .30651 .1977 .29353 Mtetra
.71 .635 .772 r
.1977 .29353 .20423 .30651 .2149 .29949 .20842 .28613 Mtetra
.651 .604 .788 r
.20842 .28613 .2149 .29949 .22534 .29501 .21887 .28154 Mtetra
.573 .564 .805 r
.21887 .28154 .22534 .29501 .23558 .29309 .2291 .2798 Mtetra
.469 .512 .82 r
.2291 .2798 .23558 .29309 .24566 .29367 .23912 .28083 Mtetra
.33 .442 .824 r
.23912 .28083 .24566 .29367 .2556 .29657 .24898 .28444 Mtetra
.153 .35 .806 r
.24898 .28444 .2556 .29657 .26545 .30153 .25875 .29033 Mtetra
0 .242 .756 r
.25875 .29033 .26545 .30153 .27528 .30816 .26846 .29809 Mtetra
0 .133 .675 r
.26846 .29809 .27528 .30816 .28512 .31604 .27819 .30724 Mtetra
0 .046 .583 r
.27819 .30724 .28512 .31604 .29503 .32465 .28798 .31722 Mtetra
0 0 .503 r
.28798 .31722 .29503 .32465 .30505 .33343 .2979 .32742 Mtetra
.541 .015 0 r
.2979 .32742 .30505 .33343 .31524 .34182 .30799 .33718 Mtetra
.535 0 0 r
.30799 .33718 .31524 .34182 .32561 .34923 .31829 .34586 Mtetra
.476 0 0 r
.31829 .34586 .32561 .34923 .3362 .35513 .32882 .35287 Mtetra
.351 0 0 r
.32882 .35287 .3362 .35513 .34701 .35902 .33961 .35765 Mtetra
.137 0 0 r
.33961 .35765 .34701 .35902 .35805 .36053 .35065 .35977 Mtetra
.164 .699 .835 r
.35065 .35977 .35805 .36053 .36931 .35936 .36194 .35891 Mtetra
.478 .891 .923 r
.36194 .35891 .36931 .35936 .38076 .35538 .37345 .3549 Mtetra
.704 .972 .927 r
.37345 .3549 .38076 .35538 .39238 .34857 .38514 .34774 Mtetra
.828 .974 .888 r
.38514 .34774 .39238 .34857 .40413 .33907 .39699 .33757 Mtetra
.888 .946 .843 r
.39699 .33757 .40413 .33907 .41597 .32715 .40893 .3247 Mtetra
.912 .91 .805 r
.40893 .3247 .41597 .32715 .42787 .31318 .42094 .30956 Mtetra
.919 .875 .778 r
.42094 .30956 .42787 .31318 .43979 .29765 .43297 .29269 Mtetra
.915 .842 .759 r
.43297 .29269 .43979 .29765 .4517 .2811 .44498 .27469 Mtetra
.904 .813 .747 r
.44498 .27469 .4517 .2811 .46357 .2641 .45695 .25621 Mtetra
.889 .786 .741 r
.45695 .25621 .46357 .2641 .47539 .24725 .46886 .2379 Mtetra
.869 .76 .74 r
.46886 .2379 .47539 .24725 .48716 .2311 .4807 .22039 Mtetra
.845 .735 .742 r
.4807 .22039 .48716 .2311 .49888 .21617 .49248 .20425 Mtetra
.815 .709 .748 r
.49248 .20425 .49888 .21617 .51056 .20293 .5042 .18999 Mtetra
.779 .682 .758 r
.5042 .18999 .51056 .20293 .52222 .19175 .51589 .17802 Mtetra
.735 .654 .769 r
.51589 .17802 .52222 .19175 .53388 .18291 .52756 .16866 Mtetra
.681 .622 .782 r
.52756 .16866 .53388 .18291 .54557 .17661 .53927 .16211 Mtetra
.616 .585 .796 r
.53927 .16211 .54557 .17661 .55732 .17293 .55103 .15846 Mtetra
.537 .543 .809 r
.55103 .15846 .55732 .17293 .56917 .17184 .56288 .15769 Mtetra
.442 .495 .818 r
.56288 .15769 .56917 .17184 .58114 .17323 .57486 .15966 Mtetra
.331 .44 .822 r
.57486 .15966 .58114 .17323 .59326 .17686 .587 .16413 Mtetra
.208 .38 .815 r
.587 .16413 .59326 .17686 .60555 .18241 .59931 .17072 Mtetra
.079 .319 .798 r
.59931 .17072 .60555 .18241 .61802 .18946 .61181 .179 Mtetra
0 .264 .772 r
.61181 .179 .61802 .18946 .63067 .19753 .62451 .18843 Mtetra
0 .224 .742 r
.62451 .18843 .63067 .19753 .6435 .20607 .6374 .19839 Mtetra
0 .206 .716 r
.6374 .19839 .6435 .20607 .65649 .2145 .65047 .20824 Mtetra
0 .217 .702 r
.65047 .20824 .65649 .2145 .66961 .22223 .66367 .21733 Mtetra
0 .265 .709 r
.66367 .21733 .66961 .22223 .68282 .22867 .67698 .22499 Mtetra
0 .355 .74 r
.67698 .22499 .68282 .22867 .69608 .2333 .69034 .23065 Mtetra
0 .49 .796 r
.69034 .23065 .69608 .2333 .70934 .23567 .7037 .23378 Mtetra
.126 .659 .863 r
.7037 .23378 .70934 .23567 .72255 .23542 .71701 .23401 Mtetra
.362 .825 .913 r
.71701 .23401 .72255 .23542 .73566 .23234 .7302 .23106 Mtetra
.599 .947 .916 r
.03949 .46948 .04846 .46846 .05887 .46337 .04998 .4642 Mtetra
.801 .977 .903 r
.04998 .4642 .05887 .46337 .06973 .45527 .06097 .45554 Mtetra
.878 .941 .853 r
.06097 .45554 .06973 .45527 .08098 .44438 .07241 .44377 Mtetra
.904 .897 .809 r
.07241 .44377 .08098 .44438 .09256 .43105 .0842 .42927 Mtetra
.91 .857 .777 r
.0842 .42927 .09256 .43105 .10437 .41575 .09626 .4126 Mtetra
.905 .823 .755 r
.09626 .4126 .10437 .41575 .11633 .39904 .10848 .39437 Mtetra
.895 .794 .741 r
.10848 .39437 .11633 .39904 .12834 .38155 .12076 .37528 Mtetra
.882 .769 .732 r
.12076 .37528 .12834 .38155 .14033 .3639 .13301 .35602 Mtetra
.866 .746 .728 r
.13301 .35602 .14033 .3639 .15222 .34672 .14513 .33731 Mtetra
.847 .724 .728 r
.14513 .33731 .15222 .34672 .16394 .3306 .15706 .3198 Mtetra
.823 .702 .731 r
.15706 .3198 .16394 .3306 .17545 .31608 .16874 .30407 Mtetra
.794 .68 .738 r
.16874 .30407 .17545 .31608 .18671 .3036 .18013 .29061 Mtetra
.758 .655 .748 r
.18013 .29061 .18671 .3036 .1977 .29353 .19122 .27984 Mtetra
.711 .627 .762 r
.19122 .27984 .1977 .29353 .20842 .28613 .20199 .27202 Mtetra
.649 .593 .778 r
.20199 .27202 .20842 .28613 .21887 .28154 .21246 .26732 Mtetra
.565 .549 .795 r
.21246 .26732 .21887 .28154 .2291 .2798 .22266 .26578 Mtetra
.45 .489 .808 r
.22266 .26578 .2291 .2798 .23912 .28083 .23262 .26731 Mtetra
.293 .406 .807 r
.23262 .26731 .23912 .28083 .24898 .28444 .24239 .27169 Mtetra
.092 .297 .777 r
.24239 .27169 .24898 .28444 .25875 .29033 .25205 .27862 Mtetra
0 .169 .707 r
.25205 .27862 .25875 .29033 .26846 .29809 .26163 .28764 Mtetra
0 .044 .602 r
.26163 .28764 .26846 .29809 .27819 .30724 .27123 .29821 Mtetra
0 0 .49 r
.27123 .29821 .27819 .30724 .28798 .31722 .28089 .30972 Mtetra
.595 .102 0 r
.28089 .30972 .28798 .31722 .2979 .32742 .29068 .32149 Mtetra
.634 .112 0 r
.29068 .32149 .2979 .32742 .30799 .33718 .30065 .33279 Mtetra
.627 .079 0 r
.30065 .33279 .30799 .33718 .31829 .34586 .31086 .34291 Mtetra
.573 .001 0 r
.31086 .34291 .31829 .34586 .32882 .35287 .32133 .35117 Mtetra
.459 0 0 r
.32133 .35117 .32882 .35287 .33961 .35765 .33208 .35695 Mtetra
.255 0 0 r
.33208 .35695 .33961 .35765 .35065 .35977 .34312 .35976 Mtetra
.061 .626 .743 r
.34312 .35976 .35065 .35977 .36194 .35891 .35444 .35925 Mtetra
.422 .867 .874 r
.35444 .35925 .36194 .35891 .37345 .3549 .366 .35521 Mtetra
.693 .978 .902 r
.366 .35521 .37345 .3549 .38514 .34774 .37778 .34765 Mtetra
.837 .986 .869 r
.37778 .34765 .38514 .34774 .39699 .33757 .38973 .33674 Mtetra
.901 .954 .824 r
.38973 .33674 .39699 .33757 .40893 .3247 .40179 .32281 Mtetra
.926 .915 .787 r
.40179 .32281 .40893 .3247 .42094 .30956 .41393 .30635 Mtetra
.931 .877 .761 r
.41393 .30635 .42094 .30956 .43297 .29269 .42608 .28797 Mtetra
.926 .843 .743 r
.42608 .28797 .43297 .29269 .44498 .27469 .43821 .26836 Mtetra
.914 .812 .732 r
.43821 .26836 .44498 .27469 .45695 .25621 .45029 .24823 Mtetra
.898 .784 .727 r
.45029 .24823 .45695 .25621 .46886 .2379 .46229 .2283 Mtetra
.877 .757 .726 r
.46229 .2283 .46886 .2379 .4807 .22039 .47421 .20928 Mtetra
.852 .731 .729 r
.47421 .20928 .4807 .22039 .49248 .20425 .48605 .19181 Mtetra
.821 .704 .736 r
.48605 .19181 .49248 .20425 .5042 .18999 .49782 .17642 Mtetra
.783 .676 .746 r
.49782 .17642 .5042 .18999 .51589 .17802 .50953 .16359 Mtetra
.738 .646 .758 r
.50953 .16359 .51589 .17802 .52756 .16866 .52123 .15365 Mtetra
.681 .612 .772 r
.52123 .15365 .52756 .16866 .53927 .16211 .53294 .14682 Mtetra
.612 .572 .786 r
.53294 .14682 .53927 .16211 .55103 .15846 .54471 .14321 Mtetra
.526 .526 .798 r
.54471 .14321 .55103 .15846 .56288 .15769 .55656 .14279 Mtetra
.421 .471 .806 r
.55656 .14279 .56288 .15769 .57486 .15966 .56855 .14542 Mtetra
.298 .408 .806 r
.56855 .14542 .57486 .15966 .587 .16413 .58069 .15081 Mtetra
.159 .337 .793 r
.58069 .15081 .587 .16413 .59931 .17072 .59302 .15857 Mtetra
.015 .265 .767 r
.59302 .15857 .59931 .17072 .61181 .179 .60556 .16822 Mtetra
0 .199 .729 r
.60556 .16822 .61181 .179 .62451 .18843 .6183 .17915 Mtetra
0 .15 .686 r
.6183 .17915 .62451 .18843 .6374 .19839 .63126 .1907 Mtetra
0 .124 .647 r
.63126 .1907 .6374 .19839 .65047 .20824 .6444 .20215 Mtetra
0 .13 .623 r
.6444 .20215 .65047 .20824 .66367 .21733 .65769 .21275 Mtetra
0 .174 .62 r
.65769 .21275 .66367 .21733 .67698 .22499 .6711 .2218 Mtetra
0 .263 .647 r
.6711 .2218 .67698 .22499 .69034 .23065 .68457 .22861 Mtetra
0 .404 .705 r
.68457 .22861 .69034 .23065 .7037 .23378 .69803 .23262 Mtetra
.023 .59 .784 r
.69803 .23262 .7037 .23378 .71701 .23401 .71144 .23337 Mtetra
.287 .786 .854 r
.71144 .23337 .71701 .23401 .7302 .23106 .72472 .23059 Mtetra
.566 .938 .876 r
.03029 .47139 .03949 .46948 .04998 .4642 .04086 .46588 Mtetra
.806 .988 .884 r
.04086 .46588 .04998 .4642 .06097 .45554 .052 .4566 Mtetra
.891 .949 .838 r
.052 .4566 .06097 .45554 .07241 .44377 .06364 .44384 Mtetra
.917 .901 .795 r
.06364 .44384 .07241 .44377 .0842 .42927 .07568 .42805 Mtetra
.92 .858 .763 r
.07568 .42805 .0842 .42927 .09626 .4126 .08802 .40983 Mtetra
.914 .823 .742 r
.08802 .40983 .09626 .4126 .10848 .39437 .10053 .3899 Mtetra
.903 .793 .728 r
.10053 .3899 .10848 .39437 .12076 .37528 .11311 .36902 Mtetra
.889 .766 .72 r
.11311 .36902 .12076 .37528 .13301 .35602 .12564 .34799 Mtetra
.872 .742 .716 r
.12564 .34799 .13301 .35602 .14513 .33731 .13803 .32758 Mtetra
.852 .72 .716 r
.13803 .32758 .14513 .33731 .15706 .3198 .15019 .30851 Mtetra
.828 .697 .72 r
.15019 .30851 .15706 .3198 .16874 .30407 .16207 .29144 Mtetra
.798 .674 .727 r
.16207 .29144 .16874 .30407 .18013 .29061 .17361 .27691 Mtetra
.761 .648 .738 r
.17361 .27691 .18013 .29061 .19122 .27984 .1848 .26536 Mtetra
.712 .618 .751 r
.1848 .26536 .19122 .27984 .20199 .27202 .19563 .25708 Mtetra
.647 .581 .767 r
.19563 .25708 .20199 .27202 .21246 .26732 .20611 .25226 Mtetra
.556 .532 .784 r
.20611 .25226 .21246 .26732 .22266 .26578 .21627 .25094 Mtetra
.43 .464 .794 r
.21627 .25094 .22266 .26578 .23262 .26731 .22616 .25302 Mtetra
.253 .368 .787 r
.22616 .25302 .23262 .26731 .24239 .27169 .23584 .25828 Mtetra
.025 .239 .743 r
.23584 .25828 .24239 .27169 .25205 .27862 .24536 .26635 Mtetra
0 .09 .648 r
.24536 .26635 .25205 .27862 .26163 .28764 .2548 .27677 Mtetra
0 0 .52 r
.2548 .27677 .26163 .28764 .27123 .29821 .26423 .28892 Mtetra
.595 .143 0 r
.26423 .28892 .27123 .29821 .28089 .30972 .27374 .30214 Mtetra
.679 .192 0 r
.27374 .30214 .28089 .30972 .29068 .32149 .28338 .31566 Mtetra
.71 .199 0 r
.28338 .31566 .29068 .32149 .30065 .33279 .29322 .32869 Mtetra
.701 .168 0 r
.29322 .32869 .30065 .33279 .31086 .34291 .30332 .34042 Mtetra
.652 .095 0 r
.30332 .34042 .31086 .34291 .32133 .35117 .31371 .35009 Mtetra
.549 0 0 r
.31371 .35009 .32133 .35117 .33208 .35695 .32442 .357 Mtetra
.362 0 0 r
.32442 .357 .33208 .35695 .34312 .35976 .33545 .3606 Mtetra
.049 0 0 r
.33545 .3606 .34312 .35976 .35444 .35925 .34679 .36047 Mtetra
.353 .827 .805 r
.34679 .36047 .35444 .35925 .366 .35521 .35842 .35642 Mtetra
.675 .977 .867 r
.35842 .35642 .366 .35521 .37778 .34765 .37029 .34841 Mtetra
.842 .994 .845 r
.37029 .34841 .37778 .34765 .38973 .33674 .38235 .33666 Mtetra
.913 .961 .803 r
.38235 .33666 .38973 .33674 .40179 .32281 .39454 .32154 Mtetra
.938 .918 .768 r
.39454 .32154 .40179 .32281 .41393 .30635 .40681 .30361 Mtetra
.942 .878 .742 r
.40681 .30361 .41393 .30635 .42608 .28797 .4191 .28355 Mtetra
.936 .842 .726 r
.4191 .28355 .42608 .28797 .43821 .26836 .43137 .26213 Mtetra
.924 .81 .716 r
.43137 .26213 .43821 .26836 .45029 .24823 .44357 .24016 Mtetra
.906 .781 .712 r
.44357 .24016 .45029 .24823 .46229 .2283 .45568 .21844 Mtetra
.885 .754 .712 r
.45568 .21844 .46229 .2283 .47421 .20928 .46769 .19775 Mtetra
.858 .727 .716 r
.46769 .19775 .47421 .20928 .48605 .19181 .4796 .17879 Mtetra
.827 .699 .724 r
.4796 .17879 .48605 .19181 .49782 .17642 .49141 .16217 Mtetra
.788 .67 .734 r
.49141 .16217 .49782 .17642 .50953 .16359 .50316 .14839 Mtetra
.74 .638 .747 r
.50316 .14839 .50953 .16359 .52123 .15365 .51488 .13781 Mtetra
.681 .602 .761 r
.51488 .13781 .52123 .15365 .53294 .14682 .5266 .13068 Mtetra
.607 .559 .775 r
.5266 .13068 .53294 .14682 .54471 .14321 .53836 .12712 Mtetra
.514 .508 .787 r
.53836 .12712 .54471 .14321 .55656 .14279 .55021 .12709 Mtetra
.4 .446 .793 r
.55021 .12709 .55656 .14279 .56855 .14542 .5622 .13043 Mtetra
.263 .373 .788 r
.5622 .13043 .56855 .14542 .58069 .15081 .57434 .13685 Mtetra
.108 .291 .768 r
.57434 .13685 .58069 .15081 .59302 .15857 .58669 .14591 Mtetra
0 .207 .73 r
.58669 .14591 .59302 .15857 .60556 .16822 .59925 .15707 Mtetra
0 .131 .678 r
.59925 .15707 .60556 .16822 .6183 .17915 .61205 .16969 Mtetra
0 .072 .621 r
.61205 .16969 .6183 .17915 .63126 .1907 .62506 .18301 Mtetra
0 .041 .57 r
.62506 .18301 .63126 .1907 .6444 .20215 .63828 .19624 Mtetra
0 .042 .535 r
.63828 .19624 .6444 .20215 .65769 .21275 .65167 .20856 Mtetra
.465 0 0 r
.65167 .20856 .65769 .21275 .6711 .2218 .66518 .21916 Mtetra
.412 0 0 r
.66518 .21916 .6711 .2218 .68457 .22861 .67876 .22728 Mtetra
.292 0 0 r
.67876 .22728 .68457 .22861 .69803 .23262 .69233 .23227 Mtetra
.086 0 0 r
.69233 .23227 .69803 .23262 .71144 .23337 .70584 .23362 Mtetra
.2 .728 .773 r
.70584 .23362 .71144 .23337 .72472 .23059 .71922 .23102 Mtetra
.522 .917 .821 r
.02082 .47429 .03029 .47139 .04086 .46588 .03148 .46853 Mtetra
.809 .996 .861 r
.03148 .46853 .04086 .46588 .052 .4566 .04278 .45855 Mtetra
.903 .956 .82 r
.04278 .45855 .052 .4566 .06364 .44384 .05465 .44468 Mtetra
.928 .904 .779 r
.05465 .44468 .06364 .44384 .07568 .42805 .06697 .42744 Mtetra
.93 .859 .749 r
.06697 .42744 .07568 .42805 .08802 .40983 .07962 .4075 Mtetra
.923 .822 .728 r
.07962 .4075 .08802 .40983 .10053 .3899 .09247 .38566 Mtetra
.911 .791 .715 r
.09247 .38566 .10053 .3899 .11311 .36902 .10539 .36279 Mtetra
.896 .764 .708 r
.10539 .36279 .11311 .36902 .12564 .34799 .11824 .33977 Mtetra
.878 .739 .705 r
.11824 .33977 .12564 .34799 .13803 .32758 .13093 .31748 Mtetra
.857 .716 .705 r
.13093 .31748 .13803 .32758 .15019 .30851 .14335 .2967 Mtetra
.833 .693 .709 r
.14335 .2967 .15019 .30851 .16207 .29144 .15544 .27815 Mtetra
.802 .669 .716 r
.15544 .27815 .16207 .29144 .17361 .27691 .16715 .26243 Mtetra
.763 .642 .727 r
.16715 .26243 .17361 .27691 .1848 .26536 .17846 .25002 Mtetra
.713 .61 .74 r
.17846 .25002 .1848 .26536 .19563 .25708 .18934 .24124 Mtetra
.644 .569 .756 r
.18934 .24124 .19563 .25708 .20611 .25226 .19983 .23629 Mtetra
.547 .515 .772 r
.19983 .23629 .20611 .25226 .21627 .25094 .20996 .23521 Mtetra
.408 .437 .78 r
.20996 .23521 .21627 .25094 .22616 .25302 .21977 .23791 Mtetra
.21 .326 .764 r
.21977 .23791 .22616 .25302 .23584 .25828 .22932 .24413 Mtetra
0 .175 .702 r
.22932 .24413 .23584 .25828 .24536 .26635 .23869 .25348 Mtetra
0 .008 .582 r
.23869 .25348 .24536 .26635 .2548 .27677 .24797 .26544 Mtetra
0 0 .432 r
.24797 .26544 .2548 .27677 .26423 .28892 .25722 .27936 Mtetra
.677 .228 0 r
.25722 .27936 .26423 .28892 .27374 .30214 .26654 .29448 Mtetra
.747 .271 0 r
.26654 .29448 .27374 .30214 .28338 .31566 .276 .30997 Mtetra
.77 .275 0 r
.276 .30997 .28338 .31566 .29322 .32869 .28569 .32493 Mtetra
.758 .244 0 r
.28569 .32493 .29322 .32869 .30332 .34042 .29565 .33846 Mtetra
.712 .176 0 r
.29565 .33846 .30332 .34042 .31371 .35009 .30595 .34971 Mtetra
.621 .059 0 r
.30595 .34971 .31371 .35009 .32442 .357 .3166 .3579 Mtetra
.453 0 0 r
.3166 .3579 .32442 .357 .33545 .3606 .32762 .36239 Mtetra
.155 0 0 r
.32762 .36239 .33545 .3606 .34679 .36047 .33898 .36271 Mtetra
.273 .769 .715 r
.33898 .36271 .34679 .36047 .35842 .35642 .35068 .35863 Mtetra
.649 .967 .82 r
.35068 .35863 .35842 .35642 .37029 .34841 .36265 .35013 Mtetra
.845 .998 .815 r
.36265 .35013 .37029 .34841 .38235 .33666 .37483 .33743 Mtetra
.923 .965 .779 r
.37483 .33743 .38235 .33666 .39454 .32154 .38717 .32098 Mtetra
.949 .92 .746 r
.38717 .32098 .39454 .32154 .40681 .30361 .3996 .3014 Mtetra
.953 .878 .723 r
.3996 .3014 .40681 .30361 .4191 .28355 .41205 .27946 Mtetra
.946 .841 .708 r
.41205 .27946 .4191 .28355 .43137 .26213 .42446 .25603 Mtetra
.932 .808 .7 r
.42446 .25603 .43137 .26213 .44357 .24016 .4368 .232 Mtetra
.914 .778 .697 r
.4368 .232 .44357 .24016 .45568 .21844 .44903 .2083 Mtetra
.892 .75 .698 r
.44903 .2083 .45568 .21844 .46769 .19775 .46114 .18576 Mtetra
.865 .722 .703 r
.46114 .18576 .46769 .19775 .4796 .17879 .47312 .16516 Mtetra
.832 .694 .711 r
.47312 .16516 .4796 .17879 .49141 .16217 .48499 .14717 Mtetra
.792 .664 .722 r
.48499 .14717 .49141 .16217 .50316 .14839 .49678 .13233 Mtetra
.742 .63 .735 r
.49678 .13233 .50316 .14839 .51488 .13781 .50851 .12106 Mtetra
.68 .591 .749 r
.50851 .12106 .51488 .13781 .5266 .13068 .52024 .11361 Mtetra
.601 .545 .764 r
.52024 .11361 .5266 .13068 .53836 .12712 .532 .1101 Mtetra
.501 .488 .775 r
.532 .1101 .53836 .12712 .55021 .12709 .54384 .1105 Mtetra
.376 .419 .778 r
.54384 .1105 .55021 .12709 .5622 .13043 .55582 .11464 Mtetra
.225 .336 .768 r
.55582 .11464 .5622 .13043 .57434 .13685 .56796 .12219 Mtetra
.053 .242 .739 r
.56796 .12219 .57434 .13685 .58669 .14591 .58032 .13269 Mtetra
0 .146 .688 r
.58032 .13269 .58669 .14591 .59925 .15707 .59291 .14554 Mtetra
0 .059 .622 r
.59291 .14554 .59925 .15707 .61205 .16969 .60574 .16003 Mtetra
0 0 .551 r
.60574 .16003 .61205 .16969 .62506 .18301 .61881 .17533 Mtetra
0 0 .489 r
.61881 .17533 .62506 .18301 .63828 .19624 .63211 .19056 Mtetra
.553 .044 0 r
.63211 .19056 .63828 .19624 .65167 .20856 .64559 .2048 Mtetra
.556 .009 0 r
.64559 .2048 .65167 .20856 .66518 .21916 .65921 .21715 Mtetra
.508 0 0 r
.65921 .21715 .66518 .21916 .67876 .22728 .67291 .22673 Mtetra
.395 0 0 r
.67291 .22673 .67876 .22728 .69233 .23227 .68661 .23284 Mtetra
.193 0 0 r
.68661 .23284 .69233 .23227 .70584 .23362 .70023 .23488 Mtetra
0 0 0 r
.70023 .23488 .70584 .23362 .71922 .23102 .7137 .23249 Mtetra
.469 .881 .75 r
.01105 .47832 .02082 .47429 .03148 .46853 .02181 .47228 Mtetra
.808 1 .832 r
.02181 .47228 .03148 .46853 .04278 .45855 .0333 .46152 Mtetra
.914 .962 .801 r
.0333 .46152 .04278 .45855 .05465 .44468 .04542 .44641 Mtetra
.939 .906 .762 r
.04542 .44641 .05465 .44468 .06697 .42744 .05806 .42753 Mtetra
.939 .859 .734 r
.05806 .42753 .06697 .42744 .07962 .4075 .07107 .40565 Mtetra
.931 .82 .715 r
.07107 .40565 .07962 .4075 .09247 .38566 .0843 .38168 Mtetra
.918 .788 .703 r
.0843 .38168 .09247 .38566 .10539 .36279 .09759 .35659 Mtetra
.902 .761 .696 r
.09759 .35659 .10539 .36279 .11824 .33977 .11081 .33137 Mtetra
.884 .736 .693 r
.11081 .33137 .11824 .33977 .13093 .31748 .12383 .30698 Mtetra
.862 .712 .694 r
.12383 .30698 .13093 .31748 .14335 .2967 .13655 .2843 Mtetra
.837 .688 .698 r
.13655 .2843 .14335 .2967 .15544 .27815 .14888 .26412 Mtetra
.806 .663 .705 r
.14888 .26412 .15544 .27815 .16715 .26243 .16078 .24709 Mtetra
.766 .635 .716 r
.16078 .24709 .16715 .26243 .17846 .25002 .1722 .23374 Mtetra
.713 .601 .729 r
.1722 .23374 .17846 .25002 .18934 .24124 .18316 .22441 Mtetra
.641 .557 .745 r
.18316 .22441 .18934 .24124 .19983 .23629 .19365 .21932 Mtetra
.537 .497 .759 r
.19365 .21932 .19983 .23629 .20996 .23521 .20373 .21852 Mtetra
.384 .409 .763 r
.20373 .21852 .20996 .23521 .21977 .23791 .21345 .22189 Mtetra
.163 .28 .738 r
.21345 .22189 .21977 .23791 .22932 .24413 .22286 .22917 Mtetra
0 .108 .655 r
.22286 .22917 .22932 .24413 .23869 .25348 .23206 .23994 Mtetra
0 0 .51 r
.23206 .23994 .23869 .25348 .24797 .26544 .24114 .25361 Mtetra
.621 .22 0 r
.24114 .25361 .24797 .26544 .25722 .27936 .25018 .26949 Mtetra
.744 .304 0 r
.25018 .26949 .25722 .27936 .26654 .29448 .25928 .28673 Mtetra
.801 .339 0 r
.25928 .28673 .26654 .29448 .276 .30997 .26854 .30441 Mtetra
.815 .338 0 r
.26854 .30441 .276 .30997 .28569 .32493 .27804 .32154 Mtetra
.8 .307 0 r
.27804 .32154 .28569 .32493 .29565 .33846 .28785 .33711 Mtetra
.757 .244 0 r
.28785 .33711 .29565 .33846 .30595 .34971 .29803 .35014 Mtetra
.675 .138 0 r
.29803 .35014 .30595 .34971 .3166 .3579 .30861 .35977 Mtetra
.526 0 0 r
.30861 .35977 .3166 .3579 .32762 .36239 .3196 .36526 Mtetra
.251 0 0 r
.3196 .36526 .32762 .36239 .33898 .36271 .331 .3661 Mtetra
0 0 0 r
.331 .3661 .33898 .36271 .35068 .35863 .34276 .36199 Mtetra
.614 .945 .759 r
.34276 .36199 .35068 .35863 .36265 .35013 .35484 .35294 Mtetra
.844 .998 .778 r
.35484 .35294 .36265 .35013 .37483 .33743 .36717 .33918 Mtetra
.932 .967 .752 r
.36717 .33918 .37483 .33743 .38717 .32098 .37967 .32123 Mtetra
.959 .92 .724 r
.37967 .32123 .38717 .32098 .3996 .3014 .39227 .29979 Mtetra
.962 .877 .703 r
.39227 .29979 .3996 .3014 .41205 .27946 .4049 .27575 Mtetra
.954 .839 .69 r
.4049 .27575 .41205 .27946 .42446 .25603 .41748 .25006 Mtetra
.94 .805 .684 r
.41748 .25006 .42446 .25603 .4368 .232 .42998 .22376 Mtetra
.921 .775 .682 r
.42998 .22376 .4368 .232 .44903 .2083 .44234 .19784 Mtetra
.898 .746 .684 r
.44234 .19784 .44903 .2083 .46114 .18576 .45456 .17325 Mtetra
.871 .718 .69 r
.45456 .17325 .46114 .18576 .47312 .16516 .46663 .15084 Mtetra
.837 .689 .698 r
.46663 .15084 .47312 .16516 .48499 .14717 .47857 .13134 Mtetra
.796 .657 .71 r
.47857 .13134 .48499 .14717 .49678 .13233 .49039 .11536 Mtetra
.744 .622 .723 r
.49039 .11536 .49678 .13233 .50851 .12106 .50215 .10332 Mtetra
.679 .581 .738 r
.50215 .10332 .50851 .12106 .52024 .11361 .51387 .09551 Mtetra
.596 .531 .752 r
.51387 .09551 .52024 .11361 .532 .1101 .52562 .09207 Mtetra
.488 .468 .762 r
.52562 .09207 .532 .1101 .54384 .1105 .53745 .09295 Mtetra
.352 .391 .762 r
.53745 .09295 .54384 .1105 .55582 .11464 .54941 .09797 Mtetra
.185 .297 .746 r
.54941 .09797 .55582 .11464 .56796 .12219 .56155 .10678 Mtetra
0 .19 .706 r
.56155 .10678 .56796 .12219 .58032 .13269 .57391 .11887 Mtetra
0 .082 .642 r
.57391 .11887 .58032 .13269 .59291 .14554 .58651 .13359 Mtetra
0 0 .561 r
.58651 .13359 .59291 .14554 .60574 .16003 .59938 .15016 Mtetra
0 0 .478 r
.59938 .15016 .60574 .16003 .61881 .17533 .61251 .16767 Mtetra
.587 .121 0 r
.61251 .16767 .61881 .17533 .63211 .19056 .62588 .18514 Mtetra
.631 .125 0 r
.62588 .18514 .63211 .19056 .64559 .2048 .63946 .20154 Mtetra
.633 .092 0 r
.63946 .20154 .64559 .2048 .65921 .21715 .6532 .21584 Mtetra
.588 .018 0 r
.6532 .21584 .65921 .21715 .67291 .22673 .66702 .22709 Mtetra
.483 0 0 r
.66702 .22709 .67291 .22673 .68661 .23284 .68085 .23445 Mtetra
.292 0 0 r
.68085 .23445 .68661 .23284 .70023 .23488 .69459 .23727 Mtetra
0 0 0 r
.69459 .23727 .70023 .23488 .7137 .23249 .70817 .23513 Mtetra
.406 .83 .665 r
.00095 .48363 .01105 .47832 .02181 .47228 .01182 .47728 Mtetra
.803 .999 .797 r
.01182 .47728 .02181 .47228 .0333 .46152 .02351 .46564 Mtetra
.923 .965 .779 r
.02351 .46564 .0333 .46152 .04542 .44641 .03593 .44912 Mtetra
.949 .907 .745 r
.03593 .44912 .04542 .44641 .05806 .42753 .04893 .42841 Mtetra
.948 .858 .719 r
.04893 .42841 .05806 .42753 .07107 .40565 .06235 .40436 Mtetra
.938 .818 .701 r
.06235 .40436 .07107 .40565 .0843 .38168 .076 .378 Mtetra
.924 .786 .69 r
.076 .378 .0843 .38168 .09759 .35659 .08972 .35043 Mtetra
.907 .758 .684 r
.08972 .35043 .09759 .35659 .11081 .33137 .10335 .32276 Mtetra
.889 .732 .682 r
.10335 .32276 .11081 .33137 .12383 .30698 .11675 .29604 Mtetra
.867 .708 .683 r
.11675 .29604 .12383 .30698 .13655 .2843 .12979 .27126 Mtetra
.841 .683 .687 r
.12979 .27126 .13655 .2843 .14888 .26412 .14239 .24928 Mtetra
.809 .657 .695 r
.14239 .24928 .14888 .26412 .16078 .24709 .15449 .23082 Mtetra
.768 .628 .705 r
.15449 .23082 .16078 .24709 .1722 .23374 .16606 .21642 Mtetra
.714 .592 .718 r
.16606 .21642 .1722 .23374 .18316 .22441 .17709 .2065 Mtetra
.638 .545 .733 r
.17709 .2065 .18316 .22441 .19365 .21932 .18759 .20126 Mtetra
.527 .479 .746 r
.18759 .20126 .19365 .21932 .20373 .21852 .19761 .20076 Mtetra
.359 .38 .746 r
.19761 .20076 .20373 .21852 .21345 .22189 .20721 .20488 Mtetra
.114 .232 .709 r
.20721 .20488 .21345 .22189 .22286 .22917 .21647 .21333 Mtetra
0 .037 .603 r
.21647 .21333 .22286 .22917 .23206 .23994 .22547 .22566 Mtetra
0 0 .433 r
.22547 .22566 .23206 .23994 .24114 .25361 .23432 .24124 Mtetra
.694 .296 0 r
.23432 .24124 .24114 .25361 .25018 .26949 .24312 .25929 Mtetra
.799 .37 0 r
.24312 .25929 .25018 .26949 .25928 .28673 .25198 .27889 Mtetra
.842 .396 0 r
.25198 .27889 .25928 .28673 .26854 .30441 .261 .29902 Mtetra
.849 .391 .024 r
.261 .29902 .26854 .30441 .27804 .32154 .27028 .31858 Mtetra
.832 .36 .048 r
.27028 .31858 .27804 .32154 .28785 .33711 .27991 .33643 Mtetra
.79 .301 .044 r
.27991 .33643 .28785 .33711 .29803 .35014 .28994 .35148 Mtetra
.716 .203 .005 r
.28994 .35148 .29803 .35014 .30861 .35977 .30043 .36274 Mtetra
.582 .042 0 r
.30043 .36274 .30861 .35977 .3196 .36526 .31139 .36937 Mtetra
.333 0 0 r
.31139 .36937 .3196 .36526 .331 .3661 .32281 .37078 Mtetra
0 0 0 r
.32281 .37078 .331 .3661 .34276 .36199 .33465 .36665 Mtetra
.57 .91 .687 r
.33465 .36665 .34276 .36199 .35484 .35294 .34685 .35697 Mtetra
.838 .992 .736 r
.34685 .35697 .35484 .35294 .36717 .33918 .35934 .34203 Mtetra
.938 .966 .722 r
.35934 .34203 .36717 .33918 .37967 .32123 .37203 .32239 Mtetra
.968 .919 .699 r
.37203 .32239 .37967 .32123 .39227 .29979 .38483 .29887 Mtetra
.971 .875 .682 r
.38483 .29887 .39227 .29979 .4049 .27575 .39765 .27246 Mtetra
.962 .836 .672 r
.39765 .27246 .4049 .27575 .41748 .25006 .41043 .24426 Mtetra
.947 .802 .667 r
.41043 .24426 .41748 .25006 .42998 .22376 .4231 .21542 Mtetra
.928 .771 .667 r
.4231 .21542 .42998 .22376 .44234 .19784 .43562 .18704 Mtetra
.904 .742 .67 r
.43562 .18704 .44234 .19784 .45456 .17325 .44797 .16018 Mtetra
.876 .713 .676 r
.44797 .16018 .45456 .17325 .46663 .15084 .46014 .13577 Mtetra
.842 .683 .686 r
.46014 .13577 .46663 .15084 .47857 .13134 .47214 .11462 Mtetra
.799 .651 .698 r
.47214 .11462 .47857 .13134 .49039 .11536 .48401 .09737 Mtetra
.746 .614 .712 r
.48401 .09737 .49039 .11536 .50215 .10332 .49578 .08449 Mtetra
.678 .57 .726 r
.49578 .08449 .50215 .10332 .51387 .09551 .5075 .0763 Mtetra
.59 .516 .74 r
.5075 .0763 .51387 .09551 .52562 .09207 .51924 .07293 Mtetra
.474 .448 .748 r
.51924 .07293 .52562 .09207 .53745 .09295 .53105 .07434 Mtetra
.326 .362 .745 r
.53105 .07434 .53745 .09295 .54941 .09797 .54299 .08033 Mtetra
.143 .256 .722 r
.54299 .08033 .54941 .09797 .56155 .10678 .55511 .09053 Mtetra
0 .136 .67 r
.55511 .09053 .56155 .10678 .57391 .11887 .56746 .10438 Mtetra
0 .017 .591 r
.56746 .10438 .57391 .11887 .58651 .13359 .58007 .12118 Mtetra
0 0 .497 r
.58007 .12118 .58651 .13359 .59938 .15016 .59297 .14006 Mtetra
0 0 .404 r
.59297 .14006 .59938 .15016 .61251 .16767 .60615 .16003 Mtetra
.656 .193 0 r
.60615 .16003 .61251 .16767 .62588 .18514 .6196 .18001 Mtetra
.696 .197 0 r
.6196 .18001 .62588 .18514 .63946 .20154 .63329 .19883 Mtetra
.696 .167 0 r
.63329 .19883 .63946 .20154 .6532 .21584 .64714 .21535 Mtetra
.654 .098 0 r
.64714 .21535 .6532 .21584 .66702 .22709 .66109 .22847 Mtetra
.556 0 0 r
.66109 .22847 .66702 .22709 .68085 .23445 .67505 .23726 Mtetra
.377 0 0 r
.67505 .23726 .68085 .23445 .69459 .23727 .68893 .24096 Mtetra
.087 0 0 r
.68893 .24096 .69459 .23727 .70817 .23513 .70262 .2391 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -83.0625 -13.9115 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
76.375 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -75.6257 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -69.7874 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.6363 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -74.1266 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.188 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
gsave
.29165 .07573 -69.671 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.312 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.22332e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -22.0625 -9.91147 ]
[.02757 .24618 0 .33853 ]
[.17646 .18758 -14.6257 -10.25 ]
[.17646 .18758 .24931 0 ]
[.3345 .12542 -8.78742 -10.25 ]
[.3345 .12542 .65008 0 ]
[.50253 .05935 -7.63626 -10.25 ]
[.50253 .05935 1.05124 0 ]
[.68156 -0.01098 -13.1266 -10.25 ]
[.68156 -0.01098 2.74843 0 ]
[.29165 .07573 -8.67103 -10.25 ]
[.29165 .07573 .64147 0 ]
[.76162 .0881 0 -7.02759 ]
[.76162 .0881 15.6875 3.22241 ]
[.81073 .16331 0 -6.94482 ]
[.81073 .16331 15.1875 3.30518 ]
[.8565 .23339 0 -6.86895 ]
[.8565 .23339 9.4375 3.38105 ]
[.89924 .29884 0 -6.79915 ]
[.89924 .29884 9 3.45085 ]
[.93925 .36012 0 -6.73472 ]
[.93925 .36012 9.5 3.51528 ]
[.91861 .21225 0 -6.91083 ]
[.91861 .21225 9.375 3.40167 ]
[.02189 .27907 -20.625 -3.13662 ]
[.02189 .27907 0 7.11338 ]
[.01453 .32516 -15.75 -3.18103 ]
[.01453 .32516 0 7.06897 ]
[.00696 .37264 -9.4375 -3.22692 ]
[.00696 .37264 0 7.02308 ]
[-0.00085 .42158 -9.5625 -3.27436 ]
[-0.00085 .42158 0 6.97564 ]
[-0.0089 .47204 -14.4375 -3.32344 ]
[-0.0089 .47204 0 6.92656 ]
[-0.05457 .39542 -14.125 -3.22692 ]
[-0.05457 .39542 0 7.02308 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -83.0625 -13.9115 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
76.375 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -75.6257 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -69.7874 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.6363 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -74.1266 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.188 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
gsave
.29165 .07573 -69.671 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.312 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
gsave
.76162 .0881 -61 -11.0276 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.79837 .1677 m
.79219 .16989 L
s
gsave
.81073 .16331 -61 -10.9448 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -10.8689 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.88677 .30292 m
.88053 .30496 L
s
gsave
.89924 .29884 -61 -10.7991 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.92673 .36405 m
.92047 .36602 L
s
gsave
.93925 .36012 -61 -10.7347 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.91861 .21225 -61 -10.9108 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
68.375 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03716 .25514 m
0 .48963 L
s
.03412 .27433 m
.04024 .27195 L
s
gsave
.02189 .27907 -81.625 -7.13662 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.0268 .3205 m
.03294 .31818 L
s
gsave
.01453 .32516 -76.75 -7.18103 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -70.4375 -7.22692 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01149 .41712 m
.01766 .41489 L
s
gsave
-0.00085 .42158 -70.5625 -7.27436 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.00348 .46769 m
.00967 .46551 L
s
gsave
-0.0089 .47204 -75.4375 -7.32344 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.03267 .28345 m
.03635 .28203 L
s
.03122 .29263 m
.03489 .29122 L
s
.02975 .30187 m
.03343 .30046 L
s
.02828 .31116 m
.03196 .30976 L
s
.02531 .32991 m
.02899 .32852 L
s
.02381 .33936 m
.0275 .33798 L
s
.0223 .34888 m
.02599 .3475 L
s
.02079 .35845 m
.02448 .35708 L
s
.01773 .37777 m
.02142 .37641 L
s
.01618 .38752 m
.01988 .38616 L
s
.01463 .39732 m
.01833 .39597 L
s
.01306 .40719 m
.01676 .40585 L
s
.00991 .42711 m
.01361 .42578 L
s
.00831 .43716 m
.01202 .43583 L
s
.00671 .44727 m
.01042 .44595 L
s
.0051 .45745 m
.00881 .45614 L
s
.03556 .26525 m
.03923 .26382 L
s
.03699 .25623 m
.04065 .2548 L
s
.00184 .47799 m
.00556 .47669 L
s
.0002 .48836 m
.00392 .48707 L
s
gsave
-0.05457 .39542 -75.125 -7.22692 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Im) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.889 .745 .696 r
.39636 .6972 .40169 .70185 .4113 .6781 .40595 .67554 Mtetra
.911 .783 .706 r
.40595 .67554 .4113 .6781 .4208 .6555 .41545 .6549 Mtetra
.933 .831 .721 r
.41545 .6549 .4208 .6555 .43017 .6349 .42482 .63605 Mtetra
.947 .893 .743 r
.42482 .63605 .43017 .6349 .43941 .61707 .43408 .61968 Mtetra
.929 .967 .762 r
.43408 .61968 .43941 .61707 .44853 .60262 .44323 .60635 Mtetra
.763 .978 .716 r
.44323 .60635 .44853 .60262 .45754 .59202 .45227 .59649 Mtetra
0 0 0 r
.45227 .59649 .45754 .59202 .46646 .58558 .46124 .59041 Mtetra
.262 0 0 r
.46124 .59041 .46646 .58558 .47533 .58346 .47015 .58823 Mtetra
.528 .072 .114 r
.47015 .58823 .47533 .58346 .48419 .58565 .47905 .58995 Mtetra
.662 .226 .202 r
.47905 .58995 .48419 .58565 .49305 .59198 .48795 .59541 Mtetra
.742 .315 .237 r
.48795 .59541 .49305 .59198 .50197 .60211 .4969 .6043 Mtetra
.795 .372 .241 r
.4969 .6043 .50197 .60211 .51097 .61554 .50593 .61617 Mtetra
.834 .406 .22 r
.50593 .61617 .51097 .61554 .52009 .63165 .51506 .63044 Mtetra
.859 .422 .171 r
.51506 .63044 .52009 .63165 .52934 .64966 .5243 .64639 Mtetra
.864 .414 .081 r
.5243 .64639 .52934 .64966 .53873 .66868 .53369 .66324 Mtetra
.821 .364 0 r
.53369 .66324 .53873 .66868 .54827 .68776 .54321 .68012 Mtetra
.667 .236 0 r
.54321 .68012 .54827 .68776 .55796 .70589 .55286 .69612 Mtetra
0 0 .563 r
.55286 .69612 .55796 .70589 .56776 .72207 .56262 .71035 Mtetra
.024 .211 .718 r
.56262 .71035 .56776 .72207 .57766 .73538 .57248 .72198 Mtetra
.297 .363 .761 r
.57248 .72198 .57766 .73538 .58762 .74498 .5824 .73028 Mtetra
.469 .453 .758 r
.5824 .73028 .58762 .74498 .59759 .75025 .59234 .73469 Mtetra
.578 .511 .743 r
.59234 .73469 .59759 .75025 .60752 .75073 .60226 .73483 Mtetra
.653 .551 .727 r
.60226 .73483 .60752 .75073 .61739 .74627 .61212 .73053 Mtetra
.708 .583 .713 r
.61212 .73053 .61739 .74627 .62713 .73694 .62189 .72188 Mtetra
.752 .611 .702 r
.62189 .72188 .62713 .73694 .63673 .72308 .63153 .70917 Mtetra
.788 .637 .694 r
.63153 .70917 .63673 .72308 .64617 .70527 .64104 .6929 Mtetra
.82 .662 .687 r
.64104 .6929 .64617 .70527 .65544 .68427 .65041 .67377 Mtetra
.849 .689 .684 r
.65041 .67377 .65544 .68427 .66455 .66099 .65963 .65256 Mtetra
.876 .718 .682 r
.65963 .65256 .66455 .66099 .67352 .63641 .66873 .63017 Mtetra
.903 .752 .684 r
.66873 .63017 .67352 .63641 .68239 .61157 .67775 .60751 Mtetra
.929 .792 .689 r
.67775 .60751 .68239 .61157 .69119 .58744 .68671 .58547 Mtetra
.952 .841 .697 r
.68671 .58547 .69119 .58744 .7 .56496 .69567 .5649 Mtetra
.965 .9 .707 r
.69567 .5649 .7 .56496 .70885 .54495 .70468 .54654 Mtetra
.943 .962 .711 r
.70468 .54654 .70885 .54495 .71783 .52812 .71379 .53103 Mtetra
.802 .969 .664 r
.71379 .53103 .71783 .52812 .72698 .51501 .72306 .51889 Mtetra
0 0 0 r
.72306 .51889 .72698 .51501 .73636 .50604 .73254 .51048 Mtetra
.071 0 0 r
.73254 .51048 .73636 .50604 .74604 .50144 .74228 .50602 Mtetra
.391 0 0 r
.74228 .50602 .74604 .50144 .75605 .50128 .75232 .50559 Mtetra
.571 .093 .081 r
.75232 .50559 .75605 .50128 .76642 .50546 .76269 .50909 Mtetra
.678 .202 .114 r
.76269 .50909 .76642 .50546 .77719 .51374 .77341 .51628 Mtetra
.746 .268 .108 r
.77341 .51628 .77719 .51374 .78834 .52569 .78449 .52678 Mtetra
.787 .303 .068 r
.78449 .52678 .78834 .52569 .79988 .54073 .79591 .54007 Mtetra
.802 .31 0 r
.79591 .54007 .79988 .54073 .81176 .55814 .80764 .55547 Mtetra
.775 .282 0 r
.80764 .55547 .81176 .55814 .82394 .57707 .81965 .57222 Mtetra
.676 .203 0 r
.81965 .57222 .82394 .57707 .83635 .59658 .83186 .58946 Mtetra
0 0 .498 r
.83186 .58946 .83635 .59658 .84889 .61564 .84419 .60627 Mtetra
0 .103 .658 r
.84419 .60627 .84889 .61564 .86147 .63321 .85656 .62172 Mtetra
.076 .252 .742 r
.85656 .62172 .86147 .63321 .87397 .6483 .86886 .63492 Mtetra
.285 .361 .766 r
.86886 .63492 .87397 .6483 .88627 .65999 .88099 .64506 Mtetra
.434 .436 .763 r
.88099 .64506 .88627 .65999 .89826 .66751 .89285 .65146 Mtetra
.54 .491 .749 r
.89285 .65146 .89826 .66751 .90984 .6703 .90435 .65363 Mtetra
.62 .533 .734 r
.90435 .65363 .90984 .6703 .92092 .66805 .91542 .65127 Mtetra
.682 .568 .72 r
.91542 .65127 .92092 .66805 .93145 .66069 .926 .64435 Mtetra
.733 .599 .707 r
.926 .64435 .93145 .66069 .94142 .64846 .93608 .63307 Mtetra
.777 .629 .696 r
.93608 .63307 .94142 .64846 .95082 .63184 .94567 .61784 Mtetra
.816 .658 .687 r
.94567 .61784 .95082 .63184 .95971 .61152 .9548 .59929 Mtetra
.852 .689 .679 r
.9548 .59929 .95971 .61152 .96815 .58838 .96354 .5782 Mtetra
.887 .723 .673 r
.96354 .5782 .96815 .58838 .97627 .5634 .97199 .55543 Mtetra
.919 .76 .668 r
.97199 .55543 .97627 .5634 .98416 .53763 .98024 .53192 Mtetra
.884 .748 .708 r
.391 .69252 .39636 .6972 .40595 .67554 .40057 .67275 Mtetra
.904 .785 .719 r
.40057 .67275 .40595 .67554 .41545 .6549 .41006 .65387 Mtetra
.923 .831 .736 r
.41006 .65387 .41545 .6549 .42482 .63605 .41944 .6366 Mtetra
.936 .891 .761 r
.41944 .6366 .42482 .63605 .43408 .61968 .42872 .62155 Mtetra
.919 .963 .79 r
.42872 .62155 .43408 .61968 .44323 .60635 .43789 .60924 Mtetra
.787 .994 .776 r
.43789 .60924 .44323 .60635 .45227 .59649 .44696 .60007 Mtetra
0 0 0 r
.44696 .60007 .45227 .59649 .46124 .59041 .45597 .5943 Mtetra
.179 0 0 r
.45597 .5943 .46124 .59041 .47015 .58823 .46493 .59207 Mtetra
.482 0 .02 r
.46493 .59207 .47015 .58823 .47905 .58995 .47386 .59336 Mtetra
.635 .169 .129 r
.47386 .59336 .47905 .58995 .48795 .59541 .48281 .59803 Mtetra
.723 .27 .175 r
.48281 .59803 .48795 .59541 .4969 .6043 .49179 .60579 Mtetra
.78 .331 .183 r
.49179 .60579 .4969 .6043 .50593 .61617 .50084 .61624 Mtetra
.818 .367 .161 r
.50084 .61624 .50593 .61617 .51506 .63044 .50998 .62884 Mtetra
.839 .379 .106 r
.50998 .62884 .51506 .63044 .5243 .64639 .51924 .64294 Mtetra
.834 .363 .005 r
.51924 .64294 .5243 .64639 .53369 .66324 .52861 .65783 Mtetra
.77 .298 0 r
.52861 .65783 .53369 .66324 .54321 .68012 .53812 .67272 Mtetra
.588 .153 0 r
.53812 .67272 .54321 .68012 .55286 .69612 .54774 .6868 Mtetra
0 .062 .626 r
.54774 .6868 .55286 .69612 .56262 .71035 .55748 .69928 Mtetra
.078 .261 .749 r
.55748 .69928 .56262 .71035 .57248 .72198 .56731 .70941 Mtetra
.324 .392 .779 r
.56731 .70941 .57248 .72198 .5824 .73028 .57719 .71656 Mtetra
.481 .472 .771 r
.57719 .71656 .5824 .73028 .59234 .73469 .58711 .72021 Mtetra
.583 .524 .754 r
.58711 .72021 .59234 .73469 .60226 .73483 .59701 .72003 Mtetra
.655 .561 .737 r
.59701 .72003 .60226 .73483 .61212 .73053 .60688 .71588 Mtetra
.708 .591 .723 r
.60688 .71588 .61212 .73053 .62189 .72188 .61666 .70782 Mtetra
.75 .618 .712 r
.61666 .70782 .62189 .72188 .63153 .70917 .62635 .69613 Mtetra
.786 .643 .704 r
.62635 .69613 .63153 .70917 .64104 .6929 .63592 .68125 Mtetra
.817 .668 .698 r
.63592 .68125 .64104 .6929 .65041 .67377 .64537 .66378 Mtetra
.845 .694 .695 r
.64537 .66378 .65041 .67377 .65963 .65256 .6547 .64444 Mtetra
.871 .723 .695 r
.6547 .64444 .65963 .65256 .66873 .63017 .66393 .62401 Mtetra
.897 .756 .697 r
.66393 .62401 .66873 .63017 .67775 .60751 .67307 .60332 Mtetra
.921 .795 .704 r
.67307 .60332 .67775 .60751 .68671 .58547 .68218 .58316 Mtetra
.942 .842 .715 r
.68218 .58316 .68671 .58547 .69567 .5649 .69127 .56431 Mtetra
.954 .9 .731 r
.69127 .56431 .69567 .5649 .70468 .54654 .70042 .54744 Mtetra
.937 .963 .746 r
.70042 .54744 .70468 .54654 .71379 .53103 .70965 .53313 Mtetra
.825 .99 .729 r
.70965 .53313 .71379 .53103 .72306 .51889 .71903 .52186 Mtetra
.499 .852 .595 r
.71903 .52186 .72306 .51889 .73254 .51048 .7286 .51397 Mtetra
0 0 0 r
.7286 .51397 .73254 .51048 .74228 .50602 .7384 .50964 Mtetra
.323 0 0 r
.7384 .50964 .74228 .50602 .75232 .50559 .74848 .50896 Mtetra
.526 .015 0 r
.74848 .50896 .75232 .50559 .76269 .50909 .75885 .51183 Mtetra
.644 .137 .029 r
.75885 .51183 .76269 .50909 .77341 .51628 .76954 .51804 Mtetra
.715 .209 .028 r
.76954 .51804 .77341 .51628 .78449 .52678 .78055 .52723 Mtetra
.755 .245 0 r
.78055 .52723 .78449 .52678 .79591 .54007 .79187 .53891 Mtetra
.762 .248 0 r
.79187 .53891 .79591 .54007 .80764 .55547 .80347 .5525 Mtetra
.72 .212 0 r
.80347 .5525 .80764 .55547 .81965 .57222 .81532 .56727 Mtetra
.602 .125 0 r
.81532 .56727 .81965 .57222 .83186 .58946 .82735 .58247 Mtetra
0 .012 .57 r
.82735 .58247 .83186 .58946 .84419 .60627 .8395 .59726 Mtetra
0 .165 .703 r
.8395 .59726 .84419 .60627 .85656 .62172 .85169 .61081 Mtetra
.122 .295 .767 r
.85169 .61081 .85656 .62172 .86886 .63492 .86382 .62232 Mtetra
.311 .389 .782 r
.86382 .62232 .86886 .63492 .88099 .64506 .8758 .63107 Mtetra
.447 .456 .775 r
.8758 .63107 .88099 .64506 .89285 .65146 .88755 .63647 Mtetra
.547 .505 .761 r
.88755 .63647 .89285 .65146 .90435 .65363 .89898 .63807 Mtetra
.623 .544 .745 r
.89898 .63807 .90435 .65363 .91542 .65127 .91004 .63562 Mtetra
.682 .577 .73 r
.91004 .63562 .91542 .65127 .926 .64435 .92067 .62909 Mtetra
.732 .607 .718 r
.92067 .62909 .926 .64435 .93608 .63307 .93086 .61865 Mtetra
.775 .635 .707 r
.93086 .61865 .93608 .63307 .94567 .61784 .94062 .60467 Mtetra
.813 .664 .699 r
.94062 .60467 .94567 .61784 .9548 .59929 .94997 .5877 Mtetra
.848 .695 .692 r
.94997 .5877 .9548 .59929 .96354 .5782 .95897 .56843 Mtetra
.881 .728 .687 r
.95897 .56843 .96354 .5782 .97199 .55543 .96771 .54764 Mtetra
.912 .765 .685 r
.96771 .54764 .97199 .55543 .98024 .53192 .97628 .52616 Mtetra
.878 .751 .719 r
.38561 .68781 .391 .69252 .40057 .67275 .39516 .66974 Mtetra
.897 .787 .732 r
.39516 .66974 .40057 .67275 .41006 .65387 .40464 .65246 Mtetra
.914 .831 .751 r
.40464 .65246 .41006 .65387 .41944 .6366 .41403 .63661 Mtetra
.924 .888 .779 r
.41403 .63661 .41944 .6366 .42872 .62155 .42331 .62276 Mtetra
.908 .956 .813 r
.42331 .62276 .42872 .62155 .43789 .60924 .43251 .61138 Mtetra
.8 1 .824 r
.43251 .61138 .43789 .60924 .44696 .60007 .44162 .60283 Mtetra
.443 .854 .685 r
.44162 .60283 .44696 .60007 .45597 .5943 .45066 .59735 Mtetra
.078 0 0 r
.45066 .59735 .45597 .5943 .46493 .59207 .45966 .59506 Mtetra
.421 0 0 r
.45966 .59506 .46493 .59207 .47386 .59336 .46863 .59596 Mtetra
.598 .099 .039 r
.46863 .59596 .47386 .59336 .48281 .59803 .47762 .59991 Mtetra
.696 .214 .098 r
.47762 .59991 .48281 .59803 .49179 .60579 .48663 .60665 Mtetra
.757 .281 .111 r
.48663 .60665 .49179 .60579 .50084 .61624 .49571 .6158 Mtetra
.795 .317 .089 r
.49571 .6158 .50084 .61624 .50998 .62884 .50487 .62689 Mtetra
.81 .326 .027 r
.50487 .62689 .50998 .62884 .51924 .64294 .51413 .63932 Mtetra
.792 .3 0 r
.51413 .63932 .51924 .64294 .52861 .65783 .52351 .65244 Mtetra
.705 .219 0 r
.52351 .65244 .52861 .65783 .53812 .67272 .533 .66554 Mtetra
0 0 .487 r
.533 .66554 .53812 .67272 .54774 .6868 .54261 .6779 Mtetra
0 .138 .685 r
.54261 .6779 .54774 .6868 .55748 .69928 .55233 .68881 Mtetra
.13 .31 .778 r
.55233 .68881 .55748 .69928 .56731 .70941 .56213 .6976 Mtetra
.349 .421 .794 r
.56213 .6976 .56731 .70941 .57719 .71656 .57199 .7037 Mtetra
.493 .49 .783 r
.57199 .7037 .57719 .71656 .58711 .72021 .58188 .70667 Mtetra
.588 .537 .765 r
.58188 .70667 .58711 .72021 .59701 .72003 .59178 .7062 Mtetra
.656 .571 .748 r
.59178 .7062 .59701 .72003 .60688 .71588 .60165 .70218 Mtetra
.708 .6 .733 r
.60165 .70218 .60688 .71588 .61666 .70782 .61146 .69466 Mtetra
.749 .625 .722 r
.61146 .69466 .61666 .70782 .62635 .69613 .62118 .68388 Mtetra
.783 .649 .714 r
.62118 .68388 .62635 .69613 .63592 .68125 .63081 .67023 Mtetra
.813 .673 .709 r
.63081 .67023 .63592 .68125 .64537 .66378 .64034 .65425 Mtetra
.84 .699 .706 r
.64034 .65425 .64537 .66378 .6547 .64444 .64976 .63658 Mtetra
.866 .727 .707 r
.64976 .63658 .6547 .64444 .66393 .62401 .6591 .61791 Mtetra
.89 .759 .711 r
.6591 .61791 .66393 .62401 .67307 .60332 .66836 .59899 Mtetra
.913 .797 .719 r
.66836 .59899 .67307 .60332 .68218 .58316 .67759 .58053 Mtetra
.932 .843 .733 r
.67759 .58053 .68218 .58316 .69127 .56431 .68682 .56324 Mtetra
.942 .898 .754 r
.68682 .56324 .69127 .56431 .70042 .54744 .69608 .54772 Mtetra
.927 .96 .777 r
.69608 .54772 .70042 .54744 .70965 .53313 .70543 .5345 Mtetra
.837 .998 .783 r
.70543 .5345 .70965 .53313 .71903 .52186 .71491 .52403 Mtetra
.572 .915 .702 r
.71491 .52403 .71903 .52186 .7286 .51397 .72456 .51659 Mtetra
0 0 0 r
.72456 .51659 .7286 .51397 .7384 .50964 .73443 .51239 Mtetra
.236 0 0 r
.73443 .51239 .7384 .50964 .74848 .50896 .74453 .51147 Mtetra
.464 0 0 r
.74453 .51147 .74848 .50896 .75885 .51183 .75491 .51377 Mtetra
.596 .058 0 r
.75491 .51377 .75885 .51183 .76954 .51804 .76557 .51908 Mtetra
.673 .137 0 r
.76557 .51908 .76954 .51804 .78055 .52723 .77652 .52707 Mtetra
.71 .175 0 r
.77652 .52707 .78055 .52723 .79187 .53891 .78775 .53731 Mtetra
.708 .174 0 r
.78775 .53731 .79187 .53891 .80347 .5525 .79924 .54925 Mtetra
.65 .131 0 r
.79924 .54925 .80347 .5525 .81532 .56727 .81095 .56224 Mtetra
0 0 .482 r
.81095 .56224 .81532 .56727 .82735 .58247 .82283 .5756 Mtetra
0 .09 .639 r
.82283 .5756 .82735 .58247 .8395 .59726 .83482 .58856 Mtetra
0 .225 .744 r
.83482 .58856 .8395 .59726 .85169 .61081 .84685 .60041 Mtetra
.166 .336 .79 r
.84685 .60041 .85169 .61081 .86382 .62232 .85883 .6104 Mtetra
.336 .417 .797 r
.85883 .6104 .86382 .62232 .8758 .63107 .87069 .61792 Mtetra
.461 .475 .787 r
.87069 .61792 .8758 .63107 .88755 .63647 .88234 .62242 Mtetra
.554 .519 .771 r
.88234 .62242 .88755 .63647 .89898 .63807 .89372 .62351 Mtetra
.626 .555 .756 r
.89372 .62351 .89898 .63807 .91004 .63562 .90477 .62098 Mtetra
.683 .586 .741 r
.90477 .62098 .91004 .63562 .92067 .62909 .91544 .61479 Mtetra
.731 .615 .729 r
.91544 .61479 .92067 .62909 .93086 .61865 .92573 .6051 Mtetra
.772 .642 .718 r
.92573 .6051 .93086 .61865 .94062 .60467 .93564 .59223 Mtetra
.809 .671 .711 r
.93564 .59223 .94062 .60467 .94997 .5877 .94519 .57668 Mtetra
.843 .7 .705 r
.94519 .57668 .94997 .5877 .95897 .56843 .95443 .55904 Mtetra
.875 .732 .702 r
.95443 .55904 .95897 .56843 .96771 .54764 .96344 .54002 Mtetra
.904 .769 .701 r
.96344 .54002 .96771 .54764 .97628 .52616 .9723 .52037 Mtetra
.871 .754 .731 r
.38018 .68308 .38561 .68781 .39516 .66974 .38972 .66654 Mtetra
.889 .789 .744 r
.38972 .66654 .39516 .66974 .40464 .65246 .39919 .6507 Mtetra
.903 .831 .765 r
.39919 .6507 .40464 .65246 .41403 .63661 .40858 .63614 Mtetra
.911 .885 .794 r
.40858 .63614 .41403 .63661 .42331 .62276 .41788 .62337 Mtetra
.895 .948 .833 r
.41788 .62337 .42331 .62276 .43251 .61138 .4271 .61283 Mtetra
.805 .996 .861 r
.4271 .61283 .43251 .61138 .44162 .60283 .43624 .60483 Mtetra
.519 .91 .784 r
.43624 .60483 .44162 .60283 .45066 .59735 .44531 .59961 Mtetra
0 0 0 r
.44531 .59961 .45066 .59735 .45966 .59506 .45435 .59728 Mtetra
.34 0 0 r
.45435 .59728 .45966 .59506 .46863 .59596 .46336 .59782 Mtetra
.545 .012 0 r
.46336 .59782 .46863 .59596 .47762 .59991 .47238 .60111 Mtetra
.658 .143 .004 r
.47238 .60111 .47762 .59991 .48663 .60665 .48143 .60692 Mtetra
.724 .218 .024 r
.48143 .60692 .48663 .60665 .49571 .6158 .49054 .61491 Mtetra
.761 .255 .001 r
.49054 .61491 .49571 .6158 .50487 .62689 .49972 .62462 Mtetra
.769 .259 0 r
.49972 .62462 .50487 .62689 .51413 .63932 .509 .63553 Mtetra
.735 .223 0 r
.509 .63553 .51413 .63932 .52351 .65244 .51837 .64705 Mtetra
.622 .129 0 r
.51837 .64705 .52351 .65244 .533 .66554 .52786 .65854 Mtetra
0 .029 .577 r
.52786 .65854 .533 .66554 .54261 .6779 .53746 .66936 Mtetra
0 .211 .736 r
.53746 .66936 .54261 .6779 .55233 .68881 .54716 .67885 Mtetra
.18 .355 .802 r
.54716 .67885 .55233 .68881 .56213 .6976 .55694 .68644 Mtetra
.374 .449 .809 r
.55694 .68644 .56213 .6976 .57199 .7037 .56678 .69161 Mtetra
.504 .509 .794 r
.56678 .69161 .57199 .7037 .58188 .70667 .57667 .69397 Mtetra
.593 .55 .775 r
.57667 .69397 .58188 .70667 .59178 .7062 .58656 .69325 Mtetra
.658 .582 .758 r
.58656 .69325 .59178 .7062 .60165 .70218 .59643 .68934 Mtetra
.707 .608 .744 r
.59643 .68934 .60165 .70218 .61146 .69466 .60626 .6823 Mtetra
.747 .632 .733 r
.60626 .6823 .61146 .69466 .62118 .68388 .61602 .67233 Mtetra
.78 .655 .725 r
.61602 .67233 .62118 .68388 .63081 .67023 .6257 .65978 Mtetra
.809 .679 .72 r
.6257 .65978 .63081 .67023 .64034 .65425 .6353 .64513 Mtetra
.836 .703 .718 r
.6353 .64513 .64034 .65425 .64976 .63658 .64481 .62895 Mtetra
.86 .731 .719 r
.64481 .62895 .64976 .63658 .6591 .61791 .65424 .61187 Mtetra
.883 .762 .724 r
.65424 .61187 .6591 .61791 .66836 .59899 .66361 .59454 Mtetra
.903 .799 .734 r
.66361 .59454 .66836 .59899 .67759 .58053 .67295 .57762 Mtetra
.921 .843 .75 r
.67295 .57762 .67759 .58053 .68682 .56324 .6823 .56173 Mtetra
.929 .895 .774 r
.6823 .56173 .68682 .56324 .69608 .54772 .69168 .54743 Mtetra
.915 .954 .803 r
.69168 .54743 .69608 .54772 .70543 .5345 .70113 .5352 Mtetra
.841 .998 .825 r
.70113 .5352 .70543 .5345 .71491 .52403 .71071 .52544 Mtetra
.629 .956 .789 r
.71071 .52544 .71491 .52403 .72456 .51659 .72043 .51843 Mtetra
0 0 0 r
.72043 .51843 .72456 .51659 .73443 .51239 .73035 .51433 Mtetra
.129 0 0 r
.73035 .51433 .73443 .51239 .74453 .51147 .74049 .5132 Mtetra
.382 0 0 r
.74049 .5132 .74453 .51147 .75491 .51377 .75087 .51497 Mtetra
.531 0 0 r
.75087 .51497 .75491 .51377 .76557 .51908 .76151 .51947 Mtetra
.613 .05 0 r
.76151 .51947 .76557 .51908 .77652 .52707 .77241 .52638 Mtetra
.648 .09 0 r
.77241 .52638 .77652 .52707 .78775 .53731 .78357 .5353 Mtetra
.636 .087 0 r
.78357 .5353 .78775 .53731 .79924 .54925 .79496 .54575 Mtetra
.564 .04 0 r
.79496 .54575 .79924 .54925 .81095 .56224 .80655 .55713 Mtetra
0 .051 .573 r
.80655 .55713 .81095 .56224 .82283 .5756 .8183 .56882 Mtetra
0 .168 .701 r
.8183 .56882 .82283 .5756 .83482 .58856 .83015 .58015 Mtetra
.014 .282 .78 r
.83015 .58015 .83482 .58856 .84685 .60041 .84204 .59046 Mtetra
.209 .375 .81 r
.84204 .59046 .84685 .60041 .85883 .6104 .85389 .5991 Mtetra
.36 .443 .811 r
.85389 .5991 .85883 .6104 .87069 .61792 .86564 .6055 Mtetra
.474 .494 .798 r
.86564 .6055 .87069 .61792 .88234 .62242 .87721 .60919 Mtetra
.561 .534 .782 r
.87721 .60919 .88234 .62242 .89372 .62351 .88854 .60983 Mtetra
.628 .567 .766 r
.88854 .60983 .89372 .62351 .90477 .62098 .89958 .60723 Mtetra
.683 .596 .752 r
.89958 .60723 .90477 .62098 .91544 .61479 .91031 .60134 Mtetra
.729 .623 .74 r
.91031 .60134 .91544 .61479 .92573 .6051 .92069 .59232 Mtetra
.769 .649 .73 r
.92069 .59232 .92573 .6051 .93564 .59223 .93073 .58044 Mtetra
.805 .677 .723 r
.93073 .58044 .93564 .59223 .94519 .57668 .94046 .56615 Mtetra
.837 .705 .718 r
.94046 .56615 .94519 .57668 .95443 .55904 .94992 .54997 Mtetra
.868 .737 .716 r
.94992 .54997 .95443 .55904 .96344 .54002 .95917 .53255 Mtetra
.896 .772 .717 r
.95917 .53255 .96344 .54002 .9723 .52037 .96829 .51454 Mtetra
.864 .757 .742 r
.37472 .67831 .38018 .68308 .38972 .66654 .38424 .66315 Mtetra
.88 .79 .757 r
.38424 .66315 .38972 .66654 .39919 .6507 .39371 .64861 Mtetra
.893 .83 .778 r
.39371 .64861 .39919 .6507 .40858 .63614 .4031 .63522 Mtetra
.897 .88 .809 r
.4031 .63522 .40858 .63614 .41788 .62337 .41241 .62343 Mtetra
.881 .938 .85 r
.41241 .62343 .41788 .62337 .4271 .61283 .42165 .61364 Mtetra
.805 .987 .888 r
.42165 .61364 .4271 .61283 .43624 .60483 .43082 .60616 Mtetra
.576 .942 .857 r
.43082 .60616 .43624 .60483 .44531 .59961 .43993 .60117 Mtetra
0 0 0 r
.43993 .60117 .44531 .59961 .45435 .59728 .449 .59879 Mtetra
.237 0 0 r
.449 .59879 .45435 .59728 .46336 .59782 .45805 .599 Mtetra
.473 0 0 r
.45805 .599 .46336 .59782 .47238 .60111 .46711 .6017 Mtetra
.604 .055 0 r
.46711 .6017 .47238 .60111 .48143 .60692 .47619 .60667 Mtetra
.677 .139 0 r
.47619 .60667 .48143 .60692 .49054 .61491 .48533 .61359 Mtetra
.712 .178 0 r
.48533 .61359 .49054 .61491 .49972 .62462 .49453 .62206 Mtetra
.49453 .62206 .49972 .62462 .509 .63553 .50382 .6316 Mtetra
.659 .132 0 r
.50382 .6316 .509 .63553 .51837 .64705 .51321 .64168 Mtetra
.523 .029 0 r
.51321 .64168 .51837 .64705 .52786 .65854 .5227 .65172 Mtetra
0 .123 .659 r
.5227 .65172 .52786 .65854 .53746 .66936 .53229 .66114 Mtetra
0 .279 .78 r
.53229 .66114 .53746 .66936 .54716 .67885 .54198 .66936 Mtetra
.227 .397 .824 r
.54198 .66936 .54716 .67885 .55694 .68644 .55174 .67587 Mtetra
.398 .475 .823 r
.55174 .67587 .55694 .68644 .56678 .69161 .56157 .6802 Mtetra
.515 .526 .805 r
.56157 .6802 .56678 .69161 .57667 .69397 .57145 .68201 Mtetra
.598 .563 .786 r
.57145 .68201 .57667 .69397 .58656 .69325 .58133 .68106 Mtetra
.659 .592 .768 r
.58133 .68106 .58656 .69325 .59643 .68934 .59121 .67725 Mtetra
.706 .616 .754 r
.59121 .67725 .59643 .68934 .60626 .6823 .60106 .67063 Mtetra
.745 .639 .743 r
.60106 .67063 .60626 .6823 .61602 .67233 .61086 .66138 Mtetra
.777 .661 .735 r
.61086 .66138 .61602 .67233 .6257 .65978 .62059 .64982 Mtetra
.805 .684 .731 r
.62059 .64982 .6257 .65978 .6353 .64513 .63025 .63637 Mtetra
.83 .708 .729 r
.63025 .63637 .6353 .64513 .64481 .62895 .63983 .62153 Mtetra
.854 .735 .732 r
.63983 .62153 .64481 .62895 .65424 .61187 .64935 .60587 Mtetra
.875 .765 .738 r
.64935 .60587 .65424 .61187 .66361 .59454 .65883 .58998 Mtetra
.894 .8 .749 r
.65883 .58998 .66361 .59454 .67295 .57762 .66827 .57444 Mtetra
.909 .842 .767 r
.66827 .57444 .67295 .57762 .6823 .56173 .67772 .55982 Mtetra
.915 .891 .792 r
.67772 .55982 .6823 .56173 .69168 .54743 .68721 .54662 Mtetra
.901 .946 .825 r
.68721 .54662 .69168 .54743 .70113 .5352 .69676 .53529 Mtetra
.838 .991 .857 r
.69676 .53529 .70113 .5352 .71071 .52544 .70642 .52618 Mtetra
.668 .975 .853 r
.70642 .52618 .71071 .52544 .72043 .51843 .71621 .51954 Mtetra
.352 .821 .752 r
.71621 .51954 .72043 .51843 .73035 .51433 .72618 .51554 Mtetra
.009 0 0 r
.72618 .51554 .73035 .51433 .74049 .5132 .73636 .51422 Mtetra
.279 0 0 r
.73636 .51422 .74049 .5132 .75087 .51497 .74675 .51551 Mtetra
.444 0 0 r
.74675 .51551 .75087 .51497 .76151 .51947 .75737 .51926 Mtetra
.534 0 0 r
.75737 .51926 .76151 .51947 .77241 .52638 .76823 .52518 Mtetra
.567 0 0 r
.76823 .52518 .77241 .52638 .78357 .5353 .77933 .53292 Mtetra
.546 0 0 r
.77933 .53292 .78357 .5353 .79496 .54575 .79063 .54201 Mtetra
.463 0 0 r
.79063 .54201 .79496 .54575 .80655 .55713 .80212 .55194 Mtetra
0 .142 .657 r
.80212 .55194 .80655 .55713 .8183 .56882 .81376 .56213 Mtetra
0 .242 .756 r
.81376 .56213 .8183 .56882 .83015 .58015 .82548 .57199 Mtetra
.078 .336 .811 r
.82548 .57199 .83015 .58015 .84204 .59046 .83725 .58091 Mtetra
.249 .411 .829 r
.83725 .58091 .84204 .59046 .85389 .5991 .84899 .58833 Mtetra
.384 .469 .824 r
.84899 .58833 .85389 .5991 .86564 .6055 .86064 .59374 Mtetra
.488 .513 .809 r
.86064 .59374 .86564 .6055 .87721 .60919 .87214 .59671 Mtetra
.568 .548 .792 r
.87214 .59671 .87721 .60919 .88854 .60983 .88344 .59694 Mtetra
.631 .578 .776 r
.88344 .59694 .88854 .60983 .89958 .60723 .89448 .59426 Mtetra
.683 .605 .762 r
.89448 .59426 .89958 .60723 .91031 .60134 .90524 .58865 Mtetra
.727 .631 .751 r
.90524 .58865 .91031 .60134 .92069 .59232 .91571 .58022 Mtetra
.766 .656 .741 r
.91571 .58022 .92069 .59232 .93073 .58044 .92588 .56923 Mtetra
.8 .683 .735 r
.92588 .56923 .93073 .58044 .94046 .56615 .93577 .55606 Mtetra
.831 .711 .731 r
.93577 .55606 .94046 .56615 .94992 .54997 .94543 .5412 Mtetra
.86 .741 .73 r
.94543 .5412 .94992 .54997 .95917 .53255 .9549 .5252 Mtetra
.887 .775 .733 r
.9549 .5252 .95917 .53255 .96829 .51454 .96426 .50866 Mtetra
.857 .759 .754 r
.36922 .67351 .37472 .67831 .38424 .66315 .37873 .6596 Mtetra
.871 .791 .769 r
.37873 .6596 .38424 .66315 .39371 .64861 .38819 .64623 Mtetra
.881 .829 .791 r
.38819 .64623 .39371 .64861 .4031 .63522 .39759 .63389 Mtetra
.884 .875 .822 r
.39759 .63389 .4031 .63522 .41241 .62343 .40691 .62299 Mtetra
.867 .928 .864 r
.40691 .62299 .41241 .62343 .42165 .61364 .41617 .61389 Mtetra
.8 .973 .907 r
.41617 .61389 .42165 .61364 .43082 .60616 .42537 .60686 Mtetra
.617 .955 .907 r
.42537 .60686 .43082 .60616 .43993 .60117 .43451 .60209 Mtetra
.268 .773 .778 r
.43451 .60209 .43993 .60117 .449 .59879 .44362 .59966 Mtetra
.115 0 0 r
.44362 .59966 .449 .59879 .45805 .599 .4527 .59958 Mtetra
.377 0 0 r
.4527 .59958 .45805 .599 .46711 .6017 .4618 .60173 Mtetra
.528 0 0 r
.4618 .60173 .46711 .6017 .47619 .60667 .47091 .60593 Mtetra
.61 .043 0 r
.47091 .60593 .47619 .60667 .48533 .61359 .48008 .61188 Mtetra
.644 .085 0 r
.48008 .61188 .48533 .61359 .49453 .62206 .4893 .61923 Mtetra
.634 .081 0 r
.4893 .61923 .49453 .62206 .50382 .6316 .49861 .62753 Mtetra
.563 .028 0 r
.49861 .62753 .50382 .6316 .51321 .64168 .50801 .6363 Mtetra
0 .076 .583 r
.50801 .6363 .51321 .64168 .5227 .65172 .5175 .64504 Mtetra
0 .212 .73 r
.5175 .64504 .5227 .65172 .53229 .66114 .52709 .6532 Mtetra
.064 .34 .817 r
.52709 .6532 .53229 .66114 .54198 .66936 .53677 .66028 Mtetra
.27 .436 .842 r
.53677 .66028 .54198 .66936 .55174 .67587 .54653 .66582 Mtetra
.42 .5 .835 r
.54653 .66582 .55174 .67587 .56157 .6802 .55636 .6694 Mtetra
.526 .543 .816 r
.55636 .6694 .56157 .6802 .57145 .68201 .56622 .67072 Mtetra
.603 .576 .796 r
.56622 .67072 .57145 .68201 .58133 .68106 .57611 .66956 Mtetra
.66 .602 .778 r
.57611 .66956 .58133 .68106 .59121 .67725 .586 .66583 Mtetra
.705 .625 .764 r
.586 .66583 .59121 .67725 .60106 .67063 .59586 .65959 Mtetra
.742 .646 .754 r
.59586 .65959 .60106 .67063 .61086 .66138 .60569 .65099 Mtetra
.773 .667 .746 r
.60569 .65099 .61086 .66138 .62059 .64982 .61547 .64031 Mtetra
.8 .689 .742 r
.61547 .64031 .62059 .64982 .63025 .63637 .62518 .62793 Mtetra
.825 .713 .741 r
.62518 .62793 .63025 .63637 .63983 .62153 .63484 .61429 Mtetra
.847 .738 .744 r
.63484 .61429 .63983 .62153 .64935 .60587 .64444 .59991 Mtetra
.866 .768 .751 r
.64444 .59991 .64935 .60587 .65883 .58998 .654 .58531 Mtetra
.884 .801 .763 r
.654 .58531 .65883 .58998 .66827 .57444 .66355 .57102 Mtetra
.896 .841 .782 r
.66355 .57102 .66827 .57444 .67772 .55982 .67309 .55755 Mtetra
.901 .886 .809 r
.67309 .55755 .67772 .55982 .68721 .54662 .68267 .54535 Mtetra
.886 .936 .844 r
.68267 .54535 .68721 .54662 .69676 .53529 .69231 .53482 Mtetra
.832 .979 .881 r
.69231 .53482 .69676 .53529 .70642 .52618 .70205 .5263 Mtetra
.694 .979 .897 r
.70205 .5263 .70642 .52618 .71621 .51954 .71191 .52001 Mtetra
.438 .876 .845 r
.71191 .52001 .71621 .51954 .72618 .51554 .72194 .51609 Mtetra
.115 .665 .714 r
.72194 .51609 .72618 .51554 .73636 .51422 .73214 .51459 Mtetra
.157 0 0 r
.73214 .51459 .73636 .51422 .74675 .51551 .74254 .51545 Mtetra
.335 0 0 r
.74254 .51545 .74675 .51551 .75737 .51926 .75315 .51851 Mtetra
.432 0 0 r
.75315 .51851 .75737 .51926 .76823 .52518 .76398 .52354 Mtetra
.465 0 0 r
.76398 .52354 .76823 .52518 .77933 .53292 .77502 .5302 Mtetra
.438 0 0 r
.77502 .5302 .77933 .53292 .79063 .54201 .78626 .53807 Mtetra
0 .159 .635 r
.78626 .53807 .79063 .54201 .80212 .55194 .79766 .54668 Mtetra
0 .229 .731 r
.79766 .54668 .80212 .55194 .81376 .56213 .80919 .55552 Mtetra
0 .31 .802 r
.80919 .55552 .81376 .56213 .82548 .57199 .82081 .56404 Mtetra
.139 .385 .837 r
.82081 .56404 .82548 .57199 .83725 .58091 .83247 .57172 Mtetra
.288 .445 .844 r
.83247 .57172 .83725 .58091 .84899 .58833 .84412 .57804 Mtetra
.407 .493 .835 r
.84412 .57804 .84899 .58833 .86064 .59374 .85569 .58255 Mtetra
.5 .531 .82 r
.85569 .58255 .86064 .59374 .87214 .59671 .86713 .58488 Mtetra
.574 .562 .802 r
.86713 .58488 .87214 .59671 .88344 .59694 .8784 .58474 Mtetra
.634 .589 .787 r
.8784 .58474 .88344 .59694 .89448 .59426 .88944 .582 Mtetra
.683 .614 .773 r
.88944 .582 .89448 .59426 .90524 .58865 .90024 .57662 Mtetra
.725 .639 .761 r
.90024 .57662 .90524 .58865 .91571 .58022 .91079 .56872 Mtetra
.762 .663 .753 r
.91079 .56872 .91571 .58022 .92588 .56923 .92107 .55852 Mtetra
.795 .688 .747 r
.92107 .55852 .92588 .56923 .93577 .55606 .93111 .54636 Mtetra
.825 .715 .744 r
.93111 .54636 .93577 .55606 .94543 .5412 .94095 .53267 Mtetra
.852 .745 .744 r
.94095 .53267 .94543 .5412 .9549 .5252 .95062 .51796 Mtetra
.877 .778 .748 r
.95062 .51796 .9549 .5252 .96426 .50866 .9602 .50275 Mtetra
.849 .761 .765 r
.36369 .66869 .36922 .67351 .37873 .6596 .37319 .65589 Mtetra
.862 .792 .781 r
.37319 .65589 .37873 .6596 .38819 .64623 .38264 .64359 Mtetra
.87 .827 .803 r
.38264 .64359 .38819 .64623 .39759 .63389 .39204 .63219 Mtetra
.87 .869 .834 r
.39204 .63219 .39759 .63389 .40691 .62299 .40138 .6221 Mtetra
.852 .917 .875 r
.40138 .6221 .40691 .62299 .41617 .61389 .41066 .61362 Mtetra
.793 .958 .92 r
.41066 .61362 .41617 .61389 .42537 .60686 .41988 .607 Mtetra
.645 .955 .939 r
.41988 .607 .42537 .60686 .43451 .60209 .42905 .60242 Mtetra
.363 .833 .868 r
.42905 .60242 .43451 .60209 .44362 .59966 .43819 .59995 Mtetra
0 0 0 r
.43819 .59995 .44362 .59966 .4527 .59958 .44732 .59959 Mtetra
.259 0 0 r
.44732 .59959 .4527 .59958 .4618 .60173 .45644 .60125 Mtetra
.428 0 0 r
.45644 .60125 .4618 .60173 .47091 .60593 .46559 .60475 Mtetra
.519 0 0 r
.46559 .60475 .47091 .60593 .48008 .61188 .47479 .60983 Mtetra
.553 0 0 r
.47479 .60983 .48008 .61188 .4893 .61923 .48404 .61615 Mtetra
.533 0 0 r
.48404 .61615 .4893 .61923 .49861 .62753 .49337 .62333 Mtetra
.449 0 0 r
.49337 .62333 .49861 .62753 .50801 .6363 .50278 .63093 Mtetra
0 .179 .679 r
.50278 .63093 .50801 .6363 .5175 .64504 .51228 .63848 Mtetra
0 .294 .789 r
.51228 .63848 .5175 .64504 .52709 .6532 .52187 .64551 Mtetra
.135 .395 .846 r
.52187 .64551 .52709 .6532 .53677 .66028 .53155 .65157 Mtetra
.311 .471 .858 r
.53155 .65157 .53677 .66028 .54653 .66582 .54131 .65623 Mtetra
.442 .523 .845 r
.54131 .65623 .54653 .66582 .55636 .6694 .55112 .65914 Mtetra
.537 .56 .826 r
.55112 .65914 .55636 .6694 .56622 .67072 .56099 .66001 Mtetra
.607 .588 .806 r
.56099 .66001 .56622 .67072 .57611 .66956 .57088 .65866 Mtetra
.661 .612 .788 r
.57088 .65866 .57611 .66956 .586 .66583 .58078 .65501 Mtetra
.704 .633 .775 r
.58078 .65501 .586 .66583 .59586 .65959 .59066 .64911 Mtetra
.739 .653 .764 r
.59066 .64911 .59586 .65959 .60569 .65099 .60052 .64108 Mtetra
.769 .673 .757 r
.60052 .64108 .60569 .65099 .61547 .64031 .61034 .63119 Mtetra
.795 .694 .753 r
.61034 .63119 .61547 .64031 .62518 .62793 .62011 .61977 Mtetra
.819 .717 .753 r
.62011 .61977 .62518 .62793 .63484 .61429 .62983 .60722 Mtetra
.839 .742 .756 r
.62983 .60722 .63484 .61429 .64444 .59991 .6395 .59398 Mtetra
.858 .77 .764 r
.6395 .59398 .64444 .59991 .654 .58531 .64915 .58055 Mtetra
.873 .802 .777 r
.64915 .58055 .654 .58531 .66355 .57102 .65878 .56738 Mtetra
.884 .839 .796 r
.65878 .56738 .66355 .57102 .67309 .55755 .66841 .55494 Mtetra
.886 .881 .823 r
.66841 .55494 .67309 .55755 .68267 .54535 .67807 .54364 Mtetra
.871 .926 .859 r
.67807 .54364 .68267 .54535 .69231 .53482 .6878 .53385 Mtetra
.822 .965 .899 r
.6878 .53385 .69231 .53482 .70205 .5263 .69761 .52585 Mtetra
.709 .973 .926 r
.69761 .52585 .70205 .5263 .71191 .52001 .70754 .51987 Mtetra
.503 .906 .908 r
.70754 .51987 .71191 .52001 .72194 .51609 .71761 .51602 Mtetra
.23 .749 .825 r
.71761 .51602 .72194 .51609 .73214 .51459 .72784 .51436 Mtetra
0 .555 .712 r
.72784 .51436 .73214 .51459 .74254 .51545 .73825 .51482 Mtetra
.208 0 0 r
.73825 .51482 .74254 .51545 .75315 .51851 .74886 .51727 Mtetra
.311 0 0 r
.74886 .51727 .75315 .51851 .76398 .52354 .75967 .52149 Mtetra
.345 0 0 r
.75967 .52149 .76398 .52354 .77502 .5302 .77066 .52716 Mtetra
0 .226 .654 r
.77066 .52716 .77502 .5302 .78626 .53807 .78183 .53392 Mtetra
0 .256 .725 r
.78183 .53392 .78626 .53807 .79766 .54668 .79316 .54134 Mtetra
0 .31 .793 r
.79316 .54134 .79766 .54668 .80919 .55552 .8046 .54896 Mtetra
.048 .372 .839 r
.8046 .54896 .80919 .55552 .82081 .56404 .81614 .55629 Mtetra
.195 .429 .859 r
.81614 .55629 .82081 .56404 .83247 .57172 .82771 .56285 Mtetra
.323 .477 .858 r
.82771 .56285 .83247 .57172 .84412 .57804 .83927 .56818 Mtetra
.428 .516 .846 r
.83927 .56818 .84412 .57804 .85569 .58255 .85077 .57188 Mtetra
.513 .548 .829 r
.85077 .57188 .85569 .58255 .86713 .58488 .86216 .57362 Mtetra
.58 .575 .812 r
.86216 .57362 .86713 .58488 .8784 .58474 .87341 .57316 Mtetra
.636 .6 .796 r
.87341 .57316 .8784 .58474 .88944 .582 .88446 .57035 Mtetra
.683 .624 .783 r
.88446 .57035 .88944 .582 .90024 .57662 .8953 .56519 Mtetra
.723 .646 .772 r
.8953 .56519 .90024 .57662 .91079 .56872 .90591 .55775 Mtetra
.758 .67 .764 r
.90591 .55775 .91079 .56872 .92107 .55852 .9163 .54826 Mtetra
.79 .694 .759 r
.9163 .54826 .92107 .55852 .93111 .54636 .92648 .53701 Mtetra
.818 .72 .757 r
.92648 .53701 .93111 .54636 .94095 .53267 .93648 .52438 Mtetra
.844 .748 .758 r
.93648 .52438 .94095 .53267 .95062 .51796 .94633 .51081 Mtetra
.867 .78 .763 r
.94633 .51081 .95062 .51796 .9602 .50275 .9561 .4968 Mtetra
.841 .763 .777 r
.35813 .66383 .36369 .66869 .37319 .65589 .36761 .65205 Mtetra
.852 .792 .792 r
.36761 .65205 .37319 .65589 .38264 .64359 .37706 .6407 Mtetra
.858 .825 .814 r
.37706 .6407 .38264 .64359 .39204 .63219 .38647 .63016 Mtetra
.856 .863 .845 r
.38647 .63016 .39204 .63219 .40138 .6221 .39582 .62079 Mtetra
.837 .905 .885 r
.39582 .62079 .40138 .6221 .41066 .61362 .40511 .61287 Mtetra
.784 .942 .929 r
.40511 .61287 .41066 .61362 .41988 .607 .41436 .60662 Mtetra
.662 .946 .958 r
.41436 .60662 .41988 .607 .42905 .60242 .42356 .60221 Mtetra
.438 .867 .928 r
.42356 .60221 .42905 .60242 .43819 .59995 .43273 .59971 Mtetra
.141 .685 .811 r
.43273 .59971 .43819 .59995 .44732 .59959 .44189 .5991 Mtetra
.125 0 0 r
.44189 .5991 .44732 .59959 .45644 .60125 .45105 .60031 Mtetra
.305 0 0 r
.45105 .60031 .45644 .60125 .46559 .60475 .46024 .60318 Mtetra
.405 0 0 r
.46024 .60318 .46559 .60475 .47479 .60983 .46946 .60746 Mtetra
.439 0 0 r
.46946 .60746 .47479 .60983 .48404 .61615 .47874 .61286 Mtetra
.413 0 0 r
.47874 .61286 .48404 .61615 .49337 .62333 .48809 .61902 Mtetra
0 .196 .658 r
.48809 .61902 .49337 .62333 .50278 .63093 .49751 .62555 Mtetra
0 .276 .76 r
.49751 .62555 .50278 .63093 .51228 .63848 .50703 .63204 Mtetra
.017 .366 .836 r
.50703 .63204 .51228 .63848 .52187 .64551 .51662 .63805 Mtetra
.198 .444 .87 r
.51662 .63805 .52187 .64551 .53155 .65157 .5263 .64318 Mtetra
.347 .502 .87 r
.5263 .64318 .53155 .65157 .54131 .65623 .53606 .64706 Mtetra
.461 .544 .855 r
.53606 .64706 .54131 .65623 .55112 .65914 .54588 .64935 Mtetra
.547 .575 .835 r
.54588 .64935 .55112 .65914 .56099 .66001 .55574 .64982 Mtetra
.611 .6 .815 r
.55574 .64982 .56099 .66001 .57088 .65866 .56564 .6483 Mtetra
.662 .621 .798 r
.56564 .6483 .57088 .65866 .58078 .65501 .57555 .64472 Mtetra
.703 .641 .785 r
.57555 .64472 .58078 .65501 .59066 .64911 .58545 .63911 Mtetra
.736 .66 .774 r
.58545 .63911 .59066 .64911 .60052 .64108 .59534 .63161 Mtetra
.765 .679 .768 r
.59534 .63161 .60052 .64108 .61034 .63119 .60519 .62242 Mtetra
.79 .699 .764 r
.60519 .62242 .61034 .63119 .62011 .61977 .61501 .61186 Mtetra
.812 .721 .764 r
.61501 .61186 .62011 .61977 .62983 .60722 .62479 .60028 Mtetra
.832 .745 .768 r
.62479 .60028 .62983 .60722 .6395 .59398 .63453 .58808 Mtetra
.849 .771 .776 r
.63453 .58808 .6395 .59398 .64915 .58055 .64425 .57569 Mtetra
.862 .802 .79 r
.64425 .57569 .64915 .58055 .65878 .56738 .65396 .56353 Mtetra
.871 .836 .809 r
.65396 .56353 .65878 .56738 .66841 .55494 .66368 .55203 Mtetra
.871 .874 .837 r
.66368 .55203 .66841 .55494 .67807 .54364 .67342 .54154 Mtetra
.855 .915 .872 r
.67342 .54154 .67807 .54364 .6878 .53385 .68322 .53241 Mtetra
.811 .949 .911 r
.68322 .53241 .6878 .53385 .69761 .52585 .6931 .5249 Mtetra
.716 .96 .945 r
.6931 .5249 .69761 .52585 .70754 .51987 .70309 .51919 Mtetra
.551 .918 .948 r
.70309 .51919 .70754 .51987 .71761 .51602 .7132 .51541 Mtetra
.326 .804 .902 r
.7132 .51541 .71761 .51602 .72784 .51436 .72347 .51359 Mtetra
.1 .649 .824 r
.72347 .51359 .72784 .51436 .73825 .51482 .7339 .51369 Mtetra
0 .503 .752 r
.7339 .51369 .73825 .51482 .74886 .51727 .7445 .51558 Mtetra
0 .4 .716 r
.7445 .51558 .74886 .51727 .75967 .52149 .75529 .51906 Mtetra
0 .343 .718 r
.75529 .51906 .75967 .52149 .77066 .52716 .76624 .52384 Mtetra
0 .328 .751 r
.76624 .52384 .77066 .52716 .78183 .53392 .77736 .5296 Mtetra
0 .345 .798 r
.77736 .5296 .78183 .53392 .79316 .54134 .78862 .53594 Mtetra
0 .382 .842 r
.78862 .53594 .79316 .54134 .8046 .54896 .8 .54246 Mtetra
.122 .426 .869 r
.8 .54246 .8046 .54896 .81614 .55629 .81145 .5487 Mtetra
.247 .469 .876 r
.81145 .5487 .81614 .55629 .82771 .56285 .82295 .55425 Mtetra
.357 .506 .87 r
.82295 .55425 .82771 .56285 .83927 .56818 .83444 .55869 Mtetra
.449 .537 .855 r
.83444 .55869 .83927 .56818 .85077 .57188 .84588 .56167 Mtetra
.524 .564 .838 r
.84588 .56167 .85077 .57188 .86216 .57362 .85724 .56288 Mtetra
.587 .588 .821 r
.85724 .56288 .86216 .57362 .87341 .57316 .86846 .56212 Mtetra
.638 .611 .806 r
.86846 .56212 .87341 .57316 .88446 .57035 .87952 .55926 Mtetra
.683 .632 .793 r
.87952 .55926 .88446 .57035 .8953 .56519 .8904 .55428 Mtetra
.721 .654 .783 r
.8904 .55428 .8953 .56519 .90591 .55775 .90108 .54727 Mtetra
.754 .676 .775 r
.90108 .54727 .90591 .55775 .9163 .54826 .91156 .5384 Mtetra
.784 .699 .77 r
.91156 .5384 .9163 .54826 .92648 .53701 .92187 .52796 Mtetra
.811 .724 .769 r
.92187 .52796 .92648 .53701 .93648 .52438 .93201 .51627 Mtetra
.835 .751 .771 r
.93201 .51627 .93648 .52438 .94633 .51081 .94203 .50374 Mtetra
.856 .781 .777 r
.94203 .50374 .94633 .51081 .9561 .4968 .95198 .4908 Mtetra
.833 .765 .787 r
.35253 .65894 .35813 .66383 .36761 .65205 .36201 .64807 Mtetra
.842 .792 .803 r
.36201 .64807 .36761 .65205 .37706 .6407 .37145 .63758 Mtetra
.846 .823 .825 r
.37145 .63758 .37706 .6407 .38647 .63016 .38086 .62782 Mtetra
.842 .857 .855 r
.38086 .62782 .38647 .63016 .39582 .62079 .39022 .6191 Mtetra
.823 .894 .893 r
.39022 .6191 .39582 .62079 .40511 .61287 .39953 .61169 Mtetra
.774 .926 .935 r
.39953 .61169 .40511 .61287 .41436 .60662 .4088 .60578 Mtetra
.673 .933 .969 r
.4088 .60578 .41436 .60662 .42356 .60221 .41803 .60152 Mtetra
.494 .882 .964 r
.41803 .60152 .42356 .60221 .43273 .59971 .42723 .59898 Mtetra
.251 .752 .895 r
.42723 .59898 .43273 .59971 .44189 .5991 .43643 .59815 Mtetra
.011 .578 .785 r
.43643 .59815 .44189 .5991 .45105 .60031 .44562 .59895 Mtetra
0 .423 .689 r
.44562 .59895 .45105 .60031 .46024 .60318 .45484 .60124 Mtetra
.272 0 0 r
.45484 .60124 .46024 .60318 .46946 .60746 .46409 .6048 Mtetra
0 .267 .64 r
.46409 .6048 .46946 .60746 .47874 .61286 .4734 .60936 Mtetra
0 .265 .684 r
.4734 .60936 .47874 .61286 .48809 .61902 .48277 .6146 Mtetra
0 .301 .754 r
.48277 .6146 .48809 .61902 .49751 .62555 .49222 .62017 Mtetra
0 .362 .825 r
.49222 .62017 .49751 .62555 .50703 .63204 .50174 .62569 Mtetra
.104 .429 .871 r
.50174 .62569 .50703 .63204 .51662 .63805 .51135 .63078 Mtetra
.255 .486 .887 r
.51135 .63078 .51662 .63805 .5263 .64318 .52103 .63508 Mtetra
.381 .531 .881 r
.52103 .63508 .5263 .64318 .53606 .64706 .53079 .63824 Mtetra
.48 .564 .863 r
.53079 .63824 .53606 .64706 .54588 .64935 .54061 .63999 Mtetra
.556 .59 .843 r
.54061 .63999 .54588 .64935 .55574 .64982 .55048 .6401 Mtetra
.615 .611 .824 r
.55048 .6401 .55574 .64982 .56564 .6483 .56038 .63842 Mtetra
.663 .631 .807 r
.56038 .63842 .56564 .6483 .57555 .64472 .5703 .6349 Mtetra
.701 .649 .794 r
.5703 .6349 .57555 .64472 .58545 .63911 .58023 .62956 Mtetra
.733 .666 .784 r
.58023 .62956 .58545 .63911 .59534 .63161 .59014 .62251 Mtetra
.761 .685 .778 r
.59014 .62251 .59534 .63161 .60519 .62242 .60003 .61396 Mtetra
.784 .704 .775 r
.60003 .61396 .60519 .62242 .61501 .61186 .6099 .60417 Mtetra
.805 .725 .775 r
.6099 .60417 .61501 .61186 .62479 .60028 .61973 .59346 Mtetra
.824 .747 .78 r
.61973 .59346 .62479 .60028 .63453 .58808 .62954 .58219 Mtetra
.839 .773 .788 r
.62954 .58219 .63453 .58808 .64425 .57569 .63932 .57074 Mtetra
.851 .801 .802 r
.63932 .57074 .64425 .57569 .65396 .56353 .6491 .5595 Mtetra
.857 .833 .821 r
.6491 .5595 .65396 .56353 .66368 .55203 .6589 .54884 Mtetra
.856 .868 .848 r
.6589 .54884 .66368 .55203 .67342 .54154 .66871 .53909 Mtetra
.84 .903 .882 r
.66871 .53909 .67342 .54154 .68322 .53241 .67859 .53055 Mtetra
.799 .933 .92 r
.67859 .53055 .68322 .53241 .6931 .5249 .68853 .52347 Mtetra
.718 .945 .955 r
.68853 .52347 .6931 .5249 .70309 .51919 .69857 .51801 Mtetra
.584 .917 .971 r
.69857 .51801 .70309 .51919 .7132 .51541 .70873 .51429 Mtetra
.403 .836 .951 r
.70873 .51429 .7132 .51541 .72347 .51359 .71903 .51234 Mtetra
.211 .716 .902 r
.71903 .51234 .72347 .51359 .7339 .51369 .72947 .51211 Mtetra
.053 .594 .849 r
.72947 .51211 .7339 .51369 .7445 .51558 .74008 .51348 Mtetra
0 .498 .816 r
.74008 .51348 .7445 .51558 .75529 .51906 .75085 .51629 Mtetra
0 .44 .811 r
.75085 .51629 .75529 .51906 .76624 .52384 .76177 .52026 Mtetra
0 .417 .828 r
.76177 .52026 .76624 .52384 .77736 .5296 .77285 .52511 Mtetra
0 .422 .855 r
.77285 .52511 .77736 .5296 .78862 .53594 .78406 .53048 Mtetra
.083 .444 .879 r
.78406 .53048 .78862 .53594 .8 .54246 .79537 .53599 Mtetra
.189 .473 .891 r
.79537 .53599 .8 .54246 .81145 .5487 .80676 .54126 Mtetra
.293 .504 .89 r
.80676 .54126 .81145 .5487 .82295 .55425 .81819 .54589 Mtetra
.387 .532 .879 r
.81819 .54589 .82295 .55425 .83444 .55869 .82962 .54953 Mtetra
.468 .557 .864 r
.82962 .54953 .83444 .55869 .84588 .56167 .84101 .55186 Mtetra
.535 .58 .846 r
.84101 .55186 .84588 .56167 .85724 .56288 .85233 .5526 Mtetra
.592 .601 .83 r
.85233 .5526 .85724 .56288 .86846 .56212 .86354 .55156 Mtetra
.641 .621 .815 r
.86354 .55156 .86846 .56212 .87952 .55926 .87462 .54864 Mtetra
.682 .641 .802 r
.87462 .54864 .87952 .55926 .8904 .55428 .88553 .54383 Mtetra
.718 .661 .793 r
.88553 .54383 .8904 .55428 .90108 .54727 .89627 .53719 Mtetra
.75 .682 .786 r
.89627 .53719 .90108 .54727 .91156 .5384 .90685 .5289 Mtetra
.778 .704 .782 r
.90685 .5289 .91156 .5384 .92187 .52796 .91726 .51917 Mtetra
.804 .728 .781 r
.91726 .51917 .92187 .52796 .93201 .51627 .92755 .50834 Mtetra
.826 .754 .783 r
.92755 .50834 .93201 .51627 .94203 .50374 .93772 .49674 Mtetra
.845 .782 .79 r
.93772 .49674 .94203 .50374 .95198 .4908 .94784 .48476 Mtetra
.824 .766 .798 r
.34689 .65403 .35253 .65894 .36201 .64807 .35636 .64397 Mtetra
.832 .791 .813 r
.35636 .64397 .36201 .64807 .37145 .63758 .36581 .63426 Mtetra
.834 .82 .835 r
.36581 .63426 .37145 .63758 .38086 .62782 .37522 .6252 Mtetra
.829 .851 .863 r
.37522 .6252 .38086 .62782 .39022 .6191 .38459 .61707 Mtetra
.809 .883 .899 r
.38459 .61707 .39022 .6191 .39953 .61169 .39392 .61012 Mtetra
.765 .911 .939 r
.39392 .61012 .39953 .61169 .4088 .60578 .40321 .60451 Mtetra
.678 .919 .973 r
.40321 .60451 .4088 .60578 .41803 .60152 .41247 .60039 Mtetra
.535 .885 .983 r
.41247 .60039 .41803 .60152 .42723 .59898 .4217 .59781 Mtetra
.339 .793 .948 r
.4217 .59781 .42723 .59898 .43643 .59815 .43093 .59677 Mtetra
.135 .66 .877 r
.43093 .59677 .43643 .59815 .44562 .59895 .44016 .5972 Mtetra
0 .529 .804 r
.44016 .5972 .44562 .59895 .45484 .60124 .44941 .59896 Mtetra
0 .433 .76 r
.44941 .59896 .45484 .60124 .46409 .6048 .45869 .60187 Mtetra
0 .381 .755 r
.45869 .60187 .46409 .6048 .4734 .60936 .46803 .60567 Mtetra
0 .371 .783 r
.46803 .60567 .4734 .60936 .48277 .6146 .47742 .61008 Mtetra
0 .393 .829 r
.47742 .61008 .48277 .6146 .49222 .62017 .48688 .61477 Mtetra
.049 .435 .872 r
.48688 .61477 .49222 .62017 .50174 .62569 .49642 .61942 Mtetra
.181 .481 .897 r
.49642 .61942 .50174 .62569 .51135 .63078 .50604 .62368 Mtetra
.305 .523 .901 r
.50604 .62368 .51135 .63078 .52103 .63508 .51574 .62722 Mtetra
.411 .556 .889 r
.51574 .62722 .52103 .63508 .53079 .63824 .5255 .62975 Mtetra
.497 .582 .871 r
.5255 .62975 .53079 .63824 .54061 .63999 .53532 .631 Mtetra
.565 .604 .851 r
.53532 .631 .54061 .63999 .55048 .6401 .5452 .63078 Mtetra
.619 .622 .832 r
.5452 .63078 .55048 .6401 .56038 .63842 .55511 .62896 Mtetra
.663 .639 .816 r
.55511 .62896 .56038 .63842 .5703 .6349 .56505 .62549 Mtetra
.699 .656 .804 r
.56505 .62549 .5703 .6349 .58023 .62956 .57499 .62038 Mtetra
.73 .673 .794 r
.57499 .62038 .58023 .62956 .59014 .62251 .58493 .61375 Mtetra
.756 .69 .788 r
.58493 .61375 .59014 .62251 .60003 .61396 .59485 .60577 Mtetra
.779 .708 .786 r
.59485 .60577 .60003 .61396 .6099 .60417 .60476 .59667 Mtetra
.798 .728 .786 r
.60476 .59667 .6099 .60417 .61973 .59346 .61464 .58674 Mtetra
.815 .75 .791 r
.61464 .58674 .61973 .59346 .62954 .58219 .62451 .57631 Mtetra
.829 .774 .8 r
.62451 .57631 .62954 .58219 .63932 .57074 .63436 .56571 Mtetra
.839 .8 .813 r
.63436 .56571 .63932 .57074 .6491 .5595 .64421 .55529 Mtetra
.844 .83 .833 r
.64421 .55529 .6491 .5595 .6589 .54884 .65407 .54539 Mtetra
.841 .861 .858 r
.65407 .54539 .6589 .54884 .66871 .53909 .66396 .53631 Mtetra
.825 .892 .89 r
.66396 .53631 .66871 .53909 .67859 .53055 .67389 .52831 Mtetra
.787 .918 .926 r
.67389 .52831 .67859 .53055 .68853 .52347 .6839 .52162 Mtetra
.718 .928 .961 r
.6839 .52162 .68853 .52347 .69857 .51801 .69399 .51639 Mtetra
.608 .909 .982 r
.69399 .51639 .69857 .51801 .70873 .51429 .70419 .51271 Mtetra
.461 .851 .979 r
.70419 .51271 .70873 .51429 .71903 .51234 .71452 .51063 Mtetra
.302 .76 .952 r
.71452 .51063 .71903 .51234 .72947 .51211 .72498 .5101 Mtetra
.165 .66 .916 r
.72498 .5101 .72947 .51211 .74008 .51348 .73559 .51101 Mtetra
.073 .576 .889 r
.73559 .51101 .74008 .51348 .75085 .51629 .74635 .5132 Mtetra
.032 .52 .88 r
.74635 .5132 .75085 .51629 .76177 .52026 .75725 .51644 Mtetra
.04 .491 .885 r
.75725 .51644 .76177 .52026 .77285 .52511 .76829 .52046 Mtetra
.088 .486 .897 r
.76829 .52046 .77285 .52511 .78406 .53048 .77945 .52495 Mtetra
.162 .496 .906 r
.77945 .52495 .78406 .53048 .79537 .53599 .79072 .52956 Mtetra
.249 .514 .908 r
.79072 .52956 .79537 .53599 .80676 .54126 .80205 .53394 Mtetra
.335 .535 .901 r
.80205 .53394 .80676 .54126 .81819 .54589 .81342 .53775 Mtetra
.415 .556 .887 r
.81342 .53775 .81819 .54589 .82962 .54953 .82481 .54067 Mtetra
.485 .576 .871 r
.82481 .54067 .82962 .54953 .84101 .55186 .83616 .5424 Mtetra
.546 .594 .854 r
.83616 .5424 .84101 .55186 .85233 .5526 .84745 .54271 Mtetra
.598 .613 .838 r
.84745 .54271 .85233 .5526 .86354 .55156 .85866 .54143 Mtetra
.642 .631 .823 r
.85866 .54143 .86354 .55156 .87462 .54864 .86974 .53846 Mtetra
.681 .649 .812 r
.86974 .53846 .87462 .54864 .88553 .54383 .88069 .53379 Mtetra
.715 .668 .802 r
.88069 .53379 .88553 .54383 .89627 .53719 .89149 .52749 Mtetra
.745 .688 .796 r
.89149 .52749 .89627 .53719 .90685 .5289 .90215 .5197 Mtetra
.772 .709 .792 r
.90215 .5197 .90685 .5289 .91726 .51917 .91267 .51063 Mtetra
.796 .731 .792 r
.91267 .51063 .91726 .51917 .92755 .50834 .92308 .50055 Mtetra
.817 .756 .795 r
.92308 .50055 .92755 .50834 .93772 .49674 .93339 .48979 Mtetra
.834 .782 .803 r
.93339 .48979 .93772 .49674 .94784 .48476 .94366 .47868 Mtetra
.815 .767 .808 r
.34122 .64908 .34689 .65403 .35636 .64397 .35069 .63976 Mtetra
.821 .791 .823 r
.35069 .63976 .35636 .64397 .36581 .63426 .36013 .63075 Mtetra
.823 .817 .844 r
.36013 .63075 .36581 .63426 .37522 .6252 .36955 .62233 Mtetra
.816 .845 .871 r
.36955 .62233 .37522 .6252 .38459 .61707 .37893 .61473 Mtetra
.796 .873 .904 r
.37893 .61473 .38459 .61707 .39392 .61012 .38827 .60819 Mtetra
.755 .896 .941 r
.38827 .60819 .39392 .61012 .40321 .60451 .39759 .60286 Mtetra
.681 .904 .975 r
.39759 .60286 .40321 .60451 .41247 .60039 .40687 .59886 Mtetra
.564 .881 .992 r
.40687 .59886 .41247 .60039 .4217 .59781 .41613 .59625 Mtetra
.408 .816 .979 r
.41613 .59625 .4217 .59781 .43093 .59677 .42539 .59502 Mtetra
.24 .717 .937 r
.42539 .59502 .43093 .59677 .44016 .5972 .43465 .5951 Mtetra
.097 .612 .887 r
.43465 .5951 .44016 .5972 .44941 .59896 .44394 .59639 Mtetra
.003 .528 .852 r
.44394 .59639 .44941 .59896 .45869 .60187 .45325 .5987 Mtetra
0 .477 .844 r
.45325 .5987 .45869 .60187 .46803 .60567 .46261 .60181 Mtetra
0 .46 .858 r
.46261 .60181 .46803 .60567 .47742 .61008 .47203 .60546 Mtetra
.047 .47 .883 r
.47203 .60546 .47742 .61008 .48688 .61477 .48152 .60937 Mtetra
.141 .495 .906 r
.48152 .60937 .48688 .61477 .49642 .61942 .49107 .61323 Mtetra
.247 .525 .915 r
.49107 .61323 .49642 .61942 .50604 .62368 .50071 .61673 Mtetra
.349 .554 .911 r
.50071 .61673 .50604 .62368 .51574 .62722 .51041 .61959 Mtetra
.439 .578 .896 r
.51041 .61959 .51574 .62722 .5255 .62975 .52018 .62154 Mtetra
.513 .599 .877 r
.52018 .62154 .5255 .62975 .53532 .631 .53002 .62234 Mtetra
.573 .617 .858 r
.53002 .62234 .53532 .631 .5452 .63078 .5399 .62183 Mtetra
.623 .633 .84 r
.5399 .62183 .5452 .63078 .55511 .62896 .54982 .61988 Mtetra
.663 .648 .825 r
.54982 .61988 .55511 .62896 .56505 .62549 .55977 .61645 Mtetra
.697 .663 .813 r
.55977 .61645 .56505 .62549 .57499 .62038 .56973 .61155 Mtetra
.726 .679 .804 r
.56973 .61155 .57499 .62038 .58493 .61375 .5797 .60529 Mtetra
.751 .695 .798 r
.5797 .60529 .58493 .61375 .59485 .60577 .58965 .59782 Mtetra
.772 .712 .796 r
.58965 .59782 .59485 .60577 .60476 .59667 .5996 .58934 Mtetra
.791 .731 .797 r
.5996 .58934 .60476 .59667 .61464 .58674 .60953 .58012 Mtetra
.807 .752 .802 r
.60953 .58012 .61464 .58674 .62451 .57631 .61945 .57043 Mtetra
.819 .774 .81 r
.61945 .57043 .62451 .57631 .63436 .56571 .62936 .5606 Mtetra
.828 .799 .824 r
.62936 .5606 .63436 .56571 .64421 .55529 .63927 .55093 Mtetra
.831 .826 .843 r
.63927 .55093 .64421 .55529 .65407 .54539 .64919 .54171 Mtetra
.827 .854 .867 r
.64919 .54171 .65407 .54539 .66396 .53631 .65914 .53323 Mtetra
.81 .881 .897 r
.65914 .53323 .66396 .53631 .67389 .52831 .66914 .52572 Mtetra
.775 .903 .93 r
.66914 .52572 .67389 .52831 .6839 .52162 .6792 .51938 Mtetra
.715 .912 .963 r
.6792 .51938 .6839 .52162 .69399 .51639 .68935 .51435 Mtetra
.624 .899 .986 r
.68935 .51435 .69399 .51639 .70419 .51271 .69959 .51072 Mtetra
.504 .855 .993 r
.69959 .51072 .70419 .51271 .71452 .51063 .70995 .50852 Mtetra
.375 .786 .98 r
.70995 .50852 .71452 .51063 .72498 .5101 .72043 .50771 Mtetra
.259 .707 .958 r
.72043 .50771 .72498 .5101 .73559 .51101 .73105 .5082 Mtetra
.177 .635 .938 r
.73105 .5082 .73559 .51101 .74635 .5132 .7418 .50983 Mtetra
.137 .582 .926 r
.7418 .50983 .74635 .5132 .75725 .51644 .75268 .51241 Mtetra
.138 .551 .924 r
.75268 .51241 .75725 .51644 .76829 .52046 .7637 .51568 Mtetra
.173 .538 .925 r
.7637 .51568 .76829 .52046 .77945 .52495 .77482 .51936 Mtetra
.231 .54 .925 r
.77482 .51936 .77945 .52495 .79072 .52956 .78604 .52315 Mtetra
.301 .549 .92 r
.78604 .52315 .79072 .52956 .80205 .53394 .79733 .52673 Mtetra
.373 .562 .909 r
.79733 .52673 .80205 .53394 .81342 .53775 .80865 .5298 Mtetra
.441 .577 .894 r
.80865 .5298 .81342 .53775 .82481 .54067 .82 .53206 Mtetra
.502 .592 .877 r
.82 .53206 .82481 .54067 .83616 .5424 .83132 .53326 Mtetra
.556 .608 .86 r
.83132 .53326 .83616 .5424 .84745 .54271 .84259 .53318 Mtetra
.603 .624 .845 r
.84259 .53318 .84745 .54271 .85866 .54143 .85379 .53167 Mtetra
.644 .64 .831 r
.85379 .53167 .85866 .54143 .86974 .53846 .86489 .52866 Mtetra
.68 .657 .82 r
.86489 .52866 .86974 .53846 .88069 .53379 .87587 .52412 Mtetra
.712 .674 .812 r
.87587 .52412 .88069 .53379 .89149 .52749 .88673 .51812 Mtetra
.74 .693 .806 r
.88673 .51812 .89149 .52749 .90215 .5197 .89747 .51077 Mtetra
.766 .713 .803 r
.89747 .51077 .90215 .5197 .91267 .51063 .90808 .50229 Mtetra
.788 .734 .803 r
.90808 .50229 .91267 .51063 .92308 .50055 .9186 .4929 Mtetra
.807 .757 .807 r
.9186 .4929 .92308 .50055 .93339 .48979 .92905 .48288 Mtetra
.823 .782 .814 r
.92905 .48288 .93339 .48979 .94366 .47868 .93945 .47256 Mtetra
.806 .768 .818 r
.33552 .6441 .34122 .64908 .35069 .63976 .34497 .63545 Mtetra
.811 .79 .833 r
.34497 .63545 .35069 .63976 .36013 .63075 .35442 .62707 Mtetra
.811 .814 .852 r
.35442 .62707 .36013 .63075 .36955 .62233 .36384 .61922 Mtetra
.803 .839 .878 r
.36384 .61922 .36955 .62233 .37893 .61473 .37323 .61211 Mtetra
.784 .863 .908 r
.37323 .61211 .37893 .61473 .38827 .60819 .38259 .60593 Mtetra
.746 .882 .942 r
.38259 .60593 .38827 .60819 .39759 .60286 .39193 .60085 Mtetra
.682 .889 .974 r
.39193 .60085 .39759 .60286 .40687 .59886 .40124 .59696 Mtetra
.586 .873 .994 r
.40124 .59696 .40687 .59886 .41613 .59625 .41053 .59432 Mtetra
.461 .826 .994 r
.41053 .59432 .41613 .59625 .42539 .59502 .41982 .59291 Mtetra
.324 .753 .972 r
.41982 .59291 .42539 .59502 .43465 .5951 .42911 .59269 Mtetra
.204 .671 .941 r
.42911 .59269 .43465 .5951 .44394 .59639 .43843 .59354 Mtetra
.122 .6 .915 r
.43843 .59354 .44394 .59639 .45325 .5987 .44777 .5953 Mtetra
.086 .553 .905 r
.44777 .5953 .45325 .5987 .46261 .60181 .45716 .59779 Mtetra
.097 .532 .909 r
.45716 .59779 .46261 .60181 .47203 .60546 .46661 .60075 Mtetra
.145 .531 .92 r
.46661 .60075 .47203 .60546 .48152 .60937 .47612 .60394 Mtetra
.22 .544 .928 r
.47612 .60394 .48152 .60937 .49107 .61323 .48569 .60709 Mtetra
.305 .562 .927 r
.48569 .60709 .49107 .61323 .50071 .61673 .49534 .60991 Mtetra
.388 .581 .918 r
.49534 .60991 .50071 .61673 .51041 .61959 .50506 .61216 Mtetra
.463 .598 .901 r
.50506 .61216 .51041 .61959 .52018 .62154 .51484 .61358 Mtetra
.527 .614 .882 r
.51484 .61358 .52018 .62154 .53002 .62234 .52468 .61398 Mtetra
.581 .629 .864 r
.52468 .61398 .53002 .62234 .5399 .62183 .53457 .61319 Mtetra
.626 .642 .847 r
.53457 .61319 .5399 .62183 .54982 .61988 .54451 .61112 Mtetra
.663 .656 .832 r
.54451 .61112 .54982 .61988 .55977 .61645 .55447 .60773 Mtetra
.695 .67 .821 r
.55447 .60773 .55977 .61645 .56973 .61155 .56445 .60302 Mtetra
.722 .684 .813 r
.56445 .60302 .56973 .61155 .5797 .60529 .57444 .59709 Mtetra
.746 .7 .808 r
.57444 .59709 .5797 .60529 .58965 .59782 .58443 .59007 Mtetra
.766 .716 .806 r
.58443 .59007 .58965 .59782 .5996 .58934 .59442 .58215 Mtetra
.784 .734 .807 r
.59442 .58215 .5996 .58934 .60953 .58012 .60439 .57357 Mtetra
.798 .753 .812 r
.60439 .57357 .60953 .58012 .61945 .57043 .61436 .56456 Mtetra
.809 .775 .821 r
.61436 .56456 .61945 .57043 .62936 .5606 .62432 .55542 Mtetra
.817 .798 .834 r
.62432 .55542 .62936 .5606 .63927 .55093 .63429 .54642 Mtetra
.819 .822 .852 r
.63429 .54642 .63927 .55093 .64919 .54171 .64427 .53782 Mtetra
.813 .847 .875 r
.64427 .53782 .64919 .54171 .65914 .53323 .65429 .52988 Mtetra
.797 .87 .902 r
.65429 .52988 .65914 .53323 .66914 .52572 .66434 .52281 Mtetra
.764 .889 .933 r
.66434 .52281 .66914 .52572 .6792 .51938 .67446 .51678 Mtetra
.711 .897 .963 r
.67446 .51678 .6792 .51938 .68935 .51435 .68465 .51193 Mtetra
.634 .886 .987 r
.68465 .51193 .68935 .51435 .69959 .51072 .69493 .50834 Mtetra
.537 .853 .998 r
.69493 .50834 .69959 .51072 .70995 .50852 .70532 .50603 Mtetra
.431 .8 .994 r
.70532 .50603 .70995 .50852 .72043 .50771 .71582 .50497 Mtetra
.334 .737 .982 r
.71582 .50497 .72043 .50771 .73105 .5082 .72644 .50507 Mtetra
.263 .676 .967 r
.72644 .50507 .73105 .5082 .7418 .50983 .73719 .5062 Mtetra
.225 .629 .956 r
.73719 .5062 .7418 .50983 .75268 .51241 .74807 .50817 Mtetra
.221 .597 .949 r
.74807 .50817 .75268 .51241 .7637 .51568 .75906 .51076 Mtetra
.246 .58 .944 r
.75906 .51076 .7637 .51568 .77482 .51936 .77015 .51371 Mtetra
.291 .576 .938 r
.77015 .51371 .77482 .51936 .78604 .52315 .78133 .51676 Mtetra
.347 .578 .928 r
.78133 .51676 .78604 .52315 .79733 .52673 .79258 .51962 Mtetra
.406 .586 .915 r
.79258 .51962 .79733 .52673 .80865 .5298 .80387 .52201 Mtetra
.464 .596 .899 r
.80387 .52201 .80865 .5298 .82 .53206 .81518 .52368 Mtetra
.517 .608 .883 r
.81518 .52368 .82 .53206 .83132 .53326 .82648 .52439 Mtetra
.565 .621 .867 r
.82648 .52439 .83132 .53326 .84259 .53318 .83774 .52396 Mtetra
.608 .634 .852 r
.83774 .52396 .84259 .53318 .85379 .53167 .84893 .52225 Mtetra
.646 .649 .839 r
.84893 .52225 .85379 .53167 .86489 .52866 .86005 .51919 Mtetra
.679 .664 .828 r
.86005 .51919 .86489 .52866 .87587 .52412 .87107 .51476 Mtetra
.709 .681 .82 r
.87107 .51476 .87587 .52412 .88673 .51812 .88198 .50902 Mtetra
.736 .698 .815 r
.88198 .50902 .88673 .51812 .89747 .51077 .89279 .50209 Mtetra
.759 .717 .813 r
.89279 .50209 .89747 .51077 .90808 .50229 .90349 .49413 Mtetra
.78 .737 .813 r
.90349 .49413 .90808 .50229 .9186 .4929 .91412 .48535 Mtetra
.798 .759 .817 r
.91412 .48535 .9186 .4929 .92905 .48288 .92468 .47601 Mtetra
.812 .782 .825 r
.92468 .47601 .92905 .48288 .93945 .47256 .93521 .46639 Mtetra
.797 .769 .827 r
.32977 .63908 .33552 .6441 .34497 .63545 .33923 .63104 Mtetra
.801 .789 .841 r
.33923 .63104 .34497 .63545 .35442 .62707 .34867 .62324 Mtetra
.8 .81 .86 r
.34867 .62324 .35442 .62707 .36384 .61922 .3581 .6159 Mtetra
.791 .833 .884 r
.3581 .6159 .36384 .61922 .37323 .61211 .3675 .60922 Mtetra
.772 .854 .912 r
.3675 .60922 .37323 .61211 .38259 .60593 .37688 .60339 Mtetra
.737 .87 .942 r
.37688 .60339 .38259 .60593 .39193 .60085 .38624 .59853 Mtetra
.682 .876 .971 r
.38624 .59853 .39193 .60085 .40124 .59696 .39557 .59474 Mtetra
.602 .864 .992 r
.39557 .59474 .40124 .59696 .41053 .59432 .40489 .59206 Mtetra
.5 .829 .999 r
.40489 .59206 .41053 .59432 .41982 .59291 .41421 .59049 Mtetra
.39 .774 .99 r
.41421 .59049 .41982 .59291 .42911 .59269 .42354 .58998 Mtetra
.292 .711 .972 r
.42354 .58998 .42911 .59269 .43843 .59354 .43288 .59044 Mtetra
.221 .653 .954 r
.43288 .59044 .43843 .59354 .44777 .5953 .44226 .59171 Mtetra
.188 .61 .944 r
.44226 .59171 .44777 .5953 .45716 .59779 .45168 .59362 Mtetra
.192 .586 .942 r
.45168 .59362 .45716 .59779 .46661 .60075 .46115 .59596 Mtetra
.229 .579 .943 r
.46115 .59596 .46661 .60075 .47612 .60394 .47068 .5985 Mtetra
.286 .583 .942 r
.47068 .5985 .47612 .60394 .48569 .60709 .48028 .601 Mtetra
.354 .592 .935 r
.48028 .601 .48569 .60709 .49534 .60991 .48994 .60321 Mtetra
.422 .604 .922 r
.48994 .60321 .49534 .60991 .50506 .61216 .49967 .60489 Mtetra
.485 .616 .905 r
.49967 .60489 .50506 .61216 .51484 .61358 .50947 .60584 Mtetra
.541 .628 .887 r
.50947 .60584 .51484 .61358 .52468 .61398 .51932 .60587 Mtetra
.588 .64 .869 r
.51932 .60587 .52468 .61398 .53457 .61319 .52923 .60484 Mtetra
.629 .651 .853 r
.52923 .60484 .53457 .61319 .54451 .61112 .53917 .60266 Mtetra
.663 .663 .84 r
.53917 .60266 .54451 .61112 .55447 .60773 .54915 .59929 Mtetra
.693 .676 .829 r
.54915 .59929 .55447 .60773 .56445 .60302 .55915 .59475 Mtetra
.719 .69 .821 r
.55915 .59475 .56445 .60302 .57444 .59709 .56917 .58912 Mtetra
.741 .704 .817 r
.56917 .58912 .57444 .59709 .58443 .59007 .57919 .58251 Mtetra
.76 .72 .815 r
.57919 .58251 .58443 .59007 .59442 .58215 .5892 .5751 Mtetra
.776 .736 .817 r
.5892 .5751 .59442 .58215 .60439 .57357 .59922 .56708 Mtetra
.789 .755 .822 r
.59922 .56708 .60439 .57357 .61436 .56456 .60923 .55869 Mtetra
.799 .775 .83 r
.60923 .55869 .61436 .56456 .62432 .55542 .61925 .55017 Mtetra
.805 .796 .843 r
.61925 .55017 .62432 .55542 .63429 .54642 .62927 .54177 Mtetra
.806 .818 .86 r
.62927 .54177 .63429 .54642 .64427 .53782 .63931 .53373 Mtetra
.8 .84 .882 r
.63931 .53373 .64427 .53782 .65429 .52988 .64938 .52628 Mtetra
.784 .861 .907 r
.64938 .52628 .65429 .52988 .66434 .52281 .65949 .5196 Mtetra
.754 .876 .935 r
.65949 .5196 .66434 .52281 .67446 .51678 .66965 .51386 Mtetra
.707 .882 .962 r
.66965 .51386 .67446 .51678 .68465 .51193 .67989 .50918 Mtetra
.642 .874 .984 r
.67989 .50918 .68465 .51193 .69493 .50834 .69021 .50562 Mtetra
.561 .848 .997 r
.69021 .50562 .69493 .50834 .70532 .50603 .70063 .50321 Mtetra
.474 .807 .999 r
.70063 .50321 .70532 .50603 .71582 .50497 .71115 .50191 Mtetra
.394 .756 .993 r
.71115 .50191 .71582 .50497 .72644 .50507 .72179 .50166 Mtetra
.333 .706 .983 r
.72179 .50166 .72644 .50507 .73719 .5062 .73254 .50233 Mtetra
.298 .663 .972 r
.73254 .50233 .73719 .5062 .74807 .50817 .74341 .50374 Mtetra
.291 .633 .964 r
.74341 .50374 .74807 .50817 .75906 .51076 .75438 .50571 Mtetra
.308 .614 .955 r
.75438 .50571 .75906 .51076 .77015 .51371 .76545 .50801 Mtetra
.342 .605 .946 r
.76545 .50801 .77015 .51371 .78133 .51676 .7766 .51038 Mtetra
.387 .603 .934 r
.7766 .51038 .78133 .51676 .79258 .51962 .78782 .51258 Mtetra
.436 .607 .919 r
.78782 .51258 .79258 .51962 .80387 .52201 .79908 .51436 Mtetra
.485 .613 .903 r
.79908 .51436 .80387 .52201 .81518 .52368 .81036 .51549 Mtetra
.531 .622 .887 r
.81036 .51549 .81518 .52368 .82648 .52439 .82164 .51576 Mtetra
.574 .633 .872 r
.82164 .51576 .82648 .52439 .83774 .52396 .83289 .51501 Mtetra
.612 .644 .858 r
.83289 .51501 .83774 .52396 .84893 .52225 .84409 .51312 Mtetra
.647 .657 .846 r
.84409 .51312 .84893 .52225 .86005 .51919 .85522 .51001 Mtetra
.678 .671 .836 r
.85522 .51001 .86005 .51919 .87107 .51476 .86627 .50568 Mtetra
.706 .686 .829 r
.86627 .50568 .87107 .51476 .88198 .50902 .87723 .50018 Mtetra
.731 .703 .824 r
.87723 .50018 .88198 .50902 .89279 .50209 .88811 .49361 Mtetra
.753 .72 .822 r
.88811 .49361 .89279 .50209 .90349 .49413 .8989 .48612 Mtetra
.772 .739 .823 r
.8989 .48612 .90349 .49413 .91412 .48535 .90963 .47789 Mtetra
.788 .759 .827 r
.90963 .47789 .91412 .48535 .92468 .47601 .9203 .46917 Mtetra
.801 .781 .835 r
.9203 .46917 .92468 .47601 .93521 .46639 .93095 .46018 Mtetra
.788 .769 .836 r
.32399 .63404 .32977 .63908 .33923 .63104 .33344 .62654 Mtetra
.791 .787 .85 r
.33344 .62654 .33923 .63104 .34867 .62324 .34289 .61926 Mtetra
.789 .807 .867 r
.34289 .61926 .34867 .62324 .3581 .6159 .35232 .61238 Mtetra
.78 .827 .889 r
.35232 .61238 .3581 .6159 .3675 .60922 .36174 .6061 Mtetra
.761 .845 .915 r
.36174 .6061 .3675 .60922 .37688 .60339 .37113 .60057 Mtetra
.729 .859 .942 r
.37113 .60057 .37688 .60339 .38624 .59853 .38051 .59591 Mtetra
.681 .864 .969 r
.38051 .59591 .38624 .59853 .39557 .59474 .38987 .59221 Mtetra
.613 .854 .989 r
.38987 .59221 .39557 .59474 .40489 .59206 .39922 .5895 Mtetra
.531 .828 .999 r
.39922 .5895 .40489 .59206 .41421 .59049 .40857 .58778 Mtetra
.442 .786 .998 r
.40857 .58778 .41421 .59049 .42354 .58998 .41792 .58702 Mtetra
.361 .737 .988 r
.41792 .58702 .42354 .58998 .43288 .59044 .4273 .58711 Mtetra
.302 .689 .976 r
.4273 .58711 .43288 .59044 .44226 .59171 .43671 .58793 Mtetra
.271 .652 .967 r
.43671 .58793 .44226 .59171 .45168 .59362 .44616 .58932 Mtetra
.272 .628 .962 r
.44616 .58932 .45168 .59362 .46115 .59596 .45566 .59109 Mtetra
.298 .616 .957 r
.45566 .59109 .46115 .59596 .47068 .5985 .46521 .59304 Mtetra
.342 .614 .95 r
.46521 .59304 .47068 .5985 .48028 .601 .47483 .59495 Mtetra
.396 .617 .94 r
.47483 .59495 .48028 .601 .48994 .60321 .48451 .59659 Mtetra
.452 .624 .925 r
.48451 .59659 .48994 .60321 .49967 .60489 .49426 .59777 Mtetra
.505 .632 .909 r
.49426 .59777 .49967 .60489 .50947 .60584 .50407 .59828 Mtetra
.553 .64 .891 r
.50407 .59828 .50947 .60584 .51932 .60587 .51393 .59798 Mtetra
.595 .65 .874 r
.51393 .59798 .51932 .60587 .52923 .60484 .52385 .59673 Mtetra
.632 .66 .859 r
.52385 .59673 .52923 .60484 .53917 .60266 .53381 .59445 Mtetra
.663 .67 .847 r
.53381 .59445 .53917 .60266 .54915 .59929 .54381 .59111 Mtetra
.691 .682 .837 r
.54381 .59111 .54915 .59929 .55915 .59475 .55383 .58672 Mtetra
.715 .695 .83 r
.55383 .58672 .55915 .59475 .56917 .58912 .56387 .58135 Mtetra
.735 .708 .825 r
.56387 .58135 .56917 .58912 .57919 .58251 .57391 .57511 Mtetra
.753 .723 .824 r
.57391 .57511 .57919 .58251 .5892 .5751 .58397 .56815 Mtetra
.768 .739 .826 r
.58397 .56815 .5892 .5751 .59922 .56708 .59402 .56064 Mtetra
.78 .756 .831 r
.59402 .56064 .59922 .56708 .60923 .55869 .60408 .55281 Mtetra
.789 .774 .839 r
.60408 .55281 .60923 .55869 .61925 .55017 .61414 .54485 Mtetra
.794 .794 .851 r
.61414 .54485 .61925 .55017 .62927 .54177 .62421 .537 Mtetra
.794 .814 .868 r
.62421 .537 .62927 .54177 .63931 .53373 .6343 .52947 Mtetra
.787 .834 .888 r
.6343 .52947 .63931 .53373 .64938 .52628 .64442 .52245 Mtetra
.771 .851 .911 r
.64442 .52245 .64938 .52628 .65949 .5196 .65459 .51614 Mtetra
.744 .864 .936 r
.65459 .51614 .65949 .5196 .66965 .51386 .6648 .51066 Mtetra
.703 .869 .96 r
.6648 .51066 .66965 .51386 .67989 .50918 .67508 .50612 Mtetra
.647 .863 .981 r
.67508 .50612 .67989 .50918 .69021 .50562 .68544 .50258 Mtetra
.58 .842 .994 r
.68544 .50258 .69021 .50562 .70063 .50321 .69589 .50008 Mtetra
.508 .809 .999 r
.69589 .50008 .70063 .50321 .71115 .50191 .70643 .49857 Mtetra
.441 .768 .997 r
.70643 .49857 .71115 .50191 .72179 .50166 .71708 .49799 Mtetra
.389 .726 .99 r
.71708 .49799 .72179 .50166 .73254 .50233 .72784 .49823 Mtetra
.358 .688 .981 r
.72784 .49823 .73254 .50233 .74341 .50374 .7387 .49915 Mtetra
.349 .66 .971 r
.7387 .49915 .74341 .50374 .75438 .50571 .74966 .50055 Mtetra
.36 .64 .961 r
.74966 .50055 .75438 .50571 .76545 .50801 .76071 .50225 Mtetra
.386 .629 .95 r
.76071 .50225 .76545 .50801 .7766 .51038 .77184 .50401 Mtetra
.422 .625 .937 r
.77184 .50401 .7766 .51038 .78782 .51258 .78304 .50561 Mtetra
.462 .625 .922 r
.78304 .50561 .78782 .51258 .79908 .51436 .79427 .50683 Mtetra
.504 .629 .907 r
.79427 .50683 .79908 .51436 .81036 .51549 .80554 .50747 Mtetra
.544 .635 .891 r
.80554 .50747 .81036 .51549 .82164 .51576 .8168 .50734 Mtetra
.582 .643 .877 r
.8168 .50734 .82164 .51576 .83289 .51501 .82804 .5063 Mtetra
.617 .653 .864 r
.82804 .5063 .83289 .51501 .84409 .51312 .83924 .50424 Mtetra
.648 .665 .852 r
.83924 .50424 .84409 .51312 .85522 .51001 .85039 .50109 Mtetra
.677 .677 .843 r
.85039 .50109 .85522 .51001 .86627 .50568 .86148 .49685 Mtetra
.702 .691 .836 r
.86148 .49685 .86627 .50568 .87723 .50018 .87249 .49156 Mtetra
.726 .707 .832 r
.87249 .49156 .87723 .50018 .88811 .49361 .88343 .48532 Mtetra
.746 .723 .831 r
.88343 .48532 .88811 .49361 .8989 .48612 .8943 .47824 Mtetra
.764 .741 .832 r
.8943 .47824 .8989 .48612 .90963 .47789 .90512 .47052 Mtetra
.779 .76 .836 r
.90512 .47052 .90963 .47789 .9203 .46917 .91589 .46234 Mtetra
.79 .78 .844 r
.91589 .46234 .9203 .46917 .93095 .46018 .92665 .45393 Mtetra
.779 .769 .844 r
.31818 .62896 .32399 .63404 .33344 .62654 .32763 .62196 Mtetra
.781 .786 .857 r
.32763 .62196 .33344 .62654 .34289 .61926 .33708 .61514 Mtetra
.778 .804 .874 r
.33708 .61514 .34289 .61926 .35232 .61238 .34652 .60869 Mtetra
.769 .821 .894 r
.34652 .60869 .35232 .61238 .36174 .6061 .35594 .60276 Mtetra
.751 .837 .917 r
.35594 .60276 .36174 .6061 .37113 .60057 .36535 .59751 Mtetra
.722 .849 .942 r
.36535 .59751 .37113 .60057 .38051 .59591 .37475 .59303 Mtetra
.679 .853 .966 r
.37475 .59303 .38051 .59591 .38987 .59221 .38413 .5894 Mtetra
.622 .845 .985 r
.38413 .5894 .38987 .59221 .39922 .5895 .39351 .58667 Mtetra
.554 .825 .996 r
.39351 .58667 .39922 .5895 .40857 .58778 .40288 .58481 Mtetra
.482 .792 .999 r
.40288 .58481 .40857 .58778 .41792 .58702 .41227 .58381 Mtetra
.416 .753 .995 r
.41227 .58381 .41792 .58702 .4273 .58711 .42168 .58357 Mtetra
.366 .714 .987 r
.42168 .58357 .4273 .58711 .43671 .58793 .43112 .58398 Mtetra
.339 .682 .979 r
.43112 .58398 .43671 .58793 .44616 .58932 .4406 .58489 Mtetra
.337 .658 .972 r
.4406 .58489 .44616 .58932 .45566 .59109 .45012 .58615 Mtetra
.356 .645 .964 r
.45012 .58615 .45566 .59109 .46521 .59304 .4597 .58756 Mtetra
.39 .639 .955 r
.4597 .58756 .46521 .59304 .47483 .59495 .46934 .58893 Mtetra
.432 .638 .942 r
.46934 .58893 .47483 .59495 .48451 .59659 .47904 .59006 Mtetra
.478 .64 .927 r
.47904 .59006 .48451 .59659 .49426 .59777 .48881 .59078 Mtetra
.523 .645 .911 r
.48881 .59078 .49426 .59777 .50407 .59828 .49863 .5909 Mtetra
.564 .652 .894 r
.49863 .5909 .50407 .59828 .51393 .59798 .50852 .59029 Mtetra
.601 .659 .879 r
.50852 .59029 .51393 .59798 .52385 .59673 .51845 .58883 Mtetra
.634 .667 .865 r
.51845 .58883 .52385 .59673 .53381 .59445 .52842 .58646 Mtetra
.663 .677 .853 r
.52842 .58646 .53381 .59445 .54381 .59111 .53844 .58314 Mtetra
.688 .687 .844 r
.53844 .58314 .54381 .59111 .55383 .58672 .54848 .57888 Mtetra
.711 .699 .837 r
.54848 .57888 .55383 .58672 .56387 .58135 .55854 .57376 Mtetra
.73 .712 .833 r
.55854 .57376 .56387 .58135 .57391 .57511 .56861 .56785 Mtetra
.747 .725 .832 r
.56861 .56785 .57391 .57511 .58397 .56815 .5787 .56129 Mtetra
.76 .74 .834 r
.5787 .56129 .58397 .56815 .59402 .56064 .58879 .55425 Mtetra
.772 .756 .839 r
.58879 .55425 .59402 .56064 .60408 .55281 .59889 .54691 Mtetra
.779 .774 .848 r
.59889 .54691 .60408 .55281 .61414 .54485 .609 .53946 Mtetra
.783 .791 .859 r
.609 .53946 .61414 .54485 .62421 .537 .61912 .53211 Mtetra
.783 .81 .874 r
.61912 .53211 .62421 .537 .6343 .52947 .62926 .52503 Mtetra
.775 .827 .893 r
.62926 .52503 .6343 .52947 .64442 .52245 .63943 .51842 Mtetra
.76 .843 .914 r
.63943 .51842 .64442 .52245 .65459 .51614 .64964 .51243 Mtetra
.735 .854 .936 r
.64964 .51243 .65459 .51614 .6648 .51066 .6599 .50718 Mtetra
.698 .858 .958 r
.6599 .50718 .6648 .51066 .67508 .50612 .67022 .50277 Mtetra
.65 .852 .977 r
.67022 .50277 .67508 .50612 .68544 .50258 .68061 .49926 Mtetra
.594 .835 .99 r
.68061 .49926 .68544 .50258 .69589 .50008 .69109 .49666 Mtetra
.534 .808 .996 r
.69109 .49666 .69589 .50008 .70643 .49857 .70166 .49496 Mtetra
.478 .774 .996 r
.70166 .49496 .70643 .49857 .71708 .49799 .71232 .49409 Mtetra
.434 .739 .991 r
.71232 .49409 .71708 .49799 .72784 .49823 .72309 .49394 Mtetra
.407 .707 .984 r
.72309 .49394 .72784 .49823 .7387 .49915 .73395 .4944 Mtetra
.397 .681 .975 r
.73395 .4944 .7387 .49915 .74966 .50055 .7449 .49529 Mtetra
.404 .662 .964 r
.7449 .49529 .74966 .50055 .76071 .50225 .75594 .49643 Mtetra
.424 .649 .952 r
.75594 .49643 .76071 .50225 .77184 .50401 .76706 .49763 Mtetra
.452 .643 .939 r
.76706 .49763 .77184 .50401 .78304 .50561 .77823 .49869 Mtetra
.486 .641 .924 r
.77823 .49869 .78304 .50561 .79427 .50683 .78945 .49941 Mtetra
.521 .642 .909 r
.78945 .49941 .79427 .50683 .80554 .50747 .8007 .4996 Mtetra
.556 .647 .895 r
.8007 .4996 .80554 .50747 .8168 .50734 .81195 .49911 Mtetra
.589 .653 .881 r
.81195 .49911 .8168 .50734 .82804 .5063 .82319 .4978 Mtetra
.621 .662 .869 r
.82319 .4978 .82804 .5063 .83924 .50424 .8344 .49558 Mtetra
.649 .672 .858 r
.8344 .49558 .83924 .50424 .85039 .50109 .84557 .49239 Mtetra
.675 .683 .85 r
.84557 .49239 .85039 .50109 .86148 .49685 .85669 .48823 Mtetra
.699 .696 .844 r
.85669 .48823 .86148 .49685 .87249 .49156 .86775 .48313 Mtetra
.721 .71 .84 r
.86775 .48313 .87249 .49156 .88343 .48532 .87875 .47718 Mtetra
.739 .726 .839 r
.87875 .47718 .88343 .48532 .8943 .47824 .88969 .47048 Mtetra
.756 .742 .84 r
.88969 .47048 .8943 .47824 .90512 .47052 .90059 .46321 Mtetra
.769 .76 .845 r
.90059 .46321 .90512 .47052 .91589 .46234 .91146 .45552 Mtetra
.779 .779 .852 r
.91146 .45552 .91589 .46234 .92665 .45393 .92232 .44763 Mtetra
.769 .769 .852 r
.31232 .62385 .31818 .62896 .32763 .62196 .32177 .6173 Mtetra
.771 .784 .864 r
.32177 .6173 .32763 .62196 .33708 .61514 .33122 .6109 Mtetra
.767 .8 .88 r
.33122 .6109 .33708 .61514 .34652 .60869 .34067 .60483 Mtetra
.758 .816 .898 r
.34067 .60483 .34652 .60869 .35594 .60276 .35011 .59923 Mtetra
.741 .83 .919 r
.35011 .59923 .35594 .60276 .36535 .59751 .35953 .59422 Mtetra
.715 .839 .941 r
.35953 .59422 .36535 .59751 .37475 .59303 .36895 .58991 Mtetra
.677 .843 .962 r
.36895 .58991 .37475 .59303 .38413 .5894 .37836 .58635 Mtetra
.629 .837 .98 r
.37836 .58635 .38413 .5894 .39351 .58667 .38776 .58358 Mtetra
.572 .82 .992 r
.38776 .58358 .39351 .58667 .40288 .58481 .39717 .58161 Mtetra
.513 .795 .997 r
.39717 .58161 .40288 .58481 .41227 .58381 .40659 .58038 Mtetra
.459 .763 .995 r
.40659 .58038 .41227 .58381 .42168 .58357 .41603 .57984 Mtetra
.418 .731 .99 r
.41603 .57984 .42168 .58357 .43112 .58398 .42549 .57987 Mtetra
.394 .703 .984 r
.42549 .57987 .43112 .58398 .4406 .58489 .435 .58035 Mtetra
.39 .681 .976 r
.435 .58035 .4406 .58489 .45012 .58615 .44455 .58114 Mtetra
.403 .667 .967 r
.44455 .58114 .45012 .58615 .4597 .58756 .45416 .58205 Mtetra
.43 .658 .956 r
.45416 .58205 .4597 .58756 .46934 .58893 .46382 .58293 Mtetra
.464 .655 .943 r
.46382 .58293 .46934 .58893 .47904 .59006 .47355 .5836 Mtetra
.501 .655 .928 r
.47355 .5836 .47904 .59006 .48881 .59078 .48333 .58389 Mtetra
.538 .657 .913 r
.48333 .58389 .48881 .59078 .49863 .5909 .49317 .58366 Mtetra
.574 .662 .897 r
.49317 .58366 .49863 .5909 .50852 .59029 .50307 .58277 Mtetra
.607 .667 .882 r
.50307 .58277 .50852 .59029 .51845 .58883 .51302 .58112 Mtetra
.636 .675 .87 r
.51302 .58112 .51845 .58883 .52842 .58646 .52301 .57866 Mtetra
.663 .683 .859 r
.52301 .57866 .52842 .58646 .53844 .58314 .53304 .57536 Mtetra
.686 .692 .85 r
.53304 .57536 .53844 .58314 .54848 .57888 .5431 .57123 Mtetra
.707 .703 .844 r
.5431 .57123 .54848 .57888 .55854 .57376 .55318 .56631 Mtetra
.725 .715 .841 r
.55318 .56631 .55854 .57376 .56861 .56785 .56329 .5607 Mtetra
.74 .728 .84 r
.56329 .5607 .56861 .56785 .5787 .56129 .5734 .55452 Mtetra
.753 .742 .842 r
.5734 .55452 .5787 .56129 .58879 .55425 .58353 .5479 Mtetra
.763 .757 .847 r
.58353 .5479 .58879 .55425 .59889 .54691 .59367 .54101 Mtetra
.77 .773 .855 r
.59367 .54101 .59889 .54691 .609 .53946 .60381 .53402 Mtetra
.773 .789 .866 r
.60381 .53402 .609 .53946 .61912 .53211 .61398 .52711 Mtetra
.771 .806 .88 r
.61398 .52711 .61912 .53211 .62926 .52503 .62417 .52045 Mtetra
.764 .821 .897 r
.62417 .52045 .62926 .52503 .63943 .51842 .63438 .5142 Mtetra
.75 .835 .916 r
.63438 .5142 .63943 .51842 .64964 .51243 .64464 .5085 Mtetra
.726 .844 .937 r
.64464 .5085 .64964 .51243 .6599 .50718 .65494 .50346 Mtetra
.694 .847 .956 r
.65494 .50346 .6599 .50718 .67022 .50277 .66531 .49917 Mtetra
.653 .842 .973 r
.66531 .49917 .67022 .50277 .68061 .49926 .67574 .49567 Mtetra
.605 .828 .985 r
.67574 .49567 .68061 .49926 .69109 .49666 .68624 .493 Mtetra
.555 .806 .992 r
.68624 .493 .69109 .49666 .70166 .49496 .69684 .49111 Mtetra
.508 .778 .993 r
.69684 .49111 .70166 .49496 .71232 .49409 .70752 .48996 Mtetra
.471 .749 .99 r
.70752 .48996 .71232 .49409 .72309 .49394 .71829 .48947 Mtetra
.447 .721 .983 r
.71829 .48947 .72309 .49394 .73395 .4944 .72915 .4895 Mtetra
.437 .697 .975 r
.72915 .4895 .73395 .4944 .7449 .49529 .7401 .48992 Mtetra
.441 .679 .964 r
.7401 .48992 .7449 .49529 .75594 .49643 .75114 .49056 Mtetra
.456 .666 .953 r
.75114 .49056 .75594 .49643 .76706 .49763 .76224 .49125 Mtetra
.479 .658 .939 r
.76224 .49125 .76706 .49763 .77823 .49869 .7734 .49181 Mtetra
.507 .655 .925 r
.7734 .49181 .77823 .49869 .78945 .49941 .78461 .49207 Mtetra
.537 .655 .911 r
.78461 .49207 .78945 .49941 .8007 .4996 .79584 .49186 Mtetra
.567 .657 .897 r
.79584 .49186 .8007 .4996 .81195 .49911 .80709 .49103 Mtetra
.596 .662 .885 r
.80709 .49103 .81195 .49911 .82319 .4978 .81833 .48948 Mtetra
.624 .67 .873 r
.81833 .48948 .82319 .4978 .8344 .49558 .82955 .48711 Mtetra
.65 .678 .864 r
.82955 .48711 .8344 .49558 .84557 .49239 .84074 .48388 Mtetra
.674 .689 .856 r
.84074 .48388 .84557 .49239 .85669 .48823 .85189 .47979 Mtetra
.696 .701 .85 r
.85189 .47979 .85669 .48823 .86775 .48313 .863 .47486 Mtetra
.715 .714 .847 r
.863 .47486 .86775 .48313 .87875 .47718 .87406 .46917 Mtetra
.733 .728 .846 r
.87406 .46917 .87875 .47718 .88969 .47048 .88507 .46282 Mtetra
.748 .743 .848 r
.88507 .46282 .88969 .47048 .90059 .46321 .89605 .45595 Mtetra
.76 .76 .852 r
.89605 .45595 .90059 .46321 .91146 .45552 .90701 .44871 Mtetra
.769 .777 .86 r
.90701 .44871 .91146 .45552 .92232 .44763 .91796 .44128 Mtetra
.76 .768 .859 r
.30643 .61871 .31232 .62385 .32177 .6173 .31588 .61256 Mtetra
.761 .783 .871 r
.31588 .61256 .32177 .6173 .33122 .6109 .32534 .60655 Mtetra
.757 .797 .885 r
.32534 .60655 .33122 .6109 .34067 .60483 .33479 .60083 Mtetra
.748 .811 .902 r
.33479 .60083 .34067 .60483 .35011 .59923 .34424 .59552 Mtetra
.732 .823 .921 r
.34424 .59552 .35011 .59923 .35953 .59422 .35368 .59074 Mtetra
.708 .831 .941 r
.35368 .59074 .35953 .59422 .36895 .58991 .36312 .58657 Mtetra
.675 .834 .959 r
.36312 .58657 .36895 .58991 .37836 .58635 .37255 .58307 Mtetra
.634 .829 .975 r
.37255 .58307 .37836 .58635 .38776 .58358 .38198 .58028 Mtetra
.586 .816 .987 r
.38198 .58028 .38776 .58358 .39717 .58161 .39141 .57818 Mtetra
.538 .795 .992 r
.39141 .57818 .39717 .58161 .40659 .58038 .40086 .57676 Mtetra
.493 .769 .993 r
.40086 .57676 .40659 .58038 .41603 .57984 .41033 .57593 Mtetra
.459 .743 .99 r
.41033 .57593 .41603 .57984 .42549 .57987 .41983 .57562 Mtetra
.439 .719 .984 r
.41983 .57562 .42549 .57987 .435 .58035 .42937 .57571 Mtetra
.434 .699 .976 r
.42937 .57571 .435 .58035 .44455 .58114 .43895 .57606 Mtetra
.443 .684 .967 r
.43895 .57606 .44455 .58114 .45416 .58205 .44858 .57652 Mtetra
.463 .675 .956 r
.44858 .57652 .45416 .58205 .46382 .58293 .45827 .57696 Mtetra
.49 .669 .943 r
.45827 .57696 .46382 .58293 .47355 .5836 .46801 .5772 Mtetra
.521 .667 .929 r
.46801 .5772 .47355 .5836 .48333 .58389 .47781 .5771 Mtetra
.553 .668 .914 r
.47781 .5771 .48333 .58389 .49317 .58366 .48767 .57654 Mtetra
.583 .671 .899 r
.48767 .57654 .49317 .58366 .50307 .58277 .49759 .57539 Mtetra
.612 .675 .886 r
.49759 .57539 .50307 .58277 .51302 .58112 .50755 .57358 Mtetra
.639 .681 .874 r
.50755 .57358 .51302 .58112 .52301 .57866 .51756 .57103 Mtetra
.662 .688 .864 r
.51756 .57103 .52301 .57866 .53304 .57536 .52761 .56774 Mtetra
.684 .697 .856 r
.52761 .56774 .53304 .57536 .5431 .57123 .53769 .56372 Mtetra
.703 .707 .851 r
.53769 .56372 .5431 .57123 .55318 .56631 .5478 .55899 Mtetra
.719 .718 .848 r
.5478 .55899 .55318 .56631 .56329 .5607 .55793 .55366 Mtetra
.733 .73 .848 r
.55793 .55366 .56329 .5607 .5734 .55452 .56807 .5478 Mtetra
.745 .743 .85 r
.56807 .5478 .5734 .55452 .58353 .5479 .57823 .54156 Mtetra
.754 .757 .855 r
.57823 .54156 .58353 .5479 .59367 .54101 .58841 .53508 Mtetra
.76 .772 .862 r
.58841 .53508 .59367 .54101 .60381 .53402 .5986 .52851 Mtetra
.763 .787 .873 r
.5986 .52851 .60381 .53402 .61398 .52711 .6088 .52201 Mtetra
.761 .802 .886 r
.6088 .52201 .61398 .52711 .62417 .52045 .61904 .51572 Mtetra
.753 .815 .901 r
.61904 .51572 .62417 .52045 .63438 .5142 .6293 .5098 Mtetra
.74 .827 .919 r
.6293 .5098 .63438 .5142 .64464 .5085 .6396 .50436 Mtetra
.719 .835 .937 r
.6396 .50436 .64464 .5085 .65494 .50346 .64994 .49952 Mtetra
.69 .838 .954 r
.64994 .49952 .65494 .50346 .66531 .49917 .66034 .49533 Mtetra
.654 .833 .969 r
.66034 .49533 .66531 .49917 .67574 .49567 .67081 .49185 Mtetra
.614 .822 .98 r
.67081 .49185 .67574 .49567 .68624 .493 .68135 .48909 Mtetra
.571 .803 .987 r
.68135 .48909 .68624 .493 .69684 .49111 .69196 .48704 Mtetra
.532 .78 .989 r
.69196 .48704 .69684 .49111 .70752 .48996 .70266 .48565 Mtetra
.501 .755 .986 r
.70266 .48565 .70752 .48996 .71829 .48947 .71345 .48482 Mtetra
.48 .731 .981 r
.71345 .48482 .71829 .48947 .72915 .4895 .72432 .48447 Mtetra
.471 .709 .973 r
.72432 .48447 .72915 .4895 .7401 .48992 .73527 .48446 Mtetra
.473 .692 .963 r
.73527 .48446 .7401 .48992 .75114 .49056 .7463 .48464 Mtetra
.484 .68 .952 r
.7463 .48464 .75114 .49056 .76224 .49125 .75739 .48486 Mtetra
.503 .671 .939 r
.75739 .48486 .76224 .49125 .7734 .49181 .76854 .48497 Mtetra
.526 .667 .926 r
.76854 .48497 .7734 .49181 .78461 .49207 .77974 .4848 Mtetra
.551 .665 .913 r
.77974 .4848 .78461 .49207 .79584 .49186 .79097 .48422 Mtetra
.577 .667 .9 r
.79097 .48422 .79584 .49186 .80709 .49103 .80221 .48309 Mtetra
.603 .671 .888 r
.80221 .48309 .80709 .49103 .81833 .48948 .81346 .48131 Mtetra
.628 .677 .877 r
.81346 .48131 .81833 .48948 .82955 .48711 .82469 .47881 Mtetra
.651 .684 .868 r
.82469 .47881 .82955 .48711 .84074 .48388 .83591 .47554 Mtetra
.673 .694 .861 r
.83591 .47554 .84074 .48388 .85189 .47979 .84709 .47151 Mtetra
.693 .704 .856 r
.84709 .47151 .85189 .47979 .863 .47486 .85824 .46673 Mtetra
.711 .717 .854 r
.85824 .46673 .863 .47486 .87406 .46917 .86935 .46128 Mtetra
.726 .73 .853 r
.86935 .46128 .87406 .46917 .88507 .46282 .88043 .45524 Mtetra
.74 .744 .855 r
.88043 .45524 .88507 .46282 .89605 .45595 .89149 .44873 Mtetra
.751 .759 .86 r
.89149 .44873 .89605 .45595 .90701 .44871 .90253 .4419 Mtetra
.759 .775 .867 r
.90253 .4419 .90701 .44871 .91796 .44128 .91357 .43489 Mtetra
.751 .767 .866 r
.3005 .61354 .30643 .61871 .31588 .61256 .30995 .60775 Mtetra
.752 .781 .877 r
.30995 .60775 .31588 .61256 .32534 .60655 .31941 .60209 Mtetra
.748 .794 .89 r
.31941 .60209 .32534 .60655 .33479 .60083 .32887 .59669 Mtetra
.739 .806 .906 r
.32887 .59669 .33479 .60083 .34424 .59552 .33834 .59164 Mtetra
.724 .817 .923 r
.33834 .59164 .34424 .59552 .35368 .59074 .34779 .58707 Mtetra
.702 .824 .94 r
.34779 .58707 .35368 .59074 .36312 .58657 .35725 .58303 Mtetra
.673 .826 .957 r
.35725 .58303 .36312 .58657 .37255 .58307 .3667 .57959 Mtetra
.638 .822 .971 r
.3667 .57959 .37255 .58307 .38198 .58028 .37616 .57677 Mtetra
.598 .811 .981 r
.37616 .57677 .38198 .58028 .39141 .57818 .38562 .57456 Mtetra
.558 .794 .987 r
.38562 .57456 .39141 .57818 .40086 .57676 .3951 .57295 Mtetra
.521 .773 .989 r
.3951 .57295 .40086 .57676 .41033 .57593 .4046 .57187 Mtetra
.492 .751 .987 r
.4046 .57187 .41033 .57593 .41983 .57562 .41413 .57124 Mtetra
.475 .73 .982 r
.41413 .57124 .41983 .57562 .42937 .57571 .4237 .57096 Mtetra
.47 .712 .974 r
.4237 .57096 .42937 .57571 .43895 .57606 .43331 .57091 Mtetra
.477 .698 .965 r
.43331 .57091 .43895 .57606 .44858 .57652 .44296 .57097 Mtetra
.492 .688 .954 r
.44296 .57097 .44858 .57652 .45827 .57696 .45268 .57099 Mtetra
.514 .681 .942 r
.45268 .57099 .45827 .57696 .46801 .5772 .46244 .57084 Mtetra
.539 .678 .928 r
.46244 .57084 .46801 .5772 .47781 .5771 .47227 .57039 Mtetra
.566 .677 .914 r
.47227 .57039 .47781 .5771 .48767 .57654 .48214 .56952 Mtetra
.592 .679 .901 r
.48214 .56952 .48767 .57654 .49759 .57539 .49208 .56814 Mtetra
.617 .682 .889 r
.49208 .56814 .49759 .57539 .50755 .57358 .50206 .56617 Mtetra
.641 .687 .878 r
.50206 .56617 .50755 .57358 .51756 .57103 .51209 .56355 Mtetra
.662 .693 .869 r
.51209 .56355 .51756 .57103 .52761 .56774 .52215 .56027 Mtetra
.681 .701 .862 r
.52215 .56027 .52761 .56774 .53769 .56372 .53226 .55634 Mtetra
.699 .71 .857 r
.53226 .55634 .53769 .56372 .5478 .55899 .54239 .55179 Mtetra
.714 .72 .855 r
.54239 .55179 .5478 .55899 .55793 .55366 .55254 .54669 Mtetra
.727 .731 .854 r
.55254 .54669 .55793 .55366 .56807 .5478 .56271 .54114 Mtetra
.737 .744 .857 r
.56271 .54114 .56807 .5478 .57823 .54156 .57291 .53525 Mtetra
.746 .757 .862 r
.57291 .53525 .57823 .54156 .58841 .53508 .58312 .52914 Mtetra
.751 .77 .869 r
.58312 .52914 .58841 .53508 .5986 .52851 .59334 .52295 Mtetra
.753 .784 .879 r
.59334 .52295 .5986 .52851 .6088 .52201 .60359 .51681 Mtetra
.75 .798 .891 r
.60359 .51681 .6088 .52201 .61904 .51572 .61386 .51087 Mtetra
.743 .81 .905 r
.61386 .51087 .61904 .51572 .6293 .5098 .62417 .50525 Mtetra
.731 .82 .921 r
.62417 .50525 .6293 .5098 .6396 .50436 .63451 .50005 Mtetra
.712 .827 .937 r
.63451 .50005 .6396 .50436 .64994 .49952 .6449 .49537 Mtetra
.686 .829 .952 r
.6449 .49537 .64994 .49952 .66034 .49533 .65534 .49128 Mtetra
.655 .826 .965 r
.65534 .49128 .66034 .49533 .67081 .49185 .66584 .48781 Mtetra
.621 .816 .975 r
.66584 .48781 .67081 .49185 .68135 .48909 .6764 .48498 Mtetra
.585 .8 .982 r
.6764 .48498 .68135 .48909 .69196 .48704 .68705 .48278 Mtetra
.552 .781 .984 r
.68705 .48278 .69196 .48704 .70266 .48565 .69776 .48115 Mtetra
.526 .76 .982 r
.69776 .48115 .70266 .48565 .71345 .48482 .70856 .48002 Mtetra
.508 .738 .978 r
.70856 .48002 .71345 .48482 .72432 .48447 .71944 .47931 Mtetra
.499 .719 .97 r
.71944 .47931 .72432 .48447 .73527 .48446 .73039 .4789 Mtetra
.5 .703 .961 r
.73039 .4789 .73527 .48446 .7463 .48464 .74142 .47867 Mtetra
.508 .691 .95 r
.74142 .47867 .7463 .48464 .75739 .48486 .75251 .47846 Mtetra
.523 .682 .938 r
.75251 .47846 .75739 .48486 .76854 .48497 .76366 .47815 Mtetra
.542 .677 .926 r
.76366 .47815 .76854 .48497 .77974 .4848 .77485 .47759 Mtetra
.564 .675 .914 r
.77485 .47759 .77974 .4848 .79097 .48422 .78608 .47667 Mtetra
.586 .675 .902 r
.78608 .47667 .79097 .48422 .80221 .48309 .79732 .47526 Mtetra
.609 .678 .891 r
.79732 .47526 .80221 .48309 .81346 .48131 .80858 .47327 Mtetra
.631 .683 .881 r
.80858 .47327 .81346 .48131 .82469 .47881 .81983 .47065 Mtetra
.652 .69 .873 r
.81983 .47065 .82469 .47881 .83591 .47554 .83106 .46735 Mtetra
.671 .698 .866 r
.83106 .46735 .83591 .47554 .84709 .47151 .84228 .46336 Mtetra
.689 .708 .862 r
.84228 .46336 .84709 .47151 .85824 .46673 .85347 .45872 Mtetra
.706 .719 .86 r
.85347 .45872 .85824 .46673 .86935 .46128 .86464 .45348 Mtetra
.72 .731 .86 r
.86464 .45348 .86935 .46128 .88043 .45524 .87578 .44772 Mtetra
.732 .745 .862 r
.87578 .44772 .88043 .45524 .89149 .44873 .8869 .44154 Mtetra
.742 .759 .866 r
.8869 .44154 .89149 .44873 .90253 .4419 .89802 .43508 Mtetra
.749 .773 .873 r
.89802 .43508 .90253 .4419 .91357 .43489 .90915 .42846 Mtetra
.743 .767 .872 r
.29453 .60833 .3005 .61354 .30995 .60775 .30399 .60288 Mtetra
.743 .779 .882 r
.30399 .60288 .30995 .60775 .31941 .60209 .31345 .59754 Mtetra
.739 .791 .895 r
.31345 .59754 .31941 .60209 .32887 .59669 .32292 .59242 Mtetra
.73 .802 .909 r
.32292 .59242 .32887 .59669 .33834 .59164 .33239 .58762 Mtetra
.716 .811 .924 r
.33239 .58762 .33834 .59164 .34779 .58707 .34187 .58323 Mtetra
.697 .817 .94 r
.34187 .58323 .34779 .58707 .35725 .58303 .35134 .57931 Mtetra
.671 .819 .954 r
.35134 .57931 .35725 .58303 .3667 .57959 .36082 .57592 Mtetra
.641 .815 .967 r
.36082 .57592 .3667 .57959 .37616 .57677 .3703 .57307 Mtetra
.607 .806 .976 r
.3703 .57307 .37616 .57677 .38562 .57456 .37979 .57077 Mtetra
.574 .793 .982 r
.37979 .57077 .38562 .57456 .3951 .57295 .3893 .56898 Mtetra
.544 .775 .984 r
.3893 .56898 .3951 .57295 .4046 .57187 .39883 .56766 Mtetra
.52 .756 .982 r
.39883 .56766 .4046 .57187 .41413 .57124 .40839 .56674 Mtetra
.505 .738 .978 r
.40839 .56674 .41413 .57124 .4237 .57096 .41799 .56612 Mtetra
.5 .722 .971 r
.41799 .56612 .4237 .57096 .43331 .57091 .42762 .56571 Mtetra
.505 .709 .963 r
.42762 .56571 .43331 .57091 .44296 .57097 .43731 .56538 Mtetra
.517 .699 .952 r
.43731 .56538 .44296 .57097 .45268 .57099 .44705 .56502 Mtetra
.534 .692 .94 r
.44705 .56502 .45268 .57099 .46244 .57084 .45684 .56451 Mtetra
.555 .687 .927 r
.45684 .56451 .46244 .57084 .47227 .57039 .46668 .56374 Mtetra
.577 .686 .915 r
.46668 .56374 .47227 .57039 .48214 .56952 .47658 .5626 Mtetra
.6 .686 .902 r
.47658 .5626 .48214 .56952 .49208 .56814 .48653 .561 Mtetra
.622 .688 .891 r
.48653 .561 .49208 .56814 .50206 .56617 .49653 .55888 Mtetra
.642 .692 .881 r
.49653 .55888 .50206 .56617 .51209 .56355 .50658 .55619 Mtetra
.661 .698 .873 r
.50658 .55619 .51209 .56355 .52215 .56027 .51667 .55292 Mtetra
.679 .705 .867 r
.51667 .55292 .52215 .56027 .53226 .55634 .52679 .54907 Mtetra
.695 .713 .863 r
.52679 .54907 .53226 .55634 .54239 .55179 .53694 .54468 Mtetra
.708 .722 .861 r
.53694 .54468 .54239 .55179 .55254 .54669 .54712 .5398 Mtetra
.72 .733 .861 r
.54712 .5398 .55254 .54669 .56271 .54114 .55732 .53452 Mtetra
.73 .744 .863 r
.55732 .53452 .56271 .54114 .57291 .53525 .56754 .52894 Mtetra
.737 .756 .868 r
.56754 .52894 .57291 .53525 .58312 .52914 .57779 .52317 Mtetra
.742 .769 .875 r
.57779 .52317 .58312 .52914 .59334 .52295 .58805 .51732 Mtetra
.743 .782 .884 r
.58805 .51732 .59334 .52295 .60359 .51681 .59834 .51153 Mtetra
.741 .794 .895 r
.59834 .51153 .60359 .51681 .61386 .51087 .60865 .5059 Mtetra
.734 .805 .908 r
.60865 .5059 .61386 .51087 .62417 .50525 .619 .50054 Mtetra
.722 .814 .922 r
.619 .50054 .62417 .50525 .63451 .50005 .62938 .49557 Mtetra
.705 .82 .936 r
.62938 .49557 .63451 .50005 .6449 .49537 .6398 .49104 Mtetra
.683 .822 .95 r
.6398 .49104 .6449 .49537 .65534 .49128 .65028 .48703 Mtetra
.656 .819 .962 r
.65028 .48703 .65534 .49128 .66584 .48781 .66082 .48358 Mtetra
.626 .81 .971 r
.66082 .48358 .66584 .48781 .6764 .48498 .67141 .48068 Mtetra
.596 .797 .976 r
.67141 .48068 .6764 .48498 .68705 .48278 .68208 .47833 Mtetra
.569 .781 .979 r
.68208 .47833 .68705 .48278 .69776 .48115 .69282 .47648 Mtetra
.546 .763 .978 r
.69282 .47648 .69776 .48115 .70856 .48002 .70363 .47508 Mtetra
.531 .744 .973 r
.70363 .47508 .70856 .48002 .71944 .47931 .71452 .47404 Mtetra
.523 .727 .967 r
.71452 .47404 .71944 .47931 .73039 .4789 .72548 .47327 Mtetra
.523 .713 .958 r
.72548 .47327 .73039 .4789 .74142 .47867 .73651 .47264 Mtetra
.53 .701 .948 r
.73651 .47264 .74142 .47867 .75251 .47846 .7476 .47204 Mtetra
.541 .692 .937 r
.7476 .47204 .75251 .47846 .76366 .47815 .75875 .47135 Mtetra
.557 .686 .926 r
.75875 .47135 .76366 .47815 .77485 .47759 .76994 .47043 Mtetra
.575 .684 .914 r
.76994 .47043 .77485 .47759 .78608 .47667 .78117 .46919 Mtetra
.595 .683 .903 r
.78117 .46919 .78608 .47667 .79732 .47526 .79242 .46752 Mtetra
.614 .685 .893 r
.79242 .46752 .79732 .47526 .80858 .47327 .80368 .46534 Mtetra
.634 .689 .884 r
.80368 .46534 .80858 .47327 .81983 .47065 .81494 .4626 Mtetra
.652 .695 .877 r
.81494 .4626 .81983 .47065 .83106 .46735 .8262 .45927 Mtetra
.67 .702 .871 r
.8262 .45927 .83106 .46735 .84228 .46336 .83745 .45533 Mtetra
.686 .711 .867 r
.83745 .45533 .84228 .46336 .85347 .45872 .84868 .45081 Mtetra
.701 .721 .865 r
.84868 .45081 .85347 .45872 .86464 .45348 .8599 .44576 Mtetra
.714 .732 .865 r
.8599 .44576 .86464 .45348 .87578 .44772 .8711 .44025 Mtetra
.725 .745 .868 r
.8711 .44025 .87578 .44772 .8869 .44154 .8823 .43438 Mtetra
.734 .758 .872 r
.8823 .43438 .8869 .44154 .89802 .43508 .89349 .42824 Mtetra
.74 .771 .878 r
.89349 .42824 .89802 .43508 .90915 .42846 .90469 .42197 Mtetra
.734 .766 .878 r
.28853 .60308 .29453 .60833 .30399 .60288 .29798 .59795 Mtetra
.734 .777 .888 r
.29798 .59795 .30399 .60288 .31345 .59754 .30745 .5929 Mtetra
.73 .788 .899 r
.30745 .5929 .31345 .59754 .32292 .59242 .31693 .58804 Mtetra
.722 .798 .912 r
.31693 .58804 .32292 .59242 .33239 .58762 .32642 .58346 Mtetra
.709 .806 .925 r
.32642 .58346 .33239 .58762 .34187 .58323 .33591 .57924 Mtetra
.692 .811 .939 r
.33591 .57924 .34187 .58323 .35134 .57931 .3454 .57544 Mtetra
.669 .813 .952 r
.3454 .57544 .35134 .57931 .36082 .57592 .3549 .57208 Mtetra
.643 .81 .963 r
.3549 .57208 .36082 .57592 .3703 .57307 .3644 .56921 Mtetra
.615 .802 .972 r
.3644 .56921 .3703 .57307 .37979 .57077 .37392 .56681 Mtetra
.587 .791 .977 r
.37392 .56681 .37979 .57077 .3893 .56898 .38346 .56486 Mtetra
.562 .776 .979 r
.38346 .56486 .3893 .56898 .39883 .56766 .39302 .56332 Mtetra
.543 .76 .978 r
.39302 .56332 .39883 .56766 .40839 .56674 .40261 .56213 Mtetra
.53 .745 .974 r
.40261 .56213 .40839 .56674 .41799 .56612 .41224 .5612 Mtetra
.526 .73 .967 r
.41224 .5612 .41799 .56612 .42762 .56571 .42191 .56044 Mtetra
.529 .718 .959 r
.42191 .56044 .42762 .56571 .43731 .56538 .43162 .55977 Mtetra
.538 .708 .949 r
.43162 .55977 .43731 .56538 .44705 .56502 .44138 .55906 Mtetra
.552 .7 .938 r
.44138 .55906 .44705 .56502 .45684 .56451 .4512 .55822 Mtetra
.569 .695 .926 r
.4512 .55822 .45684 .56451 .46668 .56374 .46106 .55714 Mtetra
.588 .693 .915 r
.46106 .55714 .46668 .56374 .47658 .5626 .47098 .55574 Mtetra
.607 .692 .903 r
.47098 .55574 .47658 .5626 .48653 .561 .48095 .55394 Mtetra
.626 .694 .893 r
.48095 .55394 .48653 .561 .49653 .55888 .49097 .55168 Mtetra
.644 .697 .884 r
.49097 .55168 .49653 .55888 .50658 .55619 .50104 .54893 Mtetra
.661 .702 .877 r
.50104 .54893 .50658 .55619 .51667 .55292 .51114 .54566 Mtetra
.677 .708 .871 r
.51114 .54566 .51667 .55292 .52679 .54907 .52129 .54189 Mtetra
.691 .715 .868 r
.52129 .54189 .52679 .54907 .53694 .54468 .53146 .53764 Mtetra
.703 .724 .866 r
.53146 .53764 .53694 .54468 .54712 .5398 .54167 .53296 Mtetra
.714 .734 .867 r
.54167 .53296 .54712 .5398 .55732 .53452 .5519 .52794 Mtetra
.723 .744 .869 r
.5519 .52794 .55732 .53452 .56754 .52894 .56215 .52264 Mtetra
.729 .756 .874 r
.56215 .52264 .56754 .52894 .57779 .52317 .57242 .51718 Mtetra
.733 .767 .881 r
.57242 .51718 .57779 .52317 .58805 .51732 .58272 .51165 Mtetra
.734 .779 .889 r
.58272 .51165 .58805 .51732 .59834 .51153 .59305 .50616 Mtetra
.731 .79 .9 r
.59305 .50616 .59834 .51153 .60865 .5059 .6034 .50081 Mtetra
.725 .8 .911 r
.6034 .50081 .60865 .5059 .619 .50054 .61378 .49571 Mtetra
.714 .808 .924 r
.61378 .49571 .619 .50054 .62938 .49557 .6242 .49093 Mtetra
.699 .814 .936 r
.6242 .49093 .62938 .49557 .6398 .49104 .63467 .48655 Mtetra
.679 .815 .948 r
.63467 .48655 .6398 .49104 .65028 .48703 .64518 .48262 Mtetra
.656 .813 .959 r
.64518 .48262 .65028 .48703 .66082 .48358 .65575 .47916 Mtetra
.631 .806 .967 r
.65575 .47916 .66082 .48358 .67141 .48068 .66638 .4762 Mtetra
.606 .795 .972 r
.66638 .4762 .67141 .48068 .68208 .47833 .67707 .47371 Mtetra
.583 .781 .974 r
.67707 .47371 .68208 .47833 .69282 .47648 .68783 .47167 Mtetra
.564 .765 .973 r
.68783 .47167 .69282 .47648 .70363 .47508 .69866 .47001 Mtetra
.55 .749 .969 r
.69866 .47001 .70363 .47508 .71452 .47404 .70956 .46867 Mtetra
.544 .734 .963 r
.70956 .46867 .71452 .47404 .72548 .47327 .72053 .46755 Mtetra
.543 .72 .955 r
.72053 .46755 .72548 .47327 .73651 .47264 .73157 .46657 Mtetra
.548 .709 .946 r
.73157 .46657 .73651 .47264 .7476 .47204 .74266 .4656 Mtetra
.558 .701 .936 r
.74266 .4656 .7476 .47204 .75875 .47135 .75381 .46455 Mtetra
.571 .695 .925 r
.75381 .46455 .75875 .47135 .76994 .47043 .765 .4633 Mtetra
.586 .691 .914 r
.765 .4633 .76994 .47043 .78117 .46919 .77623 .46177 Mtetra
.602 .69 .904 r
.77623 .46177 .78117 .46919 .79242 .46752 .78749 .45986 Mtetra
.619 .691 .895 r
.78749 .45986 .79242 .46752 .80368 .46534 .79876 .45751 Mtetra
.636 .694 .887 r
.79876 .45751 .80368 .46534 .81494 .4626 .81004 .45466 Mtetra
.653 .699 .88 r
.81004 .45466 .81494 .4626 .8262 .45927 .82133 .45129 Mtetra
.668 .706 .875 r
.82133 .45129 .8262 .45927 .83745 .45533 .83261 .44739 Mtetra
.683 .714 .872 r
.83261 .44739 .83745 .45533 .84868 .45081 .84388 .44298 Mtetra
.696 .723 .87 r
.84388 .44298 .84868 .45081 .8599 .44576 .85515 .4381 Mtetra
.708 .733 .871 r
.85515 .4381 .8599 .44576 .8711 .44025 .86641 .43282 Mtetra
.718 .745 .873 r
.86641 .43282 .8711 .44025 .8823 .43438 .87766 .42722 Mtetra
.725 .757 .877 r
.87766 .42722 .8823 .43438 .89349 .42824 .88893 .42139 Mtetra
.731 .769 .884 r
.88893 .42139 .89349 .42824 .90469 .42197 .90021 .41544 Mtetra
.726 .765 .884 r
.28248 .59781 .28853 .60308 .29798 .59795 .29194 .59295 Mtetra
.725 .775 .893 r
.29194 .59295 .29798 .59795 .30745 .5929 .30141 .58817 Mtetra
.721 .785 .903 r
.30141 .58817 .30745 .5929 .31693 .58804 .3109 .58356 Mtetra
.714 .794 .914 r
.3109 .58356 .31693 .58804 .32642 .58346 .3204 .57918 Mtetra
.702 .801 .927 r
.3204 .57918 .32642 .58346 .33591 .57924 .3299 .57512 Mtetra
.687 .806 .939 r
.3299 .57512 .33591 .57924 .3454 .57544 .33942 .57141 Mtetra
.667 .808 .95 r
.33942 .57141 .3454 .57544 .3549 .57208 .34894 .5681 Mtetra
.645 .805 .96 r
.34894 .5681 .3549 .57208 .3644 .56921 .35847 .5652 Mtetra
.622 .799 .967 r
.35847 .5652 .3644 .56921 .37392 .56681 .36802 .56271 Mtetra
.599 .789 .972 r
.36802 .56271 .37392 .56681 .38346 .56486 .37758 .56061 Mtetra
.578 .777 .974 r
.37758 .56061 .38346 .56486 .39302 .56332 .38717 .55886 Mtetra
.562 .763 .973 r
.38717 .55886 .39302 .56332 .40261 .56213 .39679 .55741 Mtetra
.552 .749 .969 r
.39679 .55741 .40261 .56213 .41224 .5612 .40645 .55619 Mtetra
.548 .736 .963 r
.40645 .55619 .41224 .5612 .42191 .56044 .41615 .55513 Mtetra
.55 .725 .955 r
.41615 .55513 .42191 .56044 .43162 .55977 .42589 .55412 Mtetra
.557 .715 .946 r
.42589 .55412 .43162 .55977 .44138 .55906 .43568 .55309 Mtetra
.568 .708 .936 r
.43568 .55309 .44138 .55906 .4512 .55822 .44552 .55194 Mtetra
.582 .702 .925 r
.44552 .55194 .4512 .55822 .46106 .55714 .45541 .55058 Mtetra
.597 .699 .914 r
.45541 .55058 .46106 .55714 .47098 .55574 .46535 .54894 Mtetra
.614 .698 .904 r
.46535 .54894 .47098 .55574 .48095 .55394 .47534 .54696 Mtetra
.63 .699 .895 r
.47534 .54696 .48095 .55394 .49097 .55168 .48538 .54457 Mtetra
.646 .701 .887 r
.48538 .54457 .49097 .55168 .50104 .54893 .49546 .54175 Mtetra
.66 .705 .88 r
.49546 .54175 .50104 .54893 .51114 .54566 .50559 .53848 Mtetra
.674 .711 .876 r
.50559 .53848 .51114 .54566 .52129 .54189 .51575 .53478 Mtetra
.687 .718 .873 r
.51575 .53478 .52129 .54189 .53146 .53764 .52595 .53066 Mtetra
.698 .726 .871 r
.52595 .53066 .53146 .53764 .54167 .53296 .53618 .52617 Mtetra
.707 .735 .872 r
.53618 .52617 .54167 .53296 .5519 .52794 .54643 .52137 Mtetra
.715 .744 .875 r
.54643 .52137 .5519 .52794 .56215 .52264 .55672 .51634 Mtetra
.721 .755 .879 r
.55672 .51634 .56215 .52264 .57242 .51718 .56702 .51116 Mtetra
.724 .766 .886 r
.56702 .51116 .57242 .51718 .58272 .51165 .57736 .50592 Mtetra
.725 .777 .894 r
.57736 .50592 .58272 .51165 .59305 .50616 .58772 .50071 Mtetra
.722 .787 .903 r
.58772 .50071 .59305 .50616 .6034 .50081 .59811 .49563 Mtetra
.716 .796 .914 r
.59811 .49563 .6034 .50081 .61378 .49571 .60853 .49075 Mtetra
.707 .803 .925 r
.60853 .49075 .61378 .49571 .6242 .49093 .61899 .48615 Mtetra
.693 .808 .936 r
.61899 .48615 .6242 .49093 .63467 .48655 .62949 .4819 Mtetra
.676 .81 .947 r
.62949 .4819 .63467 .48655 .64518 .48262 .64004 .47804 Mtetra
.656 .807 .956 r
.64004 .47804 .64518 .48262 .65575 .47916 .65064 .47459 Mtetra
.635 .802 .963 r
.65064 .47459 .65575 .47916 .66638 .4762 .66129 .47156 Mtetra
.614 .792 .967 r
.66129 .47156 .66638 .4762 .67707 .47371 .67201 .46895 Mtetra
.594 .78 .969 r
.67201 .46895 .67707 .47371 .68783 .47167 .6828 .46671 Mtetra
.579 .767 .968 r
.6828 .46671 .68783 .47167 .69866 .47001 .69365 .46482 Mtetra
.567 .753 .965 r
.69365 .46482 .69866 .47001 .70956 .46867 .70456 .46319 Mtetra
.561 .739 .959 r
.70456 .46319 .70956 .46867 .72053 .46755 .71554 .46176 Mtetra
.561 .727 .952 r
.71554 .46176 .72053 .46755 .73157 .46657 .72658 .46044 Mtetra
.564 .716 .944 r
.72658 .46044 .73157 .46657 .74266 .4656 .73769 .45913 Mtetra
.572 .708 .934 r
.73769 .45913 .74266 .4656 .75381 .46455 .74884 .45775 Mtetra
.583 .702 .924 r
.74884 .45775 .75381 .46455 .765 .4633 .76004 .4562 Mtetra
.596 .698 .914 r
.76004 .4562 .765 .4633 .77623 .46177 .77127 .4544 Mtetra
.61 .696 .905 r
.77127 .4544 .77623 .46177 .78749 .45986 .78254 .45226 Mtetra
.624 .697 .897 r
.78254 .45226 .78749 .45986 .79876 .45751 .79382 .44974 Mtetra
.639 .699 .889 r
.79382 .44974 .79876 .45751 .81004 .45466 .80512 .44679 Mtetra
.653 .703 .883 r
.80512 .44679 .81004 .45466 .82133 .45129 .81643 .44338 Mtetra
.667 .709 .879 r
.81643 .44338 .82133 .45129 .83261 .44739 .82775 .43952 Mtetra
.68 .716 .876 r
.82775 .43952 .83261 .44739 .84388 .44298 .83906 .43521 Mtetra
.692 .724 .875 r
.83906 .43521 .84388 .44298 .85515 .4381 .85037 .43049 Mtetra
.702 .734 .876 r
.85037 .43049 .85515 .4381 .86641 .43282 .86169 .42542 Mtetra
.711 .744 .878 r
.86169 .42542 .86641 .43282 .87766 .42722 .87301 .42007 Mtetra
.717 .755 .882 r
.87301 .42007 .87766 .42722 .88893 .42139 .88434 .41452 Mtetra
.722 .767 .888 r
.88434 .41452 .88893 .42139 .90021 .41544 .89569 .40886 Mtetra
.717 .764 .889 r
.27639 .59249 .28248 .59781 .29194 .59295 .28586 .5879 Mtetra
.717 .773 .897 r
.28586 .5879 .29194 .59295 .30141 .58817 .29534 .58337 Mtetra
.713 .783 .907 r
.29534 .58337 .30141 .58817 .3109 .58356 .30484 .57898 Mtetra
.706 .791 .917 r
.30484 .57898 .3109 .58356 .3204 .57918 .31435 .57479 Mtetra
.696 .797 .928 r
.31435 .57479 .3204 .57918 .3299 .57512 .32387 .57087 Mtetra
.682 .802 .939 r
.32387 .57087 .3299 .57512 .33942 .57141 .3334 .56725 Mtetra
.666 .803 .948 r
.3334 .56725 .33942 .57141 .34894 .5681 .34294 .56397 Mtetra
.647 .801 .957 r
.34294 .56397 .34894 .5681 .35847 .5652 .3525 .56105 Mtetra
.627 .796 .963 r
.3525 .56105 .35847 .5652 .36802 .56271 .36207 .55847 Mtetra
.608 .788 .967 r
.36207 .55847 .36802 .56271 .37758 .56061 .37167 .55623 Mtetra
.591 .777 .969 r
.37167 .55623 .37758 .56061 .38717 .55886 .38129 .55429 Mtetra
.578 .766 .968 r
.38129 .55429 .38717 .55886 .39679 .55741 .39094 .5526 Mtetra
.57 .753 .964 r
.39094 .5526 .39679 .55741 .40645 .55619 .40062 .55111 Mtetra
.566 .742 .959 r
.40062 .55111 .40645 .55619 .41615 .55513 .41035 .54975 Mtetra
.568 .731 .952 r
.41035 .54975 .41615 .55513 .42589 .55412 .42012 .54844 Mtetra
.573 .722 .943 r
.42012 .54844 .42589 .55412 .43568 .55309 .42994 .54711 Mtetra
.582 .714 .934 r
.42994 .54711 .43568 .55309 .44552 .55194 .4398 .54567 Mtetra
.593 .709 .924 r
.4398 .54567 .44552 .55194 .45541 .55058 .44971 .54405 Mtetra
.606 .705 .914 r
.44971 .54405 .45541 .55058 .46535 .54894 .45968 .54219 Mtetra
.62 .703 .905 r
.45968 .54219 .46535 .54894 .47534 .54696 .46969 .54003 Mtetra
.634 .703 .896 r
.46969 .54003 .47534 .54696 .48538 .54457 .47975 .53752 Mtetra
.647 .705 .889 r
.47975 .53752 .48538 .54457 .49546 .54175 .48986 .53464 Mtetra
.66 .708 .883 r
.48986 .53464 .49546 .54175 .50559 .53848 .5 .53137 Mtetra
.672 .713 .879 r
.5 .53137 .50559 .53848 .51575 .53478 .51019 .52773 Mtetra
.683 .719 .877 r
.51019 .52773 .51575 .53478 .52595 .53066 .52041 .52373 Mtetra
.693 .727 .876 r
.52041 .52373 .52595 .53066 .53618 .52617 .53066 .51941 Mtetra
.701 .735 .877 r
.53066 .51941 .53618 .52617 .54643 .52137 .54094 .51482 Mtetra
.708 .744 .88 r
.54094 .51482 .54643 .52137 .55672 .51634 .55125 .51003 Mtetra
.713 .754 .884 r
.55125 .51003 .55672 .51634 .56702 .51116 .56159 .50511 Mtetra
.716 .764 .89 r
.56159 .50511 .56702 .51116 .57736 .50592 .57195 .50014 Mtetra
.716 .774 .898 r
.57195 .50014 .57736 .50592 .58772 .50071 .58235 .49519 Mtetra
.714 .784 .907 r
.58235 .49519 .58772 .50071 .59811 .49563 .59277 .49035 Mtetra
.708 .792 .916 r
.59277 .49035 .59811 .49563 .60853 .49075 .60323 .48568 Mtetra
.699 .799 .927 r
.60323 .48568 .60853 .49075 .61899 .48615 .61373 .48125 Mtetra
.688 .803 .936 r
.61373 .48125 .61899 .48615 .62949 .4819 .62426 .47712 Mtetra
.673 .805 .946 r
.62426 .47712 .62949 .4819 .64004 .47804 .63485 .47331 Mtetra
.656 .803 .953 r
.63485 .47331 .64004 .47804 .65064 .47459 .64548 .46987 Mtetra
.638 .798 .959 r
.64548 .46987 .65064 .47459 .66129 .47156 .65617 .46678 Mtetra
.62 .79 .963 r
.65617 .46678 .66129 .47156 .67201 .46895 .66691 .46404 Mtetra
.604 .78 .965 r
.66691 .46404 .67201 .46895 .6828 .46671 .67772 .46164 Mtetra
.591 .768 .964 r
.67772 .46164 .6828 .46671 .69365 .46482 .68859 .45952 Mtetra
.582 .756 .961 r
.68859 .45952 .69365 .46482 .70456 .46319 .69952 .45762 Mtetra
.577 .744 .956 r
.69952 .45762 .70456 .46319 .71554 .46176 .71051 .4559 Mtetra
.576 .733 .949 r
.71051 .4559 .71554 .46176 .72658 .46044 .72157 .45426 Mtetra
.579 .723 .941 r
.72157 .45426 .72658 .46044 .73769 .45913 .73268 .45264 Mtetra
.585 .715 .932 r
.73268 .45264 .73769 .45913 .74884 .45775 .74384 .45095 Mtetra
.594 .708 .923 r
.74384 .45095 .74884 .45775 .76004 .4562 .75504 .44911 Mtetra
.605 .704 .914 r
.75504 .44911 .76004 .4562 .77127 .4544 .76629 .44705 Mtetra
.616 .702 .906 r
.76629 .44705 .77127 .4544 .78254 .45226 .77756 .44471 Mtetra
.629 .702 .898 r
.77756 .44471 .78254 .45226 .79382 .44974 .78886 .44204 Mtetra
.641 .703 .891 r
.78886 .44204 .79382 .44974 .80512 .44679 .80018 .43899 Mtetra
.654 .706 .886 r
.80018 .43899 .80512 .44679 .81643 .44338 .81152 .43555 Mtetra
.666 .711 .882 r
.81152 .43555 .81643 .44338 .82775 .43952 .82286 .43171 Mtetra
.677 .718 .88 r
.82286 .43171 .82775 .43952 .83906 .43521 .83422 .42749 Mtetra
.687 .725 .879 r
.83422 .42749 .83906 .43521 .85037 .43049 .84558 .42292 Mtetra
.696 .734 .88 r
.84558 .42292 .85037 .43049 .86169 .42542 .85694 .41804 Mtetra
.704 .744 .883 r
.85694 .41804 .86169 .42542 .87301 .42007 .86832 .41292 Mtetra
.71 .754 .887 r
.86832 .41292 .87301 .42007 .88434 .41452 .87972 .40763 Mtetra
.714 .765 .892 r
.87972 .40763 .88434 .41452 .89569 .40886 .89113 .40224 Mtetra
.709 .762 .894 r
.27027 .58715 .27639 .59249 .28586 .5879 .27973 .5828 Mtetra
.708 .771 .901 r
.27973 .5828 .28586 .5879 .29534 .58337 .28922 .5785 Mtetra
.705 .78 .91 r
.28922 .5785 .29534 .58337 .30484 .57898 .29873 .57431 Mtetra
.699 .788 .92 r
.29873 .57431 .30484 .57898 .31435 .57479 .30825 .5703 Mtetra
.69 .794 .929 r
.30825 .5703 .31435 .57479 .32387 .57087 .31779 .56651 Mtetra
.678 .798 .939 r
.31779 .56651 .32387 .57087 .3334 .56725 .32734 .56298 Mtetra
.664 .799 .947 r
.32734 .56298 .3334 .56725 .34294 .56397 .3369 .55973 Mtetra
.648 .798 .954 r
.3369 .55973 .34294 .56397 .3525 .56105 .34648 .55677 Mtetra
.632 .793 .96 r
.34648 .55677 .3525 .56105 .36207 .55847 .35608 .55412 Mtetra
.616 .786 .963 r
.35608 .55412 .36207 .55847 .37167 .55623 .36571 .55174 Mtetra
.603 .778 .964 r
.36571 .55174 .37167 .55623 .38129 .55429 .37536 .54962 Mtetra
.592 .767 .963 r
.37536 .54962 .38129 .55429 .39094 .5526 .38504 .54771 Mtetra
.585 .757 .96 r
.38504 .54771 .39094 .5526 .40062 .55111 .39476 .54597 Mtetra
.582 .746 .955 r
.39476 .54597 .40062 .55111 .41035 .54975 .40451 .54433 Mtetra
.583 .736 .948 r
.40451 .54433 .41035 .54975 .42012 .54844 .41431 .54273 Mtetra
.588 .727 .94 r
.41431 .54273 .42012 .54844 .42994 .54711 .42416 .54111 Mtetra
.595 .72 .931 r
.42416 .54111 .42994 .54711 .4398 .54567 .43405 .5394 Mtetra
.604 .714 .922 r
.43405 .5394 .4398 .54567 .44971 .54405 .44399 .53754 Mtetra
.614 .71 .913 r
.44399 .53754 .44971 .54405 .45968 .54219 .45397 .53547 Mtetra
.626 .708 .905 r
.45397 .53547 .45968 .54219 .46969 .54003 .46401 .53314 Mtetra
.637 .707 .897 r
.46401 .53314 .46969 .54003 .47975 .53752 .47409 .53052 Mtetra
.648 .708 .891 r
.47409 .53052 .47975 .53752 .48986 .53464 .48421 .52758 Mtetra
.659 .711 .886 r
.48421 .52758 .48986 .53464 .5 .53137 .49438 .52431 Mtetra
.67 .715 .882 r
.49438 .52431 .5 .53137 .51019 .52773 .50458 .52072 Mtetra
.679 .721 .881 r
.50458 .52072 .51019 .52773 .52041 .52373 .51483 .51683 Mtetra
.688 .727 .88 r
.51483 .51683 .52041 .52373 .53066 .51941 .5251 .51267 Mtetra
.695 .735 .882 r
.5251 .51267 .53066 .51941 .54094 .51482 .53541 .50828 Mtetra
.701 .744 .885 r
.53541 .50828 .54094 .51482 .55125 .51003 .54575 .50371 Mtetra
.705 .753 .889 r
.54575 .50371 .55125 .51003 .56159 .50511 .55611 .49903 Mtetra
.708 .762 .895 r
.55611 .49903 .56159 .50511 .57195 .50014 .56651 .49431 Mtetra
.708 .772 .902 r
.56651 .49431 .57195 .50014 .58235 .49519 .57694 .4896 Mtetra
.705 .78 .91 r
.57694 .4896 .58235 .49519 .59277 .49035 .5874 .48498 Mtetra
.7 .788 .919 r
.5874 .48498 .59277 .49035 .60323 .48568 .59789 .48051 Mtetra
.693 .794 .928 r
.59789 .48051 .60323 .48568 .61373 .48125 .60842 .47624 Mtetra
.682 .799 .937 r
.60842 .47624 .61373 .48125 .62426 .47712 .619 .47221 Mtetra
.67 .8 .945 r
.619 .47221 .62426 .47712 .63485 .47331 .62961 .46846 Mtetra
.656 .799 .951 r
.62961 .46846 .63485 .47331 .64548 .46987 .64028 .46501 Mtetra
.641 .795 .956 r
.64028 .46501 .64548 .46987 .65617 .46678 .651 .46187 Mtetra
.626 .788 .96 r
.651 .46187 .65617 .46678 .66691 .46404 .66177 .45902 Mtetra
.613 .78 .961 r
.66177 .45902 .66691 .46404 .67772 .46164 .6726 .45645 Mtetra
.602 .77 .96 r
.6726 .45645 .67772 .46164 .68859 .45952 .68349 .45411 Mtetra
.595 .759 .957 r
.68349 .45411 .68859 .45952 .69952 .45762 .69444 .45197 Mtetra
.591 .748 .952 r
.69444 .45197 .69952 .45762 .71051 .4559 .70545 .44997 Mtetra
.59 .738 .946 r
.70545 .44997 .71051 .4559 .72157 .45426 .71651 .44804 Mtetra
.592 .728 .938 r
.71651 .44804 .72157 .45426 .73268 .45264 .72763 .44612 Mtetra
.597 .72 .93 r
.72763 .44612 .73268 .45264 .74384 .45095 .7388 .44414 Mtetra
.604 .714 .922 r
.7388 .44414 .74384 .45095 .75504 .44911 .75002 .44203 Mtetra
.613 .709 .914 r
.75002 .44203 .75504 .44911 .76629 .44705 .76127 .43973 Mtetra
.623 .707 .906 r
.76127 .43973 .76629 .44705 .77756 .44471 .77256 .43719 Mtetra
.633 .706 .899 r
.77256 .43719 .77756 .44471 .78886 .44204 .78388 .43437 Mtetra
.643 .707 .893 r
.78388 .43437 .78886 .44204 .80018 .43899 .79522 .43123 Mtetra
.654 .709 .888 r
.79522 .43123 .80018 .43899 .81152 .43555 .80658 .42775 Mtetra
.664 .713 .885 r
.80658 .42775 .81152 .43555 .82286 .43171 .81796 .42394 Mtetra
.674 .719 .883 r
.81796 .42394 .82286 .43171 .83422 .42749 .82935 .4198 Mtetra
.683 .726 .883 r
.82935 .4198 .83422 .42749 .84558 .42292 .84075 .41536 Mtetra
.691 .734 .884 r
.84075 .41536 .84558 .42292 .85694 .41804 .85217 .41067 Mtetra
.697 .743 .887 r
.85217 .41067 .85694 .41804 .86832 .41292 .86361 .40576 Mtetra
.702 .752 .891 r
.86361 .40576 .86832 .41292 .87972 .40763 .87506 .4007 Mtetra
.705 .762 .896 r
.87506 .4007 .87972 .40763 .89113 .40224 .88655 .39556 Mtetra
.701 .761 .898 r
.2641 .58177 .27027 .58715 .27973 .5828 .27357 .57764 Mtetra
.7 .769 .906 r
.27357 .57764 .27973 .5828 .28922 .5785 .28307 .57356 Mtetra
.697 .778 .914 r
.28307 .57356 .28922 .5785 .29873 .57431 .29258 .56957 Mtetra
.692 .785 .922 r
.29258 .56957 .29873 .57431 .30825 .5703 .30212 .56572 Mtetra
.684 .79 .931 r
.30212 .56572 .30825 .5703 .31779 .56651 .31167 .56205 Mtetra
.674 .794 .939 r
.31167 .56205 .31779 .56651 .32734 .56298 .32124 .55859 Mtetra
.662 .796 .946 r
.32124 .55859 .32734 .56298 .3369 .55973 .33082 .55537 Mtetra
.649 .795 .952 r
.33082 .55537 .3369 .55973 .34648 .55677 .34043 .55239 Mtetra
.636 .791 .957 r
.34043 .55239 .34648 .55677 .35608 .55412 .35006 .54966 Mtetra
.624 .785 .959 r
.35006 .54966 .35608 .55412 .36571 .55174 .35971 .54716 Mtetra
.613 .778 .96 r
.35971 .54716 .36571 .55174 .37536 .54962 .36939 .54486 Mtetra
.604 .769 .959 r
.36939 .54486 .37536 .54962 .38504 .54771 .3791 .54274 Mtetra
.599 .759 .955 r
.3791 .54274 .38504 .54771 .39476 .54597 .38885 .54076 Mtetra
.597 .75 .95 r
.38885 .54076 .39476 .54597 .40451 .54433 .39864 .53885 Mtetra
.597 .74 .944 r
.39864 .53885 .40451 .54433 .41431 .54273 .40847 .53699 Mtetra
.601 .732 .937 r
.40847 .53699 .41431 .54273 .42416 .54111 .41834 .5351 Mtetra
.606 .724 .929 r
.41834 .5351 .42416 .54111 .43405 .5394 .42825 .53313 Mtetra
.614 .719 .92 r
.42825 .53313 .43405 .5394 .44399 .53754 .43822 .53104 Mtetra
.622 .714 .912 r
.43822 .53104 .44399 .53754 .45397 .53547 .44823 .52877 Mtetra
.631 .712 .905 r
.44823 .52877 .45397 .53547 .46401 .53314 .45828 .52628 Mtetra
.64 .71 .898 r
.45828 .52628 .46401 .53314 .47409 .53052 .46839 .52355 Mtetra
.65 .711 .892 r
.46839 .52355 .47409 .53052 .48421 .52758 .47853 .52055 Mtetra
.659 .713 .888 r
.47853 .52055 .48421 .52758 .49438 .52431 .48872 .51729 Mtetra
.668 .717 .885 r
.48872 .51729 .49438 .52431 .50458 .52072 .49895 .51375 Mtetra
.676 .722 .884 r
.49895 .51375 .50458 .52072 .51483 .51683 .50921 .50996 Mtetra
.683 .728 .884 r
.50921 .50996 .51483 .51683 .5251 .51267 .51951 .50594 Mtetra
.689 .735 .886 r
.51951 .50594 .5251 .51267 .53541 .50828 .52984 .50173 Mtetra
.694 .743 .889 r
.52984 .50173 .53541 .50828 .54575 .50371 .54021 .49737 Mtetra
.698 .751 .893 r
.54021 .49737 .54575 .50371 .55611 .49903 .5506 .49292 Mtetra
.7 .76 .899 r
.5506 .49292 .55611 .49903 .56651 .49431 .56103 .48843 Mtetra
.7 .769 .906 r
.56103 .48843 .56651 .49431 .57694 .4896 .57149 .48395 Mtetra
.697 .777 .913 r
.57149 .48395 .57694 .4896 .5874 .48498 .58198 .47954 Mtetra
.693 .785 .921 r
.58198 .47954 .5874 .48498 .59789 .48051 .59251 .47524 Mtetra
.686 .791 .929 r
.59251 .47524 .59789 .48051 .60842 .47624 .60308 .47112 Mtetra
.678 .795 .937 r
.60308 .47112 .60842 .47624 .619 .47221 .61369 .46719 Mtetra
.667 .796 .944 r
.61369 .46719 .619 .47221 .62961 .46846 .62434 .46349 Mtetra
.655 .796 .95 r
.62434 .46349 .62961 .46846 .64028 .46501 .63504 .46004 Mtetra
.643 .793 .954 r
.63504 .46004 .64028 .46501 .651 .46187 .64578 .45684 Mtetra
.631 .787 .957 r
.64578 .45684 .651 .46187 .66177 .45902 .65659 .45388 Mtetra
.621 .78 .957 r
.65659 .45388 .66177 .45902 .6726 .45645 .66744 .45115 Mtetra
.612 .771 .956 r
.66744 .45115 .6726 .45645 .68349 .45411 .67835 .44862 Mtetra
.606 .761 .953 r
.67835 .44862 .68349 .45411 .69444 .45197 .68932 .44624 Mtetra
.603 .752 .949 r
.68932 .44624 .69444 .45197 .70545 .44997 .70034 .44397 Mtetra
.602 .742 .943 r
.70034 .44397 .70545 .44997 .71651 .44804 .71142 .44176 Mtetra
.604 .733 .936 r
.71142 .44176 .71651 .44804 .72763 .44612 .72255 .43956 Mtetra
.608 .725 .928 r
.72255 .43956 .72763 .44612 .7388 .44414 .73373 .43731 Mtetra
.614 .719 .921 r
.73373 .43731 .7388 .44414 .75002 .44203 .74496 .43494 Mtetra
.621 .714 .913 r
.74496 .43494 .75002 .44203 .76127 .43973 .75623 .43242 Mtetra
.628 .711 .906 r
.75623 .43242 .76127 .43973 .77256 .43719 .76753 .42969 Mtetra
.637 .71 .9 r
.76753 .42969 .77256 .43719 .78388 .43437 .77887 .42673 Mtetra
.646 .71 .894 r
.77887 .42673 .78388 .43437 .79522 .43123 .79023 .4235 Mtetra
.654 .712 .89 r
.79023 .4235 .79522 .43123 .80658 .42775 .80162 .41999 Mtetra
.663 .715 .887 r
.80162 .41999 .80658 .42775 .81796 .42394 .81303 .4162 Mtetra
.671 .72 .886 r
.81303 .4162 .81796 .42394 .82935 .4198 .82446 .41214 Mtetra
.678 .726 .886 r
.82446 .41214 .82935 .4198 .84075 .41536 .8359 .40782 Mtetra
.685 .734 .887 r
.8359 .40782 .84075 .41536 .85217 .41067 .84737 .40329 Mtetra
.691 .742 .89 r
.84737 .40329 .85217 .41067 .86361 .40576 .85886 .39858 Mtetra
.695 .751 .894 r
.85886 .39858 .86361 .40576 .87506 .4007 .87038 .39375 Mtetra
.698 .76 .9 r
.87038 .39375 .87506 .4007 .88655 .39556 .88193 .38884 Mtetra
.693 .759 .903 r
.25789 .57635 .2641 .58177 .27357 .57764 .26737 .57244 Mtetra
.692 .768 .909 r
.26737 .57244 .27357 .57764 .28307 .57356 .27687 .56856 Mtetra
.689 .775 .917 r
.27687 .56856 .28307 .57356 .29258 .56957 .2864 .56475 Mtetra
.685 .782 .924 r
.2864 .56475 .29258 .56957 .30212 .56572 .29594 .56106 Mtetra
.678 .787 .932 r
.29594 .56106 .30212 .56572 .31167 .56205 .30551 .5575 Mtetra
.67 .791 .939 r
.30551 .5575 .31167 .56205 .32124 .55859 .3151 .55412 Mtetra
.66 .793 .945 r
.3151 .55412 .32124 .55859 .33082 .55537 .32471 .55092 Mtetra
.65 .792 .95 r
.32471 .55092 .33082 .55537 .34043 .55239 .33434 .54792 Mtetra
.64 .789 .954 r
.33434 .54792 .34043 .55239 .35006 .54966 .34399 .54511 Mtetra
.63 .785 .956 r
.34399 .54511 .35006 .54966 .35971 .54716 .35367 .54248 Mtetra
.622 .778 .956 r
.35367 .54248 .35971 .54716 .36939 .54486 .36338 .54002 Mtetra
.615 .77 .954 r
.36338 .54002 .36939 .54486 .3791 .54274 .37313 .5377 Mtetra
.611 .762 .951 r
.37313 .5377 .3791 .54274 .38885 .54076 .38291 .53548 Mtetra
.61 .753 .946 r
.38291 .53548 .38885 .54076 .39864 .53885 .39272 .53333 Mtetra
.61 .744 .94 r
.39272 .53333 .39864 .53885 .40847 .53699 .40258 .53121 Mtetra
.613 .736 .933 r
.40258 .53121 .40847 .53699 .41834 .5351 .41248 .52906 Mtetra
.617 .729 .926 r
.41248 .52906 .41834 .5351 .42825 .53313 .42242 .52685 Mtetra
.622 .723 .918 r
.42242 .52685 .42825 .53313 .43822 .53104 .43241 .52453 Mtetra
.629 .718 .911 r
.43241 .52453 .43822 .53104 .44823 .52877 .44245 .52207 Mtetra
.636 .715 .904 r
.44245 .52207 .44823 .52877 .45828 .52628 .45253 .51944 Mtetra
.643 .713 .898 r
.45253 .51944 .45828 .52628 .46839 .52355 .46265 .5166 Mtetra
.651 .713 .894 r
.46265 .5166 .46839 .52355 .47853 .52055 .47282 .51355 Mtetra
.658 .715 .89 r
.47282 .51355 .47853 .52055 .48872 .51729 .48302 .51028 Mtetra
.665 .718 .888 r
.48302 .51028 .48872 .51729 .49895 .51375 .49327 .50679 Mtetra
.672 .722 .887 r
.49327 .50679 .49895 .51375 .50921 .50996 .50356 .50309 Mtetra
.678 .728 .888 r
.50356 .50309 .50921 .50996 .51951 .50594 .51388 .49921 Mtetra
.683 .734 .89 r
.51388 .49921 .51951 .50594 .52984 .50173 .52424 .49517 Mtetra
.687 .742 .893 r
.52424 .49517 .52984 .50173 .54021 .49737 .53463 .49101 Mtetra
.69 .75 .897 r
.53463 .49101 .54021 .49737 .5506 .49292 .54505 .48677 Mtetra
.692 .758 .903 r
.54505 .48677 .5506 .49292 .56103 .48843 .55551 .4825 Mtetra
.692 .767 .909 r
.55551 .4825 .56103 .48843 .57149 .48395 .566 .47823 Mtetra
.69 .774 .916 r
.566 .47823 .57149 .48395 .58198 .47954 .57653 .47402 Mtetra
.686 .782 .923 r
.57653 .47402 .58198 .47954 .59251 .47524 .58709 .46989 Mtetra
.68 .787 .931 r
.58709 .46989 .59251 .47524 .60308 .47112 .59769 .4659 Mtetra
.673 .791 .937 r
.59769 .4659 .60308 .47112 .61369 .46719 .60833 .46207 Mtetra
.664 .793 .943 r
.60833 .46207 .61369 .46719 .62434 .46349 .61902 .45842 Mtetra
.655 .793 .948 r
.61902 .45842 .62434 .46349 .63504 .46004 .62975 .45497 Mtetra
.645 .791 .952 r
.62975 .45497 .63504 .46004 .64578 .45684 .64053 .45171 Mtetra
.636 .786 .954 r
.64053 .45171 .64578 .45684 .65659 .45388 .65136 .44865 Mtetra
.628 .78 .954 r
.65136 .44865 .65659 .45388 .66744 .45115 .66224 .44576 Mtetra
.621 .772 .953 r
.66224 .44576 .66744 .45115 .67835 .44862 .67317 .44304 Mtetra
.617 .764 .95 r
.67317 .44304 .67835 .44862 .68932 .44624 .68416 .44043 Mtetra
.614 .755 .945 r
.68416 .44043 .68932 .44624 .70034 .44397 .6952 .43791 Mtetra
.614 .746 .94 r
.6952 .43791 .70034 .44397 .71142 .44176 .7063 .43544 Mtetra
.615 .737 .933 r
.7063 .43544 .71142 .44176 .72255 .43956 .71744 .43297 Mtetra
.618 .73 .926 r
.71744 .43297 .72255 .43956 .73373 .43731 .72863 .43045 Mtetra
.622 .724 .919 r
.72863 .43045 .73373 .43731 .74496 .43494 .73987 .42784 Mtetra
.628 .719 .912 r
.73987 .42784 .74496 .43494 .75623 .43242 .75115 .42511 Mtetra
.634 .715 .906 r
.75115 .42511 .75623 .43242 .76753 .42969 .76247 .4222 Mtetra
.641 .713 .9 r
.76247 .4222 .76753 .42969 .77887 .42673 .77383 .4191 Mtetra
.648 .713 .895 r
.77383 .4191 .77887 .42673 .79023 .4235 .78521 .41579 Mtetra
.655 .714 .892 r
.78521 .41579 .79023 .4235 .80162 .41999 .79663 .41224 Mtetra
.662 .717 .889 r
.79663 .41224 .80162 .41999 .81303 .4162 .80807 .40847 Mtetra
.668 .721 .888 r
.80807 .40847 .81303 .4162 .82446 .41214 .81954 .40448 Mtetra
.674 .726 .889 r
.81954 .40448 .82446 .41214 .8359 .40782 .83103 .40028 Mtetra
.68 .733 .891 r
.83103 .40028 .8359 .40782 .84737 .40329 .84254 .3959 Mtetra
.684 .74 .894 r
.84254 .3959 .84737 .40329 .85886 .39858 .85409 .39138 Mtetra
.688 .749 .898 r
.85409 .39138 .85886 .39858 .87038 .39375 .86566 .38675 Mtetra
.69 .757 .903 r
.86566 .38675 .87038 .39375 .88193 .38884 .87727 .38207 Mtetra
.685 .758 .907 r
.25164 .57089 .25789 .57635 .26737 .57244 .26112 .56719 Mtetra
.684 .766 .913 r
.26112 .56719 .26737 .57244 .27687 .56856 .27063 .5635 Mtetra
.682 .773 .92 r
.27063 .5635 .27687 .56856 .2864 .56475 .28017 .55987 Mtetra
.678 .78 .927 r
.28017 .55987 .2864 .56475 .29594 .56106 .28973 .55632 Mtetra
.673 .785 .933 r
.28973 .55632 .29594 .56106 .30551 .5575 .29931 .55288 Mtetra
.666 .789 .94 r
.29931 .55288 .30551 .5575 .3151 .55412 .30891 .54956 Mtetra
.659 .79 .945 r
.30891 .54956 .3151 .55412 .32471 .55092 .31854 .54638 Mtetra
.651 .79 .949 r
.31854 .54638 .32471 .55092 .33434 .54792 .3282 .54336 Mtetra
.643 .788 .952 r
.3282 .54336 .33434 .54792 .34399 .54511 .33788 .54047 Mtetra
.636 .784 .953 r
.33788 .54047 .34399 .54511 .35367 .54248 .34759 .53773 Mtetra
.63 .779 .952 r
.34759 .53773 .35367 .54248 .36338 .54002 .35733 .53511 Mtetra
.625 .772 .95 r
.35733 .53511 .36338 .54002 .37313 .5377 .36711 .53259 Mtetra
.622 .764 .947 r
.36711 .53259 .37313 .5377 .38291 .53548 .37692 .53015 Mtetra
.621 .756 .942 r
.37692 .53015 .38291 .53548 .39272 .53333 .38677 .52776 Mtetra
.622 .747 .937 r
.38677 .52776 .39272 .53333 .40258 .53121 .39665 .52539 Mtetra
.623 .74 .93 r
.39665 .52539 .40258 .53121 .41248 .52906 .40658 .523 Mtetra
.627 .732 .923 r
.40658 .523 .41248 .52906 .42242 .52685 .41655 .52055 Mtetra
.631 .726 .916 r
.41655 .52055 .42242 .52685 .43241 .52453 .42657 .51802 Mtetra
.635 .721 .91 r
.42657 .51802 .43241 .52453 .44245 .52207 .43663 .51538 Mtetra
.641 .718 .904 r
.43663 .51538 .44245 .52207 .45253 .51944 .44673 .5126 Mtetra
.646 .716 .899 r
.44673 .5126 .45253 .51944 .46265 .5166 .45688 .50966 Mtetra
.652 .715 .895 r
.45688 .50966 .46265 .5166 .47282 .51355 .46706 .50656 Mtetra
.658 .716 .892 r
.46706 .50656 .47282 .51355 .48302 .51028 .47729 .50328 Mtetra
.663 .719 .89 r
.47729 .50328 .48302 .51028 .49327 .50679 .48756 .49984 Mtetra
.668 .723 .89 r
.48756 .49984 .49327 .50679 .50356 .50309 .49787 .49623 Mtetra
.673 .728 .891 r
.49787 .49623 .50356 .50309 .51388 .49921 .50822 .49247 Mtetra
.677 .734 .893 r
.50822 .49247 .51388 .49921 .52424 .49517 .5186 .4886 Mtetra
.68 .741 .896 r
.5186 .4886 .52424 .49517 .53463 .49101 .52901 .48462 Mtetra
.683 .748 .901 r
.52901 .48462 .53463 .49101 .54505 .48677 .53947 .48059 Mtetra
.684 .756 .906 r
.53947 .48059 .54505 .48677 .55551 .4825 .54995 .47652 Mtetra
.684 .764 .912 r
.54995 .47652 .55551 .4825 .566 .47823 .56048 .47245 Mtetra
.682 .772 .919 r
.56048 .47245 .566 .47823 .57653 .47402 .57103 .46843 Mtetra
.679 .778 .926 r
.57103 .46843 .57653 .47402 .58709 .46989 .58163 .46447 Mtetra
.674 .784 .932 r
.58163 .46447 .58709 .46989 .59769 .4659 .59226 .46061 Mtetra
.669 .788 .938 r
.59226 .46061 .59769 .4659 .60833 .46207 .60294 .45687 Mtetra
.662 .79 .943 r
.60294 .45687 .60833 .46207 .61902 .45842 .61366 .45326 Mtetra
.655 .791 .947 r
.61366 .45326 .61902 .45842 .62975 .45497 .62442 .4498 Mtetra
.647 .789 .95 r
.62442 .4498 .62975 .45497 .64053 .45171 .63523 .44649 Mtetra
.64 .785 .951 r
.63523 .44649 .64053 .45171 .65136 .44865 .64609 .44332 Mtetra
.634 .78 .951 r
.64609 .44332 .65136 .44865 .66224 .44576 .65699 .44029 Mtetra
.629 .774 .95 r
.65699 .44029 .66224 .44576 .67317 .44304 .66795 .43738 Mtetra
.626 .766 .947 r
.66795 .43738 .67317 .44304 .68416 .44043 .67896 .43456 Mtetra
.624 .758 .942 r
.67896 .43456 .68416 .44043 .6952 .43791 .69002 .4318 Mtetra
.624 .749 .937 r
.69002 .4318 .6952 .43791 .7063 .43544 .70113 .42907 Mtetra
.625 .741 .931 r
.70113 .42907 .7063 .43544 .71744 .43297 .71229 .42634 Mtetra
.627 .734 .924 r
.71229 .42634 .71744 .43297 .72863 .43045 .7235 .42357 Mtetra
.63 .728 .917 r
.7235 .42357 .72863 .43045 .73987 .42784 .73475 .42073 Mtetra
.635 .722 .911 r
.73475 .42073 .73987 .42784 .75115 .42511 .74605 .41778 Mtetra
.639 .718 .905 r
.74605 .41778 .75115 .42511 .76247 .4222 .75738 .41471 Mtetra
.644 .716 .9 r
.75738 .41471 .76247 .4222 .77383 .4191 .76876 .41148 Mtetra
.649 .715 .896 r
.76876 .41148 .77383 .4191 .78521 .41579 .78017 .40808 Mtetra
.655 .716 .893 r
.78017 .40808 .78521 .41579 .79663 .41224 .79161 .4045 Mtetra
.66 .718 .891 r
.79161 .4045 .79663 .41224 .80807 .40847 .80308 .40074 Mtetra
.665 .721 .891 r
.80308 .40074 .80807 .40847 .81954 .40448 .81459 .39682 Mtetra
.67 .726 .891 r
.81459 .39682 .81954 .40448 .83103 .40028 .82612 .39273 Mtetra
.674 .732 .893 r
.82612 .39273 .83103 .40028 .84254 .3959 .83769 .3885 Mtetra
.678 .739 .897 r
.83769 .3885 .84254 .3959 .85409 .39138 .84928 .38415 Mtetra
.681 .746 .901 r
.84928 .38415 .85409 .39138 .86566 .38675 .86092 .37972 Mtetra
.682 .754 .906 r
.86092 .37972 .86566 .38675 .87727 .38207 .87259 .37524 Mtetra
.677 .756 .911 r
.24535 .5654 .25164 .57089 .26112 .56719 .25484 .56189 Mtetra
.676 .764 .917 r
.25484 .56189 .26112 .56719 .27063 .5635 .26435 .55839 Mtetra
.674 .771 .923 r
.26435 .55839 .27063 .5635 .28017 .55987 .2739 .55493 Mtetra
.671 .777 .929 r
.2739 .55493 .28017 .55987 .28973 .55632 .28347 .55152 Mtetra
.667 .783 .935 r
.28347 .55152 .28973 .55632 .29931 .55288 .29306 .54818 Mtetra
.662 .786 .94 r
.29306 .54818 .29931 .55288 .30891 .54956 .30269 .54493 Mtetra
.657 .788 .945 r
.30269 .54493 .30891 .54956 .31854 .54638 .31234 .54178 Mtetra
.651 .789 .948 r
.31234 .54178 .31854 .54638 .3282 .54336 .32202 .53872 Mtetra
.646 .787 .95 r
.32202 .53872 .3282 .54336 .33788 .54047 .33173 .53577 Mtetra
.641 .784 .95 r
.33173 .53577 .33788 .54047 .34759 .53773 .34147 .53291 Mtetra
.637 .779 .949 r
.34147 .53291 .34759 .53773 .35733 .53511 .35124 .53013 Mtetra
.634 .773 .947 r
.35124 .53013 .35733 .53511 .36711 .53259 .36105 .52743 Mtetra
.632 .766 .943 r
.36105 .52743 .36711 .53259 .37692 .53015 .37089 .52477 Mtetra
.632 .758 .939 r
.37089 .52477 .37692 .53015 .38677 .52776 .38077 .52215 Mtetra
.632 .75 .933 r
.38077 .52215 .38677 .52776 .39665 .52539 .39069 .51953 Mtetra
.633 .743 .927 r
.39069 .51953 .39665 .52539 .40658 .523 .40064 .5169 Mtetra
.636 .736 .921 r
.40064 .5169 .40658 .523 .41655 .52055 .41064 .51423 Mtetra
.638 .729 .914 r
.41064 .51423 .41655 .52055 .42657 .51802 .42069 .51149 Mtetra
.642 .724 .908 r
.42069 .51149 .42657 .51802 .43663 .51538 .43077 .50867 Mtetra
.645 .721 .903 r
.43077 .50867 .43663 .51538 .44673 .5126 .4409 .50575 Mtetra
.649 .718 .899 r
.4409 .50575 .44673 .5126 .45688 .50966 .45107 .50272 Mtetra
.653 .717 .895 r
.45107 .50272 .45688 .50966 .46706 .50656 .46127 .49956 Mtetra
.657 .717 .893 r
.46127 .49956 .46706 .50656 .47729 .50328 .47153 .49628 Mtetra
.661 .719 .892 r
.47153 .49628 .47729 .50328 .48756 .49984 .48182 .49287 Mtetra
.665 .723 .892 r
.48182 .49287 .48756 .49984 .49787 .49623 .49215 .48935 Mtetra
.668 .727 .894 r
.49215 .48935 .49787 .49623 .50822 .49247 .50251 .48572 Mtetra
.671 .733 .896 r
.50251 .48572 .50822 .49247 .5186 .4886 .51292 .482 Mtetra
.674 .739 .9 r
.51292 .482 .5186 .4886 .52901 .48462 .52336 .4782 Mtetra
.675 .746 .904 r
.52336 .4782 .52901 .48462 .53947 .48059 .53384 .47436 Mtetra
.676 .754 .91 r
.53384 .47436 .53947 .48059 .54995 .47652 .54436 .47049 Mtetra
.676 .762 .916 r
.54436 .47049 .54995 .47652 .56048 .47245 .55491 .46662 Mtetra
.674 .769 .922 r
.55491 .46662 .56048 .47245 .57103 .46843 .5655 .46278 Mtetra
.672 .776 .928 r
.5655 .46278 .57103 .46843 .58163 .46447 .57612 .45897 Mtetra
.669 .781 .934 r
.57612 .45897 .58163 .46447 .59226 .46061 .58679 .45524 Mtetra
.664 .786 .939 r
.58679 .45524 .59226 .46061 .60294 .45687 .5975 .45158 Mtetra
.659 .788 .943 r
.5975 .45158 .60294 .45687 .61366 .45326 .60825 .44801 Mtetra
.654 .789 .946 r
.60825 .44801 .61366 .45326 .62442 .4498 .61905 .44455 Mtetra
.649 .788 .949 r
.61905 .44455 .62442 .4498 .63523 .44649 .62989 .44119 Mtetra
.644 .785 .949 r
.62989 .44119 .63523 .44649 .64609 .44332 .64077 .43792 Mtetra
.64 .781 .949 r
.64077 .43792 .64609 .44332 .65699 .44029 .65171 .43475 Mtetra
.637 .775 .947 r
.65171 .43475 .65699 .44029 .66795 .43738 .66269 .43165 Mtetra
.635 .768 .944 r
.66269 .43165 .66795 .43738 .67896 .43456 .67372 .42862 Mtetra
.634 .761 .939 r
.67372 .42862 .67896 .43456 .69002 .4318 .6848 .42562 Mtetra
.633 .753 .934 r
.6848 .42562 .69002 .4318 .70113 .42907 .69593 .42265 Mtetra
.634 .745 .928 r
.69593 .42265 .70113 .42907 .71229 .42634 .70711 .41967 Mtetra
.636 .738 .922 r
.70711 .41967 .71229 .42634 .7235 .42357 .71833 .41665 Mtetra
.638 .731 .916 r
.71833 .41665 .7235 .42357 .73475 .42073 .7296 .41358 Mtetra
.641 .726 .91 r
.7296 .41358 .73475 .42073 .74605 .41778 .74091 .41044 Mtetra
.644 .722 .904 r
.74091 .41044 .74605 .41778 .75738 .41471 .75226 .40719 Mtetra
.648 .719 .9 r
.75226 .40719 .75738 .41471 .76876 .41148 .76366 .40384 Mtetra
.651 .717 .896 r
.76366 .40384 .76876 .41148 .78017 .40808 .77509 .40036 Mtetra
.655 .717 .894 r
.77509 .40036 .78017 .40808 .79161 .4045 .78656 .39675 Mtetra
.659 .718 .893 r
.78656 .39675 .79161 .4045 .80308 .40074 .79807 .39301 Mtetra
.663 .721 .892 r
.79807 .39301 .80308 .40074 .81459 .39682 .80961 .38914 Mtetra
.666 .725 .894 r
.80961 .38914 .81459 .39682 .82612 .39273 .82118 .38515 Mtetra
.669 .731 .896 r
.82118 .38515 .82612 .39273 .83769 .3885 .8328 .38106 Mtetra
.672 .737 .899 r
.8328 .38106 .83769 .3885 .84928 .38415 .84445 .37689 Mtetra
.674 .744 .904 r
.84445 .37689 .84928 .38415 .86092 .37972 .85613 .37265 Mtetra
.675 .752 .909 r
.85613 .37265 .86092 .37972 .87259 .37524 .86786 .36837 Mtetra
.669 .754 .915 r
.23902 .55988 .24535 .5654 .25484 .56189 .24851 .55656 Mtetra
.668 .762 .92 r
.24851 .55656 .25484 .56189 .26435 .55839 .25803 .55324 Mtetra
.667 .769 .926 r
.25803 .55324 .26435 .55839 .2739 .55493 .26758 .54994 Mtetra
.665 .775 .932 r
.26758 .54994 .2739 .55493 .28347 .55152 .27716 .54666 Mtetra
.662 .781 .937 r
.27716 .54666 .28347 .55152 .29306 .54818 .28678 .54343 Mtetra
.659 .785 .941 r
.28678 .54343 .29306 .54818 .30269 .54493 .29642 .54024 Mtetra
.655 .787 .945 r
.29642 .54024 .30269 .54493 .31234 .54178 .30609 .5371 Mtetra
.652 .788 .947 r
.30609 .5371 .31234 .54178 .32202 .53872 .3158 .53402 Mtetra
.649 .787 .948 r
.3158 .53402 .32202 .53872 .33173 .53577 .32553 .531 Mtetra
.646 .784 .948 r
.32553 .531 .33173 .53577 .34147 .53291 .3353 .52803 Mtetra
.644 .78 .946 r
.3353 .52803 .34147 .53291 .35124 .53013 .34511 .5251 Mtetra
.642 .774 .944 r
.34511 .5251 .35124 .53013 .36105 .52743 .35494 .52221 Mtetra
.642 .768 .94 r
.35494 .52221 .36105 .52743 .37089 .52477 .36482 .51934 Mtetra
.641 .761 .935 r
.36482 .51934 .37089 .52477 .38077 .52215 .37473 .51649 Mtetra
.642 .753 .93 r
.37473 .51649 .38077 .52215 .39069 .51953 .38468 .51364 Mtetra
.643 .746 .924 r
.38468 .51364 .39069 .51953 .40064 .5169 .39467 .51077 Mtetra
.644 .739 .918 r
.39467 .51077 .40064 .5169 .41064 .51423 .4047 .50788 Mtetra
.646 .732 .912 r
.4047 .50788 .41064 .51423 .42069 .51149 .41477 .50494 Mtetra
.648 .727 .907 r
.41477 .50494 .42069 .51149 .43077 .50867 .42487 .50195 Mtetra
.65 .723 .902 r
.42487 .50195 .43077 .50867 .4409 .50575 .43503 .49889 Mtetra
.652 .72 .898 r
.43503 .49889 .4409 .50575 .45107 .50272 .44522 .49576 Mtetra
.654 .718 .896 r
.44522 .49576 .45107 .50272 .46127 .49956 .45545 .49255 Mtetra
.657 .718 .894 r
.45545 .49255 .46127 .49956 .47153 .49628 .46572 .48926 Mtetra
.659 .72 .893 r
.46572 .48926 .47153 .49628 .48182 .49287 .47603 .4859 Mtetra
.661 .722 .894 r
.47603 .4859 .48182 .49287 .49215 .48935 .48638 .48245 Mtetra
.663 .726 .896 r
.48638 .48245 .49215 .48935 .50251 .48572 .49677 .47894 Mtetra
.665 .731 .899 r
.49677 .47894 .50251 .48572 .51292 .482 .5072 .47537 Mtetra
.667 .737 .903 r
.5072 .47537 .51292 .482 .52336 .4782 .51767 .47175 Mtetra
.668 .744 .908 r
.51767 .47175 .52336 .4782 .53384 .47436 .52817 .4681 Mtetra
.668 .752 .913 r
.52817 .4681 .53384 .47436 .54436 .47049 .53872 .46442 Mtetra
.668 .759 .919 r
.53872 .46442 .54436 .47049 .55491 .46662 .5493 .46074 Mtetra
.667 .766 .924 r
.5493 .46074 .55491 .46662 .5655 .46278 .55992 .45707 Mtetra
.665 .773 .93 r
.55992 .45707 .5655 .46278 .57612 .45897 .57058 .45342 Mtetra
.663 .779 .935 r
.57058 .45342 .57612 .45897 .58679 .45524 .58128 .4498 Mtetra
.66 .783 .94 r
.58128 .4498 .58679 .45524 .5975 .45158 .59202 .44623 Mtetra
.657 .786 .943 r
.59202 .44623 .5975 .45158 .60825 .44801 .6028 .4427 Mtetra
.653 .788 .946 r
.6028 .4427 .60825 .44801 .61905 .44455 .61363 .43923 Mtetra
.65 .787 .947 r
.61363 .43923 .61905 .44455 .62989 .44119 .6245 .43581 Mtetra
.648 .785 .948 r
.6245 .43581 .62989 .44119 .64077 .43792 .63542 .43245 Mtetra
.645 .782 .946 r
.63542 .43245 .64077 .43792 .65171 .43475 .64638 .42914 Mtetra
.644 .777 .944 r
.64638 .42914 .65171 .43475 .66269 .43165 .65739 .42586 Mtetra
.643 .77 .941 r
.65739 .42586 .66269 .43165 .67372 .42862 .66844 .42262 Mtetra
.642 .763 .936 r
.66844 .42262 .67372 .42862 .6848 .42562 .67954 .4194 Mtetra
.642 .756 .931 r
.67954 .4194 .6848 .42562 .69593 .42265 .69069 .41618 Mtetra
.643 .748 .926 r
.69069 .41618 .69593 .42265 .70711 .41967 .70188 .41295 Mtetra
.644 .741 .92 r
.70188 .41295 .70711 .41967 .71833 .41665 .71312 .4097 Mtetra
.646 .735 .914 r
.71312 .4097 .71833 .41665 .7296 .41358 .72441 .40641 Mtetra
.647 .729 .908 r
.72441 .40641 .7296 .41358 .74091 .41044 .73574 .40306 Mtetra
.649 .724 .904 r
.73574 .40306 .74091 .41044 .75226 .40719 .74711 .39966 Mtetra
.651 .721 .9 r
.74711 .39966 .75226 .40719 .76366 .40384 .75853 .39618 Mtetra
.653 .719 .897 r
.75853 .39618 .76366 .40384 .77509 .40036 .76998 .39262 Mtetra
.655 .718 .895 r
.76998 .39262 .77509 .40036 .78656 .39675 .78148 .38897 Mtetra
.658 .719 .894 r
.78148 .38897 .78656 .39675 .79807 .39301 .79302 .38524 Mtetra
.66 .721 .894 r
.79302 .38524 .79807 .39301 .80961 .38914 .8046 .38143 Mtetra
.662 .724 .896 r
.8046 .38143 .80961 .38914 .82118 .38515 .81621 .37755 Mtetra
.664 .729 .898 r
.81621 .37755 .82118 .38515 .8328 .38106 .82787 .37359 Mtetra
.665 .735 .902 r
.82787 .37359 .8328 .38106 .84445 .37689 .83957 .36958 Mtetra
.667 .742 .906 r
.83957 .36958 .84445 .37689 .85613 .37265 .85132 .36553 Mtetra
.667 .749 .911 r
.85132 .36553 .85613 .37265 .86786 .36837 .8631 .36144 Mtetra
.66 .752 .918 r
.23264 .55431 .23902 .55988 .24851 .55656 .24214 .55118 Mtetra
.66 .76 .924 r
.24214 .55118 .24851 .55656 .25803 .55324 .25166 .54804 Mtetra
.659 .767 .929 r
.25166 .54804 .25803 .55324 .26758 .54994 .26122 .5449 Mtetra
.658 .773 .934 r
.26122 .5449 .26758 .54994 .27716 .54666 .27082 .54176 Mtetra
.656 .779 .939 r
.27082 .54176 .27716 .54666 .28678 .54343 .28044 .53862 Mtetra
.655 .783 .942 r
.28044 .53862 .28678 .54343 .29642 .54024 .29011 .5355 Mtetra
.653 .786 .945 r
.29011 .5355 .29642 .54024 .30609 .5371 .2998 .53238 Mtetra
.652 .787 .946 r
.2998 .53238 .30609 .5371 .3158 .53402 .30953 .52927 Mtetra
.651 .787 .947 r
.30953 .52927 .3158 .53402 .32553 .531 .31929 .52618 Mtetra
.65 .785 .946 r
.31929 .52618 .32553 .531 .3353 .52803 .32909 .52309 Mtetra
.65 .781 .944 r
.32909 .52309 .3353 .52803 .34511 .5251 .33893 .52002 Mtetra
.65 .776 .94 r
.33893 .52002 .34511 .5251 .35494 .52221 .3488 .51694 Mtetra
.65 .77 .936 r
.3488 .51694 .35494 .52221 .36482 .51934 .3587 .51387 Mtetra
.651 .763 .931 r
.3587 .51387 .36482 .51934 .37473 .51649 .36865 .51079 Mtetra
.651 .756 .926 r
.36865 .51079 .37473 .51649 .38468 .51364 .37863 .50771 Mtetra
.652 .748 .921 r
.37863 .50771 .38468 .51364 .39467 .51077 .38865 .50461 Mtetra
.652 .741 .915 r
.38865 .50461 .39467 .51077 .4047 .50788 .39871 .5015 Mtetra
.653 .735 .91 r
.39871 .5015 .4047 .50788 .41477 .50494 .4088 .49836 Mtetra
.653 .729 .905 r
.4088 .49836 .41477 .50494 .42487 .50195 .41894 .49519 Mtetra
.654 .724 .901 r
.41894 .49519 .42487 .50195 .43503 .49889 .42912 .492 Mtetra
.654 .721 .898 r
.42912 .492 .43503 .49889 .44522 .49576 .43933 .48877 Mtetra
.655 .719 .896 r
.43933 .48877 .44522 .49576 .45545 .49255 .44958 .48551 Mtetra
.656 .719 .895 r
.44958 .48551 .45545 .49255 .46572 .48926 .45988 .48222 Mtetra
.657 .719 .895 r
.45988 .48222 .46572 .48926 .47603 .4859 .47021 .47889 Mtetra
.658 .721 .896 r
.47021 .47889 .47603 .4859 .48638 .48245 .48058 .47552 Mtetra
.658 .725 .898 r
.48058 .47552 .48638 .48245 .49677 .47894 .491 .47213 Mtetra
.659 .73 .902 r
.491 .47213 .49677 .47894 .5072 .47537 .50145 .46871 Mtetra
.66 .735 .906 r
.50145 .46871 .5072 .47537 .51767 .47175 .51194 .46526 Mtetra
.66 .742 .911 r
.51194 .46526 .51767 .47175 .52817 .4681 .52247 .46179 Mtetra
.66 .749 .916 r
.52247 .46179 .52817 .4681 .53872 .46442 .53304 .45831 Mtetra
.66 .756 .922 r
.53304 .45831 .53872 .46442 .5493 .46074 .54365 .45481 Mtetra
.659 .764 .927 r
.54365 .45481 .5493 .46074 .55992 .45707 .5543 .45131 Mtetra
.658 .77 .932 r
.5543 .45131 .55992 .45707 .57058 .45342 .56499 .44781 Mtetra
.657 .776 .937 r
.56499 .44781 .57058 .45342 .58128 .4498 .57572 .44431 Mtetra
.656 .781 .941 r
.57572 .44431 .58128 .4498 .59202 .44623 .5865 .44082 Mtetra
.654 .785 .944 r
.5865 .44082 .59202 .44623 .6028 .4427 .59731 .43733 Mtetra
.653 .787 .946 r
.59731 .43733 .6028 .4427 .61363 .43923 .60817 .43385 Mtetra
.652 .787 .947 r
.60817 .43385 .61363 .43923 .6245 .43581 .61907 .43038 Mtetra
.651 .786 .946 r
.61907 .43038 .6245 .43581 .63542 .43245 .63002 .42692 Mtetra
.65 .783 .945 r
.63002 .42692 .63542 .43245 .64638 .42914 .64101 .42347 Mtetra
.65 .778 .942 r
.64101 .42347 .64638 .42914 .65739 .42586 .65204 .42002 Mtetra
.65 .773 .938 r
.65204 .42002 .65739 .42586 .66844 .42262 .66312 .41657 Mtetra
.651 .766 .934 r
.66312 .41657 .66844 .42262 .67954 .4194 .67424 .41312 Mtetra
.651 .759 .928 r
.67424 .41312 .67954 .4194 .69069 .41618 .68541 .40966 Mtetra
.652 .752 .923 r
.68541 .40966 .69069 .41618 .70188 .41295 .69662 .40619 Mtetra
.652 .744 .917 r
.69662 .40619 .70188 .41295 .71312 .4097 .70788 .4027 Mtetra
.653 .738 .912 r
.70788 .4027 .71312 .4097 .72441 .40641 .71918 .39919 Mtetra
.653 .732 .907 r
.71918 .39919 .72441 .40641 .73574 .40306 .73053 .39565 Mtetra
.654 .726 .902 r
.73053 .39565 .73574 .40306 .74711 .39966 .74192 .39208 Mtetra
.654 .723 .899 r
.74192 .39208 .74711 .39966 .75853 .39618 .75336 .38848 Mtetra
.655 .72 .896 r
.75336 .38848 .75853 .39618 .76998 .39262 .76484 .38484 Mtetra
.656 .719 .895 r
.76484 .38484 .76998 .39262 .78148 .38897 .77637 .38116 Mtetra
.77637 .38116 .78148 .38897 .79302 .38524 .78794 .37745 Mtetra
.657 .72 .895 r
.78794 .37745 .79302 .38524 .8046 .38143 .79955 .37369 Mtetra
.658 .723 .897 r
.79955 .37369 .8046 .38143 .81621 .37755 .81121 .3699 Mtetra
.659 .727 .9 r
.81121 .3699 .81621 .37755 .82787 .37359 .82292 .36608 Mtetra
.659 .733 .904 r
.82292 .36608 .82787 .37359 .83957 .36958 .83467 .36223 Mtetra
.66 .739 .908 r
.83467 .36223 .83957 .36958 .85132 .36553 .84646 .35836 Mtetra
.66 .746 .914 r
.84646 .35836 .85132 .36553 .8631 .36144 .85831 .35446 Mtetra
.651 .75 .922 r
.22623 .54871 .23264 .55431 .24214 .55118 .23572 .54577 Mtetra
.651 .758 .928 r
.23572 .54577 .24214 .55118 .25166 .54804 .24525 .5428 Mtetra
.651 .765 .933 r
.24525 .5428 .25166 .54804 .26122 .5449 .25482 .53982 Mtetra
.651 .772 .937 r
.25482 .53982 .26122 .5449 .27082 .54176 .26442 .53681 Mtetra
.651 .777 .941 r
.26442 .53681 .27082 .54176 .28044 .53862 .27407 .53378 Mtetra
.651 .782 .944 r
.27407 .53378 .28044 .53862 .29011 .5355 .28375 .53072 Mtetra
.652 .785 .945 r
.28375 .53072 .29011 .5355 .2998 .53238 .29346 .52762 Mtetra
.652 .787 .946 r
.29346 .52762 .2998 .53238 .30953 .52927 .30322 .52449 Mtetra
.654 .787 .946 r
.30322 .52449 .30953 .52927 .31929 .52618 .31301 .52132 Mtetra
.655 .786 .944 r
.31301 .52132 .31929 .52618 .32909 .52309 .32284 .51812 Mtetra
.656 .782 .941 r
.32284 .51812 .32909 .52309 .33893 .52002 .3327 .51489 Mtetra
.657 .778 .937 r
.3327 .51489 .33893 .52002 .3488 .51694 .34261 .51164 Mtetra
.659 .772 .933 r
.34261 .51164 .3488 .51694 .3587 .51387 .35255 .50835 Mtetra
.659 .765 .928 r
.35255 .50835 .3587 .51387 .36865 .51079 .36252 .50505 Mtetra
.66 .758 .923 r
.36252 .50505 .36865 .51079 .37863 .50771 .37254 .50173 Mtetra
.66 .751 .917 r
.37254 .50173 .37863 .50771 .38865 .50461 .38259 .49841 Mtetra
.66 .744 .912 r
.38259 .49841 .38865 .50461 .39871 .5015 .39268 .49507 Mtetra
.659 .737 .907 r
.39268 .49507 .39871 .5015 .4088 .49836 .4028 .49173 Mtetra
.659 .731 .903 r
.4028 .49173 .4088 .49836 .41894 .49519 .41297 .4884 Mtetra
.658 .726 .899 r
.41297 .4884 .41894 .49519 .42912 .492 .42317 .48507 Mtetra
.657 .722 .897 r
.42317 .48507 .42912 .492 .43933 .48877 .43341 .48175 Mtetra
.656 .72 .895 r
.43341 .48175 .43933 .48877 .44958 .48551 .44368 .47843 Mtetra
.655 .718 .895 r
.44368 .47843 .44958 .48551 .45988 .48222 .454 .47513 Mtetra
.655 .719 .896 r
.454 .47513 .45988 .48222 .47021 .47889 .46435 .47184 Mtetra
.654 .72 .897 r
.46435 .47184 .47021 .47889 .48058 .47552 .47475 .46855 Mtetra
.653 .723 .9 r
.47475 .46855 .48058 .47552 .491 .47213 .48518 .46528 Mtetra
.653 .728 .904 r
.48518 .46528 .491 .47213 .50145 .46871 .49565 .462 Mtetra
.652 .733 .908 r
.49565 .462 .50145 .46871 .51194 .46526 .50617 .45872 Mtetra
.652 .739 .914 r
.50617 .45872 .51194 .46526 .52247 .46179 .51672 .45544 Mtetra
.652 .746 .919 r
.51672 .45544 .52247 .46179 .53304 .45831 .52732 .45215 Mtetra
.651 .754 .924 r
.52732 .45215 .53304 .45831 .54365 .45481 .53796 .44884 Mtetra
.651 .761 .93 r
.53796 .44884 .54365 .45481 .5543 .45131 .54864 .44551 Mtetra
.651 .768 .935 r
.54864 .44551 .5543 .45131 .56499 .44781 .55936 .44216 Mtetra
.651 .774 .939 r
.55936 .44216 .56499 .44781 .57572 .44431 .57012 .43877 Mtetra
.651 .78 .942 r
.57012 .43877 .57572 .44431 .5865 .44082 .58093 .43536 Mtetra
.651 .784 .945 r
.58093 .43536 .5865 .44082 .59731 .43733 .59178 .43191 Mtetra
.652 .786 .946 r
.59178 .43191 .59731 .43733 .60817 .43385 .60267 .42842 Mtetra
.653 .787 .946 r
.60267 .42842 .60817 .43385 .61907 .43038 .6136 .4249 Mtetra
.654 .787 .945 r
.6136 .4249 .61907 .43038 .63002 .42692 .62458 .42134 Mtetra
.655 .784 .943 r
.62458 .42134 .63002 .42692 .64101 .42347 .6356 .41775 Mtetra
.657 .78 .94 r
.6356 .41775 .64101 .42347 .65204 .42002 .64666 .41413 Mtetra
.658 .775 .936 r
.64666 .41413 .65204 .42002 .66312 .41657 .65776 .41047 Mtetra
.659 .769 .931 r
.65776 .41047 .66312 .41657 .67424 .41312 .6689 .4068 Mtetra
.659 .762 .926 r
.6689 .4068 .67424 .41312 .68541 .40966 .68009 .4031 Mtetra
.66 .755 .92 r
.68009 .4031 .68541 .40966 .69662 .40619 .69132 .39938 Mtetra
.66 .747 .915 r
.69132 .39938 .69662 .40619 .70788 .4027 .7026 .39566 Mtetra
.659 .74 .91 r
.7026 .39566 .70788 .4027 .71918 .39919 .71392 .39193 Mtetra
.659 .734 .905 r
.71392 .39193 .71918 .39919 .73053 .39565 .72529 .38819 Mtetra
.658 .728 .901 r
.72529 .38819 .73053 .39565 .74192 .39208 .7367 .38446 Mtetra
.657 .724 .898 r
.7367 .38446 .74192 .39208 .75336 .38848 .74816 .38073 Mtetra
.657 .721 .896 r
.74816 .38073 .75336 .38848 .76484 .38484 .75966 .37701 Mtetra
.656 .719 .895 r
.75966 .37701 .76484 .38484 .77637 .38116 .77122 .3733 Mtetra
.655 .718 .895 r
.77122 .3733 .77637 .38116 .78794 .37745 .78282 .3696 Mtetra
.654 .719 .896 r
.78282 .3696 .78794 .37745 .79955 .37369 .79447 .3659 Mtetra
.654 .722 .899 r
.79447 .3659 .79955 .37369 .81121 .3699 .80617 .36221 Mtetra
.653 .725 .902 r
.80617 .36221 .81121 .3699 .82292 .36608 .81793 .35852 Mtetra
.653 .73 .906 r
.81793 .35852 .82292 .36608 .83467 .36223 .82973 .35483 Mtetra
.652 .736 .911 r
.82973 .35483 .83467 .36223 .84646 .35836 .84158 .35114 Mtetra
.652 .743 .916 r
.84158 .35114 .84646 .35836 .85831 .35446 .85348 .34743 Mtetra
.642 .748 .926 r
.21976 .54307 .22623 .54871 .23572 .54577 .22926 .54031 Mtetra
.642 .755 .931 r
.22926 .54031 .23572 .54577 .24525 .5428 .2388 .53753 Mtetra
.642 .763 .936 r
.2388 .53753 .24525 .5428 .25482 .53982 .24837 .53471 Mtetra
.643 .77 .94 r
.24837 .53471 .25482 .53982 .26442 .53681 .25799 .53184 Mtetra
.645 .776 .943 r
.25799 .53184 .26442 .53681 .27407 .53378 .26764 .52891 Mtetra
.647 .781 .945 r
.26764 .52891 .27407 .53378 .28375 .53072 .27734 .5259 Mtetra
.65 .785 .946 r
.27734 .5259 .28375 .53072 .29346 .52762 .28707 .52282 Mtetra
.653 .787 .946 r
.28707 .52282 .29346 .52762 .30322 .52449 .29685 .51967 Mtetra
.656 .788 .945 r
.29685 .51967 .30322 .52449 .31301 .52132 .30667 .51643 Mtetra
.659 .787 .942 r
.30667 .51643 .31301 .52132 .32284 .51812 .31653 .51312 Mtetra
.662 .784 .939 r
.31653 .51312 .32284 .51812 .3327 .51489 .32643 .50974 Mtetra
.665 .78 .935 r
.32643 .50974 .3327 .51489 .34261 .51164 .33637 .50629 Mtetra
.667 .774 .93 r
.33637 .50629 .34261 .51164 .35255 .50835 .34634 .5028 Mtetra
.668 .768 .925 r
.34634 .5028 .35255 .50835 .36252 .50505 .35636 .49927 Mtetra
.668 .76 .919 r
.35636 .49927 .36252 .50505 .37254 .50173 .36641 .49572 Mtetra
.668 .753 .914 r
.36641 .49572 .37254 .50173 .38259 .49841 .37649 .49216 Mtetra
.667 .746 .909 r
.37649 .49216 .38259 .49841 .39268 .49507 .38661 .4886 Mtetra
.666 .739 .904 r
.38661 .4886 .39268 .49507 .4028 .49173 .39677 .48506 Mtetra
.664 .732 .901 r
.39677 .48506 .4028 .49173 .41297 .4884 .40696 .48156 Mtetra
.662 .727 .898 r
.40696 .48156 .41297 .4884 .42317 .48507 .41718 .47809 Mtetra
.66 .723 .896 r
.41718 .47809 .42317 .48507 .43341 .48175 .42744 .47467 Mtetra
.657 .72 .895 r
.42744 .47467 .43341 .48175 .44368 .47843 .43774 .4713 Mtetra
.655 .718 .895 r
.43774 .4713 .44368 .47843 .454 .47513 .44808 .468 Mtetra
.652 .718 .896 r
.44808 .468 .454 .47513 .46435 .47184 .45845 .46474 Mtetra
.65 .719 .899 r
.45845 .46474 .46435 .47184 .47475 .46855 .46887 .46153 Mtetra
.648 .721 .902 r
.46887 .46153 .47475 .46855 .48518 .46528 .47932 .45837 Mtetra
.646 .725 .906 r
.47932 .45837 .48518 .46528 .49565 .462 .48982 .45525 Mtetra
.645 .73 .911 r
.48982 .45525 .49565 .462 .50617 .45872 .50036 .45214 Mtetra
.644 .737 .916 r
.50036 .45214 .50617 .45872 .51672 .45544 .51094 .44904 Mtetra
.643 .743 .922 r
.51094 .44904 .51672 .45544 .52732 .45215 .52156 .44594 Mtetra
.643 .751 .927 r
.52156 .44594 .52732 .45215 .53796 .44884 .53222 .44282 Mtetra
.643 .758 .933 r
.53222 .44282 .53796 .44884 .54864 .44551 .54293 .43966 Mtetra
.644 .766 .937 r
.54293 .43966 .54864 .44551 .55936 .44216 .55369 .43646 Mtetra
.645 .773 .941 r
.55369 .43646 .55936 .44216 .57012 .43877 .56448 .4332 Mtetra
.646 .778 .944 r
.56448 .4332 .57012 .43877 .58093 .43536 .57532 .42986 Mtetra
.649 .783 .946 r
.57532 .42986 .58093 .43536 .59178 .43191 .5862 .42645 Mtetra
.651 .786 .946 r
.5862 .42645 .59178 .43191 .60267 .42842 .59713 .42296 Mtetra
.654 .788 .946 r
.59713 .42296 .60267 .42842 .6136 .4249 .60809 .41939 Mtetra
.657 .788 .944 r
.60809 .41939 .6136 .4249 .62458 .42134 .6191 .41573 Mtetra
.66 .786 .941 r
.6191 .41573 .62458 .42134 .6356 .41775 .63014 .412 Mtetra
.663 .783 .938 r
.63014 .412 .6356 .41775 .64666 .41413 .64123 .40819 Mtetra
.665 .778 .933 r
.64123 .40819 .64666 .41413 .65776 .41047 .65236 .40433 Mtetra
.667 .772 .928 r
.65236 .40433 .65776 .41047 .6689 .4068 .66352 .40042 Mtetra
.668 .765 .923 r
.66352 .40042 .6689 .4068 .68009 .4031 .67473 .39648 Mtetra
.668 .758 .918 r
.67473 .39648 .68009 .4031 .69132 .39938 .68599 .39252 Mtetra
.667 .75 .912 r
.68599 .39252 .69132 .39938 .7026 .39566 .69728 .38856 Mtetra
.666 .743 .907 r
.69728 .38856 .7026 .39566 .71392 .39193 .70862 .38461 Mtetra
.665 .736 .903 r
.70862 .38461 .71392 .39193 .72529 .38819 .72001 .38068 Mtetra
.663 .73 .9 r
.72001 .38068 .72529 .38819 .7367 .38446 .73144 .37678 Mtetra
.661 .725 .897 r
.73144 .37678 .7367 .38446 .74816 .38073 .74292 .37293 Mtetra
.658 .721 .895 r
.74292 .37293 .74816 .38073 .75966 .37701 .75445 .36913 Mtetra
.656 .719 .895 r
.75445 .36913 .75966 .37701 .77122 .3733 .76604 .36538 Mtetra
.654 .718 .895 r
.76604 .36538 .77122 .3733 .78282 .3696 .77767 .36169 Mtetra
.651 .718 .897 r
.77767 .36169 .78282 .3696 .79447 .3659 .78936 .35805 Mtetra
.649 .72 .9 r
.78936 .35805 .79447 .3659 .80617 .36221 .8011 .35446 Mtetra
.648 .723 .903 r
.8011 .35446 .80617 .36221 .81793 .35852 .8129 .35091 Mtetra
.646 .727 .908 r
.8129 .35091 .81793 .35852 .82973 .35483 .82475 .34738 Mtetra
.645 .733 .913 r
.82475 .34738 .82973 .35483 .84158 .35114 .83665 .34386 Mtetra
.644 .739 .918 r
.83665 .34386 .84158 .35114 .85348 .34743 .84861 .34035 Mtetra
.632 .745 .93 r
.21326 .53739 .21976 .54307 .22926 .54031 .22276 .53483 Mtetra
.632 .753 .935 r
.22276 .53483 .22926 .54031 .2388 .53753 .23229 .53223 Mtetra
.633 .761 .939 r
.23229 .53223 .2388 .53753 .24837 .53471 .24187 .52957 Mtetra
.636 .768 .943 r
.24187 .52957 .24837 .53471 .25799 .53184 .2515 .52684 Mtetra
.639 .775 .946 r
.2515 .52684 .25799 .53184 .26764 .52891 .26117 .52401 Mtetra
.643 .781 .947 r
.26117 .52401 .26764 .52891 .27734 .5259 .27088 .52107 Mtetra
.648 .785 .947 r
.27088 .52107 .27734 .5259 .28707 .52282 .28064 .51801 Mtetra
.653 .788 .946 r
.28064 .51801 .28707 .52282 .29685 .51967 .29044 .51483 Mtetra
.658 .789 .944 r
.29044 .51483 .29685 .51967 .30667 .51643 .30029 .51152 Mtetra
.663 .788 .941 r
.30029 .51152 .30667 .51643 .31653 .51312 .31018 .50809 Mtetra
.668 .786 .937 r
.31018 .50809 .31653 .51312 .32643 .50974 .32011 .50455 Mtetra
.672 .782 .932 r
.32011 .50455 .32643 .50974 .33637 .50629 .33009 .50092 Mtetra
.674 .776 .927 r
.33009 .50092 .33637 .50629 .34634 .5028 .3401 .49722 Mtetra
.676 .77 .921 r
.3401 .49722 .34634 .5028 .35636 .49927 .35015 .49345 Mtetra
.677 .763 .916 r
.35015 .49345 .35636 .49927 .36641 .49572 .36023 .48966 Mtetra
.676 .755 .91 r
.36023 .48966 .36641 .49572 .37649 .49216 .37035 .48586 Mtetra
.675 .748 .906 r
.37035 .48586 .37649 .49216 .38661 .4886 .3805 .48208 Mtetra
.673 .74 .901 r
.3805 .48208 .38661 .4886 .39677 .48506 .39069 .47834 Mtetra
.67 .734 .898 r
.39069 .47834 .39677 .48506 .40696 .48156 .40091 .47465 Mtetra
.666 .728 .896 r
.40091 .47465 .40696 .48156 .41718 .47809 .41116 .47105 Mtetra
.662 .723 .894 r
.41116 .47105 .41718 .47809 .42744 .47467 .42144 .46753 Mtetra
.658 .72 .894 r
.42144 .46753 .42744 .47467 .43774 .4713 .43177 .46411 Mtetra
.654 .717 .895 r
.43177 .46411 .43774 .4713 .44808 .468 .44212 .46079 Mtetra
.65 .717 .897 r
.44212 .46079 .44808 .468 .45845 .46474 .45252 .45758 Mtetra
.646 .717 .9 r
.45252 .45758 .45845 .46474 .46887 .46153 .46295 .45445 Mtetra
.643 .719 .903 r
.46295 .45445 .46887 .46153 .47932 .45837 .47343 .45141 Mtetra
.64 .723 .908 r
.47343 .45141 .47932 .45837 .48982 .45525 .48395 .44844 Mtetra
.637 .727 .913 r
.48395 .44844 .48982 .45525 .50036 .45214 .4945 .44551 Mtetra
.635 .733 .919 r
.4945 .44551 .50036 .45214 .51094 .44904 .50511 .4426 Mtetra
.634 .74 .925 r
.50511 .4426 .51094 .44904 .52156 .44594 .51576 .43969 Mtetra
.634 .748 .93 r
.51576 .43969 .52156 .44594 .53222 .44282 .52645 .43676 Mtetra
.634 .756 .935 r
.52645 .43676 .53222 .44282 .54293 .43966 .53719 .43378 Mtetra
.636 .763 .94 r
.53719 .43378 .54293 .43966 .55369 .43646 .54797 .43073 Mtetra
.638 .771 .943 r
.54797 .43073 .55369 .43646 .56448 .4332 .5588 .42759 Mtetra
.642 .777 .946 r
.5588 .42759 .56448 .4332 .57532 .42986 .56967 .42434 Mtetra
.646 .783 .947 r
.56967 .42434 .57532 .42986 .5862 .42645 .58058 .42097 Mtetra
.65 .787 .947 r
.58058 .42097 .5862 .42645 .59713 .42296 .59154 .41747 Mtetra
.655 .789 .946 r
.59154 .41747 .59713 .42296 .60809 .41939 .60253 .41384 Mtetra
.66 .79 .943 r
.60253 .41384 .60809 .41939 .6191 .41573 .61357 .41008 Mtetra
.665 .788 .94 r
.61357 .41008 .6191 .41573 .63014 .412 .62465 .40621 Mtetra
.669 .785 .936 r
.62465 .40621 .63014 .412 .64123 .40819 .63576 .40222 Mtetra
.672 .781 .931 r
.63576 .40222 .64123 .40819 .65236 .40433 .64691 .39815 Mtetra
.674 .775 .926 r
.64691 .39815 .65236 .40433 .66352 .40042 .65811 .39401 Mtetra
.676 .768 .92 r
.65811 .39401 .66352 .40042 .67473 .39648 .66934 .38982 Mtetra
.676 .761 .915 r
.66934 .38982 .67473 .39648 .68599 .39252 .68061 .38561 Mtetra
.675 .753 .91 r
.68061 .38561 .68599 .39252 .69728 .38856 .69193 .38141 Mtetra
.673 .745 .905 r
.69193 .38141 .69728 .38856 .70862 .38461 .70329 .37723 Mtetra
.67 .738 .901 r
.70329 .37723 .70862 .38461 .72001 .38068 .71469 .3731 Mtetra
.667 .732 .898 r
.71469 .3731 .72001 .38068 .73144 .37678 .72614 .36904 Mtetra
.664 .726 .896 r
.72614 .36904 .73144 .37678 .74292 .37293 .73765 .36506 Mtetra
.66 .722 .894 r
.73765 .36506 .74292 .37293 .75445 .36913 .7492 .36118 Mtetra
.656 .718 .894 r
.7492 .36118 .75445 .36913 .76604 .36538 .76082 .3574 Mtetra
.652 .717 .895 r
.76082 .3574 .76604 .36538 .77767 .36169 .77248 .35372 Mtetra
.649 .716 .897 r
.77248 .35372 .77767 .36169 .78936 .35805 .78421 .35014 Mtetra
.645 .717 .9 r
.78421 .35014 .78936 .35805 .8011 .35446 .79599 .34664 Mtetra
.642 .72 .904 r
.79599 .34664 .8011 .35446 .8129 .35091 .80783 .34322 Mtetra
.639 .724 .909 r
.80783 .34322 .8129 .35091 .82475 .34738 .81973 .33986 Mtetra
.637 .729 .914 r
.81973 .33986 .82475 .34738 .83665 .34386 .83169 .33653 Mtetra
.636 .735 .92 r
.83169 .33653 .83665 .34386 .84861 .34035 .8437 .33321 Mtetra
.621 .742 .933 r
.20671 .53168 .21326 .53739 .22276 .53483 .21621 .52931 Mtetra
.622 .75 .939 r
.21621 .52931 .22276 .53483 .23229 .53223 .22575 .5269 Mtetra
.624 .759 .943 r
.22575 .5269 .23229 .53223 .24187 .52957 .23533 .52442 Mtetra
.627 .767 .946 r
.23533 .52442 .24187 .52957 .2515 .52684 .24496 .52183 Mtetra
.632 .774 .949 r
.24496 .52183 .2515 .52684 .26117 .52401 .25464 .5191 Mtetra
.638 .781 .949 r
.25464 .5191 .26117 .52401 .27088 .52107 .26437 .51623 Mtetra
.645 .786 .949 r
.26437 .51623 .27088 .52107 .28064 .51801 .27415 .51319 Mtetra
.653 .789 .947 r
.27415 .51319 .28064 .51801 .29044 .51483 .28398 .50998 Mtetra
.661 .791 .944 r
.28398 .50998 .29044 .51483 .30029 .51152 .29386 .5066 Mtetra
.668 .79 .94 r
.29386 .5066 .30029 .51152 .31018 .50809 .30378 .50305 Mtetra
.674 .788 .935 r
.30378 .50305 .31018 .50809 .32011 .50455 .31375 .49935 Mtetra
.679 .784 .929 r
.31375 .49935 .32011 .50455 .33009 .50092 .32376 .49553 Mtetra
.682 .779 .924 r
.32376 .49553 .33009 .50092 .3401 .49722 .33381 .4916 Mtetra
.684 .772 .918 r
.33381 .4916 .3401 .49722 .35015 .49345 .34389 .4876 Mtetra
.685 .765 .912 r
.34389 .4876 .35015 .49345 .36023 .48966 .35401 .48356 Mtetra
.684 .757 .907 r
.35401 .48356 .36023 .48966 .37035 .48586 .36417 .47952 Mtetra
.682 .749 .902 r
.36417 .47952 .37035 .48586 .3805 .48208 .37435 .4755 Mtetra
.679 .742 .898 r
.37435 .4755 .3805 .48208 .39069 .47834 .38457 .47155 Mtetra
.675 .735 .895 r
.38457 .47155 .39069 .47834 .40091 .47465 .39482 .46768 Mtetra
.67 .729 .893 r
.39482 .46768 .40091 .47465 .41116 .47105 .4051 .46393 Mtetra
.665 .723 .893 r
.4051 .46393 .41116 .47105 .42144 .46753 .41541 .46032 Mtetra
.659 .719 .893 r
.41541 .46032 .42144 .46753 .43177 .46411 .42575 .45684 Mtetra
.653 .716 .894 r
.42575 .45684 .43177 .46411 .44212 .46079 .43613 .45352 Mtetra
.648 .715 .897 r
.43613 .45352 .44212 .46079 .45252 .45758 .44655 .45034 Mtetra
.642 .715 .9 r
.44655 .45034 .45252 .45758 .46295 .45445 .457 .4473 Mtetra
.637 .716 .905 r
.457 .4473 .46295 .45445 .47343 .45141 .46749 .44439 Mtetra
.633 .719 .91 r
.46749 .44439 .47343 .45141 .48395 .44844 .47803 .44157 Mtetra
.629 .724 .916 r
.47803 .44157 .48395 .44844 .4945 .44551 .48861 .43882 Mtetra
.626 .73 .922 r
.48861 .43882 .4945 .44551 .50511 .4426 .49924 .43611 Mtetra
.624 .737 .928 r
.49924 .43611 .50511 .4426 .51576 .43969 .50991 .4334 Mtetra
.624 .744 .933 r
.50991 .4334 .51576 .43969 .52645 .43676 .52063 .43067 Mtetra
.625 .753 .938 r
.52063 .43067 .52645 .43676 .53719 .43378 .5314 .42788 Mtetra
.628 .761 .943 r
.5314 .42788 .53719 .43378 .54797 .43073 .54221 .42498 Mtetra
.631 .769 .946 r
.54221 .42498 .54797 .43073 .5588 .42759 .55307 .42197 Mtetra
.637 .777 .948 r
.55307 .42197 .5588 .42759 .56967 .42434 .56397 .4188 Mtetra
.643 .783 .949 r
.56397 .4188 .56967 .42434 .58058 .42097 .57492 .41547 Mtetra
.649 .787 .948 r
.57492 .41547 .58058 .42097 .59154 .41747 .58591 .41197 Mtetra
.656 .79 .946 r
.58591 .41197 .59154 .41747 .60253 .41384 .59693 .40828 Mtetra
.663 .792 .943 r
.59693 .40828 .60253 .41384 .61357 .41008 .608 .40442 Mtetra
.67 .791 .939 r
.608 .40442 .61357 .41008 .62465 .40621 .61911 .4004 Mtetra
.675 .788 .934 r
.61911 .4004 .62465 .40621 .63576 .40222 .63025 .39623 Mtetra
.679 .784 .929 r
.63025 .39623 .63576 .40222 .64691 .39815 .64143 .39194 Mtetra
.682 .778 .923 r
.64143 .39194 .64691 .39815 .65811 .39401 .65265 .38755 Mtetra
.684 .771 .917 r
.65265 .38755 .65811 .39401 .66934 .38982 .6639 .38311 Mtetra
.684 .763 .912 r
.6639 .38311 .66934 .38982 .68061 .38561 .6752 .37865 Mtetra
.682 .755 .907 r
.6752 .37865 .68061 .38561 .69193 .38141 .68653 .37419 Mtetra
.68 .747 .902 r
.68653 .37419 .69193 .38141 .70329 .37723 .69791 .36978 Mtetra
.676 .74 .899 r
.69791 .36978 .70329 .37723 .71469 .3731 .70933 .36544 Mtetra
.672 .733 .896 r
.70933 .36544 .71469 .3731 .72614 .36904 .72081 .36121 Mtetra
.667 .727 .894 r
.72081 .36121 .72614 .36904 .73765 .36506 .73234 .3571 Mtetra
.662 .721 .893 r
.73234 .3571 .73765 .36506 .7492 .36118 .74392 .35314 Mtetra
.656 .718 .894 r
.74392 .35314 .7492 .36118 .76082 .3574 .75556 .34932 Mtetra
.651 .715 .895 r
.75556 .34932 .76082 .3574 .77248 .35372 .76726 .34566 Mtetra
.646 .714 .898 r
.76726 .34566 .77248 .35372 .78421 .35014 .77902 .34214 Mtetra
.641 .714 .901 r
.77902 .34214 .78421 .35014 .79599 .34664 .79084 .33875 Mtetra
.636 .717 .905 r
.79084 .33875 .79599 .34664 .80783 .34322 .80273 .33547 Mtetra
.632 .72 .911 r
.80273 .33547 .80783 .34322 .81973 .33986 .81468 .33227 Mtetra
.629 .725 .916 r
.81468 .33227 .81973 .33986 .83169 .33653 .82669 .32913 Mtetra
.627 .731 .922 r
.82669 .32913 .83169 .33653 .8437 .33321 .83876 .32602 Mtetra
.61 .739 .937 r
.20012 .52592 .20671 .53168 .21621 .52931 .20961 .52377 Mtetra
.61 .748 .942 r
.20961 .52377 .21621 .52931 .22575 .5269 .21915 .52156 Mtetra
.613 .756 .947 r
.21915 .52156 .22575 .5269 .23533 .52442 .22874 .51925 Mtetra
.618 .765 .95 r
.22874 .51925 .23533 .52442 .24496 .52183 .23837 .51681 Mtetra
.625 .774 .952 r
.23837 .51681 .24496 .52183 .25464 .5191 .24807 .5142 Mtetra
.634 .781 .952 r
.24807 .5142 .25464 .5191 .26437 .51623 .25781 .51139 Mtetra
.643 .787 .951 r
.25781 .51139 .26437 .51623 .27415 .51319 .26761 .50838 Mtetra
.653 .791 .948 r
.26761 .50838 .27415 .51319 .28398 .50998 .27747 .50514 Mtetra
.663 .793 .944 r
.27747 .50514 .28398 .50998 .29386 .5066 .28738 .50168 Mtetra
.672 .793 .939 r
.28738 .50168 .29386 .5066 .30378 .50305 .29733 .49801 Mtetra
.68 .79 .933 r
.29733 .49801 .30378 .50305 .31375 .49935 .30733 .49414 Mtetra
.686 .787 .927 r
.30733 .49414 .31375 .49935 .32376 .49553 .31738 .49012 Mtetra
.69 .781 .92 r
.31738 .49012 .32376 .49553 .33381 .4916 .32747 .48596 Mtetra
.693 .774 .914 r
.32747 .48596 .33381 .4916 .34389 .4876 .33759 .48171 Mtetra
.693 .767 .908 r
.33759 .48171 .34389 .4876 .35401 .48356 .34775 .47741 Mtetra
.692 .759 .903 r
.34775 .47741 .35401 .48356 .36417 .47952 .35794 .47312 Mtetra
.689 .751 .898 r
.35794 .47312 .36417 .47952 .37435 .4755 .36816 .46886 Mtetra
.685 .743 .895 r
.36816 .46886 .37435 .4755 .38457 .47155 .37841 .46469 Mtetra
.68 .736 .892 r
.37841 .46469 .38457 .47155 .39482 .46768 .38869 .46064 Mtetra
.674 .729 .891 r
.38869 .46064 .39482 .46768 .4051 .46393 .399 .45674 Mtetra
.667 .723 .891 r
.399 .45674 .4051 .46393 .41541 .46032 .40933 .45302 Mtetra
.66 .718 .892 r
.40933 .45302 .41541 .46032 .42575 .45684 .4197 .44949 Mtetra
.653 .715 .894 r
.4197 .44949 .42575 .45684 .43613 .45352 .4301 .44616 Mtetra
.645 .713 .897 r
.4301 .44616 .43613 .45352 .44655 .45034 .44053 .44302 Mtetra
.638 .712 .901 r
.44053 .44302 .44655 .45034 .457 .4473 .45101 .44007 Mtetra
.631 .713 .906 r
.45101 .44007 .457 .4473 .46749 .44439 .46152 .43728 Mtetra
.625 .716 .912 r
.46152 .43728 .46749 .44439 .47803 .44157 .47208 .43463 Mtetra
.62 .72 .918 r
.47208 .43463 .47803 .44157 .48861 .43882 .48268 .43207 Mtetra
.616 .726 .924 r
.48268 .43207 .48861 .43882 .49924 .43611 .49333 .42957 Mtetra
.614 .733 .93 r
.49333 .42957 .49924 .43611 .50991 .4334 .50402 .42707 Mtetra
.614 .741 .936 r
.50402 .42707 .50991 .4334 .52063 .43067 .51477 .42455 Mtetra
.615 .75 .941 r
.51477 .42455 .52063 .43067 .5314 .42788 .52556 .42194 Mtetra
.619 .759 .946 r
.52556 .42194 .5314 .42788 .54221 .42498 .5364 .41922 Mtetra
.624 .768 .949 r
.5364 .41922 .54221 .42498 .55307 .42197 .54729 .41633 Mtetra
.631 .776 .95 r
.54729 .41633 .55307 .42197 .56397 .4188 .55823 .41326 Mtetra
.639 .783 .95 r
.55823 .41326 .56397 .4188 .57492 .41547 .56921 .40997 Mtetra
.648 .789 .949 r
.56921 .40997 .57492 .41547 .58591 .41197 .58023 .40646 Mtetra
.658 .792 .947 r
.58023 .40646 .58591 .41197 .59693 .40828 .59129 .40272 Mtetra
.667 .794 .943 r
.59129 .40272 .59693 .40828 .608 .40442 .60239 .39875 Mtetra
.675 .794 .938 r
.60239 .39875 .608 .40442 .61911 .4004 .61353 .39457 Mtetra
.681 .791 .933 r
.61353 .39457 .61911 .4004 .63025 .39623 .6247 .39021 Mtetra
.687 .787 .927 r
.6247 .39021 .63025 .39623 .64143 .39194 .6359 .38569 Mtetra
.69 .781 .921 r
.6359 .38569 .64143 .39194 .65265 .38755 .64715 .38106 Mtetra
.692 .774 .914 r
.64715 .38106 .65265 .38755 .6639 .38311 .65842 .37635 Mtetra
.691 .766 .909 r
.65842 .37635 .6639 .38311 .6752 .37865 .66974 .37162 Mtetra
.69 .758 .904 r
.66974 .37162 .6752 .37865 .68653 .37419 .6811 .36691 Mtetra
.686 .749 .899 r
.6811 .36691 .68653 .37419 .69791 .36978 .69249 .36225 Mtetra
.682 .741 .896 r
.69249 .36225 .69791 .36978 .70933 .36544 .70394 .35771 Mtetra
.676 .734 .893 r
.70394 .35771 .70933 .36544 .72081 .36121 .71544 .3533 Mtetra
.67 .727 .892 r
.71544 .3533 .72081 .36121 .73234 .3571 .72699 .34906 Mtetra
.663 .721 .892 r
.72699 .34906 .73234 .3571 .74392 .35314 .73859 .345 Mtetra
.656 .716 .892 r
.73859 .345 .74392 .35314 .75556 .34932 .75026 .34115 Mtetra
.649 .713 .894 r
.75026 .34115 .75556 .34932 .76726 .34566 .76199 .3375 Mtetra
.642 .711 .897 r
.76199 .3375 .76726 .34566 .77902 .34214 .77379 .33404 Mtetra
.636 .711 .901 r
.77379 .33404 .77902 .34214 .79084 .33875 .78566 .33076 Mtetra
.63 .713 .906 r
.78566 .33076 .79084 .33875 .80273 .33547 .79759 .32763 Mtetra
.625 .716 .912 r
.79759 .32763 .80273 .33547 .81468 .33227 .80959 .32461 Mtetra
.621 .721 .918 r
.80959 .32461 .81468 .33227 .82669 .32913 .82165 .32167 Mtetra
.618 .727 .924 r
.82165 .32167 .82669 .32913 .83876 .32602 .83378 .31877 Mtetra
.597 .735 .941 r
.19348 .52013 .20012 .52592 .20961 .52377 .20296 .51819 Mtetra
.598 .744 .946 r
.20296 .51819 .20961 .52377 .21915 .52156 .2125 .51619 Mtetra
.602 .754 .951 r
.2125 .51619 .21915 .52156 .22874 .51925 .22209 .51407 Mtetra
.608 .764 .954 r
.22209 .51407 .22874 .51925 .23837 .51681 .23174 .51179 Mtetra
.617 .773 .955 r
.23174 .51179 .23837 .51681 .24807 .5142 .24144 .5093 Mtetra
.628 .781 .955 r
.24144 .5093 .24807 .5142 .25781 .51139 .2512 .50657 Mtetra
.64 .788 .953 r
.2512 .50657 .25781 .51139 .26761 .50838 .26102 .50358 Mtetra
.653 .793 .949 r
.26102 .50358 .26761 .50838 .27747 .50514 .2709 .50031 Mtetra
.665 .795 .944 r
.2709 .50031 .27747 .50514 .28738 .50168 .28084 .49677 Mtetra
.676 .795 .938 r
.28084 .49677 .28738 .50168 .29733 .49801 .29083 .49297 Mtetra
.686 .793 .931 r
.29083 .49297 .29733 .49801 .30733 .49414 .30087 .48893 Mtetra
.693 .789 .924 r
.30087 .48893 .30733 .49414 .31738 .49012 .31095 .48469 Mtetra
.698 .784 .917 r
.31095 .48469 .31738 .49012 .32747 .48596 .32108 .48029 Mtetra
.701 .777 .911 r
.32108 .48029 .32747 .48596 .33759 .48171 .33125 .47579 Mtetra
.701 .769 .904 r
.33125 .47579 .33759 .48171 .34775 .47741 .34144 .47122 Mtetra
.7 .761 .899 r
.34144 .47122 .34775 .47741 .35794 .47312 .35167 .46666 Mtetra
.697 .752 .895 r
.35167 .46666 .35794 .47312 .36816 .46886 .36193 .46215 Mtetra
.692 .744 .891 r
.36193 .46215 .36816 .46886 .37841 .46469 .37221 .45775 Mtetra
.686 .736 .889 r
.37221 .45775 .37841 .46469 .38869 .46064 .38252 .4535 Mtetra
.678 .729 .888 r
.38252 .4535 .38869 .46064 .399 .45674 .39286 .44945 Mtetra
.67 .722 .888 r
.39286 .44945 .399 .45674 .40933 .45302 .40322 .44562 Mtetra
.661 .717 .89 r
.40322 .44562 .40933 .45302 .4197 .44949 .41361 .44203 Mtetra
.652 .713 .893 r
.41361 .44203 .4197 .44949 .4301 .44616 .42403 .43869 Mtetra
.643 .71 .896 r
.42403 .43869 .4301 .44616 .44053 .44302 .43449 .43561 Mtetra
.633 .709 .901 r
.43449 .43561 .44053 .44302 .45101 .44007 .44498 .43275 Mtetra
.625 .71 .907 r
.44498 .43275 .45101 .44007 .46152 .43728 .45551 .4301 Mtetra
.617 .712 .913 r
.45551 .4301 .46152 .43728 .47208 .43463 .46608 .42761 Mtetra
.611 .716 .92 r
.46608 .42761 .47208 .43463 .48268 .43207 .47671 .42526 Mtetra
.606 .721 .926 r
.47671 .42526 .48268 .43207 .49333 .42957 .48737 .42297 Mtetra
.603 .728 .933 r
.48737 .42297 .49333 .42957 .50402 .42707 .49809 .4207 Mtetra
.602 .737 .939 r
.49809 .4207 .50402 .42707 .51477 .42455 .50886 .41839 Mtetra
.604 .746 .945 r
.50886 .41839 .51477 .42455 .52556 .42194 .51968 .41599 Mtetra
.609 .756 .949 r
.51968 .41599 .52556 .42194 .5364 .41922 .53056 .41344 Mtetra
.616 .766 .952 r
.53056 .41344 .5364 .41922 .54729 .41633 .54147 .4107 Mtetra
.625 .775 .953 r
.54147 .4107 .54729 .41633 .55823 .41326 .55244 .40772 Mtetra
.636 .784 .953 r
.55244 .40772 .55823 .41326 .56921 .40997 .56345 .40448 Mtetra
.647 .79 .951 r
.56345 .40448 .56921 .40997 .58023 .40646 .57451 .40096 Mtetra
.659 .795 .947 r
.57451 .40096 .58023 .40646 .59129 .40272 .5856 .39716 Mtetra
.67 .797 .943 r
.5856 .39716 .59129 .40272 .60239 .39875 .59673 .39308 Mtetra
.68 .797 .937 r
.59673 .39308 .60239 .39875 .61353 .39457 .6079 .38875 Mtetra
.688 .795 .931 r
.6079 .38875 .61353 .39457 .6247 .39021 .6191 .38418 Mtetra
.694 .79 .924 r
.6191 .38418 .6247 .39021 .6359 .38569 .63034 .37943 Mtetra
.698 .784 .918 r
.63034 .37943 .6359 .38569 .64715 .38106 .6416 .37453 Mtetra
.7 .777 .911 r
.6416 .37453 .64715 .38106 .65842 .37635 .65291 .36955 Mtetra
.7 .769 .906 r
.65291 .36955 .65842 .37635 .66974 .37162 .66424 .36454 Mtetra
.697 .76 .9 r
.66424 .36454 .66974 .37162 .6811 .36691 .67562 .35955 Mtetra
.693 .751 .896 r
.67562 .35955 .6811 .36691 .69249 .36225 .68704 .35465 Mtetra
.688 .743 .893 r
.68704 .35465 .69249 .36225 .70394 .35771 .69851 .34987 Mtetra
.681 .734 .891 r
.69851 .34987 .70394 .35771 .71544 .3533 .71002 .34528 Mtetra
.674 .727 .89 r
.71002 .34528 .71544 .3533 .72699 .34906 .72159 .3409 Mtetra
.665 .72 .89 r
.72159 .3409 .72699 .34906 .73859 .345 .73323 .33676 Mtetra
.657 .715 .891 r
.73323 .33676 .73859 .345 .75026 .34115 .74492 .33287 Mtetra
.648 .711 .894 r
.74492 .33287 .75026 .34115 .76199 .3375 .75669 .32924 Mtetra
.639 .708 .897 r
.75669 .32924 .76199 .3375 .77379 .33404 .76852 .32585 Mtetra
.631 .708 .902 r
.76852 .32585 .77379 .33404 .78566 .33076 .78043 .32268 Mtetra
.623 .709 .907 r
.78043 .32268 .78566 .33076 .79759 .32763 .79241 .3197 Mtetra
.617 .711 .913 r
.79241 .3197 .79759 .32763 .80959 .32461 .80446 .31688 Mtetra
.612 .716 .919 r
.80446 .31688 .80959 .32461 .82165 .32167 .81658 .31415 Mtetra
.609 .722 .925 r
.81658 .31415 .82165 .32167 .83378 .31877 .82876 .31146 Mtetra
.583 .731 .945 r
.18679 .51429 .19348 .52013 .20296 .51819 .19627 .51259 Mtetra
.584 .74 .951 r
.19627 .51259 .20296 .51819 .2125 .51619 .2058 .51081 Mtetra
.588 .751 .955 r
.2058 .51081 .2125 .51619 .22209 .51407 .21539 .5089 Mtetra
.597 .762 .958 r
.21539 .5089 .22209 .51407 .23174 .51179 .22504 .50678 Mtetra
.608 .772 .959 r
.22504 .50678 .23174 .51179 .24144 .5093 .23475 .50442 Mtetra
.622 .782 .958 r
.23475 .50442 .24144 .5093 .2512 .50657 .24453 .50177 Mtetra
.637 .79 .955 r
.24453 .50177 .2512 .50657 .26102 .50358 .25437 .49881 Mtetra
.653 .795 .951 r
.25437 .49881 .26102 .50358 .2709 .50031 .26428 .49551 Mtetra
.668 .798 .945 r
.26428 .49551 .2709 .50031 .28084 .49677 .27425 .49189 Mtetra
.681 .799 .938 r
.27425 .49189 .28084 .49677 .29083 .49297 .28427 .48795 Mtetra
.692 .797 .93 r
.28427 .48795 .29083 .49297 .30087 .48893 .29435 .48373 Mtetra
.7 .792 .922 r
.29435 .48373 .30087 .48893 .31095 .48469 .30448 .47927 Mtetra
.706 .786 .914 r
.30448 .47927 .31095 .48469 .32108 .48029 .31465 .47461 Mtetra
.709 .779 .907 r
.31465 .47461 .32108 .48029 .33125 .47579 .32485 .46983 Mtetra
.71 .771 .9 r
.32485 .46983 .33125 .47579 .34144 .47122 .33509 .46498 Mtetra
.708 .762 .895 r
.33509 .46498 .34144 .47122 .35167 .46666 .34536 .46014 Mtetra
.704 .753 .89 r
.34536 .46014 .35167 .46666 .36193 .46215 .35566 .45536 Mtetra
.698 .745 .887 r
.35566 .45536 .36193 .46215 .37221 .45775 .36598 .45072 Mtetra
.691 .736 .885 r
.36598 .45072 .37221 .45775 .38252 .4535 .37632 .44627 Mtetra
.682 .728 .885 r
.37632 .44627 .38252 .4535 .39286 .44945 .38668 .44205 Mtetra
.673 .721 .886 r
.38668 .44205 .39286 .44945 .40322 .44562 .39707 .43811 Mtetra
.662 .715 .888 r
.39707 .43811 .40322 .44562 .41361 .44203 .40748 .43446 Mtetra
.651 .711 .891 r
.40748 .43446 .41361 .44203 .42403 .43869 .41792 .43112 Mtetra
.64 .707 .896 r
.41792 .43112 .42403 .43869 .43449 .43561 .4284 .42808 Mtetra
.629 .705 .901 r
.4284 .42808 .43449 .43561 .44498 .43275 .43891 .42532 Mtetra
.618 .705 .907 r
.43891 .42532 .44498 .43275 .45551 .4301 .44946 .42282 Mtetra
.608 .707 .914 r
.44946 .42282 .45551 .4301 .46608 .42761 .46005 .42052 Mtetra
.6 .711 .921 r
.46005 .42052 .46608 .42761 .47671 .42526 .47069 .41837 Mtetra
.594 .716 .929 r
.47069 .41837 .47671 .42526 .48737 .42297 .48138 .41632 Mtetra
.591 .723 .936 r
.48138 .41632 .48737 .42297 .49809 .4207 .49212 .41429 Mtetra
.59 .732 .942 r
.49212 .41429 .49809 .4207 .50886 .41839 .50291 .41222 Mtetra
.592 .742 .948 r
.50291 .41222 .50886 .41839 .51968 .41599 .51376 .41003 Mtetra
.598 .753 .952 r
.51376 .41003 .51968 .41599 .53056 .41344 .52466 .40767 Mtetra
.607 .765 .955 r
.52466 .40767 .53056 .41344 .54147 .4107 .53561 .40507 Mtetra
.618 .775 .956 r
.53561 .40507 .54147 .4107 .55244 .40772 .54661 .4022 Mtetra
.632 .785 .955 r
.54661 .4022 .55244 .40772 .56345 .40448 .55765 .39901 Mtetra
.646 .792 .953 r
.55765 .39901 .56345 .40448 .57451 .40096 .56874 .39549 Mtetra
.66 .798 .948 r
.56874 .39549 .57451 .40096 .5856 .39716 .57987 .39163 Mtetra
.673 .801 .943 r
.57987 .39163 .5856 .39716 .59673 .39308 .59103 .38743 Mtetra
.685 .801 .937 r
.59103 .38743 .59673 .39308 .6079 .38875 .60223 .38293 Mtetra
.695 .799 .929 r
.60223 .38293 .6079 .38875 .6191 .38418 .61346 .37815 Mtetra
.702 .794 .922 r
.61346 .37815 .6191 .38418 .63034 .37943 .62473 .37314 Mtetra
.706 .788 .915 r
.62473 .37314 .63034 .37943 .6416 .37453 .63602 .36797 Mtetra
.708 .78 .908 r
.63602 .36797 .6416 .37453 .65291 .36955 .64735 .3627 Mtetra
.708 .772 .902 r
.64735 .3627 .65291 .36955 .66424 .36454 .65871 .35739 Mtetra
.705 .762 .897 r
.65871 .35739 .66424 .36454 .67562 .35955 .6701 .35211 Mtetra
.7 .753 .893 r
.6701 .35211 .67562 .35955 .68704 .35465 .68154 .34695 Mtetra
.694 .744 .89 r
.68154 .34695 .68704 .35465 .69851 .34987 .69303 .34194 Mtetra
.686 .735 .888 r
.69303 .34194 .69851 .34987 .71002 .34528 .70457 .33715 Mtetra
.677 .726 .887 r
.70457 .33715 .71002 .34528 .72159 .3409 .71616 .33263 Mtetra
.667 .719 .888 r
.71616 .33263 .72159 .3409 .73323 .33676 .72782 .32839 Mtetra
.657 .713 .89 r
.72782 .32839 .73323 .33676 .74492 .33287 .73955 .32446 Mtetra
.646 .708 .892 r
.73955 .32446 .74492 .33287 .75669 .32924 .75134 .32085 Mtetra
.636 .705 .896 r
.75134 .32085 .75669 .32924 .76852 .32585 .76321 .31753 Mtetra
.626 .703 .901 r
.76321 .31753 .76852 .32585 .78043 .32268 .77516 .31449 Mtetra
.616 .704 .907 r
.77516 .31449 .78043 .32268 .79241 .3197 .78719 .31168 Mtetra
.609 .706 .913 r
.78719 .31168 .79241 .3197 .80446 .31688 .79929 .30905 Mtetra
.602 .71 .92 r
.79929 .30905 .80446 .31688 .81658 .31415 .81146 .30655 Mtetra
.598 .717 .927 r
.81146 .30655 .81658 .31415 .82876 .31146 .82371 .3041 Mtetra
.567 .725 .949 r
.18006 .50842 .18679 .51429 .19627 .51259 .18953 .50697 Mtetra
.568 .736 .955 r
.18953 .50697 .19627 .51259 .2058 .51081 .19906 .50543 Mtetra
.574 .748 .959 r
.19906 .50543 .2058 .51081 .21539 .5089 .20864 .50373 Mtetra
.584 .76 .962 r
.20864 .50373 .21539 .5089 .22504 .50678 .21829 .5018 Mtetra
.598 .772 .963 r
.21829 .5018 .22504 .50678 .23475 .50442 .22801 .49958 Mtetra
.616 .783 .961 r
.22801 .49958 .23475 .50442 .24453 .50177 .23781 .49701 Mtetra
.634 .792 .958 r
.23781 .49701 .24453 .50177 .25437 .49881 .24767 .49408 Mtetra
.653 .798 .952 r
.24767 .49408 .25437 .49881 .26428 .49551 .2576 .49075 Mtetra
.67 .802 .945 r
.2576 .49075 .26428 .49551 .27425 .49189 .2676 .48704 Mtetra
.686 .802 .937 r
.2676 .48704 .27425 .49189 .28427 .48795 .27766 .48296 Mtetra
.698 .8 .928 r
.27766 .48296 .28427 .48795 .29435 .48373 .28778 .47855 Mtetra
.708 .796 .919 r
.28778 .47855 .29435 .48373 .30448 .47927 .29795 .47384 Mtetra
.714 .789 .911 r
.29795 .47384 .30448 .47927 .31465 .47461 .30816 .46892 Mtetra
.718 .782 .903 r
.30816 .46892 .31465 .47461 .32485 .46983 .31842 .46385 Mtetra
.718 .773 .896 r
.31842 .46385 .32485 .46983 .33509 .46498 .3287 .4587 Mtetra
.716 .764 .89 r
.3287 .4587 .33509 .46498 .34536 .46014 .33901 .45355 Mtetra
.712 .755 .886 r
.33901 .45355 .34536 .46014 .35566 .45536 .34935 .44849 Mtetra
.705 .745 .883 r
.34935 .44849 .35566 .45536 .36598 .45072 .3597 .44359 Mtetra
.697 .736 .882 r
.3597 .44359 .36598 .45072 .37632 .44627 .37008 .43892 Mtetra
.687 .728 .881 r
.37008 .43892 .37632 .44627 .38668 .44205 .38047 .43453 Mtetra
.675 .72 .883 r
.38047 .43453 .38668 .44205 .39707 .43811 .39088 .43047 Mtetra
.663 .714 .886 r
.39088 .43047 .39707 .43811 .40748 .43446 .40132 .42676 Mtetra
.65 .708 .89 r
.40132 .42676 .40748 .43446 .41792 .43112 .41178 .42341 Mtetra
.637 .704 .895 r
.41178 .42341 .41792 .43112 .4284 .42808 .42227 .42043 Mtetra
.623 .701 .901 r
.42227 .42043 .4284 .42808 .43891 .42532 .4328 .41778 Mtetra
.611 .7 .908 r
.4328 .41778 .43891 .42532 .44946 .42282 .44337 .41543 Mtetra
.599 .702 .915 r
.44337 .41543 .44946 .42282 .46005 .42052 .45398 .41333 Mtetra
.589 .705 .923 r
.45398 .41333 .46005 .42052 .47069 .41837 .46463 .41142 Mtetra
.581 .71 .931 r
.46463 .41142 .47069 .41837 .48138 .41632 .47534 .40961 Mtetra
.577 .718 .939 r
.47534 .40961 .48138 .41632 .49212 .41429 .4861 .40784 Mtetra
.576 .727 .945 r
.4861 .40784 .49212 .41429 .50291 .41222 .49692 .40602 Mtetra
.579 .738 .951 r
.49692 .40602 .50291 .41222 .51376 .41003 .50779 .40406 Mtetra
.586 .75 .956 r
.50779 .40406 .51376 .41003 .52466 .40767 .51872 .4019 Mtetra
.597 .763 .958 r
.51872 .4019 .52466 .40767 .53561 .40507 .5297 .39947 Mtetra
.611 .775 .959 r
.5297 .39947 .53561 .40507 .54661 .4022 .54073 .39671 Mtetra
.627 .786 .958 r
.54073 .39671 .54661 .4022 .55765 .39901 .55181 .39358 Mtetra
.644 .795 .955 r
.55181 .39358 .55765 .39901 .56874 .39549 .56293 .39006 Mtetra
.661 .801 .95 r
.56293 .39006 .56874 .39549 .57987 .39163 .57409 .38613 Mtetra
.677 .805 .943 r
.57409 .38613 .57987 .39163 .59103 .38743 .58529 .38181 Mtetra
.691 .805 .936 r
.58529 .38181 .59103 .38743 .60223 .38293 .59652 .37712 Mtetra
.702 .803 .928 r
.59652 .37712 .60223 .38293 .61346 .37815 .60778 .37212 Mtetra
.71 .798 .92 r
.60778 .37212 .61346 .37815 .62473 .37314 .61907 .36685 Mtetra
.715 .792 .912 r
.61907 .36685 .62473 .37314 .63602 .36797 .63039 .36138 Mtetra
.717 .784 .905 r
.63039 .36138 .63602 .36797 .64735 .3627 .64174 .3558 Mtetra
.716 .774 .898 r
.64174 .3558 .64735 .3627 .65871 .35739 .65313 .35017 Mtetra
.713 .765 .893 r
.65313 .35017 .65871 .35739 .6701 .35211 .66455 .3446 Mtetra
.707 .755 .889 r
.66455 .3446 .6701 .35211 .68154 .34695 .67601 .33914 Mtetra
.7 .745 .886 r
.67601 .33914 .68154 .34695 .69303 .34194 .68751 .33389 Mtetra
.691 .735 .884 r
.68751 .33389 .69303 .34194 .70457 .33715 .69907 .3289 Mtetra
.68 .726 .884 r
.69907 .3289 .70457 .33715 .71616 .33263 .71069 .32422 Mtetra
.669 .718 .885 r
.71069 .32422 .71616 .33263 .72782 .32839 .72237 .31988 Mtetra
.657 .711 .888 r
.72237 .31988 .72782 .32839 .73955 .32446 .73413 .31592 Mtetra
.644 .705 .891 r
.73413 .31592 .73955 .32446 .75134 .32085 .74595 .31232 Mtetra
.632 .701 .896 r
.74595 .31232 .75134 .32085 .76321 .31753 .75786 .30909 Mtetra
.62 .699 .901 r
.75786 .30909 .76321 .31753 .77516 .31449 .76985 .30618 Mtetra
.609 .698 .907 r
.76985 .30618 .77516 .31449 .78719 .31168 .78192 .30355 Mtetra
.599 .7 .914 r
.78192 .30355 .78719 .31168 .79929 .30905 .79408 .30114 Mtetra
.592 .704 .921 r
.79408 .30114 .79929 .30905 .81146 .30655 .80631 .29888 Mtetra
.587 .711 .929 r
.80631 .29888 .81146 .30655 .82371 .3041 .81861 .29669 Mtetra
.548 .719 .952 r
.17328 .5025 .18006 .50842 .18953 .50697 .18274 .50133 Mtetra
.55 .73 .959 r
.18274 .50133 .18953 .50697 .19906 .50543 .19225 .50005 Mtetra
.557 .743 .964 r
.19225 .50005 .19906 .50543 .20864 .50373 .20183 .49858 Mtetra
.57 .757 .967 r
.20183 .49858 .20864 .50373 .21829 .5018 .21149 .49685 Mtetra
.587 .771 .967 r
.21149 .49685 .21829 .5018 .22801 .49958 .22121 .49478 Mtetra
.608 .784 .965 r
.22121 .49478 .22801 .49958 .23781 .49701 .23102 .49231 Mtetra
.63 .794 .961 r
.23102 .49231 .23781 .49701 .24767 .49408 .2409 .48941 Mtetra
.653 .802 .954 r
.2409 .48941 .24767 .49408 .2576 .49075 .25086 .48605 Mtetra
.673 .806 .946 r
.25086 .48605 .2576 .49075 .2676 .48704 .26089 .48225 Mtetra
.691 .806 .937 r
.26089 .48225 .2676 .48704 .27766 .48296 .27099 .47801 Mtetra
.705 .804 .926 r
.27099 .47801 .27766 .48296 .28778 .47855 .28116 .47339 Mtetra
.716 .799 .916 r
.28116 .47339 .28778 .47855 .29795 .47384 .29137 .46843 Mtetra
.723 .793 .907 r
.29137 .46843 .29795 .47384 .30816 .46892 .30163 .46322 Mtetra
.727 .784 .898 r
.30163 .46322 .30816 .46892 .31842 .46385 .31193 .45783 Mtetra
.727 .775 .891 r
.31193 .45783 .31842 .46385 .3287 .4587 .32226 .45236 Mtetra
.724 .765 .885 r
.32226 .45236 .3287 .4587 .33901 .45355 .33262 .44689 Mtetra
.719 .756 .881 r
.33262 .44689 .33901 .45355 .34935 .44849 .34299 .44153 Mtetra
.712 .746 .878 r
.34299 .44153 .34935 .44849 .3597 .44359 .35339 .43636 Mtetra
.702 .736 .877 r
.35339 .43636 .3597 .44359 .37008 .43892 .3638 .43145 Mtetra
.691 .727 .878 r
.3638 .43145 .37008 .43892 .38047 .43453 .37422 .42688 Mtetra
.678 .719 .88 r
.37422 .42688 .38047 .43453 .39088 .43047 .38466 .42269 Mtetra
.664 .711 .883 r
.38466 .42269 .39088 .43047 .40132 .42676 .39512 .41891 Mtetra
.649 .705 .888 r
.39512 .41891 .40132 .42676 .41178 .42341 .4056 .41557 Mtetra
.634 .7 .893 r
.4056 .41557 .41178 .42341 .42227 .42043 .41611 .41264 Mtetra
.618 .697 .9 r
.41611 .41264 .42227 .42043 .4328 .41778 .42666 .41011 Mtetra
.603 .695 .908 r
.42666 .41011 .4328 .41778 .44337 .41543 .43724 .40794 Mtetra
.589 .695 .916 r
.43724 .40794 .44337 .41543 .45398 .41333 .44786 .40605 Mtetra
.577 .698 .925 r
.44786 .40605 .45398 .41333 .46463 .41142 .45853 .40438 Mtetra
.567 .703 .933 r
.45853 .40438 .46463 .41142 .47534 .40961 .46926 .40285 Mtetra
.562 .711 .941 r
.46926 .40285 .47534 .40961 .4861 .40784 .48004 .40135 Mtetra
.561 .721 .948 r
.48004 .40135 .4861 .40784 .49692 .40602 .49088 .3998 Mtetra
.564 .733 .955 r
.49088 .3998 .49692 .40602 .50779 .40406 .50177 .3981 Mtetra
.573 .747 .959 r
.50177 .3981 .50779 .40406 .51872 .4019 .51273 .39616 Mtetra
.586 .761 .962 r
.51273 .39616 .51872 .4019 .5297 .39947 .52374 .3939 Mtetra
.603 .775 .963 r
.52374 .3939 .5297 .39947 .54073 .39671 .5348 .39127 Mtetra
.622 .788 .961 r
.5348 .39127 .54073 .39671 .55181 .39358 .54591 .3882 Mtetra
.642 .798 .957 r
.54591 .3882 .55181 .39358 .56293 .39006 .55707 .38467 Mtetra
.662 .805 .951 r
.55707 .38467 .56293 .39006 .57409 .38613 .56826 .38068 Mtetra
.681 .809 .944 r
.56826 .38068 .57409 .38613 .58529 .38181 .5795 .37623 Mtetra
.697 .81 .935 r
.5795 .37623 .58529 .38181 .59652 .37712 .59076 .37135 Mtetra
.709 .808 .926 r
.59076 .37135 .59652 .37712 .60778 .37212 .60206 .3661 Mtetra
.718 .803 .917 r
.60206 .3661 .60778 .37212 .61907 .36685 .61338 .36055 Mtetra
.724 .796 .909 r
.61338 .36055 .61907 .36685 .63039 .36138 .62472 .35476 Mtetra
.726 .787 .901 r
.62472 .35476 .63039 .36138 .64174 .3558 .6361 .34885 Mtetra
.725 .777 .894 r
.6361 .34885 .64174 .3558 .65313 .35017 .64751 .34289 Mtetra
.721 .767 .889 r
.64751 .34289 .65313 .35017 .66455 .3446 .65895 .33699 Mtetra
.715 .756 .885 r
.65895 .33699 .66455 .3446 .67601 .33914 .67043 .33124 Mtetra
.706 .745 .882 r
.67043 .33124 .67601 .33914 .68751 .33389 .68196 .32572 Mtetra
.696 .735 .881 r
.68196 .32572 .68751 .33389 .69907 .3289 .69353 .3205 Mtetra
.684 .725 .881 r
.69353 .3205 .69907 .3289 .71069 .32422 .70517 .31566 Mtetra
.671 .716 .883 r
.70517 .31566 .71069 .32422 .72237 .31988 .71688 .31122 Mtetra
.657 .708 .885 r
.71688 .31122 .72237 .31988 .73413 .31592 .72866 .30722 Mtetra
.642 .702 .889 r
.72866 .30722 .73413 .31592 .74595 .31232 .74052 .30365 Mtetra
.628 .697 .894 r
.74052 .30365 .74595 .31232 .75786 .30909 .75247 .3005 Mtetra
.614 .693 .9 r
.75247 .3005 .75786 .30909 .76985 .30618 .7645 .29774 Mtetra
.601 .692 .907 r
.7645 .29774 .76985 .30618 .78192 .30355 .77662 .2953 Mtetra
.589 .694 .914 r
.77662 .2953 .78192 .30355 .79408 .30114 .78882 .29312 Mtetra
.58 .697 .922 r
.78882 .29312 .79408 .30114 .80631 .29888 .80111 .29112 Mtetra
.574 .704 .93 r
.80111 .29112 .80631 .29888 .81861 .29669 .81347 .28921 Mtetra
.527 .711 .956 r
.16646 .49655 .17328 .5025 .18274 .50133 .1759 .49567 Mtetra
.528 .724 .963 r
.1759 .49567 .18274 .50133 .19225 .50005 .1854 .49467 Mtetra
.537 .738 .968 r
.1854 .49467 .19225 .50005 .20183 .49858 .19497 .49346 Mtetra
.553 .754 .971 r
.19497 .49346 .20183 .49858 .21149 .49685 .20462 .49195 Mtetra
.574 .77 .972 r
.20462 .49195 .21149 .49685 .22121 .49478 .21435 .49004 Mtetra
.599 .785 .97 r
.21435 .49004 .22121 .49478 .23102 .49231 .22417 .48768 Mtetra
.626 .797 .965 r
.22417 .48768 .23102 .49231 .2409 .48941 .23407 .48481 Mtetra
.652 .806 .957 r
.23407 .48481 .2409 .48941 .25086 .48605 .24406 .48143 Mtetra
.676 .81 .947 r
.24406 .48143 .25086 .48605 .26089 .48225 .25413 .47752 Mtetra
.696 .811 .936 r
.25413 .47752 .26089 .48225 .27099 .47801 .26427 .47312 Mtetra
.713 .809 .925 r
.26427 .47312 .27099 .47801 .28116 .47339 .27447 .46827 Mtetra
.724 .803 .913 r
.27447 .46827 .28116 .47339 .29137 .46843 .28474 .46304 Mtetra
.732 .796 .903 r
.28474 .46304 .29137 .46843 .30163 .46322 .29505 .45752 Mtetra
.736 .787 .894 r
.29505 .45752 .30163 .46322 .31193 .45783 .3054 .45179 Mtetra
.736 .777 .886 r
.3054 .45179 .31193 .45783 .32226 .45236 .31578 .44597 Mtetra
.733 .767 .88 r
.31578 .44597 .32226 .45236 .33262 .44689 .32618 .44016 Mtetra
.727 .756 .876 r
.32618 .44016 .33262 .44689 .34299 .44153 .3366 .43447 Mtetra
.719 .746 .873 r
.3366 .43447 .34299 .44153 .35339 .43636 .34704 .42901 Mtetra
.708 .736 .873 r
.34704 .42901 .35339 .43636 .3638 .43145 .35748 .42385 Mtetra
.696 .726 .873 r
.35748 .42385 .3638 .43145 .37422 .42688 .36794 .41908 Mtetra
.681 .717 .876 r
.36794 .41908 .37422 .42688 .38466 .42269 .37841 .41475 Mtetra
.665 .709 .88 r
.37841 .41475 .38466 .42269 .39512 .41891 .38889 .41091 Mtetra
.648 .701 .885 r
.38889 .41091 .39512 .41891 .4056 .41557 .39939 .40756 Mtetra
.63 .696 .892 r
.39939 .40756 .4056 .41557 .41611 .41264 .40992 .4047 Mtetra
.612 .691 .9 r
.40992 .4047 .41611 .41264 .42666 .41011 .42047 .4023 Mtetra
.594 .689 .908 r
.42047 .4023 .42666 .41011 .43724 .40794 .43107 .40031 Mtetra
.577 .688 .917 r
.43107 .40031 .43724 .40794 .44786 .40605 .4417 .39866 Mtetra
.563 .69 .926 r
.4417 .39866 .44786 .40605 .45853 .40438 .45239 .39726 Mtetra
.552 .695 .935 r
.45239 .39726 .45853 .40438 .46926 .40285 .46313 .39602 Mtetra
.545 .703 .944 r
.46313 .39602 .46926 .40285 .48004 .40135 .47393 .39483 Mtetra
.543 .714 .951 r
.47393 .39483 .48004 .40135 .49088 .3998 .48479 .39357 Mtetra
.547 .728 .958 r
.48479 .39357 .49088 .3998 .50177 .3981 .49571 .39214 Mtetra
.557 .743 .963 r
.49571 .39214 .50177 .3981 .51273 .39616 .50669 .39044 Mtetra
.573 .759 .966 r
.50669 .39044 .51273 .39616 .52374 .3939 .51773 .38838 Mtetra
.593 .775 .967 r
.51773 .38838 .52374 .3939 .5348 .39127 .52882 .38588 Mtetra
.616 .789 .965 r
.52882 .38588 .5348 .39127 .54591 .3882 .53997 .38288 Mtetra
.64 .801 .96 r
.53997 .38288 .54591 .3882 .55707 .38467 .55116 .37936 Mtetra
.663 .81 .953 r
.55116 .37936 .55707 .38467 .56826 .38068 .56239 .37529 Mtetra
.685 .815 .945 r
.56239 .37529 .56826 .38068 .5795 .37623 .57366 .3707 Mtetra
.703 .815 .935 r
.57366 .3707 .5795 .37623 .59076 .37135 .58496 .36562 Mtetra
.717 .813 .925 r
.58496 .36562 .59076 .37135 .60206 .3661 .59628 .36011 Mtetra
.727 .808 .914 r
.59628 .36011 .60206 .3661 .61338 .36055 .60764 .35425 Mtetra
.733 .8 .905 r
.60764 .35425 .61338 .36055 .62472 .35476 .61901 .34813 Mtetra
.736 .791 .897 r
.61901 .34813 .62472 .35476 .6361 .34885 .63041 .34185 Mtetra
.734 .78 .89 r
.63041 .34185 .6361 .34885 .64751 .34289 .64184 .33553 Mtetra
.73 .769 .884 r
.64184 .33553 .64751 .34289 .65895 .33699 .65331 .32928 Mtetra
.723 .757 .88 r
.65331 .32928 .65895 .33699 .67043 .33124 .66481 .32321 Mtetra
.713 .746 .878 r
.66481 .32321 .67043 .33124 .68196 .32572 .67635 .3174 Mtetra
.701 .734 .877 r
.67635 .3174 .68196 .32572 .69353 .3205 .68795 .31195 Mtetra
.688 .724 .877 r
.68795 .31195 .69353 .3205 .70517 .31566 .69962 .30693 Mtetra
.673 .714 .879 r
.69962 .30693 .70517 .31566 .71688 .31122 .71135 .30239 Mtetra
.657 .705 .883 r
.71135 .30239 .71688 .31122 .72866 .30722 .72315 .29834 Mtetra
.64 .697 .887 r
.72315 .29834 .72866 .30722 .74052 .30365 .73505 .29481 Mtetra
.623 .692 .893 r
.73505 .29481 .74052 .30365 .75247 .3005 .74703 .29175 Mtetra
.607 .688 .899 r
.74703 .29175 .75247 .3005 .7645 .29774 .7591 .28915 Mtetra
.592 .686 .907 r
.7591 .28915 .7645 .29774 .77662 .2953 .77127 .28692 Mtetra
.579 .686 .915 r
.77127 .28692 .77662 .2953 .78882 .29312 .78353 .285 Mtetra
.568 .69 .923 r
.78353 .285 .78882 .29312 .80111 .29112 .79587 .28329 Mtetra
.56 .696 .931 r
.79587 .28329 .80111 .29112 .81347 .28921 .8083 .28168 Mtetra
.503 .702 .959 r
.15958 .49055 .16646 .49655 .1759 .49567 .169 .48999 Mtetra
.504 .715 .967 r
.169 .48999 .1759 .49567 .1854 .49467 .17849 .48931 Mtetra
.514 .732 .972 r
.17849 .48931 .1854 .49467 .19497 .49346 .18805 .48838 Mtetra
.533 .75 .976 r
.18805 .48838 .19497 .49346 .20462 .49195 .19769 .4871 Mtetra
.559 .769 .977 r
.19769 .4871 .20462 .49195 .21435 .49004 .20742 .48537 Mtetra
.589 .787 .974 r
.20742 .48537 .21435 .49004 .22417 .48768 .21725 .48313 Mtetra
.621 .801 .968 r
.21725 .48313 .22417 .48768 .23407 .48481 .22718 .48031 Mtetra
.652 .811 .96 r
.22718 .48031 .23407 .48481 .24406 .48143 .23719 .47689 Mtetra
.679 .816 .948 r
.23719 .47689 .24406 .48143 .25413 .47752 .24729 .47288 Mtetra
.702 .817 .936 r
.24729 .47288 .25413 .47752 .26427 .47312 .25748 .4683 Mtetra
.72 .814 .923 r
.25748 .4683 .26427 .47312 .27447 .46827 .26773 .46321 Mtetra
.733 .808 .91 r
.26773 .46321 .27447 .46827 .28474 .46304 .27805 .45768 Mtetra
.741 .799 .899 r
.27805 .45768 .28474 .46304 .29505 .45752 .28841 .45182 Mtetra
.745 .79 .889 r
.28841 .45182 .29505 .45752 .3054 .45179 .29881 .44573 Mtetra
.745 .779 .881 r
.29881 .44573 .3054 .45179 .31578 .44597 .30925 .43953 Mtetra
.742 .768 .874 r
.30925 .43953 .31578 .44597 .32618 .44016 .3197 .43335 Mtetra
.735 .757 .87 r
.3197 .43335 .32618 .44016 .3366 .43447 .33017 .42731 Mtetra
.726 .746 .868 r
.33017 .42731 .3366 .43447 .34704 .42901 .34065 .42152 Mtetra
.714 .735 .867 r
.34065 .42152 .34704 .42901 .35748 .42385 .35113 .4161 Mtetra
.7 .724 .869 r
.35113 .4161 .35748 .42385 .36794 .41908 .36162 .41111 Mtetra
.684 .715 .872 r
.36162 .41111 .36794 .41908 .37841 .41475 .37212 .40664 Mtetra
.666 .706 .877 r
.37212 .40664 .37841 .41475 .38889 .41091 .38262 .40272 Mtetra
.647 .697 .883 r
.38262 .40272 .38889 .41091 .39939 .40756 .39314 .39938 Mtetra
.626 .69 .89 r
.39314 .39938 .39939 .40756 .40992 .4047 .40368 .39659 Mtetra
.605 .685 .898 r
.40368 .39659 .40992 .4047 .42047 .4023 .41425 .39434 Mtetra
.584 .682 .908 r
.41425 .39434 .42047 .4023 .43107 .40031 .42486 .39255 Mtetra
.565 .68 .917 r
.42486 .39255 .43107 .40031 .4417 .39866 .43551 .39116 Mtetra
.547 .682 .927 r
.43551 .39116 .4417 .39866 .45239 .39726 .44621 .39005 Mtetra
.534 .686 .937 r
.44621 .39005 .45239 .39726 .46313 .39602 .45696 .38913 Mtetra
.525 .694 .946 r
.45696 .38913 .46313 .39602 .47393 .39483 .46777 .38827 Mtetra
.523 .706 .954 r
.46777 .38827 .47393 .39483 .48479 .39357 .47865 .38734 Mtetra
.527 .721 .962 r
.47865 .38734 .48479 .39357 .49571 .39214 .48959 .38621 Mtetra
.539 .738 .967 r
.48959 .38621 .49571 .39214 .50669 .39044 .5006 .38477 Mtetra
.558 .757 .97 r
.5006 .38477 .50669 .39044 .51773 .38838 .51167 .38292 Mtetra
.582 .775 .971 r
.51167 .38292 .51773 .38838 .52882 .38588 .52279 .38057 Mtetra
.609 .792 .969 r
.52279 .38057 .52882 .38588 .53997 .38288 .53397 .37765 Mtetra
.637 .805 .964 r
.53397 .37765 .53997 .38288 .55116 .37936 .5452 .37413 Mtetra
.665 .815 .956 r
.5452 .37413 .55116 .37936 .56239 .37529 .55647 .36999 Mtetra
.689 .82 .946 r
.55647 .36999 .56239 .37529 .57366 .3707 .56777 .36525 Mtetra
.71 .821 .934 r
.56777 .36525 .57366 .3707 .58496 .36562 .57911 .35995 Mtetra
.726 .819 .923 r
.57911 .35995 .58496 .36562 .59628 .36011 .59047 .35415 Mtetra
.737 .813 .911 r
.59047 .35415 .59628 .36011 .60764 .35425 .60185 .34796 Mtetra
.743 .804 .901 r
.60185 .34796 .60764 .35425 .61901 .34813 .61326 .34147 Mtetra
.745 .794 .892 r
.61326 .34147 .61901 .34813 .63041 .34185 .62468 .33481 Mtetra
.744 .783 .885 r
.62468 .33481 .63041 .34185 .64184 .33553 .63614 .3281 Mtetra
.739 .771 .879 r
.63614 .3281 .64184 .33553 .65331 .32928 .64762 .32147 Mtetra
.73 .758 .875 r
.64762 .32147 .65331 .32928 .66481 .32321 .65914 .31505 Mtetra
.72 .746 .873 r
.65914 .31505 .66481 .32321 .67635 .3174 .67071 .30894 Mtetra
.707 .734 .872 r
.67071 .30894 .67635 .3174 .68795 .31195 .68233 .30324 Mtetra
.691 .722 .873 r
.68233 .30324 .68795 .31195 .69962 .30693 .69401 .29803 Mtetra
.675 .711 .876 r
.69401 .29803 .69962 .30693 .71135 .30239 .70577 .29337 Mtetra
.657 .701 .88 r
.70577 .29337 .71135 .30239 .72315 .29834 .7176 .28928 Mtetra
.638 .693 .885 r
.7176 .28928 .72315 .29834 .73505 .29481 .72953 .28578 Mtetra
.619 .686 .891 r
.72953 .28578 .73505 .29481 .74703 .29175 .74154 .28283 Mtetra
.6 .681 .898 r
.74154 .28283 .74703 .29175 .7591 .28915 .75366 .2804 Mtetra
.582 .678 .906 r
.75366 .2804 .7591 .28915 .77127 .28692 .76587 .27841 Mtetra
.567 .678 .915 r
.76587 .27841 .77127 .28692 .78353 .285 .77818 .27677 Mtetra
.554 .681 .923 r
.77818 .27677 .78353 .285 .79587 .28329 .79059 .27537 Mtetra
.545 .687 .932 r
.79059 .27537 .79587 .28329 .8083 .28168 .80308 .27409 Mtetra
.474 .69 .962 r
.15266 .48451 .15958 .49055 .169 .48999 .16206 .48431 Mtetra
.475 .705 .97 r
.16206 .48431 .169 .48999 .17849 .48931 .17152 .48397 Mtetra
.487 .724 .976 r
.17152 .48397 .17849 .48931 .18805 .48838 .18106 .48335 Mtetra
.509 .745 .98 r
.18106 .48335 .18805 .48838 .19769 .4871 .19069 .48233 Mtetra
.54 .767 .981 r
.19069 .48233 .19769 .4871 .20742 .48537 .20043 .4808 Mtetra
.577 .788 .979 r
.20043 .4808 .20742 .48537 .21725 .48313 .21027 .47868 Mtetra
.615 .804 .973 r
.21027 .47868 .21725 .48313 .22718 .48031 .22021 .47591 Mtetra
.651 .816 .963 r
.22021 .47591 .22718 .48031 .23719 .47689 .23025 .47246 Mtetra
.683 .822 .95 r
.23025 .47246 .23719 .47689 .24729 .47288 .24039 .46834 Mtetra
.709 .822 .936 r
.24039 .46834 .24729 .47288 .25748 .4683 .25062 .46357 Mtetra
.729 .819 .921 r
.25062 .46357 .25748 .4683 .26773 .46321 .26093 .45821 Mtetra
.743 .812 .907 r
.26093 .45821 .26773 .46321 .27805 .45768 .2713 .45237 Mtetra
.751 .803 .894 r
.2713 .45237 .27805 .45768 .28841 .45182 .28172 .44613 Mtetra
.755 .793 .883 r
.28172 .44613 .28841 .45182 .29881 .44573 .29218 .43964 Mtetra
.755 .781 .875 r
.29218 .43964 .29881 .44573 .30925 .43953 .30267 .43304 Mtetra
.751 .769 .868 r
.30267 .43304 .30925 .43953 .3197 .43335 .31318 .42645 Mtetra
.743 .757 .864 r
.31318 .42645 .3197 .43335 .33017 .42731 .3237 .42003 Mtetra
.733 .746 .862 r
.3237 .42003 .33017 .42731 .34065 .42152 .33422 .4139 Mtetra
.72 .734 .862 r
.33422 .4139 .34065 .42152 .35113 .4161 .34475 .40818 Mtetra
.705 .723 .864 r
.34475 .40818 .35113 .4161 .36162 .41111 .35527 .40296 Mtetra
.687 .712 .867 r
.35527 .40296 .36162 .41111 .37212 .40664 .36579 .39834 Mtetra
.667 .702 .873 r
.36579 .39834 .37212 .40664 .38262 .40272 .37632 .39434 Mtetra
.646 .693 .88 r
.37632 .39434 .38262 .40272 .39314 .39938 .38686 .391 Mtetra
.622 .685 .888 r
.38686 .391 .39314 .39938 .40368 .39659 .39742 .38829 Mtetra
.598 .678 .897 r
.39742 .38829 .40368 .39659 .41425 .39434 .408 .3862 Mtetra
.574 .673 .907 r
.408 .3862 .41425 .39434 .42486 .39255 .41861 .38464 Mtetra
.551 .671 .917 r
.41861 .38464 .42486 .39255 .43551 .39116 .42927 .38352 Mtetra
.53 .672 .928 r
.42927 .38352 .43551 .39116 .44621 .39005 .43998 .38275 Mtetra
.513 .676 .938 r
.43998 .38275 .44621 .39005 .45696 .38913 .45075 .38218 Mtetra
.503 .684 .948 r
.45075 .38218 .45696 .38913 .46777 .38827 .46157 .38167 Mtetra
.5 .696 .957 r
.46157 .38167 .46777 .38827 .47865 .38734 .47247 .3811 Mtetra
.505 .712 .965 r
.47247 .3811 .47865 .38734 .48959 .38621 .48343 .3803 Mtetra
.519 .732 .971 r
.48343 .3803 .48959 .38621 .5006 .38477 .49446 .37916 Mtetra
.541 .753 .975 r
.49446 .37916 .5006 .38477 .51167 .38292 .50556 .37754 Mtetra
.569 .775 .976 r
.50556 .37754 .51167 .38292 .52279 .38057 .51672 .37536 Mtetra
.601 .794 .973 r
.51672 .37536 .52279 .38057 .53397 .37765 .52793 .37253 Mtetra
.634 .81 .967 r
.52793 .37253 .53397 .37765 .5452 .37413 .53919 .36901 Mtetra
.666 .821 .958 r
.53919 .36901 .5452 .37413 .55647 .36999 .5505 .36479 Mtetra
.694 .827 .947 r
.5505 .36479 .55647 .36999 .56777 .36525 .56184 .35988 Mtetra
.717 .828 .934 r
.56184 .35988 .56777 .36525 .57911 .35995 .57321 .35434 Mtetra
.735 .825 .921 r
.57321 .35434 .57911 .35995 .59047 .35415 .5846 .34824 Mtetra
.747 .818 .908 r
.5846 .34824 .59047 .35415 .60185 .34796 .59602 .34169 Mtetra
.753 .809 .897 r
.59602 .34169 .60185 .34796 .61326 .34147 .60745 .33481 Mtetra
.756 .798 .887 r
.60745 .33481 .61326 .34147 .62468 .33481 .61891 .32772 Mtetra
.754 .786 .879 r
.61891 .32772 .62468 .33481 .63614 .3281 .63039 .32059 Mtetra
.748 .773 .873 r
.63039 .32059 .63614 .3281 .64762 .32147 .64189 .31355 Mtetra
.739 .76 .869 r
.64189 .31355 .64762 .32147 .65914 .31505 .65344 .30675 Mtetra
.727 .746 .868 r
.65344 .30675 .65914 .31505 .67071 .30894 .66502 .3003 Mtetra
.712 .733 .867 r
.66502 .3003 .67071 .30894 .68233 .30324 .67666 .29433 Mtetra
.695 .72 .869 r
.67666 .29433 .68233 .30324 .69401 .29803 .68836 .28892 Mtetra
.677 .709 .872 r
.68836 .28892 .69401 .29803 .70577 .29337 .70014 .28413 Mtetra
.656 .698 .876 r
.70014 .28413 .70577 .29337 .7176 .28928 .712 .28001 Mtetra
.635 .688 .882 r
.712 .28001 .7176 .28928 .72953 .28578 .72396 .27654 Mtetra
.614 .68 .889 r
.72396 .27654 .72953 .28578 .74154 .28283 .73601 .27372 Mtetra
.592 .673 .897 r
.73601 .27372 .74154 .28283 .75366 .2804 .74817 .27148 Mtetra
.572 .67 .905 r
.74817 .27148 .75366 .2804 .76587 .27841 .76043 .26974 Mtetra
.553 .669 .914 r
.76043 .26974 .76587 .27841 .77818 .27677 .7728 .26841 Mtetra
.538 .671 .923 r
.7728 .26841 .77818 .27677 .79059 .27537 .78527 .26735 Mtetra
.527 .677 .933 r
.78527 .26735 .79059 .27537 .80308 .27409 .79782 .26643 Mtetra
.439 .675 .963 r
.14569 .47843 .15266 .48451 .16206 .48431 .15505 .47862 Mtetra
.44 .691 .972 r
.15505 .47862 .16206 .48431 .17152 .48397 .16449 .47865 Mtetra
.454 .713 .979 r
.16449 .47865 .17152 .48397 .18106 .48335 .17401 .47837 Mtetra
.481 .738 .984 r
.17401 .47837 .18106 .48335 .19069 .48233 .18363 .47764 Mtetra
.519 .765 .986 r
.18363 .47764 .19069 .48233 .20043 .4808 .19336 .47634 Mtetra
.563 .789 .984 r
.19336 .47634 .20043 .4808 .21027 .47868 .20321 .47436 Mtetra
.608 .809 .977 r
.20321 .47436 .21027 .47868 .22021 .47591 .21317 .47165 Mtetra
.65 .822 .966 r
.21317 .47165 .22021 .47591 .23025 .47246 .22324 .46817 Mtetra
.686 .829 .951 r
.22324 .46817 .23025 .47246 .24039 .46834 .23342 .46392 Mtetra
.716 .829 .935 r
.23342 .46392 .24039 .46834 .25062 .46357 .2437 .45894 Mtetra
.737 .825 .919 r
.2437 .45894 .25062 .46357 .26093 .45821 .25406 .4533 Mtetra
.752 .817 .903 r
.25406 .4533 .26093 .45821 .2713 .45237 .26449 .4471 Mtetra
.761 .807 .889 r
.26449 .4471 .2713 .45237 .28172 .44613 .27497 .44046 Mtetra
.765 .795 .878 r
.27497 .44046 .28172 .44613 .29218 .43964 .2855 .43354 Mtetra
.764 .783 .868 r
.2855 .43354 .29218 .43964 .30267 .43304 .29605 .42649 Mtetra
.76 .77 .862 r
.29605 .42649 .30267 .43304 .31318 .42645 .30662 .41946 Mtetra
.752 .758 .857 r
.30662 .41946 .31318 .42645 .3237 .42003 .31719 .41262 Mtetra
.74 .745 .855 r
.31719 .41262 .3237 .42003 .33422 .4139 .32776 .40611 Mtetra
.726 .733 .856 r
.32776 .40611 .33422 .4139 .34475 .40818 .33833 .40007 Mtetra
.71 .721 .858 r
.33833 .40007 .34475 .40818 .35527 .40296 .34889 .39462 Mtetra
.69 .709 .863 r
.34889 .39462 .35527 .40296 .36579 .39834 .35944 .38982 Mtetra
.668 .698 .869 r
.35944 .38982 .36579 .39834 .37632 .39434 .36999 .38574 Mtetra
.644 .688 .876 r
.36999 .38574 .37632 .39434 .38686 .391 .38055 .3824 Mtetra
.618 .679 .885 r
.38055 .3824 .38686 .391 .39742 .38829 .39112 .37979 Mtetra
.59 .671 .895 r
.39112 .37979 .39742 .38829 .408 .3862 .40171 .37787 Mtetra
.562 .664 .906 r
.40171 .37787 .408 .3862 .41861 .38464 .41233 .37655 Mtetra
.535 .661 .917 r
.41233 .37655 .41861 .38464 .42927 .38352 .423 .37575 Mtetra
.51 .66 .928 r
.423 .37575 .42927 .38352 .43998 .38275 .43371 .37533 Mtetra
.49 .663 .939 r
.43371 .37533 .43998 .38275 .45075 .38218 .44448 .37515 Mtetra
.477 .671 .949 r
.44448 .37515 .45075 .38218 .46157 .38167 .45532 .37505 Mtetra
.473 .684 .959 r
.45532 .37505 .46157 .38167 .47247 .3811 .46623 .37487 Mtetra
.478 .702 .967 r
.46623 .37487 .47247 .3811 .48343 .3803 .47722 .37444 Mtetra
.495 .724 .974 r
.47722 .37444 .48343 .3803 .49446 .37916 .48827 .37361 Mtetra
.52 .749 .979 r
.48827 .37361 .49446 .37916 .50556 .37754 .49939 .37226 Mtetra
.554 .774 .98 r
.49939 .37226 .50556 .37754 .51672 .37536 .51058 .37026 Mtetra
.592 .797 .978 r
.51058 .37026 .51672 .37536 .52793 .37253 .52183 .36753 Mtetra
.631 .815 .971 r
.52183 .36753 .52793 .37253 .53919 .36901 .53313 .36402 Mtetra
.667 .828 .961 r
.53313 .36402 .53919 .36901 .5505 .36479 .54447 .35971 Mtetra
.699 .835 .948 r
.54447 .35971 .5505 .36479 .56184 .35988 .55585 .35463 Mtetra
.725 .836 .933 r
.55585 .35463 .56184 .35988 .57321 .35434 .56726 .34883 Mtetra
.744 .832 .918 r
.56726 .34883 .57321 .35434 .5846 .34824 .57869 .3424 Mtetra
.757 .824 .904 r
.57869 .3424 .5846 .34824 .59602 .34169 .59014 .33545 Mtetra
.764 .814 .892 r
.59014 .33545 .59602 .34169 .60745 .33481 .60161 .32813 Mtetra
.766 .802 .882 r
.60161 .32813 .60745 .33481 .61891 .32772 .61309 .32059 Mtetra
.764 .789 .873 r
.61309 .32059 .61891 .32772 .63039 .32059 .6246 .313 Mtetra
.757 .775 .867 r
.6246 .313 .63039 .32059 .64189 .31355 .63612 .30551 Mtetra
.747 .76 .863 r
.63612 .30551 .64189 .31355 .65344 .30675 .64769 .2983 Mtetra
.734 .746 .862 r
.64769 .2983 .65344 .30675 .66502 .3003 .65929 .29149 Mtetra
.718 .732 .862 r
.65929 .29149 .66502 .3003 .67666 .29433 .67095 .28522 Mtetra
.699 .718 .864 r
.67095 .28522 .67666 .29433 .68836 .28892 .68267 .27959 Mtetra
.679 .705 .868 r
.68267 .27959 .68836 .28892 .70014 .28413 .69447 .27467 Mtetra
.656 .693 .873 r
.69447 .27467 .70014 .28413 .712 .28001 .70636 .2705 Mtetra
.633 .682 .879 r
.70636 .2705 .712 .28001 .72396 .27654 .71834 .26708 Mtetra
.608 .673 .886 r
.71834 .26708 .72396 .27654 .73601 .27372 .73043 .26439 Mtetra
.584 .665 .895 r
.73043 .26439 .73601 .27372 .74817 .27148 .74263 .26236 Mtetra
.56 .66 .904 r
.74263 .26236 .74817 .27148 .76043 .26974 .75495 .26091 Mtetra
.539 .658 .913 r
.75495 .26091 .76043 .26974 .7728 .26841 .76737 .25991 Mtetra
.521 .66 .923 r
.76737 .25991 .7728 .26841 .78527 .26735 .7799 .25924 Mtetra
.508 .666 .933 r
.7799 .25924 .78527 .26735 .79782 .26643 .79252 .25872 Mtetra
.399 .657 .963 r
.13868 .4723 .14569 .47843 .15505 .47862 .148 .47293 Mtetra
.398 .674 .972 r
.148 .47293 .15505 .47862 .16449 .47865 .1574 .47338 Mtetra
.414 .699 .98 r
.1574 .47338 .16449 .47865 .17401 .47837 .16689 .47348 Mtetra
.447 .728 .986 r
.16689 .47348 .17401 .47837 .18363 .47764 .1765 .47307 Mtetra
.493 .76 .99 r
.1765 .47307 .18363 .47764 .19336 .47634 .18622 .47201 Mtetra
.545 .79 .989 r
.18622 .47201 .19336 .47634 .20321 .47436 .19607 .47019 Mtetra
.599 .813 .982 r
.19607 .47019 .20321 .47436 .21317 .47165 .20605 .46755 Mtetra
.649 .829 .969 r
.20605 .46755 .21317 .47165 .22324 .46817 .21616 .46403 Mtetra
.69 .836 .953 r
.21616 .46403 .22324 .46817 .23342 .46392 .22638 .45964 Mtetra
.723 .836 .935 r
.22638 .45964 .23342 .46392 .2437 .45894 .23671 .45443 Mtetra
.747 .831 .916 r
.23671 .45443 .2437 .45894 .25406 .4533 .24712 .44848 Mtetra
.763 .822 .899 r
.24712 .44848 .25406 .4533 .26449 .4471 .25762 .44189 Mtetra
.772 .811 .884 r
.25762 .44189 .26449 .4471 .27497 .44046 .26817 .43482 Mtetra
.775 .798 .871 r
.26817 .43482 .27497 .44046 .2855 .43354 .27876 .42742 Mtetra
.774 .785 .862 r
.27876 .42742 .2855 .43354 .29605 .42649 .28938 .41988 Mtetra
.769 .771 .855 r
.28938 .41988 .29605 .42649 .30662 .41946 .30001 .41237 Mtetra
.76 .758 .85 r
.30001 .41237 .30662 .41946 .31719 .41262 .31064 .40507 Mtetra
.748 .744 .849 r
.31064 .40507 .31719 .41262 .32776 .40611 .32127 .39816 Mtetra
.733 .731 .849 r
.32127 .39816 .32776 .40611 .33833 .40007 .33188 .39177 Mtetra
.715 .718 .852 r
.33188 .39177 .33833 .40007 .34889 .39462 .34247 .38604 Mtetra
.693 .706 .857 r
.34247 .38604 .34889 .39462 .35944 .38982 .35306 .38106 Mtetra
.669 .694 .864 r
.35306 .38106 .35944 .38982 .36999 .38574 .36363 .3769 Mtetra
.642 .682 .873 r
.36363 .3769 .36999 .38574 .38055 .3824 .37421 .37356 Mtetra
.613 .672 .882 r
.37421 .37356 .38055 .3824 .39112 .37979 .38479 .37106 Mtetra
.582 .662 .893 r
.38479 .37106 .39112 .37979 .40171 .37787 .39538 .36933 Mtetra
.549 .654 .904 r
.39538 .36933 .40171 .37787 .41233 .37655 .40601 .36829 Mtetra
.517 .649 .916 r
.40601 .36829 .41233 .37655 .423 .37575 .41668 .36783 Mtetra
.488 .646 .927 r
.41668 .36783 .423 .37575 .43371 .37533 .4274 .36781 Mtetra
.464 .649 .939 r
.4274 .36781 .43371 .37533 .44448 .37515 .43818 .36805 Mtetra
.447 .656 .949 r
.43818 .36805 .44448 .37515 .45532 .37505 .44903 .36839 Mtetra
.441 .67 .96 r
.44903 .36839 .45532 .37505 .46623 .37487 .45995 .36865 Mtetra
.447 .69 .969 r
.45995 .36865 .46623 .37487 .47722 .37444 .47095 .36862 Mtetra
.466 .715 .977 r
.47095 .36862 .47722 .37444 .48827 .37361 .48203 .36816 Mtetra
.496 .744 .983 r
.48203 .36816 .48827 .37361 .49939 .37226 .49318 .36709 Mtetra
.536 .773 .985 r
.49318 .36709 .49939 .37226 .51058 .37026 .5044 .36529 Mtetra
.581 .8 .983 r
.5044 .36529 .51058 .37026 .52183 .36753 .51568 .36268 Mtetra
.626 .821 .975 r
.51568 .36268 .52183 .36753 .53313 .36402 .52702 .35918 Mtetra
.669 .836 .964 r
.52702 .35918 .53313 .36402 .54447 .35971 .5384 .35478 Mtetra
.705 .843 .949 r
.5384 .35478 .54447 .35971 .55585 .35463 .54982 .34951 Mtetra
.733 .844 .932 r
.54982 .34951 .55585 .35463 .56726 .34883 .56127 .34342 Mtetra
.755 .839 .916 r
.56127 .34342 .56726 .34883 .57869 .3424 .57273 .33662 Mtetra
.768 .83 .9 r
.57273 .33662 .57869 .3424 .59014 .33545 .58422 .32925 Mtetra
.776 .819 .887 r
.58422 .32925 .59014 .33545 .60161 .32813 .59572 .32145 Mtetra
.778 .806 .875 r
.59572 .32145 .60161 .32813 .61309 .32059 .60723 .31341 Mtetra
.774 .791 .867 r
.60723 .31341 .61309 .32059 .6246 .313 .61876 .30532 Mtetra
.767 .776 .861 r
.61876 .30532 .6246 .313 .63612 .30551 .63031 .29734 Mtetra
.756 .761 .857 r
.63031 .29734 .63612 .30551 .64769 .2983 .64189 .28968 Mtetra
.741 .746 .855 r
.64189 .28968 .64769 .2983 .65929 .29149 .65351 .28248 Mtetra
.724 .731 .856 r
.65351 .28248 .65929 .29149 .67095 .28522 .66519 .27589 Mtetra
.704 .716 .859 r
.66519 .27589 .67095 .28522 .68267 .27959 .67693 .27002 Mtetra
.681 .702 .863 r
.67693 .27002 .68267 .27959 .69447 .27467 .68875 .26496 Mtetra
.656 .688 .868 r
.68875 .26496 .69447 .27467 .70636 .2705 .70066 .26074 Mtetra
.629 .676 .875 r
.70066 .26074 .70636 .2705 .71834 .26708 .71268 .25737 Mtetra
.602 .665 .883 r
.71268 .25737 .71834 .26708 .73043 .26439 .72481 .25483 Mtetra
.574 .656 .892 r
.72481 .25483 .73043 .26439 .74263 .26236 .73705 .25304 Mtetra
.547 .65 .902 r
.73705 .25304 .74263 .26236 .75495 .26091 .74941 .2519 Mtetra
.523 .647 .912 r
.74941 .2519 .75495 .26091 .76737 .25991 .76189 .25128 Mtetra
.502 .647 .922 r
.76189 .25128 .76737 .25991 .7799 .25924 .77449 .25102 Mtetra
.486 .653 .933 r
.77449 .25102 .7799 .25924 .79252 .25872 .78718 .25095 Mtetra
.349 .633 .96 r
.13161 .46613 .13868 .4723 .148 .47293 .14088 .46724 Mtetra
.347 .651 .968 r
.14088 .46724 .148 .47293 .1574 .47338 .15024 .46815 Mtetra
.366 .679 .978 r
.15024 .46815 .1574 .47338 .16689 .47348 .1597 .46867 Mtetra
.405 .715 .987 r
.1597 .46867 .16689 .47348 .1765 .47307 .16928 .46861 Mtetra
.461 .754 .993 r
.16928 .46861 .1765 .47307 .18622 .47201 .179 .46783 Mtetra
.524 .79 .993 r
.179 .46783 .18622 .47201 .19607 .47019 .18886 .46619 Mtetra
.589 .818 .987 r
.18886 .46619 .19607 .47019 .20605 .46755 .19886 .46362 Mtetra
.647 .836 .973 r
.19886 .46362 .20605 .46755 .21616 .46403 .20899 .46007 Mtetra
.695 .845 .955 r
.20899 .46007 .21616 .46403 .22638 .45964 .21926 .45553 Mtetra
.731 .844 .934 r
.21926 .45553 .22638 .45964 .23671 .45443 .22964 .45007 Mtetra
.757 .838 .913 r
.22964 .45007 .23671 .45443 .24712 .44848 .24012 .44377 Mtetra
.774 .827 .894 r
.24012 .44377 .24712 .44848 .25762 .44189 .25068 .43677 Mtetra
.783 .815 .878 r
.25068 .43677 .25762 .44189 .26817 .43482 .2613 .42921 Mtetra
.786 .801 .864 r
.2613 .42921 .26817 .43482 .27876 .42742 .27197 .42129 Mtetra
.784 .786 .854 r
.27197 .42129 .27876 .42742 .28938 .41988 .28266 .41321 Mtetra
.778 .772 .847 r
.28266 .41321 .28938 .41988 .30001 .41237 .29336 .40517 Mtetra
.769 .757 .843 r
.29336 .40517 .30001 .41237 .31064 .40507 .30406 .39738 Mtetra
.756 .743 .841 r
.30406 .39738 .31064 .40507 .32127 .39816 .31474 .39001 Mtetra
.739 .729 .842 r
.31474 .39001 .32127 .39816 .33188 .39177 .3254 .38325 Mtetra
.72 .716 .846 r
.3254 .38325 .33188 .39177 .34247 .38604 .33603 .37723 Mtetra
.697 .702 .851 r
.33603 .37723 .34247 .38604 .35306 .38106 .34665 .37205 Mtetra
.67 .689 .859 r
.34665 .37205 .35306 .38106 .36363 .3769 .35725 .36779 Mtetra
.64 .676 .868 r
.35725 .36779 .36363 .3769 .37421 .37356 .36784 .36447 Mtetra
.608 .664 .879 r
.36784 .36447 .37421 .37356 .38479 .37106 .37843 .36208 Mtetra
.572 .652 .89 r
.37843 .36208 .38479 .37106 .39538 .36933 .38903 .36056 Mtetra
.535 .642 .903 r
.38903 .36056 .39538 .36933 .40601 .36829 .39966 .35983 Mtetra
.498 .635 .915 r
.39966 .35983 .40601 .36829 .41668 .36783 .41033 .35975 Mtetra
.463 .631 .926 r
.41033 .35975 .41668 .36783 .4274 .36781 .42105 .36016 Mtetra
.433 .631 .937 r
.42105 .36016 .4274 .36781 .43818 .36805 .43183 .36088 Mtetra
.413 .638 .948 r
.43183 .36088 .43818 .36805 .44903 .36839 .44268 .36171 Mtetra
.404 .652 .959 r
.44268 .36171 .44903 .36839 .45995 .36865 .45361 .36244 Mtetra
.41 .674 .969 r
.45361 .36244 .45995 .36865 .47095 .36862 .46463 .36287 Mtetra
.432 .703 .979 r
.46463 .36287 .47095 .36862 .48203 .36816 .47573 .3628 Mtetra
.468 .736 .986 r
.47573 .3628 .48203 .36816 .49318 .36709 .4869 .36205 Mtetra
.515 .771 .989 r
.4869 .36205 .49318 .36709 .5044 .36529 .49815 .36049 Mtetra
.568 .802 .987 r
.49815 .36049 .5044 .36529 .51568 .36268 .50947 .358 Mtetra
.621 .827 .98 r
.50947 .358 .51568 .36268 .52702 .35918 .52085 .35452 Mtetra
.67 .844 .967 r
.52085 .35452 .52702 .35918 .5384 .35478 .53227 .35002 Mtetra
.711 .852 .95 r
.53227 .35002 .5384 .35478 .54982 .34951 .54373 .34454 Mtetra
.743 .852 .931 r
.54373 .34454 .54982 .34951 .56127 .34342 .55522 .33814 Mtetra
.766 .847 .912 r
.55522 .33814 .56127 .34342 .57273 .33662 .56673 .33094 Mtetra
.78 .837 .895 r
.56673 .33094 .57273 .33662 .58422 .32925 .57825 .3231 Mtetra
.788 .824 .881 r
.57825 .3231 .58422 .32925 .59572 .32145 .58978 .31478 Mtetra
.789 .81 .869 r
.58978 .31478 .59572 .32145 .60723 .31341 .60132 .30619 Mtetra
.785 .794 .86 r
.60132 .30619 .60723 .31341 .61876 .30532 .61287 .29754 Mtetra
.777 .778 .853 r
.61287 .29754 .61876 .30532 .63031 .29734 .62445 .28903 Mtetra
.765 .761 .85 r
.62445 .28903 .63031 .29734 .64189 .28968 .63605 .28088 Mtetra
.749 .745 .849 r
.63605 .28088 .64189 .28968 .65351 .28248 .64769 .27325 Mtetra
.73 .729 .85 r
.64769 .27325 .65351 .28248 .66519 .27589 .65938 .26631 Mtetra
.708 .713 .853 r
.65938 .26631 .66519 .27589 .67693 .27002 .67114 .26018 Mtetra
.683 .698 .857 r
.67114 .26018 .67693 .27002 .68875 .26496 .68299 .25496 Mtetra
.656 .683 .864 r
.68299 .25496 .68875 .26496 .70066 .26074 .69492 .2507 Mtetra
.626 .669 .871 r
.69492 .2507 .70066 .26074 .71268 .25737 .70697 .24739 Mtetra
.595 .656 .88 r
.70697 .24739 .71268 .25737 .72481 .25483 .71913 .24501 Mtetra
.564 .646 .889 r
.71913 .24501 .72481 .25483 .73705 .25304 .73142 .24348 Mtetra
.533 .638 .899 r
.73142 .24348 .73705 .25304 .74941 .2519 .74383 .24269 Mtetra
.505 .633 .91 r
.74383 .24269 .74941 .2519 .76189 .25128 .75637 .24249 Mtetra
.48 .633 .921 r
.75637 .24249 .76189 .25128 .77449 .25102 .76903 .24269 Mtetra
.462 .638 .932 r
.76903 .24269 .77449 .25102 .78718 .25095 .7818 .24311 Mtetra
.29 .603 .952 r
.12449 .45992 .13161 .46613 .14088 .46724 .13371 .46156 Mtetra
.286 .622 .96 r
.13371 .46156 .14088 .46724 .15024 .46815 .14302 .46298 Mtetra
.307 .654 .971 r
.14302 .46298 .15024 .46815 .1597 .46867 .15244 .46396 Mtetra
.354 .696 .983 r
.15244 .46396 .1597 .46867 .16928 .46861 .16199 .4643 Mtetra
.421 .744 .993 r
.16199 .4643 .16928 .46861 .179 .46783 .1717 .46383 Mtetra
.499 .788 .997 r
.1717 .46383 .179 .46783 .18886 .46619 .18155 .46239 Mtetra
.576 .823 .992 r
.18155 .46239 .18886 .46619 .19886 .46362 .19157 .4599 Mtetra
.644 .845 .977 r
.19157 .4599 .19886 .46362 .20899 .46007 .20174 .45631 Mtetra
.699 .854 .956 r
.20174 .45631 .20899 .46007 .21926 .45553 .21205 .45162 Mtetra
.74 .853 .933 r
.21205 .45162 .21926 .45553 .22964 .45007 .22249 .44588 Mtetra
.768 .845 .91 r
.22249 .44588 .22964 .45007 .24012 .44377 .23304 .43921 Mtetra
.785 .833 .889 r
.23304 .43921 .24012 .44377 .25068 .43677 .24367 .43174 Mtetra
.794 .819 .871 r
.24367 .43174 .25068 .43677 .2613 .42921 .25438 .42365 Mtetra
.797 .803 .857 r
.25438 .42365 .2613 .42921 .27197 .42129 .26513 .41516 Mtetra
.795 .788 .846 r
.26513 .41516 .27197 .42129 .28266 .41321 .2759 .40649 Mtetra
.788 .772 .839 r
.2759 .40649 .28266 .41321 .29336 .40517 .28667 .39787 Mtetra
.777 .757 .835 r
.28667 .39787 .29336 .40517 .30406 .39738 .29744 .38952 Mtetra
.763 .742 .833 r
.29744 .38952 .30406 .39738 .31474 .39001 .30818 .38167 Mtetra
.746 .727 .835 r
.30818 .38167 .31474 .39001 .3254 .38325 .31889 .37449 Mtetra
.725 .713 .839 r
.31889 .37449 .3254 .38325 .33603 .37723 .32957 .36814 Mtetra
.7 .698 .845 r
.32957 .36814 .33603 .37723 .34665 .37205 .34022 .36275 Mtetra
.671 .684 .854 r
.34022 .36275 .34665 .37205 .35725 .36779 .35084 .35838 Mtetra
.638 .669 .864 r
.35084 .35838 .35725 .36779 .36784 .36447 .36144 .35508 Mtetra
.602 .655 .875 r
.36144 .35508 .36784 .36447 .37843 .36208 .37204 .35282 Mtetra
.561 .642 .887 r
.37204 .35282 .37843 .36208 .38903 .36056 .38264 .35154 Mtetra
.519 .629 .9 r
.38264 .35154 .38903 .36056 .39966 .35983 .39327 .35115 Mtetra
.475 .619 .912 r
.39327 .35115 .39966 .35983 .41033 .35975 .40393 .35149 Mtetra
.434 .612 .924 r
.40393 .35149 .41033 .35975 .42105 .36016 .41465 .35238 Mtetra
.398 .61 .935 r
.41465 .35238 .42105 .36016 .43183 .36088 .42543 .35363 Mtetra
.372 .616 .945 r
.42543 .35363 .43183 .36088 .44268 .36171 .43629 .35501 Mtetra
.361 .63 .956 r
.43629 .35501 .44268 .36171 .45361 .36244 .44723 .35627 Mtetra
.366 .654 .967 r
.44723 .35627 .45361 .36244 .46463 .36287 .45825 .3572 Mtetra
.391 .687 .978 r
.45825 .3572 .46463 .36287 .47573 .3628 .46937 .35757 Mtetra
.433 .726 .987 r
.46937 .35757 .47573 .3628 .4869 .36205 .48057 .35718 Mtetra
.489 .767 .993 r
.48057 .35718 .4869 .36205 .49815 .36049 .49185 .35587 Mtetra
.552 .805 .992 r
.49185 .35587 .49815 .36049 .50947 .358 .5032 .35353 Mtetra
.614 .834 .984 r
.5032 .35353 .50947 .358 .52085 .35452 .51462 .35006 Mtetra
.671 .854 .97 r
.51462 .35006 .52085 .35452 .53227 .35002 .52608 .34546 Mtetra
.717 .862 .95 r
.52608 .34546 .53227 .35002 .54373 .34454 .53759 .33975 Mtetra
.753 .862 .929 r
.53759 .33975 .54373 .34454 .55522 .33814 .54912 .33301 Mtetra
.777 .855 .909 r
.54912 .33301 .55522 .33814 .56673 .33094 .56067 .32537 Mtetra
.793 .844 .89 r
.56067 .32537 .56673 .33094 .57825 .3231 .57223 .31701 Mtetra
.8 .829 .874 r
.57223 .31701 .57825 .3231 .58978 .31478 .58379 .30812 Mtetra
.801 .813 .861 r
.58379 .30812 .58978 .31478 .60132 .30619 .59537 .29893 Mtetra
.797 .796 .852 r
.59537 .29893 .60132 .30619 .61287 .29754 .60695 .28967 Mtetra
.787 .779 .845 r
.60695 .28967 .61287 .29754 .62445 .28903 .61854 .28058 Mtetra
.774 .762 .842 r
.61854 .28058 .62445 .28903 .63605 .28088 .63016 .27188 Mtetra
.757 .744 .841 r
.63016 .27188 .63605 .28088 .64769 .27325 .64182 .26378 Mtetra
.736 .727 .843 r
.64182 .26378 .64769 .27325 .65938 .26631 .65353 .25646 Mtetra
.712 .71 .846 r
.65353 .25646 .65938 .26631 .67114 .26018 .66531 .25005 Mtetra
.685 .693 .852 r
.66531 .25005 .67114 .26018 .68299 .25496 .67717 .24466 Mtetra
.655 .677 .859 r
.67717 .24466 .68299 .25496 .69492 .2507 .68913 .24035 Mtetra
.623 .661 .867 r
.68913 .24035 .69492 .2507 .70697 .24739 .70121 .23711 Mtetra
.588 .647 .876 r
.70121 .23711 .70697 .24739 .71913 .24501 .7134 .23492 Mtetra
.553 .634 .886 r
.7134 .23492 .71913 .24501 .73142 .24348 .72573 .23368 Mtetra
.518 .625 .896 r
.72573 .23368 .73142 .24348 .74383 .24269 .7382 .23327 Mtetra
.485 .618 .907 r
.7382 .23327 .74383 .24269 .75637 .24249 .7508 .23353 Mtetra
.456 .616 .918 r
.7508 .23353 .75637 .24249 .76903 .24269 .76353 .23425 Mtetra
.434 .621 .93 r
.76353 .23425 .76903 .24269 .7818 .24311 .77637 .23521 Mtetra
.219 .563 .937 r
.11732 .45366 .12449 .45992 .13371 .46156 .12647 .45589 Mtetra
.211 .582 .943 r
.12647 .45589 .13371 .46156 .14302 .46298 .13572 .45788 Mtetra
.235 .619 .956 r
.13572 .45788 .14302 .46298 .15244 .46396 .1451 .45938 Mtetra
.291 .67 .973 r
.1451 .45938 .15244 .46396 .16199 .4643 .15462 .46017 Mtetra
.373 .729 .989 r
.15462 .46017 .16199 .4643 .1717 .46383 .1643 .46003 Mtetra
.467 .785 .999 r
.1643 .46003 .1717 .46383 .18155 .46239 .17416 .45882 Mtetra
.56 .828 .996 r
.17416 .45882 .18155 .46239 .19157 .4599 .18419 .45643 Mtetra
.641 .854 .981 r
.18419 .45643 .19157 .4599 .20174 .45631 .19439 .4528 Mtetra
.704 .864 .958 r
.19439 .4528 .20174 .45631 .21205 .45162 .20475 .44793 Mtetra
.749 .862 .932 r
.20475 .44793 .21205 .45162 .22249 .44588 .21525 .44189 Mtetra
.779 .853 .906 r
.21525 .44189 .22249 .44588 .23304 .43921 .22588 .4348 Mtetra
.797 .839 .883 r
.22588 .4348 .23304 .43921 .24367 .43174 .2366 .42681 Mtetra
.806 .822 .864 r
.2366 .42681 .24367 .43174 .25438 .42365 .24739 .41814 Mtetra
.808 .806 .849 r
.24739 .41814 .25438 .42365 .26513 .41516 .25823 .40902 Mtetra
.805 .789 .837 r
.25823 .40902 .26513 .41516 .2759 .40649 .26908 .3997 Mtetra
.798 .772 .83 r
.26908 .3997 .2759 .40649 .28667 .39787 .27994 .39044 Mtetra
.786 .756 .826 r
.27994 .39044 .28667 .39787 .29744 .38952 .29078 .38149 Mtetra
.771 .74 .825 r
.29078 .38149 .29744 .38952 .30818 .38167 .30159 .37309 Mtetra
.752 .725 .827 r
.30159 .37309 .30818 .38167 .31889 .37449 .31236 .36546 Mtetra
.73 .709 .831 r
.31236 .36546 .31889 .37449 .32957 .36814 .32308 .35876 Mtetra
.703 .694 .838 r
.32308 .35876 .32957 .36814 .34022 .36275 .33376 .35313 Mtetra
.672 .678 .848 r
.33376 .35313 .34022 .36275 .35084 .35838 .3444 .34865 Mtetra
.636 .662 .858 r
.3444 .34865 .35084 .35838 .36144 .35508 .35502 .34537 Mtetra
.595 .646 .871 r
.35502 .34537 .36144 .35508 .37204 .35282 .36562 .34325 Mtetra
.55 .63 .884 r
.36562 .34325 .37204 .35282 .38264 .35154 .37623 .34224 Mtetra
.501 .614 .897 r
.37623 .34224 .38264 .35154 .39327 .35115 .38685 .34222 Mtetra
.45 .601 .909 r
.38685 .34222 .39327 .35115 .40393 .35149 .39751 .34303 Mtetra
.401 .59 .92 r
.39751 .34303 .40393 .35149 .41465 .35238 .40821 .34447 Mtetra
.357 .585 .93 r
.40821 .34447 .41465 .35238 .42543 .35363 .41899 .3463 Mtetra
.325 .589 .94 r
.41899 .3463 .42543 .35363 .43629 .35501 .42984 .34828 Mtetra
.309 .603 .95 r
.42984 .34828 .43629 .35501 .44723 .35627 .44078 .35014 Mtetra
.314 .629 .961 r
.44078 .35014 .44723 .35627 .45825 .3572 .45182 .35162 Mtetra
.342 .666 .974 r
.45182 .35162 .45825 .3572 .46937 .35757 .46295 .35248 Mtetra
.391 .712 .987 r
.46295 .35248 .46937 .35757 .48057 .35718 .47417 .35249 Mtetra
.457 .761 .995 r
.47417 .35249 .48057 .35718 .49185 .35587 .48548 .35147 Mtetra
.532 .807 .996 r
.48548 .35147 .49185 .35587 .5032 .35353 .49687 .34929 Mtetra
.606 .842 .989 r
.49687 .34929 .5032 .35353 .51462 .35006 .50833 .34585 Mtetra
.672 .864 .972 r
.50833 .34585 .51462 .35006 .52608 .34546 .51984 .34113 Mtetra
.724 .873 .951 r
.51984 .34113 .52608 .34546 .53759 .33975 .53139 .33517 Mtetra
.763 .872 .927 r
.53139 .33517 .53759 .33975 .54912 .33301 .54296 .32806 Mtetra
.79 .864 .904 r
.54296 .32806 .54912 .33301 .56067 .32537 .55456 .31994 Mtetra
.806 .851 .883 r
.55456 .31994 .56067 .32537 .57223 .31701 .56616 .311 Mtetra
.813 .835 .866 r
.56616 .311 .57223 .31701 .58379 .30812 .57776 .30148 Mtetra
.814 .817 .853 r
.57776 .30148 .58379 .30812 .59537 .29893 .58937 .29162 Mtetra
.808 .799 .843 r
.58937 .29162 .59537 .29893 .60695 .28967 .60097 .28169 Mtetra
.798 .78 .837 r
.60097 .28169 .60695 .28967 .61854 .28058 .61259 .27196 Mtetra
.783 .762 .833 r
.61259 .27196 .61854 .28058 .63016 .27188 .62423 .26266 Mtetra
.765 .743 .833 r
.62423 .26266 .63016 .27188 .64182 .26378 .63591 .25405 Mtetra
.743 .725 .835 r
.63591 .25405 .64182 .26378 .65353 .25646 .64764 .24631 Mtetra
.717 .706 .839 r
.64764 .24631 .65353 .25646 .66531 .25005 .65943 .23959 Mtetra
.687 .688 .845 r
.65943 .23959 .66531 .25005 .67717 .24466 .67131 .23402 Mtetra
.654 .67 .853 r
.67131 .23402 .67717 .24466 .68913 .24035 .68329 .22966 Mtetra
.618 .653 .862 r
.68329 .22966 .68913 .24035 .70121 .23711 .69539 .2265 Mtetra
.58 .637 .872 r
.69539 .2265 .70121 .23711 .7134 .23492 .70763 .22452 Mtetra
.541 .622 .882 r
.70763 .22452 .7134 .23492 .72573 .23368 .72 .2236 Mtetra
.501 .61 .893 r
.72 .2236 .72573 .23368 .7382 .23327 .73252 .22362 Mtetra
.463 .601 .904 r
.73252 .22362 .7382 .23327 .7508 .23353 .74518 .22439 Mtetra
.429 .598 .915 r
.74518 .22439 .7508 .23353 .76353 .23425 .75798 .22568 Mtetra
.402 .6 .927 r
.75798 .22568 .76353 .23425 .77637 .23521 .7709 .22725 Mtetra
.133 .512 .912 r
.1101 .44736 .11732 .45366 .12647 .45589 .11918 .45025 Mtetra
.12 .53 .916 r
.11918 .45025 .12647 .45589 .13572 .45788 .12836 .45287 Mtetra
.147 .572 .929 r
.12836 .45287 .13572 .45788 .1451 .45938 .13767 .45495 Mtetra
.214 .633 .953 r
.13767 .45495 .1451 .45938 .15462 .46017 .14715 .45622 Mtetra
.312 .707 .979 r
.14715 .45622 .15462 .46017 .1643 .46003 .15681 .45647 Mtetra
.427 .777 .997 r
.15681 .45647 .1643 .46003 .17416 .45882 .16666 .45552 Mtetra
.54 .832 .999 r
.16666 .45552 .17416 .45882 .18419 .45643 .17671 .45323 Mtetra
.637 .864 .984 r
.17671 .45323 .18419 .45643 .19439 .4528 .18695 .44956 Mtetra
.709 .876 .959 r
.18695 .44956 .19439 .4528 .20475 .44793 .19736 .4445 Mtetra
.759 .872 .93 r
.19736 .4445 .20475 .44793 .21525 .44189 .20793 .43813 Mtetra
.791 .86 .901 r
.20793 .43813 .21525 .44189 .22588 .4348 .21864 .43057 Mtetra
.809 .844 .876 r
.21864 .43057 .22588 .4348 .2366 .42681 .22945 .42202 Mtetra
.818 .826 .856 r
.22945 .42202 .2366 .42681 .24739 .41814 .24034 .4127 Mtetra
.82 .808 .84 r
.24034 .4127 .24739 .41814 .25823 .40902 .25127 .40288 Mtetra
.816 .79 .828 r
.25127 .40288 .25823 .40902 .26908 .3997 .26222 .39284 Mtetra
.807 .772 .821 r
.26222 .39284 .26908 .3997 .27994 .39044 .27317 .38287 Mtetra
.795 .755 .817 r
.27317 .38287 .27994 .39044 .29078 .38149 .28409 .37326 Mtetra
.779 .739 .816 r
.28409 .37326 .29078 .38149 .30159 .37309 .29497 .36427 Mtetra
.759 .722 .818 r
.29497 .36427 .30159 .37309 .31236 .36546 .3058 .35614 Mtetra
.735 .706 .823 r
.3058 .35614 .31236 .36546 .32308 .35876 .31657 .34905 Mtetra
.706 .689 .831 r
.31657 .34905 .32308 .35876 .33376 .35313 .32729 .34316 Mtetra
.673 .672 .841 r
.32729 .34316 .33376 .35313 .3444 .34865 .33796 .33857 Mtetra
.633 .654 .853 r
.33796 .33857 .3444 .34865 .35502 .34537 .34858 .3353 Mtetra
.588 .636 .866 r
.34858 .3353 .35502 .34537 .36562 .34325 .35919 .33336 Mtetra
.537 .617 .879 r
.35919 .33336 .36562 .34325 .37623 .34224 .36979 .33264 Mtetra
.481 .598 .892 r
.36979 .33264 .37623 .34224 .38685 .34222 .3804 .33304 Mtetra
.421 .58 .904 r
.3804 .33304 .38685 .34222 .39751 .34303 .39104 .33437 Mtetra
.363 .565 .914 r
.39104 .33437 .39751 .34303 .40821 .34447 .40174 .3364 Mtetra
.31 .556 .922 r
.40174 .3364 .40821 .34447 .41899 .3463 .4125 .33888 Mtetra
.27 .556 .93 r
.4125 .33888 .41899 .3463 .42984 .34828 .42335 .34153 Mtetra
.248 .568 .938 r
.42335 .34153 .42984 .34828 .44078 .35014 .43429 .34405 Mtetra
.252 .596 .95 r
.43429 .34405 .44078 .35014 .45182 .35162 .44533 .34615 Mtetra
.283 .639 .965 r
.44533 .34615 .45182 .35162 .46295 .35248 .45647 .34756 Mtetra
.34 .693 .982 r
.45647 .34756 .46295 .35248 .47417 .35249 .46772 .34802 Mtetra
.419 .752 .995 r
.46772 .34802 .47417 .35249 .48548 .35147 .47906 .34733 Mtetra
.508 .807 .999 r
.47906 .34733 .48548 .35147 .49687 .34929 .49048 .34532 Mtetra
.595 .85 .992 r
.49048 .34532 .49687 .34929 .50833 .34585 .50198 .34191 Mtetra
.672 .876 .975 r
.50198 .34191 .50833 .34585 .51984 .34113 .51353 .33707 Mtetra
.732 .886 .951 r
.51353 .33707 .51984 .34113 .53139 .33517 .52513 .33083 Mtetra
.775 .884 .924 r
.52513 .33083 .53139 .33517 .54296 .32806 .53675 .32331 Mtetra
.803 .873 .899 r
.53675 .32331 .54296 .32806 .55456 .31994 .54839 .31465 Mtetra
.82 .858 .876 r
.54839 .31465 .55456 .31994 .56616 .311 .56004 .30508 Mtetra
.827 .84 .858 r
.56004 .30508 .56616 .311 .57776 .30148 .57168 .29486 Mtetra
.826 .821 .843 r
.57168 .29486 .57776 .30148 .58937 .29162 .58332 .28427 Mtetra
.82 .801 .833 r
.58332 .28427 .58937 .29162 .60097 .28169 .59495 .27361 Mtetra
.809 .781 .827 r
.59495 .27361 .60097 .28169 .61259 .27196 .6066 .26316 Mtetra
.793 .761 .824 r
.6066 .26316 .61259 .27196 .62423 .26266 .61826 .25322 Mtetra
.773 .742 .824 r
.61826 .25322 .62423 .26266 .63591 .25405 .62995 .24404 Mtetra
.749 .722 .827 r
.62995 .24404 .63591 .25405 .64764 .24631 .64169 .23583 Mtetra
.721 .702 .832 r
.64169 .23583 .64764 .24631 .65943 .23959 .6535 .22878 Mtetra
.689 .683 .839 r
.6535 .22878 .65943 .23959 .67131 .23402 .6654 .22302 Mtetra
.653 .663 .847 r
.6654 .22302 .67131 .23402 .68329 .22966 .6774 .21859 Mtetra
.614 .644 .856 r
.6774 .21859 .68329 .22966 .69539 .2265 .68953 .21553 Mtetra
.572 .625 .867 r
.68953 .21553 .69539 .2265 .70763 .22452 .7018 .21378 Mtetra
.527 .608 .877 r
.7018 .21378 .70763 .22452 .72 .2236 .71422 .21323 Mtetra
.482 .593 .888 r
.71422 .21323 .72 .2236 .73252 .22362 .72679 .21372 Mtetra
.438 .582 .899 r
.72679 .21372 .73252 .22362 .74518 .22439 .73951 .21506 Mtetra
.398 .576 .91 r
.73951 .21506 .74518 .22439 .75798 .22568 .75238 .21698 Mtetra
.366 .577 .922 r
.75238 .21698 .75798 .22568 .7709 .22725 .76539 .21923 Mtetra
.031 .447 .873 r
.10283 .44102 .1101 .44736 .11918 .45025 .11182 .44464 Mtetra
.014 .463 .872 r
.11182 .44464 .11918 .45025 .12836 .45287 .12091 .44796 Mtetra
.043 .509 .887 r
.12091 .44796 .12836 .45287 .13767 .45495 .13016 .45068 Mtetra
.119 .583 .918 r
.13016 .45068 .13767 .45495 .14715 .45622 .13959 .45251 Mtetra
.236 .674 .957 r
.13959 .45251 .14715 .45622 .15681 .45647 .14922 .45318 Mtetra
.377 .764 .989 r
.14922 .45318 .15681 .45647 .16666 .45552 .15906 .45251 Mtetra
.515 .834 .999 r
.15906 .45251 .16666 .45552 .17671 .45323 .16912 .45035 Mtetra
.631 .875 .987 r
.16912 .45035 .17671 .45323 .18695 .44956 .1794 .44664 Mtetra
.714 .888 .96 r
.1794 .44664 .18695 .44956 .19736 .4445 .18987 .44137 Mtetra
.77 .883 .928 r
.18987 .44137 .19736 .4445 .20793 .43813 .20051 .43463 Mtetra
.803 .869 .896 r
.20051 .43463 .20793 .43813 .21864 .43057 .21131 .42656 Mtetra
.822 .85 .869 r
.21131 .42656 .21864 .43057 .22945 .42202 .22222 .41738 Mtetra
.83 .83 .847 r
.22222 .41738 .22945 .42202 .24034 .4127 .23321 .40734 Mtetra
.831 .81 .83 r
.23321 .40734 .24034 .4127 .25127 .40288 .24426 .39675 Mtetra
.826 .791 .818 r
.24426 .39675 .25127 .40288 .26222 .39284 .25532 .38592 Mtetra
.817 .772 .811 r
.25532 .38592 .26222 .39284 .27317 .38287 .26636 .37517 Mtetra
.804 .754 .807 r
.26636 .37517 .27317 .38287 .28409 .37326 .27738 .36483 Mtetra
.786 .736 .807 r
.27738 .36483 .28409 .37326 .29497 .36427 .28833 .35518 Mtetra
.765 .719 .809 r
.28833 .35518 .29497 .36427 .3058 .35614 .29923 .34649 Mtetra
.74 .702 .815 r
.29923 .34649 .3058 .35614 .31657 .34905 .31005 .33898 Mtetra
.709 .684 .823 r
.31005 .33898 .31657 .34905 .32729 .34316 .3208 .33281 Mtetra
.673 .665 .834 r
.3208 .33281 .32729 .34316 .33796 .33857 .33149 .32809 Mtetra
.63 .645 .847 r
.33149 .32809 .33796 .33857 .34858 .3353 .34213 .32486 Mtetra
.58 .624 .86 r
.34213 .32486 .34858 .3353 .35919 .33336 .35273 .32309 Mtetra
.523 .602 .874 r
.35273 .32309 .35919 .33336 .36979 .33264 .36332 .32271 Mtetra
.458 .579 .887 r
.36332 .32271 .36979 .33264 .3804 .33304 .37392 .32357 Mtetra
.389 .555 .898 r
.37392 .32357 .3804 .33304 .39104 .33437 .38454 .32547 Mtetra
.319 .535 .906 r
.38454 .32547 .39104 .33437 .40174 .3364 .39522 .32816 Mtetra
.255 .52 .91 r
.39522 .32816 .40174 .3364 .4125 .33888 .40596 .33137 Mtetra
.205 .515 .914 r
.40596 .33137 .4125 .33888 .42335 .34153 .4168 .33476 Mtetra
.177 .526 .92 r
.4168 .33476 .42335 .34153 .43429 .34405 .42773 .33802 Mtetra
.178 .555 .931 r
.42773 .33802 .43429 .34405 .44533 .34615 .43877 .34081 Mtetra
.211 .603 .949 r
.43877 .34081 .44533 .34615 .45647 .34756 .44993 .34283 Mtetra
.278 .667 .97 r
.44993 .34283 .45647 .34756 .46772 .34802 .46119 .34379 Mtetra
.371 .738 .99 r
.46119 .34379 .46772 .34802 .47906 .34733 .47256 .34346 Mtetra
.478 .806 1 r
.47256 .34346 .47906 .34733 .49048 .34532 .48402 .34167 Mtetra
.582 .857 .995 r
.48402 .34167 .49048 .34532 .50198 .34191 .49556 .3383 Mtetra
.671 .888 .977 r
.49556 .3383 .50198 .34191 .51353 .33707 .50716 .33332 Mtetra
.74 .899 .95 r
.50716 .33332 .51353 .33707 .52513 .33083 .51881 .32678 Mtetra
.787 .895 .92 r
.51881 .32678 .52513 .33083 .53675 .32331 .53048 .31879 Mtetra
.817 .883 .892 r
.53048 .31879 .53675 .32331 .54839 .31465 .54217 .30954 Mtetra
.834 .865 .868 r
.54217 .30954 .54839 .31465 .56004 .30508 .55386 .29928 Mtetra
.84 .845 .848 r
.55386 .29928 .56004 .30508 .57168 .29486 .56555 .28829 Mtetra
.839 .824 .833 r
.56555 .28829 .57168 .29486 .58332 .28427 .57722 .27688 Mtetra
.832 .803 .823 r
.57722 .27688 .58332 .28427 .59495 .27361 .58889 .2654 Mtetra
.82 .782 .817 r
.58889 .2654 .59495 .27361 .6066 .26316 .60056 .25417 Mtetra
.802 .761 .814 r
.60056 .25417 .6066 .26316 .61826 .25322 .61224 .24351 Mtetra
.781 .74 .815 r
.61224 .24351 .61826 .25322 .62995 .24404 .62395 .23371 Mtetra
.756 .719 .818 r
.62395 .23371 .62995 .24404 .64169 .23583 .6357 .225 Mtetra
.726 .698 .824 r
.6357 .225 .64169 .23583 .6535 .22878 .64752 .21759 Mtetra
.691 .677 .831 r
.64752 .21759 .6535 .22878 .6654 .22302 .65944 .2116 Mtetra
.652 .656 .84 r
.65944 .2116 .6654 .22302 .6774 .21859 .67146 .20712 Mtetra
.609 .634 .851 r
.67146 .20712 .6774 .21859 .68953 .21553 .68362 .20416 Mtetra
.562 .613 .861 r
.68362 .20416 .68953 .21553 .7018 .21378 .69592 .20267 Mtetra
.512 .593 .872 r
.69592 .20267 .7018 .21378 .71422 .21323 .70838 .20252 Mtetra
.461 .575 .883 r
.70838 .20252 .71422 .21323 .72679 .21372 .721 .20355 Mtetra
.41 .56 .893 r
.721 .20355 .72679 .21372 .73951 .21506 .73379 .20551 Mtetra
.364 .551 .904 r
.73379 .20551 .73951 .21506 .75238 .21698 .74674 .20814 Mtetra
.325 .55 .914 r
.74674 .20814 .75238 .21698 .76539 .21923 .75983 .21113 Mtetra
0 .367 .817 r
.09551 .43462 .10283 .44102 .11182 .44464 .10439 .43906 Mtetra
0 .379 .807 r
.10439 .43906 .11182 .44464 .12091 .44796 .11339 .44317 Mtetra
0 .429 .822 r
.11339 .44317 .12091 .44796 .13016 .45068 .12256 .44661 Mtetra
.007 .514 .863 r
.12256 .44661 .13016 .45068 .13959 .45251 .13193 .44905 Mtetra
.144 .627 .92 r
.13193 .44905 .13959 .45251 .14922 .45318 .14152 .45021 Mtetra
.314 .743 .972 r
.14152 .45021 .14922 .45318 .15906 .45251 .15135 .44985 Mtetra
.483 .834 .996 r
.15135 .44985 .15906 .45251 .16912 .45035 .16142 .44783 Mtetra
.622 .885 .989 r
.16142 .44783 .16912 .45035 .1794 .44664 .17173 .44407 Mtetra
.72 .901 .96 r
.17173 .44407 .1794 .44664 .18987 .44137 .18226 .43857 Mtetra
.781 .895 .924 r
.18226 .43857 .18987 .44137 .20051 .43463 .19299 .43142 Mtetra
.817 .877 .89 r
.19299 .43142 .20051 .43463 .21131 .42656 .20389 .42279 Mtetra
.835 .856 .861 r
.20389 .42279 .21131 .42656 .22222 .41738 .21491 .41291 Mtetra
.843 .833 .837 r
.21491 .41291 .22222 .41738 .23321 .40734 .22602 .40208 Mtetra
.842 .812 .82 r
.22602 .40208 .23321 .40734 .24426 .39675 .23718 .39063 Mtetra
.837 .791 .808 r
.23718 .39063 .24426 .39675 .25532 .38592 .24836 .37892 Mtetra
.826 .771 .8 r
.24836 .37892 .25532 .38592 .26636 .37517 .25952 .36731 Mtetra
.812 .752 .797 r
.25952 .36731 .26636 .37517 .27738 .36483 .27063 .35616 Mtetra
.794 .734 .797 r
.27063 .35616 .27738 .36483 .28833 .35518 .28167 .34579 Mtetra
.772 .716 .8 r
.28167 .34579 .28833 .35518 .29923 .34649 .29264 .3365 Mtetra
.745 .697 .806 r
.29264 .3365 .29923 .34649 .31005 .33898 .30352 .32852 Mtetra
.713 .678 .815 r
.30352 .32852 .31005 .33898 .3208 .33281 .31431 .32204 Mtetra
.674 .658 .826 r
.31431 .32204 .3208 .33281 .33149 .32809 .32502 .31718 Mtetra
.627 .636 .84 r
.32502 .31718 .33149 .32809 .34213 .32486 .33566 .31398 Mtetra
.572 .612 .854 r
.33566 .31398 .34213 .32486 .35273 .32309 .34626 .31242 Mtetra
.507 .586 .868 r
.34626 .31242 .35273 .32309 .36332 .32271 .35684 .31241 Mtetra
.433 .557 .881 r
.35684 .31241 .36332 .32271 .37392 .32357 .36741 .31378 Mtetra
.352 .528 .889 r
.36741 .31378 .37392 .32357 .38454 .32547 .37801 .31632 Mtetra
.269 .499 .893 r
.37801 .31632 .38454 .32547 .39522 .32816 .38866 .31975 Mtetra
.191 .477 .893 r
.38866 .31975 .39522 .32816 .40596 .33137 .39938 .32376 Mtetra
.129 .466 .892 r
.39938 .32376 .40596 .33137 .4168 .33476 .41019 .32798 Mtetra
.093 .473 .893 r
.41019 .32798 .4168 .33476 .42773 .33802 .42111 .33206 Mtetra
.091 .502 .902 r
.42111 .33206 .42773 .33802 .43877 .34081 .43215 .33563 Mtetra
.127 .556 .922 r
.43215 .33563 .43877 .34081 .44993 .34283 .44331 .33833 Mtetra
.203 .63 .949 r
.44331 .33833 .44993 .34283 .46119 .34379 .45459 .33985 Mtetra
.312 .717 .978 r
.45459 .33985 .46119 .34379 .47256 .34346 .46599 .33993 Mtetra
.44 .8 .996 r
.46599 .33993 .47256 .34346 .48402 .34167 .47749 .33837 Mtetra
.565 .864 .996 r
.47749 .33837 .48402 .34167 .49556 .3383 .48907 .33504 Mtetra
.67 .901 .978 r
.48907 .33504 .49556 .3383 .50716 .33332 .50072 .32992 Mtetra
.748 .913 .948 r
.50072 .32992 .50716 .33332 .51881 .32678 .51242 .32304 Mtetra
.8 .908 .915 r
.51242 .32304 .51881 .32678 .53048 .31879 .52415 .31455 Mtetra
.832 .892 .884 r
.52415 .31455 .53048 .31879 .54217 .30954 .53589 .30464 Mtetra
.849 .872 .858 r
.53589 .30464 .54217 .30954 .55386 .29928 .54763 .2936 Mtetra
.854 .85 .837 r
.54763 .2936 .55386 .29928 .56555 .28829 .55936 .28176 Mtetra
.852 .827 .822 r
.55936 .28176 .56555 .28829 .57722 .27688 .57108 .26946 Mtetra
.844 .804 .812 r
.57108 .26946 .57722 .27688 .58889 .2654 .58278 .25708 Mtetra
.83 .782 .806 r
.58278 .25708 .58889 .2654 .60056 .25417 .59447 .24498 Mtetra
.812 .76 .804 r
.59447 .24498 .60056 .25417 .61224 .24351 .60617 .23353 Mtetra
.789 .738 .805 r
.60617 .23353 .61224 .24351 .62395 .23371 .6179 .22304 Mtetra
.762 .716 .809 r
.6179 .22304 .62395 .23371 .6357 .225 .62966 .21378 Mtetra
.73 .693 .815 r
.62966 .21378 .6357 .225 .64752 .21759 .6415 .20596 Mtetra
.693 .671 .824 r
.6415 .20596 .64752 .21759 .65944 .2116 .65343 .19974 Mtetra
.651 .647 .833 r
.65343 .19974 .65944 .2116 .67146 .20712 .66547 .19521 Mtetra
.604 .624 .844 r
.66547 .19521 .67146 .20712 .68362 .20416 .67765 .19236 Mtetra
.552 .6 .855 r
.67765 .19236 .68362 .20416 .69592 .20267 .68998 .19116 Mtetra
.496 .576 .866 r
.68998 .19116 .69592 .20267 .70838 .20252 .70249 .19146 Mtetra
.438 .555 .876 r
.70249 .19146 .70838 .20252 .721 .20355 .71517 .19307 Mtetra
.38 .536 .886 r
.71517 .19307 .721 .20355 .73379 .20551 .72802 .19573 Mtetra
.325 .523 .895 r
.72802 .19573 .73379 .20551 .74674 .20814 .74104 .19915 Mtetra
.279 .518 .904 r
.74104 .19915 .74674 .20814 .75983 .21113 .75422 .20298 Mtetra
0 .271 .739 r
.08813 .42819 .09551 .43462 .10439 .43906 .09689 .43353 Mtetra
0 .279 .719 r
.09689 .43353 .10439 .43906 .11339 .44317 .10578 .43852 Mtetra
0 .33 .733 r
.10578 .43852 .11339 .44317 .12256 .44661 .11486 .44276 Mtetra
0 .427 .784 r
.11486 .44276 .12256 .44661 .13193 .44905 .12415 .44589 Mtetra
.035 .562 .861 r
.12415 .44589 .13193 .44905 .14152 .45021 .1337 .44758 Mtetra
.236 .709 .94 r
.1337 .44758 .14152 .45021 .15135 .44985 .14351 .44759 Mtetra
.443 .829 .986 r
.14351 .44759 .15135 .44985 .16142 .44783 .15359 .44573 Mtetra
.611 .896 .988 r
.15359 .44573 .16142 .44783 .17173 .44407 .16394 .44192 Mtetra
.725 .915 .959 r
.16394 .44192 .17173 .44407 .18226 .43857 .17454 .43616 Mtetra
.793 .907 .92 r
.17454 .43616 .18226 .43857 .19299 .43142 .18536 .42856 Mtetra
.83 .886 .882 r
.18536 .42856 .19299 .43142 .20389 .42279 .19636 .4193 Mtetra
.849 .861 .851 r
.19636 .4193 .20389 .42279 .21491 .41291 .20751 .40865 Mtetra
.855 .837 .827 r
.20751 .40865 .21491 .41291 .22602 .40208 .21875 .39694 Mtetra
.854 .813 .809 r
.21875 .39694 .22602 .40208 .23718 .39063 .23005 .38454 Mtetra
.847 .791 .797 r
.23005 .38454 .23718 .39063 .24836 .37892 .24135 .37185 Mtetra
.836 .77 .789 r
.24135 .37185 .24836 .37892 .25952 .36731 .25263 .35929 Mtetra
.821 .75 .786 r
.25263 .35929 .25952 .36731 .27063 .35616 .26386 .34724 Mtetra
.801 .731 .786 r
.26386 .34724 .27063 .35616 .28167 .34579 .275 .33608 Mtetra
.778 .712 .79 r
.275 .33608 .28167 .34579 .29264 .3365 .28604 .32612 Mtetra
.75 .693 .797 r
.28604 .32612 .29264 .3365 .30352 .32852 .29697 .31763 Mtetra
.716 .672 .806 r
.29697 .31763 .30352 .32852 .31431 .32204 .30781 .31081 Mtetra
.674 .65 .818 r
.30781 .31081 .31431 .32204 .32502 .31718 .31854 .3058 Mtetra
.624 .626 .832 r
.31854 .3058 .32502 .31718 .33566 .31398 .32919 .30263 Mtetra
.563 .599 .847 r
.32919 .30263 .33566 .31398 .34626 .31242 .33978 .3013 Mtetra
.49 .568 .861 r
.33978 .3013 .34626 .31242 .35684 .31241 .35034 .3017 Mtetra
.405 .533 .873 r
.35034 .3017 .35684 .31241 .36741 .31378 .36089 .30365 Mtetra
.31 .495 .878 r
.36089 .30365 .36741 .31378 .37801 .31632 .37145 .3069 Mtetra
.211 .458 .877 r
.37145 .3069 .37801 .31632 .38866 .31975 .38207 .31115 Mtetra
.118 .426 .869 r
.38207 .31115 .38866 .31975 .39938 .32376 .39275 .31605 Mtetra
.043 .407 .859 r
.39275 .31605 .39938 .32376 .41019 .32798 .40354 .3212 Mtetra
0 .409 .853 r
.40354 .3212 .41019 .32798 .42111 .33206 .41444 .32619 Mtetra
0 .437 .859 r
.41444 .32619 .42111 .33206 .43215 .33563 .42547 .33062 Mtetra
.028 .495 .88 r
.42547 .33062 .43215 .33563 .44331 .33833 .43663 .33409 Mtetra
.113 .582 .915 r
.43663 .33409 .44331 .33833 .45459 .33985 .44792 .33624 Mtetra
.24 .686 .955 r
.44792 .33624 .45459 .33985 .46599 .33993 .45934 .33678 Mtetra
.392 .79 .986 r
.45934 .33678 .46599 .33993 .47749 .33837 .47088 .33548 Mtetra
.543 .869 .994 r
.47088 .33548 .47749 .33837 .48907 .33504 .48251 .33221 Mtetra
.667 .914 .977 r
.48251 .33221 .48907 .33504 .50072 .32992 .49421 .32692 Mtetra
.756 .928 .945 r
.49421 .32692 .50072 .32992 .51242 .32304 .50597 .31967 Mtetra
.814 .92 .908 r
.50597 .31967 .51242 .32304 .52415 .31455 .51776 .31061 Mtetra
.847 .902 .875 r
.51776 .31061 .52415 .31455 .53589 .30464 .52956 .29998 Mtetra
.864 .879 .847 r
.52956 .29998 .53589 .30464 .54763 .2936 .54135 .28808 Mtetra
.869 .854 .825 r
.54135 .28808 .54763 .2936 .55936 .28176 .55313 .27529 Mtetra
.865 .829 .81 r
.55313 .27529 .55936 .28176 .57108 .26946 .56488 .26199 Mtetra
.856 .805 .8 r
.56488 .26199 .57108 .26946 .58278 .25708 .57662 .24862 Mtetra
.841 .781 .794 r
.57662 .24862 .58278 .25708 .59447 .24498 .58834 .23557 Mtetra
.822 .758 .793 r
.58834 .23557 .59447 .24498 .60617 .23353 .60006 .22325 Mtetra
.798 .735 .794 r
.60006 .22325 .60617 .23353 .6179 .22304 .6118 .212 Mtetra
.769 .712 .799 r
.6118 .212 .6179 .22304 .62966 .21378 .62358 .20212 Mtetra
.735 .688 .806 r
.62358 .20212 .62966 .21378 .6415 .20596 .63543 .19387 Mtetra
.695 .664 .815 r
.63543 .19387 .6415 .20596 .65343 .19974 .64737 .18739 Mtetra
.65 .639 .826 r
.64737 .18739 .65343 .19974 .66547 .19521 .65943 .18279 Mtetra
.598 .612 .837 r
.65943 .18279 .66547 .19521 .67765 .19236 .67163 .18009 Mtetra
.541 .585 .848 r
.67163 .18009 .67765 .19236 .68998 .19116 .684 .1792 Mtetra
.478 .558 .859 r
.684 .1792 .68998 .19116 .70249 .19146 .69654 .18 Mtetra
.412 .532 .868 r
.69654 .18 .70249 .19146 .71517 .19307 .70928 .18226 Mtetra
.346 .509 .876 r
.70928 .18226 .71517 .19307 .72802 .19573 .7222 .18571 Mtetra
.282 .491 .883 r
.7222 .18571 .72802 .19573 .74104 .19915 .7353 .19 Mtetra
.227 .482 .89 r
.7353 .19 .74104 .19915 .75422 .20298 .74857 .19475 Mtetra
0 .162 .639 r
.0807 .4217 .08813 .42819 .09689 .43353 .08932 .42806 Mtetra
0 .166 .609 r
.08932 .42806 .09689 .43353 .10578 .43852 .09808 .43402 Mtetra
0 .217 .62 r
.09808 .43402 .10578 .43852 .11486 .44276 .10705 .43916 Mtetra
0 .321 .678 r
.10705 .43916 .11486 .44276 .12415 .44589 .11626 .44306 Mtetra
0 .476 .777 r
.11626 .44306 .12415 .44589 .1337 .44758 .12575 .44536 Mtetra
.14 .658 .889 r
.12575 .44536 .1337 .44758 .14351 .44759 .13553 .44577 Mtetra
.39 .816 .967 r
.13553 .44577 .14351 .44759 .15359 .44573 .14563 .44409 Mtetra
.596 .905 .983 r
.14563 .44409 .15359 .44573 .16394 .44192 .15602 .44023 Mtetra
.73 .93 .956 r
.15602 .44023 .16394 .44192 .17454 .43616 .16669 .43419 Mtetra
.805 .919 .914 r
.16669 .43419 .17454 .43616 .18536 .42856 .17761 .42608 Mtetra
.844 .894 .874 r
.17761 .42608 .18536 .42856 .19636 .4193 .18873 .41612 Mtetra
.862 .866 .841 r
.18873 .41612 .19636 .4193 .20751 .40865 .20001 .40461 Mtetra
.867 .839 .816 r
.20001 .40461 .20751 .40865 .21875 .39694 .2114 .39192 Mtetra
.865 .814 .798 r
.2114 .39192 .21875 .39694 .23005 .38454 .22285 .37847 Mtetra
.857 .791 .785 r
.22285 .37847 .23005 .38454 .24135 .37185 .2343 .36471 Mtetra
.845 .769 .778 r
.2343 .36471 .24135 .37185 .25263 .35929 .24571 .35109 Mtetra
.829 .748 .775 r
.24571 .35109 .25263 .35929 .26386 .34724 .25706 .33805 Mtetra
.809 .728 .776 r
.25706 .33805 .26386 .34724 .275 .33608 .2683 .32601 Mtetra
.784 .708 .78 r
.2683 .32601 .275 .33608 .28604 .32612 .27943 .31531 Mtetra
.755 .688 .787 r
.27943 .31531 .28604 .32612 .29697 .31763 .29043 .30626 Mtetra
.719 .666 .797 r
.29043 .30626 .29697 .31763 .30781 .31081 .30131 .29907 Mtetra
.674 .642 .81 r
.30131 .29907 .30781 .31081 .31854 .3058 .31206 .29389 Mtetra
.62 .615 .825 r
.31206 .29389 .31854 .3058 .32919 .30263 .32272 .29077 Mtetra
.553 .584 .84 r
.32272 .29077 .32919 .30263 .33978 .3013 .3333 .2897 Mtetra
.471 .548 .853 r
.3333 .2897 .33978 .3013 .35034 .3017 .34383 .29055 Mtetra
.373 .506 .863 r
.34383 .29055 .35034 .3017 .36089 .30365 .35434 .29313 Mtetra
.263 .458 .864 r
.35434 .29313 .36089 .30365 .37145 .3069 .36486 .29717 Mtetra
.146 .41 .855 r
.36486 .29717 .37145 .3069 .38207 .31115 .37543 .30234 Mtetra
.036 .367 .836 r
.37543 .30234 .38207 .31115 .39275 .31605 .38608 .30823 Mtetra
0 .338 .815 r
.38608 .30823 .39275 .31605 .40354 .3212 .39683 .31441 Mtetra
0 .332 .799 r
.39683 .31441 .40354 .3212 .41444 .32619 .4077 .32043 Mtetra
0 .358 .798 r
.4077 .32043 .41444 .32619 .42547 .33062 .41871 .32582 Mtetra
0 .42 .819 r
.41871 .32582 .42547 .33062 .43663 .33409 .42987 .33014 Mtetra
.008 .517 .863 r
.42987 .33014 .43663 .33409 .44792 .33624 .44117 .333 Mtetra
.153 .642 .918 r
.44117 .333 .44792 .33624 .45934 .33678 .45262 .33406 Mtetra
.333 .771 .966 r
.45262 .33406 .45934 .33678 .47088 .33548 .46419 .33305 Mtetra
.514 .871 .986 r
.46419 .33305 .47088 .33548 .48251 .33221 .47587 .32984 Mtetra
.662 .927 .973 r
.47587 .32984 .48251 .33221 .49421 .32692 .48763 .32438 Mtetra
.764 .943 .939 r
.48763 .32438 .49421 .32692 .50597 .31967 .49945 .31672 Mtetra
.827 .933 .9 r
.49945 .31672 .50597 .31967 .51776 .31061 .5113 .30703 Mtetra
.862 .911 .864 r
.5113 .30703 .51776 .31061 .52956 .29998 .52316 .29559 Mtetra
.879 .885 .834 r
.52316 .29559 .52956 .29998 .54135 .28808 .53501 .28274 Mtetra
.883 .858 .812 r
.53501 .28274 .54135 .28808 .55313 .27529 .54684 .26889 Mtetra
.878 .831 .797 r
.54684 .26889 .55313 .27529 .56488 .26199 .55864 .2545 Mtetra
.868 .806 .787 r
.55864 .2545 .56488 .26199 .57662 .24862 .57041 .24002 Mtetra
.852 .781 .782 r
.57041 .24002 .57662 .24862 .58834 .23557 .58216 .22592 Mtetra
.831 .757 .781 r
.58216 .22592 .58834 .23557 .60006 .22325 .5939 .21263 Mtetra
.806 .732 .783 r
.5939 .21263 .60006 .22325 .6118 .212 .60566 .20055 Mtetra
.775 .708 .789 r
.60566 .20055 .6118 .212 .62358 .20212 .61745 .19 Mtetra
.739 .683 .797 r
.61745 .19 .62358 .20212 .63543 .19387 .62931 .18126 Mtetra
.697 .657 .806 r
.62931 .18126 .63543 .19387 .64737 .18739 .64126 .17451 Mtetra
.648 .629 .817 r
.64126 .17451 .64737 .18739 .65943 .18279 .65333 .16984 Mtetra
.592 .6 .829 r
.65333 .16984 .65943 .18279 .67163 .18009 .66556 .16728 Mtetra
.529 .57 .84 r
.66556 .16728 .67163 .18009 .684 .1792 .67795 .16676 Mtetra
.459 .538 .851 r
.67795 .16676 .684 .1792 .69654 .18 .69054 .16811 Mtetra
.384 .507 .859 r
.69054 .16811 .69654 .18 .70928 .18226 .70333 .1711 Mtetra
.308 .478 .865 r
.70333 .1711 .70928 .18226 .7222 .18571 .71632 .17541 Mtetra
.234 .454 .869 r
.71632 .17541 .7222 .18571 .7353 .19 .72951 .18068 Mtetra
.169 .44 .872 r
.72951 .18068 .7353 .19 .74857 .19475 .74288 .18646 Mtetra
.474 0 0 r
.07322 .41517 .0807 .4217 .08932 .42806 .08167 .42265 Mtetra
.501 0 0 r
.08167 .42265 .08932 .42806 .09808 .43402 .09029 .42971 Mtetra
.472 0 0 r
.09029 .42971 .09808 .43402 .10705 .43916 .09912 .43585 Mtetra
.384 0 0 r
.09912 .43585 .10705 .43916 .11626 .44306 .10823 .44061 Mtetra
.22 0 0 r
.10823 .44061 .11626 .44306 .12575 .44536 .11766 .44359 Mtetra
.029 .587 .812 r
.11766 .44359 .12575 .44536 .13553 .44577 .12741 .44446 Mtetra
.324 .791 .932 r
.12741 .44446 .13553 .44577 .14563 .44409 .13751 .44299 Mtetra
.575 .911 .973 r
.13751 .44299 .14563 .44409 .15602 .44023 .14795 .43907 Mtetra
.734 .944 .951 r
.14795 .43907 .15602 .44023 .16669 .43419 .1587 .43271 Mtetra
.818 .931 .907 r
.1587 .43271 .16669 .43419 .17761 .42608 .16973 .42405 Mtetra
.858 .903 .864 r
.16973 .42405 .17761 .42608 .18873 .41612 .18099 .41331 Mtetra
.875 .871 .829 r
.18099 .41331 .18873 .41612 .20001 .40461 .19242 .40084 Mtetra
.879 .842 .804 r
.19242 .40084 .20001 .40461 .2114 .39192 .20397 .38706 Mtetra
.876 .814 .785 r
.20397 .38706 .2114 .39192 .22285 .37847 .21558 .37244 Mtetra
.867 .79 .773 r
.21558 .37244 .22285 .37847 .2343 .36471 .22719 .35748 Mtetra
.853 .767 .766 r
.22719 .35748 .2343 .36471 .24571 .35109 .23876 .34269 Mtetra
.837 .746 .763 r
.23876 .34269 .24571 .35109 .25706 .33805 .25024 .32856 Mtetra
.816 .725 .764 r
.25024 .32856 .25706 .33805 .2683 .32601 .2616 .31554 Mtetra
.79 .704 .769 r
.2616 .31554 .2683 .32601 .27943 .31531 .27283 .30404 Mtetra
.759 .682 .777 r
.27283 .30404 .27943 .31531 .29043 .30626 .2839 .29436 Mtetra
.721 .659 .788 r
.2839 .29436 .29043 .30626 .30131 .29907 .29482 .28677 Mtetra
.674 .633 .801 r
.29482 .28677 .30131 .29907 .31206 .29389 .3056 .28141 Mtetra
.615 .604 .816 r
.3056 .28141 .31206 .29389 .32272 .29077 .31625 .27835 Mtetra
.542 .569 .831 r
.31625 .27835 .32272 .29077 .3333 .2897 .32681 .27756 Mtetra
.45 .526 .844 r
.32681 .27756 .3333 .2897 .34383 .29055 .33731 .27891 Mtetra
.338 .475 .851 r
.33731 .27891 .34383 .29055 .35434 .29313 .34778 .2822 Mtetra
.209 .416 .845 r
.34778 .2822 .35434 .29313 .36486 .29717 .35825 .28712 Mtetra
.073 .354 .826 r
.35825 .28712 .36486 .29717 .37543 .30234 .36876 .2933 Mtetra
0 .298 .794 r
.36876 .2933 .37543 .30234 .38608 .30823 .37936 .30029 Mtetra
0 .258 .757 r
.37936 .30029 .38608 .30823 .39683 .31441 .39006 .30763 Mtetra
0 .245 .729 r
.39006 .30763 .39683 .31441 .4077 .32043 .40089 .31479 Mtetra
0 .267 .72 r
.40089 .31479 .4077 .32043 .41871 .32582 .41188 .32125 Mtetra
0 .33 .739 r
.41188 .32125 .41871 .32582 .42987 .33014 .42303 .32654 Mtetra
0 .437 .789 r
.42303 .32654 .42987 .33014 .44117 .333 .43434 .33018 Mtetra
.05 .582 .861 r
.43434 .33018 .44117 .333 .45262 .33406 .44581 .33182 Mtetra
.259 .739 .932 r
.44581 .33182 .45262 .33406 .46419 .33305 .45741 .33116 Mtetra
.476 .868 .97 r
.45741 .33116 .46419 .33305 .47587 .32984 .46914 .32802 Mtetra
.653 .939 .965 r
.46914 .32802 .47587 .32984 .48763 .32438 .48096 .32236 Mtetra
.772 .958 .931 r
.48096 .32236 .48763 .32438 .49945 .31672 .49284 .31424 Mtetra
.841 .946 .889 r
.49284 .31424 .49945 .31672 .5113 .30703 .50476 .30386 Mtetra
.878 .92 .851 r
.50476 .30386 .5113 .30703 .52316 .29559 .51669 .29152 Mtetra
.893 .891 .82 r
.51669 .29152 .52316 .29559 .53501 .28274 .52861 .27761 Mtetra
.896 .861 .798 r
.52861 .27761 .53501 .28274 .54684 .26889 .5405 .26259 Mtetra
.891 .833 .782 r
.5405 .26259 .54684 .26889 .55864 .2545 .55235 .24697 Mtetra
.879 .806 .773 r
.55235 .24697 .55864 .2545 .57041 .24002 .56416 .23127 Mtetra
.862 .78 .769 r
.56416 .23127 .57041 .24002 .58216 .22592 .57594 .216 Mtetra
.84 .754 .768 r
.57594 .216 .58216 .22592 .5939 .21263 .5877 .20165 Mtetra
.813 .729 .772 r
.5877 .20165 .5939 .21263 .60566 .20055 .59948 .18864 Mtetra
.781 .704 .778 r
.59948 .18864 .60566 .20055 .61745 .19 .61128 .17736 Mtetra
.743 .677 .787 r
.61128 .17736 .61745 .19 .62931 .18126 .62314 .16809 Mtetra
.699 .649 .797 r
.62314 .16809 .62931 .18126 .64126 .17451 .6351 .16103 Mtetra
.646 .619 .809 r
.6351 .16103 .64126 .17451 .65333 .16984 .64719 .1563 Mtetra
.585 .587 .821 r
.64719 .1563 .65333 .16984 .66556 .16728 .65943 .15391 Mtetra
.516 .553 .832 r
.65943 .15391 .66556 .16728 .67795 .16676 .67186 .15378 Mtetra
.438 .516 .841 r
.67186 .15378 .67795 .16676 .69054 .16811 .68449 .15575 Mtetra
.354 .479 .848 r
.68449 .15575 .69054 .16811 .70333 .1711 .69733 .15954 Mtetra
.266 .444 .851 r
.69733 .15954 .70333 .1711 .71632 .17541 .71039 .16482 Mtetra
.181 .414 .85 r
.71039 .16482 .71632 .17541 .72951 .18068 .72367 .17116 Mtetra
.105 .392 .848 r
.72367 .17116 .72951 .18068 .74288 .18646 .73713 .1781 Mtetra
.589 .067 0 r
.06568 .40859 .07322 .41517 .08167 .42265 .07395 .41733 Mtetra
.61 .065 0 r
.07395 .41733 .08167 .42265 .09029 .42971 .08239 .42561 Mtetra
.582 .016 0 r
.08239 .42561 .09029 .42971 .09912 .43585 .09108 .43288 Mtetra
.5 0 0 r
.09108 .43288 .09912 .43585 .10823 .44061 .10007 .4386 Mtetra
.346 0 0 r
.10007 .4386 .10823 .44061 .11766 .44359 .10941 .44234 Mtetra
0 .496 .709 r
.10941 .44234 .11766 .44359 .12741 .44446 .11913 .44372 Mtetra
.243 .751 .878 r
.11913 .44372 .12741 .44446 .13751 .44299 .12924 .44248 Mtetra
.547 .913 .955 r
.12924 .44248 .13751 .44299 .14795 .43907 .13972 .43851 Mtetra
.737 .958 .942 r
.13972 .43851 .14795 .43907 .1587 .43271 .15056 .4318 Mtetra
.831 .944 .897 r
.15056 .4318 .1587 .43271 .16973 .42405 .16171 .42251 Mtetra
.873 .91 .853 r
.16171 .42251 .16973 .42405 .18099 .41331 .17312 .41091 Mtetra
.889 .876 .817 r
.17312 .41091 .18099 .41331 .19242 .40084 .18472 .39737 Mtetra
.891 .843 .791 r
.18472 .39737 .19242 .40084 .20397 .38706 .19645 .38238 Mtetra
.886 .815 .773 r
.19645 .38238 .20397 .38706 .21558 .37244 .20825 .36646 Mtetra
.876 .789 .761 r
.20825 .36646 .21558 .37244 .22719 .35748 .22004 .35017 Mtetra
.862 .765 .754 r
.22004 .35017 .22719 .35748 .23876 .34269 .23178 .33408 Mtetra
.844 .743 .752 r
.23178 .33408 .23876 .34269 .25024 .32856 .24341 .31874 Mtetra
.823 .721 .753 r
.24341 .31874 .25024 .32856 .2616 .31554 .2549 .30465 Mtetra
.796 .699 .758 r
.2549 .30465 .2616 .31554 .27283 .30404 .26622 .29225 Mtetra
.764 .677 .766 r
.26622 .29225 .27283 .30404 .2839 .29436 .27737 .28189 Mtetra
.724 .652 .778 r
.27737 .28189 .2839 .29436 .29482 .28677 .28834 .27385 Mtetra
.674 .624 .791 r
.28834 .27385 .29482 .28677 .3056 .28141 .29914 .26829 Mtetra
.611 .592 .807 r
.29914 .26829 .3056 .28141 .31625 .27835 .3098 .2653 Mtetra
.53 .552 .822 r
.3098 .2653 .31625 .27835 .32681 .27756 .32034 .26483 Mtetra
.427 .502 .834 r
.32034 .26483 .32681 .27756 .33731 .27891 .33079 .26674 Mtetra
.299 .441 .836 r
.33079 .26674 .33731 .27891 .34778 .2822 .3412 .27081 Mtetra
.15 .368 .822 r
.3412 .27081 .34778 .2822 .35825 .28712 .35161 .27671 Mtetra
0 .291 .789 r
.35161 .27671 .35825 .28712 .36876 .2933 .36206 .28401 Mtetra
0 .22 .739 r
.36206 .28401 .36876 .2933 .37936 .30029 .37259 .29224 Mtetra
0 .169 .686 r
.37259 .29224 .37936 .30029 .39006 .30763 .38323 .30085 Mtetra
0 .148 .643 r
.38323 .30085 .39006 .30763 .40089 .31479 .39402 .30928 Mtetra
0 .167 .625 r
.39402 .30928 .40089 .31479 .41188 .32125 .40497 .31696 Mtetra
0 .229 .64 r
.40497 .31696 .41188 .32125 .42303 .32654 .4161 .32331 Mtetra
0 .341 .694 r
.4161 .32331 .42303 .32654 .43434 .33018 .42742 .32785 Mtetra
0 .503 .781 r
.42742 .32785 .43434 .33018 .44581 .33182 .4389 .33014 Mtetra
.17 .692 .878 r
.4389 .33014 .44581 .33182 .45741 .33116 .45055 .32986 Mtetra
.427 .856 .942 r
.45055 .32986 .45741 .33116 .46914 .32802 .46232 .32681 Mtetra
.64 .948 .95 r
.46232 .32681 .46914 .32802 .48096 .32236 .47421 .32093 Mtetra
.778 .972 .918 r
.47421 .32093 .48096 .32236 .49284 .31424 .48616 .3123 Mtetra
.855 .958 .875 r
.48616 .3123 .49284 .31424 .50476 .30386 .49815 .30115 Mtetra
.893 .929 .835 r
.49815 .30115 .50476 .30386 .51669 .29152 .51016 .2878 Mtetra
.908 .896 .804 r
.51016 .2878 .51669 .29152 .52861 .27761 .52214 .27271 Mtetra
.91 .864 .782 r
.52214 .27271 .52861 .27761 .5405 .26259 .5341 .25639 Mtetra
.903 .834 .767 r
.5341 .25639 .5405 .26259 .55235 .24697 .546 .23941 Mtetra
.89 .805 .758 r
.546 .23941 .55235 .24697 .56416 .23127 .55786 .22235 Mtetra
.872 .778 .755 r
.55786 .22235 .56416 .23127 .57594 .216 .56967 .20579 Mtetra
.849 .752 .755 r
.56967 .20579 .57594 .216 .5877 .20165 .58146 .19027 Mtetra
.821 .726 .759 r
.58146 .19027 .5877 .20165 .59948 .18864 .59325 .17625 Mtetra
.788 .699 .766 r
.59325 .17625 .59948 .18864 .61128 .17736 .60506 .16415 Mtetra
.748 .671 .776 r
.60506 .16415 .61128 .17736 .62314 .16809 .61693 .1543 Mtetra
.7 .641 .787 r
.61693 .1543 .62314 .16809 .6351 .16103 .6289 .14691 Mtetra
.644 .609 .799 r
.6289 .14691 .6351 .16103 .64719 .1563 .641 .1421 Mtetra
.578 .573 .812 r
.641 .1421 .64719 .1563 .65943 .15391 .65326 .1399 Mtetra
.502 .535 .823 r
.65326 .1399 .65943 .15391 .67186 .15378 .66571 .14022 Mtetra
.416 .493 .831 r
.66571 .14022 .67186 .15378 .68449 .15575 .67838 .14287 Mtetra
.321 .449 .835 r
.67838 .14287 .68449 .15575 .69733 .15954 .69127 .14756 Mtetra
.221 .406 .834 r
.69127 .14756 .69733 .15954 .71039 .16482 .70441 .1539 Mtetra
.123 .368 .828 r
.70441 .1539 .71039 .16482 .72367 .17116 .71777 .16145 Mtetra
.034 .339 .819 r
.71777 .16145 .72367 .17116 .73713 .1781 .73134 .16968 Mtetra
.684 .171 0 r
.05808 .40196 .06568 .40859 .07395 .41733 .06614 .41211 Mtetra
.697 .166 0 r
.06614 .41211 .07395 .41733 .08239 .42561 .07438 .42175 Mtetra
.669 .12 0 r
.07438 .42175 .08239 .42561 .09108 .43288 .0829 .43027 Mtetra
.597 .024 0 r
.0829 .43027 .09108 .43288 .10007 .4386 .09176 .43709 Mtetra
.459 0 0 r
.09176 .43709 .10007 .4386 .10941 .44234 .101 .44168 Mtetra
.216 0 0 r
.101 .44168 .10941 .44234 .11913 .44372 .11067 .44363 Mtetra
.147 .69 .8 r
.11067 .44363 .11913 .44372 .12924 .44248 .12078 .44266 Mtetra
.51 .906 .926 r
.12078 .44266 .12924 .44248 .13972 .43851 .13131 .43862 Mtetra
.738 .971 .93 r
.13131 .43862 .13972 .43851 .15056 .4318 .14225 .43153 Mtetra
.843 .955 .886 r
.14225 .43153 .15056 .4318 .16171 .42251 .15353 .42154 Mtetra
.887 .918 .84 r
.15353 .42154 .16171 .42251 .17312 .41091 .16511 .40897 Mtetra
.902 .879 .803 r
.16511 .40897 .17312 .41091 .18472 .39737 .1769 .39425 Mtetra
.902 .845 .777 r
.1769 .39425 .18472 .39737 .19645 .38238 .18884 .3779 Mtetra
.896 .814 .759 r
.18884 .3779 .19645 .38238 .20825 .36646 .20084 .36053 Mtetra
.885 .787 .748 r
.20084 .36053 .20825 .36646 .22004 .35017 .21284 .34277 Mtetra
.87 .763 .742 r
.21284 .34277 .22004 .35017 .23178 .33408 .22476 .32524 Mtetra
.851 .74 .74 r
.22476 .32524 .23178 .33408 .24341 .31874 .23656 .30856 Mtetra
.829 .717 .742 r
.23656 .30856 .24341 .31874 .2549 .30465 .2482 .29329 Mtetra
.802 .695 .747 r
.2482 .29329 .2549 .30465 .26622 .29225 .25964 .2799 Mtetra
.768 .671 .756 r
.25964 .2799 .26622 .29225 .27737 .28189 .27087 .26879 Mtetra
.727 .645 .767 r
.27087 .26879 .27737 .28189 .28834 .27385 .28189 .26025 Mtetra
.674 .615 .781 r
.28189 .26025 .28834 .27385 .29914 .26829 .29272 .25449 Mtetra
.606 .579 .797 r
.29272 .25449 .29914 .26829 .3098 .2653 .30337 .25156 Mtetra
.517 .534 .812 r
.30337 .25156 .3098 .2653 .32034 .26483 .31387 .25144 Mtetra
.402 .476 .822 r
.31387 .25144 .32034 .26483 .33079 .26674 .32428 .25399 Mtetra
.256 .403 .818 r
.32428 .25399 .33079 .26674 .3412 .27081 .33462 .25892 Mtetra
.085 .315 .793 r
.33462 .25892 .3412 .27081 .35161 .27671 .34496 .2659 Mtetra
0 .22 .743 r
.34496 .2659 .35161 .27671 .36206 .28401 .35532 .27445 Mtetra
0 .135 .673 r
.35532 .27445 .36206 .28401 .37259 .29224 .36577 .28405 Mtetra
0 .074 .602 r
.36577 .28405 .37259 .29224 .38323 .30085 .37634 .29409 Mtetra
0 .048 .546 r
.37634 .29409 .38323 .30085 .39402 .30928 .38707 .30395 Mtetra
.474 0 0 r
.38707 .30395 .39402 .30928 .40497 .31696 .39798 .31297 Mtetra
.443 0 0 r
.39798 .31297 .40497 .31696 .4161 .32331 .40909 .32053 Mtetra
.352 0 0 r
.40909 .32053 .4161 .32331 .42742 .32785 .42039 .32607 Mtetra
.184 0 0 r
.42039 .32607 .42742 .32785 .4389 .33014 .4319 .32909 Mtetra
.068 .626 .801 r
.4319 .32909 .4389 .33014 .45055 .32986 .44358 .32924 Mtetra
.366 .831 .898 r
.44358 .32924 .45055 .32986 .46232 .32681 .45541 .32629 Mtetra
.621 .952 .927 r
.45541 .32629 .46232 .32681 .47421 .32093 .46736 .32017 Mtetra
.782 .984 .901 r
.46736 .32017 .47421 .32093 .48616 .3123 .47939 .31098 Mtetra
.868 .968 .858 r
.47939 .31098 .48616 .3123 .49815 .30115 .49146 .29896 Mtetra
.907 .936 .818 r
.49146 .29896 .49815 .30115 .51016 .2878 .50355 .28449 Mtetra
.922 .9 .787 r
.50355 .28449 .51016 .2878 .52214 .27271 .51562 .26808 Mtetra
.923 .866 .765 r
.51562 .26808 .52214 .27271 .5341 .25639 .52764 .25032 Mtetra
.915 .834 .751 r
.52764 .25032 .5341 .25639 .546 .23941 .5396 .23183 Mtetra
.901 .804 .743 r
.5396 .23183 .546 .23941 .55786 .22235 .55151 .21327 Mtetra
.882 .776 .74 r
.55151 .21327 .55786 .22235 .56967 .20579 .56336 .19528 Mtetra
.858 .749 .742 r
.56336 .19528 .56967 .20579 .58146 .19027 .57518 .17845 Mtetra
.829 .722 .747 r
.57518 .17845 .58146 .19027 .59325 .17625 .58698 .16332 Mtetra
.794 .694 .755 r
.58698 .16332 .59325 .17625 .60506 .16415 .5988 .15033 Mtetra
.752 .665 .765 r
.5988 .15033 .60506 .16415 .61693 .1543 .61068 .13983 Mtetra
.701 .633 .777 r
.61068 .13983 .61693 .1543 .6289 .14691 .62265 .13208 Mtetra
.642 .598 .79 r
.62265 .13208 .6289 .14691 .641 .1421 .63475 .1272 Mtetra
.57 .559 .802 r
.63475 .1272 .641 .1421 .65326 .1399 .64703 .12521 Mtetra
.487 .515 .812 r
.64703 .12521 .65326 .1399 .66571 .14022 .6595 .12602 Mtetra
.391 .468 .819 r
.6595 .12602 .66571 .14022 .67838 .14287 .67221 .12943 Mtetra
.285 .417 .82 r
.67221 .12943 .67838 .14287 .69127 .14756 .68516 .1351 Mtetra
.172 .365 .813 r
.68516 .1351 .69127 .14756 .70441 .1539 .69837 .14264 Mtetra
.06 .317 .8 r
.69837 .14264 .70441 .1539 .71777 .16145 .71182 .15152 Mtetra
0 .28 .783 r
.71182 .15152 .71777 .16145 .73134 .16968 .7255 .16118 Mtetra
.758 .261 0 r
.05043 .39529 .05808 .40196 .06614 .41211 .05824 .407 Mtetra
.763 .253 0 r
.05824 .407 .06614 .41211 .07438 .42175 .06626 .41817 Mtetra
.735 .208 0 r
.06626 .41817 .07438 .42175 .0829 .43027 .07458 .4281 Mtetra
.671 .121 0 r
.07458 .4281 .0829 .43027 .09176 .43709 .08327 .43613 Mtetra
.551 0 0 r
.08327 .43613 .09176 .43709 .101 .44168 .09241 .44168 Mtetra
.329 0 0 r
.09241 .44168 .101 .44168 .11067 .44363 .10202 .44429 Mtetra
0 0 0 r
.10202 .44429 .11067 .44363 .12078 .44266 .11212 .44362 Mtetra
.462 .889 .881 r
.11212 .44362 .12078 .44266 .13131 .43862 .12271 .43951 Mtetra
.735 .981 .911 r
.12271 .43951 .13131 .43862 .14225 .43153 .13375 .43198 Mtetra
.855 .966 .871 r
.13375 .43198 .14225 .43153 .15353 .42154 .14519 .42122 Mtetra
.9 .924 .825 r
.14519 .42122 .15353 .42154 .16511 .40897 .15695 .40756 Mtetra
.914 .882 .789 r
.15695 .40756 .16511 .40897 .1769 .39425 .16896 .39151 Mtetra
.913 .845 .763 r
.16896 .39151 .1769 .39425 .18884 .3779 .18113 .37366 Mtetra
.905 .813 .746 r
.18113 .37366 .18884 .3779 .20084 .36053 .19336 .35468 Mtetra
.893 .785 .735 r
.19336 .35468 .20084 .36053 .21284 .34277 .20559 .33527 Mtetra
.877 .76 .729 r
.20559 .33527 .21284 .34277 .22476 .32524 .21773 .31615 Mtetra
.858 .736 .728 r
.21773 .31615 .22476 .32524 .23656 .30856 .22971 .29799 Mtetra
.835 .713 .73 r
.22971 .29799 .23656 .30856 .2482 .29329 .24151 .28141 Mtetra
.807 .69 .736 r
.24151 .28141 .2482 .29329 .25964 .2799 .25307 .26693 Mtetra
.772 .665 .745 r
.25307 .26693 .25964 .2799 .27087 .26879 .2644 .25499 Mtetra
.729 .638 .757 r
.2644 .25499 .27087 .26879 .28189 .26025 .27548 .24591 Mtetra
.673 .605 .771 r
.27548 .24591 .28189 .26025 .29272 .25449 .28632 .23992 Mtetra
.6 .565 .787 r
.28632 .23992 .29272 .25449 .30337 .25156 .29697 .23708 Mtetra
.503 .514 .801 r
.29697 .23708 .30337 .25156 .31387 .25144 .30744 .23735 Mtetra
.374 .447 .808 r
.30744 .23735 .31387 .25144 .32428 .25399 .31778 .24058 Mtetra
.209 .36 .797 r
.31778 .24058 .32428 .25399 .33462 .25892 .32805 .24648 Mtetra
.014 .255 .758 r
.32805 .24648 .33462 .25892 .34496 .2659 .33829 .25466 Mtetra
0 .143 .688 r
.33829 .25466 .34496 .2659 .35532 .27445 .34856 .2646 Mtetra
0 .045 .597 r
.34856 .2646 .35532 .27445 .36577 .28405 .35891 .27572 Mtetra
0 0 .509 r
.35891 .27572 .36577 .28405 .37634 .29409 .3694 .28736 Mtetra
.555 .05 0 r
.3694 .28736 .37634 .29409 .38707 .30395 .38005 .29881 Mtetra
.575 .037 0 r
.38005 .29881 .38707 .30395 .39798 .31297 .3909 .30934 Mtetra
.547 0 0 r
.3909 .30934 .39798 .31297 .40909 .32053 .40197 .31825 Mtetra
.462 0 0 r
.40197 .31825 .40909 .32053 .42039 .32607 .41327 .32491 Mtetra
.302 0 0 r
.41327 .32491 .42039 .32607 .4319 .32909 .42478 .32876 Mtetra
.043 0 0 r
.42478 .32876 .4319 .32909 .44358 .32924 .4365 .3294 Mtetra
.291 .79 .834 r
.4365 .3294 .44358 .32924 .45541 .32629 .44838 .32657 Mtetra
.593 .948 .892 r
.44838 .32657 .45541 .32629 .46736 .32017 .46041 .32018 Mtetra
.783 .993 .878 r
.46041 .32018 .46736 .32017 .47939 .31098 .47252 .31036 Mtetra
.879 .977 .837 r
.47252 .31036 .47939 .31098 .49146 .29896 .48469 .29736 Mtetra
.921 .941 .798 r
.48469 .29736 .49146 .29896 .50355 .28449 .49687 .28165 Mtetra
.935 .903 .768 r
.49687 .28165 .50355 .28449 .51562 .26808 .50902 .26377 Mtetra
.935 .866 .747 r
.50902 .26377 .51562 .26808 .52764 .25032 .52112 .24439 Mtetra
.926 .833 .734 r
.52112 .24439 .52764 .25032 .5396 .23183 .53315 .22422 Mtetra
.911 .802 .727 r
.53315 .22422 .5396 .23183 .55151 .21327 .54511 .20399 Mtetra
.891 .774 .726 r
.54511 .20399 .55151 .21327 .56336 .19528 .55701 .18442 Mtetra
.866 .746 .728 r
.55701 .18442 .56336 .19528 .57518 .17845 .56885 .16616 Mtetra
.836 .718 .734 r
.56885 .16616 .57518 .17845 .58698 .16332 .58067 .14979 Mtetra
.799 .689 .743 r
.58067 .14979 .58698 .16332 .5988 .15033 .5925 .13582 Mtetra
.756 .658 .754 r
.5925 .13582 .5988 .15033 .61068 .13983 .60438 .12462 Mtetra
.703 .624 .766 r
.60438 .12462 .61068 .13983 .62265 .13208 .61635 .11647 Mtetra
.639 .586 .779 r
.61635 .11647 .62265 .13208 .63475 .1272 .62846 .11151 Mtetra
.562 .544 .792 r
.62846 .11151 .63475 .1272 .64703 .12521 .64075 .10976 Mtetra
.471 .495 .801 r
.64075 .10976 .64703 .12521 .6595 .12602 .65325 .11112 Mtetra
.365 .44 .806 r
.65325 .11112 .6595 .12602 .67221 .12943 .66599 .11536 Mtetra
.246 .381 .802 r
.66599 .11536 .67221 .12943 .68516 .1351 .67899 .12214 Mtetra
.119 .32 .79 r
.67899 .12214 .68516 .1351 .69837 .14264 .69227 .13099 Mtetra
0 .262 .768 r
.69227 .13099 .69837 .14264 .71182 .15152 .70582 .14136 Mtetra
0 .215 .739 r
.70582 .14136 .71182 .15152 .7255 .16118 .71961 .15261 Mtetra
.813 .336 0 r
.04273 .38856 .05043 .39529 .05824 .407 .05026 .40202 Mtetra
.811 .325 0 r
.05026 .40202 .05824 .407 .06626 .41817 .05801 .4149 Mtetra
.783 .282 0 r
.05801 .4149 .06626 .41817 .07458 .4281 .0661 .42641 Mtetra
.725 .202 0 r
.0661 .42641 .07458 .4281 .08327 .43613 .07461 .4358 Mtetra
.621 .067 0 r
.07461 .4358 .08327 .43613 .09241 .44168 .08361 .44244 Mtetra
.427 0 0 r
.08361 .44244 .09241 .44168 .10202 .44429 .09315 .44578 Mtetra
.07 0 0 r
.09315 .44578 .10202 .44429 .11212 .44362 .10325 .44545 Mtetra
.402 .856 .818 r
.10325 .44545 .11212 .44362 .12271 .43951 .1139 .44127 Mtetra
.729 .988 .886 r
.1139 .44127 .12271 .43951 .13375 .43198 .12505 .43326 Mtetra
.866 .976 .853 r
.12505 .43326 .13375 .43198 .14519 .42122 .13666 .42162 Mtetra
.913 .93 .809 r
.13666 .42162 .14519 .42122 .15695 .40756 .14863 .40676 Mtetra
.926 .884 .773 r
.14863 .40676 .15695 .40756 .16896 .39151 .16088 .38922 Mtetra
.923 .845 .748 r
.16088 .38922 .16896 .39151 .18113 .37366 .17331 .36968 Mtetra
.914 .812 .732 r
.17331 .36968 .18113 .37366 .19336 .35468 .18581 .34891 Mtetra
.901 .783 .722 r
.18581 .34891 .19336 .35468 .20559 .33527 .19829 .32768 Mtetra
.884 .757 .716 r
.19829 .32768 .20559 .33527 .21773 .31615 .21066 .30679 Mtetra
.865 .733 .715 r
.21066 .30679 .21773 .31615 .22971 .29799 .22286 .28699 Mtetra
.841 .709 .718 r
.22286 .28699 .22971 .29799 .24151 .28141 .23484 .26895 Mtetra
.812 .685 .724 r
.23484 .26895 .24151 .28141 .25307 .26693 .24654 .25327 Mtetra
.776 .659 .733 r
.24654 .25327 .25307 .26693 .2644 .25499 .25797 .24043 Mtetra
.731 .63 .746 r
.25797 .24043 .2644 .25499 .27548 .24591 .26911 .23076 Mtetra
.672 .595 .76 r
.26911 .23076 .27548 .24591 .28632 .23992 .27998 .22451 Mtetra
.594 .551 .776 r
.27998 .22451 .28632 .23992 .29697 .23708 .2906 .22176 Mtetra
.488 .494 .789 r
.2906 .22176 .29697 .23708 .30744 .23735 .30103 .22248 Mtetra
.345 .416 .792 r
.30103 .22248 .30744 .23735 .31778 .24058 .3113 .22647 Mtetra
.158 .314 .773 r
.3113 .22647 .31778 .24058 .32805 .24648 .32147 .23344 Mtetra
0 .19 .717 r
.32147 .23344 .32805 .24648 .33829 .25466 .33161 .24294 Mtetra
0 .061 .624 r
.33161 .24294 .33829 .25466 .34856 .2646 .34177 .25443 Mtetra
0 0 .513 r
.34177 .25443 .34856 .2646 .35891 .27572 .35201 .26725 Mtetra
.581 .115 0 r
.35201 .26725 .35891 .27572 .3694 .28736 .36239 .28066 Mtetra
.644 .142 0 r
.36239 .28066 .3694 .28736 .38005 .29881 .37295 .29388 Mtetra
.66 .13 0 r
.37295 .29388 .38005 .29881 .3909 .30934 .38373 .3061 Mtetra
.632 .077 0 r
.38373 .3061 .3909 .30934 .40197 .31825 .39475 .31654 Mtetra
.555 0 0 r
.39475 .31654 .40197 .31825 .41327 .32491 .40603 .32446 Mtetra
.407 0 0 r
.40603 .32446 .41327 .32491 .42478 .32876 .41755 .32925 Mtetra
.155 0 0 r
.41755 .32925 .42478 .32876 .4365 .3294 .4293 .33044 Mtetra
.204 .73 .749 r
.4293 .33044 .4365 .3294 .44838 .32657 .44124 .32774 Mtetra
.556 .933 .844 r
.44124 .32774 .44838 .32657 .46041 .32018 .45334 .32106 Mtetra
.78 .998 .847 r
.45334 .32106 .46041 .32018 .47252 .31036 .46555 .31053 Mtetra
.889 .984 .812 r
.46555 .31053 .47252 .31036 .48469 .29736 .47782 .29645 Mtetra
.933 .945 .775 r
.47782 .29645 .48469 .29736 .49687 .28165 .4901 .27933 Mtetra
.948 .904 .747 r
.4901 .27933 .49687 .28165 .50902 .26377 .50235 .25981 Mtetra
.946 .866 .728 r
.50235 .25981 .50902 .26377 .52112 .24439 .51454 .23863 Mtetra
.936 .832 .716 r
.51454 .23863 .52112 .24439 .53315 .22422 .52665 .2166 Mtetra
.92 .8 .711 r
.52665 .2166 .53315 .22422 .54511 .20399 .53867 .19452 Mtetra
.899 .771 .71 r
.53867 .19452 .54511 .20399 .55701 .18442 .55061 .17319 Mtetra
.874 .742 .714 r
.55061 .17319 .55701 .18442 .56885 .16616 .56249 .15334 Mtetra
.843 .713 .721 r
.56249 .15334 .56885 .16616 .58067 .14979 .57432 .13562 Mtetra
.805 .683 .73 r
.57432 .13562 .58067 .14979 .5925 .13582 .58616 .12056 Mtetra
.759 .651 .742 r
.58616 .12056 .5925 .13582 .60438 .12462 .59804 .1086 Mtetra
.704 .615 .755 r
.59804 .1086 .60438 .12462 .61635 .11647 .61002 .10001 Mtetra
.636 .574 .769 r
.61002 .10001 .61635 .11647 .62846 .11151 .62212 .09496 Mtetra
.553 .528 .781 r
.62212 .09496 .62846 .11151 .64075 .10976 .63442 .09348 Mtetra
.454 .473 .789 r
.63442 .09348 .64075 .10976 .65325 .11112 .64693 .09545 Mtetra
.337 .411 .791 r
.64693 .09545 .65325 .11112 .66599 .11536 .65971 .10062 Mtetra
.205 .343 .783 r
.65971 .10062 .66599 .11536 .67899 .12214 .67277 .10861 Mtetra
.063 .271 .762 r
.67277 .10861 .67899 .12214 .69227 .13099 .68612 .11893 Mtetra
0 .203 .73 r
.68612 .11893 .69227 .13099 .70582 .14136 .69976 .13095 Mtetra
0 .147 .689 r
.69976 .13095 .70582 .14136 .71961 .15261 .71368 .14397 Mtetra
.853 .398 .029 r
.03496 .38178 .04273 .38856 .05026 .40202 .04217 .3972 Mtetra
.845 .382 .067 r
.04217 .3972 .05026 .40202 .05801 .4149 .04962 .41198 Mtetra
.817 .341 .071 r
.04962 .41198 .05801 .4149 .0661 .42641 .05744 .42526 Mtetra
.765 .269 .042 r
.05744 .42526 .0661 .42641 .07461 .4358 .06574 .4362 Mtetra
.674 .148 0 r
.06574 .4362 .07461 .4358 .08361 .44244 .07459 .44405 Mtetra
.504 0 0 r
.07459 .44405 .08361 .44244 .09315 .44578 .08404 .44822 Mtetra
.174 0 0 r
.08404 .44822 .09315 .44578 .10325 .44545 .09413 .44828 Mtetra
.33 .805 .737 r
.09413 .44828 .10325 .44545 .1139 .44127 .10484 .44403 Mtetra
.718 .988 .852 r
.10484 .44403 .1139 .44127 .12505 .43326 .11613 .43547 Mtetra
.876 .983 .832 r
.11613 .43547 .12505 .43326 .13666 .42162 .12792 .42285 Mtetra
.926 .934 .791 r
.12792 .42285 .13666 .42162 .14863 .40676 .14014 .40663 Mtetra
.937 .886 .757 r
.14014 .40663 .14863 .40676 .16088 .38922 .15266 .38743 Mtetra
.933 .845 .733 r
.15266 .38743 .16088 .38922 .17331 .36968 .16538 .36602 Mtetra
.923 .81 .718 r
.16538 .36602 .17331 .36968 .18581 .34891 .17817 .34324 Mtetra
.908 .781 .708 r
.17817 .34324 .18581 .34891 .19829 .32768 .19094 .31998 Mtetra
.891 .754 .704 r
.19094 .31998 .19829 .32768 .21066 .30679 .20358 .29713 Mtetra
.87 .729 .703 r
.20358 .29713 .21066 .30679 .22286 .28699 .21602 .27551 Mtetra
.846 .705 .706 r
.21602 .27551 .22286 .28699 .23484 .26895 .22819 .25588 Mtetra
.817 .68 .713 r
.22819 .25588 .23484 .26895 .24654 .25327 .24005 .23888 Mtetra
.78 .653 .722 r
.24005 .23888 .24654 .25327 .25797 .24043 .25159 .22503 Mtetra
.733 .622 .735 r
.25159 .22503 .25797 .24043 .26911 .23076 .2628 .21472 Mtetra
.671 .585 .749 r
.2628 .21472 .26911 .23076 .27998 .22451 .27369 .20819 Mtetra
.588 .537 .765 r
.27369 .20819 .27998 .22451 .2906 .22176 .2843 .20555 Mtetra
.472 .472 .776 r
.2843 .20555 .2906 .22176 .30103 .22248 .29467 .20675 Mtetra
.313 .383 .775 r
.29467 .20675 .30103 .22248 .3113 .22647 .30485 .21159 Mtetra
.103 .264 .744 r
.30485 .21159 .3113 .22647 .32147 .23344 .31492 .21973 Mtetra
0 .12 .669 r
.31492 .21973 .32147 .23344 .33161 .24294 .32493 .23071 Mtetra
0 0 .553 r
.32493 .23071 .33161 .24294 .34177 .25443 .33495 .24391 Mtetra
0 0 .425 r
.33495 .24391 .34177 .25443 .35201 .26725 .34506 .25861 Mtetra
.664 .201 0 r
.34506 .25861 .35201 .26725 .36239 .28066 .35531 .274 Mtetra
.717 .225 0 r
.35531 .274 .36239 .28066 .37295 .29388 .36576 .28921 Mtetra
.727 .212 0 r
.36576 .28921 .37295 .29388 .38373 .3061 .37645 .30333 Mtetra
.7 .161 0 r
.37645 .30333 .38373 .3061 .39475 .31654 .38741 .31547 Mtetra
.63 .066 0 r
.38741 .31547 .39475 .31654 .40603 .32446 .39866 .32481 Mtetra
.496 0 0 r
.39866 .32481 .40603 .32446 .41755 .32925 .41018 .33066 Mtetra
.259 0 0 r
.41018 .33066 .41755 .32925 .4293 .33044 .42197 .33247 Mtetra
0 0 0 r
.42197 .33247 .4293 .33044 .44124 .32774 .43398 .32993 Mtetra
.508 .905 .779 r
.43398 .32993 .44124 .32774 .45334 .32106 .44616 .32292 Mtetra
.772 .996 .807 r
.44616 .32292 .45334 .32106 .46555 .31053 .45847 .31159 Mtetra
.896 .987 .782 r
.45847 .31159 .46555 .31053 .47782 .29645 .47085 .2963 Mtetra
.944 .947 .75 r
.47085 .2963 .47782 .29645 .4901 .27933 .48324 .27762 Mtetra
.958 .905 .724 r
.48324 .27762 .4901 .27933 .50235 .25981 .4956 .25626 Mtetra
.957 .865 .708 r
.4956 .25626 .50235 .25981 .51454 .23863 .50789 .23307 Mtetra
.946 .83 .698 r
.50789 .23307 .51454 .23863 .52665 .2166 .52009 .20896 Mtetra
.929 .797 .694 r
.52009 .20896 .52665 .2166 .53867 .19452 .53218 .18483 Mtetra
.907 .767 .695 r
.53218 .18483 .53867 .19452 .55061 .17319 .54417 .16156 Mtetra
.881 .738 .699 r
.54417 .16156 .55061 .17319 .56249 .15334 .55608 .13996 Mtetra
.849 .708 .707 r
.55608 .13996 .56249 .15334 .57432 .13562 .56794 .12074 Mtetra
.81 .677 .717 r
.56794 .12074 .57432 .13562 .58616 .12056 .57979 .10449 Mtetra
.763 .644 .73 r
.57979 .10449 .58616 .12056 .59804 .1086 .59167 .09168 Mtetra
.704 .606 .744 r
.59167 .09168 .59804 .1086 .61002 .10001 .60364 .08262 Mtetra
.633 .562 .758 r
.60364 .08262 .61002 .10001 .62212 .09496 .61574 .07748 Mtetra
.544 .511 .769 r
.61574 .07748 .62212 .09496 .63442 .09348 .62804 .07629 Mtetra
.436 .451 .777 r
.62804 .07629 .63442 .09348 .64693 .09545 .64057 .07893 Mtetra
.307 .381 .775 r
.64057 .07893 .64693 .09545 .65971 .10062 .65338 .08513 Mtetra
.161 .302 .76 r
.65338 .08513 .65971 .10062 .67277 .10861 .66649 .09447 Mtetra
.005 .22 .731 r
.66649 .09447 .67277 .10861 .68612 .11893 .67991 .1064 Mtetra
0 .141 .687 r
.67991 .1064 .68612 .11893 .69976 .13095 .69365 .12026 Mtetra
0 .076 .634 r
.69365 .12026 .69976 .13095 .71368 .14397 .70769 .13525 Mtetra
.882 .448 .103 r
.02714 .37496 .03496 .38178 .04217 .3972 .03398 .39255 Mtetra
.869 .429 .137 r
.03398 .39255 .04217 .3972 .04962 .41198 .04109 .40948 Mtetra
.84 .389 .142 r
.04109 .40948 .04962 .41198 .05744 .42526 .0486 .42474 Mtetra
.793 .323 .118 r
.0486 .42474 .05744 .42526 .06574 .4362 .05665 .4374 Mtetra
.712 .215 .055 r
.05665 .4374 .06574 .4362 .07459 .44405 .06531 .44663 Mtetra
.564 .029 0 r
.06531 .44663 .07459 .44405 .08404 .44822 .07467 .45174 Mtetra
.266 0 0 r
.07467 .45174 .08404 .44822 .09413 .44828 .08474 .45224 Mtetra
0 0 0 r
.08474 .45224 .09413 .44828 .10484 .44403 .09551 .4479 Mtetra
.7 .981 .809 r
.09551 .4479 .10484 .44403 .11613 .43547 .10695 .43874 Mtetra
.883 .988 .808 r
.10695 .43874 .11613 .43547 .12792 .42285 .11896 .42502 Mtetra
.937 .937 .771 r
.11896 .42502 .12792 .42285 .14014 .40663 .13144 .40728 Mtetra
.947 .886 .74 r
.13144 .40728 .14014 .40663 .15266 .38743 .14427 .38621 Mtetra
.942 .844 .718 r
.14427 .38621 .15266 .38743 .16538 .36602 .15732 .3627 Mtetra
.93 .808 .704 r
.15732 .3627 .16538 .36602 .17817 .34324 .17045 .33768 Mtetra
.915 .778 .695 r
.17045 .33768 .17817 .34324 .19094 .31998 .18354 .31217 Mtetra
.897 .751 .691 r
.18354 .31217 .19094 .31998 .20358 .29713 .19649 .28714 Mtetra
.876 .725 .691 r
.19649 .28714 .20358 .29713 .21602 .27551 .20919 .26351 Mtetra
.851 .701 .695 r
.20919 .26351 .21602 .27551 .22819 .25588 .22158 .24212 Mtetra
.821 .675 .702 r
.22158 .24212 .22819 .25588 .24005 .23888 .23362 .22366 Mtetra
.783 .647 .711 r
.23362 .22366 .24005 .23888 .25159 .22503 .24528 .20871 Mtetra
.735 .614 .724 r
.24528 .20871 .25159 .22503 .2628 .21472 .25656 .19769 Mtetra
.67 .574 .738 r
.25656 .19769 .2628 .21472 .27369 .20819 .26747 .19087 Mtetra
.581 .522 .753 r
.26747 .19087 .27369 .20819 .2843 .20555 .27806 .18835 Mtetra
.456 .449 .763 r
.27806 .18835 .2843 .20555 .29467 .20675 .28836 .19008 Mtetra
.279 .347 .755 r
.28836 .19008 .29467 .20675 .30485 .21159 .29845 .19585 Mtetra
.044 .209 .711 r
.29845 .19585 .30485 .21159 .31492 .21973 .30839 .2053 Mtetra
0 .047 .614 r
.30839 .2053 .31492 .21973 .32493 .23071 .31825 .2179 Mtetra
0 0 .477 r
.31825 .2179 .32493 .23071 .33495 .24391 .32812 .233 Mtetra
.635 .216 0 r
.32812 .233 .33495 .24391 .34506 .25861 .33807 .2498 Mtetra
.732 .277 0 r
.33807 .2498 .34506 .25861 .35531 .274 .34817 .2674 Mtetra
.775 .296 0 r
.34817 .2674 .35531 .274 .36576 .28921 .35849 .28483 Mtetra
.78 .281 0 r
.35849 .28483 .36576 .28921 .37645 .30333 .36907 .30107 Mtetra
.752 .233 0 r
.36907 .30107 .37645 .30333 .38741 .31547 .37995 .31513 Mtetra
.688 .146 0 r
.37995 .31513 .38741 .31547 .39866 .32481 .39116 .32607 Mtetra
.568 .001 0 r
.39116 .32607 .39866 .32481 .41018 .33066 .40268 .33311 Mtetra
.35 0 0 r
.40268 .33311 .41018 .33066 .42197 .33247 .41449 .33564 Mtetra
0 0 0 r
.41449 .33564 .42197 .33247 .43398 .32993 .42657 .33328 Mtetra
.45 .861 .699 r
.42657 .33328 .43398 .32993 .44616 .32292 .43884 .32591 Mtetra
.758 .987 .759 r
.43884 .32591 .44616 .32292 .45847 .31159 .45127 .31369 Mtetra
.9 .986 .748 r
.45127 .31369 .45847 .31159 .47085 .2963 .46377 .29703 Mtetra
.953 .947 .722 r
.46377 .29703 .47085 .2963 .48324 .27762 .47629 .27658 Mtetra
.968 .903 .701 r
.47629 .27658 .48324 .27762 .4956 .25626 .48877 .25317 Mtetra
.966 .863 .687 r
.48877 .25317 .4956 .25626 .50789 .23307 .50118 .22774 Mtetra
.954 .827 .679 r
.50118 .22774 .50789 .23307 .52009 .20896 .51347 .20131 Mtetra
.937 .794 .677 r
.51347 .20131 .52009 .20896 .53218 .18483 .52564 .1749 Mtetra
.915 .764 .679 r
.52564 .1749 .53218 .18483 .54417 .16156 .5377 .14948 Mtetra
.888 .734 .685 r
.5377 .14948 .54417 .16156 .55608 .13996 .54965 .12594 Mtetra
.855 .703 .693 r
.54965 .12594 .55608 .13996 .56794 .12074 .56153 .10508 Mtetra
.815 .671 .705 r
.56153 .10508 .56794 .12074 .57979 .10449 .57338 .08753 Mtetra
.766 .636 .718 r
.57338 .08753 .57979 .10449 .59167 .09168 .58526 .07379 Mtetra
.705 .596 .732 r
.58526 .07379 .59167 .09168 .60364 .08262 .59722 .06421 Mtetra
.629 .55 .746 r
.59722 .06421 .60364 .08262 .61574 .07748 .60932 .05898 Mtetra
.534 .494 .757 r
.60932 .05898 .61574 .07748 .62804 .07629 .62162 .05812 Mtetra
.417 .427 .763 r
.62162 .05812 .62804 .07629 .64057 .07893 .63416 .0615 Mtetra
.276 .348 .757 r
.63416 .0615 .64057 .07893 .65338 .08513 .64699 .06882 Mtetra
.115 .259 .736 r
.64699 .06882 .65338 .08513 .66649 .09447 .66015 .07965 Mtetra
0 .166 .696 r
.66015 .07965 .66649 .09447 .67991 .1064 .67365 .09338 Mtetra
0 .078 .639 r
.67365 .09338 .67991 .1064 .69365 .12026 .68749 .10927 Mtetra
0 .005 .573 r
.68749 .10927 .69365 .12026 .70769 .13525 .70165 .12647 Mtetra
.902 .487 .166 r
.01926 .36808 .02714 .37496 .03398 .39255 .02568 .38811 Mtetra
.886 .466 .195 r
.02568 .38811 .03398 .39255 .04109 .40948 .03239 .40742 Mtetra
.857 .428 .2 r
.03239 .40742 .04109 .40948 .0486 .42474 .03955 .42492 Mtetra
.812 .366 .181 r
.03955 .42492 .0486 .42474 .05665 .4374 .04731 .43953 Mtetra
.74 .269 .129 r
.04731 .43953 .05665 .4374 .06531 .44663 .05576 .45031 Mtetra
.609 .102 .021 r
.05576 .45031 .06531 .44663 .07467 .45174 .065 .45648 Mtetra
.343 0 0 r
.065 .45648 .07467 .45174 .08474 .45224 .07504 .45748 Mtetra
0 0 0 r
.07504 .45748 .08474 .45224 .09551 .4479 .08589 .45305 Mtetra
.675 .965 .756 r
.08589 .45305 .09551 .4479 .10695 .43874 .09749 .4432 Mtetra
.889 .99 .78 r
.09749 .4432 .10695 .43874 .11896 .42502 .10974 .42826 Mtetra
.946 .939 .75 r
.10974 .42826 .11896 .42502 .13144 .40728 .12253 .4088 Mtetra
.956 .886 .722 r
.12253 .4088 .13144 .40728 .14427 .38621 .13571 .38564 Mtetra
.95 .842 .702 r
.13571 .38564 .14427 .38621 .15732 .3627 .14913 .35977 Mtetra
.937 .806 .689 r
.14913 .35977 .15732 .3627 .17045 .33768 .16264 .33227 Mtetra
.921 .775 .682 r
.16264 .33227 .17045 .33768 .18354 .31217 .1761 .30424 Mtetra
.903 .747 .679 r
.1761 .30424 .18354 .31217 .19649 .28714 .18938 .27679 Mtetra
.881 .722 .68 r
.18938 .27679 .19649 .28714 .20919 .26351 .20238 .25094 Mtetra
.856 .696 .684 r
.20238 .25094 .20919 .26351 .22158 .24212 .21502 .2276 Mtetra
.825 .67 .69 r
.21502 .2276 .22158 .24212 .23362 .22366 .22725 .20755 Mtetra
.786 .64 .7 r
.22725 .20755 .23362 .22366 .24528 .20871 .23905 .19139 Mtetra
.736 .606 .713 r
.23905 .19139 .24528 .20871 .25656 .19769 .2504 .1796 Mtetra
.669 .563 .727 r
.2504 .1796 .25656 .19769 .26747 .19087 .26134 .17245 Mtetra
.574 .506 .741 r
.26134 .17245 .26747 .19087 .27806 .18835 .2719 .17006 Mtetra
.438 .425 .748 r
.2719 .17006 .27806 .18835 .28836 .19008 .28213 .17238 Mtetra
.242 .31 .733 r
.28213 .17238 .28836 .19008 .29845 .19585 .2921 .17918 Mtetra
0 .152 .674 r
.2921 .17918 .29845 .19585 .30839 .2053 .30189 .19007 Mtetra
0 0 .554 r
.30189 .19007 .30839 .2053 .31825 .2179 .31158 .20447 Mtetra
0 0 .398 r
.31158 .20447 .31825 .2179 .32812 .233 .32127 .22167 Mtetra
.704 .29 0 r
.32127 .22167 .32812 .233 .33807 .2498 .33103 .2408 Mtetra
.787 .343 0 r
.33103 .2408 .33807 .2498 .34817 .2674 .34096 .26087 Mtetra
.82 .356 0 r
.34096 .26087 .34817 .2674 .35849 .28483 .35111 .28078 Mtetra
.819 .339 0 r
.35111 .28078 .35849 .28483 .36907 .30107 .36157 .2994 Mtetra
.791 .293 0 r
.36157 .2994 .36907 .30107 .37995 .31513 .37235 .31562 Mtetra
.731 .213 0 r
.37235 .31562 .37995 .31513 .39116 .32607 .3835 .32837 Mtetra
.622 .08 0 r
.3835 .32837 .39116 .32607 .40268 .33311 .39501 .33677 Mtetra
.425 0 0 r
.39501 .33677 .40268 .33311 .41449 .33564 .40686 .3401 Mtetra
.079 0 0 r
.40686 .3401 .41449 .33564 .42657 .33328 .419 .33794 Mtetra
.383 .802 .606 r
.419 .33794 .42657 .33328 .43884 .32591 .43138 .33016 Mtetra
.736 .968 .702 r
.43138 .33016 .43884 .32591 .45127 .31369 .44392 .31694 Mtetra
.9 .982 .709 r
.44392 .31694 .45127 .31369 .46377 .29703 .45657 .29875 Mtetra
.96 .945 .692 r
.45657 .29875 .46377 .29703 .47629 .27658 .46923 .27633 Mtetra
.976 .901 .676 r
.46923 .27633 .47629 .27658 .48877 .25317 .48186 .25061 Mtetra
.974 .86 .666 r
.48186 .25061 .48877 .25317 .50118 .22774 .49439 .22268 Mtetra
.962 .824 .66 r
.49439 .22268 .50118 .22774 .51347 .20131 .5068 .19366 Mtetra
.944 .791 .66 r
.5068 .19366 .51347 .20131 .52564 .1749 .51906 .16471 Mtetra
.922 .76 .664 r
.51906 .16471 .52564 .1749 .5377 .14948 .53118 .13691 Mtetra
.894 .729 .67 r
.53118 .13691 .5377 .14948 .54965 .12594 .54318 .11124 Mtetra
.86 .698 .68 r
.54318 .11124 .54965 .12594 .56153 .10508 .55509 .08857 Mtetra
.819 .665 .692 r
.55509 .08857 .56153 .10508 .57338 .08753 .56695 .06958 Mtetra
.769 .629 .706 r
.56695 .06958 .57338 .08753 .58526 .07379 .57883 .05484 Mtetra
.705 .587 .72 r
.57883 .05484 .58526 .07379 .59722 .06421 .59078 .04469 Mtetra
.625 .537 .734 r
.59078 .04469 .59722 .06421 .60932 .05898 .60286 .03936 Mtetra
.524 .476 .745 r
.60286 .03936 .60932 .05898 .62162 .05812 .61515 .03886 Mtetra
.397 .402 .748 r
.61515 .03886 .62162 .05812 .63416 .0615 .6277 .04305 Mtetra
.244 .315 .738 r
.6277 .04305 .63416 .0615 .64699 .06882 .64055 .05163 Mtetra
.068 .215 .708 r
.64055 .05163 .64699 .06882 .66015 .07965 .65376 .0641 Mtetra
0 .11 .657 r
.65376 .0641 .66015 .07965 .67365 .09338 .66733 .07981 Mtetra
0 .013 .588 r
.66733 .07981 .67365 .09338 .68749 .10927 .68127 .09797 Mtetra
0 0 .51 r
.68127 .09797 .68749 .10927 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -83.0625 -13.9115 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
76.375 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -75.6257 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -69.7874 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.6363 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -74.1266 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.188 11.438 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
gsave
.29165 .07573 -69.671 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.312 11.438 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{550.188, 212.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008V0000e2000`400?l00000o`00003oo`3ooooo
0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo
003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0
oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool0
0?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooolH0oooo1@0000020?ooo`040000
003oool00000000005H0oooo002d0?ooo`D000000P3oool010000000oooo00000000003o0?ooo`P0
oooo00<000000?ooo`3oool0103oool2000005L0oooo002e0?ooo`030000003oool0oooo00@0oooo
0P00003o0?ooo`X0oooo0P0000040?ooo`030000003oool0000005H0oooo002f0?ooo`800000103o
ool00`000000oooo0000003o0?ooo`/0oooo00@000000?ooo`3oool0oooo1000001E0?ooo`00^03o
ool010000000oooo0?ooo`3oool400000?l0oooo1`3oool01@000000oooo0?ooo`3oool0000005/0
oooo002e0?ooo`050000003oool0oooo0?ooo`000000o`3oool>0?ooo`@00000F`3oool00;H0oooo
1000003o0?ooofd0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooB0?oo
o`800000D`3oool00<00oooo0P00003o0?ooo`h0oooo0P0000000`3oool000000000001B0?ooo`00
_P3oool2000000030?ooo`00000000000?l0oooo2P3oool3000000<0oooo0P00001B0?ooo`00^`3o
ool3000000<0oooo0P00003o0?ooo`P0oooo0P0000060?ooo`030000003oool000000540oooo002h
0?ooo`<000001P3oool00`000000oooo0000003o0?ooo`@0oooo0`0000080?ooo`040000003oool0
oooo00000500oooo002f0?ooo`8000002@3oool010000000oooo0?ooo`00003o0?ooo`40oooo0P00
000;0?ooo`040000003oool0oooo00000500oooo002c0?ooo`<000002`3oool010000000oooo0?oo
o`00003m0?ooo`<000003@3oool01@000000oooo0?ooo`3oool0000004l0oooo002B0?ooo`040000
003oool00000000001/0oooo0P00000>0?ooo`050000003oool0oooo0?ooo`000000g@3oool01000
0000oooo00000000000H0?ooo`<00000403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo04`0oooo002C0?ooo`8000006@3oool300000100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`3K0?ooo`8000005`3oool2000001<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1<0?ooo`00T`3oool00`000000oooo0000000F0?ooo`8000004`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`0000004`3oool3000001D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;0?ooo`00T`3oool400000180oooo
0`00000F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0000000]0?ooo`@00000403oool200000080oooo102ORK/208Ii_P80IFJo3`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04X0oooo001T0?ooo`030000003oool0000003l0oooo0`00
000I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0000
000n0?ooo`<000000`3oool20;BF^0<0WhVk0P26NKh306EV_`0303i@_03oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1:0?ooo`00I03oool00`000000oooo0000000m
0?ooo`800000703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:X0oooo00<00000
0?ooo`3oool0>`3oool2000000@0oooo102dU[P309n9^`<0QWVn0P1UI[l203i@_0`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`190?ooo`00I@3oool00`000000oooo0?ooo`0i0?oo
o`<000007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:T0oooo0`00000h0?oo
o`<000001P3oool01034XK@0]9Jh0;BF^02dU[P309n9^`<0QWVn0`1UI[l203i@_003014g]@3oool0
oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`190?ooo`00I@3oool30000
03L0oooo0P00000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0000000f0?ooo`800000203oool20<BQ]0<0]9Jh102QS;h308Qn`@80JVg30P0nD;`2014g
]@T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`180?ooo`00I@3oool00`000000
oooo0000000d0?ooo`<000008`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=h0
oooo0`00000:0?ooo`<0a:6d00<0]9Jh0;BH^`2dV;/00`2QS;h308Qn`@<0JVg300@0AUW1014g]@0A
=kD04CNe203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04L0oooo002J0?ooo`80
00009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0=/0oooo0P00000<0?ooo`@0
a:6d0`2dV;/30:6<_P<0R7k10`1ZKL<204II`@804CNe00<001bX0?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo1@00000g0?ooo`00U`3oool3000000030?oo
o`000000oooo02D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`D00000
b03oool300000080oooo00<000000?ooo`3oool02@3oool01@3AZ[40a:6d0<BQ]034XK@0a::g00<0
]9Rk0P2QS;h308Qn`@<0JVg30P16FL40100M@[`04CNe000LZ0007:P60?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0h0?ooo`00U03oool300000080
oooo102GQ;d207Ub_`80Debn8@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0aP3oool300000100oooo0P3AZ[420<BQ]080a::g0`2dV;/30::?`P<0
Rh;40P1_LlH304II`@0301e2_0007:P001bX00H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`040?ooo`@000000`3oool2000003P0oooo002B0?ooo`8000000P3oool40:fA^@<0UhBm
0P1iL[l305=L_R00oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`@00000
0`3oool200000<@0oooo0P00000B0?ooo`<0dJZa00@0a:6d0<BR]`34X[L0a::g0P2dV;/20;BK_P80
XXo20`2;P/@306mcaP80CV760P0M@[`2000LZ0D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo03D0oooo002?0?ooo`<00000103oool0102nWKH0[I6i
0:fA^@2]TKT309N4_@<0NG:o0P1CG;h00`0T@KP0oooo0?ooo`0M0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2n0?ooo`<000004`3oool40=6Z/@@0
a::g102dVkh30::?`P<0Rh;40P1_LlH304iQaP0402U=`P0M@[`001bX0003UP@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000=P3oool0
08d0oooo0P0000060?ooo`80_Yff0`2]TKT309N4_@<0NG:o0P1CG;h00`0T@KP0oooo0?ooo`0M0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0
00000;d0oooo0P00000F0?ooo`030=bb[P3AZ[40dJZa0080d:^d0P34X[L20<>T^P<0]9^n0`2RSl83
08^2a080Kg?60`1>HLH202U=`P03000Z/P000iH000>F00<0oooo00<000000?ooo`3oool0203oool3
000000/0oooo1000000f0?ooo`00K@3oool3000001X0oooo0`0000070?ooo`@0_Yff0P2]TKT409R7
`0<0O7O300<0FVC302A1^00T@KP07P3oool00`000000oooo0?ooo`080?ooo`030000003oool00000
00/0oooo1000002N0?ooo`<000006@3oool3000001L0oooo0P3L/Zh01@3AZ[40d:^d0=2[]03@Zk@0
a::g00<0`jBj0`2dVkh40::Ba0<0SHO70P1dNLT205IYbP<0:Dg200<002Zb0003UP3oool00P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04<0oooo001]0?ooo`040000003oool0oooo
000001L0oooo0P00000:0?ooo`040<bV/P2nWKH0_Yff0;jM]P<0[IBl0`2HQl0307ag``80FVC300<0
;dbn02A1^03oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:X0oooo00@0
00000?ooo`3oool000005P3oool2000001X0oooo0P3L/Zh40=2[]0D0`jBj00<0]9^n0;BM`@2dWL40
0`2RT/@308f7a`80M7W90`1FJLX01@0dElP0:Dg2004h^`00:[8000>F0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`120?ooo`00K@3oool010000000oooo0?ooo`00000D0?ooo`<0
00002`3oool20<bV/P80_Yff0P2nWkT20:fD_0<0V8O00`1lMl<205YT``80;dbn00<002:[0?ooo`3o
ool06P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:X0oooo00@000000?ooo`3o
ool000004`3oool3000001/0oooo0`3L/Zh01@3J/k40d:^d0=2[]03@Zk@0cjfg00@0`jBj0`2dWL43
0::Ba0<0SHO70`1dNLT205IYbP80=5O80P01>;/010004j<000220?ooo`00000>0?ooo`030000003o
ool0oooo0440oooo001]0?ooo`050000003oool0oooo0?ooo`000000403oool3000000d0oooo0`3<
Y[80102nWKH0_Yni0;jO^@2nWkT30:fD_080V8O00`1lMl<305YT``80;dbn00<002:[0?ooo`3oool0
6@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0:T0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`8000007@3oool40=bb[P030=Zc/@3@Zk@0d:^d0080cjfg0`33Y;X20<:V_@<0
]9g10P2RT/@408n;bP80N7k=0`1FJLX203AGb0800CRk00<001>S0000PP0000003P3oool00`000000
oooo0?ooo`110?ooo`00K@3oool01@000000oooo0?ooo`3oool0000000h0oooo0P00000?0?ooo`@0
c:Jb102nWkT30:fD_0<0VH_30`20O<H2061[a`80;dbn00<0032d000RZ`3oool06@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0:T0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`<000007`3oool00`3T^Z/0g;:^0=bb[P030=Zc/@050=2[]03?[KL0cjfg0<n]]`33Y;X00`32Y[d3
0;BM`@<0XiK70`2?RlX307Qnc@80GG3>0P0dElP01@0@AL<00CRk000T[`004j<0000000l0oooo00<0
00000?ooo`3oool0@03oool006h0oooo1000000;0?ooo`<000004@3oool01@3G[Zl0c:Jb0<bV/P3<
Y[80bjRe00<0_Yni102^Ukl209V;``<0P7c60`1PJlL0100_C;h0032d000`]00019LI0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0Z@3oool4000000/0oooo0P00000R0?ooo`80i;Z[
00@0g;:^0=Zc/@3J/k40f[>a103?[KL40<:V_@80]9g10P2cWl@30:>Fa`80Sh_:0`1hO/d305e`cP03
03iQc@0@AL<044G3008002B_00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00
N`3oool2000001@0oooo00<0ejj_0<bV/P3<Y[800P3;Z;D30;jO^@040;fQ_02^Ukl0[YNo0:jG_`<0
VH_30P20O<H3061[a`0503UFa000<;@0032d000`]00019L06@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0;@0oooo0`00000S0?ooo`<0i;Z[103J/k400`3I]K@0cjfg0<n]]`020<j^
^P<0`ZJm102cWl@30:>Fa`80Sh_:0`1hO/d305e`cP80?V7=00D07U7:0115``00<kX002B_0000000?
0?ooo`030000003oool0oooo03l0oooo001h0?ooo`<000005@3oool30=N^[`050<bV/P3;Z;D0bjRe
0<^X]@2nWkT00P2mXK`30:jG_`<0VH_30P20O<H3061[a`80>EK400@03Cfm000`]0005:@0001o603o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;40oooo0`00000V0?ooo`<0i;Z[00<0
hk^_0=Zc/@3J/k400P3I]K@0103?[KL0cZjj0<j^^P3>[[X20<:V_@80`JS10`2cWl@40:BIbP80THo=
0`1lPll206Agd@<0?V7=00D07U7:000c^P00<kX000000001TP0?0?ooo`030000003oool0oooo03h0
oooo001f0?ooo`800000603oool30=N^[`@0bjRe102mXK`20:jG_`@0Vho60P23P/T306Ibb`0504=O
b@0iE/@03Cfm000DY00007l0603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0:h0
oooo0P00000Y0?ooo`80i;Z[0P3S^jl0103J/k40fKFd0=Ve]03I]K@40<j^^P@0`JS10P2cWl@20;>R
aP<0Y9W:0`2ASld307b3c`80I7OA0P18J]4201iAbP030013a000000001>R0100oooo00<000000?oo
o`3oool0?@3oool007<0oooo0`00000I0?ooo`@0ejj_00<0e[2b0<^X]@3;Z;D00P3:ZKP30;fQ_0<0
[Y[20`2KSlH308>2b@80IW;;0P13GlT200dm_@03000DY00007l0oooo01H0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`2Z0?ooo`<0000000<0oooo0000003oool09`3oool30>BjZ`80
hk^_103I]K@01@3G][P0cZjj0<j^^P3>[[X0c;2n00<0`JS1102cX/H30:BIbP<0THo=0`1lPll206Ag
d@<0B6[A00D0;5g@01iAbP00000002F`000CXP0?0?ooo`030000003oool0oooo03d0oooo001`0?oo
o`<000000`3oool00`000000oooo0?ooo`0F0?ooo`030>2f[@3G[Zl0ejj_0080e[2b00@0bjRe0<ZY
^03:ZKP0bZVh0P2mXK`20;fS_`<0[Y[20P2KSlH308>2b@80IW;;0`13GlT00`0=?Kd002F`000DY00G
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0Z03oool2000002d0oooo00<0k<:Y
0>BjZ`3S^jl00P3S^jl00`3Q_;80fKFd0=Ve]0030=Nf^0050<j^^P3</;h0c;2n0<b`_P31Z<400P30
Z/<30;>RaP<0Y9W:102CT/l30828dP0406Yne018J]40B6[A04QZd@80;5g@00<000000013a000=kd0
403oool00`000000oooo0?ooo`0l0?ooo`00KP3oool2000001h0oooo0P3P]Zd0103G[Zl0e[2b0=J`
/P3F/;840<ZY^0@0_J>o0`2^V/8309bBb@<0QXK<00D0JgS>04=Ob@13GlT0@eo901]:a002000U/003
0000S`3oool0oooo01@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`2T0?ooo`<0
0000;P3oool20>c2Z@@0hk^_0P3Q_;80103I]K@0ekJh0=Nf^03G][P40<b`_P@0`:[30P2cX/H40:BK
c0<0Ti;?0`20R=8206Yne080DW;E0P0/GM00100000003e7<0013a000=kd@0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0:`3oool006/0oooo0`00000P0?ooo`80h;J]103F/;800`3D
/KH0bZVh0<ZY^0020<V[^`<0_J>o0P2^V/820:jLa@80W9;90`26Q/`206]hcP80C6S>0P0KB/@00`00
=;X002F`0000I`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`2A0?ooo`800000<@3oool20>c2Z@030>[3[@3S^jl0hk^_00<0hKbb103G][P00`3F
]k/0c;2n0<b`_P020<^a`@<0`:[30`2cY<T30:BKc0<0Ti;?0`20R=8306Yne080DW;E00@0>6OE0000
000?DL`03e7<0P00=kd?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:`3oool0
06T0oooo0P00000R0?ooo`<0h;J]00<0g[N`0=J`/P3F/;800P3D/KH0103:ZKP0bJ^k0<V[^`39Zk/3
0;fS_`@0[Yc50`2LT/T208J6c0<0JgS>0P1<J<h01@0XE//06d[4000d^P003il0001W01@0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06l0oooo00@0
00000?ooo`00000000006`3oool300000380oooo0P3/`ZT30>[3[@050>>k[`3Q_;80hKbb0>6l/P3O
_KH00P3G][P20=Jg^`040<b`_P3;/L40bk710<^a`@80`:[30P2oZlH30;>Tb@80Y9_<102EU]8308B=
e080L8CG0`1BL]D01P000000>6OE01mNd`0?DL`004O8000g_@l0oooo00<000000?ooo`3oool0103o
ool4000000@0oooo00<000000?ooo`3oool0:`3oool004X0oooo00@000000?ooo`0000000000603o
ool3000002<0oooo0`3P]Zd20=jg/0040=J`/P3D/KH0e;6f0=Ba]P@0bJ^k0P2mXkl20;bU`P<0[Yc5
0`2LT/T308V;c`80LGkA0`1<J<h0100XE//003Bj000d^P003ilD0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0103oool4000000@0oooo00<000000?ooo`3oool0L03oool2000001X0
oooo0P00000e0?ooo`80k<:Y0`3Z`jd30>6l/P80gkff00@0ekJh0=Jg^`3F]k/0e[Nk103;/L401030
Z/<0_j_60;n[aP2oZlH30;>Tb@<0YIk?102EU]8208B=e0<0L8CG0P1JN]T010000000>6OE01mNd`0O
G]<20017b0l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0[0?ooo`00B`3oool2
000001L0oooo0P00000V0?ooo`030>NmZ`3P]Zd0h;J]0080g[N`103D/KH0103C/[T0bJ^k0<V[^`39
Zk/40;bU`P80[Yc50P2^WlP309fEb`80RH_?0`1aO]4205A`dP80:5K;00<00d?4000d^P003il04`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0JP3o
ool400000080oooo00<000000?ooo`0000005P3oool3000003H0oooo0P3/`ZT40>[3[@030>S4/@3Q
_;80hKbb0080gkff103F]k/0103D^;l0bk710<^a`@3;/L440;n[aP@0/ZK<0`2UW/l309FFdP80Q8gD
0`1`Q=L205Yjf@0300000014LMT07ekC00807ekC00<025KA0017b03oool03P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02/0oooo00140?ooo`@000000`3oool00`000000oooo0000
000C0?ooo`<000009`3oool20>NmZ`050>2f[@3N]k00g[N`0=jg/03M^;<00P3D/KH20=>b^@<0bJ^k
00@0b:fn0;bU`P2lYL80_:G2102^WlP309fEb`<0RH_?0P1aO]4305A`dP0503EQd003@l@00d?4000Q
[@2W<@004P3oool00`000000oooo0?ooo`0B0?ooo`8000003@3oool00`000000oooo0?ooo`1`0?oo
o`@000004`3oool2000003T0oooo00<0lLZX0>c2Z@3Z`jd00P3Z`jd20>S4/@050>6l/P3O_KH0gkff
0=nm]P3M_[X00P3F]k/20=Bh_`80bk710P39//@20;n[aP80_Zg90`2bY/`30:FNc`@0UiWD0P27TML3
07F9f@0406:1f`000000A77I04Aaf@80;VWI0P08E]4>0?ooo`030000003oool0000000`0oooo00<0
00000?ooo`3oool0:`3oool004/0oooo1000000?0?ooo`<00000:P3oool20>NmZ`@0g[N`0P3M^;<0
1@3D/KH0dk:i0=>b^@3C/[T0bJ^k00<0b:fn00<0_:G20;bWa02lYl@00`2^WlP309fEb`<0RH_?0P1a
O]4305A`dP80=F7@00@0557<00=3a0008Jd0Yc404@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0Q03oool3000000030?ooo`2[T;X0Zi2j0080TX6m
0P1`K;l00`0mCk/0oooo0?ooo`0`0?ooo`80lLZX103Z`jd20>S4/@<0gkff0P3M_[X0103F]k/0e;Ro
0=Bh_`3D^;l40<Vba0@0_Zg90`2bY/`40:FQd@<0UiWD0`27TML207F9f@0306:1f`000000HX7K0080
CW[M0P0^JMT00`0JI=T025KA0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0:P3oool005`0oooo0P00000/0?ooo`<0ikf[00<0iKj_0=jg/03N]k000`3M^;<40=>b^@@0b:fn
102lYl@20:jOb0@0WYW>0`2<Sm4207J4e080G7SE0`0eHM00100DDL`003:j000BWP2F7P0@0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`200?ooo`<0
00000P3oool40:^@^P80TX6m0P1`K;l203e?^c40oooo0P3abZP00`3_bjd0j/>]0>[3[@030>S4/@03
0>K5]@3O_KH0gKjj0080gKjj103D^;l01@3B^L80bK;40<Vba039//@0akC700<0_Zg9102bZ<h30:FQ
d@<0UiWD0`27TML207F9f@0306:1f`000000HX7K00<0CW[M0P0kM=h00`0JI=T0oooo0?ooo`0>0?oo
o`030000003oool0oooo03L0oooo001I0?ooo`<00000;P3oool30>NmZ`80iKj_00D0g[N`0=fh/`3M
^;<0gKRc0=^j]`020=>b^@80d[Bl0P38[Kh20<N^`P<0_:O40`2^XLX309jIcP<0S8oA0`1fQ=@205ah
e@80@6_E0P0DDL`00`00@lD001:N0?ooo`0?0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0R`3oool2000000D0oooo00@0_9^f0:^@^P2[T;X0Zi2j0P2BPKd3071/_`80?Dnk;`3oool3
0?7:Z080kl^]0`3Xa;420>K5]@@0gKjj00<0fknm0=Bh_`3D^;l00`3B^L801@39//@0akC70<Nda`37
]<L0_Zg90080_Jk<0`2bZ<h30:FQd@@0VIcF0`2:UMT207Z>f`030000001YR=h0CW[M0080CW[M0`0k
M=h00`0[L=l0oooo0?ooo`0>0?ooo`030000003oool0oooo03H0oooo001G0?ooo`800000<03oool3
0>NmZ`<0iKj_0`3M^;<20=^j]`050=>b^@3B];`0d[Bl0=:d_038[Kh00`37[/820;bWa080^jW70`2^
XLX209jIcP<0S8oA0`1fQ=@205ahe@<0@6_E00@08ekC0013a@00@lD0/S803`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01L0oooo0P00001^0?ooo`<000001P3oool20;bK]P<0Zi2j
0P2BPKd3071/_`80?Dnk00<002J/0?ooo`3oool0;03oool20?7:Z0<0kl^]00<0kLba0>S4/@3VaKD0
0P3VaKD00`3Ta[T0gKjj0=fn^P030=^o_@@0d[W21037]<L40;f^c080/ZS>102VXm<309VLeP<0RYGI
0P1jS]/00`000000JHSN06V8gP0305R2h080B7gR0P0[L=l?0?ooo`030000003oool0oooo01L0oooo
0P00000M0?ooo`00E03oool300000380oooo00<0kLFZ0>NmZ`3W_J/00`3U_Zl00`3T_k80gKRc0=^j
]`020=^j]`@0d[Bl1037[/840;^Ya`<0[Z7:0`2OW=0308jCd`<0NXWG0P1SOmP204]df@808ekC00<0
1e;?0013a@0007d03P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0JP3oool2000000P0oooo102lVkH00`2[T;X0Zi:l0:^B_00209B5`0<0M7;300<0
?Dnk000V[0009Z`0;03oool30?7:Z080kl^]0P3]c;430>K5]@<0i<Ji103K_kd00`3I`<40d[W20=:i
`P020=2ja@80akC70P36]LT30;f^c0<0/JW@0`2VXm<309VLeP<0RYGI0P1jS]/010000000JHSN06V8
gP1YR=h205R2h0<0B7gR0P0jNn<?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
6`3oool00580oooo0P00000d0?ooo`<0kLFZ0`3U_Zl20>Bo/P@0fkZg00D0f[^j0=:d_03B];`0d[Bl
0=2e_`020<N^`P80a[340`2kZLL40:jSc@<0Wic@0P2>Tm<307Z9e`<0HgoH0P1;M=T01@0aJMP08ekC
00MBc`00>Kd0S@/000d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo06H0oooo0`0000090?ooo`80bJ>c0`2lVkH30:^B_080U8G00`1dL/<00`17F<40
02J/000V[00/0?ooo`030?KBZ03abZP0lLZX0080kl^]0P3]c;400`3[c;H0i/Fe0>K5]@030>C6^@03
0>76_@3K_kd0fknm0080fL3100D0d[W20=2ja@3@^/D0d;[50<Nda`030<Jeb@80_Jk<0P2l/<h30;6Y
d0<0YZGE0`2JWmP308fIfP0307jCg@000000OY?M00<0L8kP00@0HHWR04QmhP18ON80B7gR0`0jNn<?
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06P3oool004l0oooo0`0000000`3o
ool000000?ooo`0c0?ooo`<0kLFZ00<0jlJ^0>Fn[`3U_Zl00P3T_k800`3R`KH0fkZg0=^j]`030=Zk
^P040=:d_03@]Kl0d;Fo0=2e_`@0a[3400<0^jW70;Z[bP2jZlX00`2^Xld309nLd0<0T9OF0`1nS]T2
06Z5f`80BgCI0P0aJMP200MBc`030;8b002=2`00oooo00/0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0000006D0oooo0P0000020?ooo`030000003oool0
oooo00H0oooo0`39Xk<20;bK]P80_9fi0`2[T[`209B5`080M7;30P17F<400`009Z`0002=0?ooo`0Z
0?ooo`80m]:X0P3_bjd30>g</@80jlbf0`3Ta[T20>76_@040=^o_@3I`<40fL310=W0`@@0d;[51036
]LT40;b`cP80/JW@0P2aZm830:JUe@<0VYoH0P2=VMX00`1nTmd0000007jCg@03072>h080HHWR0`1C
QND204N4i`l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0000000K0?ooo`00C03oool3
000000040?ooo`2SRk/0Xh^k0:>;^`<0QWZn00<0Ff6n0?ooo`3oool0;P3oool30>g5ZP80jlJ^00@0
iKj_0>Bo/P3T_k80i;nb0P3R`KH0103K^[L0f[^j0=Zk^P3J^kX30=2e_`80c[K20`36/<@40;Z[bP80
[Z?=102PW]83092GeP80OXkI0`1ZQM/0101DO=`0<FWH035Yf00aJMP201UPeP030;8Z002=2`00oooo
00/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0E0?ooo`030000003oool00000
0680oooo0`00000<0?ooo`@0bJ>c102lWKT30:^B_080U8G00P1dL/<204MH`@0300/e]P0008d0oooo
02X0oooo0P3fdZP0103ddjd0kl^]0>g</@3]c;430>_<]P030>W=^P3Ta[T0hLJm0080hLJm103I`<40
0`3G`L@0d;[50=2ja@020<jkb080a[G90P34]/`30;b`cP@0/J_B0`2VYMD409^Rf@80SicL00<0PiOO
00000023Uml00`1fTn8206R?i0<0DhGU0P17Q>L?0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`0000006`3oool004X0oooo0P0000030?ooo`80]YNg0P2SRk/308Ij_P80Ff6n;`3oool30>g5
ZP80jlJ^0`3T_k830>;1]P<0f[^j0P3H_;d0103@]Kl0c[K20<jf`P3>]/820<J`a080a;770`2jZlX3
0:jVc`<0X9kB0`2@UmH207j>f@<0JXGK0P1DO=`203icg@<06F3F00<0/RX008h2003oool02P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool00000G`3o
ool2000000l0oooo00D0dj^`0<VS/`39Xk<0bJ>c0<RU]P030;bM^@80Zi:l0P2[UKl209J9``80N7S6
00@0D6;600/e]P0;=KH0002=:@3oool20?KBZ080m=>]0`3]c;420>_<]P80jLfj103Qa[d00`3Oal40
fL310=W0`@030=O1a0@0c[_81034]/`00`2l/<h0^[7@0;Zad0030;6[dP@0YZOG0`2KX]T308nLg003
00000023Uml0MY?R0080MY?R0`1XSn@305f=i`0305><j@3oool0oooo00h0oooo00<000000?ooo`3o
ool0503oool010000000oooo0?ooo`00000J0?ooo`00A`3oool3000000@0oooo0`2fUkL30:>;^`80
QWZn0P1KHKh00`0M>kD0oooo0?ooo`0[0?ooo`<0kLFZ0`3[aZh00`3Yak80i;nb0>Bo/P030>;1]P03
0>31^@3J^kX0f;bm0080f;bm103>]/840<Baa`80^Z_:0P2i[<`30:jVc`80X9kB102BV]P208:Cf`<0
L8_M0P1LPml203icg@80:FcL00@015[D0;8Z002>0P00SP802@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000G03oool300000100oooo0P3CZk02
0<VS/`80b:Ff0`2lWKT40:^E_`80UXW30P1hN<H2051RaP0301Y3_P0;=KH0001U02P0oooo0P3fdZP2
0?CC[@80l]Bb0`3[c;H20>W=^P030>K=_P3Qa[d0hLJm00<0glO10`3G`L@20=C1a`80c[_80P3<_</3
0<Bfc0<0^[7@102`[M@30:JWe`<0Vj;I0`2?W=`00`000000QY_P08JKh00207^Gh`<0J8oT0`1MSNL2
05><j@l0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`00000J0?ooo`008@3oool5
00000080oooo00@000000?ooo`00000000006@3oool2000000L0oooo00<0a:2d0;JG]`2fUkL00`2S
Rk/208Ij_P80Ff6n0P0M>kD/0?ooo`030?;=ZP3]aJX0kLFZ0080jlJ^0`3Yak830>;1]P80h<6i103H
_;d00`3F_<40c[K20<jf`P020<fga@<0a;77102i[<`20:jVc`80[ZSA0P2QXM@309:Jf0<0PY?K0P1`
Rmd305b3g`0604Ulh@0YK=`0:FcL02U/g00HJ=`0YaT00P2>0P080?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01@3oool3000004D0oooo1@0000020?ooo`040000003oool000000000
01T0oooo0P00000C0?ooo`<0dj^`00D0bJ>c0<RU]P38YKH0b:Ff0;bM^@020;^O_0<0ZiFo0P2FRL<3
07QhaP80D6;600<06T>n000<W@3oool09`3oool00`3fdZP0m=>]0?CC[@030?;D/P030>oD]`3[c;H0
jLfj0080jLfj0P3VcKh30=o7`@80g<O400D0el740=C1a`3D`LL0e<770<jkb0030<blb`80a;K<0P33
]ll00`2j/M00^K;B0;VbdP030;2]e0<0YZOG102MY=/209:Og@0400000026Vn00QY_P08JKh080NiOS
0`1`U>H306FCj080GI?/3`3oool00`000000oooo0?ooo`050?ooo`<00000:@3oool00280oooo00<0
00000?ooo`3oool0103oool2000001L0oooo0`0000080?ooo`80a:2d0P2fUkL40:B>_P80RGo200@0
HVS301dk]@0M>kD000VJ:`3oool20?;=ZP<0jlJ^0`3Yak800`3WakH0h/6f0>31^@020>31^@030=k2
_@3H_;d0f;bm0080e[c100@0c[K20<fga@3=]lD0cKO50P34/LL20<>bbP<0^Jc<102^Z=420:6Qe0<0
TY[H0`22Tm/2072;g@<0G8?O0P19O>4203Mgh@8066SL00@0YaT009H400220000PP001P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000A@3oool0
0`000000oooo0?ooo`040?ooo`8000005`3oool3000001@0oooo103CZk040<RU]P<0^inl0`2[UKl3
09R=aP80O7k90P1@H/H201Y3_P03000<W@3oool0oooo02@0oooo0P3fdZP20?CC[@80l]Bb0P3_e;L3
0>W=^P<0i/fn00<0hlk20=o7`@3Lal@00P3Lal@40=C1a`@0c;c;1033]ll40;VbdP80/:gD102WZMP3
09fTf`80TYoM00@0000008JKh026Vn00QY_P0P1kUn<3072DiP<0II?X0`1MTn`?0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool00000:03oool001`0oooo100000030?ooo`800000103o
ool00`000000oooo0000000D0?ooo`8000002P3oool30<BP]0030;JG]`2fVKX0]YVj00<0Y8jn0P29
Ol82069X``0302U7_0002IX000VJ02X0oooo0P3bcJX00`3`cZl0jlJ^0>W7/P020>W7/P80ilNf0`3P
`KT30=k2_@030=Rl_@3F_<40e[c100@0cKO51033//X40;V^c`<0[ZSA0`2RY=L309BMfP<0QIOM0P1e
T=l306B:hP80DhCT0P0gMn4202UehP050:LI002F1000PP000880001Y0000103oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000?`3oool4000000<0
oooo0P0000040?ooo`030000003oool0000001<0oooo0`00000F0?ooo`D0dj^`00<0dZbc0<RU]P38
YKH00P37YkP20;^O_0@0[9S20P2HSLH307anb@80F6[:00<06T>n000NZ`2dBP009@3oool00`3ig:X0
m=>]0?CC[@030?;D/P80kmBg00<0kMFk0>W=^P3YcKX00P3VcKh20>?>`P<0g<O40P3JalP20=C1a`80
d/;;0P3<_</20<VlcP80`kO?0P31^=430;VbdP<0/:kF0`2WZMP409jWg00309BSg`000000U:?O00<0
RYoQ0P20W>@307JIi`<0KIWZ0P1VVNd?0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool00000:03oool002D0oooo00@000000?ooo`3oool0oooo1000000@0?ooo`<000002`3oool40<BP
]0<0]YVj0`2TS[h208Uo`P<0HVS300<0:DNl0009VP3oool0:03oool20?;=ZP80l<j_103Yak820>O7
]P030>G8^P3P`KT0g/:m00<0g/:m0`3F_<400`3D_L@0cKO50<fga@020<^hb080`k;:0P32]<`30;V^
c`@0[Z[D0`2RY=L209BMfP<0QIOM0`1eT=l206B:hP<0DhCT00D0A87U02UehP0YMN80:GGR01mfh`02
08h0000607/0001U0000I@0004X0003oool000007P3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`000000A`3oool010000000oooo0?ooo`3oool400000100oooo0P00000I0?oo
o`040=^b[`3CZk00dj^`0=>[/080dZbc00D0b:Ff0<NW^037YkP0ajNh0;^O_0020;^Q_P<0[9S20`2H
SLH207anb@80F6[:00<0:535000NZ`007Z/0903oool20?WLZP040?OL[`3be;80l]Bb0?;D/P80kmBg
0`3]eK/20>K=_P<0hlk200<0hLk50=c7a03JalP00P3JalP40=;2b`@0bKc>1031^=440;Rce0<0/:kF
0`2WZmX309jWg00309BSg`000000U:?O00<0RYoQ0`20W>@207JIi`<0KIWZ0`1VVNd?0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000W0?ooo`008P3oool01@000000oooo
0?ooo`3oool0000001<0oooo0`00000>0?ooo`050<nX/@34X;@0a:2d0<BP]034X[L00`2fVKX20:B>
_P80RGo20`1RJ<<00`0YAk`001^W0000KP0X0?ooo`80l/fZ0P3`cZl00`3^c[<0jLNb0>W7/P020>O7
]P80iLRj103N`[d20=c3`0040=Jl`@3D_L@0e;g40=Bma0@0bkS81032]<`00`2i[/l0^:oA0;R_d@03
0:jZe0<0XZCG0`2FXM/308VKgP<0NYGQ00@0Ji3T05>4i01CQ>@0DhCT0P14PND203Qoi`807gKS101P
00030000000300Z@g@0PZ=`08:SL0080K=Sc101hfoXE0?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000140?ooo`050000003oool0oooo0?ooo`0000004`3oool3000001/0
oooo0P3K/Zl0103CZk00dZbc0=://`3B[;<40<NW^0<0^j6n0`2/V<8309R=aP80O7k90P1HJ/X202Q@
a@03000NZ`2dBP00oooo0280oooo00<0nMbZ0?OL[`3gg:l00P3dgKD20>oD]`@0kMFk00@0j]G00>?>
`P3Sc/80hlk20P3Qc/D40=[7b0050=O7b`3B`//0d/;;0=;2b`3?`/d00P39_<h20<Nmd080`KSA0P2o
^=<30;Rce0@0[k3H0`2WZmX209jWg00409JUh0000000UZGP09JUh0<0SJ;R0`24WnD207bNj0<0M9g[
0`1_W^h=0?ooo`<00000103oool01@000000oooo0?ooo`3oool0000002L0oooo000S0?ooo`@00000
4@3oool200000100oooo0`3?Z;400`34X;@0a::g0<BR]`030;JI^P<0Y9710P2<PlD306Q_a`0302U7
_00006h0oooo02L0oooo00@0l/fZ0?3>[`3`cZl0l<j_0P3^c[<20>O7]P<0iLRj00<0hlVm0=k2_@3N
`[d00`3L`l030=Bma080d[k70P3;^<P20<Vib`<0`[C<102h[m420:jZe0@0XjKH0`2FXM/208VKgP<0
NYGQ0P1[T>@305b;iP80ChSX0P0hOnL20362j@<07GgV00<08hW[01f@j`0000000`0SW^/304^nm@@0
P]cm4`3oool00`000000oooo000000050?ooo`@00000A@3oool400000140oooo0P00000M0?ooo`<0
fk:_103B[;<00`3A[[H0ajNh0<NW^0020<JX^`<0^j6n00<0[9S20:bJa@2/V/D00`2IT<T20823c@05
05mbcP0XD<D0:53502Q@a@2dBP008P3oool20?WLZP80mmb_0P3dgKD00`3bgKX0kMFk0>gE^`020>gE
^`80j]G000<0imG40>?>`P3Qc/D00P3Qc/D00`3Nc/T0f/O80=[7b0030=O7b`040=;2b`3?`/d0cl;=
0<o2c@@0akg@102o^=<00`2h/m@0]kCF0;NdeP030:n`f0@0YjgK0P2OZMd00`000000UZGP09JUh003
08fRhP<0Q9oU0`1lW^P207BMj`<0Kik^3`3oool00`000000oooo0?ooo`030?ooo`@000009`3oool0
03D0oooo0`00000A0?ooo`@0cjRa0`34X[L20;JI^P80]Ybm0`2TTL4208b3a@80J6o700<0=E?3000K
Y`0006h09P3oool20?;=ZP80l<j_0`3^c[<0103/ckL0iLRj0>G8^P3Ub;X30>?9_@<0g<?00P3J`l@0
1@3D_L@0d[k70=:na`3B_/L0bkS800<0bKW;0P32]<`20<2ec`<0^:oA0`2][=H30:>Vf0<0UZ7K0`2<
W^0307jIh`80LIGU0P1LRnH304n8j080AHSZ0P0aP^T202n8k00402>9j`000000000003:KlP<0>:Wc
101Yb?h408oJoa@0oooo00<000000?ooo`3oool0G@3oool3000001l0oooo0`3K/Zl00`3I/k40dZbc
0=://`020=6^]P040<NW^036Z;/0aZRk0<JX^`<0^j6n0`2/V/D309V@b@80P8?=0P1OL/h203ELc003
000`]`2dBP00oooo0200oooo00<0nMbZ0?OL[`3gg:l00P3dgKD20?;M^P030>oM_`3]eK/0kMFk0080
j]G00P3WeL@30>7>a@<0g/k9103Gal/30<o2c@80cL;@0P37_M020<FmdP<0_kSC0`2g]=H20:n`f080
[k7J0`2W[M/00`2OZMd000000000000209JUh0@0T:GS0`28XnH3086Rj080NZ;[0`1fXnh?0?ooo`03
0000003oool0oooo02d0oooo000c0?ooo`8000004`3oool50<nX/@030<jY]034X[L0a::g00@0]Ybm
0`2TTL4208b3a@80J6o70P0eDl<00`006jL0oooo0?ooo`0T0?ooo`040?KF[03`cZl0l<j_0?3>[`80
k/jc0P3/ckL00`3Yck/0iLRj0>G8^P030>?9_@030>79`@3L`l00f/?40080f/?4103B_/L40<Vib`@0
`;G?102g/M<30:f/eP<0XjSJ0`2HXmd308bNh080OYWS0`1aUND206BAj080FHoZ0`15R>X01010Rnd0
000000000000000203JDl@0300000014Y?L0A:Cg0080B[7i101cb_l409?HoQ<0oooo00<000000?oo
o`3oool0F`3oool200000240oooo0`3K/Zl20=Vc/@040=://`3A[[H0dJjf0=6^]P@0aZRk0P2kXKh2
0;ZS`@<0[9[50P2IT<T20823c@<0Gg;>0P0eG<`00`39E`00001/0?ooo`0N0?ooo`040?WLZP3gg:l0
mmb_0?OL[`80m=fe0P3bgKX20>oM_`80j]G00`3WeL@00`3TeLP0hLk50>7>a@020=k>b@80flk<0P3G
al/20=C8cP040<o2c@3=`]00cL;@0<g2d0@0aKgB0P2o^=<20;jie@80]kCF102_/MX0102W[M/00000
0000000000020:2[gP030000002HYn40V:OQ00<0T:GS0`28XnH3086Rj0<0NZ;[0`1fXnh?0?ooo`03
0000003oool0oooo02`0oooo000a0?ooo`8000005@3oool0103G[Zl0cjRa0<nX/@3?Z;420<jY]080
a::g00@0`jBj0;JL_@2fW;d0]Ybm102UU<@208j8b080KWK;00<0=E?3000//`2aB`00903oool20?KF
[080m=J`0`3^c[<20>c?]`80jLnk0`3SbKd20>79`@@0f/?400<0elC70=:na`3B_/L00P3@_lX20<Vi
b`80b;[=0P30]Ll20;nfd@<0]k7C102][]P20:>XfP<0V:?M0`2<W^0207jIh`<0LIGU0`1TTNP205V?
jP<000000P1=Tnl203nBl00304JLm0000000AYcd0080DZ[i0`1I]o`407c;o`@0UmKm4P3oool00`00
0000oooo0?ooo`1H0?ooo`8000008`3oool00`3Q^:h0fk:_0=^b[`020=Vc/@@0dJjf00@0cjni0<JX
^`36Z;/0aZRk102jXl430:bJa@<0ViC<0P24R<l206IidP80=Ec<00<00d720<UG003oool07P3oool0
0`3iiZd0mnNc0?OW/`020?CM]@80l]fj0`3_gKl0103/gL<0imG40>OEa03WeL@30>CEb080g/k90`3K
c/`40=C8cP<0cL;@0P3;`]830<FmdP@0_[WE0`2f]MP0102_/MX000000000000000030:N^g@80X:_N
00@0000009RWh@2HYn40V:OQ0`2BYn@308bViP<0QJGY0`20YN`307bWkPh0oooo00<000000?ooo`3o
ool0;03oool00340oooo0P00000E0?ooo`80ejj_00D0cjRa0<jY]03>ZK@0cZVd0<BR]`030<>T^P03
0;JL_@2fW/00]Yk000<0YIC40P2>R<P206ifb`03041Nb@00;;<002bc02@0oooo00H0m]J/0?CF/03d
e[00m=J`0?;G]@3^c[<20>c?]`<0jLnk00<0im2o0>?9_@3QbL400P3QbL400`3NbL@0f/?40=[3a003
0=O4a`@0d;o:1038^/d30;nfd@80]k7C0P2f/]D30:f^f0<0Y:_L0`2IY]h308jQh@80PYgT0`1gVNL0
1@1/UnT00000000000000000HYK/0080FiK^0`1=Tnl204fIlP0305>SmP000000DZ[i0080DZ[i0`1U
^_d408?;oP@0V]Cl4P3oool00`000000oooo0?ooo`1G0?ooo`8000008P3oool20>6h[P050=^b[`3I
/k40fK>a0=Vc/@3H];@00P3A[[H30<n_^@030<JX^`35Z[h0aJZn00<0^Z?1102/WLL309^Dc080Q8S?
0P1VNM801011Im400d720<UG0039E`0M0?ooo`050?WV[@3gik<0mnNc0?OW/`3eikT00`3bgKX20>oM
_`80k=g30P3XgLP30>CEb080h=C<103Kc/`00`3HcLl0e<S>0=C8cP020=78d@040<g2d03;`]80bl;B
0<_2dP@0`kkE0P2n^MD20;bje`<000000`2^/]/30:N^g@<0XJgO00@0000009ZZhP2JZ^80VZ[R0`2B
Yn@208bViP<0QJGY0`20YN`307bWkPl0oooo00<000000?ooo`3oool0:`3oool00340oooo0`00000C
0?ooo`<0ejj_103>ZK@40<>T^P<0]Yk00`2UU<@208j8b080KWK;0P10G/T00`06?Kh000:D0?ooo`0Q
0?ooo`80m]J/0P3de[020?;G]@<0k<ng0P3Yck/20>O@_`<0hLW10`3NbL@30=O4a`80eLC:0P3@_lX2
0<joc@80b;[=0P36^m020;nfd@@0][;E102][mT30:B[g080VJKN0`2>XN4308:Mi00307NIi`000000
00000080K9OY0`1RU^`205^FkP<0F9Wa0P1IWo@00`1CXoH0000005n_nP0205n_nP<0Kkgm1028b_d4
09cBna40oooo00<000000?ooo`3oool0E`3oool00`000000oooo0000000Q0?ooo`80hKR^0`3I/k43
0=Rd]0040=6^]P3?[kT0cjni0<n_^@@0aJZn00<0^Z?10;ZUa02jYL@00`2/WLL309^Dc080Q8S?0P1V
NM82045Wd@0301E@b`3AF`00ZC<001`0oooo00<0nNJ]0?OW/`3gik<00P3eikT20?;W_`80kmfo0P3/
gL<30>SMb0030>GLc03TeLP0h=C<0080h=C<00<0gMC?0=_>c03Kc/`00P3HcLl40=78d@<0bl;B0P38
`mD30<>ne@040;bje`0000000000000000@0]KKJ0`2^/]/30:N`gP<0XJgO00<0000009ZZhP2JZ^80
102EZ^D208nXi`<0RJSY0`25Z>`308:ZkPl0oooo00<000000?ooo`3oool0:P3oool00340oooo00@0
00000?ooo`3oool000004P3oool30=N^[`030=J`/P3>ZK@0cZVd0080cJ^g0P33Y;X20<:U_0<0]Yk0
0P2UU<@3092<b`0607=mcP10G/T0@5k9041Nb@06?Kh0WSP08@3oool0103feZ`0m=J`0?CF/03de[02
0?;G]@80kmNi0P3Yck/30>O@_`030>C@``3QbL40hLW10080g/W40P3Lb/L0103Ga<L0eLC:0=G4bP3E
a<X40<joc@@0a[_@0`2n]m<20;Jbe@80]KCG0`2][mT30:B[g0<0VjSP0`2@Y><300000080NigX0`1b
VnX306ZKk@0406BLk`1HVO40F9Wa05RIl@<0FIod00<0GZSg0000001NZ?L00P1Y/o/307Noo@@0SLWl
0`2Ld_/B0?ooo`030000003oool0oooo05H0oooo0P0000000`3oool000000?ooo`0N0?ooo`<0hKR^
00<0h;V`0=Vc/@3I/k400`3H];@40<n_^@040<j`_035Z[h0aJZn0<FZ_P@0^ZG40P2/WLL409bGcP80
QhgB0P1]P=D01@1<L=H05E3;01E@b`3AF`00ZC<001X0oooo00D0nNJ]0?OW/`3gik<0mnNc0?GW^@03
0?;W_`040>oWa03/gL<0k=g30>cM``80j=g80P3Ug<`30>3Dc0<0gMC?0`3HcLl00`3DcM80dLSA0=78
d@030<o7d`@0b<?E00<0`KkG0000000000000P2l^]L20;Zjf@<0]KKJ102^/m`30:N`gP<0XZkQ00<0
000009^/hP2K[>800`2EZ^D308nXi`80RJSY1029Zn`308J]kPh0oooo00<000000?ooo`3oool0:P3o
ool00300oooo0`0000020?ooo`030000003oool0oooo00h0oooo0`3G[Zl20=J`/P050<jY]03=ZkL0
cJ^g0<f[]`33Y;X00`32YK`30;JN`0<0YYO70`2@S</00`1cOLh0BfO>04]WcP0200Hm_P0309hh003o
ool0oooo01d0oooo0P3feZ`20?CF/080l]Ne0`3_ekT0103]ekh0im2o0>O@_`3Wd;l30>C@``80g/W4
0`3Lb/L40=G4bP030=?5c@3>_ld0c[o=0080c<3?0P36^m020<BldP<0_[OC102e]=L20:f_f@@0Y:gM
0P2KZ>03000000<0QZ7U0`1kWNP207:KjP<0JY_]0`1TW>l206:OlP<0HjCe00<0000006R/n01X[?P0
0`1a]_X207k0o0@0T<Wk0`2Nd?TB0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0L0?ooo`80hKR^0`3P^K040=Rd]0030=Ne]`3?[kT0cjni0080c[2l
0P35Z[h20<B[`@<0^ZG40`2/WlX309bGcP80QhgB0`1]P=D01@1<L=H09UkB01E@b`36B`00ZC<001P0
oooo0P3iiZd20?OW/`80mNNi0P3bikl20>oWa080k>K90P3XgLP30>GLc080h]_?0`3Me<l20=[CdP04
0=S=c`3DcM80e<gB0=C=dP<0clOC0P3<amH01038`mD000000000000000030<6ne`<0^[[I102d]m/3
0:jcg0@0Yk7O0P2R[^400`000000VjcR09^/hP0409N/i@<0TZ_W0P2=ZnT308V[k0<0QZg^3`3oool0
0`000000oooo0?ooo`0Y0?ooo`00<03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00d0oooo00<0gKF^0=N^[`3F/;800P3F/;840<f[]`@0`ZFl102fX<<20:JGa`<0T8c;0P1cOLh204]W
cP0301M<aP2nC@00oooo01h0oooo00<0n=n^0?CF/03de[000P3bekD30>oG^@80kMNn00<0j]O20>O@
_`3Wd;l00P3Td<<20>;@aP@0g<[700<0fL[;0=G4bP3Ea<X00`3CaLd30<c0c`@0a;cB102l^=D30;Fd
e`<0[K7K0P2T[Md300000080W:_Q0P2BYn@308VTiP<0P:7Y0P1gWn/3072Ok@<0K:3`0P1ZXo8206^X
m@0306R/n0000000J:ch00@0NKSj0`24`?/20939n`@0Wlkh4@3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool30>6h[P<0h;V`00<0g[Zc0=Rd
]03H];@00P3G]KL0103?[kT0c[2l0<j`_03>/;`40<B[`@80^ZG40P2iY/L30:bObP80W9O>0P27SM83
06f0e@80C73F00<09UkB0=5K0036B`00603oool00`3elK40mnNc0?OW/`020?GW^@80l^No0P3_il@2
0>cVb@80j>G=0`3Ug<`20>;Kc`80g][C00@0gMC?0=[CdP3Jdm80f]?B0`3DcM820=7=e@030<o7d`3<
amH00000008000000`36`mL40;nnf@030;Zjf@2i^m/0^K_K00<0];OK102]]=h30:Nag`80XZkQ00@0
WJkS0000002M[^<0WJkS0`2G[>D309:[i`<0SJ_Y0`2=[^`308^_kPh0oooo00<000000?ooo`3oool0
:@3oool002@0oooo00<000000?ooo`3oool00`0000060?ooo`8000001@3oool00`000000oooo0?oo
o`0;0?ooo`80gKF^103F/;801@3E/KD0cJ^g0<f[]`3=ZkL0c:bj00<0`ZFl00@0`ZNo0;JP``2fX<<0
]Z330P2VUlL409:@cP0307R3d@1;Ilh0BfO>00805dc600<0_Td00?ooo`3oool06`3oool20?SO[P80
m^2c00@0ln2i0>oG^@3_ekT0kmNi0P3]ekh30>[G`P80i=330`3Rd<H00`3Od<T0g<[70=c:a`030=W:
b`<0dlG=0P3@aLl00`3<`<l0b/3A0<[0d@020<BldP80`kcD0`2l^=D40;Bef@040:faf`0000000000
00000080YJkO0`2LZn4309:Wi080RJCV0`20XNT207NOj`<0L9o]0`1/X?0306ZSlP80JjSe00<0L:oh
0000001`[oP00`1i^?X408S1nP80TlSj102PcOLA0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool00`0000060?ooo`8000001@3oool2000001X0oooo00<0ikn]0>6h[P3P^K000P3P^K02
0=jj/`040=Rd]03G]KL0ekFg0=Ne]`@0c[2l00@0cK6o0<B[`@34Zl40a:_1102iY/L30:bObP<0WI[@
0P2:TM@307>6f00305Iif@0VG]809UkB0080aT/05P3oool20?Ga/@80lo:h0P3al[l00`3^lLH0knO4
0>oWa0020>cVb@80j>G=0`3Ti=420>;Kc`<0g][C0`3Jdm820=KBe@<0dLgE0`0000000`3<amH0bLOH
0<W7f0020<K3e`80`l;I0`2o_]T40;Vkf`<0/[OM0`2]]=h40:Nbh080X[3Q00<0WJkS0000002M[^<0
102I[^D309B]i`<0TJgZ0P2=[^`308^_kPl0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0N0?ooo`00903oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`80gKF^00<0g;Ja0=J`/P3F/;80
0`3E/KD01@3=ZkL0c:bj0<b/^P3<[;X0`ZFl00<0`ZNo0P2fX<<30:JJb@<0TY3>0P1hPm4205AadP03
01M<aP2nC@00oooo01`0oooo0P3hgjh00`3fh;<0ln2i0??P^@020?7P_@<0kMNn0P3Zel820>OGaP<0
h]360`3Od<T30=W:b`80e/[=00@0dlG=0=35c`3@aLl0d<G?103:`=440<>le0040;bhe@2k^ML0^kWG
0;Bef@<000000`2]/]`20:F^g`@0WJgR0`2DZND208bWi`<0Q:CY0`1lXn`207JSkP<0LZC`0`1aYo<3
07:/m@030000001g/_L0O[Wi0080O[Wi0`28`OX409K7n0<0XL_f4@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool20>No[@@0h;V`0P3N
^[<40=Ne]`030=Ff^P3>/;`0c[2l00<0cK6o00<0a:_10<>]a033[L@00`2iY/L40:bRc@80WI[@0`2:
TM@207>6f080EWWI00@0=F[H0=5F0037A`00]cT05@3oool00`3elK40lo:h0??b^0020?7b_`030>ka
aP3[l<`0jo3<0080j>oA0P3XiLd30>CTd@80hN;E0`3Nf]<20=[IeP@0e];E0`0000020<k<e`@0bLOH
1033`]T40;fnfP80^K_K0P2g^m`30;:gg@<0[KGO0`2W/^030::`h@0309j_i0000000WZoT00<0VJkU
0`2D[NL409B_jP80TK3/0`2?/^h?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
7P3oool001`0oooo100000040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool2000000L0oooo0P0000090?ooo`80gKF^0`3L][40103F/;80eK6e0=Fa]@3E/KD40<b/^P@0
`ZNo0`2eX/D30:JJb@80TY3>0P1hPm4205AadP0302MIcP00:k@0_Td001/0oooo0P3hgjh20?KP/`80
ln2i0P3ah;d20>kP`P80j]O20`3WelH00`3TelT0h]360>;@aP020=o@b@80g<o=00@0fL[;0=K:c@3F
b/d0e/[=0`3@aLl20<k5d@80b/3A0P38`M@30<>le0040;^ie`0000000000000000<0];KK0`2]/]`3
0:F`h0<0WJgR0`2DZND208bWi`@0QjOZ0`20Y^`207^VkP<0N:Oa0`1gZ_<207R^m@030000001m]?L0
OKCg00<0Pk[h0`2<`OT409S6m`<0XL_f403oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo03D0oooo100000040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo0P3W_jd00`3U`;00h;V`0>2i
/0030=jj/`030=fk]`3G]KL0ekFg00<0eKJj103=/Kl40<>]a0<0^:S90`2/X/d209fJd0@0SIGG00<0
N8cJ05Iif@1FNMT00P0eJ]P00`3AEP00adL00;Xf000C0?ooo`80mO6a00@0lo:h0?7b_`3al[l0k_76
0P3[l<`20>S_d@80i>gE0`3Ti=420>7Re@80gN7H103JfMH0103Gf=T000000000000000020=?Be`80
c/cG0P3<bmX20<W7f080a/OJ0P33`]T20<72f`<0_KkJ102g^m`40;6hgP80[KGO102X/n430:>ahP03
0000002N[n@0WZoT00<0Vk3V0`2G[nP309B_jP<0TK3/0`2B]>h>0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool07P3oool002@0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool30=fe[P<0
g;Ja103E/KD00`3C/[P0c:bj0<b/^P020<^^_080`ZNo0P31ZL820;FRa@<0YY[90`2DU=0207b8e005
05aieP0WFLh09eW>0<eF002]>P006P3oool20?SO[P030?KP/`3ch;T0ln2i0080lN2m0`3^h<80103[
glL0imO60>OGaP3WelH30>CGb@80gm390`3Lcld30=K:c@80e<[@00@0d<G?0<k5d@3>aM40c/GA1038
`M@01@31_MH00000000000000000^kWG0080^[[I0`2d]]/40:bdgP<0YK3P0`2N[n<309J/i@80SZWX
0`27YnX3082Vk0<0NjK^0P1hYo4307NZl`<0N:ke00<0000007fdm`27^oL00`27^oL308o1m`<0V<Kg
102Rb_@@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?@3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0C0?ooo`80ikn]0`3U`;030=jj/`<0gK^g103E][X00`3D]kd0cK6o0<fa_`020<^b`P80
`jg40P32[/H30;RXb@030:bRc@2/Y<l0[:C?0080WYgC0`2=UML207R<fP80Gh7L00D0@gGM0=5F003A
EP00adL00;Xf000A0?ooo`80mO6a00@0lo:h0?7b_`3al[l0k_760P3[l<`20>S_d@<0i>gE0P3PjmT2
0>7Re@<0gN7H00<0fMoK0=[IeP0000000P000000103Gf=T0dm;G0=?Be`3Cd]L20=3AfP@0c<_J1036
amX40<72f`<0^kkL0P2g^m`20;Jkg@<0/KSN0`2/]^030:Rch@<0Xk7R00@0Wk7T0000002O/N@0Wk7T
0P2K/>H309N_j0@0U[7Y0`2D/^`209:dkPl0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0N0?ooo`00903oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`80
00002`3oool00`000000oooo0?ooo`040?ooo`030>>k[P3M]Jh0g;Ja00<0g;Ja00<0fkNd0=Fa]@3E
/KD00P3C/[P01@3<[;X0bjjl0<^^_03;[[`0`ZNo00<0`JW20P2eX/D40:NMc080U9C@0`1lR=@01@1L
NMH0=FGD0=MU003=EP00V2@001P0oooo0P3hgjh01@3fh;<0ln2i0??P^@3ch;T0lN2m00<0k^320P3[
glL20>OOb`<0i=O90P3Qe/d30=c?c@80fLo?103Db]030<k5d@80c<GD0P38`M@2000000<0`KgF102j
^]T30;>gg0<0[;CN102U/^4309j_h`80UZcU0`2>ZNP308ZZj`<0Q:W]0`1oZNl207fZl@<0O:gb0`1m
/?@00`000000P[Gf08:emP0208Nkm`@0T/7f0`2JaOH40:?8la00oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0m0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0
oooo0P00000;0?ooo`030000003oool0oooo0180oooo0P3W_jd30>G0/0030>C1]03N^[<0g[Zc00<0
gK^g00<0fkbj0=Ff^P3E][X00P3D]kd01@3=/Kl0bk;20<^b`P3;//80`jg400<0`Zk60`2hZ<T30:bT
c`<0WYgC0P2=UML307R<fP80Gh7L0P3AEP000`37A`00^SH00;Xf000@0?ooo`80i_^e00D0i_bo0>Gl
b03Snll0ho_?0>7jeP020=kgf`<0i>gE0P3PjmT20=cYg@<0gN7H0`0000030=OHf@80dmOK0`3@dMX2
0<g@g080c<_J0P38bm`20<K7fP80a<KL0P31`]/20;o2g080^kkL102f^md40;2hg`<0[;KP0`2X]>83
0:>bh`0309nai0000000Wk7T00<0WK7V0`2I/NP309Jaj@@0UkC[0P2F]^d>0?ooo`8000001P3oool0
0`000000oooo0?ooo`0N0?ooo`00903oool010000000oooo0?ooo`3oool4000000<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`80hk^^103L][420=^g]0040=Fa]@3C/[P0
dk:h0=>b^0@0bjjl1031ZL830;FTb0<0Yig<0P2DU=0307b8e080G7WF00@0=FGD0<eF003=EP00V2@0
5`3oool20?O[/P040?G[^@3bjkh0l^^n0?7P_@<0k^320P3[glL30>OOb`040>CNcP3TelT0hMK=0>7F
c@80gMG@103Icll00`3Fcm80e<[@0=C:d0030=79dP80c<GD0`0000020<K1eP@0_kkH0P2j^]T20;Vk
f`<0/kOL0`2/]Ml30:Fbh@@0Wk3T0P2H[^H3092/j0<0RZ[[0P24ZNd307nYk`<0OJ[a0P1l[O8408:b
m00300000025]_D0QKKe00<0Rk_f0P2B`OH409_5m0<0XlSc3P3oool3000000H0oooo00<000000?oo
o`3oool0?@3oool010000000oooo0?ooo`3oool4000000<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0@0?ooo`80ikn]0`3U`;030>C1]0<0gK^g0P3K_;X0103E][X0e;Nm0=Bg_@3D
]kd40<^b`P@0`Zk6102hZ/`20:bTc`@0Wj3D0P2@VMP307fAg00706N8g`13MMd0bT/00<Y;0030>`00
/bT00:PQ000>0?ooo`80i_^e00D0i_bo0>Glb03Snll0ho_?0>7jeP020=kgf`<0f_GO00D0h>_I0=cY
g@3LjMd0g>WM0=SVg`0300000080fMoK0P3EgMh30=?Gf`80d=GM00@0d=7J0<g@g03=d=`0cM3L1038
bm`40<C6g0@0_l;L0`2j_]h20;Jkg@80];_O0`2`^=l40:bfh@<0Z;CR0P2S/^<20:2bi0030000002P
/^@0WK7V0080WK7V0P2I/NP409Vcj@<0UkC[0`2F]^d<0?ooo`030000003oool0000000H0oooo00<0
00000?ooo`3oool07P3oool002D0oooo00<000000?ooo`3oool01`3oool2000000d0oooo00@00000
0?ooo`3oool0oooo0P3S^jh0103R_;40g;Ja0=bf/@3L][420=^g]0@0dk:h00<0d[>k0<^^_03;[[`0
0P39[kl20<6Y`P80`:_50`2eY<P20:NMc0<0UYOC0`20SML01@1TP=T0=FGD0=UT1P3@EP00_dD001H0
oooo0P3gjk801@3ejkT0l^^n0?;[_P3bjkh0l>_40080kN[90P3[glL30>OOb`80i=k>0P3Qe/d30=gE
d0030=[Dd`3Icll0fLo?00<0e/oB0`3AbM83000000040<c5e039aMH0bLGF0<K1eP80a<7H0`2o_]P4
0;Vkf`@0/[SM0P2/]Ml40:FchP<0Wk3T0P2H[^H409:^j@<0S:c[0P27Znd308>/k`<0PJga0P20[o83
08:bm00300000025]_D0QKKe00@0S[ce0P2D`?D409c4l`<0XlOb403oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01`3oool2000000d0oooo00<00000
0?ooo`3oool03`3oool00`3[aZh0iL2`0>G0/0020>G0/0<0i<6d00<0h/6g0=fk]`3K_;X00P3K_;X4
0=Bg_@030=:h`03;//80bk;20080b[C40P32[/H20<6`b@<0^:[<0`2/Y]4309nPe0<0T9WH0P1mTM`2
06N8g`0704mnh03:B`00bT/00<0k002c:@00XA<0000UY00;0?ooo`80i_^e00D0i_bo0>Glb03Snll0
ho_?0>7jeP020=kgf`<0f_GO00@0eo;S0=?^iP3Ck^H0dnkV0P0000000`3Hi]l0e>CR0=CThP030=GM
gP80dM_P103@eMd30<g@g080bLoN0P38bm`20<K:g@80a<KL0P31a]d20;o2g080_L;N0`2j_]h30;Bk
g`@0/;WP0`2/]^440:RehP80Y;?S00<0X;;T0000002P/^@0102N/^H309^bj080VK?Y102J]N/309Vg
k@h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000
oooo0?ooo`0=0?ooo`040000003oool0hk^^0>>k[P<0h[ba00D0g;Ja0=^g]03K]k@0fkNd0=Zh]`02
0=>b^0<0d[>k1039[kl40<2[a@80]JC80`2WWlh309JGd`80P8gG0P1TP=T01012L=T0d5H00=1F0035
AP0E0?ooo`80mn^b0`3bjkh00`3`jl@0kN[90>gZb@020>WXcP<0imo;0P3Tg/h20>7MdP<0gMG@0`3J
e=<30=K?dP040=?>e0000000000000000080clWE1039aMH40<C1f0@0_[kJ0`2h^m`30;:hg@<0[;KQ
0`2U/n8409nbi@80VK3W0`2B[^T308b/j`80Qj_]1026[^l308B_l080Q;7b0`26/o<00`000000RKOd
08Vgm00308jlm@<0U/3d0`2La?<40:C6lA00oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool20>_6[P030>[7
/@3U`;00iL2`00<0i<6d0P3R`KL40=^l^P030=Vm_@3D]kd0e;Nm00<0d[S0103:]<@40<6`b@030;RZ
c02g[<h0]jc>00<0[:KA0P2OX=@409:LfP80PIKN00@0KXkQ04mnh03:B`00bT/00P30>`00102c:@00
XA<007T0001i00080?ooo`80i_^e00D0`_c20<GncP37omP0aooH0<Snh0020<SkiP80aoS[0P3Gl^<0
1@3Ck^H00000000000000000d>_X00<0e>CR0P3Ah^@30=7Kh0<0c]WR103<e=l40<W?gP<0a/[M1031
a]d40;g2gP@0^;kO00<0];_O0;>kh02c^n000`2`^N040:^ghP<0Z;GR0`2T]>@00`2Q/nD000000:6c
i@0309jbiP@0WKCX0P2K]>T309Zej`@0VkS/3P3oool00`000000oooo0?ooo`0S0?ooo`00;`3oool2
000000l0oooo00<000000>>k[P3S^jh00`3R_;430=^g]0<0f[Rg103B/k/00`3A];d0bJno0<V__`02
0<R``P<0`:_50`2dY//30:NOcP80UYOC0P20SML206B0f@05049`f@3II0H0d5H00=1F0035AP004`3o
ool20?O[/P<0l^^n0P3`jl@0103]j/T0jNS>0>WXcP3Yj<h20>GWdP80i=k>0`3QgM820=gKe0<0f]CC
0P3GdmD3000000040=?>e03?bMD0clWE0<o9e@80c<WG0P39aMH20<O5f080a<7H0P32`]T20;jnfP80
_KoK0P2h^m`40;:ig`<0[;KQ0`2V]N<309nbi@<0VK3W0`2D/>X308n^k0<0RZg]0P26[^l308B_l0<0
Q;7b0`29]O<00`000000S;Sc08bhl`03092lm080U/3d102M`o840:C5l0l0oooo00<000000?ooo`3o
ool0C@3oool2000000l0oooo00<000000?ooo`3oool0303oool20>_6[P80j/Na103T`K@20>;1]`03
0>32^P3K_;X0fkbj00<0fKfm0`3B^<020=2i``80b[C40P38]LL30<6`b@@0]jc>0P2/Y]430:2Re`<0
TYcJ0P21U]h206j>h@0305Z7h`2k=P00^cH00080/2D00P2Q400208`000L0oooo00@0_?Nc0<;l`P37
omP0aooH0P38o^001@38nnH0aoS[0<Ohj`37n>/0aOG^00<000000`3@jnP30<cXjP80dN;T0`3=gnH3
0<kIhP80bmSS0P3<e=l20<WBh@@0alkO1033bMl40;o5g`<0^/;O0`2h_]l40;>kh0<0[kWQ0`2[]n84
0:Rfh`<0Y;CT00<0XK?U0000002P/nH00`2P/nH309fdj0<0WKKY0`2L]n/309^hk0h0oooo00<00000
0?ooo`3oool08`3oool002l0oooo00<000000?ooo`3oool03P3oool20>>k[P@0h[ba00<0h;fd0=^g
]03J^;L00`3J^;L00`3H^KX0d[>k0=:c^`020=6d_@040<V__`38/<80b;320<R``P80`:_50P2o[<L2
0;BVb`@0Yj;A0P2HVmD208BBf@80JhOL00<0CG[M0=1F003@EP000P35AP0A0?ooo`80mn^b00<0k_O0
0>cga`3/mlL00P3`jl@0103]j/T0jNS>0>WXcP3Yj<h20>GWdP80h^GE0`3QgM820=gKe080f][G00D0
em?E00000000000000000=CCf0020=?>e0<0d<kG0`3<bML40<O5f0@0`/;I102m_m/30;Nlg@<0/[WO
102/]n830:Jeh`<0X;?V0`2J/NP209B`jP<0Sjk/102<[nd208V_k`<0Qk3`0`27/_8208Vel`030000
002<^?<0S;Sc00@0T[cc0`2H_o<309k2l@<0Y<G`403oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool20>_6[P<0j/Na00<0j<Ne0>C1]03T`K@0
0P3R`KL30>32^P<0fKfm0P3H_/00103B^<00d;W30=2i``3@^L<40<Rea`80`K390P2o/L`30;N/cP<0
[:SC0`2PX]L209:LfP80PIKN0`1^S^400`1JQn<0^cH00;/f00020;0U0080XA0000<0SP0007H00000
>Z<0103oool20<;l`P80S^kH0P2Gl^@00`2Nlnd0Xo;c0:?bl`0300000080`o7`0`31kO430<cXjP80
bNG[0`3=gnH20<[Mi`@0bmSS0`39d^420<KAh`80alkO0P34cN420<?9g`80`LWQ0P2oaMl20;g5h@80
^/;O102f_^040;:lh@<0[kWQ0`2[]n830:Rfh`@0YKGT00<000000::di@2P/nH00P2P/nH409nej080
WKKY0`2L]n/409jjk0h0oooo00<000000?ooo`3oool08P3oool002H0oooo0`0000060?ooo`030000
003oool0oooo00h0oooo00<0j<:_0>>k[P3R_;400P3R_;420>2m]0@0f[Rg0P3H^KX0103B/k/0dKBm
0=6d_@3A];d40<R``P@0_jc700<0]:K;0;BXc@2dZ<d00`2WX]4209RKe@<0Q9;I0P1[Qm`01@3DG0`0
c4h00<a>0032?P00XQ`00100oooo0P3`mkP20>cga`80jOK=0P3Vm=820>?be`040>GWdP3RiMD0h^GE
0>;Ue@<0g^?H0P3Mfm@0103Jf]L000000000000000020=OCe@<0e=?H0`3@c]L20<k=f@030<c9e`3:
bMT0b/WI0080alGH0P35aMX20<;2f@80`L;K0P2m_m/20;^og@<0]kcM0`2a^^030:bghP@0Y[KT0P2P
/nH409^cj080U[7Z0`2@/>`308b_k@80RJo_102:/_0308Zcl@80RkKb00<0000008jil`2>^O<00`2B
_?<409VolP80W/;a102Ta?0?0?ooo`030000003oool0oooo0480oooo0`0000060?ooo`8000004P3o
ool00`000000oooo0?ooo`090?ooo`80jlJ^0P3Zak430>S7]@<0h/6g0`3P`[X00`3N`kd0fKfm0=Rn
`0020=Rn`0@0d;W300@0ck[60<Rea`38]LL0b;G7102o/L`40;J]d080[:SC102QYMP209BOg080QI[O
0`1eU><00`1SS^D0^cH00;/f000309400080OP000P1X00001@1J0000oooo08;Wa`22ilL0S^kH0080
Uo;T00<0W_?]0:?bl`0000000P0000030:W]n@80`Nga102ojO830<WUj`80a^;/0`3:gNL20<KJj080
bmSS0P37e^D40<KAh`@0a<gQ1031bN440;g5h@<0^L7Q0P2f_^020;Bnh@<0/[cQ102^^N820:^ghP@0
Z;KS0`2U]N@00`2S]ND000000:>ei@030:6eiP<0WkGX0`2O]nT309jhj`@0X;_/3P3oool00`000000
oooo0?ooo`0Q0?ooo`009P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0
oooo0P3X`Zl40>:l/@80h;fd00<0gkfg0=Zh]`3J^;L00`3H^KX40=6d_@030<nf`038/<80b;320080
ak750`2o[<L40;BXc@80Yj;A0`2IW]L308NFf`80LHgN00D0e5`<0<a>003<CP00`Sh00:8L000>0?oo
o`80l?Nh00@0k_O00>cga`3Ym/d0jOK=0P3Vm=820>?be`80gnoK0P3KkMh30=kSf080f^7K0P000000
103Jf]L0e]WJ0=KIfP3FfMX30=CCf080dM;J103>cMT40<[9f@@0aLGJ0`31`]/40;^og@@0][gO0P2a
^^040:bhh`<0Y[KT0`2Q]NL309^cj0<0U[7Z0`2B/^`308jakP<0S;7_0P2:/_0308Zcl@<0S[Kb00<0
0000092ilP2@^O800`2D_?8409Znl@<0Wl7a0`2U`nl?0?ooo`030000003oool0oooo0440oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo
0`3[aZh20>[7/@<0j<Ne00<0i/Rh0>;1]`3P`[X00P3P`[X20=k3_@@0f;k000<0e[k30=2i``3@^L<0
0`3?^/H00`38]LL0akK:0<NfbP020;nac080_[;>0`2f[M030:bZe@<0XJGH0P2DWm`308FJg`80MICS
0P1SS^D309lD0080T@000P1200001`000000H/fK001[d@00Jm400XCL00bDg00[/N000`00000408?N
o0030:[YnP2[i_X0ZnKj0080ZnKj102mi_<30<KRk0<0`mo]1036f^P20<OFi@80a=CV0P36dN<30<?@
i0<0`LcS102nb>820;g5h@80^/CR0`2i`N430;Bnh@@0/;cR0`2^^N830:Zhh`<0Z;KS102U]^@00`2S
]ND000000:>ei@020:6eiP@0XKKW0`2O]nT30:6ijP<0X;_/3P3oool00`000000oooo0?ooo`0Q0?oo
o`00803oool4000000D0oooo00<000000?ooo`3oool00P3oool2000000l0oooo0P3X`Zl00`3V`[80
h[ba0>:l/@020>2m]0<0gkfg103H^KX00`3G^[d0dKBm0=6d_@030<nf`0@0ak750`2n[/X30;BXc@<0
Z:CC0`2IW]L208NFf`80LHgN0P3DG0`01@3<CP00`Sh00<8n002c:`00RP<000/0oooo0P3`mkP0103^
ml00k?O70>Wfc@3Ym/d20>KddP040>?be`3Okm/0gnoK0=o_f`80fngN0P3Hj^40103JhM/000000000
000000020=OOg@<0e]WJ0P3Cem`30=7BfP80c]7K0P3>cMT20<_<fP@0alSJ1033aM/30;o2g080^koM
0P2j_mh30;Jmg`@0/K_Q0`2[^^@30:Jgi@<0XKGW0`2L]>T309Ncj`80T[;/0`2>/Nh408fbk`80S;?`
0`2<]?4308jflP030000002@^O80U[cb00<0U[cb0`2J__440:31l080YL?_403oool00`000000oooo
0?ooo`0j0?ooo`@000001@3oool00`000000oooo0?ooo`030?ooo`800000503oool00`000000oooo
0?ooo`060?ooo`80klj`0P3Zak430>S7]@80i/Rh0`3P`[X30=k3_@030=c3`@3H_/00f;k000<0e[k3
103?^/H40<NfbP@0_[;>0`2e[m830:bZe@80XJGH0`2FX]d308VMh@80NiWT0P1[U>L506`0000501@0
000]Q^/0;HK[01N0iP07O^400`00000202NTj`80ELGg0P2;g_h4093MoP@0Zn?j102kh_<30<?Ok@80
`=c]1034f>T40<CDiP<0`m3T0P30cnD00`31c><0_/_T0;k;i0030;k8hP@0^/CR102g`N830;>nhP<0
/;cR102]^N<30:Zhh`<0Z;OT0`2U]^@20:Bfi@040000002T]^D0X[KV0::fiP<0XKKW102Q^>T20:6i
jP@0X[c[3P3oool00`000000oooo0?ooo`0P0?ooo`009P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00d0oooo0`3X`Zl20>K2/P<0h;fd0`3O_KL00`3M_[X0f;Vj0=Ri^P030=Nj
_@<0ckK00P3>]l<20<Naa@80a[?70P2n[/X40;>Zc`<0Z:CC0P2IW]L208NFf`80LHgN00D0Eh;P0<Y=
2`3:C@/0`Ch00;H]00020;<[000308P0003oool0oooo00L0oooo0P3`mkP0103HolL0f?o@0=Sod03G
o]P20=KlgP80doWS0P3Am^L20=_]gP050=SZh@00000000000000003Din<00`3Ggmd20=?Mg`<0dmOL
0`3@e]d30<kAf`<0blcJ0P39c=`20<O8fP80aLSL0P33aM/20<;5g0<0_l;L0`2j_mh40;Fmh0@0/;cR
0P2[^^@40:JhiP<0XKKW0P2L]>T409Rdj`80Tk?]0`2@/^h308fbk`80S;?`102>]O4208ngl@040000
002B^O80T[Wb09:ilP<0Uk_a0`2K__430:31l0<0YL;^3`3oool00`000000oooo0?ooo`100?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0503oool2000000D0oooo0`3_c[000`3^
c[@0j<Ne0>S7]@020>S7]@80i/Rh0P3Tb;`30=k3_@<0g<?10`3F_/<20=BoaP80ck[60P3=^lT20<Nf
bP80aKO<0P2n//h20;fcd080]JoB102/[=L20::WfP<0UZ;M0P29WN4307^Ii080JiCW0P1LT>T204n>
k080AHk^0`000003022>k00303>QlP0m[o@0?Jod00@0L<cn102Dfoh40:cPn@@0^Moc0`30g>d20;kJ
kP@0`MKZ1031d^L40<3?i@@0_/_T0`2kan<40;S4h`80]l7R0P2d`N<30;>nhP<0[kcS0`2]^N<40:Zh
h`80Z;OT102V]^@00`2T]^D000000:Bfi@030:BfiP<0X[OW0`2Q^>T30:>jj@<0X[c[3`3oool00`00
0000oooo0?ooo`0O0?ooo`009`3oool2000000D0oooo0P00000>0?ooo`80j<:_0`3V`[820>G3]@<0
gkfg0`3M_[X30=Nj_@80eK^o00D0ckK00<jg``3>]l<0c[O30<Naa@030<Jca`030;j^bP2m[l`0_Jo<
00<0/j[?102XYmD209^Qf@80RY[M0P1gT^401@1PRN<0bTd;0<Y=2`31?P00]Rd00080YQP000<0R000
0?ooo`3oool01P3oool0103FoK`0f?o70=Sod03Hom020=KlgP<0doWS0P3Am^L0103>l^T000000000
000000030=CWh`80dNCU0`3CgMl30=3Kh@<0d=KM0P3=e=l0103>dM/0bm3M0<_@g@3;d=d40<W<g0<0
aLSL1032aM`40;g2gP<0^L3O0P2e_N020;Bnh@<0/;cR0`2[^^D30:JhiP@0X[SX0P2L]^X309Rdj`<0
Tk?]0`2A/nh308nck`<0S[C`0P2>]O43096gl@040000002C^O40TkWa09>il@80Uk_a102L_O030:30
k`<0YL7]3`3oool00`000000oooo0?ooo`040?ooo`D00000=`3oool2000000H0oooo0P00000G0?oo
o`030000003oool0oooo0080oooo0P3_c[020>k>]0030>c?]`3XakD0j<Ne0080i/Rh0`3Tb;`00`3R
bKl0g/>m0=k3_@020=c3`@80f/C400@0e[k30=BoaP3D_lH0e;o6103=^lT40<Fgc0@0_K?@00<0]JoB
0;B`e02d/=@00`2/[=L30::WfP<0V:GN0P2<XN83082Mi@80LiWX00<0IYO[04n>k00000000P000000
0`15S^h0?i7`03nAl002042Hl`80=Y[b0`17Z_P205jlo@<0N/ko102HfOd40:cMn0<0]mcc0`2nf^h2
0;_HkP80`MKZ0`2ne>/30;oAj0@0_/gV102lb^D00`2kan<0^LKT0;W6i0030;S4h`@0]<7S102a_^<2
0:nlh`@0[;[S0`2Z^><30:Ngi0<0Y[KT0P2U]^D010000000YKKU0:BfiP2T]^H40:Bhi`<0XkWX0`2U
^nT30:Bmj`h0oooo00<000000?ooo`3oool0103oool5000001H0oooo000W0?ooo`@000000`3oool0
0`000000oooo0?ooo`0<0?ooo`<0j<:_0P3V`[830>G3]@030>?4^03O_KL0gKjj00<0gKjj00<0fknm
0=Nj_@3E^kl00P3E^kl40<jg``@0a[?7102m[l`30;>/d@<0Z:OE0P2KXMT208ZJg@<0Mi;Q0P3:C@/2
0<4n00050;H]002V6000YQP009800000>ZX01@3oool0103FoK`0f?o70=Sod03Hom020;7jiP<0]?S]
00@0dOKW00000000000000000P3<k^`20<W[k@<0dNCU0`3=hNH30=3Kh@80cMWS103=e=l30<_@g@80
bLoN0P39c=`20<K;g@030<G8g033b=d0`lSM0080`/GL0P30aMh20;g2gP80_<;O0`2i`=l30;Bnh@@0
/;gS0`2[^^D30:Jii`<0X[SX0`2L]^X309Vfk0<0U;C]0P2A/nh308nck`@0SkG`0P2?]_03096gl@03
0000002C^O40TkWa00<0V;_`0`2L_O040:6okP80YL7]403oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03P0oooo100000040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool00`3_c[00103^c[@0k<ng0>c?]`3/ckL30>K8^080i<Rl0`3RbKl20=c3`@<0f/C4103D_lH00`3B
_lT0cK_90<fkb@020<^kc080aKO<0P33^<l30;fcd0@0];3D0P2/[=L40::Yf`80V:GN0`2<XN82082M
i@80LiWX0P0000000`1VUn/0FiG^05^EkP0205>Fl080Ci[c0P10V?<304RSm`80Ek7k0`1[`?h208;>
o`@0VmOm102[f_P40;KJl`@0^mS^0`2ne>/20;cCj`030;oAj02ld>T0_=3Y0080_/gV0P2kc>L30;c:
i@@0^LKT102f`n@30;?0i0<0/KkS0`2^^n@30:bjh`@0ZKST0P2W]n@40:Jgi@80YKKU00@000000:Fg
iP2U]nH0YKOV0`2T^>L40:Fjj0<0YK_Y0`2V_^X>0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05`3oool002h0oooo00<000000?ooo`3oool0303oool20>c9/0<0i/:b0P3U`kD20>?4
^0@0gKjj0P3K_kd40=Fk_`030=>k`P3>]l<0c[O30080c;S60P36/lL20<FdbP80_Jo<0P2l/Lh30;>/
d@80Z:OE0`2LY=/208fNgP<0O9OR0P2g<`420:`S00<0WPl000<0S00007T00000>ZX00P3oool01@3F
oK`0WO720:cjg@2/n]d0/O[V0080]?S]00D0]OKa00000000000000000;Kbm0020;K^mP<0bN_]0`36
inh30<gQiP80b]kW0`3=fN<20<[Gi080cMCO0P3:dn440<W?gP@0a/_M1033b=d40<35gP<0_<;O102h
`N030;BohP<0/;gS102[^nD20:Jii`@0X[WY0`2M]n/209Vfk0@0U[G]0`2B]>h2092dk`<0SkG`0`2A
]_0309:gl0030000002D^O00U;W`00<0V;_`0`2L_Nl30:6okP@0YL3]3P3oool00`000000oooo0?oo
o`050?ooo`800000@03oool00`000000oooo0?ooo`0H0?ooo`040000003oool0klj`0>o>/080k/jd
0`3/ckL20>W?^`80i<Rl0`3RbKl20>39`P@0f/C400<0f<C70=BoaP3D_lH00`3B_lT40<^kc0@0`kS?
0`2l]=830;B`e0<0[:gI0`2RZM/309ZWg`<0SjCS0`0000001@1iW^T0Kic/06nLk01_W>`0IIc_00<0
DiK`0P1?V_<2052QmP<0Ej[i0P1T]_`307C2oP80R<kn102MeO/40:_Hm`@0]=Ob102ie^h40;cCj`@0
_=3Y0`2kc>L40;W9iP@0]lKU102d`nD20;?0i0@0/;kT0`2^^n@30:^ji0<0ZKST102W]n@50:Jgi@04
0000002U]nH0YKOV0:FgiP<0YKWW0`2U^^P40:Jlj@80Y[kZ3`3oool00`000000oooo0?ooo`040?oo
o`8000005`3oool002d0oooo0P00000=0?ooo`<0k<V`00<0jlVc0>K2/P3U`kD00P3U`kD20>?4^003
0>74^`3M_[X0gKjj00<0fknm00<0f/300=Fk_`3E^kl00`3C^l840<bhaP@0aKC:0`2l/Lh20;>/d@80
/ZkC0P2XZML309bTf`80SIkN0P1lUn800`1XT>D0]c<10;Lc0@020:`S00@0L`000P1L0000102Aj:l0
F]?>06cMg`1/gMl207[Tk0<000000P2=i_T20;K^mP@0]^[f00<0a^O^0<?SkP33hnh00P33hnh30<[N
i`<0amcX0`3:en@30<[Ch@80am7R0P39cmh20<K>g`@0a<[O1032amh40;k5g`<0^l?P0P2h`N020;O1
h@<0];oR0`2__N@30:^ki@@0Y[[X0P2R^NT409fhj`80VKO/0`2F]Nd409>fk`80TKG_0`2@]O03096f
l080TkS`00@0000009Fil02E^O00UKW`0`2H^o0309flk`<0XKk^102U_n`>0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`<0klj`00@0k/jd
0>c?]`3/ckL0k<ng0`3Yck/0103Wd;h0h/Vo0>;9_`3RbKl30>39`P030=g:a@3Ja<@0f/C400<0f<C7
0`3B_lT20<o0c080bk_<0P39_<h20<>hc`80`[SA0P2l]=840;>aeP<0[:gI0`2SZmd209ZWg`<00000
0P24XNH307VNj@80Kic/0`1UW>l205nMl@80G:7d0P1MYoL306B_nP<0K[Wl0P1ma?h308g>o@@0W]?j
102[e_H30;;ElP@0]m?_102idN`40;[>j@@0^L_X0`2gb>L20;O6i@80]LGV0`2d`nD30;70i@<0/;kT
102]^n@30:Zji0<0ZKST102W]n@40:Jgi@030000002V^>H0Y[SV0080Y[SV0P2U^NL40:Nji`<0Y[cY
0`2X_^T>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool002d0oooo0`00
000<0?ooo`80k<V`0P3[bK<30>G3]@80hlBh0`3Qa;/30=^o_@<0f/300`3C^l820=:la@80c;S60P3;
^LP20<FdbP80`kG<0P2l/Lh40;:^d`80Z:WG102MY]`2092Qh080P9_T1@2D2P001@2600009`0002L0
000W0000TNR_008006WD00@007gL00000000000000000`1EbO800`2DiO`0VN?m09WSo@0209WSo@<0
]NKg0`2dhoH40<7Pk`<0amcX0P34fNT40<OEi@@0am7R0P36c]l20<C=h@80a<[O0P32bN020<;7gP80
`<OO0P2naMl20;g5h0<0^l?P0`2g`N440;>oh`80[kgT102[_>H40:Jkj080X[[Z0`2M^>/309Zhk@<0
U[K^0`2C]^l2096ek`L0TKK`0P2C^?000`000000UKW`09Fil00409Vjk`80WKc_102Q_Nd30:Fok0d0
oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000?@3oool2000001/0oooo0P3cek<0103^
c[@0k<ng0>c?]`3/ckL30>W?^`80im2n0P3Ud<830>39`P<0gL[50`3Ha<L20=K5b@040=:ob@3?`<`0
cl3<0<o0c0@0bKc>1032^=430;Zee0<0/k7F102[[mX0102SZmd0000000000000000209^Yh@80TZKS
0P28Y>L307nRjP80MZ7]0`1^XNl206VSlP0406NVm@1MYoL0GJOg05fWm`80I:oj101g_?`308?5o@80
TLgl102Pd_T40:[CmP@0/M?b102ed^l30;O@k0@0]lgZ0P2ibnP20;O:j@80]lSW102eaNH40;;2iP80
/L3U102^_ND40:bki@<0Z[[T0`2X^>@30:Ngi0<0YkOU0P2V]nD010000000Y[SV0:JhiP2V^>H30:Ni
iP<0Yk[W102X_NP30:Zoj@`0oooo0`0000040?ooo`050000003oool0oooo0?ooo`0000005@3oool0
02d0oooo00<000000?ooo`3oool02`3oool30>c9/080jlVc0P3Yb[L30>?4^0<0hLBk00<0glFn0=^o
_@3K_kd00P3J`<020=S1``040=>k`P3B_<D0d[c50=:la@@0bkW81033]L`30;^bd@<0/ZkC0`2XZmT3
09fVg080T:7P0`20Vn@206nFi`80E@000`000002025liP0501b0i`000000000000UkhP0MV>T00`0a
[Nd4077Ao@@0W>3m00<0]>?f0;?OmP2cgoH00P2cgoH40;oMk`<0a=WY0P32enT40<CCi@@0aM3S1034
cN440<;9h0<0`<OO102maN040;[3h@<0]/7R0`2c_n<40:nni@<0ZkgW0`2V^nP30::kjP<0W[W/0`2J
^>d309NgkP<0U;K_0P2B]^l3096fl0@0T[O`0P2C^?000`000000U[W`09Jil00309Vjk`<0WKc^0`2Q
_Nd40:Fnj`h0oooo00<000000?ooo`3oool00`3oool4000003d0oooo00<000000?ooo`3oool06@3o
ool30??G/`030?7H]`3^f;/0k]Rk00<0jLnk0P3Wd;h30>G@`P030>;@a@3PbL80h<W20080gL[50P3K
b/P0103Ha<L0e/G90=K5b@3FaLT30<o0c080cL7>0P39_<h20<Nmd080`[SA0P30^M<30;Zee0<0/k;H
00@0ZjoJ00000000000000000P2S[Mh309^Yh@<0TZKS0P28Y>L207nRjP<0MZ7]0P1^XNl206VSlP<0
IjKe0P1X[?P306jcnP80Mkcl1029aO`309C<n`<0XM3h102Zd_D40;3AlP@0/m3_00<0]m3/0;G>k@2e
c^d00`2gcNX40;O:j@@0]LOX0`2ca>L30;;2iP@0[koV0`2]_NH30:bki@@0ZKWU0P2X^>@40:Nhi@<0
YkOU0P2W^>D010000000YkSV0:NhiP2W^>H30:RjiP<0Z;_W102Z_NL20:Zoj@l0oooo00<000000?oo
o`3oool00P3oool4000001D0oooo000T0?ooo`<000001P3oool00`000000oooo0?ooo`0;0?ooo`80
k<V`0P3[bK<30>W:]`80il^j0`3Qa;/30=o5_P80f/300`3H`L<40=:la@030=2mb03;^LP0bkW80080
bKW;0P33]L`20<:fc`<0^k;A0`2b[mH30:R[f@<0WZSN0P2BY>4308BOi@80MI[X0P1VU^/00`1GT^d0
?HS[0000000200000080<8c^0P0QR^/00`0`VO40=:Cb03BTlP0305Nmn`@0Pm;o102Qfo`40;;Lm@<0
_=[_0`32enT20<3EjP80a=?U0`32d^H30<??h`@0`/cR1031bN440;k7h@<0_<GQ0P2j`n420;W3hP<0
]/7R0`2c`>@40:noiP80ZkgW102W_>T30::kjP<0W[[/0`2J^Nd209NgkP<0U;K_1P2B]_0309:gl080
TkS`00@0U[S_0000002F^>l0U[S_0`2I^^l309fkk@<0XKg/0`2U_^/?0?ooo`030000003oool0oooo
03X0oooo0`0000060?ooo`030000003VO2X0oooo01T0oooo0P3cek<20?7H]`80k]Rk0P3/f;l30>O@
_P80iM320`3Rd<D20=g:a@<0fl[80`3FaLT30=?5c0@0cL7>1037_M040<2id`<0^KKF0`0000030:^`
f`<0XjgN0`2L[>4309BYi080S:OW0P24Y^X307bUk@80MZK`0`1bYo82072[m@<0L[3h0P1g]oX307jn
n`<0SLKj0`2Gc?X40:;?m`@0Z]3d0`2_d?430;?@k`@0]Lk]0`2ec>/40;C9jP@0/lKY0P2ca>L40;32
i`@0[[oV0P2]_NH40:Zki@<0ZKWU0`2X^>D30:Nhi@@0YkOU0P2W^>D010000000Z;WU0:Rii@2X^ND3
0:RjiP<0Z[cV0`2Z_NL30:c0j0h0oooo00<000000?ooo`3oool06`3oool002@0oooo00@000000?oo
o`3oool000001@3oool2000000/0oooo0`3/bK020>_9/`80jLZg0`3WbkX00`3Ubkd0hLBk0=o5_P02
0=o5_P80gLG1103H`L<00`3F`LD0d[c50=:la@030=2mb0@0bKW;1032]/l30;Zcd`<0/ZoF0`2Y[MX3
09jXgP80TZCQ0P24WnD207FJj00506JFj`00000000000000001GT^d00P1;T>h01013TO00<8c^032<
kP0eUO43032Il@80Ajgh0P1U`Oh408WAo`@0X]Sk102afO@40;_Hk`@0`=GZ0`32d^H20<3@iP030<??
h`31cN@0`LgT0080`/cR0P30bn820<79h@80_lSR0P2nan420;g6h@80_<GQ102i`n840;K2h`<0//7U
0`2__nH40:^nj080YkcY102R_>/209jjk0@0V[W^0P2G^>l309Bgk`<0T[K`1P2B]o0209Bgl0030000
002F^>l0U[S_00@0VKW^0P2M^nd40:6lk0<0YKg[3`3oool00`000000oooo0?ooo`0i0?ooo`040000
003oool0oooo000000D0oooo00<000000>Il:P3VO2X0603oool30??G/`030?7H]`3^f;/0k]Rk00<0
k=Ro0P3Yf<<20>G@`P<0h]350P3Pd<P30=_:b0<0f<[<0`3CaL`20=75c`80cL7>0P3;`M420<Nmd080
aKgC0P30^M<0102n^]D000000000000000040;:cf@80Zk3K102T[]l309b/h@80U:WT0P2<YnL308BV
jP<0PZS]0P1mZO0307Z[lP80NJoe0`1j/oL307jin@80QKoj0`2Aa_T309W;n@@0Xlkf102Yco<20:o@
l@@0//o_102ccNd40;?;k0<0//S[0`2ca^T40;34j0<0[/7X0`2^_nH30:^liP<0Z[_U102Y^ND20:Rh
i@@0YkSU0`2W]nD20:Rhi@040000002X^ND0Z;WU0:Rii@@0ZK[U0P2Z_>H40:bni`<0[/7W3P3oool0
0`000000oooo0?ooo`0J0?ooo`00903oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo00X0oooo0P3`dK<20>_9/`<0jLZg0P3WbkX20>G;_@<0glFn0`3MaL400`3Ka/@0f<730=S1``03
0=K1a@<0d;g80P3>_//20<Vib`80b;[=0P32]/l20<6gd@80^[?C102a/ML20:V]fP@0Wj_O0P2DYn<0
1027XnH0000000000000000306fKk080HIS^00<0EiO`04>Al013TO000P12U_8204JNm@80@j?f0P1G
/o/30733oP@0S]3n102Se_T30;7Gm0@0^MG^102ndnX40<3@iP@0`LgT0`30bn840;o8hP@0_LKQ102k
aN830;S3h`@0]L;T0P2b`ND40:o0iP@0ZkoX0P2W_NX30::lj`<0W[_]0`2J^Nh309Nik`<0U;S`2@2B
]o0209Bgk`030000002F^>l0U[S_00<0VKW^0`2M^^d30:6lk0@0YKcZ3P3oool00`000000oooo0?oo
o`0i0?ooo`040000003oool0oooo000000D0oooo00@000000>Il:P3VO2X0hG8J5`3oool20??G/`80
lMRg0P3^f;/20>cH_`<0jMS300@0i]S60>;@a@3Rd<D0h]350`3Pd<P20=g@c0<0f<[<0P3Fb/h0103C
aL`0dLG?0=75c`3AaLl40<_1d@@0aKgC0`000000102n^]D0^;OH0;Rgf02h]mP30;:cf@<0Zk7M0`2T
[]l409j]hP80Uj_U0P2?ZNL308RYjP80PZS]0`1mZO0207Z[lP<0NJoe0P1j/oL408Bkn080R/3i0`2A
a_T409_:n0<0Xlge0`2Yco<40:k?l@<0/<k_102ac>d40;7:k080//S[102aa^T40:o3j@80[/7X102/
_^L30:^liP<0ZK[V0`2Y^ND30:Rhi@L0YkSU0P2X^>D010000000ZKWU0:Vii@2Y^ND30:Vji@<0[;cV
102^_^H30:k1i`d0oooo00<000000?ooo`3oool06P3oool002@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00T0oooo0`3`dK<0103^dKL0jLZg0>W:]`3Yb[L30>O;^P80
iL^m0P3Sbl030=g5`@<0flK40`3F`LD20=C2b0040=2mb03>_//0c[k;0<jnb`@0b;[=1031]m430;Vd
e@<0/K7G0`2Y[m`309n[g`<000000P27XnH207ZOj@80KI_/0P1QV>h305NGl003056IlP1@WO@0D9gd
0080AYke0P1BZOT306>go080N<Gn102Bcod40:CCn0@0/=Cc102gdnh30;cAjP@0_/oW102oc>@40;k:
h`<0_LSR102la^840;[5hP<0^<?S0`2e`^@40;;1i@<0[/7W0`2[_nP30:Nnj`<0X[g/0`2N_>h309Zj
kP<0UkW_0P2D^?0909:gl0<0U;O_00<0000009Jhk`2F^>l00`2I^Nh209fjk@@0XK_[0`2U_>X?0?oo
o`030000003oool0oooo03P0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000000P3VO2X2
0>5b6QD0oooo0P3cek<20?7H]`80k]Rk0P3/f;l30>WH``80i]S60P3TelX30>3@b080gM3<0P3Jd<l0
103Hb/`0e/[>0=K:cP3Fb/h30=75c`80c/GB0P3;`M420<W1d`<0000000<0`kgE0;jje@2n^]D00P2m
^]L30;Rgf0<0/KCK0`2[/Md30:B`h0<0WZgR0P2GZnD308nYi`<0SJ_Z0P27[>d308>]l0<0P:ob0P1o
/_@2086fm`<0Q;_h102>`OP209C6n0@0WLWg0P2ScOD40:W>l`@0[Lka102_cNl30;3;kP<0/L[/102`
an/30:o5jP<0[l?Y102/`>P20:bni`@0Z[cW0`2X^^H30:Rii@<0Z;SU1P2W^>D30:Rhi0030000002Y
^ND0ZKWU00@0Zk_U0`2]_ND30:jniP@0/<7W3@3oool00`000000oooo0?ooo`0I0?ooo`00903oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool02P3oool20?3A/`80k]6g0P3/
d[X30>O;^P80iL^m0`3Sbl000`3Pbl<0gLG10=g5`@020=_6a080fLK700@0e/750=C2b03D`/P0e<;8
0`3>_//20<bnc@80b;[=0P36^m020<6gd@80_kSC0`2i]=D30;6bf@80ZJoL0`0000000`2P[N00UZWT
09JYi00308^Vi`80Oj;Z0P1cWnd206VNk`<0HIga00<0G9oc052Mm01@WO@00`1DYOL205n_nP80K[[m
0`1oaOh409G=n`<0YM7g102_d_840;KAkP@0^/oZ0`2lcNL20;o<i080_L_U0P2nb^<20;g9h`030;g8
hP2lan<0_<OS0080_<KR0P2ka^<30;[5hP@0^<?S0`2e`n@40;;2iP80[/7W102[`>T20:Nnj`@0X[k/
0`2N_>h309Zkk`<0UkW`0P2D^?0309:gl0<0TKO`0`2B]_0209Bgk`030000002F^>l0U[S_00@0VKS]
0`2M^N`30:6jjP<0YK_Y3`3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`00
00000`3oool010000000oooo0?ooo`3RMc420>5b6P030=YU1`3oool0oooo0180oooo0P3dh[P20?;R
_@030>oR`@3/f;l0k=Ro00<0jMS30P3Vf<H20>CGbP<0hMO=0P3Md<`30=[@c`<0e/[>0`3Cb]440<k5
dP040<W1d`00000000000<W1d`@0`kgE0`2m^]L40;NgfP<0/KCK0`2[/]h30:B`h0<0WjoS0P2I[ND3
09:/j080SJ_Z0`27[>d208>]l0@0Q[7b0P25]?@308JhmP80RKcg102B`_L209O6m`@0WlWf0`2Tc?@3
0:W=l`@0[<ga102^c>l20;3;kP@0[lW]102^an`20:o5jP@0[L;Z102Z_nT20:Znj0@0Z;_W0P2X^^H4
0:NiiP<0YkSU0`2W]nD50:Rhi0040000002Z^N@0Z[WT0:Zii0@0[;_T0P2]_ND40;2oi@80/<7W0P2b
`^H=0?ooo`030000003oool0oooo01P0oooo000@0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool3000000X0oooo100000030?ooo`8000002P3oool30?3A/`80k]6g0P3/d[X20>WB_@<0iL^m0P3S
bl030>3;``80flK40`3Ia/L30=C2b0<0d/;;103<_/d40<Jkd0<0_kSC102h]]L0102a/]T000000000
000000020:V`g@80X:gP0`2FZN@208^Vi`<0PjK[00@0NJ?]06VNk`1YW^l0JIk_0P1QWO4205bOl`<0
Fj?f0P1PZ_P206VbnP<0M[cl0P25aO`409S<nP@0YLof0`2_d?420;KAkP80]Lo]0P2jcnX20;W>jP<0
_<gW0`2mbnD40;g9h`@0_<OS0`2ka^<40;W5h`@0]lCT0`2d`nD30;;2iP<0[/7X102[`NX30:Joj`<0
X[k]0`2N_Nh209Zkk`@0U[[`0P2D^?0309:gl0<0TKO`0`2A]_0209>fk`030000002F]nh0U[O^00<0
VKS]102M^>`20:6jjP@0YK[X3P3oool00`000000oooo0?ooo`0U0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000002@3oool4000000<0oooo0P000000103oool0hWLa0>9g<@3N
KB<20=YU1a80oooo0P3dh[P20?;R_@80kn;10P3]h/D20>WQb@80i]S60P3TelX30>7Gc@80gMK@0`3J
d<l30=O?d@@0dl[A00<0d<[C0<k5dP0000000P0000040<K1e@@0`KkG00<0_K[G0;^kf@2k^mT00`2g
]mX40;2eg080Zk;N102U/N4209n_h`<0VJgU0`2E[^P2092^jP<0S:k]0`28[nl208JalP<0RkKc0`2<
^_D308jnmP80T/;g102Ja_H30:39m@<0Y<_d102Xc?830:_<l@<0[/c_102^b^h30:g8k@<0[/O/102]
a>/30:_2j`<0Z[oY0`2X_NP30:Rki`H0YkWV102W^>D20:Ngi@@0Z;OT0P2Y^>@010000000ZkWT0:^i
i02[^N@30:bki0<0[kgT0`2`_nD40;;2iPd0oooo00<000000?ooo`3oool0603oool00100oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
2@3oool20?3A/`80k]6g0P3/d[X30>WB_@80im;10P3Sbl030>3;``80g/c60`3Ia/L30=O6b@@0d/;;
00<0d<;=0<bnc@3<_/d00P3:_ll20<Jkd080a;cB00@0_kSC0;jie@2n^MD0^;KG0`0000020;6cf`<0
ZK3M0`2Q[n8309N/i@80SJSX0`23Y^/207VSk@80L:;`0P1YX_8306FTm080IJSf0P1Y[_P3076enP80
OKgk0`2:aO/309[;n0@0Y/gd0`2_d?430;G?k@@0^LkZ102kc>L40;c:i@<0_<ST102kan<40;[6h`<0
^LGS102ga>@20;C3i@@0//;W0`2^`^P30:_1jP@0Y/3/0P2R_^d409jmk`80V[c`0`2F^_0309>il@<0
TKOa0`2A]o02096fl0<0TkK_00<0000009FfkP2E]^h00`2I]nd309fhk0<0XKWZ0`2U^^P?0?ooo`03
0000003oool0oooo02@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000@
0?ooo`050000003oool0oooo0?ooo`3RMc400P3NKB<00`3HHA40d5H00<92000@0?ooo`80m>:h00<0
l^:m0>oR`@3_h/400P3]h/D20>WQb@80i^7=0P3Sh=430>7Gc@<0gMK@0P3Je]<40=O?d@030=C?e03C
b]40dl[A00<000000P3<aM@20<W5eP80a/7E0P34`ML30<6ne`@0^k_I0`2e^=/30;2eg0<0Z[?O0`2U
/N430:2`h`<0VZoU0P2E[^P3092^jP<0T;3]0`2=/Nl208^cl@<0RkKc0`2@^o@309:om@80U/;f102L
a_D30:39m@<0YL[c102Xbo820:_<l@@0[<_`102/bNl20:g8k@@0[<K]102[`n`20:_2j`@0Z;oZ0P2X
_NP40:Nkj0<0YkWV0`2V^>H30:Nhi@<0YkOT0`2X]n@30:Zhi0030000002[^N@0ZkWT00@0[[_T0P2_
_N@40;70i0@0]<?U3@3oool00`000000oooo0?ooo`0G0?ooo`00403oool01@000000oooo0?ooo`3o
ool000000080oooo1@00000@0?ooo`8000002@3oool20?3A/`<0k]6g00@0k=:j0>WB_@3Yd[d0jM:m
0P3Wd/420>GBa0<0h<_30`3Nc<H20=_<b@@0elK900<0eLO<0=;2b`3B`//00P3@`/d40<Zoc`@0a;cB
0P2n^MD2000000<0]kOI0`2a/m/30:Vbg`<0XJoR0P2G[>D3092[j0<0QZW[0P1nYnh207JVl080L:Kb
0`1]Z?@00`1^ZoH0JJkh06V^n00407Vgn@<0P[kj0P2>aOX409c9m`80Y/gd102^c_440;C=k@<0]lcZ
102ibnL40;_9i@<0^lST0P2kan<40;[6h`@0^LGS102ga>@40;C3i@<0/L?W0`2^`^P30:_2j`<0Y/3/
0`2R_nh309jmk`<0VKc`0`2F^_4309>il@80TKOa102@]_42096fl0<0T[K_00<0000009FfkP2H]^`0
0`2H]^`309bgj`80XKWZ102U^NL?0?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000@0?ooo`040000003oool0oooo0?ooo`80hWLa00D0gVdS
0=QQ4@3HHA40ce<00<92000>0?ooo`80m>:h00<0l^:m0>oR`@3_h/400`3]h/D00`3YhLT0i^7=0>KQ
c@030>?Pd@80gmkD0`3Me]020=[Fd`80emGF0P3Gcm401@3Dcm@00000000000000000d<[C00<0c/WF
1039aMH40<C1e`@0_kkI0`2i^m/30;Fhf`<0[kKM0`2Z/ml30:FbhP<0X;3S0`2L/>H209R`j0<0Tk3Z
0`2@/>d208fak`<0SkK`0`2?^?82092km0@0U[od0`2H`oD309k6m0<0XLSd102Ub_<20:S;lP@0Z/_a
0`2[b_040:_8k`<0[<O^0`2ZaNd30:_3k0<0Z<7[0`2X_nX40:Nlj@80Yk_X102V^NL20:JhiP@0Y[OU
0P2W]n@40:Rgi0<0Z[ST00<000000:bih`2/^N<00`2^^n@30;2mh`@0/l3T0P2d`nD20;K3i0d0oooo
00<000000?ooo`3oool05P3oool00100oooo1@0000030?ooo`040000003oool0oooo00000100oooo
00<000000?ooo`3oool0203oool20?;K^080l=^k00@0k=:j0>WB_@3Yd[d0jM:m0P3Wd/430>GBa080
h];70`3Nc<H20=_<b@80fLc<0P3Ga/T30=G7c080d<;=0P3>`m020<Zoc`80b;oA0P34_=8300000003
0;jie@2m^]L0_K[G00<0]kOI0`2`]M`30:Vbg`<0XK3S0`2I[^D2092[j080QZW[0P1nYnh307JVl080
L:Kb0P1]Z?@306j[mP80LK7h0P1i]oT408Nnn@80TLCi102Mb?H30:K<l`<0[/c`102cc>d40;K;j@<0
^<WW0P2kbND20;W8i@<0^lST0`2ja^<40;W5h`@0^<GT0`2fa>D40;C4iP80/L?W102^`nT30:_3j`<0
Y/7]0`2R`>l309fnl080VKc`102E^o4309:il@80T;Oa0`2@]_43092el080T[G_00<0000009BekP2D
]Nh00`2H]^`409bfj`80XKSY0`2U^NL?0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`00
00000P3oool010000000oooo0?ooo`00000@0?ooo`040000003oool0oooo0?ooo`80hWLa0P3NKB<2
0=QQ4@030<mC003oool0oooo00/0oooo0P3dh[P20>o_a@80kNo:0P3Yk/l00`3YhLT0i^7=0>KQc@03
0>?Pd@80gmkD0`3LgML20=[Fd`<0emGF0`0000000`3Dcm@0dLkG0=7>e`030<k9eP80blWH0P39aMH2
0<O5f080a<7G0P32`]T20;nnf@80_KkJ0P2i^m/40;Big@<0[kOO0`2Z]>020:FbhP@0XK;T0P2L/>H3
09R`j0<0U[7Z0`2C/^`2096ckP<0SkK`0`2C^_4309Bll`80U[od102K`o@209k6m0@0X/Sc102UbO82
0:S:lP@0ZL[a0`2ZbO030:_8k`@0Z/O^0`2Xa>h30:S3k@<0Y/3/0`2V_^X40:Flj@80YK[X0`2V^NL3
0:FhiP<0Y[OU0`2W]n@30:Rgi0<0ZkSS00<000000:bih`2/^N<0102_^n<30;:nh`<0/l3T102f`n@=
0?ooo`030000003oool0oooo01H0oooo000A0?ooo`050000003oool0oooo0?ooo`0000000P3oool3
00000140oooo0P0000080?ooo`80l]^h0`3`fk/00`3^fkl0jm_30>_K``020>OB`@<0iM;40`3Rd/L2
0=oBb`80flc9103Ic<`30=G7c080d/O?103>`m020<Rod@<000000`33_=@30;fje`@0][SJ0P2`]M`4
0:Vch080XK3S102J/>H209:]j@80RJ_/0`22Z^h207^Yl080MZWb0`1dZo@207B^mP80N;?h0`1n^OT2
08Nnn@@0U<Cg0P2Mb?H40:K:lP@0[L__0`2bb^`20;K;j@80]LWY0P2hbNL40;W8i@@0^/OT102ja^@3
0;W5i0@0^<GT00<0]/CU0;K5i@2faND00`2da>H30;;4j0@0[/CY0P2[`n/40:K2k@80X/3_102M_o03
09Rml@80UK_a102A^O8208ngl@<0SkKa0P2@]O0309:ek`030000002D]>d0U;C]00<0V;G/0`2L]^/3
0:2gj0<0YKSW3`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00H00000403oool2
000000<0oooo0P3KKC<01P3GHb@0f64A0=QQ4@3?D`00[b/009HA00/0oooo00<0l_2o0>o_a@3_klD0
0P3]klX20>W^c`80i^cC0P3SjmL20=oXfP80gmkD0`3LgML20=WLf@040=OEeP000000000000000080
e=CH0`3Ac]L30<k>f@<0blWH1037aMP40<;2f@@0_KkJ102h^m`30;>igP<0[kOO0`2Z]N430:FchP80
XK;T0`2N/^H309Zaj0<0U[7Z0`2F]>`209BekP<0TkO`0P2C^_4409NmlP<0VL3c0`2Ma?<309o6l`<0
XlSc0`2UbO840:O:lP<0Z<[a0`2ZbO030:W8l0@0Z<K_0P2Xa>h40:K2k@<0Y/3/0`2T_N/30:Flj@<0
Y;WX0`2T^>L30:BgiP<0Y[OU0`2W]n@30:Vgh`<0ZkSS00<000000:fihP2]^N80102`^n830;:nh`<0
]L7S102ha><=0?ooo`030000003oool0oooo01D0oooo000A0?ooo`050000003oool0oooo0?ooo`00
00005@3oool2000000T0oooo0P3bfkP20?3K^`040>kK_`3[fl<0jm_30>_K``80j=_60P3Uf/X30>;B
a`80gm;;0P3MdLd40=W<c080el_?103Ball00`3@am40c/?@0<k3d003000000<0al3C1031_MH30;^k
f@<0][SJ102`]]h20:Vch0<0X[;T0`2J/>H209:]j@80RJ_/1025[>h207n/l080Njcb0`1i[_@207Za
mP<0OKGg0P23^_P208^on0@0U/?f0P2NaoD40:K9lP@0[LW^0P2bb^`40;G9j@@0]lSW0`2ianD80;W6
i0<0^LGT0`2haN@30;K5i@@0]<GV0`2baNP30:k4j@@0ZlC/0`2V`nh30:71k`80WKo`102G_O8209>k
lP<0TKWb0`2>]o8308fel@80S[C`0`2@]>l00`000000U;C]09Bdk@0309Ndk0<0VkGZ0P2P]nP40:Fg
iPl0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00@0oooo0P3KKC<01P3GHb@0dELB0=5G4P33@000/RX009HA00T0oooo00<0l_2o0>o_a@3_klD00P3]
klX20>W^c`80i^cC0P3SjmL20=oXfP80fnOM0P3Hi=l20=WLf@<0000000@0eM_L0=CDf03De=P0e=CH
0`3Adm/30<k>f@80c<gK00@0blWH0<S9fP38bMX0b<WJ1034aMX40<32f`<0^kkL0P2h^m`20;Jlg@80
/kWN102^]n020:Zeh@@0Y[CS0P2R/n@309jbiP<0W;?X0`2I/nX209Jdk0<0U;G^0`2G^Nl309Nkl@<0
V[ka0`2K`O8209g4l`@0XLKc0`2Tb?830:K9lP@0YlWb0`2XbO430:S9l0@0Z<O`0P2Xa^l40:K4k`80
Y/;]102T_nd20:Bmj`@0Xk_Z0P2T^NP40:>gi`<0Y;OV0`2U]^D30:Nfi080ZKOS102[^>800`000000
[[WR0:jihP030;2khP@0];kR0`2g`N420;S4h`80^lCR3@3oool00`000000oooo0?ooo`0D0?ooo`00
4@3oool5000000`0oooo0`0000060?ooo`030000003oool0oooo00L0oooo0P3bfkP20?3K^`80k]^o
0P3[fl<20>SKaP80iM[:0`3Sf/d20=oBb`<0gM7=0P3JdM040=O;c`040=C;d@3Ball0d/O?0=37d@<0
000000<0c<?B0<W3e039`m@00P37`=<20<G0eP80`KgF0P30_MP30;^kf@@0][WL0`2_]ml20:Vdh@<0
X[;T0`2K/NL309B_jP80S:g/0P25[>h207n/l0<0Njcb0P1i[_@207ZamP@0P[Kf0P27^_L308jom`<0
V<?e0`2Oa_<30:O7l@<0[LW^102abN`30;C8j@@0]lOW0`2hanD70;W6i0<0^LGT102haN@40;K5i@<0
]<GW0`2baNP30:o5jP@0ZlG]0P2V`nh40:72l080W<3a102F__<209:kl`<0SkWc0P2>]o8308fel@<0
SK?`0`2?/nl00`000000T[?]09:ck@0209Ndk0<0VkGZ0`2P]NL30:FgiPl0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0<0?ooo`<000001P3oool00`000000oooo0?ooo`040?ooo`80
ffdc00L0ef<T0=5G4P3AEa80b4P00;`e002b:P00W10000L0oooo00<0l_2o0>o_a@3_klD00P3]klX2
0>W^c`80i^cC0P3SjmL0103Oj=X0fnOM0=_Wg@3Kimd20=STg`<000000`3Efm`30=;IgP<0dM?K0P3>
d]d40<c=f`<0b<WJ0P36b=`20<C5fP80`/GL0P30`]/20;k1g@80^kkL102f_=d30;:ig`<0[[OP0`2Y
]^830:Jdh`<0XkCU0`2O/nH309bcj0<0VkCY0P2I]^/309Rgk@80UkW_102J_?0209Znl@@0W/;b0`2O
a?830:?6lP<0Y<Sb0`2VbO840:O9lP80Z<Wa102Wb?440:K7l@80Y/G`102T`nl20:C1kP@0X[k]0P2R
_>`30:>kjP@0X[SY0P2S]nL40:BfiP80YKKU102W]^<20:Vgh`@0[;SR00<000000:jihP2b^n400`2b
^n420;BnhP80][kP0P2g`N440;_4hPd0oooo00<000000?ooo`3oool0503oool00280oooo00@00000
0?ooo`3oool000001@3oool2000000L0oooo0P3bfkP20?3K^`80k]^o0P3[fl<20>SKaP80iM[:0`3S
f/d20=oId0<0gM7=0`3JdM000`3Gd=80el_?0=O;c`020=C;d@<0000000<0d<OA0<k7d`3>am<01039
`m@40<G0eP@0`;gH0`2j^mX40;Fjg@80[kOO0`2Y]^830::ci@80Vk7W102E/NX208n_k@<0R:k_0P23
[_02082^lP80O[3d0`1o/_D208:fmP<0Rk_f0`2A_oH209S3m@@0X<Gb0`2Wao430:c8kP@0/LS[0`2d
anT20;O7i`80]/OW0`2hanD30;W6i0@0^LGT1`2haN@40;O5i@80]<GW102baNP30:o6j`@0ZlK]0P2V
a>l40:33l@80Vl7b0`2F__<3092km0<0SKWc0P2<]_8308^dl@80SK?`0`2?/nl010000000TK;]096b
k@2A/^d209Jbj`<0VkCY0P2P]NL40:Ffi@h0oooo0P00000b0?ooo`040000003oool0oooo000000D0
oooo0P0000060?ooo`80ced^0P3AEa820<Q800040;`e002[7P00W100080000@0oooo0P3SoLL20>;l
cP030>3ke03MnMX0gOWJ0080f_ON0P3Gm>80103DlND0dNkX0=7^j03Ak^P300000080e>;Q0`3Ah><3
0=;IgP80cmSP0`3>d]d30<_AgP@0bLgM0`36b=`40<;5g0@0_/7M102i_]h30;Flg`<0/[WO0`2]^>43
0:VfhP<0Y[GS0`2S]>D209nciP@0W[CX0P2K]>T309Vfj`<0VkS]0`2J^^h309fmk`<0WKo`0`2P`_43
0:74lP<0Y<Kb0`2Ub?840:K9lP<0YlWb0`2WbO430:K8l@<0Y/Oa0`2TaO030:C3k`<0X/3_0`2R_^d3
0:2kk0<0XK[Z102P^>T20::gi`<0Y;KV0`2U]N@30:Nfh`<0ZKKR0`2/^>800`000000[kWQ0:nih@03
0;:kh@@0][kP0`2i`N040;g5h0`0oooo0P00000E0?ooo`009@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo0P3bj;h20?3W``80kNO70P3Zi//00`3WiLl0iM[:0>GJbP030>?J
c@<0gmW@0P3Lf=<30=[Ad0<0em3B0`0000020=7;d`<0c/OC0P3<amD20<W3e080b<?F0P35`=H20<?1
e`80`;gH0P2n_]T00`2j^mX0^KcL0;Vlg0030;Fjg@<0[kSP0`2Y]^830:>ei@<0W;?X0P2E/NX208n_
k@@0Rk3_0P26/?0208>`lP<0P[;c0P23]?@208Jgm@<0Rk_f0`2C__D309W2m0<0XLCb0`2Wa_040:c7
k@<0/<O[0`2danT30;K7i`@0]lKU102haN@30;W5i0D0^<GT0P2haND30;O5i@<0]LKW102ba^T30:o7
j`<0ZlK]0`2VaO030:33l@<0V/;c0`2D__@2092km0@0RkSd0P29]_<308VclP<0Rk;`0P2=/^l00`00
0000TK;]096bk@0209Jbj`@0V[;Y0P2O]>L30:Ffi@/0oooo0`0000000`3oool000000?ooo`0d0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool20<mM;P030<]B7P33A0X0`d@:
0080^C<00`2[7P0208000080oooo00D0hog70>;lcP3Ro<h0h?_D0=gifP020=[ggP80eoCR0P3DlND2
0=7^j080000000@0c^_Y0<_Xj`3;j>/0bnS[0`3Ah><20<gNi@<0cmSP0`3<e^830<_AgP80b=3P0P39
cMd20<K<gP@0`lSN1030a=h30;c1gP80^KkN0P2h_]l30;Flg`<0/;[P0`2]^>430:VfhP<0Y[GS0`2S
]>D30:6diP80W[CX0`2M]^T309bgj`<0WKW/0`2M^nh209fmk`@0Wl3`0P2P`_440:?5l@80Y<Kb102V
b?840:K9lP80YlWb102VbO830:G8lP<0Y<Ka0`2Ra?430:;2l0<0Wko_0`2O_Nh30:2kk0<0WkW[0`2P
^>T20::gi`@0XkGV0P2U]N@40:Neh`80ZKKR102]]n400`000000[kWQ0:nih@030;>kh0@0]kkO00<0
^L7P0;_2g`2k`]l00P2maN020;o5g`P0oooo0`0000000`3oool000000?ooo`0D0?ooo`008P3oool0
10000000oooo0?ooo`0000050?ooo`8000001P3oool20?;X_P80l>O30P3]ilL20>[Vb`80inG?0P3T
i=820>3Re@<0gmW@0P3Lf=<30=WGeP80em3B0P000000103Dd=D0dL_C0=7;d`3Abm<30<o;eP@0c<OE
0`38`mH40<?1e`@0_[kI102i_=`30;BjgP<0[kSP0`2Y]n<30:>ei@<0WKCX0P2G/n/3092ak@80Rk3_
0P26/?0208>`lP@0QK?c0P26]O@308Vhm@80SK_e0`2D__@309[1l`<0XLCb0`2WaNl40:c5k@80/<O[
102ca^P40;G6iP<0]lGU102haN@30;W5i0<0^<GT0`2haND40;O6iP<0]LOW102canT20:o7j`@0ZlO^
0`2Uao4309o4lP<0V<;d0`2C_oD208jkm@<0RkSd0P29]_<308VclP@0R;7`0P2;/>l00`000000Sk3]
08n`k@0209Baj`<0V[;Y0`2O/^H30:Bdi0H0oooo100000040?ooo`030000003oool0oooo0300oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`80ced^0P3;DQh20<=42P80
^C<00P2[7P0209P6000707P0003SoLL0h_c>0>;lcP2go=X0^_cR0;ckj@020;chkP<0_?Ga0`000000
0`3>jnT0bnS[0<_Xj`040<OUk080cMkU103:g>H30<cFhP80b=GS1038d>030<K<gP80`l_P0P33b=h2
0<77g`80`<CN0P2ma=l20;c1gP@0^;kO102c_>020;2jh0@0[;SR0P2Y]^840:Jfi080XkCU102R]NH2
09nej0<0WKKY0`2N^>/309fik0<0Wkc]0`2O_^h30:;1k`<0X/?`0`2UaO030:G7l@<0Y/Sa102WbO82
0:K9lPH0YLSb102Sa_820:;4l@@0Wl;a0`2O_nl309flkP<0W[[]0P2O^N/409jfj@80X;KW0`2S]NH3
0:Bdi0<0YkGS0`2Z]^430:fgh@040;6ig`000000/KWO0;6ig`<0]K_N0`2g_]l30;_2g`@0_lGO103o
ool4000000@0oooo00<000000?ooo`3oool04`3oool002<0oooo0P0000060?ooo`030000003oool0
oooo00D0oooo00<0l^Rn0?3W``3`il<00P3]ilL20>[Vb`80inG?0P3Ti=820>3Re@<0gN7H0P3Lf=<3
0=WGeP<000000P3Dd=D30=;?e`<0cl_F0P3=b]L20<c7e@80bLKG1036`mP40<;1f@<0_KkK102h_Md2
0;BjgP@0[[WQ0P2Y]n<40:>fiP80WKCX0P2G/n/409:ck@80SK;_0`29/O0208JblP80QK?c0P26]O@4
08^hm080Sk_d0`2D__@309c1lP<0XL?a102Wa>h20:c5k@@0/<GZ0`2caNP40;G5iP<0]lGU0`2haN@7
0;W5i0@0^<KU0`2ganH30;K7i`<0/lOY102`b>`30:_8k`<0YLSb0`2OaO<209S2m0@0T;of0P2;^oH3
08Rhm@80Q[Cd0`26/_8308Ral080Rk3_00<0Sk3]0000002?/>d00`2C[nX309Vaj080Wk;V102T/n<2
0?ooo`<00000203oool00`000000oooo0?ooo`0a0?ooo`8000001P3oool00`000000oooo0?ooo`05
0?ooo`<0_D@Q0P2f=`h30:`U0080WQ400P2=00000`3SoLL0/o_?0;?kc`020;[lhP0408;Wk@2<jO@0
S>Wd08cYm0<000000P2jk_@30;WZm@<0^>Ke0`35h^d30<;OkP<0am[W0`38eN<30<KCi0@0aLoR1033
bn030<77g`@0_LCO102j`N030;Jnh0<0/kcP102_^^430:bhhP<0ZKOS0P2V]^@40:Bei@80X[GV0`2Q
]^L309ngj@80W[S[102P^^`209nlk@@0X[o^0P2R`Nl40:C4k`80YLG`102Vao440:O8l@80YlWb102V
bO830:C8lP<0XlOb0`2Qa_<30:34lP<0WL7a0`2M__0209flkP@0VkW]0P2M^>/309jfj@<0WkCW0`2R
]>H20:Bdi0@0YkCR0`2Z]^430:jgh0040;:igP000000/[WN0;:igP80]K_N102i_]h30;g2g@@0`/KM
0`0000080?ooo`030000003oool0oooo01<0oooo000S0?ooo`@00000103oool00`000000oooo0?oo
o`040?ooo`030?;X_P3`il<0l>O30080kNO70P3Zi//20>OUc`80i>CB0P3Ph]D30=gQf080f]oJ00D0
e]gM00000000000000000=KFf0030=?EfP<0d/oG0P3?c]T40<g:e`<0bLKG0P37a]T20<K3f080a<?I
0P32`MT20<31fP030;fnf`2l_m`0_;oL00<0^;gM102c^ml30:jjhP<0ZKST0P2S]^H309jfj@<0V;C[
0P2B/nd308nck`<0Rk?a0P29/o8308Rdl`80RKKc0P2;^?@3096kl`<0U[kc0P2L`O840:;2l0@0Yl?^
0P2/a>`40:o4j@<0//CW0`2eaNH30;O5i@@0^<GT1`2iaN@40;W6i0030;O7iP2hanH0^<OV00<0]/OW
0`2cb>X40;39k@<0Zl[`0`2Ub?8309k6m080Ul?f102=_oL208Rkm`<0Q;Of0`22/o@208>al`<0QJoa
0P29[nl00`000000SJo/08f_k00209>_jP<0VK7X0`2N/ND30:Bch`800000303oool00`000000oooo
0?ooo`0`0?ooo`@000000`3oool2000000P0oooo0`2mA2420;Hg3P@0P@0000<0K@000:cg`@2cnll0
0P1Vfm400`0U/<`0?/3P03k0h0030000000305;:kP2Hio/0V>Ok00@0W>Gl0P2hi_D40;KSm@<0`]o^
0P2og>h40<CHj0<0a]?T0P33d^H40<;>h`@0`L_R102nan440;_4h@<0^<7Q0`2f_^030;:lh@@0[[[R
0P2/^>840:Vgh`80Y[KT102U]^D20:>fiP<0XKKW0`2R^>P30:6ijP<0X[_[0`2R_N`30:C0k@<0Y<;^
0`2Va>l30:K6l0<0YlO`102XbO420:O9lP@0Y/Wb0P2Tb?840:;7l`<0W/Gc0`2M`o<209g1l@@0V[ga
0P2J^nl309^ik@<0V[K/0`2L]NT209ndi`@0XK?U0P2T/n@30:NdhP@0Z[GQ0`2^]]l00`000000/[WN
0;:igP030;Jkg@80^KkN0P2k_]`00`2m`]d0`<;L0<32g0020<;6g@80a<KL2`3oool00`000000oooo
0?ooo`0B0?ooo`00:P3oool00`000000oooo0?ooo`040?ooo`030>cga`3Ym/d0jOK=0080ioCA0P3T
l]H20>3`fP80gNkM0P3Jk>020=KYhP80f]oJ0`0000030=?KgP<0dmGJ0`3@dm`20<o>f@<0c<kK103:
b]T40<O6f@<0a<?I1030`MX40;bog0@0]kgN0`2c_>420:jjhP@0ZKWU0P2S^>L309jfj@<0VKK/0P2C
]>h308nck`80Rk?a0`2;]?8308ZelP80RkOc0P2>^O<3096kl`<0Ukgb0`2L`?430:;1k`<0Yl?^0`2/
`n/40:o4j@80//CW102ea>H40;O4i0<0^<CT102iaN<00`2iaN@0^LKS0;W6h`030;W6i0<0^<OV102g
b>P30;C:jP@0/L_]0`2/bo030:G9l`<0W<Sf0`2Da?L208fom`80R;_g1020]_L307jbm@80Ojoc0`22
[O4208J]kP030000002;[N`0Rjg/0080TJkY0`2H[nL209jai@@0Y;7R3@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00P0oooo102K6PD209070080;00000<0[?O10?ooo`3oool00P3o
ool300000003001]dP08Sm`028oL0080?;G`0`1ae?`00`2Oh_d0XMol0:7Oo0020:7Oo0@0]N3e0P2o
g>h40;gJkP@0`MKY0P33d^H20<3Ai`80`/kS0`30cN@40;k:h`<0_<KR0P2ka>420;W3hP80^<7Q102d
_^830;2lhP<0[[[R0`2[^><30:Vgh`<0YkOT0`2U]^D30:BgiP<0XkOW0P2R^>P40:>jj@80X[_[102T
_^`20:C0k@@0Y/;^0P2Va>l40:S6k`<0Z<S`0`2XbO430:O9lP@0YLWc0P2Sb?<40:37m080W/Gc102K
`_<209[0lP<0V[ga0`2G^_0309RhkP80V[K/102J]>T209fci`<0XK?U0`2S/^<30:NchP@0ZkCO0P2^
]]l0102c^=d000000;>hg@2c^=d20;Jkg@@0^kkL0`30`]`30<C6g0030<O7fP3oool0oooo00T0oooo
00<000000?ooo`3oool04P3oool002X0oooo0P0000040?ooo`030>cga`3Ym/d0jOK=0080ioCA00<0
i?;F0>3`fP3Pl=X00P3Mk]d20=[/h0<0e^WR0`0000020<oSiP<0dm_N0`3@f^030=3Cg080cM;M0`3<
c]/20<[=g080b/[I0P38bM/40<G6fP@0`/?K102o`M`30;^og@@0]kkO0P2c_>430:jkh`<0ZKWU0`2T
^NP309jgjP80VKK/0`2E]^h3092dk`80SKCa0`2;]?8208ZelP<0SKOc0`2?^O<209>kl`<0V;ga0`2M
_o020:;1k`@0Yl;]0`2[`^/30:o4j@@0//CW0`2ea>D40;O4i0030;S4i02ha><0^<CS00<0^LGS0`2i
a^<40;[7i0<0^LSV102hbNP30;G;jP@0/Lc^0P2/bo040:C;m0<0VlWg0`2Ba?P208Zon@<0Q;[h0P20
]_L307jbm@80Ojoc0`22[O4208J]kP0308^]k0000000Rjg/0080TJkY102F[NH209f_i0<0Y;7R3@3o
ool00`000000oooo0?ooo`0g0?ooo`8000002`3oool505L000<0oooo0`0000000`3oool08X?Y02:3
j@0200^2h`0301jEj`0TX>/09:3[0080D;kh1023eOl40:?Mn`80]=ge0`2bf_@40;_Hk`@0_mCZ1030
dNL30<3=i080_LcV0P2nb^<20;c9i080_<KR102i`n840;K1hP<0/[kS0`2`_>830:fjh`<0ZkSS0`2X
]n@30:Ngi0<0YKOU0`2T]nH30:Bhi`80XkWX102U^^T20:BljP@0Y[k[0P2V`N`40:S3k@80Z<G^102Y
anl30:W9l0<0Z<Wa102Wb_830:G:l`<0X/Wd0`2Nao@209c5m0@0V<;d0P2G_o<309NllP80Uk[`102E
]nh209Rek0<0V[CY0P2M/nL409nbi@<0Xk;S0`2W/^430:^dg`<0[kKM00<0/kSM0000002c^=d00`2h
^m`40;fnfP<0`/;J0`37amX;0?ooo`030000003oool0oooo0180oooo000Z0?ooo`030000003oool0
oooo0080oooo00<0k?O70>Wfc@3Ym/d00P3?o]`00`3>o>80cO[W0<gji`020<_fjP80bO?]00D0ano^
00000000000000000=?Vi0030<oSiP<0c>7W0`3@f^020<gHhP<0cM;M0`3;dMl40<[=g080b<WK0P36
bM`20<G6fP80a<KL0P32`m/20<73g080_l7L0P2m`Md00`2k_md0^/3N0;[0gP030;Nng`@0/[gR0P2^
^n<30:VjiP<0Y;WX0`2O^>/309Zgk080UKK^0`2A]_0308jel@80SKGa0P2<]_8308fgl`<0T;Wb0P2D
^o8309Rml@<0WKk`0`2R`>h30:O1k0<0Zl;[0`2_`nP40;;3iP<0]L?U0`2ga>@30;S4h`@0^LGS102j
a^<30;[7i0@0^/WU0`2ibnP30;K<j`@0//k^0P2/cO440:C=m@<0VL[i0`2?aOX208JonP<0OkWi0P1j
]?L307V`mP80NZgc0`1mZo4208:ZkP0300000028Zn`0R:_/0080SjcY0`2F[NH309f_i0<0Y;3P303o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00l0oooo0`0000050?ooo`80>93_00<0
=YCa02FBk@0UT^d00P0fX_<204ndnP80KLKo102?doh40:CHnP@0/MSd102ie^l40;cCj`<0_/oX102m
c>H40;c9i0@0^/KT0`2g`n<40;C0h`80/[kS102__><20:fjh`@0Z[WT0P2X]n@40:Ngi080YKOU102U
]nH20:Bhi`<0YKWW0`2U^^T30:Jmj@<0Y[k[102X`N`20:S3k@@0Z/G^0`2[anl30:W9l0<0ZL[a102W
bo820:G:l`@0XLWd0`2LaoH309[5m@80V<;d0`2C__@309>klP<0U;W`0P2E]nh309Fck0<0V;;Y0`2L
/^L209nbi@@0X[7S0P2W/^440:^cgP80[kKM00D0];SL0000002d^=`0];SL0;Rkg0020;VjfP80_KkJ
0P2o_]T01032`]X0a<;H0<C2f037amX20<[7f0X0oooo00<000000?ooo`3oool04P3oool002X0oooo
0P0000020?ooo`80cOo<00@0c_oD0<ong03>o>80c_cR0P3=n^L20<_fjP040<Wck@00000000000000
00<0a>_`0`32j?000`3<hNL0bMkX0<WNj0020<WNj0<0cMSR0`3:e^<30<_Ag`80b=3P1037c=d40<K9
g0@0a<KL0`31`m`40;g1g@@0^/3N0`2f_^440;:mh`80[[cT0`2Y^nL30:Bjj@80WkS[102J^>d209Jg
kP80TKK`102?]_4208jfl@<0SKOb0P2>^?82092ilP<0UK_a0`2I_O4209fnl0@0Xko^0`2W`>/30:_1
jP@0[l;X0`2b`^H30;G3i@<0]l?T102ia><30;[5hP@0^lKS0`2kb>@40;_9i@<0^/cX102gc^/30;?@
k`80[<ob102Sc_L309K<nP<0RlKk0P21_o/307VhnP80M;;h0`1c[_H207BZl`<0NJSa0P1nZ>h00`00
0000QZS[08JXj`0208fYj0<0UJ_U0`2L[N<20:B`h0`0oooo00<000000?ooo`3oool0=`3oool20000
00d0oooo0`0000090?ooo`0304ZJl`0fU?40=YCa00<0?9kd0P1:ZoT205njo@80MlSo102Cd_d40:GF
n@@0/=Kc0`2ge>l40;[Aj`@0^lkX102kbnL30;[8i@@0]lGU0`2e`nD30;C0h`@0/KkT0`2^_>@30:bj
i0<0Z[WT0`2X^>@30:Ngi@<0Y[OU0P2U]nH30:FhiP<0YKWW0`2V^nP30:Jmj@<0Z;oZ102[`^/20:[4
k0@0[<K]0`2/b>h30:_9l0<0ZL_a102Wbo<20:C;m0@0X<We0P2LaoH409O4mP80U<7f0`2C__@308nj
l`<0T;Oa0P2B]Nl309Fck080V;;Y102J/>L209j`i@<0X[7S0`2V/N030:^cgP<0/;GL00<0];SL0000
002d^=`00`2i^]X40;nnf@<0a<;H0P3:amP20<g7e@T0oooo00<000000?ooo`3oool04P3oool002X0
oooo00P000000?ooo`3oool0oooo0<goc03>om@0QN[B093`h080VO;Z0P2Ol_43000000@0ZN[j0P32
j?030<3Tl@<0_^7a1036fnT20<[Fh`<0amCT0`38d>020<K?h@80alcM0`35bml30<C8g@@0`/KM102o
`md40;c2gP<0^L3O0`2e_n430;:mh`@0[KgU0P2Y^nL30:Bkj@<0WkW[0`2K^Nd309Jhk`80T[O`0P2?
]_4208jfl@@0S[Ob0P2?^?82096ilP<0UK_a0`2I_?0309jnk`<0Xkk]0`2W`>/30:_1j@@0[l7W0P2b
`^H40;G2i0<0]l?S102ia>800`2jaN80^lGR0;_5hP020;_6h`80_<KR00<0^lST0;g8h`2mb><00P2k
bND20;c;i@030;[<j02kcNP0^lgX0080]lk[0P2id>/00`2cd>l0]=;_0;CBk`020:cAl`@0X]3h0`2C
cO`308K6o@80N[kl0`1b]_/206f`n@<0K:_f00@0KZOc07VXl@1iZ?40NJSa0P1nZ>h00`26Z>/00000
08JXj`0208fYj0<0UJ_U102KZn820:>^g`/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`090?ooo`<000003@3oool204ZJl`80BIoe0P1>YoP205Zbn`80Jkkn0`1obOl309KAo0@0Y]Ch
102_e?<40;GBk`@0^=3/0`2icNT40;W;j0@0]lSW0`2eaNH30;G3i@<0//3U102__^D20:jli0@0Zk[T
0P2Z^N@40:Rhi080YkOU102V]nD20:JhiP<0YkWV0`2W^^L30:Rli`<0Z;gY0`2[`>T30:_2j`@0[<C/
0`2]and20:c8kP@0[<[_102Zbo430:O<l`80Y<_d102Nb_H209[7m`@0U<Cg0P2A`?L308nmm@80Sk[c
102<]O8208jck`<0T[7/0P2F/>T309Z`i`<0WJoT0`2R/>820:Jah0@0Zk;M0P2`]M`20;JgfP030000
002f]mX0^k[H0080^k[H0P2o_]T20<6me`030<C2f037`]H0al;F00<0cLOE2@3oool00`000000oooo
0?ooo`0B0?ooo`007P3oool00`000000oooo0?ooo`03000000H0oooo00@000000?ooo`3oool0cOo<
0P25j]840?ooo`8000001@3oool20:[WnP@0Zn?j0P2nhO440;cNl@<0a=WY0P31enX40<GCi@@0a/oQ
0`35bml20<?:h0040<C8g@32b=h0`/SN0<;8gP@0`<GN0`2n`mh40;_2g`030;W0g`2h`N40^<7Q00<0
]KoQ0`2a_^@40:fniP80ZKcW0P2T^nT409njk080VkW]102G^Nl209>hl080T;Oa0`2?]o4208jglP<0
T;Sb0`2B^O4209Jjl@<0V[__0`2N_Nh20:>nk@@0Yko[0`2[_nP30:o1i`<0//7U102e`^<00`2g`n<0
^<;R0;S2hP030;W4hP<0^lGR102la^830;g8h`@0_<_U0`2kcNP40;W@j`80]=;_0P2ee?020:cCm0@0
X=?i0`2?cod307o6oP80L[gm0`1Y]?/206B/n@80HjOf0P1^Yo<307>Ul@80NZG^00<0PZG[00000022
YN/00P2;YnL309>Xi0<0Vj_R0P2S[]l;0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool00`0000070?ooo`030000003oool0oooo00L0oooo0P00000B0?ooo`80FJ;e0P1HY_L205f]nP80
IkOl0P1f`Oh208K:oP@0VM3k102Vd_L40:kBl`<0/m7_102fcn`40;O<jP@0]/WY0`2eanP30;G5iP<0
/l;V0`2``>D30:nni@@0[;cU0P2[^^@40:Vii080Z;ST0`2W]nD30:Jgi@<0YkSU0`2W^NH30:RjiP<0
Z;cW0`2[_^P30:_0j@<0[L?Z102^aN/30:o8k0<0[/W^0`2]bnl40:_<l@<0Ylgc0`2Sc?D309g:m`80
V<Oh102@`oT208bon0<0Rk_f0P2;^?@308belP80S[?_0`2B/N`309>_j@<0V:kW0P2M[n@30::`hP<0
Y[3O0`2[/]d30;6df`80][OJ00@000000;Nff02k^]P0^k[H1031_ML20<O2eP80bL;C00<0cLOE0<o8
d`3?b=<0203oool00`000000oooo0?ooo`0B0?ooo`007P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo0P0000000`1We:X0oooo0?ooo`030?ooo`<000002`3oool00`2[
h?T0Zmgi0:_Mn@020:_Mn@@0^]_a0`31enX30;oEjP@0`]7U0`34c^840<?:h0<0`/SN0P30aml20<35
gP80_lGO00<0_/?N0;g3g`2m`ml00`2k`]l40;S1h@<0]<3R0`2a_n@30:fniP<0ZKgX0`2T_>X309nk
k0<0Vk[^0P2G^Nl209>hl0<0TKSa1@2?]o82092hlP@0TkWa0P2F^_0309Zkk`<0W[c^0`2S_^`30:Nn
jP80ZkoX102_`>H30;;0i0<0]L;S0`2h`^840;[3h@<0_<GQ102man830;k9h`@0_/cU0`2mcnL40;[A
j`040;GDl02feo40]]Oa0;KGl@<0[=Wg0`2NeO/308[@oP<0N<Ko0P1X^_d305j`n`0405VXn01SYoH0
HjOf06>WmP80IZ?c0`1]X_00101eXNd0PZG[00000022YN/208^Wi`<0TjST102JZN020:>/g@/0oooo
00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0
oooo0P0000060?ooo`<000005@3oool206JXmP80IJch0P1Y/_X307:jo080O/;m0`2@bO/309_?nP<0
Y]3f102]d?840;;?k`@0]<g]0`2ebn/20;K9j@80]<WY0P2eanP40;?4i`<0/L;W0`2``>D30:fmi@@0
Zk_U0P2Z^^D40:Rii@80Z;SU0`2W]nD50:Nhi@@0Z;WU0P2X^^H40:Zli`<0[;kW0`2]`NP30:o3j@@0
/<KZ0P2_b>`40:o:k@<0[/c_102/c_830:O>m0<0X/gf0`2KboP309G7n@80T<?i0`27__T308Fjm`80
QKKe0`27/o8208Zak`<0SZo]0P2C[nT309R^i`<0VjgT0`2Q[^420:J`g`@0[;7L0P2a]=/20;Nff003
0000002g]]P0_KWF0080_KWF1033_M@30<W2d`80clSC0P3Bb=080?ooo`030000003oool0oooo0140
oooo000N0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`<000004@3oool40:_Jn0@0^=S`0`2oeNX20;gCjP@0`<oV1032c><40<79h@<0
`<OO102oaMl40;g3g`<0^/;P102g`N430;C0h`<0/KoT0`2]_^L30:Vmj0<0Y;g[0P2O^n`409^kkP80
UkW`0P2C^?03096hl@D0SkOb0`2@^?4209>il@<0U[W`0`2J^nl209jlkP@0Xkg/0P2W_^X40:^oj0<0
[koU0`2b`>@30;K1h`@0^<;Q0`2k`n440;g5h0<0_/OQ102ob^830<3=i0<0_m3W0`2le>`20;kFk0<0
^=[a0`2/g?P409WJo@80Pm7o0`1^a?l205bgo0<0D:_i00@0Bj;f05VRm@1IX_D0FJ;e0P1MW_<206FM
l080MJ7]00<0OZ;Z0000001nX^X00P28Y>L3096Vh`<0VZWP0`2RZ]`:0?ooo`030000003oool0oooo
02T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo0`00000I0?ooo`80L:cf0P1`/?P307BfnP80Nkck0P24`o`409?9nP80WLgi102VcoD4
0:g?lP<0/<k_102bc>d20;G;j`@0]<WY102ca^T30;74j0<0/L;W0`2^_nH30:bmiP<0Zk_U0`2Y^^D3
0:Rii@<0YkSU0`2W]nD60:Rhi@<0ZKWU0`2Z^nH30:bmiP<0[;kW0`2_`NL30;74j0<0/<KZ0`2ab>/4
0;7;k@<0/<g_102]co830:O@m@<0XLkg0`2Hc?T30977nP80Rl?j0P27__T407nhn080Ok?f0`22/?<2
08F^l0<0RZg]0P2@[>T309J/iP80VjgT102P[N020:J_gP<0[;7L0`2b/mT20;Ree`030000002h]ML0
_KWF0080_[WD0P33_M@20<FmdP030<W2d`3<`]40c<;A00<0d/S@00<0eLS=0?ooo`3oool01@3oool0
0`000000oooo0?ooo`0A0?ooo`007P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0
oooo0?ooo`D000005P3oool40:_Gm`<0]mK`0`2mdnX30;_AjP@0_/kV0`2obn<40<39h@@0_lOP0`2m
aN040;c3h0@0^L;Q0`2g`N830;C0h`<0/L3U0`2]_nL30:Vnj@<0Y;k[0`2P_>d209^kkP<0Uk[`0`2C
^O42096hl@D0SkOb0`2@^?4209>hl@<0U[W`0`2J^^h209jkk@@0Xkc[0P2W_NT40:bni`80[koU102c
_n@30;K1hP@0^L;Q00<0^l?Q0;c3h02l`n000P2maN020;k5g`030;k7h@30an00`<OP0080_l[R0P31
bn430<;>i0<0`M;W0`2ne^`20<3Hk0<0^Mgb0`2/goT409GMoP<0L=3m0P1A_?T203VYm080?jCf0P0k
V_<304bLm00405>Il@1UWO00IIg`06FMl080Kig]00@0NYoY0000001jWnT0QJ7V102?Xn8309VVg`80
XZ[L2P3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00P3oool5000001d0oooo0P1`[?H2072`n0<0O;Wi0`22__X208[4n`@0U/Wi0P2NcOL30:K>
m0@0[<kb102_cNl20;;<k@@0/l[/0`2bb>X40;76j@<0[l?Y0`2_`NP30:boi`<0[;gV0`2Y^nH30:Vj
i@<0Z;SU1P2W^>D20:Rhi@@0ZKST0P2Y^ND40:^ki@80[;gV102^_nH30;72i`<0/LCX0`2ba^T40;?9
j`<0//c]102ac^l30:g@lP@0Ym7f0P2PcoP309G<n`<0SLOk0P26`_/308:lnP80OkSh0P1o/oH308:`
l`80QJk`0`2:[Nd2092/j@@0Tj[V0P2JZn<30:2]h080YZoN102//=/00`2b/mT0/[;H0;:bf0020;Re
e`040000002n^M@0_[WD0;jie0@0aKgB0`3<`]40103>`Lh0d/S@0=G8c@3Eb<d70?ooo`030000003o
ool0oooo0140oooo000N0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0oooo
0P00000J0?ooo`@0ZmCf102ednl30;_AjP80^/oZ0P2nc^H20;c=iP@0_/[T102nb>830;g6h@@0_<GQ
0`2k`n420;W2h@80^L;R0P2g`N840;C1i0<0/<7V0`2]_nL30:VojP<0Y;k[0`2O_Nh209^lk`80Uk[`
102C^O42096hlP<0SkSb0P2?]o83092gl@<0TkS`0P2F^O0209ZjkP@0W[[/0P2S_>/30:Nlj0<0[;kW
0`2__^D40;>oh`030;K1hP2g`>40]l3Q00<0^L;Q0`2l`n040;k5g`<0`<OP0`31bn420<?;h0030<;>
i034cn<0a<oS00<0`mCV0`30f>`20<?Kj`<0^n3b00@0Zn?j0:[WnP2ZioX0Z^Oj1027h?`304k5l005
02>Wi00RWNX08YgZ02:MjP0CS>H00P0WT>h303jDl@0504JBk`1MV>l0GIS_05fHk`1YVN`00P1jWnT0
0`000000QJ7V08FQiP0308nShP<0VJKO0`2RYmX90?ooo`030000003oool0oooo02T0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`8000008@3oool207V`mP80NKCh0P1l
^OT408Ron@80SlCj102Ib?P20:3<m`@0Ylgd102[cO430:k<l0<0/Lc^0`2abN`40;37j`<0[lG[0`2_
`nT30:g1j0<0[;oW0`2Z_NL20:VkiP@0Z;WV0P2X^>D60:Nhi@<0Z;ST0`2Y^>@40:^ji080Zk_U0`2^
_ND40;2oi@80/L;W102ca>L30;C7j0@0]L[Z0`2dcN`40;;@k`<0[];c102WdoL209k@n@<0T/gl0`28
aod20831o0<0N[_k0P1h]OT307VamP80Njkc0P20Zo0308JZk@80SJ[Y0`2CZ^H209Z[h`@0Wj_O0P2V
[Md30:b`f`<0/[;H0`2i]=@010000000_[WD0<2hdP30^=820<FmdP80akc@00<0c<;A0<k1cP3>`Lh0
0P3Eb<d20=S8bPH0oooo00<000000?ooo`3oool04@3oool001h0oooo00@000000?ooo`3oool0oooo
100000040?ooo`030000003oool0oooo01`0oooo0P2[d_@40;CAk`<0^/oZ0`2lcNH20;_;i`80_/[T
0P2lbN@20;k8hP80_LOR00<0_LKQ0;c6hP2la^800P2laN420;_4h@<0^l?Q0`2i`^840;K2h`<0/l7T
0`2``NH30:g0j0<0ZL3Z0`2T_n`309nnkP<0Vkc`0P2G^o4209>il@<0T;Wb0`2?^?8208nglP80T;Oa
102B]o0209Jhk`80V[W^102N^^`20:>kjP<0YkcX0`2/_NH30;2mi0<0/koS102g`>430;[1g`<0_L?N
102oaMh30<;8g`@0`l_P0P34cn<20<KAhP@0a]KV00D0`m_[0<GNj`35g^/0aMk[0;cTl`030;kXlP03
0:S[nP2Uk_P0X?7d0080X?7d00<0F]?P0474b@3oool01@3oool0100k000007[G0122i@0@P^D202b:
k@80AY;_0P1CT^d206VIk00307FKj0000000MI_X0080PYgU0`2=X>4309RTg@80XZOJ2@3oool00`00
0000oooo0?ooo`0Y0?ooo`040000003oool0oooo0?ooo`@000001@3oool00`000000oooo0?ooo`0Q
0?ooo`80P;?e0P21]oL208>kn0@0SL7h0P2BaOP409_8m`80XL_f0`2Wc?<40:_<l@80[/c`102_bnh4
0:o9k@<0[/O/0P2_aN/40:g3jP<0Zl3Y0`2Z_^P30:Rlj0<0Z;_W0`2W^NH30:Nhi@<0YkOU0P2X]n@3
0:Rhi0<0Z[WT102/^^@20:fki0<0[kgT0`2`_nD40;?2iP<0]LGV102fb>P30;O;j@<0]/k/102ddNl3
0:oDl`@0YmGh0P2Md_X408k>o@80P/On0P1h_od307:hn`80Kk;i0`1`[OH207BZl`80NZS`0`21Yn`2
08VWj@<0TJSU0P2HZN8309n[g`<0YZcK0`2/[]T30;>`eP80^KCD00@000000<2hdP30^=80`;SB1037
_=020<k1cP80dL7;0`3Hb<X00`3KalH0oooo0?ooo`030?ooo`030000003oool0oooo0140oooo000O
0?ooo`030000003oool0oooo00T0oooo0P00000M0?ooo`80Zm3d102ccnl40;S>jP@0^l_W0`2lbN@4
0;g7hP@0_<KR0`2ka>440;[3h@@0^<?R0`2f`^<30;?2i@<0/<7V0`2]`NT30:W0jP<0Y;o]0P2O_^h4
09^ml080U[ca0P2C^_83092ilP<0S[Sb0P2>]o83092gl@80T[O`0`2E]nl309Zhk@80W[[/0`2S^^T3
0:Nkj0<0[;cU0`2`_N@30;BnhP@0^;oP0`2k`Mh30;k3g@80_lGN0P31aMd30<C8gP@0aLcO0P36dN82
0<WBh@<0b=SU0P3;f^@20<SRj`80bnGZ0P30kO801`31lO40`_K^0<;fkP2HlNd0S>kP07cUcP3LnJ/0
2@3oool2001af08067kV00D0>8W/05>Bk@1CT^d0Di;]066Cj`0207FKj00400000022WND0PYgU08:M
i@80SJ3Q0`2HY=d30:6Uf0P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?oo
o`8000008P3oool208Jfm080QkWf0`29_?L30971m`80U/Gg102Mb?H20:;:m@@0Yl_c102Zbo420:g;
l0<0[/[^102]b>d20:k7k0@0[LG[0`2[`^/30:_0j@<0Z;kY0P2X_>P40:Nji`80YkWV102V^>D20:Ng
i@<0Z;OT0`2Y^>@30:^ih`<0[;[T0`2^^n<30:nmi0<0//3T102e`nD30;O6i@@0^<WW0`2ic>T40;S@
k0<0]]?_0`2`e_@40:OGn@<0V=Gm0`28c_h207[6oP80Kkgm0`1X]?/206F^n@<0IjWf00@0K:Kc07ZX
l01jZ?00NZS`0P21Yn`308VWj@80TJSU0P2HZN8409jYgP<0YZcK0`2][ML20;>`eP<0^k?B00@00000
0<2hdP32]m00`[O@0P37_=020<Vkc@<0dL7;00D0dl780=S8bP3KalH0flO60=g7``040?ooo`030000
003oool0oooo0140oooo000]0?ooo`030000003oool0oooo01`0oooo0P2[c_<40;;>kP<0]lcZ102j
b^L40;_8i0<0^lOS102kaN840;[4hP<0^L?R102h`n<30;K3i0<0/l;U0`2``^L30:g2j@<0ZL7[0`2T
`Nh309nok`80Vkg`0`2F_?8309:jlP80SkWc0P2>^?8308fglP<0SkKa0P2A]o0209Fgk`@0VKO]0P2N
^N/30:>jj@<0Yk[W0P2/_>D40;2lh`<0];gQ0P2h_n020;RngP030;_1gP2l`=d0_<3M00<0_/?M0P31
aMd20<?5g0040<C8gP36bM`0a/WL0<K9g0<0b<gN0P39d^420<cCg`<0bm[T0P3?g><20<_UjP80c^WY
00L0`O7a0<;fkP32n^/0`OgT0;Slc@2^m[/0gofj00`0oooo00@004B_005_g00WO^L09gkW0`17R^/0
101ISNT0L9KW072Fi`00000307jJh`80RigO0`2GXM`20:6Uf0P0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0O0?ooo`<0S;Sc0`2<^_D208jnmP80TL7g102IaOH209g8mP@0Xl[d0`2W
bo840:W;l@80[<_`102/bNl30:c8kP<0[<K]0`2[a>`20:_2j`@0Z<3Z0`2V_NX30:Nlj080Yk[W102V
^NH20:Jhi@<0YkOU0`2X]n@30:Vhh`<0ZkWS0`2]^^<20:jkh`@0/KkS0`2d`><40;O3h`<0^LKT102k
b^H30;_>j0@0^m7[0`2heNl40;7Hm0<0Y][j0`2Deoh308;?o`<0I<7n00@0EKCk05^`n`1K/?/0Fk3k
0P1IZ?P205bSmP80K:Kc0`1cY?0207bTk0<0QJCX0P2>YND209JWh@<0WZWN102UZ]X20:f]e`<0]:oD
0`2k/m800`000000`[O@0<:gd0030<Vkc@80bk_:00<0dL7;0=?1b03C`LP00P3KalH20=g7``@0oooo
00<000000?ooo`3oool04@3oool002h0oooo00<000000?ooo`3oool0703oool30:[=lP<0/Lc^102f
bnX40;S9i`<0^/OU102ja^<40;[5hP<0^/CR0`2i`n820;S3h`80]l?S0`2f`n@30;?3i@@0/<?W0P2]
`^T30:W2k080Y<7^102O`?0209Znl@<0U;gc0`2A^o<208jil`80SKSc0`2=]o8308jfl@80TKK`0`2D
]^l209Vgk@<0WKO[0`2S^NT30:NiiP<0[;_T0`2a^n820;Bmh@@0^;kN0`2l`=d40<33g0<0`lGL0`36
bM`20<S9f`<0b/kM0P3<dml20<oEgP<0cmcS0P3Bgn802P3>jNT0d^gW0=;]i`3El>D0f?CQ0=_hg@3N
nmL0h?g?0>7naP3LnJ/=0?ooo`0406D00000G<l04g;Q01=bh@80>X;X0P1ISNT206ZAi@030000001n
V^<0OY[S0080RigO0`2GXM`20:6Uf0T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0P0?ooo`80S;Sc0`2A_?@309:om@80UL;f0`2KaOD309o8m@<0XlWc102Wb_820:W;l@@0Zl[`0`2[
bNl20:c8kP@0Z/K^0`2X`nd30:S2k0<0Y[o[0`2V_NX30:Fkj@80YK[X102U^>L20:JgiP80YkOU102X
]n@20:Vhh`@0[;SS0`2^^^830;2lhP<0/kkR0`2f`N820;O3h`80^LCR00<0^LKT0;_7h`2kan<00P2k
b^H20;g;i@030;_>j02ncnL0_/oW00@0_M?[0`2if>l00`2bfoD0/mke0;?Nm@020;?Nm@<0Y=ok0`29
f_l306k<oP80EKck0P13[OL203VQm080BZ;f0P1>WO@206:Ql`<0K9o_00@0MYo/08FTj025Y>P0QJCX
0P2>YND309JWh@<0WJOM0`2UZ]X30:f[eP<0]:oD0`2l/]000`000000a;K=0<Bfc@040<^kbP<0dl78
00D0eL350=_7aP3Mal<0gLO30>37_`040?ooo`030000003oool0oooo0100oooo000_0?ooo`030000
003oool0oooo01d0oooo0P2Zbo440;3;k@<0]<WY102gb>L40;W7i@<0^/GS102jaN800`2ja>80^LCR
0;W4hP030;W3hP<0]l?S102f`n@30;?3iP@0/<CX0P2]`nX40:S3k@80Y<;^0`2N`O4209VolP<0U;gc
0`2?^o@208fim0<0S;Oc0P2<]_8208jfl@<0SkG`0`2C]Nh209Rfk@80WKO[102R^>P20:NiiP@0[;[S
0P2a^n840;Flg`<0^KkM0`2m`=`40<72f`<0aLGJ0`38bM/20<[:f@030<[>g@3=cm/0cLoK0080cmGN
0P3Bem`30=;OhP040=KRh03Ji=d0f^CM0=G`i@80foSM00@0g__G0>3mc`3Qo/H0g?V[403oool01P00
Akd006?H01=bh@0[N><0>X;X04n6iP80JY7U00@0000007ZEhP1jUN80NYGR0P28V]h309FNfP80XJ?F
203oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0200oooo0P2A^O82096lm0@0U/3d
0P2H`oD409g5m080X<Od102TbO<30:O9lP80ZL[a102YbO040:W8l080Z/O_0`2XaNh30:S3k@<0Y/7]
0P2V_n/40:Bmj`80YK_Y0`2T^NP30:Fhi`<0YKOV0`2V]nD30:Rgh`<0Z[OS0`2]^>820:jjhP@0/KcQ
0`2e_^430;K1hP<0^LCR102kan<30;g;i@80_/oW0`30d>H30;oEjP80_=[_0P2ngNl40;CQmP040:;R
o02Oi_`0WnKl09oVo0<0M]Wj0`1=`_<00`0ZZ>X0;J;`02fRl00202>Dk@0403RHlP1>WO@0CYgd04jM
m080Ei[b0P1SV^l207JOk0<0PJ7X0P2;X^@309BTh080WJOM102UZ=P20:f[eP@0]JkA0P2l/]001000
0000a;K=0<FebP35]LX20<^kbP80cK[700<0dl780=G0a@3E`<D00P3Mal<20>37_`050>?6^`3oool0
oooo0?ooo`0000004P3oool00300oooo0P00000N0?ooo`<0Z/W`0`2`bNd40;C8j@@0]/OW0`2ha^D0
0`2jaN<0^LGS0;W5h`030;[5hP@0^LCR0`2i`n840;O3h`<0]/CU0`2ca>H30;34j0<0[LC[102Xa>d2
0:C3k`<0W/;b0`2H_o<209>mm080Sk_d0`2;^O@308Vgm080R[Kc0P2<]O4308nel080TkG^0`2H]N`3
09ffjP80X[SX0`2W^>D30:bjh`<0/K[Q102f_=h0102i_]d0^[gL0;Zmg02m`=`20;nofP80`L;K0P33
`]T00`35aMX0alGI0<O5f@040<[:f@80cLoK0P3@d=T20=;Gg080eMSJ00`0e^;P0=[Tg@3Ji=d0f^CM
0=gWf`3Rj]L0iNcC0=kke`3PoLl0hOk60??b^`3el[8A0?ooo`04000GS`00DL`0:gSS02]hh`80ChKV
0P1SS>@00`000000NYGR07ZEhP0208RJgP<0UIkJ0P2QXmH80?ooo`030000003oool0oooo03/0oooo
0P00000Q0?ooo`<0UK_a0P2E_O<409[1l`80Vl?d0`2Oa_<20:;7l`@0YLWb102WbO850:S9l@@0YlS`
0P2Xanl40:K5k`80Y/?^0`2T`>h30:Bnk0<0X[c[0P2S^^T30:Bij0<0Y;OW0P2U]nH40:Jfi080Z;OS
102[]n820:fhhP@0/;[Q0`2c_>020;Fnh@@0^<7Q0`2ka>440;k8hP<0_lcT0`30d>H20<?Bi@<0`]OY
00@0_]g_0<7Pk`31h>l0`N3_0P2fiOH30;OYmP0709_Xn`2Ej_P0UN[h09GZn01CcNH0>[oC01fZ]P04
0?ooo`04001od008QN4028GQ02>=k0<0?YCa00@0BY?`06>Jk`1SV^l0Hi[_0P1_Vn/207bLi`80Rj;T
102BX]l209bTf`<0YJSH0`2]ZM<30;F^d@<0_K7>00<000000<FebP35]LX0103=^/L30=G0a@030=Ro
`P3Pakl0h<No0080hlJk00@0iLFg0?ooo`3oool000004P3oool00380oooo00<000000?ooo`3oool0
6`3oool40:[8k`@0[lS/0`2canT40;K6i`80^<KU102iaN<30;W4h`@0^LCR102ha><30;O4h`<0]/CU
0`2ca>H30;74j0@0[LG[0P2Xa>d30:?4l0<0W/;b0`2G`?@209:mm080SK_e0`2;^O@308Nfm080R;Cc
0`2:]?8208jdl080T[C^0P2H]N`409bej@80X[KW0`2W]n@30:bihP<0/KWO0`2f_=h30;Zmg0@0_koJ
0`33`]T20<O5f@80bLGG103=b]L20=3@f@80dm7G0P3Ef=X20=WJf0050=cLeP3Mim/0gNOK0>;Ze`3U
k=<00P3Yk/l00`3]l<T0l?720?Gb/P0C0?ooo`05000GS`00?K`06fcN01]/gP14O^@00`1SS>@00`00
0000MI7P07FAh00208FFg0<0Ti_H0P2PX=@70?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool07`3oool309Rll080VKkb102L`O8209k3l`@0XLKb0P2Sao830:G8lP@0YlWb1P2WbO420:O8
l0@0Y/K`0`2Ta?020:C2k`<0XKo^0`2R_^d20::lj`<0XKWZ0`2R^>P30::gi`<0Y;KU0P2V]^@30:Rf
h`<0ZkOR0`2]^>440;6jh080/kcP102g_]l30;[1g`<0_LCO1030b>430<;=hP<0`m;U0P36dn@20<GI
j@80b=cX0`33hnh20<KWkP030;O]mP2glO@0]o7d0080]oGa00<0P>OX0:_ifP3CoKX0203oool00`00
EkL02WgR02b9k00202b9k00503^:k01HTnd0F9?]05RCk@1WU^X00`1lW>L208NOh`<0TZ;O0P2LY=/4
0:FVeP80[JWC102f[<l01P2m/Lh0_[3;0;j`b`000000aKG:0<Ndb080cK[70P3?^L@01P3E`<D0f;o2
0=Ro`P3J_[h0h<No0>?6^`80iLFg0P3oool00`000000oooo0?ooo`0@0?ooo`00<`3oool00`000000
oooo0?ooo`0L0?ooo`@0Z/O_0`2_an`30;;6j@<0]/KW102gaND30;S4h`@0^LCS0`2ia>840;S4h`<0
^<CT0`2fa>D30;C5i`@0/LGY0`2]a^`20:S5kP@0XlGa0P2M`o<309G1m@80T;kf0`2;^oH208Rhm@80
QkKd0P28]?<408RblP80S;;`0P2A/nh309Ndk080W;GY0`2R]NH30:Ngi0<0[KOQ0P2a^Ml40;Nkg@<0
^kcJ1030_mT30<G2e`80bLGG0P3;aMD20<g:e`80cl_E0P3CdML20=KAe@80fM[H00D0g=cF0>3MdP3P
gM80h^[G0>G/d`020>W^c`040>g`b@3`lL80lo:k0?Gb/Q@0oooo0P00?K`00`08G]H06fcN03Qeh002
05b5hP030000001eTN00MI7P0080QIKL0`2CVmP20:2Pe0L0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`0O0?ooo`<0W;g_0`2L_o4209c1lP@0X<Cb0`2Sa_820:C7lP@0Y/Sb1P2WbO83
0:K8lP80Y/Oa102Ta_420:C4l0@0XL;`0P2Q_nh309nmkP<0X;_/0P2Q^NX30:6gj@80X[OW102S]ND2
0:Jfi080Z;KS102[]n430:jhh0<0/K[P0`2d_=l40;VngP040;[1g`2l`Mh0_<7N0;g4g`<0`<GN0`33
bMl30<G>h@<0a]?T0P39eN<20<SLj080c=kV00@0a^O^0<W[k@39jnd0bN_]0P3<k^/01@2gmO40]OW]
0;7ji@2[nMX0dofj00/0oooo00<0M`0001Ili@0FO>D00P0kR^`204f<j`80IiKZ0`1fV>H00`24Vn80
T9kM092Ng@02092Ng@80Vj;J0`2UY]H30:jXd@<0]Zc?0`2n/</00`000000akC80<Ndb0040<nia080
f;o20P3J_[h20>?6^`80iLFg0P3oool00`000000oooo0?ooo`0@0?ooo`00=03oool00`000000oooo
0?ooo`0L0?ooo`@0Z/K^0`2^aN/30;;6j@<0]LGV102ga>D40;S4h`<0^LCS0`2ia>820;S4h`80^LCS
0P2ha>@40;K5i@<0]<GW102aa^T30:k7k0<0Z<K_0`2Ra_8209c4m0<0Tl7f0`2=__L208Rjm`80QKOf
0P24]OD308Fcl`80R;;b0P2</_0308nakP<0UK;[0P2L/nT20::eiP@0YkKS0P2]]n440;:hgP<0^;[K
00<0^kcJ0;flf@2m_=T00P30_mT20<:ne`030<G2e`36`MD0a/7E00@0blGE0P3?bmD20=;;d`80e]7E
0P3Id]800`3Lg=H0h=gB0>3MdP020>CNc`060>OPb`3[hLL0kO390?3a`P3cl[/0mO:b5P3oool00`00
::X003fl001?c@0203Qeh00305=ng`1LQN8000000080L8cN00<0PY;J09:HeP2BV=H00P2BV=H209nM
dPH0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0P0?ooo`80W;g_0`2O_o0209o2
l@@0X/Ca0P2Sa_840:G7l@<0Y/Sa1P2VbO840:G8lP80Y<Ob0`2RaO820:74l@@0W/7a0P2O_nl209nm
kP@0WK[]0P2O^N/20:6gj@@0XKKW0P2S]ND30:Fei0<0Z;KR0`2/]^430:jhh0<0/[WN0`2f^md30;Vn
gP<0_<7N0`30aMh20<;5g0030<?9g`35bMd0aLWM00@0b<oO0P39eN<20<cGh@030<cNiP3?hND0cn7U
0080dnCS00T0c>k[0<obj@3?l^T0co;Y0=;giP3Dn^40e_gK0=?m^P3am[H03@3oool2001/fP0502Un
i`1=S>/0CHc[04f<j`1OSnP00`1fV>H208BKhP<0T9kM0P2KX]X40:BSe080[ZSA0P2f[<l20;N[c@80
_[3;00@0akC800000037]<P0b;;50P3?^L@20=6h`@<0f[jn00L0g;fj0>G5]`3UaKL0ilBc0>W3[`3o
ool000000180oooo000e0?ooo`8000007P3oool40:W5k@80[/G[0`2baNP40;C4iP<0]/CT102h`n<3
0;W3hP<0^LCR0`2ia><40;S4i0<0]lGU102ea^L30;;7jP<0[/S]0`2Xao030:;7l`80V/Ge0`2C`OH3
08Znn080QK[h0P21]oL3082dm@80P[;d0P25/O8208Val0<0Sk7^0P2E/^/309^bj0<0XK?U0P2W]^<3
0:ffg`@0/kOL0P2h^]/30;flf@@0`[kG0P36`MD20<S1d`80blGE0P3=aM<20=;;d`80e<_A0P3Id]82
0=cCc`040=oDc03Tg/l0i=k?0>OPb`80jn7700@0k^;20?;R_@3eh[P0mn:a5`3oool010004ID004o=
001?c@0[Jm/205=ng`03072<gP000000L8cN0080PY;J0`2BV=H209nMdPH0oooo00<000000?ooo`3o
ool0@03oool200000240oooo0P2N_Nh40:70k`80X/;`0`2TaO030:G6l@<0Y/Sa102WbO450:K9lP@0
Y<Sc0P2Sao8409o5l`80Wl?b0P2N`O4309bnl0<0W;c^0`2K^Nd209fhj`<0WkKY0`2P]NL20:>di@80
YKGT102X]N820:bfh@@0[kOO0`2c^Md20;Jkg@@0^[kL0`2n`M`40<;5g080aLWM0P38b]/40<_@gP80
c=OQ00<0d=SO0=?Jg@3Cf]d00P3Ci><02@3Gin40f^[O0=[Zg`3BmnH0e?[Q0=Kmf`3Gom<0kOG60>of
_P0?0?ooo`8005S<00<05G7Q03n3j00oPnP00P1OSnP3072Ci003082Gh02>Vm`0SY_L0080SY_L0P2J
WmP30:BSe080[ZSA102gZld30;n^b@030<Ndb0000000b;;500<0dKS10P3C]kh02@3J_[h0g;fj0=bm
^P3N_;L0iLFg0>O4/`3Y`jl0jl:[0000000B0?ooo`00=`3oool00`000000oooo0?ooo`0L0?ooo`@0
ZLC]0P2^a>X40;74j0<0]<CV0`2f`n@40;S3h`<0^L?R0`2ia>840;W4h`<0^LGT102ga^D30;K7i`<0
/lSZ0`2^b>d30:S9l@<0XLSd0`2IaOH20972m`<0Q[ki0P20^OT307fem`80O;;f0P1n/?@208:_lP80
Qjo`0`2=/>d209Baj`80Vk;X102Q/^@20:NdhP<0[KGN0`2c]m`30;Rif@@0_[_G0`33_MD30<S1d`<0
cLGC0P3?aM020=C;d@80el_>0P3Ldll20=oDc0080>;Db@3Wh</0jn770>_Qa`3^h/80l^:m0?GR^03g
h[4I0?ooo`0:000AU@00?L4004o=02][f`1;Mm`0DgkO06^6g0000000JhKL07n>f0<0TYSF0`2NV]06
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool07`3oool30:6nkP<0Y<7^0P2T`nl4
0:K5k`80Y/K`102Wb?430:O9l@80Y/Wb102UbO<30:;8l`80XLOc102MaO@209c3l`80W<3b0`2H_O43
09Vkk`80VkW]0`2J]^`309fej@80X;GW0`2R/nD30:Fdh`80Z;GR0`2/]^040;2ggP80/kWM102h^m`3
0;bnf`@0`L7J0`35aMX20<S:f`80bl_I103>dM`00`3@f=l0dm[M0=?Jg@020=OLf`050=OWh@3Jj]l0
f^[O0=k]f`3RkmP00P3Vl]<00`3Zm<d0koJn0?7f]P0@0?ooo`80046i00<05G7Q031ii00`NN@00P1E
R>H206Z>h`80P9OP0`2>Vm`209ZOf0<0Y:?D0`2^Y/l20;N[c@80]jW;0P2o[/T20<Rba@030000003:
/L80dKS100<0dkNn0P3L_KX20=jl]`80ilBc00@0jL>_0>_2Z`3oool000004@3oool003P0oooo00<0
00000?ooo`3oool07@3oool20:W4k@@0[/?Z0`2a`nL30;C3i@<0]/?T0`2h`n<70;W3hP@0^LCR0`2i
aN<40;S7i@<0]lSW102cb^/20:k:kP<0Z<[a102Pb_H209O7n080S/;i0`21_OX207^hn@<0MkCh0P1g
/?L00`1i[_@0PZob08:_lP0208N_l0@0Rjk]0P2B[nX209Z`i`<0XK;T0`2W/^420:fegP@0/kKK0`2i
^=P20;jke`80_k[E00@0`kgE0<Fmd`35_M<0b<7C0P3:`M430<o5d080d/G>0`3Gblh00`3Jbl/0gmC<
0=oDc0020>;Db@070>GEa@3XeL40k^;20>kR`P3bh[d0mN:h0?OR/@0J0?ooo`03000AU@00?L40763F
0080BgOL00<0JhKL0000001[Q]`00P1oS]P3092Dd`80WY[@1P3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo01l0oooo0`2T_nd20:C1kP@0Y/?^0`2XaNl20:O7l0@0Z<S`0`2XbO430:K9
lP<0Y<Wc0P2Rb?<409o7m080WLGd0`2I`_@309Rol`80V;ga0`2F^_0209RhkP<0V[K/0`2K]>T209jc
i`<0X[?U0`2U/n<20:Rdh@<0[KGN0`2`]mh30;Fhg0@0^[_J00<0_;kK0;jnf@2n_]T00P31`MX20<?1
f0030<G5fP37a]T0alKI0080bl_I0`3>bmL20=7BfP80e=?G0P3Gg=/20=_Nf@030=kOeP3NkM/0h^oH
0080i_;C00<0j_C=0>geaP3am[H04`3oool01@00::80<7WT031ii00`NN@0Bh7S00<0JXkS00@0O9?N
08jKg02>Vm`0SY_L0`2IW=H30:BQdP80[ZK?102gZL/01P2o[/T0`Jg60<6]aP38//D000000<Za`P@0
dkNn00X0e;Jk0=bm^P3N_;L0g[bg0=nk/`3Wa;<0jL>_0>_2Z`3oool000004@3oool003T0oooo00<0
00000?ooo`3oool07@3oool20:W3k0@0[/?Y0`2a`^L30;C3i@<0]/?T102h`n830;W3hP@0^/?R0`2j
a>840;[6h`<0^LOU102hbNP30;C;j`80[l_^102Xc?8309k;m`80U<Si0P2:`oX2086mnP<0NkSi0P1g
]?P207N`m`80NJkd0P1m[O8308B]l080Rjk]0P2B[nX309V^iP<0X;3S0P2W/^430:jcg@80/kKK0P2d
]MT20;Vhf0@0_k[E0`35_M<20<[1d@<0c<3?0`3BaLh01@3DaL/0el_>0=[;b`3Jbl/0g<_80080h]C9
00L0iMG50>SE`@3XeL40k=Fm0?;R_@3eh[P0mn:a01`0oooo00L002^c000m`@0LH=H0@FoH04]gg01V
PMT000000080OhkH0`2@U=<209jJd0H0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0O0?ooo`@0Y[o/0P2V`^d30:S4k@<0Z/K^0`2Yanl30:W9l0@0Z<[a0P2Vb_830:?9m0<0XLSd0`2L
aoD209[4m@@0UL7e0P2D__@209FllP80U[[`0`2D]^l309Nek080VkCY0P2N/nL40:6bi@80YK?S0`2Y
/n030:fegP<0/KKL00<0]KSL0;JhfP2f^=X00`2j^mX30;jnf@@0`l7H0P37a]T20<W6eP<0c/_G0P3A
c=D20=CCe`80f=CE0P3Kg]T02@3NgmH0h^7B0>;QdP3Vh/l0j^C:0>[dc@3]mLH0m>Jk0?OV]00D0?oo
o`03000XXP0OKMh07fgN0080Bh7S0P1SR>4207bCgP<0RiSJ0P2IW=H30:BQdP<0[ZC=0`2gZL/30<6]
aP80b[7200@000000<^`_`3C]kh0dkNn0P3D][/20=jl]`80gk^c0P3Y`jl20?ooo`030000003oool0
oooo00l0oooo000j0?ooo`030000003oool0oooo01`0oooo102Y`^/30:k2j0<0/L;W0`2d`^D40;K2
h`<0^<;R102i`n430;[4h@@0^lGR0`2ka^<30;[8i@@0^L[X0`2fcN/20:o=k`@0Z<kd0`2McOP20979
n`<0Q/?k0P1k_O/207BgnP80L;;i0P1`[_L207>/m@<0NJ_b0P20Zo0208R/k@80T:gY0`2I[^H309n_
hP80Yk7O0`2^/md30;Bef@<0^[OF1031^M<30<Jld0<0c<3?0P3>_l`00`3BaLh0e<G;0=C5b`020=[;
b`80g<_800@0gl_50>GEa@3UeLD0j=G10P3/eKd00`3^eKT0lMBd0??D[`0M0?ooo`04000[/`0=Dll0
@FoH045_f080IX7I00<0000007b9eP1lRMH00`2>TM4209fGc@D0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0O0?ooo`@0Z<3[0P2X`^`40:[4k@80Z/K^0`2Zb>l40:[9l0<0Z<_a0P2V
b_<40:;:m080WlSe0`2JaoH309O4mP<0TL3f0P2@_OD2096kl`80T[Sa0`2D]^l309Bck080V;;Y0`2M
/^L20:6bi@<0Y;;R0P2Y/n040:fdg@80/KKL102f^=X30;^jf@<0`;gG1035`MH20<W6eP80c<KD0`3A
c=D20=?<dP80f=CE0P3KeM80103NgmH0h^7B0>;QdP3Vh/l20>[TbP040>gUaP3aiL40m>Jk0?OV]1D0
oooo00@003Zk00aOeP0OKMh0?gSP0`1SR>40101gS]d0RiSJ08^HfP2;V=X209VLeP@0Y9k@0P2^Y<d4
0;RWb0070<6]aP32Zl<0`Z_30<Za`P3;/;l000000=>g_P030=Bf^`060=Jd]`3N_;L0gk^c0=nk/`3Q
^Zl0jl:[0P3oool00`000000oooo0?ooo`0?0?ooo`00>`3oool2000001h0oooo0`2Y`N/30:k1j0<0
/L7V0`2d`N@40;K1h`<0^<;Q0P2i`n420;[3h@030;[4h@2ka>40^lCQ0080^lGR0P2laN40102ka^<0
_<OR0;c7hP2jb>D30;c9i@<0^/cX102gc^`30;7Al@80Z=3e0`2KcoX308g:o0<0NL;n0P1[^Od00`1R
/O/0J:oi06R_n@0206R[m`<0K:Se0P1cYo8207bXk`80QJW/0P2>ZnT309N]i@80WjoR0`2W[mh30:jb
f`<0]K?G00<0^[OF0;^ee02k]M@00P31^M<20<:hd0040<Jld038^lh0b;_>0<c0c`<0c[o<0P3DaL/2
0=K4b080g<_80P3OblD01@3Rbl40j=G10>SE`@3/eKd0k]Fi0080lMBd00<0lmB_0?ooo`3oool0703o
ool01000:k<03E??03MUe011KmP205mkeP030000001lRMH0SY7A0080SY7A0`2MUld40?ooo`030000
003oool0oooo04D0oooo0P00000Q0?ooo`80Z<3[0`2[`n/40:c5k080ZlK]102/b>h30:_:l0@0ZL_b
0P2Vbo<30:7;m@80WLWf102Ga_P209?4m`80TL3f0`2<_?H308bim080S[Ob0P2A]Nl209Bck0<0U[7Z
0`2K/NL20:2ai080Y;;R102Y/]l20:fdg@<0/[GK102h]mT0102k^]T0_K[G0;fje`30_ML20<:me@80
aL7F0P37`M@20<c6e080clKB00D0dLcE0=?<dP3Cc=80dlcB0=K<d0020=_EdP80g]K?00P0h]K;0>KR
c`3Zi<X0j^C:0>gUaP3aiL40m>Jk0?OV]1L0oooo00@003Zk001?c@0oN>00?gSP0P1KPMh207N>g@<0
R9CH0P2GVM@30:BNd0<0[Z7;0`2hYlP30<:[``<0bk2o00<000000=Bf^`3D][/00P3F];L20=nk/`80
hKZ_00@0jl:[0?ooo`3oool000004@3oool003d0oooo00<000000?ooo`3oool0703oool30:W0jP<0
[/7X0`2a`ND40;C1h`<0]l7R0P2h`^440;[3h@<0^lCQ102laN430;c7hP<0_<WU0P2mb^@30;_=i`@0
^=3/0`2bdo440:ODm`80V=7k0`22bol20731oP80H;Kl00<0EZgj05j[n@1NZoT00`1OY_L206BTm003
06fTlP1lZ>l0O:S_0080QJW/0`2>ZnT209N]i@<0WjgQ0`2W[mh30:j`f@80]K?G102k]M@30<:hd0<0
b;_>0`3>_l`20=2ob@<0e/C800<0fLC50=o;a@3OblD00P3Rbl401P3Tbkh0k=Fm0>cE_@3^eKT0lMBd
0??D[b00oooo00<004G603MUe00gIM@00P1ONmH00`000000N8CC08jAd@0208jAd@@0W9C;0`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo01l0oooo0P2[`NX40:g3jP<0[/G[0P2]and4
0:g9kP<0[<_`102Yc?820:G<m0<0X<_f0`2KbOL309?6n@80Sl?i0P2=_oP208blmP@0QkOe0P29]O82
08fcl080TK7]0`2F/NX209^ai`<0Wk3T0P2T/N440:VagP80[[?L0`2c]=T30;Rgf@<0_K[G1032_MD2
0<O1e080bL7B0`3?a]830=?<dP80e/c@00<0fLg=0=kFc`3Ne/l00P3Re//0103UelP0j=O40>gUaP3a
iL420?CV^`030?OV]03oool0oooo01H0oooo0P00Cld2035]f`80Fh7N0P1bRMX208RDf0<0UiWD0`2S
W<h30:jQb`040;RWb02iYLD0^JG50<:[``80`jW000<0bk2o0<b^_00000000P3D][/20=Jd]`040=Nc
]03O^k<0hKZ_0>6j[`<0oooo00<000000?ooo`3oool03`3oool003h0oooo00<000000?ooo`3oool0
7@3oool20:W0jP<0[/3W102a`>D30;C0h`80]l7R102i`N430;_2h0@0_<CP0`2maN440;g7hP80_L[T
0P2obn@40;g>i`<0^M;/0`2beO840:KGn@<0TMCn0P1jbol206BnoP80D[7j00@0AZKg056Vn01AY_P0
DJKh0P1CXOH00`1JWo@0KJCb06fTlP0207NUk`80PJK/0`2<Z>P209JZi080WjgQ102W[M`20:j`f@<0
][;E0P2k]M@20;bdd@040<:hd033]lh0`kO>0<RkcP80b[[<0`3@_lT20=:na`040=K4b03Ia<D0fLC5
0=_3`P80h/_10P3Tbkh01@3Wb[X0k]Fi0?7D]03ae;@0lmB_0200oooo00@0001o0015aP0/G<l0=fGD
0P1IM=<00`000000N8CC08b=c`0208b=c`<0W9C;0`3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo01h0oooo102]`NT30:o4j@<0/<KZ0`2_b>`30:o:kP@0[Lc`0`2ZcO820:G=m0@0Wlcg
0P2IbOP308o6nP80Rl;j0`27__T208Jjm`80QkOe0P29]O8308Ral080SZo]0`2C[nX209V_iP80Wk3T
0`2T[n030:VagP<0[k;K0`2c]=T30;Vge`<0_kWD1034_M<20<W1dP80c<3?00@0clKB0=76c`3Aa/l0
dLK?0P3Fc=020=W=c@040=c=bP3Re//0h]K;0>GGb080j=O400@0jmNo0>kG^`3aekL0mnJd6P3oool0
1@00?L4004o=02=ReP0aKM/0DW[K00<0LXWJ0P26T=H309JFdP80Xic>0`2^XL/30;VUa@<0`jW00`3<
[[`00`000000e[Bg0=Jd]`020=Nc]080hKZ_00D0hkV/0?ooo`3oool0oooo0000000A0?ooo`00?`3o
ool00`000000oooo0?ooo`0M0?ooo`80ZKoY102^_nH30;6oi080]<3S102g`>430;W1h0@0^l;O0`2m
a=l30;k6h0@0_lSQ0P2obn@30<7<h`<0_m3W0`2ke>d40;?Hl`040:GJnP2SgO/0Xmgk0:?Mn`80S=Ko
101Sao`01013/oH0@:[f042ZmP0cWO8204:Nm@0304JJl`1JWo@0FYod0080IIoa0P1aXNl207fSj`<0
RJGW0P2DZ><209j[g`<0YjgL0`2_[mP20;Jbe@@0_;CA0`33]lh20<Zjc080c;W900@0d;o90=:na`3B
_/L0d[k70P3Ia<D20=_3`P030=g3_`3Tbkh0i<^n0080ilZj00@0jLZf0>_9/P3ce:l0lmB_8@3oool0
0`0007l0;5c?02aLc`0305Udd`040000002<SLl0S8g?08b=c`<0W9C;0`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo01l0oooo0`2_`^P40;74j080/<KZ0`2ab>`40;3;k@<0[/g`102Z
c_<30:C?mP80WLgh0`2Bbo/308_6n`80QL7k0P21_?X207nhn080PKGf0P24/_<208Ral0<0SZo]0P2C
[nX309N]iP80WJkS0`2T[n030:V`g@80[k;K102d/mP30;Zfe@030;nie030^M80`;WB0080a;gC0P36
_=430<c0c`<0dLK?0P3Da/`20=W=c@80g<g:00D0glg60>GGb03UelP0j=O40>_G_`020>kG^`030?7G
]`3cek80oooo01X0oooo00<003g102=ReP0SH]H00P1BN]/206f4f080QY3F0`2FU]820:>LcP@0[Yo8
00<0^JG50;VS`P2iXl800P33ZL001P34Ykd0c:jl0<b^_03>[KT000000=Jd]`80ek>d00<0fK6a0>6j
[`3S^J`00`3oool00`000000oooo0?ooo`0?0?ooo`00@03oool2000001h0oooo0P2Y_^P40:jniP80
/KoT102d_n830;S0h0<0^/7O102l`]h30;k4gP@0`<KO0`31bN430<7<h`80`lgS0`31d^L40;gGk@04
0;CKm02eg_@0]Mkd0;GNm0<0XN3l101kf?d205;2m`80:jS/00D03Y3R01^AjP0`UO00<9G`03FAl002
04nIlP0305bJl01aXNl0LJ7_00<0OJ?[0P29YNL209BXh`80WZ_O102VZmX20:n_f0<0][3C102m/ll0
0`33]lh0aKK<0<Ffc0030<bib@<0d[k70P3D_L@20=_3`P80gL>o00<0gl:k0>C;_P3Wb[X00P3Yb[H0
0`3[bK80kLR^0?ooo`0R0?ooo`07000W/P0/G<l0;5c?059]d01IM=<0M7o@0000000308Z9c0<0Vi78
0`3oool00`000000oooo0?ooo`190?ooo`800000803oool30;72i`@0/lCW0P2banT40;;9j`<0//c]
0`2_c_040:_@l`<0Y=3g0P2Kc_T408k;o080QLGm0P1m`?`207Vjn`80N;Ki0P1j/_L207f`m0<0Pjka
0P29[Nd2092]j@80UjgV0`2L[>830:>^g`80ZK3M0`2_/MT20;Bcf080][;F0P2j]]D40<2idP80a[cA
0P38^lh00`3<`<l0c/3=0<k0c@030=C6c080e/G90P3LcLX20=o=aP060>;=``3Xel@0jmNo0>_G_`3^
ek/0lMNg0P3cek8K0?ooo`05000[/`00?L404eK?02=ReP19LMP00`1]Q=P208><e0<0U9??0P2RVL/3
0:jOb0<0^J?200@0`jW00<BW_@34Ykd0c:jl0`3>[KT010000000ek>d0=Nc]03I/K420>>i[0@0oooo
00<000000?ooo`3oool03P3oool00480oooo00<000000?ooo`3oool06`3oool40:Vmi`80[[kV0`2a
_^<40;Fnh@<0^;oO0`2k`=h20;c2gP80_/;M1030a=d30<;6gP<0`lWO0`33cN<20<G?hP<0`mCV0P2o
fNd30<7Lk@040;KRm@2gi_H0]nKf0;OVmP80V^Kl00L0U>Si08_Ym02;jO@0RnWd05K@`P2Jl<40R^BY
0080oooo00@0066b001Zb000N=d08HKZ0P11TO00101AU>l0JYc^06ZLkP1ZW>h207VOjP80QZ;V0P2B
YN8309fXgP80YZ_J0`2_[MH00`2f/=<0]joA0;N_d@030;fcc`80aKK<0P36]<T0103<^LT0cKS60<fh
aP3=^<H30=Bma0030=Jl`@3M`kl0gL>o0080gl:k0P3Wb[X0103Yb[H0jlVb0>_9/P3]b:hT0?ooo`07
021Ab@0/G<l0DVg@059]d01dOm00000007Aod00208Z9c0<0Vi780`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo01h0oooo0`2c`^D30;?4i`<0]<OX102db^X30;?=k@@0/Lo`0`2[dO@4
0:?Bn0<0U]3l0P29bod207k4oP80MKkm0P1`^?/206nbn@<0LJog00@0MZcd07f[l@1mZo40OJ_a0P25
Z^d208f[j@80UJ_V0`2L[>820:>^g`<0ZJkK0`2_/MT30;JbeP<0_;GC1032^=030<RkcP80c/3=0`3@
_lX30=K5b@030=W5aP3OcLH0glg60080h/g300H0i<bo0>O<^`3^ek/0k]Nk0?7G]`3cek8M0?ooo`03
000[/`0CE/l04eK?0080BG7H0P1XO]D208><e0<0U9??0P2RVL/40:jMa@80^J?20`34Ykd40<j]^@06
0000003G/k@0fK6a0=Va/@3J/:d0hkV/103oool00`000000oooo0?ooo`0>0?ooo`00@`3oool00`00
0000oooo0?ooo`0L0?ooo`<0Z[cW0P2^_ND40;:mhP<0][kP00<0^;oO0;VngP2i_]h00`2k`=h20;k2
g@80_l;L0P30a=d20<74g0<0`lOM1034b]h20<G?hP80am3Q0`36e^H20<SHi@80a=o]0P36hn`20;SZ
mP060;S_m@2hlo<0]oO`0;CijP2_n^40Y_SD0P3Jo]850?ooo`04001?[P00Hl/02GOQ0328k0<0DIC_
0P1RUnd00`1cVnT0QZ;V08JRiP0209:UhP@0W:KL0P2VZMT20:n]eP@0]joA0`2n/Ld30<Jdb@<0cKS6
0P3?]l<01@3D_L@0e[c10=Jl`@3H^kd0gL>o0080gl:k00@0hL6h0>W:]P3Yb[H0jlVb0P3]b:hT0?oo
o`03000GYP0PDLT0DVg@0080DVg@00@0LG[=0000002:RL`0RXW<0`2KTLP30?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool07`3oool20;?2i@<0]LGV102fb>P30;K;j@@0]Lk/0`2bdO03
0:cCm0@0X]Ci0`2BdOd208?;o`80ML?n0P1[^od306Bcn`80Hjki0P1WZ_L00`1^Z?@0OJ_a07f[l@02
08FZk@80SJ_Y0`2BZND309^Zh@80XZcN0P2Y[]/40;2_f0<0]k7D00<0_;GC0;fdd@2m]=400P32^=02
0<BgcP030<RkcP3:^l`0b[_<00<0d;o:0P3B_lL0103FaLT0fLG60=W5aP3KaL<20>;=``050>C<_`3W
c;/0ilbk0>W<^03aekL00P3cek8N0?ooo`04000[/`03B<L04eK?04Uaf0<0J7kE00@0OhOA09BCc`2D
Tll0U9??0`2RU/T30:jMa@030;VS`P2jXL00^Z700080a:Nm00<0a:Jj0<j]^@3>[KT00P3?ZkH01@00
0000fK6a0=Va/@3J/:d0hkV/00@0oooo00<000000?ooo`3oool03P3oool004@0oooo00<000000?oo
o`3oool0703oool20:Zli`@0[[cT0`2b_>420;Jnh0@0^KkN0`2l`=d30;o2g0<0`LCL0P33a=/01033
amd0aLOK0<G7f`35am/30<O;g@80am3Q0`3:dMl20<SHi@80c=[T00X0a^?/0<WVk039i^`0bNK/0<cZ
j`3?k^T0d_;W0=Gfi03HnMl0f_cI0P3Jo]800`3al[l0oooo0?ooo`050?ooo`03001:]000IM<07G_V
00<0A8c]00<0FY7[07>Kj@1cVnT00P23WnD2096Rh@<0W:KL0P2VZMT30:n[d`@0^:g?00@0_[7=0;n`
bP2o/<X0a[C90P37/lH0103=^<H0ckO30<ng``3?]l<20=Jl`@80f;^m0P3O`[/20>71^0040>?0]03[
bK80jlVb0>g8[RH0oooo00@001NV021Ab@1<I/`0DVg@0P1aN/d00`000000R8G908R5b@0309Z>a@80
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0O0?ooo`80]L?T102gaND30;S8i`@0
^<cY00@0]lo/0;WAk02idN`0^M7/102ee?030:gGmP<0WmSl0P2=doh40779o`80G;cl00<0CK3i05J^
nP1F[_X00P1FZ?P00`1KYOH0KZSd06jXm00207JWl@80P:O]0P29Z>T309:Yi@80Vj[Q0`2RZ]d20:V]
fP@0/:kF0P2g/M@30;fdd@@0a;O>0`3:^l`00`3<^/T0d;o:0=:oa`020=:oa`80fLG60P3KaL<0103M
a<00i<bo0>C<_`3Wc;/20>W<^0030>_;]03]b[00oooo01h0oooo00@000>A00=8a`03B<L0?fWD0`1X
O]D207n7d@<0TXo=0P2RU/T30:jMa@<0^Z7000@0a:Nm0<BV^P34Y[X0cZfi0`3?ZkH0103I/K400000
0=Z`[@3J/:d50?ooo`030000003oool0oooo00h0oooo00150?ooo`8000007@3oool30:ZkiP<0[[_S
0P2b_>440;Jmg`<0^[kM0`2m_m/40<31f`<0`lCK0`35am/20<O7fP<0bLcL00<0b]7O0<cCgP3<dmh0
0P3<dmh00`3<f^@0cmcS0<oLh`020=;OhP80c>[[00D0cnkY0=;bi`3Em^@0f?WO0=[lf@020=[ndP03
0>oaaP3oool0oooo00T0oooo00<004k100I]g@0fP^T00P1JTN/206jFj00307nKi02AX^40TJ;Q00@0
Vj?K0P2VYmL30:nYd@<0^:g?0`2o/<X30<NcaP@0ckO300D0d;K00=Jl`@3H^kd0f;^m0=Vj^P020>71
^080hl2d00<0i;na0>g8[P3]b:h09`3oool00`0DAl<0C6K<04aVc002075jc@0300000028QLT0R8G9
00<0VXk50P3oool00`000000oooo0?ooo`1>0?ooo`8000007`3oool40;O3h`<0^LKT0`2jbNH30;[=
j080_LkW102kd^/30;OFl0<0[M[g102Lf_d307oDo`80HlKm0P1:]_P203RWm004032Ll@15X?H0AJ3f
04bMm080Hj?d0P1^Xo4207ZSk@80QJGY0`2@Y^@209VXh@80XZ[M0`2YZmP30;2^eP<0^;3B00<0_KCA
0;jccP2n/lh00P34]lh20<Ffb`030<Zkc03<^/T0c;[900<0d[o70P3D_/@20=_5``80gLC000@0gl>l
0>O<^`3Wc;/0jLbh0P3[bk@00`3]b[00oooo0?ooo`0N0?ooo`040003T@00>Kh00dS703mYe080HWSB
0P1oQm4309:?c@80XYK9102^V/<20;ZQ`0<0a:Jj103?ZkH0103@ZK8000000=Z`[@3J/:d50?ooo`03
0000003oool0oooo00h0oooo00170?ooo`030000003oool0oooo01X0oooo102Z^^D20:jkh`<0/k_P
102g_=d30;^mf`@0_[oJ0`32`MT30<G4f@<0alOJ0P39b=P20<_=f`<0c/gI0P3?e=d20=;Ff`060=;O
hP3Fh^00e^;P0=KRh03Ii=h0gNOK0P3QjMP01@3Tk=@0j>k@0>c`c03/l<`0lO:o00`0oooo00@004k1
00I]g@0UMn@0Ch[Y0P1^U^P207nKi0<0SYoO0P2KXm/30:JUe@<0[jWA0`2hZl`0102o/<X0`Jk80<6^
b037/lH20<Rba080ckO30P3@]/020=Rk_@80fKZj00<0fkVg0>71^03S`;@00P3T_k400`3V_Zh0oooo
0?ooo`0W0?ooo`0301A7``14G/P0C6K<0080KGG:00<0000008R5b@2JS/D00P2JS/D20?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07@3oool40;W3hP<0^lKS102mb^D20;g>i`80_loV
102me>/0102hfO40^]_a0;[Kl@2jfo440:kPn00409KOoP2@hOd0T>7m093Qo@80J=3j0P0m]nl0100H
W><07iWZ01nIjP0FSNL2036Fl@0403ZDl@1GWO<0Eigc06FMl080NZ?]0`25YNT2092Vi080VJSQ0`2Q
Z=/30:V[f0<0/JgD0P2h/=840;jccP<0aKK;0P3<^/T20<jiaP@0e;k400<0e[g10=g4`03Ma<000P3O
`k`0103R`kT0jLbh0>W<^03[bk@20>g:/200oooo00@0001o000i_P00>Kh0=Eo?0`1RN=80101lPll0
TXo=09:?c@2BSld30:6CaP<0[Y[300@0^Z700;ZO_@2jWkd0a:Jj0P35Y;L20<n[]P80d:Vb00<0f[2]
0000003J/:d01@3oool00`000000oooo0?ooo`0>0?ooo`00B03oool00`000000oooo0?ooo`0K0?oo
o`<0Z[WT0P2_^^840;>kg`<0^;_L00<0^kgK0;bmfP2l_MX00P2n_mX20<2nf0030<;1f@33`MP0`l7H
00@0a/CH0P39b=P20<c8e`<0c/gI0P3Ac]L20=;Ff`060=KGf@3If=L0fMSG0=WHe`3Ii=h0gNOK0P3Q
jMP01@3Tk=@0j>k@0>c`c03/l<`0lO:o00h0oooo00@005[A02Egi00UMn@0@h;V0P1WTNH207^GhP<0
S9cM0P2JXMT20:JUe@@0/:O?0P2hZl`30<6^b0@0b;;40`3@]/000`3A]Kd0fKZj0=Vj^P020=^i]`80
hl2d0P3T_k400`3V_Zh0oooo0?ooo`0W0?ooo`0300Pk_014G/P0A5k800<0KGG:00<0000008J1a`2I
Rl<00P2IRl<00`3oool000000?ooo`1B0?ooo`030000003oool0oooo01h0oooo0`2ka>040;k7h@<0
_l_S00<0_loV0<;@i@32d>D00P32d>D20<3FjP80`]SZ102lg_400`2^hoT0[^Oi0:g[n@030:g[n@06
07kQmP1`gNd0G=GN04C5a`24j<P0bOk60P3oool01@00K/8068SX01R8j00UQn/0BIGa00<0IIg`0P1c
Wn`2086Qj080SJ?T0P2HY]l20:6Xf`@0ZJWG0P2a[M@30;R_d0@0`;7<00<0aKK;0<Neb@37]LT00`3>
^LH00`3?^<<0e;k40=Bna0020=Jm`@030=Rl_P3Ma<00gl>l0080h/>i00@0hl:f0>_;]03[bk@0kLZ`
8P3oool01P0007l003Vn000i_P0eGll0G77?069hdP80O8??0`2AS<X20:6CaP<0[Y[30`2jWkd40<FT
]`<0d:Vb00<0d:R_0=Z`[@0000001@3oool00`000000oooo0?ooo`0>0?ooo`00B@3oool00`000000
oooo0?ooo`0K0?ooo`80Z[WT102_^N430;Bjg@80^;_L102l_MX30<2nf080`l7H0`35`MH30<S4eP80
c<SG0`3>b=D20=7>e`80dloE00@0e]OI0=WHe`3If=L0fMSG0P3Lf]@0103Ofm80hmc?0>C/e03Xk]02
0>c`c0030?3P_`3bh;X0oooo00h0oooo00D004G0015Yg013P^H0@h;V05n;i00307^GhP80S9cM0P2J
XMT30:FRdP<0/:O?00@0^:_<0;VYbP2iZLX0`Jk80P32[LD20<Rba080b[3100D0d;K00=6e_@3A]Kd0
dk>j0=Vj^P020=^i]`030=bh]03T_k40i;na0080i[j^:P3oool304ANb00406U`a`1]MLX0QX770000
00<0VH_30P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01h0oooo102na=l30<37
h080`LcR0`34c>430<CBi0030<;HjP35f^T0aM[Y0080aM[Y00<0_^7a0<7Ul031iO000P33jO020:c^
n0070:Wbm@2Um?00WOCX0<klh`3>o]`0bOk60>gg``050?ooo`04001ef`0UQn/09HO[03R;k@80FYO_
0P1/V^`00`1lWNL0SJ?T08fSi00309JSgP80XJKJ0`2YZML30;6[dP030;R_d02i[Ld0^Jg=00<0`;7<
0P37]LT20<RdaP040<jiaP3?^<<0ckS30<nh``80e[g10P3H_;h20=o3_0040>;3^@3S`[H0hl:f0>G1
/P80kLZ`8`3oool00`00:[<003Vn02YFbP0205aac`80O8??0`2AS<X20:6CaP@0[YS00P2jWkd00`2k
WKX0aJBg0<FT]`020<JR]0060=2Y/P3@Z:l0d:R_0=Z`[@3oool000001@3oool00`000000oooo0?oo
o`0=0?ooo`00BP3oool2000001`0oooo0`2Z]n<30:nhg`80];[M0`2i^]/40;flf@<0`KkG0`35`MH2
0<O0e0030<S4eP3;a=@0blCD00<0c/SE0P3@b=820=??e@80e/oC00H0fM3@0=cJe03Lf]@0g=[D0=oK
dP3Sg<l20>KMb`040>WNa`3]gl<0l>2o0?;P^Q40oooo00<002f/001Id`0fN>800P1ORn@307NBh@80
RYSL0P2IWML20:FRdP<0/:O?0`2iZLX30<:]a@@0b[310P3A]Kd20=>c^P80fkVg0P3L^;@00`3M]k40
i;na0>Jn[P0[0?ooo`0300Pk_00mEl@0A5k80080JG3700<0QX770000002IRl<00P2IRl<20?ooo`03
0000003oool0oooo0580oooo0P00000O0?ooo`@0`<CM0`32b=h30<C<h@80algO0P37dn<30<[EhP80
b=cX0P3;gnL01P33jO00a^g_0<K]k`38lNd0boG[0<cij080c_cS00<0c_kL0>Sdd03[m/X01`3oool0
1@1`000037SR00ahhP0TO^L0CXo]0080K9[/0P1lWNL208ZPh`80UZ?N0`2QY]X30:VWe080/J_B102i
[Ld30<6`b@<0b;C60`3?^<<20=6g`0<0f;bn00<0f[bk0>;3^@3R`kT00P3S`[H00`3U`K80il2_0?oo
o`0T0?ooo`03000Z/`0ZE/X0G77?0080G77?0P1iO/`208n8b0<0X9740`2^V<00102jWkd0^ifj0;^M
^P35Y;L30<JR]0030=2Y/P3@Z:l0d:R_0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0=0?ooo`00C03oool00`000000oooo0?ooo`0I0?ooo`@0Z[KR0P2_^=l30;Fig0@0^[[I0`2n
^mL30<>me@@0al3D0P3;a=@20<g4dP<0d<SB0P3CbM020=K?d`060=W@d03LdLd0g=7=0=cAc@3Ofm80
hmc?0P3VgL/01@3Yg/L0kMo30?3P_`3`h;l0l^2j0180oooo00@002f/001Id`0fN>80EhCR0`1gT^42
08ZHg080VIgG0P2UX]840;2Uc@040;VYbP2jYlL0^ZO70<:]a@80`j_20P3:/<420<^__P050=6e_@3C
/kX0dk>j0=Bb]`3K^KL00P3L^;@00`3M]k40i[j^0>Jn[P0/0?ooo`80?EO40`1YL<L00`24OL@00000
09R7`00209R7`0030?ooo`000000oooo05D0oooo00<000000?ooo`3oool07P3oool30<;4f`@0aLSM
0P37cMl20<W>g@<0b]GR0P3=e^000`3;gnL0cn;V0<oRiP020=;Ti0040=KWhP3Jj]l0gNgM0=g]g@80
hO3I00<0j?C@0>_fbP3oool02@3oool01000I=@097kW02Ani`0oQ^X206>Dj`80MYWV0P26WN4209BQ
g@<0X:CH0P2YYm@30;:Yd080^Jg=0P2j[</01031/<T0`Zo70<:_a`38]<H20<Zb``060<nh``3A]l00
dKO00=6g`03C][d0f;bn0P3J_;/00`3L^kP0hl:f0>?2]P020>G1/P030>O0[`3oool0oooo02<0oooo
00<001ZX000Z/`0OBl@00P1FJ/`307Unc080ShS80`2PTL@20:jH`0<0^ifj1036X[@30=2X[`<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`00C@3oool00`000000oooo0?oo
o`0J0?ooo`80Z[KR0`2`]mh30;FgfP80^[[I0P2k^ML0102n^mL0_k[E0;nje@33_MD30<Bmd`<0b;oB
0P3=a=830<o3c`80dlW@0P3EbLh0103Id=00g=7=0=cAc@3LdLd20=oAb`040>;Aa`3Td/@0jMk70>gO
``80l>2o00<0l^2j0?ooo`3oool04P3oool01000AlH09fgM05N4hP1GQ>8307:=gP80QiCJ0P2HV]D2
0:FPd0<0/:G=0`2jYlL30<>[`P@0bjnn0P3C/kX20=Bb]`80g;Rd0P3M]k400`3O]Zh0i[j^0?ooo`0[
0?ooo`<0?EO400D0IF_406U`a`24OL@0Q7g40000000209R7`0030?ooo`000000oooo05H0oooo00<0
00000?ooo`3oool07P3oool00`32a=/0a<CJ0<C4fP040<O9f`030<W>g@3<cm`0c<oL0080c<oL00<0
cMKP0=3HgP3@f=h00P3DfM`20=;Ti0040=KWhP3Jj]l0gNgM0=g]g@80hO3I00<0j?C@0>_fbP3bi;h0
2`3oool01@00CL4036oO03n6jP0oQ^X0FHgY0080MYWV0P26WN4309BQg@80X:CH0`2YYM<20;:Yd0@0
^Zc;0`32[lL30<Zb``<0dKO00P3C][d20=Zl^`80g;^h00<0gKZd0>?2]P3U`K800P3W`:lV0?ooo`03
000JZ00OBl@07d_40080EV[<0P1fNLT208n8b0<0X9740`2^U[d20;^M^P060;^K]`36X[@0aZ:d0<JR
]036XK80d:R_1@3oool01@000000oooo0?ooo`3oool0000000l0oooo001>0?ooo`030000003oool0
oooo01X0oooo0P2Z]N030;2eg0<0]KOJ0`2k^ML30;nje@<0a;gC0P36_=400`38_m80b[o@0<Zod003
0<o3c`80dL?=0P3EbLh20=S9b`80f/W80P3OdL/01@3RdLL0i=;40>CBa03Wd/40jM:m0080k=6i00<0
k]6f0?ooo`3oool04`3oool01000AlH05UoF04ilg`1>O=l207:=gP80QiCJ0P2HV]D30:FPd0<0/:;:
00<0^ZO70;ZVa02jY/@00P33Zl801P33ZKl0bjnn0<^__P3;[kh0c:fk0=>c^P80e;:g00D0eK6d0=bh
]03M]k40gKNa0=nf[P0^0?ooo`80?EO40P1UJl@308Ama0040000002HQl00oooo000005P0oooo00<0
00000?ooo`3oool07@3oool20<C4fP<0alCH0P3:bMT20<g9e`<0cm3J0P3BdMP01@3DfM`0em_J0=OK
fP3GfmX0fmcH0080g]kE00H0h]oB0>7`f@3Ql=T0jN;;0>cSa`3_i<8>0?ooo`04001Ld`0^NnD0FHgY
05V=j@80L9?U0P23VN0309:Mf`80Wj;G0P2YYM<30;:Wc@80^Zc;0P2kZ/P01032[lL0`jg40<>]a03:
//<20<^a`080dKO00P3C][d00`3D]KX0f[bk0=bk^0020=fj]080iL6b00<0il2_0?ooo`3oool09P3o
ool010006ZP07d_401m;a01FJ/`307Iib@0308f4a@2PS/40X8k10080X8k10P2^U[d00`2kWKX0^i^g
0;^K]`020<JR]080aZ6b00<0d:R_0?ooo`3oool0103oool010000000oooo0?ooo`00000?0?ooo`00
C`3oool2000001X0oooo0`2[/ml30;2eg0<0][KI0`2l^=H40<6id`<0a[cA0P3:_m030<bnc@80dL?=
0P3C`l/20=S9b`80f/W80P3Lb<H20>;Aa`030>CBa03Wd/40jM:m00<0k=6i00<0k]6f0?ooo`3oool0
503oool201IOeP0504=cf`1>O=l0K8OL06b7g024T=L00`2FUm830:FMcP80/:;:0`2jY/@01@33Zl80
`jVo0<>Y_`33ZKl0bjnn0080c:fk0P3D/[L20=Fa]080gKNa0P3O]Zh_0?ooo`0403eGa01UJl@0IF_4
06E[a080PWW100@0000009R7`03oool00000F@3oool2000001h0oooo0`37a=P20<W4eP80cLWG0`3?
b]D20=;Af080eM7E0P3Hd]<0103Kg=P0g]kE0=kNe@3Rgm820>GQc`040>WRb`3/hlL0knC20?;T_Pl0
oooo00D004K201Y]gP1>QNH0CXGV06V>h`0308>Ih080TYgK0P2OX]L30:VSd0<0/ZO=0`2kZ/P30<>]
a0@0bk700P3C][d20=Be^P80g;^h0P3M^[@00`3N^K40il2_0>O0[`0Y0?ooo`0301=0_@0OBl@0Cf?8
00<0MWW90P2=Q<D30:2>`@80[YJm102kVkL00`36X[@0aZ6b0<JQ/P070?ooo`040000003oool0oooo
000000l0oooo001A0?ooo`030000003oool0oooo01P0oooo0`2[/]h30;6df`<0]kGG0`2m]m@20<6i
d`80`[SA0`37^ll30<bnc@80c[k;0`3C`l/00`3E`/P0f/W80=[9b0030=c8aP050=k8``3Td/@0im;1
0>OB`@3Yd[d00P3/dKT00`3^dKH0oooo0?ooo`0E0?ooo`04000KY003DLh00e7>04=cf`80K8OL0P24
T=L209JGdP<0YIg>0`2`X<L20;ZVa0@0`jVo0`3<[K/01P3=[;P0e;:g0=Fa]03E/K@0e[2a0=fg/@80
gkJ^<03oool306E[a0<0PWW100<0000009N4_@000000F`3oool00`000000oooo0?ooo`0M0?ooo`80
bLCF0P3<a=<30<o:e@80d/[B0P3EdMD20=SBd`80fm?@00<0g]?=0>;OdP3UhLl00P3Yh//00`3/hlL0
knC20?;T_P0A0?ooo`030016`P0JKMh0@GcS0080JHkS0`1oU=h2092Jf@80WYoD0P2YXm040;>Vb`04
0;^Zb02lZ<H0_:S60<>]a080a:c10P3;/L020<b`_@<0e;Fj00<0e[>g0=fj]03M^[@00P3N^K400`3P
]jh0oooo0?ooo`0X0?ooo`804d2m0P1?HlP2079daP80SHC50`2PS/430:jC^P<0^i^g0`36XK880?oo
o`030000003oool0000000l0oooo001B0?ooo`030000003oool0oooo01P0oooo0`2[/]h30;6bf@03
0;Nee`2h]=D0^;CE0080_KOD0`32^=420<>hc`030<Nkc`39^/`0bK[<00@0c[k;00D0d;g80=?3b`3E
`/P0eL;80=O2a@030=c8aP80g/S300<0hLRo0>?7_03Yd[d00`3/dKT00`3^dKH0oooo0?ooo`0F0?oo
o`040004S`00@<<00e7>04=cf`80IX;I00<0PHcE09JGdP2FUm80102TV//20;2Pa`<0^jC20P33ZKl2
0<BW_@030<b]^`3=[;P0cJbh0080eK6d0P3F/;420=nf[S<0oooo00P0IF_4089i`@22NL40PWW109N4
_@000000oooo000005/0oooo00<000000?ooo`3oool07@3oool20<c4d`<0c/CA0P3Bb]820=C:d004
0=SBd`3Kdm00fm?@0=_Cd080g]?=00L0hMC:0>CDa`3We<<0imC30>WD`03/e;`0k]Bh0180oooo00<0
15gF045lh`11O><00P1QQn4207nDgP80T9[I0P2NWm@30:VQcP<0/jK;0`2lZ<H30<B/`@@0c;2m00H0
cZnk0=Be^P3F/kL0e[>g0=Nb]03M^[@20=ji/@030>2g[P3oool0oooo02T0oooo0P0C@;d01@1?HlP0
LWC6079daP1bM<H0S87200@0Wh^n0P2^TkX20;^K]`80^iVd00<0aZ6b0?ooo`3oool0203oool00`00
0000oooo0000000>0?ooo`00D`3oool00`000000oooo0?ooo`0H0?ooo`<0Zk3L0P2a/]T30;Rde@@0
_[GA0`33^<l20<Vjc080b[W:0P3>_//20=2mb080eL;80P3G`/D20=W1`P80g/S300@0hLRo0>?7_03S
ak`0iLNi0P3Wa[H00`3^dKH0oooo0?ooo`0H0?ooo`030004S`00@<<0>6WG0080IX;I0P21S=D209FD
d0<0Y9[;0`2`W/D20;^T`P@0a:Nm0`3=[;P01P3>Z[D0eK6d0=J`/@3F/;40ejj^0=nf[S@0oooo0`22
NL4209N4_@800000G03oool00`000000oooo0?ooo`0M0?ooo`<0c/CA0P3@a<h20=C:d080el[=0P3J
b/X20=kCc@050>7DbP3Te<L0imC30>OD``3Ye<000P3/e;`00`3^e;P0oooo0?ooo`0A0?ooo`03000C
U@00BlT0<W7N0080HHOQ0P1jT=`208jGe`80WIcB0`2YXLh30;>Tb0030;bXaP2mYl<0_JO30080a:c1
00<0aJZn0<b`_@3</;d00P3>[k/20=Jc]`80ek:d0P3N^K420>2g[R`0oooo00<04d2m04QLa01bM<H0
0P1bM<H208b1`P<0Wh^n0P2^TkX40;^I]0030<JQ/P3oool0oooo00T0oooo0P00000>0?ooo`00E03o
ool2000001T0oooo0P2[/=`30;:ae`<0^K;C0P2n]M420;ndc`030<>hc`35]/`0aKK<00@0b[W:0P3@
_LP20=6laP80el;50`3I`L801@3K`Kl0hLRo0>78_`3Sak`0iLNi00<0ilJf00<0j<Jb0?ooo`3oool0
6@3oool0100018l0043303QYe`1PNmL2086<e@<0UIC@0`2TV<T20;2Na@030;^T`P2kX[l0^j:o0080
a:Nm0P35Y[X00`3=[;P0cZZe0<jZ]@020=J`/@80ejj^>03oool209N4_@800000G@3oool2000001h0
oooo0`3@a<h20=;4c080el[=0`3Jb/X0103Lb/L0hMC:0>CDa`3Te<L20>OD``030>WD`03/e;`0k]Bh
01D0oooo00@001>E001;b@0bLMh0F83N0P1jT=`208jGe`80WIcB102YW/`20;>Tb0<0_JO300@0a:c1
0<FZ_P35Z[h0aJZn0`3>[k/01`3?[KP0e[>g0=Nb]03G/[@0f;6a0=ji/@3P]jh0;P3oool204QLa003
06m_``1bM<H0S8720080S8720P2ORkh00`2^TkX0[Y6h0:jA^0030;^I]0`0oooo0P00000>0?ooo`00
EP3oool00`000000oooo0?ooo`0G0?ooo`80ZjoJ0`2b[mH30;Vbd`<0_kC?0P35]/`20<JebP80b[W:
0P3<^<L20=6laP80dkc30`3I`L820=_1_`040=c0_03Sak`0hlNl0>G7^@80ilJf0P3Xa[8L0?ooo`04
000^]`0/Gm40H7_G061ke`80OXOB0`2CT<d20:BHb@80/9k5102kX[l30<FV^P<0cZZe00@0cjVb0=J`
/@3G[Zh0ejj^>P3oool2000005l0oooo00<000000?ooo`3oool07@3oool20=;4c080eL?90`3Jb/X2
0=c:a`050=k:a03Qb/40imC30>OD``3Ye<000P3/e;`00`3^e;P0oooo0?ooo`0D0?ooo`04000f^P0R
IMP0F83N05R0gP80MX_J0P2<TmD209bId0<0ZIk<00<0/jC80;BRaP2dX/H00P2mYl<30<FZ_P80aZVl
00<0cZnk0<n]^03?[KP00P3G/[@20=Ra/@80h;N^;`3oool00`18G<@0Kfo306m_``0308b1`P80Wh^n
0`2^TKP30;^I]0`0oooo0P00000>0?ooo`00E`3oool00`000000oooo0?ooo`0F0?ooo`<0ZjgI0`2b
[mH30;Vad@<0`;?=1036]LX20<bha`80cKO50`3C_<<20=Fk`080fl6o0P3L`;`0103N_kT0iLNi0>O6
]P3Wa[H20>S6/Qh0oooo00<002jg02aOd@1JM=<00P1nQm8309>@c@80Y9S90`2`Vl820;^R_`80^inl
0P35Y[X01035Y;L0cZZe0<nY/P3?ZK830=N^[SH0oooo1000001R0?ooo`030000003oool0oooo01d0
oooo0P3E`lT30=O3aP80g<[700<0g/[40>7:`@3Qb/400P3SbKh00`3UbK/0ilRh0>kD^00H0?ooo`03
000f^P0RIMP0CgSK0080MX_J0P2<TmD209bId0<0ZIk<0`2dX/H0102mYl<0_JG10;fU`@35Z[h30<JY
_0050<j_^`3?[KP0cjfh0=2/]@3G/[@00P3H/K400`3I/:l0h;N^0?ooo`0_0?ooo`0304QLa01_Kl<0
Kfo300<0RWfo0P2NR;/30:jA^0030;^I]03oool0oooo00L0oooo1000000@0?ooo`00F03oool00`00
0000oooo0?ooo`0F0?ooo`80ZjgI102c[]<0102i/M40^Zo?0;Z_c`30/ld20<6ab`80a[G:0P37]<L3
0<fga@040<nf`P3C_<<0eK_00=Fk`080e[Zm0P3L`;`20=jo^@030>2n]`3Q_K<0j<Jb0080j<Jb7P3o
ool01@006jT07U?;05Ydd`1JM=<0NX;@00<0Ti3=0`2SULH20;2K`P@0^inl00@0aJJj0<FT]`35Y;L0
cZZe0P3?ZK800`3?Yk00ejj^0?ooo`0b0?ooo`@00000I`3oool00`000000oooo0?ooo`0M0?ooo`<0
el?60P3I`/<00`3Nb/@0hL[10>7:`@020>?9_P040>G9^`3Wb;P0ilRh0>W8]1T0oooo00<045OA04mh
f`1?N=/00P1aQMP01029Sm<0ViK>09^FcP2KU/h30:VLb@80]:;60`2mYL440<JY_080cjfh0P3@[;D3
0=Ra/@030=V`[`3oool0oooo0300oooo0P1_Kl<308Ym_`80WXRk0`2^TKP60?ooo`@00000503oool0
05T0oooo00<000000?ooo`3oool05@3oool30:^[e`<0/jkC0`2j[ll30<6ab`@0akC700@0b;?50<fg
a@3?]/80ckK20P3E^l030=Jj_@030=Ri^`3L`;`0g[ni0080h;jg00<0hKfc0>>l/@3S_;40803oool0
0`006jT07U?;059]c`0207Z2d0<0TXg;0P2SULH00`2`Vl80/9Vo0;2I_`030;^O_0<0aJBg0`3?ZK80
0`3?Yk00ejj^0?ooo`0^0?ooo`@00000K03oool00`000000oooo0?ooo`0M0?ooo`060=O3aP3I`/<0
fL;30=W2``3K`/40gL6m0P3SbKh20>G9^`030>O8^03Yb;@0jLRd01T0oooo00<000NC011Gd@15KmL0
0P1aQMP208V?d`<0ViK>0P2YW<T30;BO``030;fU`@2nXkh0_Z>n0080aZVl0P37YkT01@3?[KP0d:be
0=2/]@3AZk80f;6a0080fK2_=03oool308Ym_`80WXRk1@3oool4000001P0oooo001J0?ooo`800000
5`3oool20:^[e`<0/jcA0`2k[/`00`31/L/0`[380<:`b0020<Nda`80b;?50`3?]/80103@]Kl0e[Zm
0=Jj_@3F^[d20=Ri^`80g[ni00<0h;jg0>6m/`3Q_K<00P3S_;4P0?ooo`040008V@0@Al@0DVg?059]
c`80Mgg=0P2BSL/20:>EaP<0/9Vo0P2kWk`20;bM^P80aJBg00@0aZ:d0<nY/P3?Yk00cjN`;03oool4
00000740oooo0P00000M0?ooo`<0fL;300@0fl;10=g1_@3M`Kd0g/6k0P3UbK/20>O8^0030>W8]03o
ool0oooo01T0oooo00@004O704E_e`15KmL0JgoE0P29Sm<309^FcP<0Z9[70P2dWl<40;jS_P<0ajNi
0P3@[;D20=6[/P030=Ra/@3I/:l0fK2_03X0oooo1000000L0?ooo`00G03oool00`000000oooo0?oo
o`0E0?ooo`80ZjWE0`2dZ/l20;^^c0@0`[380P38/lD20<Za`P040<nf`P3@]Kl0d;Fo0=6d_@80e[Zm
0P3H^K/0103I^;P0h;jg0>2n]`3Q_K<30>>l/B40oooo00<044O4059]c`1BKLl00`1gOLd20929b080
XY;30P2`VKl40;bM^P040<FT]`36X[@0aZ:d0<nY/P80cjN`:@3oool3000007L0oooo00<000000?oo
o`3oool0703oool20=_2`@030=g1_@3N`K/0g/6k0080h<2h00<0h[ne0>W8]03Yb;@0703oool01000
AlL0>VGB06]oe@1[OmD208J;d0<0VY?;0P2XV/L30;BM`@80_Z>n0P2oXK/20<NW^@040<RV]P3@[;D0
dJ^b0=6[/P80fK2_=`3oool400000200oooo001M0?ooo`030000003oool0oooo01@0oooo0`2[Ym82
0;BZc`@0_:c:0`33[lH30<Za`P80d;Fo0`3A];d20=Ri^`80fKRh00<0f[Ne0>6m/`3Q_K<00P3S_;4R
0?ooo`030000R00@Al@0BfG;00<0Mgg=0P2@RLP20::B``030;2I_`2`Ukd0/9Nm00<0_9fj0`36X[@2
0<nW/2H0oooo1000001k0?ooo`030000003oool0oooo01`0oooo0P3M`Kd01P3N`K/0h<2h0>30^03P
`;P0h[ne0>>n/Qd0oooo00@003Jl03YUdP0jIM80IGWB0`26Rm0209ZCb`<0Z9O40P2dWL401@2nXkh0
_j6k0;nQ^`2oXK/0ajNi0080b:Jf0`3AZk800`3AZJl0fK2_0?ooo`0c0?ooo`<00000903oool005h0
oooo00<000000?ooo`3oool0503oool20:^WdP<0]:S=0P2l[<X20;b[a`040<>_aP34[L<0a:g30<Za
`P80bk2o103A];d00`3B/kX0fKRh0=Vh^0020=Zg]@040=^f/P3S_;40hkba0>>l/B<0oooo00<00CVl
04]Ub`1;IL/00P1cN<T20929b080XY;3102`Ukd00`2lWKX0_9bg0;bL]`020<JR]0030<JQ/P3?Yk00
oooo0240oooo100000200?ooo`030000003oool0oooo01`0oooo0P3N`K/20>30^080h[ne00<0hkjb
0?ooo`3oool0703oool01000=[`0>VGB06EidP1UNM8208>6cP<0VI390P2XUl@20;BM`@@0_j6k0`38
Y[H01039Y;@0dJ^b0=6Y[`3AZJla0?ooo`@000009`3oool005l0oooo0P00000D0?ooo`<0ZjC@0P2d
Z<d40;b[a`<0a:g30`3;/;l00`3<[kd0dKBm0=6d_@020=:c^P030=Bb]`3I^;P0f[Ne0080fkJb0P3M
]K0U0?ooo`03004i_013G<L0BfG;0080LgS90P2>QLD20::?`@<0/9Nm0`2lW;L00`36X[@0aZ6b0<JQ
/P0O0?ooo`@00000Q@3oool2000001d0oooo0`3P`;P00`3R_kD0hkjb0>>n/P0N0?ooo`03000S[`0^
F/d0IGWB0080IGWB0P23Q/h209V@b@80Z9O40`2dVkh20;nQ^`80_inh00@0b:Jf0<VT]039Y;@0dJ^b
0P3AZJl]0?ooo`@00000:`3oool00640oooo00<000000?ooo`3oool04P3oool20:^Td0<0]JK:0P2l
ZlL20;fYa@040<B]``35[<40aJc10<^`_`<0c:nm0P3B/kX20=Bb]`80f[Ne0P3K][820=fe/2D0oooo
00<002^b04=La`13G<L00P1cN<T208j5a@80XXo10P2`Ukd20;2D^P80_9bg0`36XK8K0?ooo`@00000
R`3oool00`000000oooo0?ooo`0L0?ooo`80h[ne00<0hkjb0?ooo`3oool07P3oool010003j008Do7
05mbc`1OL/l208>6cP80VI390`2XU<820;BK_P@0_inh00<0b:Jf0<VT]039Y;@00`3AZJlY0?ooo`@0
0000;`3oool00680oooo00<000000?ooo`3oool04@3oool30:^RcP<0]JK:0`2mZLD30<F/`@<0c:nm
0P3=[[X0103B/kX0e;:g0=Bb]`3E/KD20=^f/P80gKF`9`3oool304=La`0306mcaP2>QLD0SXG50080
XXo1102`U;X0102lW;L0_9Zd0;bJ]036XK8I0?ooo`<00000T03oool00`000000oooo0?ooo`0L0?oo
o`80hkjb803oool2000?X003025?a`1OL/l0Gg;?0080PH;;0P2GS<H20:RD`P030;BK_P2eVK/0]IVk
00<0_inh0`39Y;@00`39Xk40dJV_0?ooo`0U0?ooo`@00000<`3oool006<0oooo00<000000?ooo`3o
ool04@3oool30:^RcP<0]JC800@0_JW50;jW`P2nYl80aJc10P36Z[h0103<[kd0cJjj0<f^^P3=[[X2
0=Bb]`80eK6e00@0eZnb0=^f/P3M]K00gKF`:03oool0100kE<80@ec706mcaP1_LlH208f2`P80XHbn
0`2`U;X30;bJ]0030<JQ/P3oool0oooo01<0oooo1000002D0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool07`3oool2000?X004025?a`1IJl/0PH;;0862b`80Uhc60P2XU<840;FI^`04
0;nO^02oW[H0_ijf0<VT]080bJ>a00<0dJV_0?ooo`3oool0803oool4000003L0oooo001T0?ooo`80
00004P3oool30:^Pc080]JC80`2nYl830<JZ_P@0cJjj00D0cZbh0=Bb]`3E/KD0eK6e0=J_/P020=fe
/2X0oooo00<0>eC206mcaP1_LlH00P2=P/830:6<_P030;2D^P2`T[P0/9:h0080_9Zd4P3oool40000
09T0oooo0P00000L0?ooo`030000003oool0oooo0200oooo00D000nP01=2_`1IJl/0FF_;07imb002
09N<aP<0Yi:o0`2eVK/30;nN]P030<VT]039Xk40bJ>a0200oooo0`00000k0?ooo`00IP3oool00`00
0000oooo0?ooo`0@0?ooo`80Zj3<0`2eX/D0102nYl80_ZG00;jU`036Z[h20<JX^`80cJjj0P3>[;P2
0=Fa]@80eZnb00<0ejj`0=fe/03oool0:@3oool203]D`P0306a^``2=P/80SH;200<0XHbn0`2`T[P2
0;bJ]0h0oooo1000002O0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08@3oool0
0`0C@[l0FF_;05U[b`0207imb080UXW30P2WT[l20;FI^`80]INi0P2oW[H30<VS/A`0oooo1000000n
0?ooo`00I`3oool00`000000oooo0?ooo`0?0?ooo`<0Zig90P2eX/D30;jU`0@0aZRk0`3>[;P01@3?
ZkD0eK6e0=J_/P3F[k80ejj`02`0oooo00@0>eC206a^``1/K/<0Rgjo102PRK/20;2B^0030;bJ]03o
ool0oooo00T0oooo1000002T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool08P3o
ool0100C@[l0DVC707imb01nOLP209J9``80Yi:o102eUkT0102oW[H0`9bc0<2L/`39Xk4I0?ooo`@0
0000@P3oool006P0oooo00<000000?ooo`3oool03`3oool20:^Mb@040;FRa@2fX<<0]Z330;jU`080
_j>m0P36Z;/20<NW^@030<j/^03?ZkD0cj^e0080eZnb0P3G[[0]0?ooo`80K6k30P2;O[l30:29^`80
/9:h2@3oool300000:T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0R0?ooo`04
00Hf]`1BI<L0DVC707]ha@80UXW30`2WSk`30;FG^@<0`9bc00<0bJ>a0?ooo`3oool04`3oool40000
04H0oooo001Y0?ooo`8000003`3oool20:^Mb@<0]Z330`2oXkd01036Z;/0ajNi0<NW^@37YkT30<n[
]@040<nY/P3F[k80ejj`0=N^/2h0oooo00@0K6k308]n_`2;O[l0Rgjo0P2PRK/70?ooo`@00000[@3o
ool2000001L0oooo00<000000?ooo`3oool08`3oool01006=[L0DVC707]ha@1kN<D209F6`@<0Yhnl
00<0]INi0;FE]P2eUKH00P30W;<B0?ooo`@00000BP3oool006/0oooo00<000000?ooo`3oool03@3o
ool20:^KaP030;JP``2fW/00]Yk00080_j>m1037YkT01038YKH0cj^e0<nY/P3?ZK820=N^/300oooo
0`2;O[l50?ooo`@00000/`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02@0oooo
00<0C5c207]ha@1kN<D00P2EQ/430:N?_0<0]IFf0P30W;<>0?ooo`@00000CP3oool006`0oooo00<0
00000?ooo`3oool0303oool20:^KaP<0]Yk000<0_j>m0;nR^`2oX[/00P37YkT20<RU]P<0cjVb00<0
d:R`0=N^/03oool0<`3oool400000;P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0T0?ooo`80C5c200<0N7?209F6`@2EQ/40102WSKX20;FE]P030<2L/`3oool0oooo00X0oooo0`00
001B0?ooo`00K@3oool00`000000oooo0?ooo`0;0?ooo`<0ZYS40P2fW/040;nR^`<0b:Ff00@0b:Bd
0<nY/P3@Z;00d:R`<@3oool400000;d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0U0?ooo`0304aL`P1hLl80N7?20080Th:n0`2WSKX20;FE]PT0oooo1000001E0?ooo`00KP3oool2
000000`0oooo0P2ZV<@30;JL_@80_j:k0P30X;P01038YKH0b:Bd0<RT]03?ZK820=2X/2h0oooo0`00
00320?ooo`8000004P3oool00`000000oooo0?ooo`0V0?ooo`80N7?20P2CP[h30:N=^P030;FE]P3o
ool0oooo00@0oooo1000001I0?ooo`00L03oool00`000000oooo0?ooo`090?ooo`<0ZYK10`2fW;d3
0<2P^0030<RU]P38Y;@0b:Bd0080d:R`:`3oool400000<L0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0V0?ooo`80N7?20`2CP[h20:N=^P<0oooo1000001M0?ooo`00L@3oool00`00
0000oooo0?ooo`090?ooo`80ZYK10P2fW;d20;JJ^`80`:2h0`38Y;@00`39X[40d:R`0?ooo`0V0?oo
o`@00000c03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02P0oooo0`2CP[h00`3o
ool000000000000200000640oooo001b0?ooo`030000003oool0oooo00P0oooo0P2ZU/440;JJ^`04
0<2P^030W[H0`9jf0<RT]080bJ:a903oool400000=40oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0Y0?ooo`<00000I@3oool007<0oooo00<000000?ooo`3oool01`3oool30:ZC_P<0
]YZk0`30W[H30<VR/B00oooo1000003F0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool09P3oool4000006P0oooo001d0?ooo`800000203oool30:ZC_P030;JJ^`2fV;P0]YRh0080`9jf
00<0`Ibc0<VR/@3oool07@3oool300000=/0oooo0P00000;0?ooo`030000003oool0oooo0280oooo
1000001/0?ooo`00MP3oool00`000000oooo0?ooo`060?ooo`80ZY>n0`2fV;P01030W[H0`Ibc0<6L
/`39X[4J0?ooo`@00000h03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo
1000001`0?ooo`00M`3oool00`000000oooo0?ooo`050?ooo`<0ZI2l0P2fV;P30<6L/aL0oooo1000
003U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4000007@0oooo001h
0?ooo`030000003oool0oooo00D0oooo0P2YT;`00`2fV;P0]iJf0;NF]P020<6L/a<0oooo1000003Z
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool4000007P0oooo001i0?oo
o`8000001@3oool20:V@_0<0]iJf00<0`Ibc0?ooo`3oool03P3oool400000>l0oooo0P0000060?oo
o`030000003oool0oooo01<0oooo0`00001l0?ooo`00N`3oool00`000000oooo0?ooo`020?ooo`<0
ZHji0P2gU[H>0?ooo`<00000m@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0
oooo1000001o0?ooo`00O03oool00`000000oooo0?ooo`020?ooo`80ZHji00<0]iJf0?ooo`3oool0
2@3oool400000?T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000
P`3oool007d0oooo00@000000?ooo`3oool0oooo0P2YS[T80?ooo`@00000oP3oool01@000000oooo
0?ooo`3oool0000000T0oooo100000270?ooo`00OP3oool2000000030?ooo`000000oooo00@0oooo
1000003o0?ooo`@0oooo0P0000000`3oool000000?ooo`040?ooo`@00000R`3oool00800oooo0P00
00000`3oool000000000000200000?l0oooo2P3oool2000000030?ooo`000000000000800000S`3o
ool00840oooo0P00003o0?ooo`l0oooo0P00002C0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0
oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool0
0?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3o
oolX0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 549.188}, {211.438, 0}} -> {-0.0534453, -0.0193168, \
0.00383638, 0.00383638}, {{13.875, 262.125}, {206.375, 5}} -> {-0.179383, \
-0.0329608, 0.00431846, 0.00431846}, {{287, 535.25}, {206.375, 5}} -> \
{-1.34405, -0.0298931, 0.0042908, 0.0042908}}]
}, Closed]],

Cell[CellGroupData[{

Cell["The best known properties and formulas for cosine function", \
"Subsection"],

Cell[CellGroupData[{

Cell["Values in points", "Subsubsection"],

Cell["\<\
Students usually learn the following basic table of values of the \
cosine function for special points of the circle:\
\>", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"cos", "(", "0", ")"}], "\[Equal]", "1"}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox["\[Pi]", "6"], ")"}], "\[Equal]", 
              FractionBox[
                SqrtBox["3"], "2"]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox["\[Pi]", "4"], ")"}], "\[Equal]", 
              FractionBox["1", 
                SqrtBox["2"]]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox["\[Pi]", "3"], ")"}], "\[Equal]", 
              FractionBox["1", "2"]}]},
          {
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox["\[Pi]", "2"], ")"}], "\[Equal]", "0"}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox[
                  RowBox[{"2", " ", "\[Pi]"}], "3"], ")"}], "\[Equal]", 
              RowBox[{"-", 
                FractionBox["1", "2"]}]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox[
                  RowBox[{"3", " ", "\[Pi]"}], "4"], ")"}], "\[Equal]", 
              RowBox[{"-", 
                FractionBox["1", 
                  SqrtBox["2"]]}]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox[
                  RowBox[{"5", " ", "\[Pi]"}], "6"], ")"}], "\[Equal]", 
              RowBox[{"-", 
                FractionBox[
                  SqrtBox["3"], "2"]}]}]},
          {
            RowBox[{
              RowBox[{"cos", "(", "\[Pi]", ")"}], "\[Equal]", 
              RowBox[{"-", "1"}]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox[
                  RowBox[{"7", " ", "\[Pi]"}], "6"], ")"}], "\[Equal]", 
              RowBox[{"-", 
                FractionBox[
                  SqrtBox["3"], "2"]}]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox[
                  RowBox[{"5", " ", "\[Pi]"}], "4"], ")"}], "\[Equal]", 
              RowBox[{"-", 
                FractionBox["1", 
                  SqrtBox["2"]]}]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox[
                  RowBox[{"4", " ", "\[Pi]"}], "3"], ")"}], "\[Equal]", 
              RowBox[{"-", 
                FractionBox["1", "2"]}]}]},
          {
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox[
                  RowBox[{"3", " ", "\[Pi]"}], "2"], ")"}], "\[Equal]", "0"}],
             
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox[
                  RowBox[{"5", " ", "\[Pi]"}], "3"], ")"}], "\[Equal]", 
              FractionBox["1", "2"]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox[
                  RowBox[{"7", " ", "\[Pi]"}], "4"], ")"}], "\[Equal]", 
              FractionBox["1", 
                SqrtBox["2"]]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox[
                  RowBox[{"11", " ", "\[Pi]"}], "6"], ")"}], "\[Equal]", 
              FractionBox[
                SqrtBox["3"], "2"]}]}
          }], TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{GridBox[{
            {
              RowBox[{
                RowBox[{"cos", "(", 
                  RowBox[{"2", " ", "\[Pi]"}], ")"}], "\[Equal]", "1"}], 
              RowBox[{
                RowBox[{
                  RowBox[{"cos", "(", 
                    RowBox[{"\[Pi]", " ", "m"}], ")"}], "\[Equal]", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], "m"]}], "/;", 
                RowBox[{"m", "\[Element]", 
                  TagBox["\[DoubleStruckCapitalZ]",
                    (Integers&)]}]}], 
              RowBox[{
                RowBox[{
                  RowBox[{"cos", "(", 
                    RowBox[{"\[Pi]", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          FractionBox["1", "2"], "+", "m"}], ")"}]}], ")"}], 
                  "\[Equal]", "0"}], "/;", 
                RowBox[{"m", "\[Element]", 
                  TagBox["\[DoubleStruckCapitalZ]",
                    (Integers&)]}]}]}
            }], "."}], TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["General characteristics", "Subsubsection"],

Cell[TextData[{
  "For real values of argument ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ", the values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " are real. "
}], "Text"],

Cell[TextData[{
  "In the points ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "=", 
          RowBox[{
            RowBox[{"2", "\[Pi]", " ", 
              RowBox[{"n", "/", "m"}]}], "/;", 
            RowBox[{
              RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalZ]"}], 
              "\[And]", 
              RowBox[{"m", "\[Element]", "\[DoubleStruckCapitalZ]"}]}]}]}], 
        TraditionalForm]]],
  ", the values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " are algebraic. In several cases they can even be rational number",
  "s, 0 or 1",
  ". Here are some examples:"
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"cos", "(", "0", ")"}], "\[Equal]", "1"}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox["\[Pi]", "3"], ")"}], "\[Equal]", 
              FractionBox["1", "2"]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                FractionBox["\[Pi]", "2"], ")"}], "\[Equal]", "0."}]}
          }], TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", 
          FractionBox[
            RowBox[{"n", " ", "\[Pi]"}], "m"], ")"}], TraditionalForm]]],
  " can be expressed using only square roots if ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalZ]"}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox["m", TraditionalForm]]],
  " is a product of a power of 2 and distinct Fermat primes {3, 5, 17, 257, \
\[Ellipsis]}. "
}], "Text"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " is an entire analytical function of ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  " that is defined over the whole complex ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "\[Hyphen]plane and does not have branch cuts and branch points. It has an \
essential singular point at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", " ", "=", " ", 
          OverscriptBox["\[Infinity]", "~"]}], TraditionalForm]]],
  ". It is a periodic function with the real period ",
  Cell[BoxData[
      FormBox[
        RowBox[{"2", "\[Pi]"}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", 
          RowBox[{"(", 
            RowBox[{"z", "+", 
              RowBox[{"2", " ", "\[Pi]"}]}], ")"}]}], "\[Equal]", 
        RowBox[{"cos", "(", "z", ")"}], " "}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{GridBox[{
            {
              RowBox[{
                RowBox[{
                  RowBox[{"cos", 
                    RowBox[{"(", "z", ")"}]}], "\[Equal]", 
                  RowBox[{"cos", "(", 
                    RowBox[{"z", "+", 
                      RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], ")"}]}], "/;", 
                
                RowBox[{"k", "\[Element]", 
                  TagBox["\[DoubleStruckCapitalZ]",
                    (Integers&)]}]}], 
              RowBox[{" ", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cos", 
                      RowBox[{"(", "z", ")"}]}], "\[Equal]", " ", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"-", "1"}], ")"}], "k"], 
                      RowBox[{"cos", "(", 
                        RowBox[{"z", "+", 
                          RowBox[{"\[Pi]", " ", "k"}]}], ")"}]}]}], "/;", 
                  RowBox[{"k", "\[Element]", 
                    TagBox["\[DoubleStruckCapitalZ]",
                      (Integers&)]}]}]}]}
            }], "."}], TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " is an even function with mirror symmetry:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{GridBox[{
            {
              RowBox[{
                RowBox[{"cos", "(", 
                  RowBox[{"-", "z"}], ")"}], "\[Equal]", 
                RowBox[{"cos", "(", "z", ")"}]}], 
              RowBox[{
                RowBox[{"cos", "(", 
                  OverscriptBox["z", "_"], ")"}], "\[Equal]", 
                OverscriptBox[
                  RowBox[{"cos", "(", "z", ")"}], "_"]}]}
            }], "."}], TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Differentiation", "Subsubsection"],

Cell[TextData[{
  "The derivatives of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " have simple representations ",
  "though the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"sin", "(", "z", ")"}], TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{GridBox[{
            {
              RowBox[{
                FractionBox[
                  RowBox[{"\[PartialD]", 
                    RowBox[{"cos", "(", "z", ")"}]}], 
                  RowBox[{"\[PartialD]", "z"}],
                  MultilineFunction->None], "\[Equal]", 
                RowBox[{"-", 
                  RowBox[{"sin", "(", "z", ")"}]}]}], 
              RowBox[{
                RowBox[{
                  FractionBox[
                    RowBox[{
                      SuperscriptBox["\[PartialD]", "n"], 
                      RowBox[{"cos", "(", "z", ")"}]}], 
                    RowBox[{"\[PartialD]", 
                      SuperscriptBox["z", "n"]}],
                    MultilineFunction->None], "\[Equal]", 
                  RowBox[{"cos", "(", 
                    RowBox[{"z", "+", 
                      FractionBox[
                        RowBox[{"\[Pi]", " ", "n"}], "2"]}], ")"}]}], "/;", 
                RowBox[{"n", "\[Element]", 
                  SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}]}
            }], "."}], TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Ordinary differential equation", "Subsubsection"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " satisfies the simples",
  "t possible linear differential equation with constant coefficients:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["w", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "z", ")"}], "+", 
            RowBox[{"w", "(", "z", ")"}]}], "\[Equal]", "0"}], "/;", 
        RowBox[{
          RowBox[{
            RowBox[{"w", "(", "z", ")"}], "\[Equal]", 
            RowBox[{"cos", "(", "z", ")"}]}], "\[And]", 
          RowBox[{
            RowBox[{"w", "(", "0", ")"}], "\[Equal]", "1"}], "\[And]", 
          RowBox[{
            RowBox[{
              SuperscriptBox["w", "\[Prime]",
                MultilineFunction->None], "(", "0", ")"}], "\[Equal]", 
            "0."}]}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The complete solution of this equation can be represented as a linear \
combination of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"sin", "(", "z", ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " with arbitrary constant coefficients ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "1"], TraditionalForm]]],
  "and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "2"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["w", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "z", ")"}], "+", 
            RowBox[{"w", "(", "z", ")"}]}], "\[Equal]", "0"}], "/;", 
        RowBox[{
          RowBox[{"w", "(", "z", ")"}], "\[Equal]", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["c", "1"], 
              RowBox[{"cos", "(", "z", ")"}]}], "+", " ", 
            RowBox[{
              SubscriptBox["c", "2"], 
              RowBox[{
                RowBox[{"sin", "(", "z", ")"}], "."}]}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " also satisfies nonlinear differential equations of the first order:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["w", "\[Prime]",
                MultilineFunction->None], "(", "z", ")"}], "-", 
            SqrtBox[
              RowBox[{"1", "-", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"w", "(", "z", ")"}], ")"}], "2"]}]]}], 
          "\[Equal]", "0"}], "/;", 
        RowBox[{
          RowBox[{
            RowBox[{"w", "(", "z", ")"}], "\[Equal]", 
            RowBox[{"cos", "(", "z", ")"}]}], "\[And]", 
          RowBox[{
            RowBox[{"w", "(", "0", ")"}], "\[Equal]", "1"}], "\[And]", 
          RowBox[{
            RowBox[{"Re", "(", "z", ")"}], "<", 
            RowBox[{
              FractionBox["\[Pi]", "2"], "."}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Series representation", "Subsubsection"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " has a simple series expansio",
  "n at the origin that converges in the whole complex ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "\[Hyphen]plane:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{"1", "-", 
          FractionBox[
            SuperscriptBox["z", "2"], "2"], "+", 
          FractionBox[
            SuperscriptBox["z", "4"], "24"], "-", "\[Ellipsis]"}], "\[Equal]",
         
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "\[Infinity]"], 
          RowBox[{
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "k"], " ", 
                SuperscriptBox["z", 
                  RowBox[{"2", " ", "k"}]]}], 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"2", " ", "k"}], ")"}], "!"}]], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "For real ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "\[Equal]", "x"}], TraditionalForm]]],
  "this series can be interpreted as the real part of the series expansion \
for the exponential function ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "x"}]], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{"1", "-", 
          FractionBox[
            SuperscriptBox["z", "2"], "2"], "+", 
          FractionBox[
            SuperscriptBox["z", "4"], "24"], "-", "\[Ellipsis]"}], "\[Equal]",
         
        RowBox[{"Re", "(", 
          RowBox[{"1", "+", 
            RowBox[{"\[ImaginaryI]", " ", "x"}], "+", 
            FractionBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"\[ImaginaryI]", " ", "x"}], ")"}], "2"], 
              RowBox[{"2", "!"}]], "+", 
            FractionBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"\[ImaginaryI]", " ", "x"}], ")"}], "3"], 
              RowBox[{"3", "!"}]], "+", "\[Ellipsis]"}], ")"}], "\[Equal]", 
        RowBox[{"Re", "(", 
          RowBox[{
            UnderoverscriptBox["\[Sum]", 
              RowBox[{"k", "=", "0"}], "\[Infinity]"], 
            FractionBox[
              RowBox[{" ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"\[ImaginaryI]", " ", "x"}], ")"}], "k"]}], 
              RowBox[{"k", "!"}]]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{"Re", "(", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", "x"}]], ")"}], "."}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Product representation", "Subsubsection"],

Cell[TextData[{
  "The following famous infinite product representation for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " clearly illustrates that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"cos", "(", "z", ")"}], "\[Equal]", "0", " "}], 
        TraditionalForm]]],
  "at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"z", "\[Equal]", 
            RowBox[{
              RowBox[{"\[Pi]", " ", "k"}], "-", 
              FractionBox["\[Pi]", "2"]}]}], "\[And]", 
          RowBox[{"k", "\[Element]", "\[DoubleStruckCapitalZ]"}]}], 
        TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{
          UnderoverscriptBox["\[Product]", 
            RowBox[{"k", "=", "1"}], "\[Infinity]"], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "-", 
                FractionBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox["z", "2"]}], 
                  RowBox[{
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"2", " ", "k"}], "-", "1"}], ")"}], 
                      "2"]}]]}], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Indefinite integration", "Subsubsection"],

Cell["\<\
Indefinite integrals of expressions involving the cosine function \
can sometimes be expressed using elementary functions. However, frequently \
special functions are needed to express the results even when the integrands \
have a simple form (if they can be evaluated in closed form). Here are some \
examples:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Integral]", 
          RowBox[{
            RowBox[{"cos", "(", "z", ")"}], 
            RowBox[{"\[DifferentialD]", "z"}]}]}], "\[Equal]", 
        RowBox[{"sin", "(", "z", ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Integral]", 
          RowBox[{
            SqrtBox[
              RowBox[{"cos", "(", "z", ")"}]], 
            RowBox[{"\[DifferentialD]", "z"}]}]}], "\[Equal]", 
        RowBox[{"2", " ", 
          RowBox[{"E", "(", 
            RowBox[{
              FractionBox["z", "2"], "\[VerticalSeparator]", "2"}], ")"}]}]}],
       TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[Integral]", 
            RowBox[{
              SuperscriptBox["z", 
                RowBox[{"\[Alpha]", "-", "1"}]], " ", 
              RowBox[{
                SuperscriptBox["cos", "v"], "(", 
                RowBox[{"a", " ", "z"}], ")"}], 
              RowBox[{"\[DifferentialD]", "z"}]}]}], "\[Equal]", 
          RowBox[{
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox["2", 
                    RowBox[{"-", "v"}]], " ", 
                  RowBox[{"(", 
                    RowBox[{"1", "-", 
                      InterpretationBox[
                        RowBox[{"v", " ", "mod", " ", "2"}],
                        Mod[ v, 2]]}], ")"}]}], "\[Alpha]"], 
              SuperscriptBox["z", "\[Alpha]"], " ", 
              TagBox[
                RowBox[{"(", GridBox[{
                      {
                        TagBox["v",
                          Identity,
                          Editable->True]},
                      {
                        TagBox[
                          FractionBox["v", "2"],
                          Identity,
                          Editable->True]}
                      }], ")"}],
                InterpretTemplate[ Binomial[ #, #2]&],
                Editable->False]}], "-", 
            RowBox[{
              SuperscriptBox["2", 
                RowBox[{"-", "v"}]], " ", 
              SuperscriptBox["z", "\[Alpha]"], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"j", "=", "0"}], 
                  RowBox[{"\[LeftFloor]", 
                    FractionBox[
                      RowBox[{"v", "-", "1"}], "2"], "\[RightFloor]"}]], 
                RowBox[{
                  TagBox[
                    RowBox[{"(", GridBox[{
                          {
                            TagBox["v",
                              Identity,
                              Editable->True]},
                          {
                            TagBox["j",
                              Identity,
                              Editable->True]}
                          }], ")"}],
                    InterpretTemplate[ Binomial[ #, #2]&],
                    Editable->False], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"\[CapitalGamma]", "(", 
                          RowBox[{"\[Alpha]", ",", 
                            RowBox[{"\[ImaginaryI]", " ", "a", " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{"2", " ", "j"}], "-", "v"}], ")"}], 
                              " ", "z"}]}], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"\[ImaginaryI]", " ", "a", " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{"2", " ", "j"}], "-", "v"}], ")"}], 
                              " ", "z"}], ")"}], 
                          RowBox[{"-", "\[Alpha]"}]]}], "+", " ", 
                      RowBox[{
                        RowBox[{"\[CapitalGamma]", "(", 
                          RowBox[{"\[Alpha]", ",", 
                            RowBox[{"\[ImaginaryI]", " ", "a", " ", 
                              RowBox[{"(", 
                                RowBox[{"v", "-", 
                                  RowBox[{"2", " ", "j"}]}], ")"}], " ", 
                              "z"}]}], ")"}], 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"\[ImaginaryI]", " ", "a", " ", 
                              RowBox[{"(", 
                                RowBox[{"v", "-", 
                                  RowBox[{"2", " ", "j"}]}], ")"}], " ", 
                              "z"}], ")"}], 
                          RowBox[{"-", "\[Alpha]"}]]}]}], ")"}]}]}]}]}]}], "/;",
         
        RowBox[{
          RowBox[{"\[Alpha]", "\[NotEqual]", "0"}], "\[And]", 
          RowBox[{"v", "\[Element]", 
            RowBox[{
              SuperscriptBox["\[DoubleStruckCapitalN]", "+"], "."}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The last integral cannot be evaluated in closed form using the known \
classical special functions for arbitrary values of parameters ",
  Cell[BoxData[
      FormBox["\[Alpha]", TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox["v", TraditionalForm]]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definite integration", "Subsubsection"],

Cell["\<\
Definite integrals including the cosine function are sometimes \
simple. For example, the famous Dirichlet type and Fresnel integrals have the \
following values:\
\>", "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
          RowBox[{
            FractionBox[
              RowBox[{
                RowBox[{"cos", 
                  RowBox[{"(", "t", ")"}]}], "-", "1"}], "t"], 
            RowBox[{"\[DifferentialD]", "t"}]}]}], "\[Equal]", 
        RowBox[{"-", 
          TagBox["\[DoubledGamma]",
            (EulerGamma&)]}]}], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{
              RowBox[{"cos", "(", 
                SuperscriptBox["t", "2"], ")"}], 
              RowBox[{"\[DifferentialD]", "t"}]}]}], "\[Equal]", 
          RowBox[{
            FractionBox["1", "2"], 
            SqrtBox[
              FractionBox["\[Pi]", "2"]]}]}], ","}], 
      TraditionalForm]}], "TraditionalFormEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox["\[DoubledGamma]", TraditionalForm]]],
  " is the Euler",
  "\[Hyphen]",
  "Mascheroni constant ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[DoubledGamma]", "\[Equal]", 
          RowBox[{"0.577216", "\[Ellipsis]"}]}], TraditionalForm]]]
}], "Text"],

Cell["\<\
Some special functions can be used to evaluate more complicated \
definite integrals. For example, to express the following integrals, elliptic \
integrals and gamma functions are needed:\
\>", "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
          RowBox[{
            RowBox[{
              SuperscriptBox["cos", 
                FractionBox["1", "2"]], "(", "z", ")"}], 
            RowBox[{"\[DifferentialD]", "z"}]}]}], "\[Equal]", 
        RowBox[{"2", " ", 
          RowBox[{"E", "(", "2", ")"}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
            RowBox[{
              SuperscriptBox["z", 
                RowBox[{"\[Alpha]", "-", "1"}]], 
              RowBox[{"cos", "(", "z", ")"}], 
              RowBox[{"\[DifferentialD]", "z"}]}]}], "\[Equal]", 
          RowBox[{
            RowBox[{"cos", "(", 
              FractionBox[
                RowBox[{"\[Pi]", " ", "\[Alpha]"}], "2"], ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", "\[Alpha]", ")"}]}]}], "/;", 
        RowBox[{"0", "<", 
          RowBox[{"Re", "(", "\[Alpha]", ")"}], "<", "1."}]}], 
      TraditionalForm]}], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integral transforms", "Subsubsection"],

Cell[TextData[{
  "Integral transforms of expressions involving the cosine function may not \
be classically convergent but can be interpreted in a generalized functions \
(distributions) sense. For example, the exponential Fourier transform of the \
cosine function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " does not exist in the classical sense but can be expressed using the \
Dirac delta function."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubscriptBox["\[ScriptCapitalF]", "t"], "[", 
            RowBox[{"cos", "(", "t", ")"}], "]"}], 
          RowBox[{"(", "z", ")"}]}], "\[Equal]", " ", 
        RowBox[{
          RowBox[{
            SqrtBox[
              FractionBox["\[Pi]", "2"]], " ", 
            RowBox[{"\[Delta]", "(", 
              RowBox[{"z", "-", "1"}], ")"}]}], "+", " ", 
          RowBox[{
            SqrtBox[
              FractionBox["\[Pi]", "2"]], " ", 
            RowBox[{
              RowBox[{"\[Delta]", "(", 
                RowBox[{"z", "+", "1"}], ")"}], "."}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell["\<\
Among other integral transforms of the cosine function, the best \
known are the Fourier cosine and sine transforms, the Laplace, the Mellin, \
the Hilbert, and the Hankel transforms:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox["\[ScriptCapitalF]\[ScriptC]", "t"], "[", 
              RowBox[{"cos", "(", 
                RowBox[{"a", " ", "t"}], ")"}], "]"}], 
            RowBox[{"(", "z", ")"}]}], "\[Equal]", 
          RowBox[{
            SqrtBox[
              FractionBox["\[Pi]", "2"]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  InterpretationBox["\[Delta]",
                    DiracDelta,
                    Editable->False,
                    Selectable->False], "(", 
                  RowBox[{"a", "-", "z"}], ")"}], "+", 
                RowBox[{
                  InterpretationBox["\[Delta]",
                    DiracDelta,
                    Editable->False,
                    Selectable->False], "(", 
                  RowBox[{"a", "+", "z"}], ")"}]}], ")"}]}]}], "/;", 
        RowBox[{"a", "\[Element]", 
          TagBox["\[DoubleStruckCapitalR]",
            (Reals&)]}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox["\[ScriptCapitalF]\[ScriptS]", "t"], "[", 
              RowBox[{"cos", "(", 
                RowBox[{"a", " ", "t"}], ")"}], "]"}], 
            RowBox[{"(", "z", ")"}]}], "\[Equal]", 
          RowBox[{
            RowBox[{"-", 
              SqrtBox[
                FractionBox["2", "\[Pi]"]]}], 
            FractionBox[
              RowBox[{" ", "z"}], 
              RowBox[{
                SuperscriptBox["a", "2"], "-", 
                SuperscriptBox["z", "2"]}]]}]}], "/;", 
        RowBox[{"a", "\[Element]", 
          TagBox["\[DoubleStruckCapitalR]",
            (Reals&)]}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubscriptBox["\[ScriptCapitalL]", "t"], "[", 
            RowBox[{"cos", "(", "t", ")"}], "]"}], 
          RowBox[{"(", "z", ")"}]}], "\[Equal]", 
        FractionBox["z", 
          RowBox[{"1", "+", 
            SuperscriptBox["z", "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox["\[ScriptCapitalM]", "t"], "[", 
              RowBox[{"cos", "(", "t", ")"}], "]"}], 
            RowBox[{"(", "z", ")"}]}], "\[Equal]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "z", ")"}], " ", 
            RowBox[{"cos", "(", 
              FractionBox[
                RowBox[{"\[Pi]", " ", "z"}], "2"], ")"}]}]}], "/;", 
        RowBox[{"0", "<", 
          RowBox[{"Re", "(", "z", ")"}], "<", "1"}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubscriptBox["\[ScriptCapitalH]", "t"], "[", 
            RowBox[{"cos", "(", "t", ")"}], "]"}], 
          RowBox[{"(", "x", ")"}]}], "\[Equal]", 
        RowBox[{"-", 
          RowBox[{"sin", "(", "x", ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox["\[ScriptCapitalH]", 
                RowBox[{"t", ";", "\[Nu]"}]], "[", 
              RowBox[{
                SuperscriptBox["t", 
                  RowBox[{"\[Alpha]", "-", "1"}]], " ", 
                RowBox[{"cos", "(", "t", ")"}]}], "]"}], 
            RowBox[{"(", "z", ")"}]}], "\[Equal]", 
          RowBox[{
            FractionBox["1", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"\[Nu]", "+", "1"}], ")"}]], 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["2", 
                  RowBox[{"-", "\[Nu]"}]], " ", 
                SuperscriptBox["z", 
                  RowBox[{"\[Nu]", "+", 
                    FractionBox["1", "2"]}]], " ", 
                RowBox[{"cos", "(", 
                  RowBox[{
                    FractionBox["1", "4"], " ", "\[Pi]", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"2", " ", "\[Alpha]"}], "+", 
                        RowBox[{"2", " ", "\[Nu]"}], "+", "1"}], ")"}]}], 
                  ")"}], " ", 
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{"\[Alpha]", "+", "\[Nu]", "+", 
                    FractionBox["1", "2"]}], ")"}], " ", 
                TagBox[
                  TagBox[
                    RowBox[{
                      RowBox[{
                        SubscriptBox["\[InvisiblePrefixScriptBase]", 
                          FormBox["2",
                            "TraditionalForm"]], 
                        SubscriptBox["F", 
                          FormBox["1",
                            "TraditionalForm"]]}], "\[InvisibleApplication]", 
                      
                      RowBox[{"(", 
                        RowBox[{
                          TagBox[
                            TagBox[
                              RowBox[{
                                TagBox[
                                  RowBox[{
                                    FractionBox["1", "4"], " ", 
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{"2", " ", "\[Alpha]"}], "+", 
                                        RowBox[{"2", " ", "\[Nu]"}], "+", 
                                        "1"}], ")"}]}],
                                  Hypergeometric2F1,
                                  Editable->True], ",", 
                                TagBox[
                                  RowBox[{
                                    FractionBox["1", "4"], " ", 
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{"2", " ", "\[Alpha]"}], "+", 
                                        RowBox[{"2", " ", "\[Nu]"}], "+", 
                                        "3"}], ")"}]}],
                                  Hypergeometric2F1,
                                  Editable->True]}],
                              InterpretTemplate[ {
                                SlotSequence[ 1]}&]],
                            Hypergeometric2F1,
                            Editable->False], ";", 
                          TagBox[
                            TagBox[
                              TagBox[
                                RowBox[{"\[Nu]", "+", "1"}],
                                Hypergeometric2F1,
                                Editable->True],
                              InterpretTemplate[ {
                                SlotSequence[ 1]}&]],
                            Hypergeometric2F1,
                            Editable->False], ";", 
                          TagBox[
                            SuperscriptBox["z", "2"],
                            Hypergeometric2F1,
                            Editable->True]}], ")"}]}],
                    InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                    Editable->False],
                  Hypergeometric2F1]}], ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{
            RowBox[{"Re", "(", 
              RowBox[{"\[Alpha]", "+", "\[Nu]"}], ")"}], ">", 
            RowBox[{"-", 
              FractionBox["1", "2"]}]}], "\[And]", 
          RowBox[{
            RowBox[{"Re", "(", "\[Alpha]", ")"}], "<", "1."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Finite summation", "Subsubsection"],

Cell["\<\
The following finite sums from the cosine can be expressed using \
the trigonometric functions:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "n"], 
          RowBox[{"cos", "(", 
            RowBox[{"a", " ", "k"}], ")"}]}], "\[Equal]", 
        RowBox[{
          RowBox[{"csc", "(", 
            FractionBox["a", "2"], ")"}], " ", 
          RowBox[{"sin", "(", 
            FractionBox[
              RowBox[{"a", " ", 
                RowBox[{"(", 
                  RowBox[{"n", "+", "1"}], ")"}]}], "2"], ")"}], " ", 
          RowBox[{"cos", "(", 
            FractionBox[
              RowBox[{"a", " ", "n"}], "2"], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "n"], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "k"], " ", 
            RowBox[{"cos", "(", 
              RowBox[{"a", " ", "k"}], ")"}]}]}], "\[Equal]", 
        RowBox[{
          RowBox[{"cos", "(", 
            RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
                RowBox[{"a", "+", 
                  RowBox[{"n", " ", 
                    RowBox[{"(", 
                      RowBox[{"a", "+", "\[Pi]"}], ")"}]}]}], ")"}]}], ")"}], 
          " ", 
          RowBox[{"sec", "(", 
            FractionBox["a", "2"], ")"}], " ", 
          RowBox[{"cos", "(", 
            RowBox[{
              FractionBox["1", "2"], " ", "n", " ", 
              RowBox[{"(", 
                RowBox[{"a", "+", "\[Pi]"}], ")"}]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "n"], 
          RowBox[{"cos", "(", 
            RowBox[{
              RowBox[{"a", " ", "k"}], "+", "z"}], ")"}]}], "\[Equal]", 
        RowBox[{
          RowBox[{"csc", "(", 
            FractionBox["a", "2"], ")"}], " ", 
          RowBox[{"sin", "(", 
            RowBox[{
              FractionBox["1", "2"], " ", "a", " ", 
              RowBox[{"(", 
                RowBox[{"n", "+", "1"}], ")"}]}], ")"}], " ", 
          RowBox[{"cos", "(", 
            RowBox[{
              FractionBox[
                RowBox[{"a", " ", "n"}], "2"], "+", "z"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "n"], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "k"], " ", 
            RowBox[{"cos", "(", 
              RowBox[{
                RowBox[{"a", " ", "k"}], "+", "z"}], ")"}]}]}], "\[Equal]", 
        RowBox[{
          RowBox[{"cos", "(", 
            RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
                RowBox[{"a", "+", 
                  RowBox[{"n", " ", 
                    RowBox[{"(", 
                      RowBox[{"a", "+", "\[Pi]"}], ")"}]}]}], ")"}]}], ")"}], 
          " ", 
          RowBox[{"sec", "(", 
            FractionBox["a", "2"], ")"}], " ", 
          RowBox[{"cos", "(", 
            RowBox[{
              RowBox[{
                FractionBox["1", "2"], " ", "n", " ", 
                RowBox[{"(", 
                  RowBox[{"a", "+", "\[Pi]"}], ")"}]}], "+", "z"}], ")"}]}]}],
       TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "1"}], "n"], 
          RowBox[{
            SuperscriptBox["z", "k"], " ", 
            RowBox[{"cos", "(", 
              RowBox[{"k", " ", "a"}], ")"}]}]}], "\[Equal]", 
        RowBox[{
          FractionBox[
            RowBox[{"z", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cos", "(", 
                      RowBox[{"a", " ", "n"}], ")"}], " ", 
                    SuperscriptBox["z", 
                      RowBox[{"n", "+", "1"}]]}], "-", 
                  RowBox[{
                    RowBox[{"cos", "(", 
                      RowBox[{
                        RowBox[{"n", " ", "a"}], "+", "a"}], ")"}], " ", 
                    SuperscriptBox["z", "n"]}], "-", "z", "+", 
                  RowBox[{"cos", "(", "a", ")"}]}], ")"}]}], 
            RowBox[{
              SuperscriptBox["z", "2"], "-", 
              RowBox[{"2", " ", 
                RowBox[{"cos", "(", "a", ")"}], " ", "z"}], "+", "1"}]], 
          "."}]}], TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Infinite summation", "Subsubsection"],

Cell["\<\
The following infinite sums can be expressed using elementary \
functions:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderoverscriptBox["\[Sum]", 
              RowBox[{"k", "=", "1"}], "\[Infinity]"], 
            FractionBox[
              RowBox[{"cos", "(", 
                RowBox[{"a", " ", "k"}], ")"}], "k"]}], "\[Equal]", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"log", "(", 
              FractionBox["1", 
                RowBox[{"2", " ", 
                  RowBox[{"(", 
                    RowBox[{"1", "-", 
                      RowBox[{"cos", "(", "a", ")"}]}], ")"}]}]], ")"}]}]}], "/;",
         
        RowBox[{"0", "<", 
          RowBox[{"Re", "(", "a", ")"}], "<", 
          RowBox[{"2", " ", "\[Pi]"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderoverscriptBox["\[Sum]", 
              RowBox[{"k", "=", "1"}], "\[Infinity]"], 
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                  RowBox[{"k", "-", "1"}]], " ", 
                RowBox[{"cos", "(", 
                  RowBox[{"a", " ", "k"}], ")"}]}], "k"]}], "\[Equal]", 
          RowBox[{"log", "(", 
            RowBox[{"2", " ", 
              RowBox[{"cos", "(", 
                FractionBox["a", "2"], ")"}]}], ")"}]}], "/;", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{"Re", "(", "a", ")"}], "\[RightBracketingBar]"}], "<", 
          "\[Pi]"}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "\[Infinity]"], 
          FractionBox[
            RowBox[{"cos", "(", 
              RowBox[{"a", " ", "k"}], ")"}], 
            RowBox[{"k", "!"}]]}], "\[Equal]", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{"cos", "(", "a", ")"}]], " ", 
          RowBox[{"cos", "(", 
            RowBox[{"sin", "(", "a", ")"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "\[Infinity]"], 
          FractionBox[
            RowBox[{
              SuperscriptBox["z", "k"], " ", 
              RowBox[{"cos", "(", 
                RowBox[{"a", " ", "k"}], ")"}]}], 
            RowBox[{"k", "!"}]]}], "\[Equal]", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{"z", " ", 
              RowBox[{"cos", "(", "a", ")"}]}]], " ", 
          RowBox[{"cos", "(", 
            RowBox[{"z", " ", 
              RowBox[{"sin", "(", "a", ")"}]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderoverscriptBox["\[Sum]", 
              RowBox[{"k", "=", "0"}], "\[Infinity]"], 
            RowBox[{
              SuperscriptBox["z", "k"], " ", 
              RowBox[{"cos", "(", 
                RowBox[{"a", " ", "k"}], ")"}]}]}], "\[Equal]", 
          FractionBox[
            RowBox[{"1", "-", 
              RowBox[{"z", " ", 
                RowBox[{"cos", "(", "a", ")"}]}]}], 
            RowBox[{
              SuperscriptBox["z", "2"], "-", 
              RowBox[{"2", " ", 
                RowBox[{"cos", "(", "a", ")"}], " ", "z"}], "+", "1"}]]}], "/;",
         
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], "<",
           "1."}]}], TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Finite products", "Subsubsection"],

Cell["\<\
The following finite products from the cosine can be expressed \
using trigonometric functions:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderoverscriptBox["\[Product]", 
              RowBox[{"k", "=", "1"}], 
              RowBox[{
                RowBox[{"2", " ", "n"}], "-", "1"}]], 
            RowBox[{"cos", "(", 
              FractionBox[
                RowBox[{"k", " ", "\[Pi]"}], "n"], ")"}]}], "\[Equal]", 
          RowBox[{
            SuperscriptBox["2", 
              RowBox[{"1", "-", 
                RowBox[{"2", " ", "n"}]}]], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "n"], "-", "1"}], ")"}]}]}], "/;",
         
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderoverscriptBox["\[Product]", 
              RowBox[{"k", "=", "1"}], 
              RowBox[{"\[LeftFloor]", 
                FractionBox[
                  RowBox[{"n", "-", "1"}], "2"], "\[RightFloor]"}]], 
            RowBox[{"cos", "(", 
              FractionBox[
                RowBox[{"\[Pi]", " ", "k"}], "n"], ")"}]}], "\[Equal]", 
          RowBox[{
            SuperscriptBox["2", 
              FractionBox[
                RowBox[{"1", "-", "n"}], "2"]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  RowBox[{"(", 
                    RowBox[{"1", "-", 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"-", "1"}], ")"}], "n"]}], ")"}]}], "+", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"-", "1"}], ")"}], "n"]}], ")"}], " ", 
                  SqrtBox["n"]}]}], ")"}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderoverscriptBox["\[Product]", 
              RowBox[{"k", "=", "1"}], 
              RowBox[{"n", "-", "1"}]], 
            RowBox[{"cos", "(", 
              RowBox[{
                FractionBox[
                  RowBox[{"\[Pi]", " ", "k"}], "n"], "+", "z"}], ")"}]}], 
          "\[Equal]", 
          RowBox[{
            FractionBox[
              SuperscriptBox["2", 
                RowBox[{"1", "-", "n"}]], 
              RowBox[{"cos", "(", "z", ")"}]], 
            RowBox[{"sin", "(", 
              RowBox[{"n", " ", 
                RowBox[{"(", 
                  RowBox[{"z", "+", 
                    FractionBox["\[Pi]", "2"]}], ")"}]}], ")"}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderoverscriptBox["\[Product]", 
              RowBox[{"k", "=", "1"}], 
              RowBox[{"n", "-", "1"}]], 
            RowBox[{"cos", "(", 
              RowBox[{
                FractionBox[
                  RowBox[{"2", " ", "\[Pi]", " ", "k"}], "n"], "+", "z"}], 
              ")"}]}], "\[Equal]", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "2"}], ")"}], 
              RowBox[{"1", "-", "n"}]], " ", 
            RowBox[{"sec", "(", "z", ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cos", "(", 
                  RowBox[{"n", " ", "z"}], ")"}], "-", 
                RowBox[{"cos", "(", 
                  FractionBox[
                    RowBox[{"n", " ", "\[Pi]"}], "2"], ")"}]}], ")"}]}]}], "/;",
         
        RowBox[{"n", "\[Element]", 
          RowBox[{
            SuperscriptBox["\[DoubleStruckCapitalN]", "+"], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Infinite products", "Subsubsection"],

Cell["\<\
The following infinite product including cosine function can be \
expressed using the sine function:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          UnderoverscriptBox["\[Product]", 
            RowBox[{"k", "=", "1"}], "\[Infinity]"], 
          RowBox[{"cos", "(", 
            FractionBox["z", 
              SuperscriptBox["2", "k"]], ")"}]}], "\[Equal]", 
        RowBox[{
          FractionBox[
            RowBox[{"sin", "(", "z", ")"}], "z"], "."}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Addition formulas", "Subsubsection"],

Cell["\<\
The cosine of a sum can be represented by the rule \"the cosine of \
a sum is equal to cosine on cosine minus sine on sine\". A similar rule is \
valid for the cosine of the difference:\
\>", "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", 
          RowBox[{"a", "+", "b"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            RowBox[{"cos", "(", "a", ")"}], 
            RowBox[{"cos", "(", "b", ")"}]}], "-", 
          RowBox[{
            RowBox[{"sin", "(", "a", ")"}], " ", 
            RowBox[{"sin", "(", "b", ")"}]}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", 
          RowBox[{"a", "-", "b"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            RowBox[{"cos", "(", "a", ")"}], 
            RowBox[{"cos", "(", "b", ")"}]}], " ", "+", 
          RowBox[{
            RowBox[{"sin", "(", "a", ")"}], " ", 
            RowBox[{
              RowBox[{"sin", "(", "b", ")"}], "."}]}]}]}], 
      TraditionalForm]}], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple arguments", "Subsubsection"],

Cell[TextData[{
  "In the case of multiple arguments ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"2", "z"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"3", "z"}], TraditionalForm]]],
  ", \[Ellipsis], the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " can be represented as the finite sum of terms that include powers of sine \
and cosine: "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", 
          RowBox[{"2", " ", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            SuperscriptBox["cos", "2"], "(", "z", ")"}], "-", 
          RowBox[{
            SuperscriptBox["sin", "2"], "(", "z", ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", 
          RowBox[{"3", " ", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{"4", 
            RowBox[{
              SuperscriptBox["cos", "3"], "(", "z", ")"}]}], "-", 
          RowBox[{"3", " ", 
            RowBox[{"cos", "(", "z", ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"cos", "(", 
            RowBox[{"n", " ", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            UnderoverscriptBox["\[Sum]", 
              RowBox[{"k", "=", "0"}], 
              RowBox[{"\[LeftFloor]", 
                FractionBox["n", "2"], "\[RightFloor]"}]], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "k"], " ", 
              TagBox[
                RowBox[{"(", GridBox[{
                      {
                        TagBox["n",
                          Identity,
                          Editable->True]},
                      {
                        TagBox[
                          RowBox[{"2", " ", "k"}],
                          Identity,
                          Editable->True]}
                      }], ")"}],
                InterpretTemplate[ Binomial[ #, #2]&],
                Editable->False], " ", 
              RowBox[{
                SuperscriptBox["sin", 
                  RowBox[{"2", " ", "k"}]], "(", "z", ")"}], " ", 
              RowBox[{
                SuperscriptBox["cos", 
                  RowBox[{"n", "-", 
                    RowBox[{"2", " ", "k"}]}]], "(", "z", ")"}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          RowBox[{
            SuperscriptBox["\[DoubleStruckCapitalN]", "+"], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", 
          RowBox[{"n", " ", "z"}], ")"}], TraditionalForm]]],
  " can also be represented as the finite sun including only the cosine of ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ": "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"cos", "(", 
            RowBox[{"n", " ", "z"}], ")"}], "\[Equal]", 
          RowBox[{"n", " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], 
                RowBox[{"\[LeftFloor]", 
                  FractionBox["n", "2"], "\[RightFloor]"}]], 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", "1"}], ")"}], "k"], " ", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{"n", "-", "k", "-", "1"}], ")"}], "!"}], " ", 
                    
                    SuperscriptBox["2", 
                      RowBox[{"n", "-", 
                        RowBox[{"2", "k"}], "-", "1"}]]}], 
                  RowBox[{
                    RowBox[{"k", "!"}], " ", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{"n", "-", 
                          RowBox[{"2", " ", "k"}]}], ")"}], "!"}]}]], 
                RowBox[{
                  SuperscriptBox["cos", 
                    RowBox[{"n", "-", 
                      RowBox[{"2", " ", "k"}]}]], "(", "z", ")"}]}]}]}]}], "/;",
         
        RowBox[{"n", "\[Element]", 
          RowBox[{
            SuperscriptBox[
              TagBox["\[DoubleStruckCapitalN]",
                (Integers&)], "+"], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Half\[Hyphen]angle formulas", "Subsubsection"],

Cell["\<\
The cosine of the half\[Hyphen]angle can be represented by the \
following simple formula that is valid in some vertical strip:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"cos", "(", 
            FractionBox["z", "2"], ")"}], "\[Equal]", 
          SqrtBox[
            FractionBox[
              RowBox[{"1", "+", 
                RowBox[{"cos", "(", "z", ")"}]}], "2"]]}], "/;", 
        RowBox[{
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{"Re", "(", "z", ")"}], "\[RightBracketingBar]"}], "<", 
            "\[Pi]"}], "\[Or]", 
          RowBox[{
            RowBox[{
              RowBox[{"Re", "(", "z", ")"}], "\[Equal]", 
              RowBox[{"-", "\[Pi]"}]}], "\[And]", 
            RowBox[{
              RowBox[{"Im", "(", "z", ")"}], "\[GreaterEqual]", "0"}]}], 
          "\[Or]", 
          RowBox[{
            RowBox[{
              RowBox[{"Re", "(", "z", ")"}], "\[Equal]", "\[Pi]"}], "\[And]", 
            
            RowBox[{
              RowBox[{"Im", "(", "z", ")"}], "\[LessEqual]", "0."}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "To make this formula correct for all complex ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ", a complicated prefactor is needed:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"cos", "(", 
              FractionBox["z", "2"], ")"}], "\[Equal]", 
            RowBox[{
              RowBox[{"c", "(", "z", ")"}], " ", 
              SqrtBox[
                RowBox[{
                  FractionBox[
                    RowBox[{"1", "+", 
                      RowBox[{"cos", "(", "z", ")"}]}], "2"], " "}]]}]}], "/;",
           
          RowBox[{
            RowBox[{"c", "(", "z", ")"}], "\[Equal]", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], 
                RowBox[{"\[LeftFloor]", 
                  FractionBox[
                    RowBox[{
                      RowBox[{"Re", "(", "z", ")"}], "+", "\[Pi]"}], 
                    RowBox[{"2", " ", "\[Pi]"}]], "\[RightFloor]"}]], " ", 
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"1", "+", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"-", "1"}], ")"}], 
                          RowBox[{
                            RowBox[{"\[LeftFloor]", 
                              FractionBox[
                                RowBox[{
                                  RowBox[{"Re", "(", "z", ")"}], "+", 
                                  "\[Pi]"}], 
                                RowBox[{"2", " ", "\[Pi]"}]], 
                              "\[RightFloor]"}], "+", 
                            RowBox[{"\[LeftFloor]", 
                              RowBox[{"-", 
                                FractionBox[
                                  RowBox[{
                                    RowBox[{"Re", "(", "z", ")"}], "+", 
                                    "\[Pi]"}], 
                                  RowBox[{"2", " ", "\[Pi]"}]]}], 
                              "\[RightFloor]"}]}]]}], ")"}], " ", 
                    RowBox[{"\[Theta]", "(", 
                      RowBox[{"-", 
                        RowBox[{"Im", "(", "z", ")"}]}], ")"}]}]}], 
                ")"}]}]}]}], ","}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "(", "z", ")"}], TraditionalForm]]],
  " includes the unit step, real part, imaginary part, and the floor \
functions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sums of two direct functions", "Subsubsection"],

Cell["\<\
The sum of two cosine functions can be described by the rule \"the \
sum of cosines is equal to the doubled cosine of the half\[Hyphen]difference \
multiplied on the cosine of the half\[Hyphen]sum\". A similar rule is valid \
for the difference of two cosines:\
\>", "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"cos", "(", "a", ")"}], "+", 
          RowBox[{"cos", "(", "b", ")"}]}], "\[Equal]", 
        RowBox[{"2", " ", 
          RowBox[{"cos", "(", 
            FractionBox[
              RowBox[{"a", "-", "b"}], "2"], ")"}], " ", 
          RowBox[{"cos", "(", 
            FractionBox[
              RowBox[{"a", "+", "b"}], "2"], ")"}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"cos", "(", "a", ")"}], "-", 
          RowBox[{"cos", "(", "b", ")"}]}], "\[Equal]", 
        RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"sin", "(", 
            FractionBox[
              RowBox[{"a", "+", "b"}], "2"], ")"}], " ", 
          RowBox[{
            RowBox[{"sin", "(", 
              FractionBox[
                RowBox[{"a", "-", "b"}], "2"], ")"}], "."}]}]}], 
      TraditionalForm]}], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Products involving the direct function", "Subsubsection"],

Cell["\<\
The product of two cosine functions or the product of the cosine \
and sine have the following representations:\
\>", "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"cos", "(", "a", ")"}], " ", 
          RowBox[{"cos", "(", "b", ")"}]}], "\[Equal]", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cos", "(", 
                RowBox[{"a", "-", "b"}], ")"}], "+", 
              RowBox[{"cos", "(", 
                RowBox[{"a", "+", "b"}], ")"}]}], ")"}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"cos", "(", "a", ")"}], 
          RowBox[{"sin", "(", "b", ")"}]}], " ", "\[Equal]", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"sin", "(", 
                  RowBox[{"b", "-", "a"}], ")"}], "+", 
                RowBox[{"sin", "(", 
                  RowBox[{"a", "+", "b"}], ")"}]}], ")"}], "."}]}]}], 
      TraditionalForm]}], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Powers of the direct function", "Subsubsection"],

Cell["\<\
The integer powers of the cosine functions can be expanded as \
finite sums of cosine functions with multiple arguments. These sums include \
binomial coefficients:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["cos", "n"], "(", "z", ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              SuperscriptBox["2", 
                RowBox[{"-", "n"}]], " ", 
              TagBox[
                RowBox[{"(", GridBox[{
                      {
                        TagBox["n",
                          Identity,
                          Editable->True]},
                      {
                        TagBox[
                          FractionBox["n", "2"],
                          Identity,
                          Editable->True]}
                      }], ")"}],
                InterpretTemplate[ Binomial[ #, #2]&],
                Editable->False], " ", 
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  InterpretationBox[
                    RowBox[{"n", " ", "mod", " ", "2"}],
                    Mod[ n, 2]]}], ")"}]}], "+", 
            RowBox[{
              SuperscriptBox["2", 
                RowBox[{"1", "-", "n"}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "0"}], 
                  RowBox[{"\[LeftFloor]", 
                    FractionBox[
                      RowBox[{"n", "-", "1"}], "2"], "\[RightFloor]"}]], 
                RowBox[{
                  TagBox[
                    RowBox[{"(", GridBox[{
                          {
                            TagBox["n",
                              Identity,
                              Editable->True]},
                          {
                            TagBox["k",
                              Identity,
                              Editable->True]}
                          }], ")"}],
                    InterpretTemplate[ Binomial[ #, #2]&],
                    Editable->False], " ", 
                  RowBox[{"cos", "(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{"n", "-", 
                          RowBox[{"2", " ", "k"}]}], ")"}], " ", "z"}], 
                    ")"}]}]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          RowBox[{
            SuperscriptBox[
              TagBox["\[DoubleStruckCapitalN]",
                (Integers&)], "+"], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Inequalities", "Subsubsection"],

Cell["\<\
The most known inequalities for cosine function are the \
following:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{"cos", "(", "x", ")"}], "\[RightBracketingBar]"}], 
          "\[LessEqual]", "1"}], "/;", 
        RowBox[{"x", "\[Element]", 
          TagBox["\[DoubleStruckCapitalR]",
            (Reals&)]}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"cos", "(", "x", ")"}], "<", 
          FractionBox[
            RowBox[{"sin", "(", "x", ")"}], "x"]}], "/;", 
        RowBox[{"0", "<", "x", "<", 
          RowBox[{"4.493409", "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Relations with inverse function", "Subsubsection"],

Cell[TextData[{
  "There are a simple relations between the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " and its inverse function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["cos", 
            RowBox[{"-", "1"}]], "(", "z", ")"}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                SuperscriptBox["cos", 
                  RowBox[{"-", "1"}]], "(", 
                RowBox[{"cos", "(", "z", ")"}], ")"}], "\[Equal]", "z"}], 
            RowBox[{" ", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    SuperscriptBox["cos", 
                      RowBox[{"-", "1"}]], "(", 
                    RowBox[{"cos", "(", "z", ")"}], ")"}], "\[Equal]", "z"}], 
                "/;", 
                RowBox[{
                  RowBox[{"0", "<", 
                    RowBox[{"Re", "(", "z", ")"}], "<", "\[Pi]"}], "\[Or]", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Re", "(", "z", ")"}], "\[Equal]", "0"}], 
                    "\[And]", 
                    RowBox[{
                      RowBox[{"Im", "(", "z", ")"}], "\[GreaterEqual]", 
                      "0"}]}], "\[Or]", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Re", "(", "z", ")"}], "\[Equal]", "\[Pi]"}], 
                    "\[And]", 
                    RowBox[{
                      RowBox[{"Im", "(", "z", ")"}], "\[LessEqual]", 
                      "0."}]}]}]}]}]}
          }], TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The second formula is valid at least in the vertical strip ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", 
          RowBox[{"Re", "(", "z", ")"}], "<", "\[Pi]"}], TraditionalForm]]],
  ". Outside of this strip a much more complicated relation (including the \
unit step, real part and the floor functions) holds:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["cos", 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"cos", "(", "z", ")"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            FractionBox["\[Pi]", "2"], 
            RowBox[{"(", 
              RowBox[{"1", "-", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                  RowBox[{"\[LeftFloor]", 
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{"Re", "(", "z", ")"}], "\[Pi]"]}], 
                    "\[RightFloor]"}]]}], ")"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
              RowBox[{"\[LeftFloor]", 
                RowBox[{"-", 
                  FractionBox[
                    RowBox[{"Re", "(", "z", ")"}], "\[Pi]"]}], 
                "\[RightFloor]"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"-", "1"}], ")"}], 
                        RowBox[{
                          RowBox[{"\[LeftFloor]", 
                            FractionBox[
                              RowBox[{"Re", "(", "z", ")"}], "\[Pi]"], 
                            "\[RightFloor]"}], "+", 
                          RowBox[{"\[LeftFloor]", 
                            RowBox[{"-", 
                              FractionBox[
                                RowBox[{"Re", "(", "z", ")"}], "\[Pi]"]}], 
                            "\[RightFloor]"}]}]]}], ")"}], " ", 
                  RowBox[{"\[Theta]", "(", 
                    RowBox[{"Im", "(", "z", ")"}], ")"}]}], "-", "1"}], ")"}],
             " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"z", "+", 
                  RowBox[{"\[Pi]", " ", 
                    RowBox[{"\[LeftFloor]", 
                      RowBox[{"-", 
                        FractionBox[
                          RowBox[{"Re", "(", "z", ")"}], "\[Pi]"]}], 
                      "\[RightFloor]"}]}]}], ")"}], "."}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Representations through other trigonometric functions", "Subsubsection"],

Cell["\<\
Cosine and sine functions are connected by a very simple formula \
including the linear function in the argument:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{"sin", "(", 
            RowBox[{
              FractionBox["\[Pi]", "2"], "-", "z"}], ")"}], "."}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "Another famous formula, connecting ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"sin", "(", "z", ")"}], TraditionalForm]]],
  ", is reflected in the well",
  "\[Hyphen]",
  "known Pythagorean theorem:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["cos", "2"], "(", "z", ")"}], "\[Equal]", 
        RowBox[{"1", "-", 
          RowBox[{
            SuperscriptBox["sin", "2"], "(", "z", ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
          SqrtBox[
            RowBox[{"1", "-", 
              RowBox[{
                SuperscriptBox["sin", "2"], "(", "z", ")"}]}]]}], "/;", 
        RowBox[{
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{"Re", "(", "z", ")"}], "\[RightBracketingBar]"}], "<", 
            FractionBox["\[Pi]", "2"]}], "\[Or]", 
          RowBox[{
            RowBox[{
              RowBox[{"Re", "(", "z", ")"}], "\[Equal]", 
              RowBox[{"-", 
                FractionBox["\[Pi]", "2"]}]}], "\[And]", 
            RowBox[{
              RowBox[{"Im", "(", "z", ")"}], "\[GreaterEqual]", "0"}]}], 
          "\[Or]", 
          RowBox[{
            RowBox[{
              RowBox[{"Re", "(", "z", ")"}], "\[Equal]", 
              FractionBox["\[Pi]", "2"]}], "\[And]", 
            RowBox[{
              RowBox[{"Im", "(", "z", ")"}], "\[LessEqual]", "0."}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The last restriction on ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  " can be removed, but the formula will get a complicated coefficient ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "(", "z", ")"}], TraditionalForm]]],
  " with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{"c", "(", "z", ")"}], "\[RightBracketingBar]"}], 
          "\[Equal]", "1"}], TraditionalForm]]],
  ", including the unit step, real part, imaginary part, and the floor \
function: "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"c", "(", "z", ")"}], 
            SqrtBox[
              RowBox[{"1", "-", 
                RowBox[{
                  SuperscriptBox["sin", "2"], "(", "z", ")"}]}]]}]}], "/;", 
        RowBox[{
          RowBox[{"c", "(", "z", ")"}], "\[Equal]", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
              RowBox[{"\[LeftFloor]", 
                RowBox[{
                  FractionBox["1", "2"], "-", 
                  FractionBox[
                    RowBox[{"Re", "(", "z", ")"}], "\[Pi]"]}], 
                "\[RightFloor]"}]], " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"1", "+", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"-", "1"}], ")"}], 
                          RowBox[{
                            RowBox[{"\[LeftFloor]", 
                              RowBox[{
                                FractionBox[
                                  RowBox[{"Re", "(", "z", ")"}], "\[Pi]"], 
                                "-", 
                                FractionBox["1", "2"]}], "\[RightFloor]"}], 
                            "+", 
                            RowBox[{"\[LeftFloor]", 
                              RowBox[{
                                FractionBox["1", "2"], "-", 
                                FractionBox[
                                  RowBox[{"Re", "(", "z", ")"}], "\[Pi]"]}], 
                              "\[RightFloor]"}]}]]}], ")"}], " ", 
                    RowBox[{"\[Theta]", "(", 
                      RowBox[{"Im", "(", "z", ")"}], ")"}]}]}], ")"}], 
              "."}]}]}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell["\<\
The cosine function can also be represented using other \
trigonometric functions by the following formulas:\
\>", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              FractionBox[
                RowBox[{"1", "-", 
                  RowBox[{
                    SuperscriptBox["tan", "2"], "(", 
                    FractionBox["z", "2"], ")"}]}], 
                RowBox[{"1", "+", 
                  RowBox[{
                    SuperscriptBox["tan", "2"], "(", 
                    FractionBox["z", "2"], ")"}]}]]}], 
            RowBox[{" ", 
              RowBox[{
                RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
                FractionBox[
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["cot", "2"], "(", 
                      FractionBox["z", "2"], ")"}], "-", "1"}], 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["cot", "2"], "(", 
                      FractionBox["z", "2"], ")"}], "+", "1"}]]}]}]}
          }], TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              FractionBox["1", 
                RowBox[{"csc", "(", 
                  RowBox[{
                    FractionBox["\[Pi]", "2"], "-", "z"}], ")"}]]}], 
            RowBox[{" ", 
              RowBox[{
                RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
                RowBox[{
                  FractionBox["1", 
                    RowBox[{"sec", "(", "z", ")"}]], "."}]}]}]}
          }], TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Representations through hyperbolic functions", "Subsubsection"],

Cell["\<\
The cosine function has representations using the hyperbolic \
functions:\
\>", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              RowBox[{"cosh", "(", 
                RowBox[{"\[ImaginaryI]", " ", "z"}], ")"}]}], 
            RowBox[{
              RowBox[{"cos", "(", 
                RowBox[{"\[ImaginaryI]", " ", "z"}], ")"}], "\[Equal]", 
              RowBox[{"cosh", "(", "z", ")"}]}], 
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", 
                RowBox[{"sinh", "(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{"\[Pi]", " ", "\[ImaginaryI]"}], "2"], "-", 
                    RowBox[{"\[ImaginaryI]", " ", "z"}]}], ")"}]}]}]}
          }], TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              FractionBox[
                RowBox[{"1", "+", 
                  RowBox[{
                    SuperscriptBox["tanh", "2"], "(", 
                    FractionBox[
                      RowBox[{"z", " ", "\[ImaginaryI]"}], "2"], ")"}]}], 
                RowBox[{"1", "-", 
                  RowBox[{
                    SuperscriptBox["tanh", "2"], "(", 
                    FractionBox[
                      RowBox[{"z", " ", "\[ImaginaryI]"}], "2"], ")"}]}]]}], 
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              FractionBox[
                RowBox[{
                  RowBox[{
                    SuperscriptBox["coth", "2"], "(", 
                    FractionBox[
                      RowBox[{"\[ImaginaryI]", " ", "z"}], "2"], ")"}], "+", 
                  "1"}], 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["coth", "2"], "(", 
                    FractionBox[
                      RowBox[{"\[ImaginaryI]", " ", "z"}], "2"], ")"}], "-", 
                  "1"}]]}], 
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              RowBox[{"-", 
                FractionBox["\[ImaginaryI]", 
                  RowBox[{"csch", "(", 
                    RowBox[{
                      FractionBox[
                        RowBox[{"\[Pi]", " ", "\[ImaginaryI]"}], "2"], "-", 
                      RowBox[{"\[ImaginaryI]", " ", "z"}]}], ")"}]]}]}], 
            RowBox[{
              RowBox[{"cos", "(", "z", ")"}], "\[Equal]", 
              RowBox[{
                FractionBox["1", 
                  RowBox[{"sech", "(", 
                    RowBox[{"\[ImaginaryI]", " ", "z"}], ")"}]], "."}]}]}
          }], TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Applications ", "Subsubsection"],

Cell["\<\
The cosine function is used throughout mathematics, the exact \
sciences, and engineering.\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{665, 551},
WindowMargins->{{Automatic, 100}, {185, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "mtrott7", "Texts"}, \
"TitleOfBox1.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
PrivateNotebookOptions->{"ShortBoxForm"->False},
CellLabelAutoDelete->False,
ShowCellTags->False,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "NoCodePrintout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["Input", "NoCodePrintout"],
    CellMargins->{{39, 0}, {4, 6}},
    CellOpen->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageSize->{Automatic, 160},
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Special Styles", "Section"],
  
  Cell[StyleData["GraphicsTitle"],
    CellMargins->{{12, Inherited}, {20, 40}},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["IntroductionSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["NSDLMetaDataSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["NSDLMetaData"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AltTag"],
    CellMargins->{{12, 10}, {7, 7}},
    CellFrameLabels->{{
      Cell[ "AT", "Text", FontColor -> RGBColor[ 0, 0.299992, 0.299992]], 
          Inherited}, {Inherited, Inherited}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["AltTag", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GraphicsCount"],
    CellMargins->{{12, 10}, {7, 7}},
    CellFrameLabels->{{
      Cell[ "CG", "Text", FontColor -> GrayLevel[ 0.2]], Inherited}, {
        Inherited, Inherited}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["GC", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrivateInput"],
    CellFrame->{{6, 0}, {0, 0}},
    CellMargins->{{50, 4}, {2, 6}},
    CellBracketOptions->{"Thickness"->2,
    "Color"->RGBColor[0, 0.299992, 0.299992]},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0, 0.299992, 0.299992],
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    SpellingOptions->{"AlwaysStop"->{}},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["PrivateInput", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TraditionalFormEquation"],
    CellMargins->{{85, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->{"OutputGrouping", 50},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Above,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Plain"],
  
  Cell[StyleData["TraditionalFormEquation", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["TraditionalFormEquation", "WebSite"],
    CellMargins->{{56, 10}, {5, 7}}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{59, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{108, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{158, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 38, 0, 61, "Section"],

Cell[CellGroupData[{
Cell[1839, 57, 50, 0, 45, "Subsection"],
Cell[1892, 59, 621, 15, 86, "Text"],
Cell[2516, 76, 1859, 55, 122, "Text"],
Cell[4378, 133, 104, 3, 32, "Text"],
Cell[4485, 138, 866, 24, 62, "TraditionalFormEquation"],
Cell[5354, 164, 139, 5, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5530, 174, 57, 0, 29, "Subsection"],
Cell[5590, 176, 332, 11, 32, "Text"],
Cell[5925, 189, 84354, 2911, 258, 45399, 2425, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[90316, 3105, 67, 0, 29, "Subsection"],
Cell[90386, 3107, 2083, 59, 55, "Text"],
Cell[92472, 3168, 1637, 42, 50, "TraditionalFormEquation"],
Cell[94112, 3212, 564, 21, 37, "Text"],
Cell[94679, 3235, 439, 13, 52, "TraditionalFormEquation"],
Cell[95121, 3250, 132, 3, 32, "Text"],
Cell[95256, 3255, 2157, 53, 43, "TraditionalFormEquation"],
Cell[97416, 3310, 123, 3, 32, "Text"],
Cell[97542, 3315, 1599, 41, 43, "TraditionalFormEquation"],
Cell[99144, 3358, 391, 13, 50, "Text"],
Cell[99538, 3373, 813, 21, 46, "TraditionalFormEquation"],
Cell[100354, 3396, 250, 8, 32, "Text"],
Cell[100607, 3406, 273, 7, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[100917, 3418, 72, 0, 29, "Subsection"],
Cell[100992, 3420, 722, 25, 50, "Text"],
Cell[101717, 3447, 475, 12, 46, "TraditionalFormEquation"],
Cell[102195, 3461, 291, 8, 50, "Text"],
Cell[102489, 3471, 389, 10, 29, "TraditionalFormEquation"],
Cell[102881, 3483, 260, 9, 32, "Text"],
Cell[103144, 3494, 417, 11, 29, "TraditionalFormEquation"],
Cell[103564, 3507, 99, 3, 32, "Text"],
Cell[103666, 3512, 475, 12, 46, "TraditionalFormEquation"],
Cell[104144, 3526, 131, 3, 32, "Text"],
Cell[104278, 3531, 742183, 18262, 221, 613331, 16666, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[846498, 21798, 82, 1, 29, "Subsection"],

Cell[CellGroupData[{
Cell[846605, 21803, 41, 0, 42, "Subsubsection"],
Cell[846649, 21805, 141, 3, 32, "Text"],
Cell[846793, 21810, 3322, 90, 141, "TraditionalFormEquation"],
Cell[850118, 21902, 1145, 28, 33, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[851300, 21935, 48, 0, 42, "Subsubsection"],
Cell[851351, 21937, 245, 9, 32, "Text"],
Cell[851599, 21948, 663, 20, 50, "Text"],
Cell[852265, 21970, 479, 12, 33, "TraditionalFormEquation"],
Cell[852747, 21984, 539, 17, 52, "Text"],
Cell[853289, 22003, 725, 22, 68, "Text"],
Cell[854017, 22027, 287, 8, 28, "TraditionalFormEquation"],
Cell[854307, 22037, 1235, 30, 29, "TraditionalFormEquation"],
Cell[855545, 22069, 184, 6, 32, "Text"],
Cell[855732, 22077, 514, 13, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[856283, 22095, 40, 0, 42, "Subsubsection"],
Cell[856326, 22097, 403, 15, 32, "Text"],
Cell[856732, 22114, 1153, 27, 37, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[857922, 22146, 55, 0, 42, "Subsubsection"],
Cell[857980, 22148, 237, 7, 32, "Text"],
Cell[858220, 22157, 754, 19, 28, "TraditionalFormEquation"],
Cell[858977, 22178, 539, 19, 50, "Text"],
Cell[859519, 22199, 699, 19, 28, "TraditionalFormEquation"],
Cell[860221, 22220, 210, 6, 32, "Text"],
Cell[860434, 22228, 913, 25, 42, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[861384, 22258, 46, 0, 42, "Subsubsection"],
Cell[861433, 22260, 305, 10, 32, "Text"],
Cell[861741, 22272, 866, 24, 62, "TraditionalFormEquation"],
Cell[862610, 22298, 390, 12, 32, "Text"],
Cell[863003, 22312, 1451, 37, 84, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[864491, 22354, 47, 0, 42, "Subsubsection"],
Cell[864541, 22356, 678, 22, 52, "Text"],
Cell[865222, 22380, 765, 20, 62, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[866024, 22405, 47, 0, 42, "Subsubsection"],
Cell[866074, 22407, 335, 6, 68, "Text"],
Cell[866412, 22415, 296, 8, 43, "TraditionalFormEquation"],
Cell[866711, 22425, 434, 12, 43, "TraditionalFormEquation"],
Cell[867148, 22439, 4399, 102, 132, "TraditionalFormEquation"],
Cell[871550, 22543, 301, 9, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[871888, 22557, 45, 0, 42, "Subsubsection"],
Cell[871936, 22559, 186, 4, 50, "Text"],
Cell[872125, 22565, 969, 27, 91, "TraditionalFormEquation"],
Cell[873097, 22594, 315, 11, 32, "Text"],
Cell[873415, 22607, 211, 4, 50, "Text"],
Cell[873629, 22613, 1149, 30, 81, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[874815, 22648, 44, 0, 42, "Subsubsection"],
Cell[874862, 22650, 470, 10, 68, "Text"],
Cell[875335, 22662, 707, 20, 52, "TraditionalFormEquation"],
Cell[876045, 22684, 207, 4, 50, "Text"],
Cell[876255, 22690, 1103, 29, 52, "TraditionalFormEquation"],
Cell[877361, 22721, 766, 21, 52, "TraditionalFormEquation"],
Cell[878130, 22744, 388, 11, 41, "TraditionalFormEquation"],
Cell[878521, 22757, 609, 16, 41, "TraditionalFormEquation"],
Cell[879133, 22775, 358, 10, 28, "TraditionalFormEquation"],
Cell[879494, 22787, 4505, 100, 140, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[884036, 22892, 41, 0, 42, "Subsubsection"],
Cell[884080, 22894, 119, 3, 32, "Text"],
Cell[884202, 22899, 683, 19, 52, "TraditionalFormEquation"],
Cell[884888, 22920, 1039, 29, 52, "TraditionalFormEquation"],
Cell[885930, 22951, 761, 21, 52, "TraditionalFormEquation"],
Cell[886694, 22974, 1117, 31, 52, "TraditionalFormEquation"],
Cell[887814, 23007, 1188, 30, 52, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[889039, 23042, 43, 0, 42, "Subsubsection"],
Cell[889085, 23044, 98, 3, 32, "Text"],
Cell[889186, 23049, 798, 22, 52, "TraditionalFormEquation"],
Cell[889987, 23073, 861, 22, 62, "TraditionalFormEquation"],
Cell[890851, 23097, 555, 15, 52, "TraditionalFormEquation"],
Cell[891409, 23114, 698, 19, 62, "TraditionalFormEquation"],
Cell[892110, 23135, 836, 22, 52, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[892983, 23162, 40, 0, 42, "Subsubsection"],
Cell[893026, 23164, 119, 3, 32, "Text"],
Cell[893148, 23169, 865, 24, 55, "TraditionalFormEquation"],
Cell[894016, 23195, 1409, 36, 64, "TraditionalFormEquation"],
Cell[895428, 23233, 917, 25, 55, "TraditionalFormEquation"],
Cell[896348, 23260, 1096, 30, 55, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[897481, 23295, 42, 0, 42, "Subsubsection"],
Cell[897526, 23297, 124, 3, 32, "Text"],
Cell[897653, 23302, 432, 12, 53, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[898122, 23319, 42, 0, 42, "Subsubsection"],
Cell[898167, 23321, 209, 4, 50, "Text"],
Cell[898379, 23327, 880, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[899296, 23357, 43, 0, 42, "Subsubsection"],
Cell[899342, 23359, 515, 18, 50, "Text"],
Cell[899860, 23379, 357, 10, 29, "TraditionalFormEquation"],
Cell[900220, 23391, 386, 11, 29, "TraditionalFormEquation"],
Cell[900609, 23404, 1484, 39, 60, "TraditionalFormEquation"],
Cell[902096, 23445, 308, 10, 32, "Text"],
Cell[902407, 23457, 1585, 41, 70, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[904029, 23503, 52, 0, 42, "Subsubsection"],
Cell[904084, 23505, 151, 3, 32, "Text"],
Cell[904238, 23510, 1024, 28, 52, "TraditionalFormEquation"],
Cell[905265, 23540, 174, 5, 32, "Text"],
Cell[905442, 23547, 2284, 54, 52, "TraditionalFormEquation"],
Cell[907729, 23603, 211, 7, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[907977, 23615, 53, 0, 42, "Subsubsection"],
Cell[908033, 23617, 284, 5, 50, "Text"],
Cell[908320, 23624, 981, 28, 81, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[909338, 23657, 63, 0, 42, "Subsubsection"],
Cell[909404, 23659, 135, 3, 32, "Text"],
Cell[909542, 23664, 1027, 29, 80, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[910606, 23698, 54, 0, 42, "Subsubsection"],
Cell[910663, 23700, 188, 4, 50, "Text"],
Cell[910854, 23706, 2392, 63, 62, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[913283, 23774, 37, 0, 42, "Subsubsection"],
Cell[913323, 23776, 92, 3, 32, "Text"],
Cell[913418, 23781, 366, 9, 28, "TraditionalFormEquation"],
Cell[913787, 23792, 319, 9, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[914143, 23806, 56, 0, 42, "Subsubsection"],
Cell[914202, 23808, 363, 12, 32, "Text"],
Cell[914568, 23822, 1348, 33, 29, "TraditionalFormEquation"],
Cell[915919, 23857, 358, 8, 50, "Text"],
Cell[916280, 23867, 2376, 59, 65, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[918693, 23931, 78, 0, 42, "Subsubsection"],
Cell[918774, 23933, 137, 3, 32, "Text"],
Cell[918914, 23938, 285, 8, 41, "TraditionalFormEquation"],
Cell[919202, 23948, 339, 12, 32, "Text"],
Cell[919544, 23962, 286, 8, 29, "TraditionalFormEquation"],
Cell[919833, 23972, 1069, 28, 42, "TraditionalFormEquation"],
Cell[920905, 24002, 582, 17, 50, "Text"],
Cell[921490, 24021, 2021, 48, 43, "TraditionalFormEquation"],
Cell[923514, 24071, 132, 3, 32, "Text"],
Cell[923649, 24076, 1052, 26, 47, "TraditionalFormEquation"],
Cell[924704, 24104, 588, 15, 39, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[925329, 24124, 69, 0, 42, "Subsubsection"],
Cell[925401, 24126, 97, 3, 32, "Text"],
Cell[925501, 24131, 865, 20, 33, "TraditionalFormEquation"],
Cell[926369, 24153, 1925, 46, 51, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[928331, 24204, 38, 0, 42, "Subsubsection"],
Cell[928372, 24206, 114, 3, 32, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

