(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2984854,     145687]*)
(*NotebookOutlinePosition[   3030971,     147211]*)
(*  CellTagsIndexPosition[   3030927,     147207]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The Gamma functions", "Section"],

Cell[CellGroupData[{

Cell["General", "Subsection"],

Cell[TextData[{
  "The gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " is applied in exact sciences almost as often as the well\[Hyphen]known \
factorial symbol ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "!"}], TraditionalForm]]],
  ". It was introduced by the famous mathematician L. Euler (1729) as a \
natural extension of the factorial operation ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "!"}], TraditionalForm]]],
  " from positive integers ",
  Cell[BoxData[
      FormBox["n", TraditionalForm]]],
  " to real and even complex values of this argument. This relation is \
described by the formula"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", "n", ")"}], "=", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"n", "-", "1"}], ")"}], "!"}], "."}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "Euler derived some basic properties and formulas for gamma function. He \
started investigations of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "!"}], TraditionalForm]]],
  " from the infinite product"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", 
          RowBox[{"\[CapitalGamma]", "(", "z", ")"}]], "\[Equal]", 
        RowBox[{"z", " ", 
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{"z", " ", 
              TagBox["\[DoubledGamma]",
                (EulerGamma&)]}]], " ", 
          RowBox[{
            UnderoverscriptBox["\[Product]", 
              RowBox[{"k", "=", "1"}], "\[Infinity]"], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "+", 
                  FractionBox["z", "k"]}], ")"}], " ", 
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    FractionBox["z", "k"]}]], "."}]}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " has a long history of development and numerous application since 1729 \
when Euler derived his famous integral representation of the factorial \
function. In modern notation it can be rewritten as the following:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"n", "!"}], "\[Equal]", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"n", "+", "1"}], ")"}], "\[Equal]", 
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "1"], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"log", "(", 
                    FractionBox["1", "t"], ")"}], ")"}], "n"], 
              RowBox[{"\[DifferentialD]", "t"}]}]}], "\[Equal]", 
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{
              SuperscriptBox["\[Tau]", "n"], " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "\[Tau]"}]], 
              RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "n", ")"}], ">", 
          RowBox[{"-", "1."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The history of the gamma function is described in the subsection \"General\
\" of the section \"Gamma function.\"  Since the famous work of J. Stirling \
(1730) who first used series for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log", "(", 
          RowBox[{"n", "!"}], ")"}], TraditionalForm]]],
  " to derive the asymptotic formula for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "!"}], TraditionalForm]]],
  ", mathematicians have used the logarithm of the gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log", "(", 
          RowBox[{"\[CapitalGamma]", "(", "z", ")"}], ")"}], 
        TraditionalForm]]],
  " for their investigations of the gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ". Investigators of mention include: ",
  StyleBox["C. ", "InventorsBox"],
  "Siegel, A. M. Legendre, K. F. Gauss,  C. J. Malmst\[EAcute]n,  O. Schl\
\[ODoubleDot]milch,  J. P. M. Binet (1843),  E. E. Kummer (1847), and G. \
Plana (1847).  M.A. Stern (1847) proved convergence of Stirling's series for \
the derivative of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log", "(", 
          RowBox[{"\[CapitalGamma]", "(", "z", ")"}], ")"}], 
        TraditionalForm]]],
  ". C. Hermite (1900) proved convergence of Stirling's series for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log", "(", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"z", "+", "1"}], ")"}], ")"}], TraditionalForm]]],
  " if ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  " is a complex number."
}], "Text"],

Cell[TextData[{
  "During the twentieth century the function log(\[CapitalGamma](z)) was used \
in many works where the gamma function was applied or investigated.  The \
appearance of computer systems at the end of the twentieth century demanded \
more careful attention to the structure of branch cuts of basic mathematical \
functions to support the validity of the mathematical relations everywhere in \
the complex plane. This lead to the appearance of a special log\[Hyphen]gamma \
function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", which is equivalent to logarithm of the gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log", "(", 
          RowBox[{"\[CapitalGamma]", "(", "z", ")"}], ")"}], 
        TraditionalForm]]],
  " as a multivalued analytic function, except that it is conventionally \
defined with a different branch cut structure and principal sheet. The log\
\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " was introduced by J. Keiper (1990) for ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"],
  "   It allows a concise formulation of many identities related to the \
Riemann zeta function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Zeta]", "(", "z", ")"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The importance of the gamma function and its Euler integral stimulated \
some mathematicians to study incomplete Euler integrals which are actually \
equal to the indefinite integral of the expression ",
  Cell[BoxData[
      FormBox[
        FormBox[
          RowBox[{
            SuperscriptBox["\[Tau]", "n"], " ", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", "\[Tau]"}]]}],
          "TraditionalForm"], TraditionalForm]]],
  ". They were introduced in article by A. M. Legendre (1811). Later, P. Schl\
\[ODoubleDot]milch (1871) introduced the name \"incomplete gamma function\" \
for such an integral. These functions were investigated by J. Tannery (1882), \
F. E. Prym (1877), and M. Lerch (1905) (who gave a series representation for \
the incomplete gamma function). N. Nielsen (1906) and other mathematicians \
also had a special interest in these functions, which were included in the \
main handbooks of special functions and current computer systems like ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "Needs of computer systems lead to implementation of slightly more general \
incomplete gamma functions and their regularized and inverse versions. In \
addition to the classical  gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " includes the following related set of gamma functions: incomplete gamma \
function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", generalized incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", regularized incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", generalized regularized incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ",  inverse of the regularized incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", and inverse of the generalized regularized incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definitions of gamma functions", "Subsection"],

Cell[TextData[{
  "The gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", the incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", the generalized incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", the regularized incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", the generalized regularized incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", the log\[Hyphen]gamma function (almost equal to the logarithm of the \
gamma function) ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", the inverse of the regularized incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", and the inverse of the generalized regularized incomplete gamma function \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " are defined by the following formulas:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "z", ")"}], "\[Equal]", 
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{
              RowBox[{
                SuperscriptBox["t", 
                  RowBox[{"z", "-", "1"}]], " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", "t"}]]}], 
              RowBox[{"\[DifferentialD]", "t"}]}]}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "z", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox["\[Integral]", "1", "\[Infinity]"], 
            RowBox[{
              RowBox[{
                SuperscriptBox["t", 
                  RowBox[{"z", "-", "1"}]], " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", "t"}]]}], 
              RowBox[{"\[DifferentialD]", "t"}]}]}], "+", 
          RowBox[{
            UnderoverscriptBox["\[Sum]", 
              RowBox[{"k", "=", "0"}], "\[Infinity]"], 
            FractionBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "k"], 
              RowBox[{
                RowBox[{"k", "!"}], " ", 
                RowBox[{"(", 
                  RowBox[{"k", "+", "z"}], ")"}]}]]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          SubsuperscriptBox["\[Integral]", "z", "\[Infinity]"], 
          RowBox[{
            RowBox[{
              SuperscriptBox["t", 
                RowBox[{"a", "-", "1"}]], " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "t"}]]}], 
            RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          SubsuperscriptBox["\[Integral]", 
            SubscriptBox["z", "1"], 
            SubscriptBox["z", "2"]], 
          RowBox[{
            RowBox[{
              SuperscriptBox["t", 
                RowBox[{"a", "-", "1"}]], " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "t"}]]}], 
            RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        FractionBox[
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}], 
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        FractionBox[
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], 
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          RowBox[{"log\[CapitalGamma]", 
            RowBox[{"(", "z", ")"}]}],
          ScriptLevel->0], "\[Equal]", 
        RowBox[{
          RowBox[{
            UnderoverscriptBox["\[Sum]", 
              RowBox[{"k", "=", "1"}], "\[Infinity]"], 
            RowBox[{"(", 
              RowBox[{
                FractionBox["z", "k"], "-", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "+", 
                    FractionBox["z", "k"]}], ")"}]}], ")"}]}], "-", 
          RowBox[{
            TagBox["\[DoubledGamma]",
              (EulerGamma&)], " ", "z"}], "-", 
          RowBox[{
            RowBox[{"log", "(", "z", ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  StyleBox["The function ", "Text"],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]], 
    "Text"], "Text"],
  StyleBox[" is equivalent to ", "Text"],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{"log", "(", 
          RowBox[{"\[CapitalGamma]", "(", "z", ")"}], ")"}], 
        TraditionalForm]], "Text"], "Text"],
  StyleBox[" as a multivalued analytic function, except that it is \
conventionally defined with a different branch cut structure and principal \
sheet. The function ", "Text"],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]], 
    "Text"], "Text"],
  StyleBox[" allows a concise formulation of many identities related to the \
Riemann zeta function ", "Text"],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{"\[Zeta]", "(", "z", ")"}], TraditionalForm]], "Text"], 
    "Text"],
  StyleBox[".", "Text"]
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"z", "\[Equal]", 
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "w"}], ")"}]}], "/;", 
        RowBox[{"w", "\[Equal]", 
          RowBox[{
            SuperscriptBox[
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], 
              RowBox[{"-", "1"}]], "(", 
            RowBox[{"a", ",", "z"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["z", "2"], "\[Equal]", 
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", "w"}], ")"}]}], "/;", 
        RowBox[{"w", "\[Equal]", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell["\<\
The above functions are an interconnected group that can be called \
the gamma functions.\
\>", "Text"],

Cell["\<\
Instead of the first three above classical definitions using \
definite integrals, the other equivalent definitions with infinite series can \
be used.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["A quick look at the gamma functions", "Subsection"],

Cell[TextData[{
  "Here is a quick look at graphics for the gamma function and the function \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " along the real axis. The real parts are shown in red and the imaginary \
parts are shown in blue."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.25 0.0412541 [
[.11905 -0.0125 -8.3125 -11.1875 ]
[.11905 -0.0125 8.3125 0 ]
[.30952 -0.0125 -8.5 -11.1875 ]
[.30952 -0.0125 8.5 0 ]
[.5 -0.0125 -5.03125 -11.1875 ]
[.5 -0.0125 5.03125 0 ]
[.69048 -0.0125 -5.0625 -11.1875 ]
[.69048 -0.0125 5.0625 0 ]
[.88095 -0.0125 -4.875 -11.1875 ]
[.88095 -0.0125 4.875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.96875 -22.375 ]
[.5 -0.0125 4.96875 -11.1875 ]
[-0.0125 .00248 -17 -5.59375 ]
[-0.0125 .00248 0 5.59375 ]
[-0.0125 .08498 -16.625 -5.59375 ]
[-0.0125 .08498 0 5.59375 ]
[-0.0125 .16749 -17 -5.59375 ]
[-0.0125 .16749 0 5.59375 ]
[-0.0125 .25 -10.0625 -5.59375 ]
[-0.0125 .25 0 5.59375 ]
[-0.0125 .33251 -10.125 -5.59375 ]
[-0.0125 .33251 0 5.59375 ]
[-0.0125 .41502 -9.75 -5.59375 ]
[-0.0125 .41502 0 5.59375 ]
[-0.0125 .49752 -10.125 -5.59375 ]
[-0.0125 .49752 0 5.59375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .25 -28.3125 -4.0625 ]
[-0.01875 .25 -17 4.0625 ]
[ 0 .5 .125 0 ]
[ 1 0 .125 0 ]
[.5 .5125 -10.9688 0 ]
[.5 .5125 10.9688 11.1875 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
gsave
.11905 -0.0125 -69.3125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.30952 0 m
.30952 .00625 L
s
gsave
.30952 -0.0125 -69.5 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.0312 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.69048 0 m
.69048 .00625 L
s
gsave
.69048 -0.0125 -66.0625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.88095 0 m
.88095 .00625 L
s
gsave
.88095 -0.0125 -65.875 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9688 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 .00248 m
.00625 .00248 L
s
gsave
-0.0125 .00248 -78 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .08498 m
.00625 .08498 L
s
gsave
-0.0125 .08498 -77.625 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .16749 m
.00625 .16749 L
s
gsave
-0.0125 .16749 -78 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .25 m
.00625 .25 L
s
gsave
-0.0125 .25 -71.0625 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .33251 m
.00625 .33251 L
s
gsave
-0.0125 .33251 -71.125 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .41502 m
.00625 .41502 L
s
gsave
-0.0125 .41502 -70.75 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .49752 m
.00625 .49752 L
s
gsave
-0.0125 .49752 -71.125 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0231 m
.00375 .0231 L
s
0 .04373 m
.00375 .04373 L
s
0 .06436 m
.00375 .06436 L
s
0 .10561 m
.00375 .10561 L
s
0 .12624 m
.00375 .12624 L
s
0 .14686 m
.00375 .14686 L
s
0 .18812 m
.00375 .18812 L
s
0 .20875 m
.00375 .20875 L
s
0 .22937 m
.00375 .22937 L
s
0 .27063 m
.00375 .27063 L
s
0 .29125 m
.00375 .29125 L
s
0 .31188 m
.00375 .31188 L
s
0 .35314 m
.00375 .35314 L
s
0 .37376 m
.00375 .37376 L
s
0 .39439 m
.00375 .39439 L
s
0 .43564 m
.00375 .43564 L
s
0 .45627 m
.00375 .45627 L
s
0 .4769 m
.00375 .4769 L
s
.25 Mabswid
0 0 m
0 .5 L
s
gsave
-0.01875 .25 -87.7188 -9.65625 Mabsadd m
1 1 Mabs scale
currentpoint translate
65.0625 9.65625 translate
90 rotate
-65.0625 -9.65625 translate
0 19.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
1.000 setlinewidth
grestore
0 .5 m
1 .5 L
s
1 0 m
1 .5 L
s
0 .25 m
1 .25 L
s
.5 0 m
.5 .5 L
s
gsave
.5 .5125 -71.9688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.875 12.125 moveto
(H) show
72.062 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
77.750 12.125 moveto
(L) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.002 w
.02394 0 m
.02395 .00893 L
.02396 .03053 L
.02397 .04761 L
.024 .0733 L
.02402 .09392 L
.02405 .11104 L
.02409 .13382 L
.02414 .15122 L
.0242 .16515 L
.02425 .1746 L
.02429 .18154 L
.02439 .19325 L
.02448 .20088 L
.02458 .20714 L
.02468 .21176 L
.02478 .21568 L
.02496 .22099 L
.02516 .22507 L
.02534 .22802 L
.02554 .23046 L
.02573 .23234 L
.02591 .23382 L
.02611 .23514 L
.0263 .23622 L
.0265 .23719 L
.02669 .23801 L
.02687 .23869 L
.02707 .23933 L
.02726 .23988 L
.02744 .24036 L
.02764 .24081 L
.02782 .24121 L
.02802 .24159 L
.02821 .24193 L
.0284 .24222 L
.02859 .24251 L
.02878 .24277 L
.02898 .24302 L
.02917 .24325 L
.02936 .24345 L
.02956 .24365 L
.02975 .24383 L
.02993 .24399 L
.03012 .24415 L
.03031 .2443 L
.03051 .24445 L
.0307 .24458 L
.03089 .2447 L
.03108 .24483 L
Mistroke
.03127 .24494 L
.03145 .24504 L
.03165 .24514 L
.03183 .24524 L
.03203 .24533 L
.03222 .24542 L
.03241 .2455 L
.0326 .24558 L
.03279 .24566 L
.03299 .24573 L
.03318 .24581 L
.03337 .24587 L
.03356 .24594 L
.03375 .246 L
.03394 .24606 L
.03413 .24611 L
.03432 .24617 L
.03452 .24622 L
.03471 .24627 L
.03489 .24632 L
.03509 .24637 L
.03528 .24641 L
.03546 .24646 L
.03565 .2465 L
.03584 .24654 L
.03604 .24658 L
.03623 .24662 L
.03641 .24665 L
.0366 .24669 L
.03679 .24672 L
.03699 .24676 L
.03718 .24679 L
.03737 .24682 L
.03756 .24685 L
.03775 .24688 L
.03794 .24691 L
.03813 .24694 L
.03832 .24696 L
.03852 .24699 L
.03871 .24702 L
.03889 .24704 L
.03909 .24707 L
.03927 .24709 L
.03947 .24711 L
.03967 .24714 L
.03985 .24716 L
.04005 .24718 L
.04024 .2472 L
.04042 .24722 L
.04062 .24724 L
Mistroke
.0408 .24725 L
.041 .24727 L
.04119 .24729 L
.04138 .24731 L
.04158 .24732 L
.04176 .24734 L
.04195 .24736 L
.04214 .24737 L
.04233 .24739 L
.04252 .2474 L
.04271 .24741 L
.0429 .24743 L
.04309 .24744 L
.04328 .24745 L
.04348 .24747 L
.04367 .24748 L
.04386 .24749 L
.04405 .2475 L
.04424 .24752 L
.04443 .24753 L
.04462 .24754 L
.04481 .24755 L
.04501 .24756 L
.0452 .24757 L
.04538 .24758 L
.04558 .24759 L
.04577 .2476 L
.04597 .24761 L
.04616 .24761 L
.04635 .24762 L
.04654 .24763 L
.04673 .24764 L
.04692 .24765 L
.04711 .24765 L
.0473 .24766 L
.0475 .24767 L
.04769 .24768 L
.04787 .24768 L
.04807 .24769 L
.04826 .2477 L
.04844 .2477 L
.04864 .24771 L
.04882 .24771 L
.04902 .24772 L
.04921 .24772 L
.04939 .24773 L
.04959 .24773 L
.04978 .24774 L
.04998 .24774 L
.05017 .24775 L
Mistroke
.05036 .24775 L
.05055 .24776 L
.05074 .24776 L
.05093 .24777 L
.05112 .24777 L
.05131 .24777 L
.05151 .24778 L
.0517 .24778 L
.05188 .24778 L
.05208 .24779 L
.05227 .24779 L
.05245 .24779 L
.05264 .24779 L
.05283 .2478 L
.05303 .2478 L
.05322 .2478 L
.0534 .2478 L
.05359 .24781 L
.05378 .24781 L
.05398 .24781 L
.05417 .24781 L
.05436 .24781 L
.05456 .24781 L
.05475 .24782 L
.05493 .24782 L
.05512 .24782 L
.05531 .24782 L
.05551 .24782 L
.0557 .24782 L
.05588 .24782 L
.05608 .24782 L
.05627 .24782 L
.05636 .24782 L
.05647 .24782 L
.05651 .24782 L
.05657 .24782 L
.05661 .24782 L
.05666 .24782 L
.0567 .24782 L
.05673 .24782 L
.05675 .24782 L
.05676 .24782 L
.05678 .24782 L
.05678 .24782 L
.0568 .24782 L
.0568 .24782 L
.05681 .24782 L
.05681 .24782 L
.05682 .24782 L
.05682 .24782 L
Mistroke
.05683 .24782 L
.05683 .24782 L
.05684 .24782 L
.05684 .24782 L
.05685 .24782 L
.05685 .24782 L
.05686 .24782 L
.05686 .24782 L
.05688 .24782 L
.05689 .24782 L
.05691 .24782 L
.05693 .24782 L
.05698 .24782 L
.05703 .24782 L
.05708 .24782 L
.05713 .24782 L
.05723 .24782 L
.05732 .24782 L
.05742 .24782 L
.05762 .24782 L
.05781 .24782 L
.05799 .24782 L
.05819 .24782 L
.05838 .24782 L
.05858 .24782 L
.05877 .24782 L
.05895 .24782 L
.05915 .24781 L
.05934 .24781 L
.05952 .24781 L
.05971 .24781 L
.0599 .24781 L
.0601 .24781 L
.06029 .24781 L
.06047 .2478 L
.06067 .2478 L
.06086 .2478 L
.06106 .2478 L
.06125 .24779 L
.06144 .24779 L
.06163 .24779 L
.06182 .24779 L
.06201 .24778 L
.0622 .24778 L
.06239 .24778 L
.06259 .24778 L
.06278 .24777 L
.06296 .24777 L
.06316 .24777 L
.06335 .24776 L
Mistroke
.06353 .24776 L
.06372 .24776 L
.06391 .24775 L
.06411 .24775 L
.0643 .24774 L
.06448 .24774 L
.06468 .24774 L
.06486 .24773 L
.06506 .24773 L
.06526 .24772 L
.06544 .24772 L
.06564 .24771 L
.06583 .24771 L
.06601 .2477 L
.0662 .2477 L
.06639 .2477 L
.06659 .24769 L
.06678 .24768 L
.06696 .24768 L
.06716 .24767 L
.06735 .24767 L
.06755 .24766 L
.06774 .24766 L
.06793 .24765 L
.06812 .24764 L
.06831 .24764 L
.0685 .24763 L
.06869 .24763 L
.06888 .24762 L
.06908 .24761 L
.06927 .24761 L
.06946 .2476 L
.06965 .24759 L
.06984 .24759 L
.07002 .24758 L
.07022 .24757 L
.0704 .24757 L
.0706 .24756 L
.07079 .24755 L
.07098 .24754 L
.07117 .24753 L
.07136 .24753 L
.07156 .24752 L
.07175 .24751 L
.07194 .2475 L
.07213 .24749 L
.07232 .24749 L
.07251 .24748 L
.0727 .24747 L
.07289 .24746 L
Mistroke
.07309 .24745 L
.07328 .24744 L
.07346 .24743 L
.07366 .24742 L
.07385 .24741 L
.07403 .2474 L
.07422 .24739 L
.07441 .24738 L
.07461 .24737 L
.0748 .24736 L
.07498 .24735 L
.07517 .24734 L
.07536 .24733 L
.07556 .24732 L
.07575 .24731 L
.07594 .2473 L
.07613 .24729 L
.07632 .24728 L
.07651 .24726 L
.0767 .24725 L
.07689 .24724 L
.07709 .24723 L
.07728 .24722 L
.07746 .2472 L
.07766 .24719 L
.07784 .24718 L
.07804 .24716 L
.07824 .24715 L
.07842 .24714 L
.07862 .24712 L
.07881 .24711 L
.07899 .2471 L
.07919 .24708 L
.07937 .24707 L
.07957 .24705 L
.07977 .24704 L
.07995 .24703 L
.08015 .24701 L
.08034 .247 L
.08052 .24698 L
.08071 .24696 L
.0809 .24695 L
.08109 .24693 L
.08129 .24692 L
.08147 .2469 L
.08166 .24688 L
.08185 .24687 L
.08205 .24685 L
.08224 .24683 L
.08243 .24681 L
Mistroke
.08263 .2468 L
.08282 .24678 L
.083 .24676 L
.08319 .24674 L
.08338 .24672 L
.08358 .2467 L
.08377 .24668 L
.08395 .24666 L
.08415 .24664 L
.08434 .24662 L
.08454 .2466 L
.08473 .24658 L
.08492 .24656 L
.08511 .24654 L
.0853 .24652 L
.08549 .2465 L
.08568 .24647 L
.08587 .24645 L
.08607 .24643 L
.08626 .2464 L
.08645 .24638 L
.08664 .24636 L
.08683 .24633 L
.08701 .24631 L
.08721 .24628 L
.08739 .24626 L
.08759 .24623 L
.08778 .24621 L
.08797 .24618 L
.08816 .24615 L
.08835 .24613 L
.08855 .2461 L
.08874 .24607 L
.08893 .24604 L
.08913 .24601 L
.08932 .24598 L
.0895 .24595 L
.08969 .24592 L
.08988 .24589 L
.09008 .24586 L
.09027 .24583 L
.09045 .2458 L
.09065 .24576 L
.09084 .24573 L
.09102 .2457 L
.09121 .24566 L
.0914 .24563 L
.0916 .24559 L
.09179 .24556 L
.09197 .24552 L
Mistroke
.09217 .24548 L
.09236 .24545 L
.09255 .24541 L
.09275 .24537 L
.09293 .24533 L
.09313 .24529 L
.09332 .24525 L
.0935 .24521 L
.09369 .24516 L
.09388 .24512 L
.09408 .24508 L
.09427 .24503 L
.09445 .24499 L
.09465 .24494 L
.09484 .2449 L
.09504 .24485 L
.09523 .2448 L
.09542 .24475 L
.09562 .2447 L
.09581 .24465 L
.09599 .2446 L
.09618 .24454 L
.09637 .24449 L
.09657 .24443 L
.09676 .24437 L
.09695 .24432 L
.09714 .24426 L
.09733 .2442 L
.09751 .24414 L
.09771 .24408 L
.09789 .24402 L
.09809 .24395 L
.09828 .24389 L
.09847 .24382 L
.09866 .24375 L
.09885 .24368 L
.09905 .24361 L
.09924 .24354 L
.09943 .24346 L
.09962 .24339 L
.09981 .24331 L
.1 .24323 L
.10019 .24315 L
.10038 .24307 L
.10058 .24298 L
.10077 .2429 L
.10095 .24281 L
.10115 .24272 L
.10134 .24263 L
.10152 .24254 L
Mistroke
.10171 .24244 L
.1019 .24235 L
.10209 .24224 L
.10228 .24214 L
.10247 .24204 L
.10266 .24193 L
.10285 .24182 L
.10305 .2417 L
.10324 .24158 L
.10343 .24147 L
.10362 .24134 L
.10381 .24121 L
.10399 .24109 L
.10419 .24096 L
.10437 .24082 L
.10457 .24068 L
.10476 .24053 L
.10495 .24039 L
.10514 .24023 L
.10533 .24008 L
.10553 .23991 L
.10572 .23974 L
.10591 .23957 L
.10611 .23939 L
.1063 .23921 L
.10648 .23903 L
.10667 .23883 L
.10686 .23864 L
.10706 .23842 L
.10725 .23821 L
.10744 .23799 L
.10763 .23776 L
.10782 .23752 L
.108 .23729 L
.1082 .23703 L
.10838 .23678 L
.10858 .2365 L
.10877 .23621 L
.10896 .23593 L
.10915 .23562 L
.10934 .23531 L
.10954 .23496 L
.10973 .23461 L
.10992 .23426 L
.11011 .23388 L
.1103 .23349 L
.11048 .2331 L
.11068 .23266 L
.11086 .23222 L
.11106 .23173 L
Mistroke
.11125 .23124 L
.11144 .23074 L
.11163 .23018 L
.11182 .22961 L
.11202 .22897 L
.11222 .22832 L
.1124 .22766 L
.1126 .22691 L
.11279 .22615 L
.11297 .22537 L
.11317 .22448 L
.11336 .22357 L
.11355 .22254 L
.11375 .22147 L
.11393 .22036 L
.11413 .21909 L
.11432 .21777 L
.1145 .21639 L
.11469 .2148 L
.11488 .21313 L
.11508 .21118 L
.11527 .2091 L
.11545 .2069 L
.11565 .20429 L
.11583 .20148 L
.11603 .19811 L
.11623 .19441 L
.11641 .19033 L
.11661 .18532 L
.1168 .17966 L
.11698 .17323 L
.11718 .165 L
.11736 .15529 L
.11756 .14229 L
.11775 .12597 L
.11794 .10496 L
.11803 .09143 L
.11813 .07328 L
.11823 .05162 L
.11832 .02658 L
Mfstroke
.11832 .02658 m
.1184 0 L
s
.11971 .5 m
.11972 .49523 L
.11982 .46396 L
.11992 .44086 L
.12002 .42127 L
.1202 .39471 L
.12039 .37431 L
.12058 .35954 L
.12078 .34732 L
.12097 .33794 L
.12115 .33052 L
.12135 .32392 L
.12153 .31855 L
.12173 .31367 L
.12193 .30961 L
.12211 .30618 L
.12231 .30297 L
.1225 .30022 L
.12268 .29785 L
.12287 .29557 L
.12306 .29359 L
.12326 .29168 L
.12345 .29 L
.12363 .28852 L
.12383 .28707 L
.12402 .28578 L
.12422 .28451 L
.12441 .28339 L
.1246 .28237 L
.12479 .28137 L
.12498 .28047 L
.12517 .27966 L
.12536 .27884 L
.12555 .27811 L
.12575 .27737 L
.12594 .2767 L
.12613 .27609 L
.12632 .27548 L
.12651 .27492 L
.12669 .27441 L
.12689 .27389 L
.12707 .27341 L
.12727 .27293 L
.12746 .27249 L
.12764 .27209 L
.12784 .27168 L
.12803 .2713 L
.12823 .27092 L
.12842 .27056 L
.12861 .27023 L
Mistroke
.1288 .2699 L
.12899 .26959 L
.12918 .26931 L
.12937 .26901 L
.12956 .26874 L
.12976 .26847 L
.12995 .26821 L
.13013 .26797 L
.13033 .26773 L
.13052 .2675 L
.1307 .26729 L
.13089 .26707 L
.13108 .26687 L
.13127 .26666 L
.13146 .26647 L
.13165 .26629 L
.13184 .26611 L
.13203 .26593 L
.13223 .26576 L
.13242 .26559 L
.13261 .26544 L
.1328 .26528 L
.13299 .26513 L
.13317 .26499 L
.13337 .26485 L
.13355 .26471 L
.13375 .26457 L
.13394 .26445 L
.13413 .26432 L
.13432 .2642 L
.13451 .26408 L
.13471 .26396 L
.1349 .26385 L
.13509 .26374 L
.13529 .26363 L
.13548 .26353 L
.13566 .26343 L
.13585 .26333 L
.13604 .26324 L
.13624 .26314 L
.13643 .26305 L
.13662 .26297 L
.13681 .26288 L
.137 .2628 L
.13718 .26272 L
.13738 .26264 L
.13756 .26257 L
.13776 .26249 L
.13795 .26241 L
.13814 .26235 L
Mistroke
.13833 .26227 L
.13852 .26221 L
.13872 .26214 L
.13891 .26207 L
.1391 .26201 L
.13929 .26195 L
.13948 .26189 L
.13966 .26183 L
.13986 .26178 L
.14005 .26172 L
.14024 .26167 L
.14044 .26161 L
.14062 .26156 L
.14082 .26151 L
.141 .26146 L
.1412 .26141 L
.1414 .26137 L
.14158 .26132 L
.14178 .26128 L
.14197 .26124 L
.14215 .2612 L
.14235 .26115 L
.14254 .26111 L
.14274 .26107 L
.14293 .26104 L
.14311 .261 L
.14331 .26096 L
.1435 .26093 L
.14368 .2609 L
.14387 .26086 L
.14406 .26083 L
.14426 .2608 L
.14445 .26077 L
.14463 .26074 L
.14483 .26071 L
.14502 .26069 L
.14522 .26066 L
.14541 .26063 L
.14559 .26061 L
.14579 .26058 L
.14598 .26056 L
.14616 .26053 L
.14636 .26051 L
.14655 .26049 L
.14674 .26047 L
.14694 .26045 L
.14712 .26043 L
.14732 .26041 L
.14751 .26039 L
.14769 .26038 L
Mistroke
.14788 .26036 L
.14807 .26034 L
.14826 .26033 L
.14845 .26031 L
.14864 .2603 L
.14883 .26028 L
.14902 .26027 L
.14922 .26026 L
.14941 .26024 L
.1496 .26023 L
.14979 .26022 L
.14998 .26021 L
.15017 .2602 L
.15036 .26019 L
.15055 .26018 L
.15074 .26017 L
.15094 .26017 L
.15112 .26016 L
.15132 .26015 L
.1515 .26015 L
.1517 .26014 L
.1519 .26014 L
.15208 .26013 L
.15228 .26013 L
.15247 .26012 L
.15265 .26012 L
.15285 .26012 L
.15303 .26012 L
.15313 .26012 L
.15323 .26011 L
.15332 .26011 L
.15343 .26011 L
.15352 .26011 L
.15357 .26011 L
.15362 .26011 L
.15367 .26011 L
.15369 .26011 L
.15371 .26011 L
.15372 .26011 L
.15373 .26011 L
.15374 .26011 L
.15375 .26011 L
.15375 .26011 L
.15376 .26011 L
.15377 .26011 L
.15377 .26011 L
.15378 .26011 L
.15378 .26011 L
.15379 .26011 L
.15379 .26011 L
Mistroke
.1538 .26011 L
.1538 .26011 L
.15381 .26011 L
.15382 .26011 L
.15383 .26011 L
.15385 .26011 L
.15388 .26011 L
.1539 .26011 L
.15394 .26011 L
.154 .26011 L
.15409 .26011 L
.15419 .26011 L
.15439 .26011 L
.15458 .26012 L
.15477 .26012 L
.15496 .26012 L
.15515 .26012 L
.15534 .26013 L
.15553 .26013 L
.15572 .26014 L
.15591 .26014 L
.15611 .26015 L
.15629 .26015 L
.15648 .26016 L
.15667 .26017 L
.15687 .26017 L
.15707 .26018 L
.15725 .26019 L
.15745 .2602 L
.15764 .26021 L
.15782 .26022 L
.15802 .26023 L
.1582 .26024 L
.1584 .26025 L
.15859 .26026 L
.15878 .26027 L
.15897 .26028 L
.15916 .26029 L
.15934 .26031 L
.15954 .26032 L
.15972 .26033 L
.15992 .26035 L
.16011 .26036 L
.1603 .26038 L
.16049 .26039 L
.16068 .26041 L
.16088 .26043 L
.16107 .26044 L
.16126 .26046 L
.16145 .26048 L
Mistroke
.16164 .2605 L
.16182 .26051 L
.16202 .26053 L
.16221 .26055 L
.1624 .26057 L
.16259 .26059 L
.16278 .26061 L
.16297 .26064 L
.16316 .26066 L
.16336 .26068 L
.16356 .2607 L
.16374 .26073 L
.16394 .26075 L
.16413 .26077 L
.16431 .2608 L
.16451 .26082 L
.16469 .26085 L
.16489 .26088 L
.16509 .2609 L
.16527 .26093 L
.16547 .26096 L
.16566 .26099 L
.16584 .26101 L
.16603 .26104 L
.16622 .26107 L
.16642 .2611 L
.16661 .26113 L
.16679 .26116 L
.16699 .26119 L
.16717 .26123 L
.16737 .26126 L
.16757 .26129 L
.16775 .26133 L
.16795 .26136 L
.16814 .2614 L
.16832 .26143 L
.16852 .26147 L
.1687 .2615 L
.1689 .26154 L
.16909 .26158 L
.16928 .26162 L
.16947 .26166 L
.16966 .2617 L
.16984 .26173 L
.17004 .26177 L
.17022 .26181 L
.17042 .26186 L
.17061 .2619 L
.17079 .26194 L
.17099 .26199 L
Mistroke
.17118 .26203 L
.17138 .26208 L
.17157 .26212 L
.17175 .26217 L
.17195 .26222 L
.17214 .26226 L
.17232 .26231 L
.17252 .26236 L
.1727 .26241 L
.1729 .26246 L
.17309 .26251 L
.17328 .26256 L
.17347 .26261 L
.17366 .26267 L
.17386 .26272 L
.17405 .26278 L
.17424 .26283 L
.17443 .26289 L
.17463 .26295 L
.17481 .263 L
.175 .26306 L
.17519 .26312 L
.17539 .26318 L
.17558 .26324 L
.17576 .2633 L
.17596 .26337 L
.17615 .26343 L
.17633 .26349 L
.17653 .26356 L
.17671 .26362 L
.17691 .26369 L
.1771 .26376 L
.17728 .26383 L
.17748 .2639 L
.17767 .26397 L
.17787 .26404 L
.17806 .26412 L
.17824 .26419 L
.17844 .26427 L
.17863 .26434 L
.17881 .26442 L
.17901 .2645 L
.17919 .26457 L
.17939 .26466 L
.17958 .26474 L
.17977 .26482 L
.17996 .2649 L
.18015 .26499 L
.18035 .26508 L
.18055 .26517 L
Mistroke
.18073 .26525 L
.18093 .26535 L
.18112 .26544 L
.1813 .26553 L
.1815 .26562 L
.18169 .26572 L
.18188 .26582 L
.18208 .26592 L
.18226 .26601 L
.18246 .26612 L
.18265 .26622 L
.18283 .26632 L
.18302 .26642 L
.18321 .26653 L
.18341 .26664 L
.1836 .26675 L
.18378 .26686 L
.18398 .26698 L
.18417 .26709 L
.18437 .26721 L
.18456 .26733 L
.18474 .26745 L
.18494 .26758 L
.18513 .2677 L
.18531 .26782 L
.18551 .26795 L
.18569 .26808 L
.18589 .26822 L
.18609 .26835 L
.18627 .26848 L
.18647 .26862 L
.18665 .26876 L
.18684 .2689 L
.18703 .26905 L
.18722 .26919 L
.18741 .26934 L
.1876 .2695 L
.18779 .26965 L
.18798 .26981 L
.18817 .26996 L
.18837 .27013 L
.18856 .2703 L
.18875 .27046 L
.18894 .27064 L
.18913 .27081 L
.18932 .27098 L
.18951 .27116 L
.1897 .27134 L
.18989 .27154 L
.19009 .27172 L
Mistroke
.19027 .27191 L
.19047 .27211 L
.19065 .27231 L
.19085 .27252 L
.19105 .27273 L
.19123 .27294 L
.19143 .27316 L
.19162 .27338 L
.1918 .27359 L
.192 .27382 L
.19219 .27405 L
.19238 .27429 L
.19258 .27453 L
.19276 .27477 L
.19296 .27503 L
.19315 .27528 L
.19333 .27553 L
.19352 .27579 L
.19371 .27606 L
.19391 .27634 L
.1941 .27662 L
.19428 .2769 L
.19448 .2772 L
.19466 .27749 L
.19486 .27781 L
.19506 .27812 L
.19524 .27843 L
.19544 .27877 L
.19563 .2791 L
.19581 .27942 L
.196 .27977 L
.19619 .28012 L
.19639 .2805 L
.19658 .28087 L
.19677 .28124 L
.19696 .28163 L
.19715 .28203 L
.19733 .28241 L
.19753 .28283 L
.19771 .28325 L
.19791 .2837 L
.1981 .28415 L
.19828 .28459 L
.19848 .28507 L
.19866 .28554 L
.19886 .28606 L
.19906 .28657 L
.19924 .28707 L
.19944 .28762 L
.19963 .28817 L
Mistroke
.19981 .28871 L
.2 .28929 L
.20019 .28988 L
.20039 .29051 L
.20058 .29115 L
.20076 .29177 L
.20096 .29246 L
.20115 .29313 L
.20135 .29388 L
.20154 .29462 L
.20173 .29535 L
.20192 .29616 L
.20211 .29696 L
.20229 .29775 L
.20249 .29863 L
.20268 .2995 L
.20288 .30046 L
.20307 .30141 L
.20325 .30236 L
.20345 .30341 L
.20364 .30446 L
.20382 .3055 L
.20401 .30665 L
.2042 .3078 L
.2044 .30907 L
.20459 .31035 L
.20477 .31162 L
.20497 .31304 L
.20515 .31445 L
.20535 .31603 L
.20555 .31762 L
.20573 .31921 L
.20593 .32099 L
.20612 .32278 L
.2063 .32458 L
.20649 .32659 L
.20668 .32863 L
.20688 .33091 L
.20707 .33323 L
.20725 .33558 L
.20745 .33821 L
.20764 .3409 L
.20784 .34394 L
.20803 .34704 L
.20822 .35022 L
.20841 .35382 L
.20861 .35753 L
.20879 .36134 L
.20898 .36568 L
.20917 .37018 L
Mistroke
.20937 .37534 L
.20956 .38072 L
.20975 .38633 L
.20994 .39283 L
.21013 .39967 L
.21031 .40686 L
.21051 .41528 L
.21069 .42424 L
.21089 .43486 L
.21108 .44633 L
.21127 .45873 L
.21146 .47371 L
.21165 .49023 L
Mfstroke
.21165 .49023 m
.21175 .5 L
s
.21701 0 m
.21716 .01337 L
.21735 .02707 L
.21755 .03994 L
.21774 .05094 L
.21792 .06044 L
.21811 .06955 L
.2183 .07748 L
.2185 .08513 L
.21869 .09185 L
.21887 .09779 L
.21907 .1036 L
.21926 .10875 L
.21946 .11382 L
.21965 .11834 L
.21983 .12239 L
.22003 .12641 L
.22022 .13002 L
.22041 .13328 L
.2206 .13654 L
.22079 .1395 L
.22099 .14245 L
.22118 .14514 L
.22136 .14758 L
.22156 .15004 L
.22175 .15228 L
.22193 .15433 L
.22212 .15641 L
.22231 .15831 L
.22251 .16024 L
.2227 .16201 L
.22288 .16363 L
.22308 .16529 L
.22327 .16681 L
.22347 .16836 L
.22366 .16978 L
.22384 .1711 L
.22404 .17244 L
.22423 .17368 L
.22441 .17483 L
.22461 .17601 L
.22479 .1771 L
.22499 .17821 L
.22518 .17925 L
.22537 .18021 L
.22556 .18119 L
.22575 .18211 L
.22594 .18296 L
.22613 .18383 L
.22631 .18465 L
Mistroke
.22651 .18548 L
.2267 .18626 L
.22689 .18699 L
.22708 .18774 L
.22727 .18844 L
.22747 .18915 L
.22766 .18982 L
.22784 .19045 L
.22804 .1911 L
.22823 .1917 L
.22841 .19226 L
.22861 .19285 L
.22879 .19339 L
.22899 .19395 L
.22918 .19448 L
.22937 .19497 L
.22956 .19548 L
.22975 .19596 L
.22995 .19645 L
.23014 .19691 L
.23033 .19735 L
.23053 .19779 L
.23072 .19821 L
.2309 .19861 L
.23109 .19902 L
.23128 .1994 L
.23148 .1998 L
.23167 .20017 L
.23186 .20052 L
.23205 .20088 L
.23224 .20122 L
.23242 .20154 L
.23262 .20187 L
.2328 .20218 L
.233 .2025 L
.23319 .20281 L
.23337 .20309 L
.23357 .20339 L
.23376 .20366 L
.23396 .20395 L
.23415 .20422 L
.23433 .20448 L
.23453 .20474 L
.23472 .20499 L
.2349 .20522 L
.2351 .20547 L
.23528 .20569 L
.23548 .20593 L
.23567 .20615 L
.23586 .20636 L
Mistroke
.23605 .20658 L
.23624 .20678 L
.23644 .207 L
.23664 .2072 L
.23682 .20738 L
.23702 .20758 L
.23721 .20776 L
.23739 .20793 L
.23759 .20811 L
.23777 .20828 L
.23797 .20846 L
.23817 .20862 L
.23835 .20877 L
.23855 .20893 L
.23874 .20909 L
.23892 .20923 L
.23911 .20937 L
.2393 .20951 L
.2395 .20966 L
.23969 .20979 L
.23987 .20992 L
.24007 .21005 L
.24025 .21017 L
.24045 .2103 L
.24065 .21042 L
.24083 .21053 L
.24103 .21065 L
.24122 .21076 L
.2414 .21086 L
.2416 .21097 L
.24178 .21107 L
.24198 .21117 L
.24217 .21127 L
.24236 .21136 L
.24255 .21145 L
.24274 .21154 L
.24292 .21162 L
.24312 .2117 L
.2433 .21178 L
.2435 .21187 L
.24369 .21194 L
.24388 .21201 L
.24407 .21209 L
.24426 .21216 L
.24446 .21223 L
.24465 .21229 L
.24484 .21235 L
.24503 .21242 L
.24522 .21247 L
.2454 .21253 L
Mistroke
.2456 .21258 L
.24578 .21264 L
.24598 .21269 L
.24617 .21274 L
.24636 .21278 L
.24655 .21283 L
.24674 .21287 L
.24694 .21291 L
.24713 .21295 L
.24732 .21299 L
.24752 .21302 L
.24771 .21306 L
.24789 .21309 L
.24809 .21312 L
.24827 .21315 L
.24847 .21317 L
.24866 .2132 L
.24885 .21322 L
.24904 .21324 L
.24923 .21326 L
.24942 .21328 L
.24961 .21329 L
.2498 .21331 L
.24999 .21332 L
.25018 .21333 L
.25037 .21334 L
.25056 .21335 L
.25075 .21335 L
.25085 .21335 L
.25095 .21336 L
.25105 .21336 L
.2511 .21336 L
.25114 .21336 L
.25119 .21336 L
.25123 .21336 L
.25126 .21336 L
.25128 .21336 L
.25131 .21336 L
.25132 .21336 L
.25133 .21336 L
.25133 .21336 L
.25134 .21336 L
.25134 .21336 L
.25135 .21336 L
.25135 .21336 L
.25136 .21336 L
.25137 .21336 L
.25137 .21336 L
.25137 .21336 L
.25138 .21336 L
Mistroke
.25138 .21336 L
.25139 .21336 L
.2514 .21336 L
.25141 .21336 L
.25142 .21336 L
.25145 .21336 L
.25147 .21336 L
.25152 .21336 L
.25157 .21336 L
.25161 .21336 L
.25171 .21336 L
.25181 .21336 L
.2519 .21335 L
.25209 .21335 L
.25228 .21334 L
.25248 .21333 L
.25267 .21332 L
.25285 .21331 L
.25304 .2133 L
.25323 .21329 L
.25343 .21327 L
.25362 .21325 L
.25381 .21323 L
.254 .21321 L
.25419 .21319 L
.25437 .21317 L
.25457 .21314 L
.25475 .21311 L
.25495 .21308 L
.25514 .21306 L
.25532 .21302 L
.25552 .21299 L
.25571 .21296 L
.25591 .21292 L
.2561 .21288 L
.25628 .21284 L
.25648 .2128 L
.25667 .21276 L
.25685 .21272 L
.25705 .21267 L
.25723 .21263 L
.25743 .21258 L
.25762 .21253 L
.25781 .21248 L
.258 .21243 L
.25819 .21237 L
.25839 .21231 L
.25858 .21225 L
.25877 .2122 L
.25897 .21213 L
Mistroke
.25916 .21207 L
.25934 .21201 L
.25954 .21195 L
.25972 .21188 L
.25992 .21181 L
.26011 .21174 L
.2603 .21167 L
.26049 .21159 L
.26068 .21152 L
.26087 .21145 L
.26106 .21137 L
.26125 .21129 L
.26144 .21121 L
.26163 .21112 L
.26182 .21104 L
.26201 .21095 L
.2622 .21087 L
.2624 .21077 L
.26259 .21068 L
.26278 .21059 L
.26298 .21049 L
.26317 .21039 L
.26335 .2103 L
.26354 .2102 L
.26373 .2101 L
.26393 .20999 L
.26412 .20988 L
.2643 .20978 L
.2645 .20967 L
.26469 .20956 L
.26487 .20945 L
.26506 .20934 L
.26525 .20922 L
.26545 .2091 L
.26564 .20898 L
.26582 .20886 L
.26602 .20873 L
.2662 .20861 L
.2664 .20847 L
.2666 .20834 L
.26678 .20821 L
.26698 .20808 L
.26717 .20794 L
.26735 .20781 L
.26754 .20766 L
.26773 .20752 L
.26793 .20737 L
.26812 .20723 L
.2683 .20708 L
.2685 .20693 L
Mistroke
.26869 .20677 L
.26889 .20661 L
.26908 .20645 L
.26927 .20629 L
.26946 .20612 L
.26965 .20596 L
.26984 .2058 L
.27003 .20562 L
.27022 .20545 L
.27042 .20527 L
.27061 .20509 L
.27079 .20491 L
.27099 .20472 L
.27118 .20454 L
.27136 .20436 L
.27155 .20416 L
.27174 .20397 L
.27194 .20377 L
.27213 .20357 L
.27231 .20337 L
.27251 .20316 L
.27269 .20296 L
.27289 .20273 L
.27309 .20252 L
.27327 .20231 L
.27347 .20208 L
.27366 .20185 L
.27384 .20164 L
.27403 .2014 L
.27422 .20117 L
.27442 .20093 L
.27461 .20068 L
.2748 .20045 L
.27499 .20019 L
.27518 .19994 L
.27538 .19968 L
.27557 .19941 L
.27576 .19916 L
.27596 .19888 L
.27615 .19861 L
.27633 .19835 L
.27653 .19806 L
.27671 .19779 L
.27691 .19749 L
.2771 .19719 L
.27729 .19691 L
.27749 .1966 L
.27767 .1963 L
.27786 .196 L
.27805 .19569 L
Mistroke
.27824 .19538 L
.27844 .19504 L
.27863 .19471 L
.27881 .19439 L
.27901 .19405 L
.27919 .19371 L
.27939 .19335 L
.27959 .19299 L
.27977 .19264 L
.27997 .19227 L
.28016 .1919 L
.28034 .19154 L
.28054 .19115 L
.28072 .19077 L
.28092 .19036 L
.28111 .18996 L
.2813 .18957 L
.28149 .18915 L
.28168 .18874 L
.28186 .18833 L
.28206 .1879 L
.28224 .18747 L
.28244 .18701 L
.28263 .18656 L
.28281 .18611 L
.28301 .18564 L
.2832 .18517 L
.2834 .18466 L
.28359 .18417 L
.28377 .18369 L
.28397 .18316 L
.28416 .18265 L
.28434 .18215 L
.28454 .18161 L
.28472 .18107 L
.28492 .1805 L
.28511 .17994 L
.2853 .17939 L
.28549 .17879 L
.28568 .1782 L
.28588 .17757 L
.28607 .17695 L
.28626 .17634 L
.28646 .17568 L
.28665 .17504 L
.28683 .17441 L
.28703 .17372 L
.28721 .17305 L
.28741 .17232 L
.2876 .17161 L
Mistroke
.28779 .17091 L
.28798 .17015 L
.28817 .1694 L
.28836 .16867 L
.28855 .16788 L
.28874 .1671 L
.28893 .16625 L
.28912 .16542 L
.28931 .16461 L
.2895 .16373 L
.28969 .16286 L
.28989 .16192 L
.29008 .16099 L
.29027 .16008 L
.29047 .15909 L
.29066 .15811 L
.29084 .15716 L
.29103 .15612 L
.29122 .15509 L
.29142 .15398 L
.29161 .15289 L
.29179 .15181 L
.29199 .15064 L
.29218 .14948 L
.29236 .14834 L
.29255 .1471 L
.29274 .14588 L
.29294 .14456 L
.29313 .14324 L
.29331 .14195 L
.2935 .14054 L
.29369 .13915 L
.29389 .13764 L
.29408 .13614 L
.29427 .13466 L
.29447 .13305 L
.29465 .13145 L
.29484 .12987 L
.29503 .12815 L
.29522 .12645 L
.29542 .12458 L
.29561 .12274 L
.29579 .12091 L
.29599 .11891 L
.29617 .11693 L
.29637 .11476 L
.29657 .1126 L
.29675 .11046 L
.29695 .10812 L
.29714 .10579 L
Mistroke
.29732 .10348 L
.29752 .10094 L
.2977 .09841 L
.2979 .09563 L
.2981 .09286 L
.29828 .09011 L
.29848 .08707 L
.29866 .08405 L
.29885 .08103 L
.29904 .07771 L
.29923 .07439 L
.29942 .07072 L
.29961 .06704 L
.2998 .06337 L
.29999 .0593 L
.30018 .05523 L
.30038 .05071 L
.30057 .04616 L
.30076 .04159 L
.30095 .03651 L
.30114 .03139 L
.30133 .02625 L
.30152 .0205 L
.30171 .01471 L
.30191 .00823 L
.3021 .00165 L
Mfstroke
.3021 .00165 m
.30214 0 L
s
.31817 .5 m
.31832 .49632 L
.3185 .49173 L
.3187 .48706 L
.3189 .48276 L
.31908 .47879 L
.31928 .47473 L
.31947 .47098 L
.31965 .46751 L
.31985 .46396 L
.32003 .46066 L
.32023 .45729 L
.32042 .45416 L
.32061 .45126 L
.3208 .44828 L
.32099 .44551 L
.32117 .44293 L
.32137 .44028 L
.32155 .43781 L
.32175 .43527 L
.32194 .4329 L
.32212 .4307 L
.32232 .42842 L
.32251 .4263 L
.32271 .42412 L
.3229 .42208 L
.32308 .42017 L
.32328 .4182 L
.32347 .41637 L
.32365 .41465 L
.32384 .41287 L
.32403 .41121 L
.32423 .40949 L
.32442 .40788 L
.3246 .40637 L
.3248 .40481 L
.32499 .40335 L
.32519 .40184 L
.32538 .40042 L
.32557 .39909 L
.32576 .39771 L
.32595 .39642 L
.32614 .39521 L
.32633 .39395 L
.32652 .39277 L
.32672 .39155 L
.32691 .3904 L
.32709 .38932 L
.32729 .3882 L
.32748 .38715 L
Mistroke
.32766 .38616 L
.32785 .38513 L
.32804 .38416 L
.32824 .38316 L
.32843 .38221 L
.32861 .38133 L
.32881 .3804 L
.329 .37953 L
.32919 .37863 L
.32939 .37778 L
.32957 .37698 L
.32977 .37615 L
.32996 .37537 L
.33014 .37464 L
.33034 .37387 L
.33052 .37315 L
.33072 .3724 L
.33091 .37169 L
.3311 .37103 L
.33129 .37033 L
.33148 .36968 L
.33168 .369 L
.33187 .36837 L
.33206 .36776 L
.33226 .36714 L
.33245 .36655 L
.33263 .36599 L
.33283 .36541 L
.33301 .36487 L
.33321 .3643 L
.3334 .36376 L
.33359 .36326 L
.33379 .36273 L
.33397 .36224 L
.33416 .36177 L
.33435 .36129 L
.33454 .36083 L
.33473 .36035 L
.33493 .3599 L
.33511 .35948 L
.3353 .35904 L
.33549 .35863 L
.33569 .35819 L
.33589 .35779 L
.33607 .3574 L
.33627 .35701 L
.33646 .35663 L
.33664 .35628 L
.33683 .35591 L
.33702 .35556 L
Mistroke
.33722 .3552 L
.33741 .35486 L
.3376 .35454 L
.33779 .35421 L
.33798 .3539 L
.33816 .3536 L
.33836 .35329 L
.33854 .35301 L
.33874 .35271 L
.33893 .35242 L
.33911 .35216 L
.33931 .35188 L
.3395 .35162 L
.3397 .35136 L
.33989 .3511 L
.34007 .35087 L
.34027 .35062 L
.34046 .35039 L
.34064 .35017 L
.34084 .34995 L
.34102 .34974 L
.34122 .34952 L
.34141 .34931 L
.3416 .34912 L
.34179 .34892 L
.34198 .34874 L
.34218 .34855 L
.34237 .34837 L
.34256 .3482 L
.34276 .34803 L
.34295 .34786 L
.34313 .34771 L
.34332 .34756 L
.34351 .34741 L
.34371 .34726 L
.3439 .34712 L
.34409 .34699 L
.34428 .34686 L
.34447 .34674 L
.34465 .34663 L
.34485 .34651 L
.34503 .3464 L
.34523 .34629 L
.34542 .34619 L
.34561 .34609 L
.3458 .346 L
.34599 .34591 L
.34619 .34582 L
.34638 .34574 L
.34657 .34567 L
Mistroke
.34676 .34559 L
.34695 .34553 L
.34714 .34546 L
.34733 .3454 L
.34752 .34535 L
.34772 .3453 L
.34791 .34525 L
.34809 .34521 L
.34829 .34517 L
.34848 .34513 L
.34866 .3451 L
.34885 .34507 L
.34904 .34505 L
.34923 .34503 L
.34942 .34501 L
.34961 .345 L
.3497 .34499 L
.3498 .34499 L
.34985 .34499 L
.3499 .34499 L
.34995 .34499 L
.34997 .34499 L
.35 .34498 L
.35003 .34498 L
.35005 .34498 L
.35007 .34498 L
.35009 .34498 L
.3501 .34498 L
.35011 .34498 L
.35012 .34498 L
.35012 .34498 L
.35013 .34498 L
.35013 .34498 L
.35014 .34498 L
.35014 .34498 L
.35015 .34498 L
.35015 .34498 L
.35016 .34498 L
.35016 .34498 L
.35017 .34498 L
.35018 .34498 L
.3502 .34498 L
.35022 .34498 L
.35024 .34498 L
.35029 .34498 L
.35034 .34499 L
.35039 .34499 L
.35049 .34499 L
.35059 .34499 L
.35077 .345 L
Mistroke
.35097 .34502 L
.35116 .34504 L
.35136 .34506 L
.35155 .34509 L
.35173 .34511 L
.35193 .34515 L
.35212 .34519 L
.3523 .34522 L
.3525 .34527 L
.35268 .34532 L
.35288 .34537 L
.35307 .34543 L
.35326 .34548 L
.35345 .34555 L
.35364 .34561 L
.35384 .34569 L
.35404 .34576 L
.35422 .34584 L
.35442 .34592 L
.35461 .34601 L
.35479 .34609 L
.35499 .34619 L
.35517 .34628 L
.35537 .34639 L
.35557 .34649 L
.35575 .34659 L
.35595 .34671 L
.35614 .34682 L
.35632 .34694 L
.35651 .34706 L
.3567 .34718 L
.3569 .34732 L
.35709 .34745 L
.35727 .34759 L
.35747 .34773 L
.35765 .34788 L
.35785 .34803 L
.35805 .34819 L
.35823 .34834 L
.35843 .34851 L
.35862 .34867 L
.3588 .34884 L
.35899 .34901 L
.35918 .34919 L
.35938 .34938 L
.35957 .34956 L
.35976 .34975 L
.35995 .34995 L
.36014 .35014 L
.36032 .35033 L
Mistroke
.36052 .35054 L
.3607 .35075 L
.3609 .35097 L
.36109 .35119 L
.36127 .35141 L
.36147 .35164 L
.36166 .35187 L
.36186 .35212 L
.36205 .35236 L
.36223 .3526 L
.36243 .35286 L
.36262 .35311 L
.3628 .35336 L
.36299 .35363 L
.36318 .35389 L
.36338 .35418 L
.36357 .35446 L
.36375 .35473 L
.36395 .35503 L
.36414 .35532 L
.36434 .35563 L
.36453 .35594 L
.36472 .35624 L
.36491 .35656 L
.3651 .35688 L
.36529 .35719 L
.36548 .35753 L
.36567 .35786 L
.36587 .35822 L
.36606 .35857 L
.36624 .35891 L
.36644 .35927 L
.36663 .35963 L
.36681 .35999 L
.367 .36037 L
.36719 .36074 L
.36739 .36114 L
.36758 .36153 L
.36776 .36192 L
.36796 .36233 L
.36815 .36274 L
.36835 .36318 L
.36854 .36361 L
.36872 .36402 L
.36892 .36448 L
.36911 .36492 L
.36929 .36535 L
.36949 .36582 L
.36967 .36627 L
.36987 .36677 L
Mistroke
.37006 .36725 L
.37025 .36772 L
.37044 .36823 L
.37063 .36872 L
.37083 .36926 L
.37103 .36979 L
.37121 .3703 L
.37141 .37085 L
.3716 .37139 L
.37178 .37192 L
.37198 .37249 L
.37216 .37305 L
.37236 .37365 L
.37256 .37424 L
.37274 .37482 L
.37294 .37544 L
.37313 .37605 L
.37331 .37664 L
.3735 .37728 L
.37369 .37791 L
.37389 .37859 L
.37408 .37925 L
.37426 .3799 L
.37446 .38059 L
.37465 .38128 L
.37485 .38202 L
.37504 .38274 L
.37522 .38344 L
.37542 .38421 L
.37561 .38495 L
.37579 .38568 L
.37599 .38647 L
.37617 .38724 L
.37637 .38807 L
.37656 .38889 L
.37675 .38968 L
.37695 .39055 L
.37713 .39139 L
.37732 .39221 L
.37751 .3931 L
.3777 .39397 L
.37789 .39491 L
.37808 .39584 L
.37827 .39674 L
.37846 .39771 L
.37865 .39867 L
.37885 .3997 L
.37904 .40071 L
.37923 .4017 L
.37942 .40277 L
Mistroke
.37961 .40382 L
.37979 .40484 L
.37999 .40595 L
.38018 .40704 L
.38037 .40822 L
.38057 .40937 L
.38075 .4105 L
.38094 .41172 L
.38113 .41292 L
.38133 .41422 L
.38153 .41549 L
.38171 .41674 L
.38191 .41809 L
.3821 .41942 L
.38228 .42071 L
.38248 .42212 L
.38266 .4235 L
.38286 .425 L
.38306 .42646 L
.38324 .4279 L
.38344 .42947 L
.38363 .431 L
.38381 .4325 L
.384 .43413 L
.38419 .43573 L
.38439 .43747 L
.38458 .43918 L
.38476 .44085 L
.38496 .44267 L
.38514 .44446 L
.38534 .4464 L
.38554 .44831 L
.38572 .45019 L
.38592 .45223 L
.38611 .45423 L
.38629 .4562 L
.38648 .45835 L
.38667 .46046 L
.38687 .46275 L
.38706 .46501 L
.38725 .46724 L
.38744 .46966 L
.38763 .47205 L
.38781 .47439 L
.388 .47695 L
.38819 .47947 L
.38839 .48222 L
.38858 .48493 L
.38876 .4876 L
.38896 .49051 L
Mistroke
.38914 .49339 L
.38934 .49652 L
.38954 .49962 L
Mfstroke
.38954 .49962 m
.38956 .5 L
s
.42258 0 m
.42272 .00156 L
.4229 .00361 L
.42309 .00575 L
.42328 .00776 L
.42348 .00985 L
.42367 .01182 L
.42385 .01367 L
.42405 .0156 L
.42423 .01741 L
.42443 .0193 L
.42463 .02108 L
.42481 .02276 L
.42501 .02451 L
.4252 .02616 L
.42538 .02771 L
.42557 .02933 L
.42576 .03085 L
.42596 .03244 L
.42615 .03394 L
.42633 .03536 L
.42653 .03684 L
.42672 .03823 L
.42692 .03968 L
.42711 .04105 L
.4273 .04234 L
.4275 .04369 L
.42769 .04496 L
.42787 .04616 L
.42806 .04741 L
.42825 .0486 L
.42845 .04983 L
.42864 .051 L
.42883 .0521 L
.42902 .05325 L
.42921 .05434 L
.42939 .05536 L
.42959 .05643 L
.42977 .05745 L
.42997 .0585 L
.43016 .0595 L
.43035 .06045 L
.43054 .06143 L
.43073 .06237 L
.43093 .06334 L
.43112 .06426 L
.43131 .06513 L
.43151 .06604 L
.4317 .0669 L
.43188 .06771 L
Mistroke
.43207 .06855 L
.43226 .06936 L
.43246 .07019 L
.43265 .07098 L
.43283 .07173 L
.43303 .07251 L
.43322 .07325 L
.4334 .07395 L
.43359 .07468 L
.43378 .07537 L
.43398 .0761 L
.43417 .07678 L
.43435 .07742 L
.43455 .0781 L
.43473 .07873 L
.43493 .0794 L
.43513 .08003 L
.43531 .08062 L
.43551 .08124 L
.4357 .08183 L
.43588 .08238 L
.43607 .08296 L
.43626 .08351 L
.43646 .08408 L
.43665 .08462 L
.43683 .08514 L
.43703 .08567 L
.43722 .08617 L
.43742 .0867 L
.43761 .0872 L
.4378 .08766 L
.43799 .08815 L
.43818 .08862 L
.43837 .08905 L
.43856 .08951 L
.43875 .08994 L
.43895 .09039 L
.43914 .09081 L
.43932 .09121 L
.43952 .09163 L
.43971 .09202 L
.43989 .09239 L
.44009 .09278 L
.44027 .09314 L
.44047 .09352 L
.44066 .09388 L
.44084 .09422 L
.44104 .09457 L
.44123 .0949 L
.44143 .09525 L
Mistroke
.44162 .09557 L
.4418 .09587 L
.442 .09619 L
.44219 .09649 L
.44237 .09677 L
.44257 .09706 L
.44275 .09734 L
.44295 .09762 L
.44314 .09789 L
.44333 .09814 L
.44352 .0984 L
.44371 .09865 L
.44389 .09888 L
.44409 .09911 L
.44427 .09934 L
.44447 .09957 L
.44466 .09978 L
.44484 .09998 L
.44504 .10019 L
.44523 .10039 L
.44543 .10059 L
.44562 .10078 L
.4458 .10095 L
.446 .10113 L
.44619 .1013 L
.44637 .10145 L
.44657 .10161 L
.44675 .10176 L
.44695 .10191 L
.44714 .10205 L
.44732 .10218 L
.44752 .10231 L
.44771 .10243 L
.44791 .10256 L
.4481 .10267 L
.44829 .10277 L
.44848 .10288 L
.44867 .10297 L
.44886 .10306 L
.44905 .10314 L
.44924 .10322 L
.44944 .1033 L
.44963 .10336 L
.44981 .10343 L
.45001 .10348 L
.4502 .10354 L
.45038 .10358 L
.45057 .10362 L
.45076 .10366 L
.45096 .10369 L
Mistroke
.45115 .10372 L
.45133 .10374 L
.45143 .10375 L
.45153 .10375 L
.45162 .10376 L
.45171 .10376 L
.45176 .10376 L
.45181 .10377 L
.45186 .10377 L
.45188 .10377 L
.45191 .10377 L
.45193 .10377 L
.45194 .10377 L
.45195 .10377 L
.45196 .10377 L
.45196 .10377 L
.45197 .10377 L
.45197 .10377 L
.45198 .10377 L
.45199 .10377 L
.45199 .10377 L
.45199 .10377 L
.452 .10377 L
.452 .10377 L
.45201 .10377 L
.45202 .10377 L
.45202 .10377 L
.45203 .10377 L
.45204 .10377 L
.45205 .10377 L
.45207 .10377 L
.45209 .10377 L
.45214 .10377 L
.45219 .10377 L
.45228 .10376 L
.45237 .10376 L
.45246 .10375 L
.45265 .10374 L
.45285 .10372 L
.45304 .10369 L
.45323 .10366 L
.45343 .10362 L
.45362 .10358 L
.4538 .10353 L
.45399 .10348 L
.45418 .10342 L
.45438 .10336 L
.45457 .10329 L
.45475 .10322 L
.45495 .10314 L
Mistroke
.45514 .10305 L
.45532 .10297 L
.45551 .10287 L
.4557 .10277 L
.4559 .10266 L
.45609 .10255 L
.45627 .10244 L
.45647 .10232 L
.45665 .10219 L
.45685 .10205 L
.45705 .10191 L
.45723 .10177 L
.45743 .10162 L
.45762 .10146 L
.4578 .10131 L
.45799 .10114 L
.45818 .10097 L
.45838 .10079 L
.45857 .1006 L
.45875 .10042 L
.45895 .10022 L
.45914 .10002 L
.45934 .0998 L
.45953 .09959 L
.45971 .09938 L
.45991 .09914 L
.4601 .09891 L
.46029 .09868 L
.46048 .09843 L
.46067 .09819 L
.46087 .09792 L
.46106 .09766 L
.46124 .0974 L
.46144 .09711 L
.46163 .09683 L
.46181 .09656 L
.462 .09626 L
.46219 .09596 L
.46239 .09564 L
.46258 .09533 L
.46276 .09502 L
.46296 .09468 L
.46314 .09435 L
.46334 .09399 L
.46354 .09364 L
.46372 .09329 L
.46392 .09291 L
.46411 .09254 L
.46429 .09218 L
.46448 .09178 L
Mistroke
.46467 .0914 L
.46487 .09098 L
.46506 .09056 L
.46525 .09016 L
.46544 .08972 L
.46563 .08929 L
.46583 .08882 L
.46602 .08836 L
.46621 .08792 L
.46641 .08743 L
.4666 .08695 L
.46678 .08648 L
.46697 .08598 L
.46716 .08548 L
.46736 .08494 L
.46755 .08442 L
.46774 .0839 L
.46794 .08334 L
.46812 .08279 L
.46831 .08226 L
.4685 .08167 L
.46869 .08111 L
.46888 .08049 L
.46908 .07988 L
.46926 .07929 L
.46945 .07865 L
.46964 .07802 L
.46984 .07735 L
.47004 .07668 L
.47022 .07603 L
.47042 .07532 L
.47061 .07463 L
.47079 .07395 L
.47099 .07322 L
.47117 .0725 L
.47137 .07173 L
.47156 .07096 L
.47175 .07022 L
.47194 .06941 L
.47213 .06862 L
.47231 .06785 L
.47251 .06701 L
.47269 .06619 L
.47289 .0653 L
.47308 .06443 L
.47326 .06358 L
.47346 .06266 L
.47365 .06175 L
.47385 .06077 L
.47404 .05981 L
Mistroke
.47422 .05887 L
.47442 .05785 L
.47461 .05685 L
.47479 .05588 L
.47499 .05482 L
.47517 .05378 L
.47537 .05265 L
.47556 .05155 L
.47575 .05047 L
.47594 .0493 L
.47613 .04815 L
.47633 .04691 L
.47652 .04569 L
.47671 .04449 L
.47691 .04319 L
.4771 .04192 L
.47728 .04067 L
.47748 .03931 L
.47766 .03798 L
.47786 .03654 L
.47805 .03513 L
.47824 .03374 L
.47843 .03223 L
.47862 .03075 L
.47881 .0293 L
.479 .02773 L
.47919 .02618 L
.47938 .0245 L
.47957 .02285 L
.47976 .02123 L
.47995 .01947 L
.48014 .01774 L
.48034 .01587 L
.48053 .01402 L
.48072 .0122 L
.48092 .01023 L
.48111 .00828 L
.48129 .00637 L
.48148 .0043 L
.48167 .00225 L
.48187 3e-05 L
Mfstroke
.48187 3e-05 m
.48187 0 L
s
.51464 .5 m
.51471 .4989 L
.5149 .49553 L
.51508 .49238 L
.51528 .48911 L
.51546 .48604 L
.51566 .48286 L
.51586 .47987 L
.51604 .47707 L
.51624 .47416 L
.51643 .47142 L
.51661 .46885 L
.51681 .46618 L
.51699 .46366 L
.51719 .46105 L
.51739 .45859 L
.51757 .45628 L
.51777 .45387 L
.51796 .4516 L
.51814 .44947 L
.51833 .44724 L
.51852 .44514 L
.51871 .44296 L
.5189 .4409 L
.51909 .43896 L
.51928 .43694 L
.51947 .43503 L
.51967 .43305 L
.51986 .43117 L
.52005 .4294 L
.52025 .42756 L
.52044 .42581 L
.52062 .42417 L
.52081 .42245 L
.521 .42083 L
.5212 .41913 L
.52139 .41753 L
.52157 .41602 L
.52177 .41444 L
.52196 .41295 L
.52216 .41139 L
.52235 .40992 L
.52254 .40852 L
.52273 .40707 L
.52292 .40569 L
.52311 .40438 L
.5233 .40302 L
.52349 .40173 L
.52369 .40038 L
.52388 .3991 L
Mistroke
.52406 .39789 L
.52426 .39663 L
.52445 .39543 L
.52463 .3943 L
.52483 .39311 L
.52501 .39198 L
.52521 .3908 L
.5254 .38969 L
.52559 .38863 L
.52578 .38752 L
.52597 .38647 L
.52617 .38537 L
.52636 .38433 L
.52655 .38334 L
.52674 .3823 L
.52693 .38132 L
.52712 .38039 L
.52731 .37941 L
.5275 .37849 L
.5277 .37752 L
.52789 .37659 L
.52807 .37572 L
.52827 .3748 L
.52846 .37393 L
.52864 .37311 L
.52883 .37224 L
.52902 .37142 L
.52922 .37056 L
.52941 .36974 L
.52959 .36896 L
.52978 .36814 L
.52997 .36737 L
.53017 .36655 L
.53036 .36578 L
.53055 .36505 L
.53075 .36428 L
.53094 .36354 L
.53112 .36285 L
.53131 .36212 L
.5315 .36142 L
.5317 .3607 L
.53189 .36 L
.53207 .35935 L
.53227 .35865 L
.53246 .358 L
.53266 .35731 L
.53285 .35665 L
.53303 .35603 L
.53323 .35537 L
.53342 .35475 L
Mistroke
.53361 .35416 L
.5338 .35353 L
.53399 .35294 L
.53419 .35232 L
.53438 .35173 L
.53456 .35116 L
.53476 .35057 L
.53495 .35001 L
.53513 .34947 L
.53532 .34891 L
.53551 .34837 L
.53571 .34781 L
.5359 .34727 L
.53608 .34676 L
.53628 .34623 L
.53646 .34571 L
.53666 .34518 L
.53686 .34467 L
.53704 .34418 L
.53724 .34367 L
.53743 .34318 L
.53761 .34272 L
.53781 .34223 L
.53799 .34176 L
.53819 .34127 L
.53838 .34081 L
.53857 .34036 L
.53876 .3399 L
.53895 .33945 L
.53913 .33903 L
.53933 .33858 L
.53951 .33816 L
.53971 .33771 L
.5399 .33728 L
.54008 .33688 L
.54028 .33645 L
.54047 .33604 L
.54066 .33562 L
.54086 .33521 L
.54104 .33482 L
.54124 .33441 L
.54143 .33402 L
.54161 .33365 L
.5418 .33326 L
.54199 .33288 L
.54219 .33249 L
.54238 .33212 L
.54256 .33176 L
.54276 .33138 L
.54295 .33102 L
Mistroke
.54315 .33065 L
.54334 .33029 L
.54352 .32994 L
.54372 .32958 L
.54391 .32924 L
.54409 .32891 L
.54429 .32856 L
.54448 .32823 L
.54468 .32789 L
.54487 .32755 L
.54505 .32724 L
.54525 .32691 L
.54544 .32659 L
.54562 .32629 L
.54581 .32597 L
.546 .32566 L
.5462 .32534 L
.54639 .32503 L
.54657 .32474 L
.54676 .32444 L
.54695 .32414 L
.54715 .32383 L
.54734 .32354 L
.54753 .32326 L
.54773 .32296 L
.54792 .32268 L
.5481 .32241 L
.54829 .32212 L
.54848 .32185 L
.54868 .32156 L
.54887 .32129 L
.54905 .32103 L
.54925 .32076 L
.54944 .32049 L
.54964 .32022 L
.54983 .31995 L
.55002 .3197 L
.55021 .31944 L
.5504 .31918 L
.55059 .31894 L
.55078 .31869 L
.55097 .31844 L
.55117 .31819 L
.55136 .31794 L
.55154 .31771 L
.55174 .31746 L
.55193 .31723 L
.55211 .317 L
.55231 .31676 L
.55249 .31654 L
Mistroke
.55269 .3163 L
.55288 .31607 L
.55306 .31585 L
.55326 .31562 L
.55345 .3154 L
.55365 .31517 L
.55384 .31495 L
.55403 .31474 L
.55422 .31452 L
.55441 .31431 L
.5546 .31411 L
.55479 .31389 L
.55498 .31369 L
.55518 .31347 L
.55537 .31327 L
.55555 .31307 L
.55575 .31286 L
.55594 .31267 L
.55612 .31248 L
.55631 .31228 L
.5565 .31209 L
.55669 .31189 L
.55688 .31169 L
.55707 .31151 L
.55726 .31132 L
.55745 .31113 L
.55765 .31094 L
.55784 .31075 L
.55803 .31057 L
.55822 .31038 L
.55841 .31021 L
.5586 .31003 L
.55879 .30985 L
.55898 .30968 L
.55917 .3095 L
.55937 .30932 L
.55955 .30916 L
.55974 .30898 L
.55993 .30881 L
.56013 .30864 L
.56033 .30847 L
.56051 .30831 L
.56071 .30813 L
.5609 .30797 L
.56108 .30782 L
.56128 .30765 L
.56146 .30749 L
.56166 .30733 L
.56185 .30717 L
.56204 .30702 L
Mistroke
.56224 .30686 L
.56242 .30671 L
.56261 .30656 L
.5628 .30641 L
.56299 .30626 L
.56318 .3061 L
.56337 .30595 L
.56356 .30581 L
.56375 .30566 L
.56394 .30552 L
.56414 .30537 L
.56433 .30522 L
.56452 .30508 L
.56471 .30494 L
.5649 .3048 L
.56509 .30467 L
.56528 .30453 L
.56547 .30439 L
.56567 .30425 L
.56586 .30411 L
.56604 .30398 L
.56624 .30385 L
.56643 .30372 L
.56663 .30358 L
.56682 .30345 L
.56701 .30332 L
.5672 .30319 L
.56739 .30306 L
.56758 .30294 L
.56777 .30281 L
.56796 .30268 L
.56816 .30255 L
.56835 .30243 L
.56854 .30231 L
.56873 .30219 L
.56892 .30207 L
.5691 .30195 L
.5693 .30183 L
.56948 .30172 L
.56968 .30159 L
.56987 .30148 L
.57006 .30136 L
.57025 .30125 L
.57044 .30113 L
.57064 .30101 L
.57083 .3009 L
.57102 .30079 L
.57121 .30068 L
.5714 .30057 L
.57159 .30046 L
Mistroke
.57178 .30035 L
.57197 .30025 L
.57217 .30013 L
.57236 .30003 L
.57254 .29992 L
.57274 .29982 L
.57293 .29971 L
.57311 .29961 L
.5733 .29951 L
.57349 .29941 L
.57369 .2993 L
.57388 .2992 L
.57406 .29911 L
.57426 .299 L
.57444 .29891 L
.57464 .2988 L
.57484 .2987 L
.57502 .29861 L
.57522 .29851 L
.57541 .29842 L
.57559 .29832 L
.57578 .29823 L
.57597 .29814 L
.57617 .29804 L
.57636 .29795 L
.57654 .29786 L
.57674 .29776 L
.57693 .29768 L
.57713 .29758 L
.57732 .29749 L
.57751 .2974 L
.5777 .29731 L
.57789 .29722 L
.57808 .29714 L
.57827 .29705 L
.57846 .29697 L
.57866 .29688 L
.57885 .29679 L
.57903 .29671 L
.57923 .29663 L
.57942 .29654 L
.5796 .29646 L
.5798 .29638 L
.57998 .2963 L
.58018 .29622 L
.58037 .29614 L
.58055 .29606 L
.58075 .29598 L
.58094 .2959 L
.58114 .29582 L
Mistroke
.58133 .29574 L
.58152 .29566 L
.58171 .29559 L
.5819 .29551 L
.58208 .29544 L
.58228 .29536 L
.58247 .29529 L
.58266 .29521 L
.58286 .29514 L
.58304 .29506 L
.58324 .29499 L
.58342 .29492 L
.58361 .29485 L
.5838 .29478 L
.58399 .29471 L
.58418 .29464 L
.58437 .29457 L
.58456 .2945 L
.58475 .29443 L
.58494 .29436 L
.58514 .29429 L
.58533 .29422 L
.58552 .29416 L
.58571 .29409 L
.5859 .29402 L
.58608 .29396 L
.58628 .29389 L
.58646 .29383 L
.58666 .29376 L
.58685 .2937 L
.58704 .29363 L
.58723 .29357 L
.58742 .29351 L
.58762 .29344 L
.58781 .29338 L
.588 .29332 L
.5882 .29325 L
.58839 .29319 L
.58857 .29314 L
.58876 .29307 L
.58895 .29302 L
.58915 .29295 L
.58934 .29289 L
.58953 .29284 L
.58972 .29278 L
.58991 .29272 L
.59009 .29267 L
.59029 .29261 L
.59047 .29255 L
.59067 .29249 L
Mistroke
.59086 .29244 L
.59104 .29239 L
.59124 .29233 L
.59143 .29227 L
.59163 .29222 L
.59182 .29216 L
.592 .29211 L
.5922 .29206 L
.59239 .292 L
.59257 .29195 L
.59277 .2919 L
.59295 .29185 L
.59315 .2918 L
.59334 .29174 L
.59353 .2917 L
.59372 .29164 L
.59391 .29159 L
.59411 .29154 L
.59431 .29149 L
.59449 .29144 L
.59469 .29139 L
.59488 .29134 L
.59506 .2913 L
.59524 .29125 L
Mfstroke
.59524 .29125 m
.59542 .29121 L
.59563 .29116 L
.59582 .29111 L
.596 .29107 L
.59619 .29102 L
.59638 .29097 L
.59658 .29093 L
.59677 .29088 L
.59696 .29084 L
.59716 .29079 L
.59734 .29075 L
.59753 .29071 L
.59772 .29066 L
.59791 .29062 L
.5981 .29057 L
.5983 .29053 L
.59848 .29049 L
.59868 .29045 L
.59886 .2904 L
.59906 .29036 L
.59926 .29032 L
.59944 .29028 L
.59964 .29024 L
.59983 .2902 L
.60001 .29016 L
.60021 .29012 L
.60039 .29008 L
.60059 .29004 L
.60078 .29 L
.60097 .28996 L
.60116 .28992 L
.60135 .28988 L
.60153 .28985 L
.60173 .28981 L
.60191 .28977 L
.60211 .28974 L
.6023 .2897 L
.60249 .28966 L
.60268 .28963 L
.60287 .28959 L
.60307 .28955 L
.60326 .28952 L
.60345 .28948 L
.60364 .28945 L
.60383 .28941 L
.60401 .28938 L
.60421 .28935 L
.60439 .28931 L
.60459 .28928 L
Mistroke
.60478 .28924 L
.60497 .28921 L
.60516 .28918 L
.60535 .28915 L
.60555 .28911 L
.60575 .28908 L
.60593 .28905 L
.60613 .28901 L
.60632 .28898 L
.6065 .28895 L
.6067 .28892 L
.60688 .28889 L
.60708 .28886 L
.60727 .28883 L
.60746 .2888 L
.60766 .28877 L
.60784 .28874 L
.60803 .28871 L
.60822 .28868 L
.60841 .28866 L
.6086 .28863 L
.6088 .2886 L
.60898 .28857 L
.60917 .28854 L
.60936 .28851 L
.60956 .28849 L
.60975 .28846 L
.60994 .28843 L
.61014 .28841 L
.61033 .28838 L
.61051 .28835 L
.6107 .28833 L
.61089 .2883 L
.61109 .28828 L
.61128 .28825 L
.61147 .28823 L
.61166 .2882 L
.61185 .28818 L
.61203 .28815 L
.61222 .28813 L
.61241 .2881 L
.61261 .28808 L
.6128 .28806 L
.61298 .28803 L
.61318 .28801 L
.61336 .28799 L
.61356 .28796 L
.61376 .28794 L
.61394 .28792 L
.61414 .2879 L
Mistroke
.61433 .28787 L
.61451 .28785 L
.6147 .28783 L
.61489 .28781 L
.61509 .28779 L
.61528 .28777 L
.61546 .28775 L
.61566 .28773 L
.61585 .28771 L
.61605 .28768 L
.61624 .28766 L
.61642 .28765 L
.61662 .28762 L
.61681 .28761 L
.61699 .28759 L
.61719 .28757 L
.61738 .28755 L
.61758 .28753 L
.61777 .28751 L
.61795 .28749 L
.61815 .28748 L
.61834 .28746 L
.61852 .28744 L
.61871 .28742 L
.6189 .28741 L
.6191 .28739 L
.61929 .28737 L
.61947 .28736 L
.61967 .28734 L
.61985 .28732 L
.62005 .28731 L
.62025 .28729 L
.62043 .28727 L
.62063 .28726 L
.62082 .28724 L
.621 .28723 L
.62119 .28721 L
.62138 .2872 L
.62158 .28718 L
.62177 .28717 L
.62195 .28715 L
.62215 .28714 L
.62234 .28713 L
.62254 .28711 L
.62273 .2871 L
.62292 .28708 L
.62312 .28707 L
.62331 .28706 L
.62349 .28705 L
.62368 .28703 L
Mistroke
.62387 .28702 L
.62407 .28701 L
.62426 .287 L
.62445 .28698 L
.62464 .28697 L
.62483 .28696 L
.62501 .28695 L
.62521 .28694 L
.62539 .28693 L
.62559 .28691 L
.62578 .2869 L
.62597 .28689 L
.62616 .28688 L
.62635 .28687 L
.62655 .28686 L
.62674 .28685 L
.62693 .28684 L
.62713 .28683 L
.62732 .28682 L
.6275 .28681 L
.62769 .2868 L
.62788 .2868 L
.62808 .28679 L
.62827 .28678 L
.62845 .28677 L
.62865 .28676 L
.62884 .28675 L
.62902 .28674 L
.62921 .28674 L
.6294 .28673 L
.6296 .28672 L
.62979 .28671 L
.62997 .28671 L
.63017 .2867 L
.63035 .28669 L
.63055 .28669 L
.63075 .28668 L
.63093 .28667 L
.63113 .28667 L
.63132 .28666 L
.6315 .28665 L
.63169 .28665 L
.63188 .28664 L
.63208 .28664 L
.63227 .28663 L
.63245 .28663 L
.63265 .28662 L
.63284 .28662 L
.63304 .28661 L
.63323 .28661 L
Mistroke
.63342 .2866 L
.63361 .2866 L
.6338 .28659 L
.63399 .28659 L
.63418 .28658 L
.63437 .28658 L
.63457 .28658 L
.63476 .28657 L
.63494 .28657 L
.63514 .28657 L
.63533 .28656 L
.63551 .28656 L
.6357 .28656 L
.63589 .28656 L
.63609 .28655 L
.63628 .28655 L
.63646 .28655 L
.63666 .28655 L
.63685 .28655 L
.63705 .28654 L
.63724 .28654 L
.63742 .28654 L
.63762 .28654 L
.63781 .28654 L
.63799 .28654 L
.63819 .28654 L
.63837 .28654 L
.63857 .28654 L
.63867 .28654 L
.63876 .28654 L
.63886 .28654 L
.63895 .28653 L
.63899 .28653 L
.63904 .28653 L
.63906 .28653 L
.63909 .28653 L
.63911 .28653 L
.63914 .28653 L
.63915 .28653 L
.63916 .28653 L
.63917 .28653 L
.63917 .28653 L
.63918 .28653 L
.63918 .28653 L
.63919 .28653 L
.6392 .28653 L
.6392 .28653 L
.63921 .28653 L
.63921 .28653 L
.63921 .28653 L
Mistroke
.63922 .28653 L
.63922 .28653 L
.63923 .28653 L
.63923 .28653 L
.63924 .28653 L
.63925 .28653 L
.63927 .28653 L
.6393 .28653 L
.63932 .28653 L
.63937 .28653 L
.63941 .28653 L
.63951 .28653 L
.63961 .28654 L
.63971 .28654 L
.6399 .28654 L
.64009 .28654 L
.64027 .28654 L
.64047 .28654 L
.64065 .28654 L
.64085 .28654 L
.64104 .28654 L
.64122 .28654 L
.64142 .28654 L
.64161 .28655 L
.64181 .28655 L
.642 .28655 L
.64218 .28655 L
.64238 .28655 L
.64257 .28656 L
.64275 .28656 L
.64295 .28656 L
.64313 .28656 L
.64333 .28657 L
.64352 .28657 L
.64371 .28657 L
.6439 .28658 L
.64409 .28658 L
.64429 .28658 L
.64449 .28659 L
.64467 .28659 L
.64487 .2866 L
.64506 .2866 L
.64524 .2866 L
.64544 .28661 L
.64562 .28661 L
.64582 .28662 L
.64602 .28662 L
.6462 .28663 L
.6464 .28663 L
.64659 .28664 L
Mistroke
.64677 .28664 L
.64696 .28665 L
.64715 .28665 L
.64735 .28666 L
.64754 .28667 L
.64772 .28667 L
.64792 .28668 L
.6481 .28669 L
.6483 .28669 L
.6485 .2867 L
.64868 .28671 L
.64888 .28671 L
.64907 .28672 L
.64925 .28673 L
.64944 .28673 L
.64963 .28674 L
.64983 .28675 L
.65002 .28676 L
.65021 .28676 L
.6504 .28677 L
.65059 .28678 L
.65077 .28679 L
.65097 .2868 L
.65115 .2868 L
.65135 .28681 L
.65154 .28682 L
.65172 .28683 L
.65192 .28684 L
.65211 .28685 L
.65231 .28686 L
.6525 .28687 L
.65268 .28688 L
.65288 .28689 L
.65307 .2869 L
.65325 .2869 L
.65344 .28692 L
.65363 .28692 L
.65383 .28694 L
.65402 .28695 L
.6542 .28696 L
.6544 .28697 L
.65459 .28698 L
.65479 .28699 L
.65498 .287 L
.65517 .28701 L
.65536 .28702 L
.65555 .28703 L
.65574 .28704 L
.65593 .28706 L
.65612 .28707 L
Mistroke
.65632 .28708 L
.65651 .28709 L
.65669 .2871 L
.65689 .28712 L
.65708 .28713 L
.65726 .28714 L
.65745 .28715 L
.65764 .28717 L
.65784 .28718 L
.65803 .28719 L
.65821 .28721 L
.65841 .28722 L
.6586 .28723 L
.6588 .28725 L
.65899 .28726 L
.65917 .28727 L
.65937 .28729 L
.65956 .2873 L
.65974 .28732 L
.65994 .28733 L
.66012 .28734 L
.66032 .28736 L
.66051 .28737 L
.6607 .28739 L
.66089 .2874 L
.66108 .28742 L
.66128 .28743 L
.66148 .28745 L
.66166 .28747 L
.66186 .28748 L
.66205 .2875 L
.66223 .28751 L
.66243 .28753 L
.66261 .28754 L
.66281 .28756 L
.66301 .28758 L
.66319 .28759 L
.66339 .28761 L
.66358 .28763 L
.66376 .28764 L
.66395 .28766 L
.66414 .28768 L
.66434 .28769 L
.66453 .28771 L
.66471 .28773 L
.66491 .28775 L
.66509 .28776 L
.66529 .28778 L
.66549 .2878 L
.66567 .28782 L
Mistroke
.66587 .28784 L
.66606 .28786 L
.66624 .28787 L
.66644 .28789 L
.66662 .28791 L
.66682 .28793 L
.66701 .28795 L
.6672 .28797 L
.66739 .28799 L
.66758 .28801 L
.66777 .28803 L
.66796 .28805 L
.66814 .28806 L
.66834 .28809 L
.66853 .28811 L
.66872 .28812 L
.66891 .28814 L
.6691 .28816 L
.6693 .28819 L
.66949 .28821 L
.66968 .28823 L
.66987 .28825 L
.67006 .28827 L
.67024 .28829 L
.67044 .28831 L
.67063 .28833 L
.67082 .28835 L
.67101 .28838 L
.6712 .2884 L
.67139 .28842 L
.67158 .28844 L
.67178 .28846 L
.67198 .28849 L
.67216 .28851 L
.67236 .28853 L
.67255 .28855 L
.67273 .28858 L
.67293 .2886 L
.67311 .28862 L
.67331 .28865 L
.67351 .28867 L
.67369 .28869 L
.67389 .28872 L
.67408 .28874 L
.67426 .28876 L
.67445 .28879 L
.67464 .28881 L
.67484 .28884 L
.67503 .28886 L
.67521 .28888 L
Mistroke
.6754 .28891 L
.67559 .28893 L
.67579 .28896 L
.67599 .28898 L
.67617 .28901 L
.67637 .28903 L
.67656 .28906 L
.67674 .28908 L
.67693 .28911 L
.67712 .28913 L
.67732 .28916 L
.67751 .28919 L
.6777 .28921 L
.67789 .28924 L
.67808 .28927 L
.67826 .28929 L
.67845 .28932 L
.67864 .28934 L
.67884 .28937 L
.67903 .2894 L
.67921 .28942 L
.67941 .28945 L
.67959 .28948 L
.67979 .28951 L
.67999 .28953 L
.68017 .28956 L
.68037 .28959 L
.68056 .28962 L
.68074 .28965 L
.68093 .28967 L
.68112 .2897 L
.68132 .28973 L
.68151 .28976 L
.68169 .28979 L
.68189 .28982 L
.68208 .28985 L
.68228 .28988 L
.68247 .28991 L
.68265 .28993 L
.68285 .28997 L
.68304 .28999 L
.68322 .29002 L
.68342 .29005 L
.68361 .29008 L
.6838 .29011 L
.684 .29015 L
.68418 .29017 L
.68438 .29021 L
.68457 .29024 L
.68475 .29027 L
Mistroke
.68494 .2903 L
.68513 .29033 L
.68533 .29036 L
.68552 .29039 L
.6857 .29042 L
.68589 .29045 L
.68608 .29049 L
.68628 .29052 L
.68647 .29055 L
.68666 .29058 L
.68686 .29062 L
.68705 .29065 L
.68723 .29068 L
.68742 .29071 L
.68761 .29074 L
.68781 .29078 L
.688 .29081 L
.68818 .29084 L
.68838 .29088 L
.68857 .29091 L
.68877 .29095 L
.68896 .29098 L
.68915 .29101 L
.68934 .29105 L
.68953 .29108 L
.68972 .29112 L
.68991 .29115 L
.6901 .29119 L
.6903 .29122 L
.69048 .29125 L
Mfstroke
.69048 .29125 m
.69066 .29129 L
.69086 .29133 L
.69106 .29136 L
.69124 .29139 L
.69143 .29143 L
.69162 .29147 L
.69182 .2915 L
.69201 .29154 L
.6922 .29157 L
.69239 .29161 L
.69258 .29165 L
.69276 .29168 L
.69296 .29172 L
.69314 .29176 L
.69334 .29179 L
.69353 .29183 L
.69372 .29187 L
.69391 .29191 L
.6941 .29194 L
.6943 .29198 L
.69449 .29202 L
.69468 .29206 L
.69488 .2921 L
.69507 .29213 L
.69525 .29217 L
.69544 .29221 L
.69563 .29225 L
.69583 .29229 L
.69602 .29233 L
.69621 .29237 L
.6964 .29241 L
.69659 .29244 L
.69677 .29248 L
.69697 .29252 L
.69715 .29256 L
.69735 .2926 L
.69754 .29264 L
.69772 .29268 L
.69792 .29272 L
.69811 .29276 L
.69831 .2928 L
.6985 .29285 L
.69868 .29289 L
.69888 .29293 L
.69907 .29297 L
.69925 .29301 L
.69945 .29305 L
.69963 .29309 L
.69983 .29313 L
Mistroke
.70002 .29318 L
.70021 .29322 L
.7004 .29326 L
.70059 .2933 L
.70079 .29335 L
.70098 .29339 L
.70117 .29343 L
.70137 .29348 L
.70156 .29352 L
.70174 .29356 L
.70193 .2936 L
.70212 .29365 L
.70232 .29369 L
.70251 .29374 L
.7027 .29378 L
.70289 .29383 L
.70308 .29387 L
.70326 .29391 L
.70346 .29396 L
.70364 .294 L
.70384 .29405 L
.70403 .29409 L
.70422 .29414 L
.70441 .29418 L
.7046 .29423 L
.7048 .29427 L
.70499 .29432 L
.70518 .29437 L
.70538 .29441 L
.70557 .29446 L
.70575 .2945 L
.70594 .29455 L
.70613 .2946 L
.70633 .29465 L
.70652 .29469 L
.7067 .29474 L
.7069 .29479 L
.70709 .29483 L
.70727 .29488 L
.70746 .29493 L
.70765 .29497 L
.70785 .29502 L
.70804 .29507 L
.70822 .29512 L
.70841 .29517 L
.7086 .29522 L
.7088 .29527 L
.70899 .29532 L
.70918 .29536 L
.70938 .29542 L
Mistroke
.70956 .29546 L
.70975 .29551 L
.70994 .29556 L
.71013 .29561 L
.71033 .29566 L
.71052 .29571 L
.7107 .29576 L
.7109 .29581 L
.71108 .29586 L
.71128 .29592 L
.71148 .29597 L
.71166 .29602 L
.71186 .29607 L
.71205 .29612 L
.71223 .29617 L
.71243 .29623 L
.71261 .29628 L
.71281 .29633 L
.71301 .29638 L
.71319 .29644 L
.71339 .29649 L
.71357 .29654 L
.71376 .29659 L
.71395 .29665 L
.71414 .2967 L
.71433 .29675 L
.71452 .29681 L
.71471 .29686 L
.7149 .29692 L
.71509 .29697 L
.71529 .29703 L
.71548 .29708 L
.71567 .29713 L
.71587 .29719 L
.71606 .29725 L
.71624 .2973 L
.71643 .29735 L
.71662 .29741 L
.71682 .29747 L
.71701 .29752 L
.71719 .29758 L
.71739 .29763 L
.71758 .29769 L
.71778 .29775 L
.71797 .29781 L
.71816 .29786 L
.71835 .29792 L
.71854 .29798 L
.71873 .29803 L
.71892 .29809 L
Mistroke
.71911 .29815 L
.71931 .29821 L
.7195 .29827 L
.71968 .29833 L
.71988 .29839 L
.72007 .29844 L
.72025 .2985 L
.72045 .29856 L
.72063 .29862 L
.72083 .29868 L
.72102 .29874 L
.72121 .2988 L
.7214 .29886 L
.72159 .29892 L
.72179 .29898 L
.72198 .29904 L
.72217 .2991 L
.72236 .29916 L
.72255 .29922 L
.72274 .29928 L
.72293 .29935 L
.72312 .29941 L
.72332 .29947 L
.72351 .29953 L
.72369 .29959 L
.72389 .29966 L
.72408 .29972 L
.72426 .29978 L
.72445 .29984 L
.72464 .2999 L
.72484 .29997 L
.72503 .30003 L
.72521 .30009 L
.7254 .30016 L
.72559 .30022 L
.72579 .30029 L
.72598 .30035 L
.72617 .30042 L
.72637 .30048 L
.72656 .30055 L
.72674 .30061 L
.72693 .30068 L
.72712 .30074 L
.72732 .30081 L
.72751 .30087 L
.72769 .30094 L
.72789 .30101 L
.72808 .30107 L
.72828 .30114 L
.72847 .30121 L
Mistroke
.72865 .30127 L
.72885 .30134 L
.72904 .30141 L
.72922 .30148 L
.72942 .30154 L
.72961 .30161 L
.72981 .30168 L
.73 .30175 L
.73018 .30182 L
.73038 .30189 L
.73057 .30196 L
.73075 .30202 L
.73094 .30209 L
.73113 .30216 L
.73133 .30223 L
.73152 .3023 L
.7317 .30237 L
.7319 .30244 L
.73208 .30251 L
.73228 .30259 L
.73248 .30266 L
.73266 .30273 L
.73286 .3028 L
.73305 .30287 L
.73323 .30294 L
.73343 .30301 L
.73361 .30308 L
.73381 .30316 L
.734 .30323 L
.73419 .3033 L
.73438 .30338 L
.73457 .30345 L
.73475 .30352 L
.73495 .30359 L
.73513 .30367 L
.73533 .30374 L
.73552 .30382 L
.7357 .30389 L
.7359 .30397 L
.73609 .30404 L
.73628 .30412 L
.73648 .30419 L
.73666 .30427 L
.73686 .30434 L
.73705 .30442 L
.73723 .30449 L
.73742 .30457 L
.73761 .30464 L
.73781 .30472 L
.738 .3048 L
Mistroke
.73818 .30488 L
.73838 .30496 L
.73857 .30503 L
.73877 .30511 L
.73896 .30519 L
.73914 .30527 L
.73934 .30535 L
.73953 .30543 L
.73971 .3055 L
.73991 .30559 L
.7401 .30566 L
.7403 .30575 L
.74049 .30583 L
.74067 .3059 L
.74087 .30599 L
.74106 .30607 L
.74124 .30614 L
.74143 .30623 L
.74162 .3063 L
.74182 .30639 L
.74201 .30647 L
.74219 .30655 L
.74238 .30663 L
.74257 .30671 L
.74277 .3068 L
.74296 .30688 L
.74315 .30696 L
.74335 .30705 L
.74354 .30713 L
.74372 .30721 L
.74391 .3073 L
.7441 .30738 L
.7443 .30747 L
.74449 .30755 L
.74467 .30764 L
.74487 .30772 L
.74506 .30781 L
.74526 .3079 L
.74545 .30798 L
.74564 .30807 L
.74583 .30816 L
.74602 .30824 L
.74621 .30833 L
.7464 .30842 L
.74659 .3085 L
.74679 .30859 L
.74698 .30868 L
.74716 .30877 L
.74736 .30886 L
.74755 .30895 L
Mistroke
.74773 .30903 L
.74793 .30912 L
.74811 .30921 L
.74831 .3093 L
.7485 .30939 L
.74868 .30948 L
.74888 .30957 L
.74907 .30966 L
.74927 .30975 L
.74946 .30985 L
.74965 .30993 L
.74984 .31003 L
.75003 .31012 L
.75022 .31021 L
.75041 .3103 L
.7506 .31039 L
.7508 .31049 L
.75099 .31058 L
.75117 .31067 L
.75137 .31077 L
.75156 .31086 L
.75174 .31095 L
.75193 .31105 L
.75212 .31114 L
.75231 .31124 L
.7525 .31133 L
.75269 .31142 L
.75288 .31152 L
.75307 .31162 L
.75327 .31172 L
.75346 .31181 L
.75365 .31191 L
.75384 .31201 L
.75403 .3121 L
.75422 .3122 L
.75441 .3123 L
.7546 .31239 L
.75479 .31249 L
.75499 .31259 L
.75517 .31269 L
.75536 .31279 L
.75555 .31289 L
.75575 .31299 L
.75595 .31309 L
.75613 .31319 L
.75633 .31329 L
.75652 .31339 L
.7567 .31349 L
.7569 .31359 L
.75708 .31369 L
Mistroke
.75728 .3138 L
.75747 .3139 L
.75766 .314 L
.75785 .31411 L
.75804 .31421 L
.75823 .31431 L
.75842 .31441 L
.75861 .31451 L
.7588 .31462 L
.75899 .31472 L
.75918 .31483 L
.75937 .31493 L
.75956 .31504 L
.75976 .31515 L
.75995 .31525 L
.76014 .31536 L
.76033 .31547 L
.76052 .31557 L
.76071 .31567 L
.7609 .31578 L
.76109 .31589 L
.76129 .316 L
.76148 .31611 L
.76166 .31621 L
.76186 .31632 L
.76205 .31643 L
.76225 .31655 L
.76244 .31666 L
.76263 .31676 L
.76282 .31688 L
.76301 .31699 L
.7632 .3171 L
.76339 .31721 L
.76358 .31732 L
.76378 .31743 L
.76397 .31755 L
.76416 .31766 L
.76435 .31777 L
.76454 .31788 L
.76472 .31799 L
.76492 .31811 L
.7651 .31822 L
.7653 .31834 L
.76549 .31845 L
.76568 .31856 L
.76587 .31868 L
.76606 .31879 L
.76626 .31891 L
.76645 .31903 L
.76664 .31914 L
Mistroke
.76683 .31926 L
.76702 .31938 L
.76721 .31949 L
.7674 .31961 L
.76759 .31973 L
.76779 .31985 L
.76798 .31997 L
.76816 .32009 L
.76836 .32021 L
.76855 .32033 L
.76873 .32044 L
.76892 .32056 L
.76911 .32068 L
.76931 .3208 L
.7695 .32093 L
.76968 .32104 L
.76988 .32117 L
.77006 .32129 L
.77026 .32141 L
.77046 .32154 L
.77064 .32166 L
.77084 .32178 L
.77103 .32191 L
.77121 .32203 L
.7714 .32215 L
.77159 .32227 L
.77179 .3224 L
.77198 .32253 L
.77216 .32265 L
.77236 .32278 L
.77255 .32291 L
.77275 .32304 L
.77294 .32317 L
.77313 .32329 L
.77332 .32342 L
.77351 .32355 L
.7737 .32367 L
.77389 .32381 L
.77408 .32393 L
.77428 .32407 L
.77447 .3242 L
.77465 .32432 L
.77485 .32446 L
.77504 .32459 L
.77522 .32471 L
.77542 .32485 L
.7756 .32498 L
.7758 .32511 L
.77599 .32525 L
.77617 .32537 L
Mistroke
.77637 .32551 L
.77656 .32564 L
.77676 .32578 L
.77695 .32592 L
.77714 .32605 L
.77733 .32619 L
.77752 .32632 L
.7777 .32645 L
.7779 .32659 L
.77809 .32673 L
.77828 .32687 L
.77848 .32701 L
.77866 .32714 L
.77886 .32728 L
.77904 .32742 L
.77923 .32755 L
.77942 .32769 L
.7796 .32783 L
.7798 .32797 L
.77999 .32811 L
.78018 .32825 L
.78037 .32839 L
.78056 .32853 L
.78076 .32868 L
.78095 .32883 L
.78114 .32896 L
.78133 .32911 L
.78152 .32925 L
.7817 .32939 L
.7819 .32954 L
.78208 .32968 L
.78228 .32983 L
.78247 .32998 L
.78266 .33012 L
.78285 .33027 L
.78304 .33041 L
.78324 .33056 L
.78343 .33071 L
.78362 .33086 L
.78382 .33101 L
.78401 .33116 L
.78419 .3313 L
.78438 .33145 L
.78457 .3316 L
.78477 .33176 L
.78496 .33191 L
.78515 .33206 L
.78534 .33221 L
.78553 .33236 L
.78571 .33251 L
Mistroke
.78571 .33251 L
Mfstroke
.78571 .33251 m
.7859 .33266 L
.7861 .33282 L
.78629 .33297 L
.78648 .33312 L
.78667 .33328 L
.78686 .33343 L
.78706 .33359 L
.78725 .33375 L
.78743 .3339 L
.78763 .33406 L
.78782 .33422 L
.788 .33437 L
.7882 .33453 L
.78838 .33468 L
.78858 .33485 L
.78877 .33501 L
.78896 .33516 L
.78915 .33532 L
.78934 .33548 L
.78954 .33565 L
.78973 .33581 L
.78992 .33597 L
.79011 .33614 L
.7903 .3363 L
.79049 .33646 L
.79068 .33662 L
.79087 .33678 L
.79107 .33695 L
.79126 .33712 L
.79144 .33728 L
.79164 .33745 L
.79183 .33761 L
.79201 .33777 L
.7922 .33794 L
.79239 .33811 L
.79259 .33828 L
.79278 .33845 L
.79296 .33861 L
.79316 .33878 L
.79334 .33895 L
.79354 .33913 L
.79374 .3393 L
.79392 .33947 L
.79412 .33964 L
.79431 .33981 L
.79449 .33998 L
.79468 .34016 L
.79487 .34033 L
.79507 .34051 L
Mistroke
.79526 .34068 L
.79544 .34085 L
.79564 .34103 L
.79583 .3412 L
.79603 .34139 L
.79622 .34157 L
.79641 .34174 L
.7966 .34192 L
.79679 .3421 L
.79698 .34227 L
.79717 .34246 L
.79736 .34263 L
.79756 .34282 L
.79775 .343 L
.79794 .34318 L
.79813 .34337 L
.79832 .34355 L
.7985 .34372 L
.7987 .34391 L
.79888 .34409 L
.79908 .34428 L
.79927 .34446 L
.79946 .34464 L
.79965 .34483 L
.79984 .34501 L
.80004 .34521 L
.80023 .3454 L
.80042 .34558 L
.80061 .34577 L
.8008 .34596 L
.80099 .34614 L
.80118 .34634 L
.80137 .34652 L
.80157 .34672 L
.80176 .34691 L
.80194 .3471 L
.80214 .3473 L
.80233 .34749 L
.80251 .34767 L
.8027 .34787 L
.80289 .34806 L
.80308 .34826 L
.80327 .34846 L
.80346 .34864 L
.80365 .34884 L
.80384 .34904 L
.80404 .34925 L
.80423 .34944 L
.80442 .34964 L
.80461 .34984 L
Mistroke
.8048 .35004 L
.80498 .35023 L
.80518 .35044 L
.80537 .35063 L
.80556 .35084 L
.80575 .35105 L
.80594 .35124 L
.80613 .35145 L
.80632 .35165 L
.80652 .35187 L
.80672 .35208 L
.8069 .35228 L
.8071 .35249 L
.80729 .3527 L
.80747 .3529 L
.80767 .35311 L
.80785 .35331 L
.80805 .35353 L
.80824 .35374 L
.80843 .35395 L
.80862 .35416 L
.80881 .35437 L
.80899 .35458 L
.80919 .35479 L
.80937 .355 L
.80957 .35522 L
.80976 .35544 L
.80995 .35564 L
.81014 .35586 L
.81033 .35608 L
.81053 .3563 L
.81072 .35652 L
.81091 .35674 L
.8111 .35696 L
.81129 .35718 L
.81148 .35739 L
.81167 .35761 L
.81186 .35783 L
.81206 .35806 L
.81225 .35829 L
.81243 .3585 L
.81263 .35873 L
.81281 .35895 L
.81302 .35919 L
.81321 .35942 L
.81339 .35964 L
.81359 .35987 L
.81378 .3601 L
.81396 .36032 L
.81416 .36055 L
Mistroke
.81435 .36078 L
.81455 .36102 L
.81474 .36125 L
.81492 .36147 L
.81512 .36171 L
.81531 .36194 L
.81549 .36216 L
.81568 .3624 L
.81587 .36263 L
.81607 .36288 L
.81626 .36311 L
.81644 .36334 L
.81664 .36358 L
.81683 .36382 L
.81703 .36407 L
.81722 .36431 L
.8174 .36454 L
.8176 .36479 L
.81779 .36503 L
.81797 .36526 L
.81817 .36551 L
.81836 .36575 L
.81855 .366 L
.81875 .36625 L
.81893 .36648 L
.81913 .36673 L
.81932 .36698 L
.8195 .36721 L
.81969 .36746 L
.81988 .36771 L
.82007 .36797 L
.82026 .36822 L
.82045 .36846 L
.82064 .36871 L
.82083 .36896 L
.82103 .36922 L
.82122 .36948 L
.82141 .36973 L
.8216 .36999 L
.82179 .37024 L
.82198 .37049 L
.82217 .37075 L
.82236 .371 L
.82255 .37127 L
.82275 .37153 L
.82293 .37178 L
.82313 .37205 L
.82331 .37231 L
.82351 .37258 L
.82371 .37285 L
Mistroke
.82389 .3731 L
.82409 .37338 L
.82428 .37364 L
.82446 .37389 L
.82466 .37417 L
.82484 .37443 L
.82504 .37471 L
.82524 .37498 L
.82542 .37524 L
.82562 .37552 L
.82581 .37578 L
.82599 .37604 L
.82618 .37632 L
.82637 .37659 L
.82657 .37687 L
.82676 .37715 L
.82694 .37741 L
.82714 .37769 L
.82732 .37797 L
.82752 .37826 L
.82772 .37854 L
.8279 .37881 L
.8281 .3791 L
.82829 .37938 L
.82847 .37965 L
.82866 .37994 L
.82885 .38021 L
.82905 .38051 L
.82924 .38079 L
.82942 .38107 L
.82962 .38136 L
.82981 .38165 L
.82999 .38192 L
.83018 .38221 L
.83037 .3825 L
.83057 .3828 L
.83076 .38309 L
.83094 .38337 L
.83114 .38367 L
.83132 .38396 L
.83152 .38426 L
.83171 .38456 L
.8319 .38485 L
.8321 .38516 L
.83229 .38545 L
.83247 .38574 L
.83266 .38604 L
.83285 .38633 L
.83305 .38665 L
.83324 .38695 L
Mistroke
.83342 .38724 L
.83362 .38755 L
.8338 .38785 L
.834 .38817 L
.8342 .38848 L
.83438 .38878 L
.83458 .3891 L
.83477 .38941 L
.83495 .3897 L
.83515 .39002 L
.83533 .39033 L
.83553 .39065 L
.83573 .39097 L
.83591 .39127 L
.83611 .3916 L
.83629 .39191 L
.83648 .39221 L
.83667 .39253 L
.83686 .39284 L
.83705 .39317 L
.83724 .3935 L
.83743 .3938 L
.83762 .39413 L
.83781 .39445 L
.83801 .39479 L
.8382 .39512 L
.83839 .39544 L
.83858 .39577 L
.83877 .3961 L
.83896 .39641 L
.83915 .39675 L
.83934 .39707 L
.83954 .39742 L
.83973 .39775 L
.83991 .39807 L
.84011 .39841 L
.8403 .39875 L
.8405 .3991 L
.84069 .39944 L
.84087 .39977 L
.84107 .40012 L
.84126 .40046 L
.84144 .40079 L
.84164 .40114 L
.84183 .40147 L
.84203 .40183 L
.84222 .40218 L
.8424 .40251 L
.8426 .40287 L
.84279 .40322 L
Mistroke
.84297 .40355 L
.84316 .4039 L
.84335 .40425 L
.84355 .40461 L
.84374 .40497 L
.84392 .40531 L
.84412 .40567 L
.84431 .40602 L
.84451 .40639 L
.8447 .40676 L
.84488 .4071 L
.84508 .40748 L
.84527 .40784 L
.84545 .40818 L
.84565 .40855 L
.84583 .40891 L
.84603 .40929 L
.84622 .40966 L
.84641 .41001 L
.84661 .41039 L
.84679 .41076 L
.84698 .41111 L
.84717 .41148 L
.84735 .41185 L
.84755 .41224 L
.84774 .41261 L
.84793 .41297 L
.84812 .41335 L
.84831 .41373 L
.84851 .41412 L
.8487 .41451 L
.84889 .41488 L
.84908 .41527 L
.84927 .41565 L
.84945 .41602 L
.84965 .41641 L
.84983 .41679 L
.85003 .41719 L
.85022 .41758 L
.85041 .41796 L
.8506 .41836 L
.85079 .41874 L
.85099 .41916 L
.85118 .41956 L
.85137 .41994 L
.85157 .42035 L
.85176 .42075 L
.85194 .42113 L
.85213 .42154 L
.85232 .42193 L
Mistroke
.85252 .42235 L
.85271 .42276 L
.8529 .42315 L
.85309 .42357 L
.85328 .42397 L
.85346 .42436 L
.85366 .42477 L
.85384 .42517 L
.85404 .4256 L
.85423 .42601 L
.85442 .42641 L
.85461 .42684 L
.8548 .42725 L
.855 .42769 L
.85519 .42811 L
.85538 .42852 L
.85557 .42895 L
.85576 .42937 L
.85594 .42978 L
.85614 .43021 L
.85633 .43063 L
.85652 .43107 L
.85672 .4315 L
.8569 .43192 L
.8571 .43236 L
.85728 .43279 L
.85748 .43324 L
.85768 .43368 L
.85786 .43411 L
.85806 .43456 L
.85825 .435 L
.85843 .43542 L
.85863 .43587 L
.85882 .43631 L
.85902 .43677 L
.85921 .43722 L
.85939 .43765 L
.85959 .43811 L
.85978 .43856 L
.85996 .43899 L
.86015 .43945 L
.86034 .43989 L
.86054 .44036 L
.86073 .44082 L
.86091 .44126 L
.86111 .44173 L
.8613 .44218 L
.8615 .44267 L
.86169 .44313 L
.86188 .44358 L
Mistroke
.86207 .44406 L
.86226 .44453 L
.86245 .44498 L
.86264 .44545 L
.86283 .44592 L
.86303 .44641 L
.86322 .44688 L
.8634 .44734 L
.8636 .44783 L
.86379 .4483 L
.86397 .44876 L
.86416 .44925 L
.86435 .44971 L
.86455 .45022 L
.86474 .4507 L
.86492 .45117 L
.86511 .45166 L
.8653 .45215 L
.8655 .45266 L
.86569 .45315 L
.86588 .45363 L
.86608 .45414 L
.86627 .45463 L
.86645 .45511 L
.86664 .45562 L
.86683 .45611 L
.86703 .45663 L
.86722 .45713 L
.8674 .45762 L
.8676 .45814 L
.86779 .45864 L
.86799 .45917 L
.86818 .45969 L
.86836 .46019 L
.86856 .46072 L
.86875 .46123 L
.86894 .46173 L
.86913 .46226 L
.86932 .46277 L
.86952 .46331 L
.86971 .46384 L
.86989 .46434 L
.87009 .46488 L
.87028 .46541 L
.87046 .46591 L
.87065 .46645 L
.87084 .46697 L
.87104 .46752 L
.87123 .46806 L
.87141 .46857 L
Mistroke
.87161 .46912 L
.8718 .46966 L
.872 .47022 L
.87219 .47077 L
.87237 .4713 L
.87257 .47186 L
.87276 .47241 L
.87294 .47293 L
.87314 .4735 L
.87332 .47404 L
.87352 .47461 L
.87371 .47517 L
.8739 .47571 L
.87409 .47628 L
.87428 .47684 L
.87446 .47737 L
.87466 .47795 L
.87484 .4785 L
.87504 .47908 L
.87523 .47965 L
.87541 .4802 L
.87561 .48078 L
.8758 .48135 L
.876 .48195 L
.87619 .48253 L
.87637 .48309 L
.87657 .48369 L
.87676 .48427 L
.87694 .48483 L
.87714 .48542 L
.87732 .486 L
.87752 .48661 L
.87771 .4872 L
.87789 .48778 L
.87809 .48839 L
.87828 .48897 L
.87848 .4896 L
.87867 .49021 L
.87886 .49079 L
.87905 .49142 L
.87924 .49202 L
.87943 .4926 L
.87962 .49322 L
.87981 .49382 L
.88001 .49446 L
.8802 .49508 L
.88038 .49568 L
.88058 .49631 L
.88077 .49693 L
.88095 .49752 L
Mistroke
.88095 .49752 L
Mfstroke
.88095 .49753 m
.88114 .49813 L
.88134 .4988 L
.88153 .49942 L
s
.88153 .49942 m
.88171 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{408, 204},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006H0000c2000`400?l00000o`00003oo`3ooonI
0?ooo`00o`3ooonI0?ooo`00o`3ooonI0?ooo`00o`3ooonI0?ooo`00o`3ooonI0?ooo`00f@3oool0
1@000000oooo0?ooo`3oool000000;X0oooo003J0?ooo`040000003oool0oooo00000;X0oooo003K
0?ooo`800000^`3oool00=`0oooo00<000000?ooo`3oool0^@3oool00=/0oooo00<000000?ooo`00
0000^P3oool00=/0oooo00@000000?ooo`3oool00000^@3oool00?l0ooooV@3oool00?l0ooooV@3o
ool00?l0ooooV@3oool00?l0ooooV@3oool00?l0ooooV@3oool006D0oooo00<000000?ooo`3oool0
=`3oool5000003H0oooo0`00000j0?ooo`D00000>`3oool00`000000oooo0?ooo`0n0?ooo`00I@3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P00
000i0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?P3oool005`0oooo1@000000
0`3oool000000000000400000340oooo1@0000020?ooo`030000003oool0oooo03H0oooo00D00000
0?ooo`3oool0oooo0000000j0?ooo`030000003oool0oooo03T0oooo1P00000n0?ooo`00H`3oool0
10000000oooo0?ooo`00000j0?ooo`800000=P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03P0oooo0P00000j0?ooo`040000003oool0oooo000003l0oooo001T0?ooo`030000003o
ool0000003`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0>03oool00`000000oooo0000000o0?ooo`00I@3oool0
0`000000oooo0000000l0?ooo`030000003oool0oooo03<0oooo00D000000?ooo`3oool0oooo0000
000m0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`000000?P3oool006H0oooo0P00000h
0?ooo`050000003oool0oooo0?ooo`000000=@3oool200000080oooo00<000000?ooo`3oool0=`3o
ool01@000000oooo0?ooo`3oool0000003/0oooo0P00000n0?ooo`00I`3oool00`000000oooo0?oo
o`0g0?ooo`<00000=`3oool3000003/0oooo0`00000m0?ooo`030000003oool0oooo03`0oooo003o
0?oooiT0oooo003o0?oooiT0oooo000`0?ooo`<00000o`3ooomV0?ooo`00;`3oool01@000000oooo
0?ooo`3oool0000000L0oooo1`0000000`3o000000000000000L000000030?l000000000000001d0
000000<0o`00000000000000600000000`3o000000000000000T000000030?l00000000000000100
000000<0o`00000000000000Y@00000J0?ooo`00:@3oool5000000030?ooo`000000oooo0080oooo
00<000000?ooo`3oool01@3oool3000000@0oooo00<0o`000?ooo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000o`00
0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00@0o`000?ooo`3oool000003P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01P0oooo000_0?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3o
ool07@3oool00`3o0000oooo0?ooo`0H0?ooo`040?l0003oool0oooo000002<0oooo00<0o`000?oo
o`3oool0403oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000_0?ooo`@0
0000203oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3o
ool07@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3o
ool0403oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3o
ool0603oool00300oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo01`0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo02@0oooo0P3o000A0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0H0?ooo`00<03oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo01d0oooo
00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00l0oooo
00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo
000a0?ooo`<000001`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0oooo00<0
o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02D0oooo00<0
o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0603oool003/0oooo0P0000050?ooo`030?l0003oool0oooo01`0oooo00<0o`00
0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02D0oooo00<0o`00
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0L0?oo
o`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0U0?oo
o`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`2N0?oo
o`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0703oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3o
ool09@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo01`0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo02D0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`040?ooo`030000
003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool0603o
ool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0103o
ool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0
oooo00@0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0
oooo01P0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00@0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`00
0000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool07@3oool00`3o
0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`040?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003/0
oooo0P0000050?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool07@3oool00`3o0000
oooo0?ooo`0H0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`040?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003/0oooo
00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo01d0oooo
00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00`0oooo
0P3o00060?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003/0oooo00<0
00000?ooo`3oool0103oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo01d0oooo00<0
o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00`0oooo00<0
o`000?ooo`3oool01@3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000k
0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0M
0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H
0?ooo`00>`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0oooo00<0o`000?oo
o`3oool07@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?oo
o`3oool0303oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo09h0oooo00<000000?oo
o`3oool0603oool003/0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0L0?ooo`03
0?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0W0?ooo`03
0?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`2N0?ooo`03
0000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0
703oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool0
9`3oool00`3o0000oooo0?ooo`0:0?ooo`80o`001`3oool00`000000oooo0?ooo`2N0?ooo`030000
003oool0oooo01P0oooo000k0?ooo`8000001@3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003o
ool0oooo01d0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo01P0oooo000k0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0703oool0
0`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool0:03oool0
0`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool0WP3oool0
0`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo
01`0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo
02P0oooo0P3o000;0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0
oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo02T0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0L0?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo
0?ooo`0Y0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000b0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo01d0oooo00<0
o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool01`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000b
0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030?l0003oool0oooo01/0oooo00<0o`00
0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo02T0oooo0P3o0009
0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H
0?ooo`00:@3oool5000000030?ooo`000000000000@000001P3oool00`000000oooo0?ooo`050?oo
o`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0G0?oo
o`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?oo
o`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool00300oooo00@000000?ooo`3o
ool000001`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01/0oooo00<0o`000?oo
o`3oool07@3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo02X0oooo0P3o00070?oo
o`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?oo
o`00<@3oool00`000000oooo000000070?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3o
ool06`3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3o
ool0:`3oool00`3o0000oooo0?ooo`040?ooo`80o`002P3oool00`000000oooo0?ooo`2N0?ooo`03
0000003oool0oooo01P0oooo000b0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`0[0?ooo`80o`001@3oool00`3o0000oooo0?ooo`090?ooo`030000
003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003<0oooo0P0000060?ooo`030000003o
ool0oooo00D0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003o
ool0oooo01L0oooo00<0o`000?ooo`3oool0;03oool20?l000<0oooo00<0o`000?ooo`3oool02P3o
ool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000d0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0
oooo01d0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0]0?ooo`D0o`00303oool0
0`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000k0?ooo`8000001P3oool00`3o
0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool05P3oool00`3o
0000oooo0?ooo`0n0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003/0
oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01h0
oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool05@3oool20?l00400oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?oo
o`050?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?oo
o`0E0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?oo
o`0H0?ooo`00>`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01/0oooo00<0o`00
0?ooo`3oool07P3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo03l0oooo00<00000
0?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`050?oo
o`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0E0?oo
o`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?oo
o`00>`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3o
ool07P3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool2000000H0oooo00<0o`000?ooo`3oool0
6`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0
?`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003o
ool0oooo00D0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003o
ool0oooo01D0oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo01P0oooo000k0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool06`3oool0
0`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo
00D0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo
01D0oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo
01P0oooo000k0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool06`3oool00`3o0000
oooo0?ooo`0N0?ooo`030?l0003oool0oooo01@0oooo0P3o00110?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo
0?ooo`100?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003/0oooo0P00
00060?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?oo
o`0D0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?oo
o`0H0?ooo`00>`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01/0oooo00<0o`00
0?ooo`3oool07P3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0400oooo00<00000
0?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`050?oo
o`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?oo
o`00>`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3o
ool07P3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`050?ooo`030?l0
003oool0oooo01/0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0B0?ooo`80o`00
@P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000_0?ooo`D000001`3o
ool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool07`3o
ool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0H0?ooo`00;`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00D0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0
oooo0180oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo01P0oooo000Y0?ooo`D000000P3oool00`000000oooo0?ooo`080?ooo`<000001@3oool00`3o
0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool04P3oool00`3o
0000oooo0?ooo`110?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool00340
oooo0P0000080?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool06`3oool00`3o0000
oooo0?ooo`0O0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool0@@3oool00`000000
oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000c0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01l0oooo
00<0o`000?ooo`3oool04@3oool20?l004<0oooo00<000000?ooo`3oool0WP3oool00`000000oooo
0?ooo`0H0?ooo`00=03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0140oooo00<0
o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000`
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030?l0003o
ool0oooo01X0oooo00<0o`000?ooo`3oool0803oool20?l00180oooo00<0o`000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000a0?ooo`<000001`3oool0
0`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`0?0?ooo`80o`00A03oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo01P0oooo000k0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool06P3oool00`3o
0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000k0?ooo`8000001P3oool00`3o0000
oooo0?ooo`0J0?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool03P3oool20?l004D0
oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo
0?ooo`050?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool08@3oool20?l000l0oooo
00<0o`000?ooo`3oool0A03oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo
000k0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?oo
o`0R0?ooo`030?l0003oool0oooo00`0oooo0P3o00160?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0J
0?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`15
0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?oo
o`3oool02P3oool20?l004L0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?oo
o`00>`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3o
ool08`3oool20?l000X0oooo0P3o00180?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3o
ool0603oool003/0oooo0P0000060?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool0
903oool20?l000L0oooo0`3o00190?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0
603oool003/0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003o
ool0oooo02D0oooo0`3o00030?ooo`<0o`00B`3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo01P0oooo000k0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool06P3oool0
0`3o0000oooo0?ooo`0W0?ooo`D0o`00C@3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo01P0oooo000k0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool06P3oool00`3o
0000oooo0?ooo`1i0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003/0
oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0I0?ooo`80o`00N`3oool00`000000
oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo00D0oooo
00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`1j0?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0I0?ooo`030?l0003oool0oooo07X0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?oo
o`0H0?ooo`00>`3oool2000000H0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`1j
0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0H0?ooo`80o`00O03oool00`000000oooo0?ooo`2N0?oo
o`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3o
ool0603oool00`3o0000oooo0?ooo`1k0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3o
ool0603oool003/0oooo00<000000?ooo`3oool01@3oool20?l001P0oooo0P3o001m0?ooo`030000
003oool0oooo09h0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0D0?ooo`<0o`00OP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo01P0oooo000`0?ooo`<00000203oool00`000000oooo0?ooo`060?ooo`@0o`00303oool0
0`3o0000oooo0?l000050?l00800oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H
0?ooo`008P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo008000001`3oool00`00
0000oooo0?ooo`080?oooa40o`00Q@3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo
01P0oooo000R0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000070?oo
ool00000A000000J0?ooo`008P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0603oool002<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0WP3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000S0?ooo`030000003oool0oooo00X0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo02X0oooo2`3o001Y0?ooo`030000
003oool0oooo09h0oooo00<000000?ooo`3oool0603oool00280oooo0`00000;0?ooo`8000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02P0oooo0`3o00090?ooo`@0o`00IP3o
ool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000S0?ooo`030000003oool0
oooo00/0oooo0`0000070?ooo`030000003oool0oooo02L0oooo0P3o000>0?ooo`<0o`00I03oool0
0`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000T0?ooo`8000005@3oool20000
02L0oooo0P3o000A0?ooo`80o`00H`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo
01P0oooo000k0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool04@3oool20?l00680
oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo
0?ooo`0U0?ooo`80o`00503oool20?l00640oooo00<000000?ooo`3oool0WP3oool00`000000oooo
0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo01@0oooo00<0
o`000?ooo`3oool0G`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo01P0oooo000k
0?ooo`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool0503oool20?l00600oooo00<00000
0?ooo`3oool0WP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`0U0?oo
o`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0GP3oool00`000000oooo0?ooo`0T0?oo
o`030?l0003oool0o`0000P0o`0000<0oooo0?l0003oool0K03oool00`000000oooo0?ooo`0H0?oo
o`00>`3oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0N0?ooo`T0o`00203oool;0?l006@0oooo00<000000?ooo`3o
ool0603oool003/0oooo0P00000V0?ooo`030?l0003oool0oooo01D0oooo0P3o001O0?ooo`030000
003oool0oooo01X0oooo1@3o000I0?ooo`L0o`00G`3oool00`000000oooo0?ooo`0H0?ooo`00>`3o
ool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0G0?ooo`@0o`008`3oool50?l005/0oooo00<000000?ooo`3oool0603o
ool003/0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0
oooo05d0oooo00<000000?ooo`3oool05@3oool30?l002X0oooo1@3o001G0?ooo`030000003oool0
oooo01P0oooo000k0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool05`3oool00`3o
0000oooo0?ooo`1M0?ooo`030000003oool0oooo01<0oooo0`3o000_0?ooo`@0o`00E@3oool00`00
0000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo01L0
oooo00<0o`000?ooo`3oool0G@3oool00`000000oooo0?ooo`0B0?ooo`80o`00=03oool30?l005<0
oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool0903oool00`3o0000oooo
0?ooo`0H0?ooo`030?l0003oool0oooo05`0oooo00<000000?ooo`3oool04@3oool20?l003L0oooo
103o001@0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo02@0oooo00<0
o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`1L0?ooo`030000003oool0oooo0100oooo0P3o
000k0?ooo`<0o`00CP3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool2000002D0oooo00<0o`00
0?ooo`3oool0603oool00`3o0000oooo0?ooo`1L0?ooo`030000003oool0oooo00l0oooo00<0o`00
0?ooo`3oool0?@3oool30?l004`0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?oo
o`3oool0903oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo05`0oooo00<000000?oo
o`3oool03P3oool00`3o0000oooo0?ooo`100?ooo`80o`00B`3oool00`000000oooo0?ooo`0H0?oo
o`00>`3oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3o
ool0G03oool00`000000oooo0?ooo`0=0?ooo`80o`00A03oool20?l004T0oooo00<000000?ooo`3o
ool0603oool003/0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo05`0oooo00<000000?ooo`3oool0303oool20?l004H0oooo0`3o00170?ooo`030000
003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool0603o
ool00`3o0000oooo0?ooo`1L0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool0A`3o
ool20?l004H0oooo00<000000?ooo`3oool0603oool002l0oooo1@0000070?ooo`030000003oool0
oooo02@0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`1L0?ooo`030000003oool0
oooo00/0oooo0P3o001:0?ooo`80o`00A@3oool00`000000oooo0?ooo`0H0?ooo`00;`3oool00`00
0000oooo0?ooo`090?ooo`<00000903oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo
05/0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`1:0?ooo`<0o`00@`3oool00`00
0000oooo0?ooo`0H0?ooo`00<03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02@0
oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`1K0?ooo`030000003oool0oooo00X0
oooo0P3o001>0?ooo`80o`00@P3oool00`000000oooo0?ooo`0H0?ooo`00<@3oool2000000P0oooo
00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo05/0oooo
00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`1>0?ooo`80o`00@@3oool00`000000oooo
0?ooo`0H0?ooo`00<`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00<0
o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`1K0?ooo`030000003oool0oooo00T0oooo0P3o
001A0?ooo`80o`00@03oool00`000000oooo0?ooo`0H0?ooo`00=03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0Z
0?ooo`<0o`00;P3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0540oooo0P3o000o
0?ooo`030000003oool0oooo01P0oooo000`0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool0:03oool2
0?l00080oooo0`3o000/0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0DP3oool2
0?l003h0oooo00<000000?ooo`3oool0603oool00340oooo0`0000070?ooo`030000003oool0oooo
02@0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0W0?ooo`80o`001@3oool00`3o
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00P0oooo0P3o001E0?ooo`80o`00?@3oool00`00
0000oooo0?ooo`0H0?ooo`00>`3oool2000002D0oooo00<0o`000?ooo`3oool06@3oool00`3o0000
oooo0?ooo`0W0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0:@3oool00`000000
oooo0?ooo`080?ooo`030?l0003oool0oooo05D0oooo0P3o000l0?ooo`030000003oool0oooo01P0
oooo000k0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo
0?ooo`0V0?ooo`80o`001`3oool20?l002X0oooo00<000000?ooo`3oool0203oool00`3o0000oooo
0?ooo`1F0?ooo`80o`00>`3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?oo
o`0T0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo02P0oooo00<000000?ooo`3oool01`3oool20?l005T0oooo0P3o
000j0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo02@0oooo00<0o`00
0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0U0?ooo`80o`002@3oool20?l002T0oooo00<00000
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`1I0?ooo`030?l0003oool0oooo03P0oooo00<00000
0?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`0I0?oo
o`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0W0?oo
o`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0FP3oool00`3o0000oooo0?ooo`0g0?oo
o`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3o
ool06@3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00T0oooo0P3o000X0?ooo`03
0000003oool0oooo00L0oooo00<0o`000?ooo`3oool0FP3oool20?l003P0oooo00<000000?ooo`3o
ool0603oool003/0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`0I0?ooo`030?l0
003oool0oooo02@0oooo0P3o000<0?ooo`030?l0003oool0oooo02H0oooo00<000000?ooo`3oool0
1P3oool20?l005d0oooo0P3o000g0?ooo`030000003oool0oooo01P0oooo000k0?ooo`8000009@3o
ool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0G@3o
ool00`3o0000oooo0?ooo`0e0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0
oooo02@0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0
oooo00/0oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0
oooo05h0oooo00<0o`000?ooo`3oool0=03oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`00
0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool0903oool00`3o
0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`1N0?ooo`80o`00=@3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000
oooo0?ooo`0T0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool0903oool00`3o0000
oooo0?ooo`0<0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`1O0?ooo`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool0603oool003/0oooo
00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo02<0oooo
0P3o000>0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool20?l00680oooo
00<0o`000?ooo`3oool0<P3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?oo
o`0T0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?oo
o`0=0?ooo`80o`009P3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo0640oooo0P3o
000c0?ooo`030000003oool0oooo01P0oooo000k0?ooo`8000009@3oool00`3o0000oooo0?ooo`0J
0?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0T
0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`0a
0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo02@0oooo00<0o`000?oo
o`3oool06P3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?oo
o`3oool0903oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo0680oooo0P3o000b0?oo
o`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3o
ool06P3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3o
ool0903oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo06<0oooo00<0o`000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`0T0?ooo`030?l0
003oool0oooo01X0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0
003oool0oooo02@0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1T0?ooo`030?l0
003oool0oooo02l0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool0903o
ool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo0P3o001V0?ooo`030?l0003o
ool0oooo02l0oooo00<000000?ooo`3oool0603oool00380oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`1V0?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool0603oool0
0380oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo
01/0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo
02<0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`1V0?ooo`80o`00;`3oool00`00
0000oooo0?ooo`0H0?ooo`00;`3oool6000000H0oooo0`00000S0?ooo`030?l0003oool0oooo01/0
oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo02<0
oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`1W0?ooo`030?l0003oool0oooo02d0
oooo00<000000?ooo`3oool0603oool00300oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`0S0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool08@3oool00`3o0000
oooo0?ooo`0@0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`3o0000
oooo0?ooo`1W0?ooo`80o`00;P3oool00`000000oooo0?ooo`0H0?ooo`00<@3oool00`000000oooo
000000070?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo
0?ooo`0Q0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool08`3oool00`000000oooo
0?ooo`040?ooo`030?l0003oool0oooo06P0oooo00<0o`000?ooo`3oool0;03oool00`000000oooo
0?ooo`0H0?ooo`00<P3oool00`000000oooo000000060?ooo`030000003oool0oooo02<0oooo00<0
o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0100oooo00<0
o`000?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo06P0oooo00<0
o`000?ooo`3oool0;03oool00`000000oooo0?ooo`0H0?ooo`00<`3oool2000000H0oooo00<00000
0?ooo`3oool08`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0240oooo00<0o`00
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0J@3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo01P0oooo000d0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0K0?oo
o`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0R0?oo
o`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0J@3oool00`3o0000oooo0?ooo`0[0?oo
o`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3o
ool06`3oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3o
ool08P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo06X0oooo0P3o000/0?ooo`03
0000003oool0oooo01P0oooo000k0?ooo`800000903oool00`3o0000oooo0?ooo`0K0?ooo`030?l0
003oool0oooo0240oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0R0?ooo`030000
003oool0oooo00<0oooo00<0o`000?ooo`3oool0J`3oool00`3o0000oooo0?ooo`0Z0?ooo`030000
003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool06`3o
ool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool08P3o
ool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo06/0oooo0P3o000[0?ooo`030000003o
ool0oooo01P0oooo000k0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool06`3oool0
0`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool08P3oool0
0`000000oooo0?ooo`030?ooo`030?l0003oool0oooo06`0oooo00<0o`000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo
01/0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo
0280oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`1/0?ooo`030?l0003oool0oooo
02T0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool08`3oool00`3o0000
oooo0?ooo`0K0?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool04P3oool00`3o0000
oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0K@3oool00`3o0000
oooo0?ooo`0X0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo02<0oooo
00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0180oooo
00<0o`000?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo06d0oooo
00<0o`000?ooo`3oool0:03oool00`000000oooo0?ooo`0H0?ooo`00>`3oool2000002@0oooo00<0
o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0180oooo00<0
o`000?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo06d0oooo0P3o
000Y0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003oool0oooo02<0oooo00<0o`00
0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0180oooo00<0o`00
0?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo06h0oooo00<0o`00
0?ooo`3oool09`3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000oooo0?ooo`0S0?oo
o`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?ooo`0C0?oo
o`030?l0003oool0oooo0240oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`1^0?oo
o`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3o
ool08`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0KP3oool20?l002P0oooo00<000000?ooo`3oool0603oool003/0oooo00<000000?ooo`3oool0
8`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool0
4`3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0
L03oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo000k0?ooo`030000003o
ool0oooo02<0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003o
ool0oooo01<0oooo00<0o`000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030?l0003o
ool0oooo0700oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool0
0`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0803oool0
0`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`1`0?ooo`80o`009`3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool20000
02@0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo
01<0oooo00<0o`000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo
0740oooo00<0o`000?ooo`3oool09@3oool00`000000oooo0?ooo`0H0?ooo`00>`3oool00`000000
oooo0?ooo`0S0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0803oool00`3o0000
oooo0?ooo`0C0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`1a0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool0603oool003/0oooo
00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0200oooo
00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo
00<0o`000?ooo`3oool0LP3oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo01P0oooo
000k0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?oo
o`0P0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool08@3oool00`000000oooo0?oo
o`020?ooo`030?l0003oool0oooo0780oooo00<0o`000?ooo`3oool0903oool00`000000oooo0?oo
o`0H0?ooo`00>`3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo01/0oooo00<0o`00
0?ooo`3oool0803oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo0240oooo00<00000
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`1b0?ooo`030?l0003oool0oooo02@0oooo00<00000
0?ooo`3oool0603oool00300oooo0`0000080?ooo`030000003oool0oooo02<0oooo00<0o`000?oo
o`3oool06`3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?oo
o`3oool08@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo0780oooo0P3o000U0?oo
o`030000003oool0oooo01P0oooo000_0?ooo`050000003oool0oooo0?ooo`0000001`3oool30000
02<0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo
01@0oooo00<0o`000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo
07<0oooo00<0o`000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`00;`3oool01@000000
oooo0?ooo`3oool0000000L0oooo9P0000000`3o000000000000000K000000030?l0000000000000
01l0000000<0o`00000000000000500000000`3o000000000000000V000000030?l0000000000000
07<0000000<0o`000000000000009000000J0?ooo`00;`3oool01@000000oooo0?ooo`3oool00000
0?l0ooooI@3oool002l0oooo1000003o0?ooofH0oooo000`0?ooo`030000003oool0oooo0?l0oooo
IP3oool00300oooo00D000000?ooo`3oool0oooo0000003o0?ooof@0oooo000a0?ooo`<00000o`3o
oomU0?ooo`00f`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;<0oooo003J0?oo
o`8000001`3oool00`000000oooo0?ooo`2b0?ooo`00d`3oool3000000@0oooo00<000000?ooo`00
00000`0000040?ooo`030000003oool0oooo0;40oooo003D0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0;40oooo003D0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0;40oooo003D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;40oooo003D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000;<0oooo003D
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`@000000P3oool00`000000oooo0?ooo`2b
0?ooo`00d`3oool600000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?oo
o`00o`3ooonI0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 407}, {203, 0}} -> {-7.17773, -8.04361, 0.0325344, \
0.0751081}}],

Cell[TextData[{
  "Here is a quick look at the graphics for the gamma function and the \
function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " along the real axis."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.44709 0.10582 0.25 0.0247525 [
[.02381 -0.0125 -8.3125 -11.1875 ]
[.02381 -0.0125 8.3125 0 ]
[.23545 -0.0125 -8.5 -11.1875 ]
[.23545 -0.0125 8.5 0 ]
[.44709 -0.0125 -5.03125 -11.1875 ]
[.44709 -0.0125 5.03125 0 ]
[.65873 -0.0125 -5.0625 -11.1875 ]
[.65873 -0.0125 5.0625 0 ]
[.87037 -0.0125 -4.875 -11.1875 ]
[.87037 -0.0125 4.875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.96875 -22.375 ]
[.5 -0.0125 4.96875 -11.1875 ]
[-0.0125 .00248 -22.4375 -5.59375 ]
[-0.0125 .00248 0 5.59375 ]
[-0.0125 .12624 -17.0625 -5.59375 ]
[-0.0125 .12624 0 5.59375 ]
[-0.0125 .25 -10.0625 -5.59375 ]
[-0.0125 .25 0 5.59375 ]
[-0.0125 .37376 -10.1875 -5.59375 ]
[-0.0125 .37376 0 5.59375 ]
[-0.0125 .49752 -15.5625 -5.59375 ]
[-0.0125 .49752 0 5.59375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .25 -33.75 -4.0625 ]
[-0.01875 .25 -22.4375 4.0625 ]
[ 0 .5 .125 0 ]
[ 1 0 .125 0 ]
[.5 .5125 -17.5625 0 ]
[.5 .5125 17.5625 11.3125 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -69.3125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.23545 0 m
.23545 .00625 L
s
gsave
.23545 -0.0125 -69.5 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.44709 0 m
.44709 .00625 L
s
gsave
.44709 -0.0125 -66.0312 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66.0625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.87037 0 m
.87037 .00625 L
s
gsave
.87037 -0.0125 -65.875 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07672 0 m
.07672 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.28836 0 m
.28836 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.5 0 m
.5 .00375 L
s
.55291 0 m
.55291 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9688 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 .00248 m
.00625 .00248 L
s
gsave
-0.0125 .00248 -83.4375 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .12624 m
.00625 .12624 L
s
gsave
-0.0125 .12624 -78.0625 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .25 m
.00625 .25 L
s
gsave
-0.0125 .25 -71.0625 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .37376 m
.00625 .37376 L
s
gsave
-0.0125 .37376 -71.1875 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .49752 m
.00625 .49752 L
s
gsave
-0.0125 .49752 -76.5625 -9.59375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02723 m
.00375 .02723 L
s
0 .05198 m
.00375 .05198 L
s
0 .07673 m
.00375 .07673 L
s
0 .10149 m
.00375 .10149 L
s
0 .15099 m
.00375 .15099 L
s
0 .17574 m
.00375 .17574 L
s
0 .2005 m
.00375 .2005 L
s
0 .22525 m
.00375 .22525 L
s
0 .27475 m
.00375 .27475 L
s
0 .2995 m
.00375 .2995 L
s
0 .32426 m
.00375 .32426 L
s
0 .34901 m
.00375 .34901 L
s
0 .39851 m
.00375 .39851 L
s
0 .42327 m
.00375 .42327 L
s
0 .44802 m
.00375 .44802 L
s
0 .47277 m
.00375 .47277 L
s
.25 Mabswid
0 0 m
0 .5 L
s
gsave
-0.01875 .25 -93.1562 -9.65625 Mabsadd m
1 1 Mabs scale
currentpoint translate
65.0625 9.65625 translate
90 rotate
-65.0625 -9.65625 translate
0 19.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
1.000 setlinewidth
grestore
0 .5 m
1 .5 L
s
1 0 m
1 .5 L
s
0 .25 m
1 .25 L
s
.44709 0 m
.44709 .5 L
s
gsave
.5 .5125 -78.5625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
%%BeginResource: font Helvetica-Oblique-MISO
%%BeginFont: Helvetica-Oblique-MISO
/Helvetica-Oblique /Helvetica-Oblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(log) show
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
82.062 12.125 moveto
(H) show
85.250 12.125 moveto
%%IncludeResource: font Helvetica-Oblique-MISO
%%IncludeFont: Helvetica-Oblique-MISO
/Helvetica-Oblique-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.938 12.125 moveto
(L) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.002 w
.02381 .5 m
.02382 .41181 L
.02382 .39599 L
.02383 .38522 L
.02383 .3781 L
.02385 .369 L
.02386 .36187 L
.02387 .35584 L
.02388 .35074 L
.02391 .3436 L
.02394 .33792 L
.02396 .33357 L
.02402 .32584 L
.02407 .31986 L
.02412 .31543 L
.02424 .30767 L
.02434 .30248 L
.02445 .29785 L
.02467 .29073 L
.02488 .28542 L
.0251 .28084 L
.02532 .27712 L
.02552 .27402 L
.02574 .27112 L
.02595 .26863 L
.02616 .26647 L
.02637 .26437 L
.02658 .26251 L
.0268 .26069 L
.02701 .25907 L
.02722 .25761 L
.02744 .25616 L
.02765 .25485 L
.02785 .25365 L
.02806 .25245 L
.02827 .25136 L
.02849 .25025 L
.0287 .24924 L
.0289 .24831 L
.02912 .24736 L
.02933 .24649 L
.02955 .2456 L
.02977 .24478 L
.02997 .24402 L
.03019 .24324 L
.0304 .24252 L
.0306 .24185 L
.03082 .24116 L
.03103 .24053 L
.03125 .23987 L
Mistroke
.03146 .23926 L
.03166 .23869 L
.03188 .2381 L
.03209 .23755 L
.03231 .23699 L
.03253 .23646 L
.03273 .23596 L
.03295 .23545 L
.03316 .23498 L
.03337 .23453 L
.03358 .23406 L
.03379 .23363 L
.03401 .23318 L
.03423 .23276 L
.03443 .23236 L
.03465 .23195 L
.03486 .23157 L
.03506 .23121 L
.03528 .23083 L
.03548 .23048 L
.0357 .23011 L
.03592 .22976 L
.03612 .22944 L
.03634 .2291 L
.03655 .22878 L
.03677 .22845 L
.03698 .22814 L
.03719 .22785 L
.03741 .22755 L
.03762 .22726 L
.03782 .22699 L
.03804 .22671 L
.03824 .22644 L
.03846 .22617 L
.03868 .22591 L
.03888 .22566 L
.0391 .2254 L
.03931 .22516 L
.03951 .22494 L
.03973 .2247 L
.03993 .22448 L
.04015 .22424 L
.04036 .22402 L
.04057 .22382 L
.04078 .2236 L
.04099 .22339 L
.04121 .22318 L
.04143 .22298 L
.04163 .22279 L
.04185 .22259 L
Mistroke
.04206 .22241 L
.04226 .22223 L
.04248 .22205 L
.04269 .22188 L
.04291 .22169 L
.04312 .22152 L
.04332 .22136 L
.04354 .22119 L
.04375 .22104 L
.04397 .22087 L
.04419 .22072 L
.04439 .22057 L
.04461 .22041 L
.04482 .22027 L
.04503 .22013 L
.04524 .21999 L
.04545 .21986 L
.04567 .21972 L
.04588 .21958 L
.04609 .21946 L
.04631 .21933 L
.04652 .21921 L
.04672 .21909 L
.04693 .21897 L
.04714 .21886 L
.04736 .21874 L
.04757 .21863 L
.04778 .21852 L
.04799 .21841 L
.0482 .21831 L
.04842 .2182 L
.04864 .2181 L
.04884 .218 L
.04906 .2179 L
.04927 .21781 L
.04948 .21772 L
.04969 .21763 L
.0499 .21754 L
.05012 .21745 L
.05033 .21737 L
.05054 .21729 L
.05075 .21721 L
.05096 .21713 L
.05119 .21705 L
.0514 .21697 L
.05161 .2169 L
.05183 .21683 L
.05204 .21676 L
.05224 .21669 L
.05246 .21663 L
Mistroke
.05267 .21656 L
.05289 .2165 L
.0531 .21644 L
.05331 .21638 L
.05352 .21632 L
.05373 .21626 L
.05394 .21621 L
.05415 .21616 L
.05436 .21611 L
.05458 .21606 L
.05479 .21601 L
.055 .21596 L
.05521 .21592 L
.05542 .21587 L
.05564 .21583 L
.05586 .21579 L
.05606 .21575 L
.05628 .21571 L
.05649 .21568 L
.0567 .21564 L
.05691 .21561 L
.05712 .21558 L
.05734 .21555 L
.05755 .21552 L
.05776 .21549 L
.05798 .21546 L
.05819 .21544 L
.05839 .21541 L
.0586 .21539 L
.05881 .21537 L
.05903 .21535 L
.05924 .21533 L
.05944 .21531 L
.05966 .2153 L
.05987 .21528 L
.06009 .21527 L
.06031 .21526 L
.06051 .21525 L
.06073 .21524 L
.06094 .21523 L
.06114 .21522 L
.06136 .21521 L
.06157 .21521 L
.06167 .21521 L
.06179 .2152 L
.0619 .2152 L
.062 .2152 L
.0621 .2152 L
.06216 .2152 L
.06222 .2152 L
Mistroke
.06227 .2152 L
.06229 .2152 L
.06232 .2152 L
.06235 .2152 L
.06236 .2152 L
.06237 .2152 L
.06237 .2152 L
.06238 .2152 L
.06239 .2152 L
.06239 .2152 L
.0624 .2152 L
.0624 .2152 L
.06241 .2152 L
.06242 .2152 L
.06242 .2152 L
.06243 .2152 L
.06244 .2152 L
.06245 .2152 L
.06246 .2152 L
.06247 .2152 L
.0625 .2152 L
.06252 .2152 L
.06258 .2152 L
.06263 .2152 L
.06274 .2152 L
.06284 .2152 L
.06304 .2152 L
.06326 .21521 L
.06348 .21521 L
.06368 .21522 L
.0639 .21523 L
.06411 .21524 L
.06431 .21524 L
.06453 .21526 L
.06473 .21527 L
.06495 .21528 L
.06516 .21529 L
.06537 .21531 L
.06558 .21533 L
.06579 .21534 L
.06601 .21536 L
.06623 .21538 L
.06643 .2154 L
.06665 .21542 L
.06686 .21545 L
.06706 .21547 L
.06728 .21549 L
.06749 .21552 L
.06771 .21555 L
.06792 .21557 L
Mistroke
.06812 .2156 L
.06834 .21563 L
.06855 .21566 L
.06877 .21569 L
.06899 .21573 L
.06919 .21576 L
.06941 .2158 L
.06962 .21583 L
.06982 .21587 L
.07004 .21591 L
.07025 .21594 L
.07047 .21599 L
.07068 .21603 L
.07089 .21607 L
.07111 .21611 L
.07132 .21616 L
.07152 .2162 L
.07173 .21624 L
.07194 .21629 L
.07216 .21634 L
.07237 .21639 L
.07257 .21644 L
.07279 .21649 L
.073 .21654 L
.07322 .21659 L
.07343 .21665 L
.07364 .2167 L
.07386 .21676 L
.07407 .21681 L
.07427 .21687 L
.07449 .21693 L
.0747 .21698 L
.07492 .21705 L
.07513 .21711 L
.07533 .21717 L
.07555 .21723 L
.07576 .2173 L
.07598 .21737 L
.0762 .21743 L
.0764 .2175 L
.07662 .21757 L
.07683 .21764 L
.07704 .2177 L
.07725 .21778 L
.07746 .21785 L
.07768 .21792 L
.0779 .218 L
.0781 .21807 L
.07832 .21815 L
.07853 .21822 L
Mistroke
.07873 .2183 L
.07895 .21838 L
.07915 .21845 L
.07937 .21854 L
.07959 .21862 L
.07979 .2187 L
.08001 .21878 L
.08022 .21887 L
.08044 .21895 L
.08065 .21904 L
.08086 .21913 L
.08108 .21922 L
.08129 .21931 L
.08149 .21939 L
.08171 .21948 L
.08191 .21957 L
.08214 .21967 L
.08235 .21977 L
.08255 .21986 L
.08277 .21996 L
.08298 .22005 L
.08318 .22015 L
.0834 .22025 L
.0836 .22034 L
.08382 .22045 L
.08404 .22055 L
.08424 .22065 L
.08446 .22075 L
.08466 .22086 L
.08489 .22097 L
.0851 .22108 L
.0853 .22118 L
.08552 .22129 L
.08573 .2214 L
.08594 .22151 L
.08615 .22162 L
.08636 .22173 L
.08658 .22185 L
.08679 .22197 L
.087 .22208 L
.08721 .2222 L
.08742 .22232 L
.08764 .22244 L
.08786 .22256 L
.08807 .22268 L
.08828 .22281 L
.0885 .22293 L
.0887 .22305 L
.08891 .22318 L
.08912 .2233 L
Mistroke
.08934 .22344 L
.08956 .22357 L
.08976 .22369 L
.08998 .22383 L
.09019 .22396 L
.09039 .22409 L
.09061 .22422 L
.09081 .22436 L
.09103 .2245 L
.09125 .22464 L
.09145 .22477 L
.09167 .22491 L
.09188 .22505 L
.0921 .2252 L
.09231 .22535 L
.09252 .22549 L
.09274 .22564 L
.09295 .22579 L
.09315 .22593 L
.09336 .22608 L
.09357 .22623 L
.09379 .22639 L
.09401 .22654 L
.09421 .22669 L
.09443 .22686 L
.09464 .22701 L
.09486 .22718 L
.09507 .22734 L
.09528 .2275 L
.0955 .22767 L
.09571 .22783 L
.09592 .22799 L
.09613 .22816 L
.09634 .22833 L
.09656 .2285 L
.09677 .22868 L
.09698 .22884 L
.0972 .22902 L
.09741 .2292 L
.09761 .22937 L
.09783 .22955 L
.09803 .22972 L
.09825 .22991 L
.09847 .23009 L
.09867 .23027 L
.09889 .23046 L
.0991 .23065 L
.09932 .23084 L
.09953 .23104 L
.09974 .23122 L
Mistroke
.09996 .23142 L
.10017 .23162 L
.10037 .23181 L
.10059 .23201 L
.1008 .23221 L
.10102 .23242 L
.10123 .23262 L
.10143 .23282 L
.10165 .23303 L
.10186 .23324 L
.10206 .23344 L
.10228 .23366 L
.10249 .23387 L
.1027 .23409 L
.10292 .23431 L
.10312 .23452 L
.10334 .23475 L
.10355 .23497 L
.10377 .2352 L
.10398 .23543 L
.10419 .23566 L
.10441 .23589 L
.10462 .23613 L
.10482 .23635 L
.10503 .2366 L
.10524 .23683 L
.10546 .23708 L
.10567 .23733 L
.10588 .23757 L
.1061 .23782 L
.10631 .23807 L
.10653 .23834 L
.10674 .2386 L
.10695 .23885 L
.10717 .23912 L
.10738 .23939 L
.10758 .23964 L
.1078 .23992 L
.10801 .24018 L
.10823 .24047 L
.10844 .24075 L
.10865 .24102 L
.10886 .24131 L
.10907 .2416 L
.10928 .24187 L
.10949 .24217 L
.1097 .24246 L
.10992 .24277 L
.11013 .24307 L
.11033 .24336 L
Mistroke
.11055 .24368 L
.11076 .24398 L
.11098 .24431 L
.1112 .24463 L
.1114 .24495 L
.11162 .24528 L
.11183 .24561 L
.11203 .24593 L
.11225 .24627 L
.11246 .24661 L
.11268 .24697 L
.11289 .24732 L
.1131 .24766 L
.11331 .24803 L
.11352 .24839 L
.11373 .24874 L
.11394 .24911 L
.11415 .24948 L
.11437 .24987 L
.11458 .25026 L
.11478 .25064 L
.115 .25104 L
.11521 .25144 L
.11543 .25186 L
.11564 .25228 L
.11585 .25269 L
.11607 .25313 L
.11628 .25356 L
.11648 .25398 L
.11669 .25443 L
.1169 .25487 L
.11712 .25535 L
.11733 .25582 L
.11754 .25628 L
.11775 .25677 L
.11796 .25726 L
.11819 .25778 L
.1184 .2583 L
.11861 .2588 L
.11883 .25935 L
.11904 .25988 L
.11924 .26041 L
.11946 .26097 L
.11966 .26153 L
.11989 .26214 L
.1201 .26273 L
.1203 .26332 L
.12052 .26396 L
.12073 .26458 L
.12093 .2652 L
Mistroke
.12115 .26587 L
.12135 .26653 L
.12157 .26725 L
.12179 .26796 L
.12199 .26866 L
.12221 .26942 L
.12242 .27018 L
.12264 .27101 L
.12285 .27183 L
.12306 .27264 L
.12328 .27354 L
.12349 .27443 L
.12369 .27531 L
.1239 .27628 L
.12411 .27724 L
.12433 .27831 L
.12455 .27938 L
.12475 .28045 L
.12497 .28164 L
.12518 .28283 L
.1254 .28416 L
.12561 .2855 L
.12582 .28686 L
.12604 .28839 L
.12625 .28995 L
.12645 .29154 L
.12667 .29335 L
.12688 .29521 L
.1271 .29735 L
.12731 .29959 L
.12752 .30194 L
.12774 .30471 L
.12795 .30768 L
.12815 .31091 L
.12836 .31486 L
.12857 .31934 L
.12879 .32518 L
.129 .33247 L
.12921 .34231 L
.12931 .34944 L
.12937 .35454 L
.12943 .36029 L
.12948 .36743 L
.12952 .37651 L
.12955 .38303 L
.12957 .39298 L
.12959 .40007 L
.1296 .40517 L
.1296 .41095 L
.12961 .41791 L
Mistroke
.12962 .42868 L
.12962 .4466 L
Mfstroke
.12962 .4466 m
.12963 .5 L
s
.12963 .5 m
.12964 .44612 L
.12964 .4303 L
.12965 .41954 L
.12965 .41242 L
.12967 .40331 L
.12968 .39618 L
.12969 .39015 L
.1297 .38505 L
.12973 .37791 L
.12976 .37222 L
.12978 .36787 L
.12984 .36014 L
.12989 .35416 L
.12994 .34972 L
.13006 .34196 L
.13016 .33676 L
.13027 .33212 L
.13049 .32499 L
.1307 .31968 L
.13092 .31507 L
.13114 .31134 L
.13134 .30823 L
.13156 .30532 L
.13177 .30282 L
.13198 .30064 L
.13219 .29853 L
.1324 .29666 L
.13262 .29483 L
.13283 .2932 L
.13304 .29173 L
.13326 .29026 L
.13347 .28894 L
.13367 .28773 L
.13388 .28652 L
.13409 .28541 L
.13431 .28429 L
.13452 .28326 L
.13472 .28232 L
.13494 .28136 L
.13515 .28047 L
.13537 .27957 L
.13559 .27874 L
.13579 .27797 L
.13601 .27718 L
.13622 .27645 L
.13642 .27577 L
.13664 .27507 L
.13685 .27441 L
.13707 .27374 L
Mistroke
.13728 .27312 L
.13748 .27254 L
.1377 .27194 L
.13791 .27138 L
.13813 .2708 L
.13835 .27026 L
.13855 .26975 L
.13877 .26923 L
.13898 .26874 L
.13919 .26828 L
.1394 .2678 L
.13961 .26735 L
.13983 .26689 L
.14005 .26646 L
.14025 .26605 L
.14047 .26562 L
.14068 .26523 L
.14088 .26485 L
.1411 .26446 L
.1413 .2641 L
.14152 .26372 L
.14174 .26336 L
.14194 .26302 L
.14216 .26267 L
.14237 .26234 L
.14259 .262 L
.1428 .26167 L
.14301 .26137 L
.14323 .26105 L
.14344 .26075 L
.14364 .26047 L
.14386 .26017 L
.14406 .2599 L
.14428 .25961 L
.1445 .25933 L
.1447 .25908 L
.14492 .25881 L
.14513 .25855 L
.14533 .25831 L
.14555 .25806 L
.14575 .25783 L
.14597 .25758 L
.14618 .25735 L
.14639 .25713 L
.1466 .2569 L
.14681 .25668 L
.14703 .25646 L
.14725 .25624 L
.14745 .25604 L
.14767 .25583 L
Mistroke
.14788 .25563 L
.14808 .25544 L
.1483 .25525 L
.14851 .25506 L
.14873 .25487 L
.14894 .25468 L
.14914 .25451 L
.14936 .25433 L
.14957 .25416 L
.14979 .25398 L
.15001 .25381 L
.15021 .25365 L
.15043 .25348 L
.15064 .25332 L
.15085 .25317 L
.15106 .25302 L
.15127 .25287 L
.15149 .25272 L
.1517 .25257 L
.15191 .25243 L
.15213 .25229 L
.15234 .25216 L
.15254 .25203 L
.15275 .25189 L
.15296 .25177 L
.15318 .25163 L
.15339 .25151 L
.1536 .25139 L
.15381 .25127 L
.15402 .25115 L
.15424 .25103 L
.15446 .25092 L
.15466 .25081 L
.15488 .25069 L
.15509 .25059 L
.1553 .25049 L
.15551 .25038 L
.15572 .25028 L
.15594 .25018 L
.15615 .25008 L
.15636 .24999 L
.15657 .24989 L
.15678 .2498 L
.15701 .24971 L
.15722 .24962 L
.15743 .24953 L
.15765 .24945 L
.15786 .24936 L
.15806 .24929 L
.15828 .24921 L
Mistroke
.15849 .24913 L
.15871 .24905 L
.15892 .24898 L
.15913 .2489 L
.15934 .24883 L
.15955 .24876 L
.15976 .2487 L
.15997 .24863 L
.16018 .24857 L
.1604 .2485 L
.16061 .24844 L
.16082 .24838 L
.16103 .24832 L
.16124 .24827 L
.16146 .24821 L
.16168 .24816 L
.16188 .2481 L
.1621 .24805 L
.16231 .248 L
.16252 .24796 L
.16273 .24791 L
.16294 .24786 L
.16316 .24782 L
.16337 .24777 L
.16358 .24773 L
.1638 .24769 L
.16401 .24765 L
.16421 .24762 L
.16442 .24758 L
.16463 .24755 L
.16485 .24751 L
.16506 .24748 L
.16526 .24745 L
.16548 .24742 L
.16569 .24739 L
.16591 .24736 L
.16613 .24734 L
.16633 .24731 L
.16655 .24729 L
.16676 .24727 L
.16696 .24725 L
.16718 .24723 L
.16739 .24721 L
.16761 .24719 L
.16782 .24717 L
.16802 .24716 L
.16824 .24715 L
.16845 .24713 L
.16867 .24712 L
.16889 .24711 L
Mistroke
.16909 .2471 L
.16931 .24709 L
.16952 .24708 L
.16973 .24708 L
.16994 .24707 L
.17015 .24707 L
.17026 .24707 L
.17037 .24707 L
.17048 .24707 L
.17054 .24706 L
.17058 .24706 L
.17064 .24706 L
.17068 .24706 L
.17071 .24706 L
.17074 .24706 L
.17075 .24706 L
.17077 .24706 L
.17077 .24706 L
.17078 .24706 L
.17079 .24706 L
.17079 .24706 L
.1708 .24706 L
.17081 .24706 L
.17081 .24706 L
.17081 .24706 L
.17082 .24706 L
.17083 .24706 L
.17083 .24706 L
.17084 .24706 L
.17084 .24706 L
.17085 .24706 L
.17086 .24706 L
.17087 .24706 L
.1709 .24706 L
.17093 .24706 L
.17096 .24706 L
.17101 .24706 L
.17106 .24706 L
.17111 .24706 L
.17121 .24707 L
.17133 .24707 L
.17143 .24707 L
.17164 .24707 L
.17186 .24708 L
.17207 .24708 L
.17227 .24709 L
.17249 .2471 L
.17269 .2471 L
.17291 .24712 L
.17313 .24713 L
Mistroke
.17333 .24714 L
.17355 .24715 L
.17376 .24716 L
.17398 .24718 L
.17419 .2472 L
.1744 .24721 L
.17462 .24723 L
.17483 .24725 L
.17503 .24727 L
.17525 .24729 L
.17546 .24731 L
.17568 .24734 L
.17589 .24736 L
.17609 .24739 L
.17631 .24741 L
.17652 .24744 L
.17672 .24747 L
.17694 .24749 L
.17715 .24752 L
.17737 .24756 L
.17758 .24759 L
.17778 .24762 L
.178 .24765 L
.17821 .24769 L
.17843 .24773 L
.17864 .24776 L
.17885 .2478 L
.17907 .24784 L
.17928 .24788 L
.17948 .24792 L
.1797 .24796 L
.1799 .248 L
.18012 .24805 L
.18034 .24809 L
.18054 .24813 L
.18076 .24818 L
.18097 .24823 L
.18119 .24828 L
.1814 .24833 L
.18161 .24838 L
.18183 .24843 L
.18204 .24848 L
.18224 .24853 L
.18246 .24859 L
.18267 .24864 L
.18289 .2487 L
.1831 .24876 L
.18331 .24881 L
.18353 .24887 L
.18374 .24893 L
Mistroke
.18394 .24899 L
.18415 .24905 L
.18436 .24911 L
.18458 .24918 L
.18479 .24924 L
.185 .24931 L
.18521 .24937 L
.18542 .24944 L
.18565 .24951 L
.18586 .24958 L
.18607 .24965 L
.18628 .24972 L
.1865 .24979 L
.1867 .24986 L
.18691 .24994 L
.18712 .25001 L
.18734 .25009 L
.18756 .25017 L
.18776 .25024 L
.18798 .25032 L
.18819 .2504 L
.18839 .25048 L
.1886 .25056 L
.18881 .25064 L
.18903 .25073 L
.18924 .25081 L
.18945 .2509 L
.18966 .25098 L
.18987 .25107 L
.19009 .25116 L
.19031 .25125 L
.19051 .25134 L
.19073 .25144 L
.19094 .25153 L
.19114 .25162 L
.19136 .25171 L
.19157 .25181 L
.19179 .25191 L
.192 .252 L
.1922 .2521 L
.19242 .2522 L
.19263 .2523 L
.19285 .25241 L
.19307 .25251 L
.19327 .25261 L
.19349 .25272 L
.1937 .25283 L
.19391 .25293 L
.19412 .25304 L
.19433 .25315 L
Mistroke
.19455 .25326 L
.19476 .25337 L
.19497 .25348 L
.19519 .2536 L
.1954 .25371 L
.1956 .25382 L
.19581 .25394 L
.19602 .25406 L
.19624 .25418 L
.19645 .2543 L
.19666 .25442 L
.19687 .25454 L
.19708 .25466 L
.1973 .2548 L
.19752 .25492 L
.19772 .25505 L
.19794 .25518 L
.19815 .25531 L
.19836 .25543 L
.19857 .25557 L
.19878 .2557 L
.199 .25584 L
.19921 .25597 L
.19942 .2561 L
.19963 .25625 L
.19984 .25638 L
.20007 .25653 L
.20028 .25667 L
.20049 .25681 L
.20071 .25696 L
.20092 .25711 L
.20112 .25725 L
.20134 .2574 L
.20155 .25755 L
.20177 .25771 L
.20198 .25786 L
.20219 .25801 L
.20241 .25817 L
.20262 .25832 L
.20282 .25847 L
.20303 .25863 L
.20324 .25879 L
.20346 .25896 L
.20367 .25912 L
.20388 .25928 L
.20409 .25945 L
.2043 .25962 L
.20453 .2598 L
.20474 .25997 L
.20495 .26014 L
Mistroke
.20516 .26032 L
.20538 .26049 L
.20558 .26066 L
.20579 .26084 L
.206 .26102 L
.20622 .26121 L
.20644 .26139 L
.20664 .26157 L
.20686 .26177 L
.20707 .26195 L
.20727 .26213 L
.20749 .26233 L
.20769 .26252 L
.20791 .26272 L
.20812 .26292 L
.20833 .26311 L
.20854 .26332 L
.20875 .26352 L
.20897 .26373 L
.20919 .26394 L
.20939 .26414 L
.20961 .26436 L
.20982 .26457 L
.21003 .26478 L
.21024 .265 L
.21045 .26521 L
.21067 .26544 L
.21088 .26566 L
.21109 .26588 L
.2113 .26612 L
.21151 .26634 L
.21173 .26659 L
.21195 .26682 L
.21216 .26705 L
.21237 .2673 L
.21259 .26754 L
.21279 .26778 L
.21301 .26803 L
.21321 .26827 L
.21344 .26854 L
.21365 .26879 L
.21385 .26904 L
.21407 .26931 L
.21428 .26957 L
.21448 .26982 L
.2147 .27009 L
.21491 .27036 L
.21513 .27064 L
.21534 .27092 L
.21554 .27119 L
Mistroke
.21576 .27148 L
.21597 .27176 L
.21619 .27206 L
.2164 .27236 L
.21661 .27265 L
.21683 .27296 L
.21704 .27326 L
.21724 .27355 L
.21746 .27387 L
.21767 .27417 L
.21789 .27451 L
.2181 .27483 L
.2183 .27514 L
.21852 .27548 L
.21873 .27581 L
.21893 .27614 L
.21915 .27648 L
.21935 .27682 L
.21957 .27718 L
.21979 .27754 L
.21999 .27789 L
.22021 .27826 L
.22041 .27863 L
.22064 .27902 L
.22085 .27941 L
.22105 .27978 L
.22127 .28019 L
.22148 .28058 L
.22169 .28097 L
.2219 .28139 L
.22211 .2818 L
.22233 .28224 L
.22254 .28267 L
.22274 .28309 L
.22296 .28355 L
.22317 .28399 L
.22339 .28447 L
.22361 .28495 L
.22381 .28541 L
.22403 .28591 L
.22424 .28641 L
.22445 .28689 L
.22466 .28741 L
.22487 .28792 L
.22509 .28848 L
.22531 .28902 L
.22551 .28956 L
.22573 .29014 L
.22594 .29071 L
.22614 .29128 L
Mistroke
.22635 .29189 L
.22656 .29249 L
.22678 .29315 L
.22699 .29379 L
.2272 .29443 L
.22741 .29512 L
.22762 .29581 L
.22784 .29656 L
.22806 .2973 L
.22826 .29803 L
.22848 .29884 L
.22869 .29963 L
.2289 .30042 L
.22911 .30129 L
.22932 .30215 L
.22954 .30309 L
.22975 .30404 L
.22996 .30498 L
.23017 .30602 L
.23038 .30706 L
.23061 .30821 L
.23082 .30937 L
.23103 .31054 L
.23125 .31184 L
.23146 .31316 L
.23166 .31449 L
.23188 .31599 L
.23209 .31752 L
.23231 .31925 L
.23252 .32103 L
.23273 .32287 L
.23294 .32498 L
.23315 .32719 L
.23336 .32951 L
.23357 .33224 L
.23378 .33518 L
.234 .33872 L
.23421 .34268 L
.23442 .34717 L
.23463 .35305 L
.23484 .36041 L
.23496 .36559 L
.23506 .3717 L
.23512 .3753 L
.23517 .37978 L
.23522 .38442 L
.23527 .39061 L
.23529 .39431 L
.23532 .39841 L
.23534 .40319 L
Mistroke
.23536 .40863 L
.23538 .41516 L
.2354 .42474 L
.23542 .43168 L
.23543 .44065 L
.23543 .44777 L
.23544 .45679 L
.23544 .47312 L
Mfstroke
.23544 .47312 m
.23544 .5 L
s
.23545 .5 m
.23546 .47331 L
.23546 .4575 L
.23547 .44673 L
.23547 .43961 L
.23549 .4305 L
.2355 .42337 L
.23551 .41734 L
.23553 .41223 L
.23555 .4051 L
.2356 .39505 L
.23563 .39076 L
.23566 .38731 L
.23576 .37689 L
.23583 .37253 L
.23588 .36912 L
.23609 .35927 L
.2363 .3525 L
.23651 .3469 L
.23672 .34251 L
.23695 .33858 L
.23716 .33532 L
.23737 .33255 L
.23759 .32992 L
.2378 .32764 L
.238 .32564 L
.23822 .32367 L
.23842 .32193 L
.23864 .3202 L
.23886 .31866 L
.23906 .31726 L
.23928 .31586 L
.23949 .31459 L
.23969 .31344 L
.23991 .31227 L
.24011 .31119 L
.24033 .31011 L
.24054 .30911 L
.24075 .30819 L
.24097 .30725 L
.24117 .30639 L
.2414 .3055 L
.24161 .30468 L
.24181 .30392 L
.24203 .30314 L
.24224 .30242 L
.24245 .30174 L
.24266 .30105 L
.24287 .3004 L
.24309 .29973 L
Mistroke
.2433 .29911 L
.24351 .29853 L
.24372 .29793 L
.24393 .29737 L
.24416 .29679 L
.24437 .29624 L
.24458 .29573 L
.2448 .29521 L
.24501 .29471 L
.24521 .29425 L
.24543 .29377 L
.24564 .29331 L
.24586 .29284 L
.24607 .2924 L
.24628 .29199 L
.24649 .29156 L
.2467 .29115 L
.24691 .29077 L
.24712 .29037 L
.24733 .28999 L
.24755 .2896 L
.24776 .28924 L
.24796 .28889 L
.24818 .28853 L
.24839 .28819 L
.24861 .28783 L
.24883 .2875 L
.24903 .28718 L
.24925 .28685 L
.24946 .28654 L
.24966 .28625 L
.24988 .28594 L
.25009 .28565 L
.25031 .28535 L
.25052 .28507 L
.25073 .2848 L
.25094 .28452 L
.25115 .28425 L
.25136 .284 L
.25157 .28373 L
.25178 .28349 L
.252 .28323 L
.25221 .28298 L
.25241 .28275 L
.25263 .2825 L
.25284 .28227 L
.25306 .28203 L
.25327 .28181 L
.25348 .28159 L
.2537 .28137 L
Mistroke
.25391 .28115 L
.25411 .28095 L
.25432 .28074 L
.25453 .28054 L
.25475 .28033 L
.25496 .28013 L
.25517 .27994 L
.25538 .27975 L
.25559 .27956 L
.25582 .27937 L
.25603 .27918 L
.25624 .27901 L
.25646 .27883 L
.25667 .27866 L
.25687 .27849 L
.25709 .27832 L
.25729 .27816 L
.25752 .27799 L
.25773 .27783 L
.25793 .27768 L
.25815 .27752 L
.25836 .27737 L
.25856 .27722 L
.25878 .27707 L
.25899 .27693 L
.25921 .27678 L
.25942 .27664 L
.25962 .27651 L
.25984 .27637 L
.26005 .27624 L
.26027 .2761 L
.26048 .27597 L
.26069 .27584 L
.26091 .27571 L
.26112 .27559 L
.26132 .27548 L
.26154 .27535 L
.26174 .27524 L
.26196 .27512 L
.26218 .275 L
.26238 .2749 L
.2626 .27478 L
.26281 .27468 L
.26303 .27457 L
.26324 .27446 L
.26345 .27436 L
.26367 .27426 L
.26388 .27416 L
.26409 .27406 L
.2643 .27397 L
Mistroke
.26451 .27387 L
.26473 .27378 L
.26494 .27368 L
.26515 .2736 L
.26537 .27351 L
.26558 .27342 L
.26578 .27334 L
.266 .27326 L
.2662 .27318 L
.26642 .2731 L
.26664 .27302 L
.26684 .27294 L
.26706 .27287 L
.26727 .27279 L
.26749 .27272 L
.2677 .27265 L
.26791 .27258 L
.26813 .27251 L
.26834 .27244 L
.26854 .27238 L
.26876 .27231 L
.26896 .27225 L
.26919 .27219 L
.2694 .27213 L
.2696 .27207 L
.26982 .27201 L
.27003 .27196 L
.27023 .27191 L
.27045 .27185 L
.27065 .2718 L
.27087 .27175 L
.27109 .2717 L
.27129 .27165 L
.27151 .2716 L
.27171 .27156 L
.27194 .27151 L
.27215 .27147 L
.27236 .27143 L
.27257 .27138 L
.27278 .27134 L
.27299 .27131 L
.2732 .27127 L
.27341 .27123 L
.27363 .2712 L
.27384 .27116 L
.27405 .27113 L
.27426 .2711 L
.27447 .27107 L
.2747 .27104 L
.27491 .27101 L
Mistroke
.27512 .27098 L
.27534 .27095 L
.27555 .27093 L
.27575 .27091 L
.27597 .27088 L
.27617 .27086 L
.2764 .27084 L
.27661 .27082 L
.27681 .2708 L
.27703 .27078 L
.27724 .27077 L
.27744 .27075 L
.27766 .27074 L
.27787 .27072 L
.27809 .27071 L
.2783 .2707 L
.2785 .27069 L
.27872 .27068 L
.27893 .27067 L
.27915 .27067 L
.27936 .27066 L
.27957 .27065 L
.27979 .27065 L
.2799 .27065 L
.28 .27065 L
.2801 .27064 L
.2802 .27064 L
.28025 .27064 L
.28031 .27064 L
.28036 .27064 L
.28041 .27064 L
.28046 .27064 L
.28049 .27064 L
.2805 .27064 L
.28052 .27064 L
.28053 .27064 L
.28054 .27064 L
.28055 .27064 L
.28056 .27064 L
.28056 .27064 L
.28057 .27064 L
.28057 .27064 L
.28058 .27064 L
.28058 .27064 L
.28059 .27064 L
.28059 .27064 L
.2806 .27064 L
.2806 .27064 L
.28061 .27064 L
.28061 .27064 L
Mistroke
.28063 .27064 L
.28064 .27064 L
.28066 .27064 L
.28068 .27064 L
.28071 .27064 L
.28073 .27064 L
.28079 .27064 L
.28084 .27064 L
.28095 .27064 L
.28105 .27064 L
.28126 .27065 L
.28148 .27065 L
.28169 .27066 L
.28189 .27066 L
.28211 .27067 L
.28232 .27068 L
.28252 .27068 L
.28274 .27069 L
.28295 .2707 L
.28317 .27071 L
.28338 .27073 L
.28358 .27074 L
.2838 .27075 L
.28401 .27077 L
.28423 .27079 L
.28444 .2708 L
.28465 .27082 L
.28487 .27084 L
.28508 .27086 L
.28528 .27088 L
.2855 .2709 L
.2857 .27092 L
.28592 .27095 L
.28614 .27097 L
.28634 .271 L
.28656 .27103 L
.28677 .27105 L
.28699 .27108 L
.2872 .27111 L
.28741 .27114 L
.28763 .27117 L
.28784 .27121 L
.28804 .27124 L
.28826 .27127 L
.28847 .27131 L
.28869 .27134 L
.2889 .27138 L
.28911 .27142 L
.28933 .27146 L
.28954 .2715 L
Mistroke
.28974 .27153 L
.28995 .27158 L
.29016 .27162 L
.29038 .27166 L
.29059 .27171 L
.2908 .27175 L
.29101 .2718 L
.29122 .27184 L
.29145 .27189 L
.29166 .27194 L
.29187 .27199 L
.29208 .27205 L
.2923 .2721 L
.2925 .27215 L
.29271 .2722 L
.29292 .27226 L
.29314 .27231 L
.29336 .27237 L
.29356 .27243 L
.29378 .27249 L
.29399 .27254 L
.29419 .2726 L
.2944 .27266 L
.29461 .27272 L
.29483 .27279 L
.29504 .27285 L
.29525 .27292 L
.29546 .27298 L
.29567 .27305 L
.29589 .27312 L
.29611 .27319 L
.29631 .27326 L
.29653 .27333 L
.29674 .2734 L
.29694 .27347 L
.29716 .27355 L
.29737 .27362 L
.29759 .2737 L
.2978 .27378 L
.298 .27385 L
.29822 .27393 L
.29843 .27401 L
.29865 .2741 L
.29887 .27418 L
.29907 .27426 L
.29929 .27435 L
.2995 .27443 L
.29971 .27452 L
.29992 .2746 L
.30013 .27469 L
Mistroke
.30035 .27478 L
.30056 .27488 L
.30077 .27496 L
.30099 .27506 L
.3012 .27515 L
.3014 .27524 L
.30161 .27534 L
.30182 .27543 L
.30204 .27554 L
.30225 .27563 L
.30246 .27573 L
.30267 .27583 L
.30288 .27594 L
.3031 .27604 L
.30332 .27615 L
.30352 .27625 L
.30374 .27636 L
.30395 .27647 L
.30416 .27658 L
.30437 .27669 L
.30458 .2768 L
.3048 .27692 L
.30501 .27703 L
.30522 .27714 L
.30543 .27726 L
.30564 .27738 L
.30587 .2775 L
.30608 .27762 L
.30629 .27774 L
.30651 .27787 L
.30672 .27799 L
.30692 .27812 L
.30714 .27824 L
.30735 .27837 L
.30757 .27851 L
.30778 .27864 L
.30799 .27877 L
.30821 .2789 L
.30842 .27904 L
.30862 .27917 L
.30883 .27931 L
.30904 .27944 L
.30926 .27959 L
.30947 .27973 L
.30968 .27987 L
.30989 .28002 L
.3101 .28016 L
.31033 .28032 L
.31054 .28047 L
.31075 .28061 L
Mistroke
.31096 .28077 L
.31118 .28092 L
.31138 .28107 L
.31159 .28123 L
.3118 .28139 L
.31202 .28155 L
.31224 .28172 L
.31244 .28187 L
.31266 .28204 L
.31287 .28221 L
.31307 .28237 L
.31329 .28254 L
.31349 .28271 L
.31371 .28289 L
.31392 .28307 L
.31413 .28324 L
.31434 .28342 L
.31455 .2836 L
.31477 .28379 L
.31499 .28397 L
.31519 .28415 L
.31541 .28435 L
.31562 .28454 L
.31583 .28472 L
.31604 .28492 L
.31625 .28511 L
.31647 .28532 L
.31668 .28552 L
.31689 .28572 L
.3171 .28593 L
.31731 .28613 L
.31754 .28635 L
.31775 .28657 L
.31796 .28678 L
.31818 .287 L
.31839 .28722 L
.31859 .28743 L
.31881 .28766 L
.31901 .28788 L
.31924 .28812 L
.31945 .28835 L
.31965 .28858 L
.31987 .28882 L
.32008 .28906 L
.32028 .28929 L
.3205 .28954 L
.32071 .28978 L
.32093 .29004 L
.32114 .2903 L
.32134 .29055 L
Mistroke
.32156 .29081 L
.32177 .29107 L
.32199 .29135 L
.3222 .29162 L
.32241 .29189 L
.32263 .29217 L
.32284 .29245 L
.32304 .29272 L
.32326 .29302 L
.32347 .2933 L
.32369 .29361 L
.3239 .29391 L
.3241 .2942 L
.32432 .29452 L
.32453 .29482 L
.32473 .29512 L
.32495 .29545 L
.32515 .29576 L
.32537 .2961 L
.32559 .29643 L
.32579 .29676 L
.32601 .29711 L
.32621 .29745 L
.32644 .29782 L
.32665 .29818 L
.32685 .29853 L
.32707 .29891 L
.32728 .29929 L
.32749 .29965 L
.3277 .30004 L
.32791 .30043 L
.32813 .30084 L
.32834 .30125 L
.32854 .30165 L
.32876 .30208 L
.32897 .3025 L
.32919 .30296 L
.32941 .30341 L
.32961 .30385 L
.32983 .30433 L
.33004 .30479 L
.33025 .30525 L
.33046 .30575 L
.33067 .30624 L
.33089 .30677 L
.33111 .30729 L
.33131 .3078 L
.33153 .30836 L
.33174 .30891 L
.33194 .30945 L
Mistroke
.33215 .31003 L
.33236 .31061 L
.33258 .31124 L
.33279 .31186 L
.333 .31247 L
.33321 .31314 L
.33342 .3138 L
.33364 .31452 L
.33386 .31524 L
.33406 .31595 L
.33428 .31672 L
.33449 .31749 L
.3347 .31826 L
.33491 .31909 L
.33512 .31993 L
.33534 .32085 L
.33555 .32176 L
.33576 .32268 L
.33597 .32369 L
.33618 .3247 L
.33641 .32583 L
.33662 .32696 L
.33683 .3281 L
.33705 .32937 L
.33726 .33065 L
.33746 .33196 L
.33768 .33342 L
.33789 .33492 L
.33811 .33661 L
.33832 .33836 L
.33853 .34016 L
.33874 .34223 L
.33895 .3444 L
.33916 .34668 L
.33937 .34935 L
.33958 .35223 L
.3398 .35571 L
.34001 .35958 L
.34022 .36398 L
.34043 .3697 L
.34064 .37683 L
.34076 .38182 L
.34086 .38765 L
.34097 .39525 L
.34102 .39989 L
.34107 .40518 L
.34112 .41165 L
.34116 .4212 L
.34118 .42461 L
.34119 .42894 L
Mistroke
.34121 .4335 L
.34122 .4395 L
.34123 .4465 L
.34124 .4516 L
.34125 .45758 L
.34125 .4647 L
.34126 .47372 L
.34126 .49005 L
Mfstroke
.34126 .49005 m
.34126 .5 L
s
.34128 .5 m
.34128 .49047 L
.34128 .47465 L
.34129 .46388 L
.34129 .45676 L
.34131 .44765 L
.34132 .44052 L
.34133 .43449 L
.34135 .42938 L
.34137 .42224 L
.34142 .41219 L
.34145 .40789 L
.34148 .40445 L
.34158 .39401 L
.34165 .38964 L
.3417 .38622 L
.34191 .37635 L
.34212 .36956 L
.34234 .36393 L
.34254 .35952 L
.34277 .35556 L
.34298 .35228 L
.34319 .34949 L
.34341 .34683 L
.34362 .34452 L
.34382 .34249 L
.34404 .3405 L
.34424 .33873 L
.34446 .33698 L
.34468 .33541 L
.34488 .33399 L
.3451 .33257 L
.34531 .33127 L
.34551 .33009 L
.34573 .3289 L
.34593 .3278 L
.34615 .32669 L
.34637 .32566 L
.34657 .32472 L
.34679 .32376 L
.34699 .32287 L
.34722 .32195 L
.34743 .32111 L
.34764 .32032 L
.34785 .31952 L
.34806 .31877 L
.34827 .31807 L
.34848 .31735 L
.34869 .31668 L
.34891 .31598 L
Mistroke
.34912 .31533 L
.34933 .31473 L
.34954 .3141 L
.34975 .31351 L
.34998 .3129 L
.35019 .31233 L
.3504 .3118 L
.35062 .31125 L
.35083 .31073 L
.35103 .31024 L
.35125 .30973 L
.35146 .30925 L
.35168 .30875 L
.35189 .30828 L
.3521 .30784 L
.35231 .30739 L
.35252 .30695 L
.35273 .30655 L
.35294 .30612 L
.35315 .30572 L
.35337 .3053 L
.35358 .30491 L
.35378 .30454 L
.354 .30415 L
.35421 .30378 L
.35443 .3034 L
.35465 .30304 L
.35485 .3027 L
.35507 .30234 L
.35528 .30201 L
.35548 .30169 L
.3557 .30135 L
.35591 .30104 L
.35613 .30071 L
.35634 .3004 L
.35655 .3001 L
.35676 .29979 L
.35697 .2995 L
.35718 .29922 L
.35739 .29893 L
.3576 .29866 L
.35782 .29837 L
.35803 .2981 L
.35823 .29784 L
.35845 .29757 L
.35866 .29731 L
.35888 .29704 L
.35909 .29679 L
.3593 .29654 L
.35952 .29629 L
Mistroke
.35973 .29605 L
.35993 .29582 L
.36014 .29558 L
.36035 .29536 L
.36057 .29512 L
.36078 .29489 L
.36099 .29468 L
.3612 .29446 L
.36141 .29424 L
.36164 .29402 L
.36185 .29381 L
.36206 .29361 L
.36228 .2934 L
.36249 .2932 L
.36269 .29301 L
.36291 .29281 L
.36311 .29262 L
.36334 .29242 L
.36355 .29223 L
.36375 .29205 L
.36397 .29186 L
.36418 .29169 L
.36438 .29152 L
.3646 .29134 L
.36481 .29117 L
.36503 .29099 L
.36524 .29082 L
.36544 .29066 L
.36566 .2905 L
.36587 .29034 L
.36609 .29017 L
.3663 .29001 L
.36651 .28986 L
.36673 .2897 L
.36694 .28955 L
.36714 .28941 L
.36736 .28926 L
.36756 .28911 L
.36778 .28896 L
.368 .28882 L
.3682 .28869 L
.36842 .28854 L
.36863 .28841 L
.36885 .28827 L
.36906 .28813 L
.36927 .288 L
.36949 .28787 L
.3697 .28774 L
.36991 .28762 L
.37012 .28749 L
Mistroke
.37033 .28737 L
.37055 .28725 L
.37077 .28713 L
.37097 .28701 L
.37119 .28689 L
.3714 .28678 L
.3716 .28667 L
.37182 .28656 L
.37202 .28645 L
.37224 .28634 L
.37246 .28623 L
.37266 .28613 L
.37288 .28602 L
.37309 .28592 L
.37331 .28581 L
.37352 .28571 L
.37373 .28561 L
.37395 .28551 L
.37416 .28542 L
.37436 .28533 L
.37458 .28523 L
.37478 .28514 L
.37501 .28505 L
.37522 .28496 L
.37542 .28487 L
.37564 .28478 L
.37585 .2847 L
.37605 .28462 L
.37627 .28453 L
.37647 .28445 L
.37669 .28437 L
.37691 .28429 L
.37711 .28422 L
.37733 .28414 L
.37753 .28406 L
.37776 .28398 L
.37797 .28391 L
.37818 .28384 L
.37839 .28377 L
.3786 .2837 L
.37881 .28363 L
.37902 .28356 L
.37923 .2835 L
.37945 .28343 L
.37966 .28337 L
.37987 .2833 L
.38008 .28324 L
.38029 .28318 L
.38052 .28312 L
.38073 .28306 L
Mistroke
.38094 .283 L
.38116 .28294 L
.38137 .28289 L
.38157 .28283 L
.38179 .28278 L
.38199 .28273 L
.38222 .28267 L
.38243 .28262 L
.38263 .28258 L
.38285 .28253 L
.38306 .28248 L
.38326 .28243 L
.38348 .28239 L
.38369 .28235 L
.38391 .2823 L
.38412 .28226 L
.38432 .28222 L
.38454 .28218 L
.38475 .28214 L
.38497 .2821 L
.38518 .28206 L
.38539 .28202 L
.38561 .28199 L
.38582 .28195 L
.38602 .28192 L
.38624 .28189 L
.38645 .28186 L
.38667 .28182 L
.38688 .28179 L
.38708 .28177 L
.3873 .28174 L
.38751 .28171 L
.38771 .28169 L
.38793 .28166 L
.38813 .28164 L
.38835 .28161 L
.38856 .28159 L
.38877 .28157 L
.38898 .28155 L
.38919 .28153 L
.38941 .28151 L
.38963 .28149 L
.38983 .28147 L
.39005 .28146 L
.39026 .28144 L
.39046 .28143 L
.39068 .28142 L
.39089 .2814 L
.39111 .28139 L
.39132 .28138 L
Mistroke
.39152 .28137 L
.39174 .28136 L
.39195 .28135 L
.39217 .28135 L
.39239 .28134 L
.39259 .28134 L
.39281 .28133 L
.39302 .28133 L
.39323 .28133 L
.39333 .28132 L
.39344 .28132 L
.3935 .28132 L
.39356 .28132 L
.39358 .28132 L
.39361 .28132 L
.39364 .28132 L
.39366 .28132 L
.39369 .28132 L
.3937 .28132 L
.39371 .28132 L
.39372 .28132 L
.39373 .28132 L
.39373 .28132 L
.39373 .28132 L
.39374 .28132 L
.39375 .28132 L
.39375 .28132 L
.39376 .28132 L
.39377 .28132 L
.39377 .28132 L
.39378 .28132 L
.39379 .28132 L
.3938 .28132 L
.39382 .28132 L
.39384 .28132 L
.39386 .28132 L
.39392 .28132 L
.39397 .28132 L
.39407 .28132 L
.39418 .28132 L
.39428 .28133 L
.39449 .28133 L
.39469 .28133 L
.39491 .28134 L
.39512 .28134 L
.39534 .28135 L
.39555 .28135 L
.39576 .28136 L
.39598 .28137 L
.39619 .28138 L
Mistroke
.39639 .28139 L
.3966 .2814 L
.39681 .28142 L
.39703 .28143 L
.39724 .28144 L
.39745 .28146 L
.39767 .28147 L
.39787 .28149 L
.3981 .28151 L
.39831 .28153 L
.39852 .28155 L
.39874 .28157 L
.39895 .28159 L
.39915 .28161 L
.39936 .28164 L
.39957 .28166 L
.39979 .28168 L
.40001 .28171 L
.40021 .28174 L
.40043 .28177 L
.40064 .28179 L
.40084 .28182 L
.40105 .28185 L
.40126 .28188 L
.40148 .28192 L
.40169 .28195 L
.4019 .28198 L
.40211 .28202 L
.40232 .28205 L
.40254 .28209 L
.40276 .28213 L
.40296 .28217 L
.40318 .28221 L
.40339 .28225 L
.40359 .28229 L
.40381 .28233 L
.40402 .28238 L
.40424 .28242 L
.40445 .28247 L
.40465 .28251 L
.40487 .28256 L
.40508 .28261 L
.4053 .28266 L
.40552 .28271 L
.40572 .28276 L
.40594 .28282 L
.40615 .28287 L
.40636 .28292 L
.40657 .28298 L
.40678 .28304 L
Mistroke
.407 .2831 L
.40721 .28316 L
.40742 .28321 L
.40764 .28328 L
.40785 .28334 L
.40805 .2834 L
.40826 .28346 L
.40847 .28352 L
.40869 .28359 L
.4089 .28366 L
.40911 .28373 L
.40932 .2838 L
.40953 .28387 L
.40975 .28394 L
.40997 .28401 L
.41017 .28409 L
.41039 .28416 L
.4106 .28424 L
.41081 .28431 L
.41102 .28439 L
.41123 .28447 L
.41145 .28455 L
.41166 .28464 L
.41187 .28472 L
.41209 .2848 L
.41229 .28489 L
.41252 .28498 L
.41273 .28507 L
.41294 .28516 L
.41316 .28525 L
.41337 .28534 L
.41357 .28543 L
.41379 .28553 L
.414 .28562 L
.41422 .28572 L
.41443 .28582 L
.41464 .28592 L
.41486 .28602 L
.41507 .28612 L
.41527 .28622 L
.41548 .28633 L
.41569 .28643 L
.41591 .28654 L
.41612 .28665 L
.41633 .28676 L
.41654 .28687 L
.41675 .28699 L
.41698 .28711 L
.41719 .28723 L
.4174 .28734 L
Mistroke
.41762 .28746 L
.41783 .28758 L
.41803 .2877 L
.41825 .28783 L
.41845 .28795 L
.41867 .28809 L
.41889 .28821 L
.41909 .28834 L
.41931 .28848 L
.41952 .28861 L
.41972 .28874 L
.41994 .28888 L
.42014 .28902 L
.42036 .28916 L
.42057 .2893 L
.42078 .28944 L
.42099 .28959 L
.4212 .28974 L
.42142 .2899 L
.42164 .29005 L
.42184 .2902 L
.42206 .29036 L
.42227 .29052 L
.42248 .29067 L
.42269 .29084 L
.4229 .291 L
.42312 .29117 L
.42333 .29134 L
.42354 .29151 L
.42375 .29169 L
.42396 .29186 L
.42419 .29205 L
.4244 .29223 L
.42461 .29241 L
.42483 .2926 L
.42504 .29279 L
.42524 .29297 L
.42546 .29316 L
.42566 .29336 L
.42589 .29356 L
.4261 .29377 L
.4263 .29396 L
.42652 .29418 L
.42673 .29438 L
.42693 .29458 L
.42715 .2948 L
.42736 .29502 L
.42758 .29525 L
.42779 .29547 L
.42799 .29569 L
Mistroke
.42821 .29593 L
.42842 .29616 L
.42864 .2964 L
.42885 .29665 L
.42906 .29689 L
.42928 .29714 L
.42949 .29739 L
.42969 .29764 L
.42991 .2979 L
.43012 .29816 L
.43034 .29844 L
.43055 .29871 L
.43075 .29898 L
.43097 .29927 L
.43118 .29955 L
.43138 .29982 L
.4316 .30012 L
.4318 .30041 L
.43202 .30073 L
.43224 .30104 L
.43244 .30134 L
.43266 .30167 L
.43286 .30199 L
.43309 .30233 L
.4333 .30267 L
.4335 .303 L
.43372 .30336 L
.43393 .30372 L
.43414 .30406 L
.43435 .30444 L
.43456 .3048 L
.43478 .3052 L
.43499 .30559 L
.4352 .30598 L
.43541 .3064 L
.43562 .3068 L
.43584 .30725 L
.43606 .30769 L
.43626 .30812 L
.43648 .30858 L
.43669 .30905 L
.4369 .3095 L
.43711 .30999 L
.43732 .31048 L
.43754 .311 L
.43776 .31153 L
.43796 .31204 L
.43818 .3126 L
.43839 .31316 L
.43859 .3137 L
Mistroke
.43881 .3143 L
.43901 .31489 L
.43923 .31554 L
.43944 .31618 L
.43965 .31682 L
.43986 .31751 L
.44007 .3182 L
.4403 .31896 L
.44051 .31972 L
.44071 .32047 L
.44093 .3213 L
.44114 .32213 L
.44135 .32296 L
.44156 .32387 L
.44177 .32479 L
.44199 .3258 L
.4422 .32682 L
.44241 .32785 L
.44262 .32899 L
.44283 .33015 L
.44306 .33145 L
.44327 .33277 L
.44348 .33411 L
.4437 .33563 L
.44391 .33719 L
.44411 .3388 L
.44433 .34063 L
.44454 .34254 L
.44476 .34476 L
.44497 .3471 L
.44518 .34959 L
.44539 .35256 L
.44561 .35581 L
.44581 .3594 L
.44602 .36392 L
.44623 .36923 L
.44645 .37651 L
.44656 .38116 L
.44666 .38644 L
.44676 .39292 L
.44687 .40243 L
.44692 .40938 L
.44695 .41438 L
.44698 .42008 L
.44701 .42647 L
.44703 .43613 L
.44705 .44294 L
.44705 .44769 L
.44706 .45322 L
.44707 .45978 L
Mistroke
.44707 .46409 L
.44708 .46969 L
.44708 .48439 L
Mfstroke
.44708 .48439 m
.44708 .5 L
s
.4471 .5 m
.4471 .49047 L
.4471 .47465 L
.44711 .46388 L
.44711 .45676 L
.44713 .44765 L
.44714 .44051 L
.44715 .43448 L
.44717 .42937 L
.44719 .42222 L
.44724 .41216 L
.44727 .40785 L
.4473 .4044 L
.4474 .39394 L
.44747 .38955 L
.44752 .38612 L
.44773 .3762 L
.44794 .36936 L
.44816 .36368 L
.44836 .35922 L
.44859 .35521 L
.4488 .35187 L
.44901 .34903 L
.44923 .34633 L
.44944 .34397 L
.44964 .34189 L
.44986 .33985 L
.45006 .33803 L
.45028 .33623 L
.4505 .3346 L
.4507 .33313 L
.45092 .33166 L
.45113 .33031 L
.45133 .32908 L
.45155 .32783 L
.45175 .32668 L
.45197 .32552 L
.45219 .32444 L
.45239 .32345 L
.45261 .32243 L
.45281 .32149 L
.45304 .32052 L
.45325 .31962 L
.45346 .31879 L
.45367 .31793 L
.45388 .31712 L
.45409 .31638 L
.4543 .3156 L
.45451 .31488 L
.45473 .31413 L
Mistroke
.45494 .31342 L
.45515 .31277 L
.45536 .31208 L
.45557 .31144 L
.4558 .31078 L
.45601 .31015 L
.45622 .30957 L
.45644 .30896 L
.45665 .30838 L
.45685 .30784 L
.45707 .30728 L
.45728 .30674 L
.4575 .30619 L
.45771 .30567 L
.45792 .30517 L
.45813 .30466 L
.45834 .30417 L
.45855 .30371 L
.45876 .30323 L
.45897 .30277 L
.45919 .3023 L
.4594 .30185 L
.4596 .30142 L
.45982 .30098 L
.46003 .30056 L
.46025 .30011 L
.46047 .2997 L
.46067 .2993 L
.46089 .29888 L
.4611 .29849 L
.4613 .29812 L
.46152 .29772 L
.46173 .29735 L
.46195 .29696 L
.46216 .29659 L
.46237 .29624 L
.46258 .29587 L
.46279 .29552 L
.463 .29519 L
.46321 .29484 L
.46342 .29451 L
.46364 .29416 L
.46385 .29383 L
.46405 .29351 L
.46427 .29318 L
.46448 .29287 L
.4647 .29254 L
.46491 .29222 L
.46512 .29192 L
.46534 .29161 L
Mistroke
.46555 .29131 L
.46575 .29102 L
.46596 .29072 L
.46617 .29044 L
.46639 .29014 L
.4666 .28985 L
.46681 .28958 L
.46703 .28929 L
.46723 .28902 L
.46746 .28873 L
.46767 .28846 L
.46788 .28819 L
.4681 .28792 L
.46831 .28766 L
.46851 .28741 L
.46873 .28715 L
.46893 .2869 L
.46916 .28663 L
.46937 .28638 L
.46957 .28614 L
.46979 .28589 L
.47 .28565 L
.4702 .28542 L
.47042 .28517 L
.47063 .28494 L
.47085 .2847 L
.47106 .28447 L
.47126 .28425 L
.47148 .28401 L
.47169 .28379 L
.47191 .28355 L
.47212 .28333 L
.47233 .28311 L
.47255 .28289 L
.47276 .28267 L
.47296 .28247 L
.47318 .28225 L
.47338 .28204 L
.4736 .28182 L
.47382 .28161 L
.47402 .28142 L
.47424 .2812 L
.47445 .281 L
.47467 .28079 L
.47489 .28059 L
.47509 .2804 L
.47531 .28019 L
.47552 .28 L
.47573 .27981 L
.47594 .27961 L
Mistroke
.47615 .27943 L
.47637 .27923 L
.47659 .27904 L
.47679 .27886 L
.47701 .27867 L
.47722 .27849 L
.47742 .27831 L
.47764 .27813 L
.47784 .27795 L
.47806 .27776 L
.47828 .27759 L
.47848 .27742 L
.4787 .27724 L
.47891 .27707 L
.47913 .27689 L
.47934 .27671 L
.47955 .27655 L
.47977 .27637 L
.47998 .27621 L
.48018 .27605 L
.4804 .27588 L
.4806 .27572 L
.48083 .27555 L
.48104 .27538 L
.48124 .27523 L
.48146 .27506 L
.48167 .2749 L
.48187 .27475 L
.48209 .27459 L
.48229 .27444 L
.48251 .27428 L
.48273 .27413 L
.48293 .27398 L
.48315 .27382 L
.48335 .27368 L
.48358 .27352 L
.48379 .27337 L
.484 .27322 L
.48421 .27307 L
.48442 .27293 L
.48463 .27279 L
.48484 .27264 L
.48505 .2725 L
.48527 .27235 L
.48548 .27221 L
.48569 .27207 L
.4859 .27193 L
.48611 .27179 L
.48634 .27165 L
.48655 .27151 L
Mistroke
.48676 .27137 L
.48698 .27123 L
.48719 .2711 L
.48739 .27097 L
.48761 .27083 L
.48781 .2707 L
.48804 .27056 L
.48825 .27043 L
.48845 .2703 L
.48867 .27017 L
.48888 .27004 L
.48908 .26992 L
.4893 .26979 L
.48951 .26967 L
.48973 .26954 L
.48994 .26941 L
.49014 .26929 L
.49036 .26916 L
.49057 .26904 L
.49079 .26891 L
.491 .26879 L
.49121 .26867 L
.49143 .26855 L
.49164 .26843 L
.49184 .26831 L
.49206 .26819 L
.49227 .26808 L
.49249 .26795 L
.4927 .26784 L
.4929 .26772 L
.49312 .26761 L
.49333 .26749 L
.49353 .26738 L
.49375 .26727 L
.49395 .26716 L
.49417 .26704 L
.49438 .26693 L
.49459 .26682 L
.4948 .26671 L
.49501 .2666 L
.49523 .26649 L
.49545 .26638 L
.49565 .26627 L
.49587 .26616 L
.49608 .26605 L
.49628 .26595 L
.4965 .26584 L
.49671 .26574 L
.49693 .26563 L
.49714 .26553 L
Mistroke
.49734 .26543 L
.49756 .26532 L
.49777 .26522 L
.49799 .26511 L
.49821 .26501 L
.49841 .26491 L
.49863 .26481 L
.49884 .26471 L
.49905 .26461 L
.49926 .26451 L
.49947 .26441 L
.49969 .26431 L
.4999 .26421 L
.50011 .26412 L
.50033 .26402 L
.50054 .26392 L
.50074 .26383 L
.50095 .26373 L
.50116 .26364 L
.50138 .26354 L
.50159 .26345 L
.5018 .26336 L
.50201 .26326 L
.50222 .26317 L
.50244 .26308 L
.50266 .26298 L
.50286 .2629 L
.50308 .2628 L
.50329 .26271 L
.50349 .26263 L
.50371 .26254 L
.50392 .26245 L
.50414 .26236 L
.50435 .26227 L
.50455 .26218 L
.50477 .26209 L
.50498 .26201 L
.5052 .26192 L
.50542 .26183 L
.50562 .26175 L
.50584 .26166 L
.50606 .26157 L
.50626 .26149 L
.50648 .26141 L
.50668 .26133 L
.5069 .26124 L
.50712 .26116 L
.50732 .26108 L
.50754 .26099 L
.50775 .26091 L
Mistroke
.50795 .26083 L
.50817 .26075 L
.50838 .26067 L
.5086 .26059 L
.50881 .26051 L
.50901 .26043 L
.50923 .26035 L
.50944 .26027 L
.50966 .26019 L
.50987 .26011 L
.51008 .26004 L
.5103 .25996 L
.51051 .25988 L
.51071 .25981 L
.51093 .25973 L
.51114 .25966 L
.51136 .25958 L
.51157 .25951 L
.51177 .25943 L
.51199 .25936 L
.5122 .25928 L
.5124 .25921 L
.51262 .25914 L
.51283 .25907 L
.51305 .25899 L
.51326 .25892 L
.51346 .25885 L
.51368 .25878 L
.51389 .25871 L
.51411 .25864 L
.51432 .25856 L
.51453 .2585 L
.51474 .25842 L
.51496 .25836 L
.51516 .25829 L
.51537 .25822 L
.51558 .25815 L
.5158 .25808 L
.51601 .25801 L
.51622 .25795 L
.51643 .25788 L
.51664 .25781 L
.51687 .25774 L
.51708 .25768 L
.51729 .25761 L
.51751 .25754 L
.51772 .25748 L
.51792 .25742 L
.51814 .25735 L
.51834 .25729 L
Mistroke
.51857 .25722 L
.51878 .25716 L
.51898 .25709 L
.5192 .25703 L
.51941 .25697 L
.51961 .25691 L
.51983 .25684 L
.52004 .25678 L
.52026 .25672 L
.52047 .25666 L
.52067 .2566 L
.52089 .25654 L
.5211 .25648 L
.52132 .25641 L
.52153 .25635 L
.52174 .25629 L
.52196 .25623 L
.52217 .25617 L
.52237 .25612 L
.52259 .25606 L
.52279 .256 L
.52301 .25594 L
.52323 .25588 L
.52343 .25583 L
.52365 .25577 L
.52386 .25571 L
.52408 .25565 L
.5243 .25559 L
.5245 .25554 L
.52472 .25548 L
.52493 .25542 L
.52514 .25537 L
.52535 .25531 L
.52556 .25526 L
.52578 .2552 L
.526 .25515 L
.5262 .2551 L
.52642 .25504 L
.52663 .25499 L
.52683 .25494 L
.52705 .25488 L
.52725 .25483 L
.52748 .25478 L
.52769 .25472 L
.52789 .25467 L
.52811 .25462 L
.52832 .25457 L
.52854 .25451 L
.52875 .25446 L
.52896 .25441 L
Mistroke
.52918 .25436 L
.52939 .25431 L
.52959 .25426 L
.52981 .25421 L
.53002 .25416 L
.53024 .25411 L
.53045 .25406 L
.53066 .25401 L
.53087 .25396 L
.53108 .25391 L
.53129 .25387 L
.5315 .25382 L
.53171 .25377 L
.53193 .25372 L
.53214 .25368 L
.53234 .25363 L
.53256 .25358 L
.53277 .25354 L
.53299 .25349 L
.5332 .25344 L
.53341 .2534 L
.53363 .25335 L
.53384 .2533 L
.53404 .25326 L
.53426 .25321 L
.53446 .25317 L
.53468 .25312 L
.5349 .25308 L
.5351 .25303 L
.53532 .25299 L
.53553 .25295 L
.53575 .2529 L
.53596 .25286 L
.53617 .25281 L
.53639 .25277 L
.5366 .25273 L
.5368 .25269 L
.53702 .25264 L
.53723 .2526 L
.53745 .25256 L
.53766 .25251 L
.53787 .25247 L
.53809 .25243 L
.5383 .25239 L
.5385 .25235 L
.53871 .25231 L
.53892 .25227 L
.53914 .25223 L
.53935 .25219 L
.53956 .25215 L
Mistroke
.53977 .25211 L
.53998 .25207 L
.5402 .25203 L
.54042 .25199 L
.54062 .25195 L
.54084 .25191 L
.54105 .25187 L
.54126 .25183 L
.54147 .2518 L
.54168 .25176 L
.5419 .25172 L
.54211 .25168 L
.54232 .25164 L
.54254 .25161 L
.54275 .25157 L
.54295 .25153 L
.54316 .2515 L
.54337 .25146 L
.54359 .25142 L
.5438 .25139 L
.544 .25135 L
.54422 .25132 L
.54443 .25128 L
.54465 .25124 L
.54486 .25121 L
.54507 .25117 L
.54529 .25114 L
.5455 .2511 L
.5457 .25107 L
.54591 .25104 L
.54612 .251 L
.54634 .25097 L
.54655 .25093 L
.54676 .2509 L
.54698 .25087 L
.54719 .25083 L
.54741 .2508 L
.54762 .25077 L
.54783 .25073 L
.54805 .2507 L
.54826 .25067 L
.54846 .25064 L
.54868 .2506 L
.54889 .25057 L
.54911 .25054 L
.54932 .25051 L
.54952 .25048 L
.54974 .25045 L
.54995 .25042 L
.55015 .25039 L
Mistroke
.55037 .25035 L
.55058 .25033 L
.5508 .25029 L
.55101 .25026 L
.55121 .25023 L
.55143 .2502 L
.55164 .25017 L
.55186 .25014 L
.55207 .25011 L
.55228 .25009 L
.5525 .25006 L
.55271 .25003 L
.55291 .25 L
Mfstroke
.55291 .25 m
.55312 .24997 L
.55334 .24994 L
.55355 .24991 L
.55376 .24989 L
.55397 .24986 L
.55418 .24983 L
.5544 .2498 L
.55462 .24977 L
.55482 .24975 L
.55504 .24972 L
.55525 .24969 L
.55545 .24967 L
.55567 .24964 L
.55588 .24962 L
.5561 .24959 L
.55631 .24956 L
.55651 .24954 L
.55673 .24951 L
.55694 .24949 L
.55716 .24946 L
.55737 .24943 L
.55758 .24941 L
.5578 .24938 L
.55801 .24936 L
.55821 .24933 L
.55843 .24931 L
.55864 .24928 L
.55886 .24926 L
.55907 .24924 L
.55928 .24921 L
.55949 .24919 L
.5597 .24916 L
.55991 .24914 L
.56012 .24912 L
.56033 .2491 L
.56055 .24907 L
.56076 .24905 L
.56096 .24903 L
.56118 .249 L
.56139 .24898 L
.56161 .24896 L
.56182 .24894 L
.56203 .24891 L
.56225 .24889 L
.56246 .24887 L
.56266 .24885 L
.56288 .24883 L
.56308 .24881 L
.5633 .24878 L
Mistroke
.56352 .24876 L
.56372 .24874 L
.56394 .24872 L
.56415 .2487 L
.56437 .24868 L
.56458 .24866 L
.56479 .24864 L
.56501 .24862 L
.56522 .2486 L
.56543 .24858 L
.56564 .24856 L
.56585 .24854 L
.56607 .24852 L
.56628 .2485 L
.56649 .24848 L
.56671 .24846 L
.56692 .24844 L
.56712 .24843 L
.56733 .24841 L
.56754 .24839 L
.56776 .24837 L
.56797 .24835 L
.56818 .24834 L
.56839 .24832 L
.5686 .2483 L
.56883 .24828 L
.56904 .24826 L
.56925 .24825 L
.56946 .24823 L
.56968 .24821 L
.56988 .2482 L
.57009 .24818 L
.5703 .24816 L
.57052 .24814 L
.57074 .24813 L
.57094 .24811 L
.57116 .2481 L
.57137 .24808 L
.57157 .24807 L
.57178 .24805 L
.57199 .24803 L
.57221 .24802 L
.57242 .248 L
.57263 .24799 L
.57284 .24797 L
.57305 .24796 L
.57327 .24794 L
.57349 .24793 L
.57369 .24791 L
.57391 .2479 L
Mistroke
.57412 .24788 L
.57432 .24787 L
.57454 .24786 L
.57474 .24784 L
.57496 .24783 L
.57518 .24781 L
.57538 .2478 L
.5756 .24779 L
.57581 .24777 L
.57603 .24776 L
.57624 .24775 L
.57645 .24773 L
.57667 .24772 L
.57688 .24771 L
.57708 .2477 L
.5773 .24768 L
.57751 .24767 L
.57773 .24766 L
.57794 .24765 L
.57815 .24763 L
.57837 .24762 L
.57858 .24761 L
.57878 .2476 L
.57899 .24759 L
.5792 .24758 L
.57942 .24756 L
.57963 .24755 L
.57983 .24754 L
.58005 .24753 L
.58026 .24752 L
.58048 .24751 L
.5807 .2475 L
.5809 .24749 L
.58112 .24748 L
.58133 .24747 L
.58153 .24746 L
.58175 .24745 L
.58196 .24744 L
.58218 .24743 L
.58239 .24742 L
.58259 .24741 L
.58281 .2474 L
.58302 .24739 L
.58324 .24738 L
.58346 .24737 L
.58367 .24736 L
.58388 .24735 L
.5841 .24734 L
.5843 .24734 L
.58452 .24733 L
Mistroke
.58472 .24732 L
.58495 .24731 L
.58516 .2473 L
.58536 .2473 L
.58558 .24729 L
.58579 .24728 L
.58599 .24727 L
.58621 .24726 L
.58642 .24726 L
.58664 .24725 L
.58685 .24724 L
.58705 .24723 L
.58727 .24723 L
.58748 .24722 L
.5877 .24721 L
.58792 .24721 L
.58812 .2472 L
.58834 .24719 L
.58855 .24719 L
.58875 .24718 L
.58897 .24717 L
.58918 .24717 L
.5894 .24716 L
.58961 .24716 L
.58982 .24715 L
.59004 .24715 L
.59024 .24714 L
.59045 .24713 L
.59066 .24713 L
.59087 .24712 L
.59109 .24712 L
.5913 .24711 L
.5915 .24711 L
.59172 .2471 L
.59193 .2471 L
.59215 .24709 L
.59236 .24709 L
.59257 .24709 L
.59279 .24708 L
.593 .24708 L
.5932 .24707 L
.59342 .24707 L
.59362 .24707 L
.59384 .24706 L
.59406 .24706 L
.59426 .24705 L
.59448 .24705 L
.59469 .24705 L
.59491 .24704 L
.59512 .24704 L
Mistroke
.59533 .24704 L
.59555 .24703 L
.59576 .24703 L
.59596 .24703 L
.59618 .24703 L
.59639 .24702 L
.59661 .24702 L
.59682 .24702 L
.59703 .24702 L
.59725 .24701 L
.59746 .24701 L
.59766 .24701 L
.59787 .24701 L
.59808 .24701 L
.5983 .24701 L
.59851 .247 L
.59872 .247 L
.59893 .247 L
.59914 .247 L
.59936 .247 L
.59958 .247 L
.59978 .247 L
.6 .247 L
.60021 .247 L
.60042 .24699 L
.60063 .24699 L
.60084 .24699 L
.60106 .24699 L
.60117 .24699 L
.60127 .24699 L
.60138 .24699 L
.60148 .24699 L
.60153 .24699 L
.60158 .24699 L
.6016 .24699 L
.60163 .24699 L
.60166 .24699 L
.60169 .24699 L
.6017 .24699 L
.60171 .24699 L
.60172 .24699 L
.60173 .24699 L
.60173 .24699 L
.60174 .24699 L
.60174 .24699 L
.60175 .24699 L
.60176 .24699 L
.60176 .24699 L
.60177 .24699 L
.60177 .24699 L
Mistroke
.60178 .24699 L
.60178 .24699 L
.60179 .24699 L
.60179 .24699 L
.6018 .24699 L
.60182 .24699 L
.60184 .24699 L
.60186 .24699 L
.60189 .24699 L
.60195 .24699 L
.60199 .24699 L
.60211 .24699 L
.60221 .24699 L
.60232 .24699 L
.60254 .24699 L
.60275 .24699 L
.60295 .24699 L
.60316 .247 L
.60337 .247 L
.60359 .247 L
.6038 .247 L
.60401 .247 L
.60422 .247 L
.60443 .247 L
.60465 .247 L
.60487 .247 L
.60507 .247 L
.60529 .24701 L
.6055 .24701 L
.6057 .24701 L
.60592 .24701 L
.60613 .24701 L
.60635 .24702 L
.60656 .24702 L
.60677 .24702 L
.60698 .24702 L
.60719 .24702 L
.60741 .24703 L
.60763 .24703 L
.60784 .24703 L
.60806 .24703 L
.60827 .24704 L
.60847 .24704 L
.60869 .24704 L
.60889 .24705 L
.60912 .24705 L
.60933 .24705 L
.60953 .24706 L
.60975 .24706 L
.60996 .24706 L
Mistroke
.61016 .24707 L
.61038 .24707 L
.61059 .24707 L
.61081 .24708 L
.61102 .24708 L
.61122 .24709 L
.61144 .24709 L
.61165 .24709 L
.61187 .2471 L
.61209 .2471 L
.61229 .24711 L
.61251 .24711 L
.61272 .24712 L
.61292 .24712 L
.61314 .24713 L
.61335 .24713 L
.61357 .24714 L
.61378 .24714 L
.61399 .24715 L
.6142 .24715 L
.61441 .24716 L
.61461 .24716 L
.61483 .24717 L
.61504 .24717 L
.61526 .24718 L
.61547 .24719 L
.61567 .24719 L
.61589 .2472 L
.6161 .2472 L
.61632 .24721 L
.61653 .24722 L
.61674 .24722 L
.61696 .24723 L
.61717 .24724 L
.61737 .24724 L
.61758 .24725 L
.61779 .24726 L
.61801 .24726 L
.61822 .24727 L
.61843 .24728 L
.61865 .24728 L
.61885 .24729 L
.61908 .2473 L
.61929 .24731 L
.6195 .24731 L
.61972 .24732 L
.61993 .24733 L
.62013 .24734 L
.62035 .24734 L
.62056 .24735 L
Mistroke
.62078 .24736 L
.62099 .24737 L
.62119 .24738 L
.62141 .24738 L
.62162 .24739 L
.62182 .2474 L
.62204 .24741 L
.62225 .24742 L
.62247 .24743 L
.62268 .24743 L
.62288 .24744 L
.6231 .24745 L
.62331 .24746 L
.62353 .24747 L
.62374 .24748 L
.62395 .24749 L
.62417 .2475 L
.62438 .24751 L
.62458 .24752 L
.6248 .24753 L
.625 .24754 L
.62523 .24755 L
.62544 .24756 L
.62564 .24756 L
.62586 .24757 L
.62607 .24758 L
.62629 .2476 L
.62651 .24761 L
.62671 .24762 L
.62693 .24763 L
.62714 .24764 L
.62735 .24765 L
.62756 .24766 L
.62777 .24767 L
.62799 .24768 L
.62821 .24769 L
.62841 .2477 L
.62863 .24771 L
.62884 .24772 L
.62904 .24773 L
.62926 .24774 L
.62947 .24775 L
.62969 .24777 L
.6299 .24778 L
.6301 .24779 L
.63032 .2478 L
.63053 .24781 L
.63075 .24782 L
.63096 .24784 L
.63117 .24785 L
Mistroke
.63139 .24786 L
.6316 .24787 L
.6318 .24788 L
.63202 .2479 L
.63223 .24791 L
.63245 .24792 L
.63266 .24793 L
.63287 .24795 L
.63308 .24796 L
.63329 .24797 L
.6335 .24798 L
.63371 .248 L
.63392 .24801 L
.63414 .24802 L
.63435 .24803 L
.63455 .24805 L
.63477 .24806 L
.63498 .24807 L
.6352 .24809 L
.63541 .2481 L
.63562 .24811 L
.63584 .24813 L
.63605 .24814 L
.63625 .24815 L
.63647 .24817 L
.63667 .24818 L
.63689 .2482 L
.63711 .24821 L
.63731 .24822 L
.63753 .24824 L
.63774 .24825 L
.63796 .24827 L
.63817 .24828 L
.63838 .2483 L
.6386 .24831 L
.63881 .24832 L
.63901 .24834 L
.63923 .24835 L
.63944 .24837 L
.63966 .24838 L
.63987 .2484 L
.64008 .24841 L
.6403 .24843 L
.64051 .24844 L
.64071 .24846 L
.64092 .24847 L
.64113 .24849 L
.64135 .2485 L
.64156 .24852 L
.64177 .24853 L
Mistroke
.64198 .24855 L
.64219 .24857 L
.64241 .24858 L
.64263 .2486 L
.64283 .24861 L
.64305 .24863 L
.64326 .24865 L
.64347 .24866 L
.64368 .24868 L
.64389 .24869 L
.64411 .24871 L
.64432 .24873 L
.64453 .24874 L
.64475 .24876 L
.64496 .24878 L
.64516 .24879 L
.64537 .24881 L
.64558 .24883 L
.6458 .24884 L
.64601 .24886 L
.64621 .24888 L
.64643 .24889 L
.64664 .24891 L
.64686 .24893 L
.64707 .24895 L
.64728 .24896 L
.6475 .24898 L
.64771 .249 L
.64791 .24902 L
.64813 .24903 L
.64833 .24905 L
.64855 .24907 L
.64877 .24909 L
.64897 .2491 L
.64919 .24912 L
.6494 .24914 L
.64962 .24916 L
.64983 .24918 L
.65004 .2492 L
.65026 .24921 L
.65047 .24923 L
.65067 .24925 L
.65089 .24927 L
.6511 .24929 L
.65132 .24931 L
.65153 .24933 L
.65174 .24934 L
.65195 .24936 L
.65216 .24938 L
.65237 .2494 L
Mistroke
.65258 .24942 L
.65279 .24944 L
.65301 .24946 L
.65322 .24948 L
.65342 .2495 L
.65364 .24952 L
.65385 .24953 L
.65407 .24955 L
.65428 .24957 L
.65449 .24959 L
.65471 .24961 L
.65492 .24963 L
.65512 .24965 L
.65534 .24967 L
.65554 .24969 L
.65576 .24971 L
.65598 .24973 L
.65618 .24975 L
.6564 .24977 L
.65661 .24979 L
.65683 .24981 L
.65705 .24984 L
.65725 .24986 L
.65747 .24988 L
.65768 .2499 L
.65789 .24992 L
.6581 .24994 L
.65831 .24996 L
.65853 .24998 L
.65873 .25 L
Mfstroke
.65873 .25 m
.65894 .25002 L
.65916 .25004 L
.65937 .25006 L
.65958 .25008 L
.65979 .25011 L
.66 .25013 L
.66022 .25015 L
.66044 .25017 L
.66064 .25019 L
.66086 .25021 L
.66107 .25024 L
.66127 .25026 L
.66149 .25028 L
.6617 .2503 L
.66192 .25032 L
.66213 .25034 L
.66233 .25037 L
.66255 .25039 L
.66276 .25041 L
.66298 .25043 L
.66319 .25046 L
.6634 .25048 L
.66362 .2505 L
.66383 .25052 L
.66403 .25054 L
.66425 .25057 L
.66446 .25059 L
.66468 .25061 L
.66489 .25064 L
.6651 .25066 L
.66531 .25068 L
.66552 .2507 L
.66573 .25073 L
.66594 .25075 L
.66615 .25077 L
.66637 .2508 L
.66658 .25082 L
.66678 .25084 L
.667 .25087 L
.66721 .25089 L
.66743 .25091 L
.66764 .25094 L
.66785 .25096 L
.66807 .25098 L
.66828 .25101 L
.66848 .25103 L
.6687 .25106 L
.6689 .25108 L
.66912 .2511 L
Mistroke
.66934 .25113 L
.66954 .25115 L
.66976 .25118 L
.66997 .2512 L
.67019 .25122 L
.67041 .25125 L
.67061 .25127 L
.67083 .2513 L
.67104 .25132 L
.67125 .25135 L
.67146 .25137 L
.67167 .2514 L
.67189 .25142 L
.6721 .25145 L
.67231 .25147 L
.67253 .2515 L
.67274 .25152 L
.67294 .25155 L
.67315 .25157 L
.67336 .2516 L
.67358 .25162 L
.67379 .25165 L
.674 .25167 L
.67422 .2517 L
.67442 .25172 L
.67465 .25175 L
.67486 .25177 L
.67507 .2518 L
.67528 .25183 L
.6755 .25185 L
.6757 .25188 L
.67591 .2519 L
.67612 .25193 L
.67634 .25196 L
.67656 .25198 L
.67676 .25201 L
.67698 .25203 L
.67719 .25206 L
.67739 .25208 L
.6776 .25211 L
.67781 .25214 L
.67803 .25216 L
.67824 .25219 L
.67845 .25222 L
.67866 .25224 L
.67887 .25227 L
.67909 .2523 L
.67931 .25232 L
.67951 .25235 L
.67973 .25238 L
Mistroke
.67994 .25241 L
.68014 .25243 L
.68036 .25246 L
.68056 .25249 L
.68079 .25251 L
.681 .25254 L
.6812 .25257 L
.68142 .2526 L
.68163 .25262 L
.68185 .25265 L
.68206 .25268 L
.68227 .25271 L
.68249 .25273 L
.6827 .25276 L
.6829 .25279 L
.68312 .25282 L
.68333 .25284 L
.68355 .25287 L
.68376 .2529 L
.68397 .25293 L
.68419 .25296 L
.6844 .25299 L
.6846 .25301 L
.68481 .25304 L
.68502 .25307 L
.68524 .2531 L
.68545 .25313 L
.68565 .25315 L
.68587 .25318 L
.68608 .25321 L
.6863 .25324 L
.68652 .25327 L
.68672 .2533 L
.68694 .25333 L
.68715 .25336 L
.68735 .25338 L
.68757 .25341 L
.68778 .25344 L
.688 .25347 L
.68821 .2535 L
.68841 .25353 L
.68863 .25356 L
.68884 .25359 L
.68906 .25362 L
.68928 .25365 L
.68949 .25368 L
.6897 .25371 L
.68992 .25374 L
.69012 .25377 L
.69034 .2538 L
Mistroke
.69054 .25383 L
.69077 .25386 L
.69098 .25389 L
.69118 .25392 L
.6914 .25395 L
.69161 .25398 L
.69181 .25401 L
.69203 .25404 L
.69224 .25407 L
.69246 .2541 L
.69267 .25413 L
.69287 .25416 L
.69309 .25419 L
.6933 .25422 L
.69352 .25425 L
.69374 .25428 L
.69394 .25431 L
.69416 .25434 L
.69437 .25437 L
.69457 .2544 L
.69479 .25443 L
.695 .25446 L
.69522 .2545 L
.69543 .25453 L
.69564 .25456 L
.69586 .25459 L
.69606 .25462 L
.69627 .25465 L
.69648 .25468 L
.69669 .25471 L
.69691 .25474 L
.69712 .25478 L
.69732 .25481 L
.69754 .25484 L
.69775 .25487 L
.69797 .2549 L
.69818 .25493 L
.69839 .25496 L
.69861 .255 L
.69882 .25503 L
.69902 .25506 L
.69924 .25509 L
.69944 .25512 L
.69966 .25516 L
.69988 .25519 L
.70008 .25522 L
.7003 .25525 L
.70051 .25528 L
.70073 .25532 L
.70094 .25535 L
Mistroke
.70115 .25538 L
.70137 .25542 L
.70158 .25545 L
.70178 .25548 L
.702 .25551 L
.70221 .25554 L
.70243 .25558 L
.70264 .25561 L
.70285 .25564 L
.70307 .25568 L
.70328 .25571 L
.70348 .25574 L
.70369 .25577 L
.7039 .25581 L
.70412 .25584 L
.70433 .25587 L
.70454 .25591 L
.70475 .25594 L
.70496 .25597 L
.70518 .25601 L
.7054 .25604 L
.7056 .25607 L
.70582 .25611 L
.70603 .25614 L
.70624 .25617 L
.70645 .25621 L
.70666 .25624 L
.70688 .25628 L
.70709 .25631 L
.7073 .25634 L
.70752 .25638 L
.70772 .25641 L
.70793 .25644 L
.70814 .25648 L
.70835 .25651 L
.70857 .25655 L
.70878 .25658 L
.70898 .25661 L
.7092 .25665 L
.70941 .25668 L
.70963 .25672 L
.70984 .25675 L
.71005 .25679 L
.71027 .25682 L
.71048 .25686 L
.71068 .25689 L
.71089 .25692 L
.7111 .25696 L
.71132 .25699 L
.71153 .25703 L
Mistroke
.71174 .25706 L
.71195 .2571 L
.71216 .25713 L
.71239 .25717 L
.7126 .25721 L
.71281 .25724 L
.71303 .25728 L
.71324 .25731 L
.71344 .25734 L
.71366 .25738 L
.71386 .25741 L
.71408 .25745 L
.7143 .25749 L
.7145 .25752 L
.71472 .25756 L
.71493 .25759 L
.71513 .25763 L
.71535 .25766 L
.71555 .2577 L
.71577 .25774 L
.71599 .25777 L
.71619 .25781 L
.71641 .25784 L
.71661 .25788 L
.71684 .25792 L
.71705 .25795 L
.71726 .25799 L
.71747 .25802 L
.71769 .25806 L
.71789 .2581 L
.7181 .25813 L
.71831 .25817 L
.71853 .25821 L
.71874 .25824 L
.71895 .25828 L
.71917 .25831 L
.71938 .25835 L
.7196 .25839 L
.71981 .25843 L
.72002 .25846 L
.72024 .2585 L
.72045 .25854 L
.72065 .25857 L
.72087 .25861 L
.72108 .25865 L
.7213 .25869 L
.72151 .25872 L
.72172 .25876 L
.72194 .2588 L
.72215 .25883 L
Mistroke
.72235 .25887 L
.72256 .25891 L
.72277 .25894 L
.72299 .25898 L
.7232 .25902 L
.72341 .25906 L
.72362 .25909 L
.72383 .25913 L
.72405 .25917 L
.72427 .25921 L
.72447 .25925 L
.72469 .25928 L
.7249 .25932 L
.72511 .25936 L
.72532 .2594 L
.72553 .25943 L
.72575 .25947 L
.72596 .25951 L
.72617 .25955 L
.72639 .25959 L
.7266 .25963 L
.7268 .25966 L
.72701 .2597 L
.72722 .25974 L
.72744 .25978 L
.72765 .25982 L
.72785 .25985 L
.72807 .25989 L
.72828 .25993 L
.7285 .25997 L
.72871 .26001 L
.72892 .26005 L
.72914 .26009 L
.72935 .26012 L
.72955 .26016 L
.72977 .2602 L
.72997 .26024 L
.73019 .26028 L
.73041 .26032 L
.73061 .26036 L
.73083 .2604 L
.73104 .26044 L
.73126 .26048 L
.73147 .26052 L
.73168 .26055 L
.7319 .26059 L
.73211 .26063 L
.73231 .26067 L
.73253 .26071 L
.73274 .26075 L
Mistroke
.73296 .26079 L
.73317 .26083 L
.73338 .26087 L
.7336 .26091 L
.73381 .26095 L
.73401 .26099 L
.73422 .26103 L
.73443 .26107 L
.73465 .26111 L
.73486 .26115 L
.73506 .26119 L
.73528 .26123 L
.73549 .26127 L
.73571 .26131 L
.73593 .26135 L
.73613 .26139 L
.73635 .26143 L
.73656 .26147 L
.73676 .26151 L
.73698 .26155 L
.73719 .26159 L
.73741 .26163 L
.73762 .26167 L
.73783 .26171 L
.73804 .26175 L
.73825 .26179 L
.73848 .26184 L
.73869 .26188 L
.7389 .26192 L
.73912 .26196 L
.73933 .262 L
.73953 .26204 L
.73975 .26208 L
.73996 .26212 L
.74018 .26216 L
.74039 .2622 L
.7406 .26224 L
.74081 .26229 L
.74102 .26233 L
.74123 .26237 L
.74144 .26241 L
.74165 .26245 L
.74187 .26249 L
.74208 .26253 L
.74229 .26257 L
.7425 .26262 L
.74271 .26266 L
.74293 .2627 L
.74315 .26274 L
.74335 .26278 L
Mistroke
.74357 .26283 L
.74378 .26287 L
.74399 .26291 L
.7442 .26295 L
.74441 .26299 L
.74463 .26304 L
.74484 .26308 L
.74505 .26312 L
.74527 .26316 L
.74548 .2632 L
.74568 .26324 L
.74589 .26329 L
.7461 .26333 L
.74632 .26337 L
.74653 .26341 L
.74674 .26345 L
.74695 .2635 L
.74716 .26354 L
.74738 .26358 L
.7476 .26363 L
.7478 .26367 L
.74802 .26371 L
.74823 .26375 L
.74843 .26379 L
.74865 .26384 L
.74886 .26388 L
.74908 .26392 L
.74929 .26397 L
.74949 .26401 L
.74971 .26405 L
.74992 .26409 L
.75014 .26414 L
.75036 .26418 L
.75056 .26423 L
.75078 .26427 L
.75099 .26431 L
.7512 .26435 L
.75141 .2644 L
.75162 .26444 L
.75184 .26449 L
.75206 .26453 L
.75226 .26457 L
.75248 .26462 L
.75269 .26466 L
.75289 .2647 L
.75311 .26475 L
.75331 .26479 L
.75353 .26483 L
.75375 .26488 L
.75395 .26492 L
Mistroke
.75417 .26496 L
.75438 .26501 L
.7546 .26505 L
.75481 .2651 L
.75502 .26514 L
.75524 .26519 L
.75545 .26523 L
.75565 .26527 L
.75587 .26532 L
.75607 .26536 L
.75629 .26541 L
.75651 .26545 L
.75671 .26549 L
.75693 .26554 L
.75714 .26558 L
.75734 .26562 L
.75756 .26567 L
.75776 .26571 L
.75798 .26576 L
.75819 .2658 L
.7584 .26585 L
.75861 .26589 L
.75882 .26594 L
.75904 .26598 L
.75926 .26603 L
.75946 .26607 L
.75968 .26612 L
.75989 .26616 L
.76009 .2662 L
.76031 .26625 L
.76052 .26629 L
.76074 .26634 L
.76095 .26639 L
.76115 .26643 L
.76137 .26648 L
.76158 .26652 L
.7618 .26657 L
.76202 .26661 L
.76222 .26666 L
.76244 .2667 L
.76265 .26675 L
.76286 .26679 L
.76307 .26684 L
.76328 .26688 L
.7635 .26693 L
.76371 .26698 L
.76392 .26702 L
.76414 .26707 L
.76435 .26711 L
.76455 .26716 L
Mistroke
.76455 .26716 L
Mfstroke
.76455 .26716 m
.76476 .2672 L
.76498 .26725 L
.76519 .2673 L
.7654 .26734 L
.76561 .26739 L
.76582 .26743 L
.76604 .26748 L
.76626 .26753 L
.76646 .26757 L
.76668 .26762 L
.76689 .26766 L
.76709 .26771 L
.76731 .26776 L
.76752 .2678 L
.76774 .26785 L
.76795 .2679 L
.76815 .26794 L
.76837 .26799 L
.76858 .26803 L
.7688 .26808 L
.76901 .26813 L
.76922 .26817 L
.76944 .26822 L
.76965 .26827 L
.76985 .26831 L
.77007 .26836 L
.77028 .26841 L
.7705 .26846 L
.77071 .2685 L
.77092 .26855 L
.77113 .2686 L
.77134 .26864 L
.77155 .26869 L
.77176 .26874 L
.77197 .26878 L
.77219 .26883 L
.7724 .26888 L
.7726 .26892 L
.77282 .26897 L
.77303 .26902 L
.77325 .26907 L
.77346 .26912 L
.77367 .26916 L
.77389 .26921 L
.7741 .26926 L
.7743 .2693 L
.77452 .26935 L
.77472 .2694 L
.77494 .26945 L
Mistroke
.77516 .2695 L
.77536 .26954 L
.77558 .26959 L
.77579 .26964 L
.77601 .26969 L
.77623 .26974 L
.77643 .26978 L
.77665 .26983 L
.77686 .26988 L
.77707 .26993 L
.77728 .26997 L
.77749 .27002 L
.77771 .27007 L
.77792 .27012 L
.77813 .27017 L
.77835 .27022 L
.77856 .27026 L
.77876 .27031 L
.77897 .27036 L
.77918 .27041 L
.7794 .27046 L
.77961 .27051 L
.77982 .27055 L
.78004 .2706 L
.78024 .27065 L
.78047 .2707 L
.78068 .27075 L
.78089 .2708 L
.7811 .27085 L
.78132 .2709 L
.78152 .27094 L
.78173 .27099 L
.78194 .27104 L
.78216 .27109 L
.78238 .27114 L
.78258 .27119 L
.7828 .27124 L
.78301 .27129 L
.78321 .27133 L
.78342 .27138 L
.78363 .27143 L
.78385 .27148 L
.78406 .27153 L
.78427 .27158 L
.78448 .27163 L
.78469 .27168 L
.78491 .27173 L
.78513 .27178 L
.78533 .27183 L
.78555 .27188 L
Mistroke
.78576 .27193 L
.78596 .27197 L
.78618 .27202 L
.78638 .27207 L
.78661 .27212 L
.78682 .27217 L
.78702 .27222 L
.78724 .27227 L
.78745 .27232 L
.78767 .27237 L
.78788 .27242 L
.78809 .27247 L
.78831 .27253 L
.78852 .27257 L
.78872 .27262 L
.78894 .27267 L
.78915 .27272 L
.78937 .27278 L
.78958 .27283 L
.78979 .27287 L
.79001 .27293 L
.79022 .27298 L
.79042 .27302 L
.79063 .27307 L
.79084 .27312 L
.79106 .27318 L
.79127 .27323 L
.79147 .27328 L
.79169 .27333 L
.7919 .27338 L
.79212 .27343 L
.79234 .27348 L
.79254 .27353 L
.79276 .27358 L
.79297 .27363 L
.79317 .27368 L
.79339 .27373 L
.7936 .27378 L
.79382 .27384 L
.79403 .27389 L
.79423 .27394 L
.79445 .27399 L
.79466 .27404 L
.79488 .27409 L
.7951 .27414 L
.79531 .27419 L
.79552 .27425 L
.79574 .2743 L
.79594 .27435 L
.79616 .2744 L
Mistroke
.79636 .27445 L
.79659 .2745 L
.7968 .27455 L
.797 .2746 L
.79722 .27466 L
.79743 .27471 L
.79763 .27476 L
.79785 .27481 L
.79806 .27486 L
.79828 .27491 L
.79849 .27497 L
.79869 .27502 L
.79891 .27507 L
.79912 .27512 L
.79934 .27517 L
.79956 .27523 L
.79976 .27528 L
.79998 .27533 L
.80019 .27538 L
.80039 .27543 L
.80061 .27548 L
.80082 .27554 L
.80104 .27559 L
.80125 .27564 L
.80146 .27569 L
.80168 .27575 L
.80189 .2758 L
.80209 .27585 L
.8023 .2759 L
.80251 .27595 L
.80273 .27601 L
.80294 .27606 L
.80314 .27611 L
.80336 .27616 L
.80357 .27621 L
.80379 .27627 L
.804 .27632 L
.80421 .27637 L
.80443 .27643 L
.80464 .27648 L
.80484 .27653 L
.80506 .27658 L
.80526 .27663 L
.80548 .27669 L
.8057 .27674 L
.8059 .27679 L
.80612 .27685 L
.80633 .2769 L
.80655 .27696 L
.80676 .27701 L
Mistroke
.80697 .27706 L
.80719 .27712 L
.8074 .27717 L
.8076 .27722 L
.80782 .27727 L
.80803 .27733 L
.80825 .27738 L
.80846 .27744 L
.80867 .27749 L
.80889 .27754 L
.8091 .27759 L
.8093 .27765 L
.80951 .2777 L
.80972 .27775 L
.80994 .27781 L
.81015 .27786 L
.81036 .27791 L
.81057 .27797 L
.81078 .27802 L
.811 .27808 L
.81122 .27813 L
.81142 .27818 L
.81164 .27824 L
.81185 .27829 L
.81206 .27834 L
.81227 .2784 L
.81248 .27845 L
.8127 .27851 L
.81291 .27856 L
.81312 .27861 L
.81334 .27867 L
.81355 .27872 L
.81375 .27877 L
.81396 .27883 L
.81417 .27888 L
.81439 .27894 L
.8146 .27899 L
.8148 .27904 L
.81502 .2791 L
.81523 .27915 L
.81545 .27921 L
.81566 .27926 L
.81587 .27932 L
.81609 .27937 L
.8163 .27943 L
.8165 .27948 L
.81671 .27953 L
.81692 .27959 L
.81714 .27964 L
.81735 .2797 L
Mistroke
.81756 .27975 L
.81777 .27981 L
.81798 .27986 L
.81821 .27992 L
.81842 .27998 L
.81863 .28003 L
.81885 .28009 L
.81906 .28014 L
.81926 .28019 L
.81948 .28025 L
.81968 .2803 L
.8199 .28036 L
.82012 .28042 L
.82032 .28047 L
.82054 .28053 L
.82075 .28058 L
.82095 .28063 L
.82117 .28069 L
.82137 .28074 L
.82159 .2808 L
.82181 .28086 L
.82201 .28091 L
.82223 .28097 L
.82243 .28102 L
.82266 .28108 L
.82287 .28113 L
.82308 .28119 L
.82329 .28124 L
.82351 .2813 L
.82371 .28135 L
.82392 .28141 L
.82413 .28146 L
.82435 .28152 L
.82456 .28158 L
.82477 .28163 L
.82499 .28169 L
.8252 .28174 L
.82542 .2818 L
.82563 .28186 L
.82584 .28191 L
.82606 .28197 L
.82627 .28203 L
.82647 .28208 L
.82669 .28214 L
.8269 .28219 L
.82712 .28225 L
.82733 .28231 L
.82754 .28236 L
.82776 .28242 L
.82797 .28248 L
Mistroke
.82817 .28253 L
.82838 .28259 L
.82859 .28264 L
.82881 .2827 L
.82902 .28276 L
.82923 .28281 L
.82944 .28287 L
.82965 .28293 L
.82987 .28299 L
.83009 .28304 L
.83029 .2831 L
.83051 .28316 L
.83072 .28321 L
.83093 .28327 L
.83114 .28333 L
.83135 .28338 L
.83157 .28344 L
.83178 .2835 L
.83199 .28355 L
.83221 .28361 L
.83242 .28367 L
.83262 .28372 L
.83283 .28378 L
.83304 .28383 L
.83326 .28389 L
.83347 .28395 L
.83367 .28401 L
.83389 .28406 L
.8341 .28412 L
.83432 .28418 L
.83453 .28424 L
.83474 .28429 L
.83496 .28435 L
.83517 .28441 L
.83537 .28446 L
.83559 .28452 L
.83579 .28458 L
.83601 .28464 L
.83623 .2847 L
.83643 .28475 L
.83665 .28481 L
.83686 .28487 L
.83708 .28493 L
.83729 .28499 L
.8375 .28504 L
.83772 .2851 L
.83793 .28516 L
.83813 .28521 L
.83835 .28527 L
.83856 .28533 L
Mistroke
.83878 .28539 L
.83899 .28545 L
.8392 .2855 L
.83942 .28556 L
.83963 .28562 L
.83983 .28568 L
.84004 .28574 L
.84025 .28579 L
.84047 .28585 L
.84068 .28591 L
.84089 .28597 L
.8411 .28603 L
.84131 .28608 L
.84153 .28615 L
.84175 .2862 L
.84195 .28626 L
.84217 .28632 L
.84238 .28638 L
.84258 .28643 L
.8428 .28649 L
.84301 .28655 L
.84323 .28661 L
.84344 .28667 L
.84365 .28673 L
.84386 .28679 L
.84407 .28685 L
.8443 .28691 L
.84451 .28697 L
.84472 .28702 L
.84494 .28709 L
.84515 .28714 L
.84535 .2872 L
.84557 .28726 L
.84578 .28732 L
.846 .28738 L
.84621 .28744 L
.84642 .2875 L
.84663 .28756 L
.84684 .28762 L
.84705 .28767 L
.84726 .28773 L
.84747 .28779 L
.84769 .28785 L
.8479 .28791 L
.84811 .28797 L
.84832 .28803 L
.84853 .28809 L
.84875 .28815 L
.84897 .28821 L
.84917 .28827 L
Mistroke
.84939 .28833 L
.8496 .28839 L
.84981 .28844 L
.85002 .2885 L
.85023 .28856 L
.85045 .28862 L
.85066 .28868 L
.85087 .28874 L
.85109 .2888 L
.8513 .28886 L
.8515 .28892 L
.85171 .28898 L
.85192 .28904 L
.85214 .2891 L
.85235 .28916 L
.85256 .28922 L
.85277 .28928 L
.85298 .28934 L
.8532 .2894 L
.85342 .28946 L
.85362 .28952 L
.85384 .28958 L
.85405 .28964 L
.85425 .2897 L
.85447 .28976 L
.85468 .28982 L
.8549 .28988 L
.85511 .28994 L
.85531 .29 L
.85553 .29006 L
.85574 .29012 L
.85596 .29018 L
.85618 .29024 L
.85638 .2903 L
.8566 .29037 L
.85681 .29043 L
.85702 .29048 L
.85723 .29055 L
.85744 .2906 L
.85766 .29067 L
.85788 .29073 L
.85808 .29079 L
.8583 .29085 L
.85851 .29091 L
.85871 .29097 L
.85893 .29103 L
.85913 .29109 L
.85935 .29115 L
.85957 .29121 L
.85977 .29127 L
Mistroke
.85999 .29133 L
.8602 .29139 L
.86042 .29146 L
.86063 .29152 L
.86084 .29158 L
.86106 .29164 L
.86127 .2917 L
.86147 .29176 L
.86169 .29182 L
.86189 .29188 L
.86211 .29195 L
.86233 .29201 L
.86253 .29207 L
.86275 .29213 L
.86296 .29219 L
.86316 .29225 L
.86338 .29231 L
.86358 .29237 L
.8638 .29243 L
.86401 .2925 L
.86422 .29255 L
.86443 .29262 L
.86464 .29268 L
.86486 .29274 L
.86508 .2928 L
.86528 .29286 L
.8655 .29293 L
.86571 .29299 L
.86591 .29305 L
.86613 .29311 L
.86634 .29317 L
.86656 .29323 L
.86677 .2933 L
.86697 .29336 L
.86719 .29342 L
.8674 .29348 L
.86762 .29355 L
.86784 .29361 L
.86804 .29367 L
.86826 .29373 L
.86847 .29379 L
.86868 .29385 L
.86889 .29392 L
.8691 .29398 L
.86932 .29404 L
.86953 .2941 L
.86974 .29416 L
.86996 .29423 L
.87017 .29429 L
.87037 .29435 L
Mistroke
.87037 .29435 L
Mfstroke
.87037 .29435 m
.87058 .29441 L
.8708 .29448 L
.87101 .29454 L
.87122 .2946 L
.87143 .29466 L
.87164 .29472 L
.87186 .29479 L
.87208 .29485 L
.87228 .29491 L
.8725 .29498 L
.87271 .29504 L
.87291 .2951 L
.87313 .29516 L
.87334 .29522 L
.87356 .29529 L
.87377 .29535 L
.87397 .29541 L
.87419 .29548 L
.8744 .29554 L
.87462 .2956 L
.87483 .29567 L
.87504 .29573 L
.87526 .29579 L
.87547 .29586 L
.87567 .29592 L
.87589 .29598 L
.8761 .29604 L
.87632 .29611 L
.87653 .29617 L
.87674 .29623 L
.87695 .2963 L
.87716 .29636 L
.87737 .29642 L
.87758 .29649 L
.87779 .29655 L
.87801 .29661 L
.87822 .29668 L
.87842 .29674 L
.87864 .2968 L
.87885 .29686 L
.87907 .29693 L
.87928 .29699 L
.87949 .29706 L
.87971 .29712 L
.87992 .29718 L
.88012 .29724 L
.88034 .29731 L
.88054 .29737 L
.88076 .29744 L
Mistroke
.88098 .2975 L
.88118 .29756 L
.8814 .29763 L
.88161 .29769 L
.88183 .29776 L
.88205 .29782 L
.88225 .29789 L
.88247 .29795 L
.88268 .29801 L
.88289 .29808 L
.8831 .29814 L
.88331 .2982 L
.88353 .29827 L
.88374 .29834 L
.88395 .2984 L
.88417 .29846 L
.88438 .29853 L
.88458 .29859 L
.8848 .29865 L
.885 .29872 L
.88522 .29878 L
.88543 .29885 L
.88564 .29891 L
.88586 .29897 L
.88606 .29904 L
.88629 .29911 L
.8865 .29917 L
.88671 .29923 L
.88692 .2993 L
.88714 .29936 L
.88734 .29943 L
.88755 .29949 L
.88776 .29955 L
.88798 .29962 L
.8882 .29969 L
.8884 .29975 L
.88862 .29981 L
.88883 .29988 L
.88903 .29994 L
.88924 .30001 L
.88945 .30007 L
.88967 .30014 L
.88988 .3002 L
.89009 .30026 L
.8903 .30033 L
.89051 .30039 L
.89073 .30046 L
.89095 .30053 L
.89115 .30059 L
.89137 .30066 L
Mistroke
.89158 .30072 L
.89178 .30078 L
.892 .30085 L
.8922 .30091 L
.89243 .30098 L
.89264 .30105 L
.89284 .30111 L
.89306 .30118 L
.89327 .30124 L
.89349 .30131 L
.8937 .30137 L
.89391 .30144 L
.89413 .30151 L
.89434 .30157 L
.89454 .30163 L
.89476 .3017 L
.89497 .30176 L
.89519 .30183 L
.8954 .3019 L
.89561 .30196 L
.89583 .30203 L
.89604 .30209 L
.89624 .30216 L
.89645 .30222 L
.89666 .30229 L
.89688 .30235 L
.89709 .30242 L
.89729 .30248 L
.89751 .30255 L
.89772 .30262 L
.89794 .30268 L
.89816 .30275 L
.89836 .30281 L
.89858 .30288 L
.89879 .30295 L
.89899 .30301 L
.89921 .30308 L
.89942 .30314 L
.89964 .30321 L
.89985 .30328 L
.90005 .30334 L
.90027 .30341 L
.90048 .30347 L
.9007 .30354 L
.90092 .30361 L
.90113 .30368 L
.90135 .30374 L
.90156 .30381 L
.90176 .30387 L
.90198 .30394 L
Mistroke
.90218 .30401 L
.90241 .30408 L
.90262 .30414 L
.90282 .30421 L
.90304 .30428 L
.90325 .30434 L
.90346 .30441 L
.90367 .30447 L
.90388 .30454 L
.9041 .30461 L
.90431 .30467 L
.90451 .30474 L
.90473 .30481 L
.90494 .30487 L
.90516 .30494 L
.90538 .30501 L
.90558 .30507 L
.9058 .30514 L
.90601 .30521 L
.90622 .30527 L
.90643 .30534 L
.90664 .30541 L
.90686 .30548 L
.90707 .30554 L
.90728 .30561 L
.9075 .30568 L
.90771 .30574 L
.90791 .30581 L
.90812 .30588 L
.90833 .30594 L
.90855 .30601 L
.90876 .30608 L
.90896 .30614 L
.90918 .30621 L
.90939 .30628 L
.90961 .30635 L
.90982 .30641 L
.91003 .30648 L
.91025 .30655 L
.91046 .30662 L
.91066 .30668 L
.91088 .30675 L
.91108 .30681 L
.9113 .30689 L
.91152 .30695 L
.91172 .30702 L
.91194 .30709 L
.91215 .30715 L
.91237 .30722 L
.91258 .30729 L
Mistroke
.91279 .30736 L
.91301 .30743 L
.91322 .3075 L
.91342 .30756 L
.91364 .30763 L
.91385 .3077 L
.91407 .30777 L
.91428 .30784 L
.91449 .3079 L
.91471 .30797 L
.91492 .30804 L
.91512 .3081 L
.91533 .30817 L
.91554 .30824 L
.91576 .30831 L
.91597 .30838 L
.91618 .30844 L
.91639 .30851 L
.9166 .30858 L
.91682 .30865 L
.91704 .30872 L
.91724 .30879 L
.91746 .30886 L
.91767 .30892 L
.91788 .30899 L
.91809 .30906 L
.9183 .30912 L
.91852 .3092 L
.91873 .30926 L
.91894 .30933 L
.91916 .3094 L
.91937 .30947 L
.91957 .30953 L
.91978 .3096 L
.91999 .30967 L
.92021 .30974 L
.92042 .30981 L
.92062 .30987 L
.92084 .30994 L
.92105 .31001 L
.92127 .31008 L
.92148 .31015 L
.92169 .31022 L
.92191 .31029 L
.92212 .31036 L
.92232 .31042 L
.92253 .31049 L
.92274 .31056 L
.92296 .31063 L
.92317 .3107 L
Mistroke
.92338 .31077 L
.9236 .31084 L
.9238 .31091 L
.92403 .31098 L
.92424 .31105 L
.92445 .31112 L
.92467 .31119 L
.92488 .31126 L
.92508 .31132 L
.9253 .31139 L
.9255 .31146 L
.92572 .31153 L
.92594 .3116 L
.92614 .31167 L
.92636 .31174 L
.92657 .31181 L
.92677 .31187 L
.92699 .31194 L
.92719 .31201 L
.92741 .31208 L
.92763 .31215 L
.92783 .31222 L
.92805 .31229 L
.92826 .31236 L
.92848 .31243 L
.92869 .3125 L
.9289 .31257 L
.92911 .31264 L
.92933 .31271 L
.92953 .31278 L
.92974 .31285 L
.92995 .31292 L
.93017 .31299 L
.93038 .31306 L
.93059 .31312 L
.93081 .3132 L
.93102 .31327 L
.93124 .31334 L
.93145 .31341 L
.93166 .31348 L
.93188 .31355 L
.93209 .31362 L
.93229 .31369 L
.93251 .31376 L
.93272 .31383 L
.93294 .3139 L
.93315 .31397 L
.93336 .31404 L
.93358 .31411 L
.93379 .31418 L
Mistroke
.93399 .31425 L
.9342 .31432 L
.93441 .31439 L
.93463 .31446 L
.93484 .31453 L
.93505 .3146 L
.93526 .31467 L
.93547 .31474 L
.93569 .31481 L
.93591 .31488 L
.93611 .31495 L
.93633 .31502 L
.93654 .31509 L
.93675 .31516 L
.93696 .31523 L
.93717 .3153 L
.93739 .31537 L
.9376 .31545 L
.93781 .31551 L
.93803 .31559 L
.93824 .31566 L
.93844 .31572 L
.93865 .31579 L
.93886 .31586 L
.93908 .31594 L
.93929 .31601 L
.93949 .31607 L
.93971 .31615 L
.93992 .31622 L
.94014 .31629 L
.94035 .31636 L
.94056 .31643 L
.94078 .3165 L
.94099 .31657 L
.94119 .31664 L
.94141 .31671 L
.94161 .31678 L
.94183 .31686 L
.94205 .31693 L
.94225 .317 L
.94247 .31707 L
.94268 .31714 L
.9429 .31721 L
.94311 .31729 L
.94332 .31736 L
.94354 .31743 L
.94375 .3175 L
.94395 .31757 L
.94417 .31764 L
.94438 .31771 L
Mistroke
.9446 .31778 L
.94481 .31786 L
.94502 .31793 L
.94524 .318 L
.94545 .31807 L
.94565 .31814 L
.94586 .31821 L
.94607 .31828 L
.94629 .31835 L
.9465 .31843 L
.94671 .31849 L
.94692 .31857 L
.94713 .31864 L
.94735 .31871 L
.94757 .31879 L
.94777 .31885 L
.94799 .31893 L
.9482 .319 L
.9484 .31907 L
.94862 .31914 L
.94883 .31921 L
.94905 .31929 L
.94926 .31936 L
.94947 .31943 L
.94968 .3195 L
.94989 .31957 L
.95012 .31965 L
.95033 .31972 L
.95054 .31979 L
.95076 .31987 L
.95097 .31994 L
.95117 .32001 L
.95139 .32008 L
.9516 .32015 L
.95182 .32023 L
.95203 .3203 L
.95224 .32037 L
.95245 .32044 L
.95266 .32051 L
.95287 .32058 L
.95308 .32066 L
.95329 .32073 L
.95351 .3208 L
.95372 .32087 L
.95393 .32094 L
.95414 .32102 L
.95435 .32109 L
.95457 .32117 L
.95479 .32124 L
.95499 .32131 L
Mistroke
.95521 .32138 L
.95542 .32146 L
.95563 .32153 L
.95584 .3216 L
.95605 .32167 L
.95627 .32175 L
.95648 .32182 L
.95669 .32189 L
.95691 .32196 L
.95712 .32204 L
.95732 .3221 L
.95753 .32218 L
.95774 .32225 L
.95796 .32232 L
.95817 .3224 L
.95838 .32247 L
.95859 .32254 L
.9588 .32261 L
.95902 .32269 L
.95924 .32276 L
.95944 .32283 L
.95966 .32291 L
.95987 .32298 L
.96007 .32305 L
.96029 .32313 L
.9605 .3232 L
.96072 .32327 L
.96093 .32335 L
.96113 .32342 L
.96135 .32349 L
.96156 .32356 L
.96178 .32364 L
.962 .32371 L
.9622 .32379 L
.96242 .32386 L
.96263 .32393 L
.96284 .324 L
.96305 .32408 L
.96326 .32415 L
.96348 .32423 L
.9637 .3243 L
.9639 .32437 L
.96412 .32445 L
.96433 .32452 L
.96453 .32459 L
.96475 .32467 L
.96495 .32474 L
.96517 .32481 L
.96539 .32489 L
.96559 .32496 L
Mistroke
.96581 .32503 L
.96602 .32511 L
.96624 .32518 L
.96645 .32526 L
.96666 .32533 L
.96688 .3254 L
.96709 .32548 L
.96729 .32555 L
.96751 .32562 L
.96771 .3257 L
.96793 .32577 L
.96815 .32585 L
.96835 .32592 L
.96857 .32599 L
.96878 .32607 L
.96898 .32614 L
.9692 .32621 L
.9694 .32628 L
.96962 .32636 L
.96983 .32644 L
.97004 .32651 L
.97025 .32658 L
.97046 .32665 L
.97068 .32673 L
.9709 .32681 L
.9711 .32688 L
.97132 .32695 L
.97153 .32703 L
.97173 .3271 L
.97195 .32717 L
.97216 .32725 L
.97238 .32732 L
.97259 .3274 L
.97279 .32747 L
.97301 .32755 L
.97322 .32762 L
.97344 .3277 L
.97366 .32777 L
.97386 .32785 L
.97408 .32792 L
.97429 .328 L
.9745 .32807 L
.97471 .32814 L
.97492 .32822 L
.97514 .3283 L
.97535 .32837 L
.97556 .32844 L
.97578 .32852 L
.97599 .32859 L
.97619 .32866 L
Mistroke
.97619 .32866 L
Mfstroke
0 0 1 r
.12963 .01671 m
.12984 .01671 L
.13006 .01671 L
.13027 .01671 L
.13048 .01671 L
.13069 .01671 L
.1309 .01671 L
.13112 .01671 L
.13134 .01671 L
.13154 .01671 L
.13176 .01671 L
.13197 .01671 L
.13217 .01671 L
.13239 .01671 L
.13259 .01671 L
.13281 .01671 L
.13303 .01671 L
.13323 .01671 L
.13345 .01671 L
.13366 .01671 L
.13388 .01671 L
.13409 .01671 L
.1343 .01671 L
.13452 .01671 L
.13473 .01671 L
.13493 .01671 L
.13515 .01671 L
.13536 .01671 L
.13558 .01671 L
.13579 .01671 L
.136 .01671 L
.13621 .01671 L
.13642 .01671 L
.13663 .01671 L
.13684 .01671 L
.13705 .01671 L
.13727 .01671 L
.13748 .01671 L
.13768 .01671 L
.1379 .01671 L
.13811 .01671 L
.13833 .01671 L
.13854 .01671 L
.13875 .01671 L
.13897 .01671 L
.13918 .01671 L
.13938 .01671 L
.1396 .01671 L
.1398 .01671 L
.14002 .01671 L
Mistroke
.14024 .01671 L
.14044 .01671 L
.14066 .01671 L
.14087 .01671 L
.14109 .01671 L
.1413 .01671 L
.14151 .01671 L
.14173 .01671 L
.14194 .01671 L
.14214 .01671 L
.14236 .01671 L
.14257 .01671 L
.14279 .01671 L
.143 .01671 L
.14321 .01671 L
.14343 .01671 L
.14364 .01671 L
.14384 .01671 L
.14405 .01671 L
.14426 .01671 L
.14448 .01671 L
.14469 .01671 L
.1449 .01671 L
.14511 .01671 L
.14532 .01671 L
.14555 .01671 L
.14576 .01671 L
.14597 .01671 L
.14618 .01671 L
.14639 .01671 L
.1466 .01671 L
.14681 .01671 L
.14702 .01671 L
.14724 .01671 L
.14745 .01671 L
.14766 .01671 L
.14788 .01671 L
.14809 .01671 L
.14829 .01671 L
.1485 .01671 L
.14871 .01671 L
.14893 .01671 L
.14914 .01671 L
.14934 .01671 L
.14956 .01671 L
.14977 .01671 L
.14999 .01671 L
.1502 .01671 L
.15041 .01671 L
.15063 .01671 L
Mistroke
.15084 .01671 L
.15104 .01671 L
.15126 .01671 L
.15146 .01671 L
.15168 .01671 L
.1519 .01671 L
.1521 .01671 L
.15232 .01671 L
.15253 .01671 L
.15275 .01671 L
.15296 .01671 L
.15317 .01671 L
.15339 .01671 L
.1536 .01671 L
.1538 .01671 L
.15402 .01671 L
.15423 .01671 L
.15445 .01671 L
.15466 .01671 L
.15487 .01671 L
.15508 .01671 L
.15529 .01671 L
.1555 .01671 L
.15571 .01671 L
.15592 .01671 L
.15614 .01671 L
.15635 .01671 L
.15655 .01671 L
.15677 .01671 L
.15698 .01671 L
.1572 .01671 L
.15742 .01671 L
.15762 .01671 L
.15784 .01671 L
.15805 .01671 L
.15825 .01671 L
.15847 .01671 L
.15868 .01671 L
.1589 .01671 L
.15911 .01671 L
.15931 .01671 L
.15953 .01671 L
.15974 .01671 L
.15996 .01671 L
.16018 .01671 L
.16038 .01671 L
.1606 .01671 L
.16082 .01671 L
.16102 .01671 L
.16124 .01671 L
Mistroke
.16144 .01671 L
.16166 .01671 L
.16188 .01671 L
.16208 .01671 L
.1623 .01671 L
.16251 .01671 L
.16271 .01671 L
.16293 .01671 L
.16314 .01671 L
.16336 .01671 L
.16357 .01671 L
.16377 .01671 L
.16399 .01671 L
.1642 .01671 L
.16442 .01671 L
.16464 .01671 L
.16484 .01671 L
.16506 .01671 L
.16527 .01671 L
.16547 .01671 L
.16569 .01671 L
.1659 .01671 L
.16612 .01671 L
.16633 .01671 L
.16654 .01671 L
.16675 .01671 L
.16696 .01671 L
.16717 .01671 L
.16738 .01671 L
.16759 .01671 L
.16781 .01671 L
.16802 .01671 L
.16822 .01671 L
.16844 .01671 L
.16865 .01671 L
.16887 .01671 L
.16908 .01671 L
.16929 .01671 L
.16951 .01671 L
.16972 .01671 L
.16992 .01671 L
.17014 .01671 L
.17034 .01671 L
.17056 .01671 L
.17078 .01671 L
.17098 .01671 L
.1712 .01671 L
.17141 .01671 L
.17163 .01671 L
.17184 .01671 L
Mistroke
.17205 .01671 L
.17227 .01671 L
.17248 .01671 L
.17268 .01671 L
.1729 .01671 L
.17311 .01671 L
.17333 .01671 L
.17354 .01671 L
.17375 .01671 L
.17397 .01671 L
.17418 .01671 L
.17438 .01671 L
.17459 .01671 L
.1748 .01671 L
.17502 .01671 L
.17523 .01671 L
.17544 .01671 L
.17565 .01671 L
.17586 .01671 L
.17608 .01671 L
.1763 .01671 L
.1765 .01671 L
.17672 .01671 L
.17693 .01671 L
.17714 .01671 L
.17735 .01671 L
.17756 .01671 L
.17778 .01671 L
.17799 .01671 L
.1782 .01671 L
.17841 .01671 L
.17862 .01671 L
.17883 .01671 L
.17904 .01671 L
.17925 .01671 L
.17947 .01671 L
.17968 .01671 L
.17988 .01671 L
.1801 .01671 L
.18031 .01671 L
.18053 .01671 L
.18074 .01671 L
.18095 .01671 L
.18117 .01671 L
.18138 .01671 L
.18158 .01671 L
.18179 .01671 L
.182 .01671 L
.18222 .01671 L
.18243 .01671 L
Mistroke
.18264 .01671 L
.18285 .01671 L
.18306 .01671 L
.18329 .01671 L
.1835 .01671 L
.18371 .01671 L
.18392 .01671 L
.18414 .01671 L
.18434 .01671 L
.18456 .01671 L
.18476 .01671 L
.18498 .01671 L
.1852 .01671 L
.1854 .01671 L
.18562 .01671 L
.18583 .01671 L
.18603 .01671 L
.18625 .01671 L
.18645 .01671 L
.18667 .01671 L
.18688 .01671 L
.18709 .01671 L
.18731 .01671 L
.18751 .01671 L
.18774 .01671 L
.18795 .01671 L
.18816 .01671 L
.18837 .01671 L
.18858 .01671 L
.18879 .01671 L
.189 .01671 L
.18921 .01671 L
.18943 .01671 L
.18964 .01671 L
.18985 .01671 L
.19007 .01671 L
.19027 .01671 L
.1905 .01671 L
.19071 .01671 L
.19092 .01671 L
.19114 .01671 L
.19135 .01671 L
.19155 .01671 L
.19177 .01671 L
.19198 .01671 L
.1922 .01671 L
.19241 .01671 L
.19262 .01671 L
.19283 .01671 L
.19304 .01671 L
Mistroke
.19325 .01671 L
.19346 .01671 L
.19367 .01671 L
.19389 .01671 L
.1941 .01671 L
.19431 .01671 L
.19452 .01671 L
.19473 .01671 L
.19495 .01671 L
.19517 .01671 L
.19537 .01671 L
.19559 .01671 L
.1958 .01671 L
.19601 .01671 L
.19622 .01671 L
.19643 .01671 L
.19665 .01671 L
.19686 .01671 L
.19707 .01671 L
.19729 .01671 L
.1975 .01671 L
.1977 .01671 L
.19791 .01671 L
.19812 .01671 L
.19834 .01671 L
.19855 .01671 L
.19875 .01671 L
.19897 .01671 L
.19918 .01671 L
.1994 .01671 L
.19961 .01671 L
.19982 .01671 L
.20004 .01671 L
.20025 .01671 L
.20045 .01671 L
.20067 .01671 L
.20087 .01671 L
.20109 .01671 L
.20131 .01671 L
.20151 .01671 L
.20173 .01671 L
.20194 .01671 L
.20216 .01671 L
.20237 .01671 L
.20258 .01671 L
.2028 .01671 L
.20301 .01671 L
.20321 .01671 L
.20343 .01671 L
.20364 .01671 L
Mistroke
.20386 .01671 L
.20407 .01671 L
.20428 .01671 L
.20449 .01671 L
.2047 .01671 L
.20491 .01671 L
.20512 .01671 L
.20533 .01671 L
.20555 .01671 L
.20576 .01671 L
.20596 .01671 L
.20618 .01671 L
.20639 .01671 L
.20661 .01671 L
.20683 .01671 L
.20703 .01671 L
.20725 .01671 L
.20746 .01671 L
.20766 .01671 L
.20788 .01671 L
.20809 .01671 L
.20831 .01671 L
.20852 .01671 L
.20872 .01671 L
.20894 .01671 L
.20915 .01671 L
.20937 .01671 L
.20959 .01671 L
.2098 .01671 L
.21002 .01671 L
.21023 .01671 L
.21043 .01671 L
.21065 .01671 L
.21085 .01671 L
.21108 .01671 L
.21129 .01671 L
.21149 .01671 L
.21171 .01671 L
.21192 .01671 L
.21213 .01671 L
.21234 .01671 L
.21255 .01671 L
.21277 .01671 L
.21298 .01671 L
.21318 .01671 L
.2134 .01671 L
.21361 .01671 L
.21383 .01671 L
.21405 .01671 L
.21425 .01671 L
Mistroke
.21447 .01671 L
.21468 .01671 L
.21489 .01671 L
.2151 .01671 L
.21531 .01671 L
.21553 .01671 L
.21574 .01671 L
.21595 .01671 L
.21617 .01671 L
.21638 .01671 L
.21658 .01671 L
.21679 .01671 L
.217 .01671 L
.21722 .01671 L
.21743 .01671 L
.21763 .01671 L
.21785 .01671 L
.21806 .01671 L
.21828 .01671 L
.2185 .01671 L
.2187 .01671 L
.21892 .01671 L
.21913 .01671 L
.21933 .01671 L
.21955 .01671 L
.21976 .01671 L
.21998 .01671 L
.22019 .01671 L
.22039 .01671 L
.22061 .01671 L
.22082 .01671 L
.22104 .01671 L
.22126 .01671 L
.22146 .01671 L
.22168 .01671 L
.22189 .01671 L
.2221 .01671 L
.22231 .01671 L
.22252 .01671 L
.22274 .01671 L
.22296 .01671 L
.22316 .01671 L
.22338 .01671 L
.22359 .01671 L
.22379 .01671 L
.22401 .01671 L
.22421 .01671 L
.22443 .01671 L
.22465 .01671 L
.22485 .01671 L
Mistroke
.22507 .01671 L
.22528 .01671 L
.2255 .01671 L
.22571 .01671 L
.22592 .01671 L
.22614 .01671 L
.22635 .01671 L
.22655 .01671 L
.22677 .01671 L
.22697 .01671 L
.22719 .01671 L
.22741 .01671 L
.22761 .01671 L
.22783 .01671 L
.22804 .01671 L
.22824 .01671 L
.22845 .01671 L
.22866 .01671 L
.22888 .01671 L
.22909 .01671 L
.2293 .01671 L
.22951 .01671 L
.22972 .01671 L
.22994 .01671 L
.23016 .01671 L
.23036 .01671 L
.23058 .01671 L
.23079 .01671 L
.23099 .01671 L
.23121 .01671 L
.23142 .01671 L
.23164 .01671 L
.23185 .01671 L
.23205 .01671 L
.23227 .01671 L
.23248 .01671 L
.2327 .01671 L
.23292 .01671 L
.23312 .01671 L
.23334 .01671 L
.23355 .01671 L
.23375 .01671 L
.23397 .01671 L
.23418 .01671 L
.2344 .01671 L
.23461 .01671 L
.23482 .01671 L
.23504 .01671 L
.23525 .01671 L
.23545 .01671 L
Mistroke
.23545 .01671 L
Mfstroke
.23545 .09448 m
.23566 .09448 L
.23588 .09448 L
.23609 .09448 L
.2363 .09448 L
.23651 .09448 L
.23672 .09448 L
.23694 .09448 L
.23716 .09448 L
.23736 .09448 L
.23758 .09448 L
.23779 .09448 L
.23799 .09448 L
.23821 .09448 L
.23841 .09448 L
.23863 .09448 L
.23885 .09448 L
.23905 .09448 L
.23927 .09448 L
.23948 .09448 L
.2397 .09448 L
.23991 .09448 L
.24012 .09448 L
.24034 .09448 L
.24055 .09448 L
.24075 .09448 L
.24097 .09448 L
.24118 .09448 L
.2414 .09448 L
.24161 .09448 L
.24182 .09448 L
.24203 .09448 L
.24224 .09448 L
.24245 .09448 L
.24266 .09448 L
.24287 .09448 L
.24309 .09448 L
.2433 .09448 L
.2435 .09448 L
.24372 .09448 L
.24393 .09448 L
.24415 .09448 L
.24436 .09448 L
.24457 .09448 L
.24479 .09448 L
.245 .09448 L
.2452 .09448 L
.24542 .09448 L
.24562 .09448 L
.24584 .09448 L
Mistroke
.24606 .09448 L
.24626 .09448 L
.24648 .09448 L
.24669 .09448 L
.24691 .09448 L
.24712 .09448 L
.24733 .09448 L
.24755 .09448 L
.24776 .09448 L
.24796 .09448 L
.24818 .09448 L
.24839 .09448 L
.24861 .09448 L
.24882 .09448 L
.24903 .09448 L
.24925 .09448 L
.24946 .09448 L
.24966 .09448 L
.24987 .09448 L
.25008 .09448 L
.2503 .09448 L
.25051 .09448 L
.25072 .09448 L
.25093 .09448 L
.25114 .09448 L
.25137 .09448 L
.25158 .09448 L
.25179 .09448 L
.252 .09448 L
.25222 .09448 L
.25242 .09448 L
.25263 .09448 L
.25284 .09448 L
.25306 .09448 L
.25328 .09448 L
.25348 .09448 L
.2537 .09448 L
.25391 .09448 L
.25411 .09448 L
.25432 .09448 L
.25453 .09448 L
.25475 .09448 L
.25496 .09448 L
.25516 .09448 L
.25538 .09448 L
.25559 .09448 L
.25581 .09448 L
.25602 .09448 L
.25623 .09448 L
.25645 .09448 L
Mistroke
.25666 .09448 L
.25686 .09448 L
.25708 .09448 L
.25728 .09448 L
.2575 .09448 L
.25772 .09448 L
.25792 .09448 L
.25814 .09448 L
.25835 .09448 L
.25857 .09448 L
.25878 .09448 L
.25899 .09448 L
.25921 .09448 L
.25942 .09448 L
.25962 .09448 L
.25984 .09448 L
.26005 .09448 L
.26027 .09448 L
.26048 .09448 L
.26069 .09448 L
.2609 .09448 L
.26111 .09448 L
.26132 .09448 L
.26153 .09448 L
.26174 .09448 L
.26196 .09448 L
.26217 .09448 L
.26237 .09448 L
.26259 .09448 L
.2628 .09448 L
.26302 .09448 L
.26324 .09448 L
.26344 .09448 L
.26366 .09448 L
.26387 .09448 L
.26407 .09448 L
.26429 .09448 L
.2645 .09448 L
.26472 .09448 L
.26493 .09448 L
.26513 .09448 L
.26535 .09448 L
.26556 .09448 L
.26578 .09448 L
.266 .09448 L
.2662 .09448 L
.26642 .09448 L
.26664 .09448 L
.26684 .09448 L
.26706 .09448 L
Mistroke
.26726 .09448 L
.26749 .09448 L
.2677 .09448 L
.2679 .09448 L
.26812 .09448 L
.26833 .09448 L
.26853 .09448 L
.26875 .09448 L
.26896 .09448 L
.26918 .09448 L
.26939 .09448 L
.26959 .09448 L
.26981 .09448 L
.27002 .09448 L
.27024 .09448 L
.27046 .09448 L
.27066 .09448 L
.27088 .09448 L
.27109 .09448 L
.27129 .09448 L
.27151 .09448 L
.27172 .09448 L
.27194 .09448 L
.27215 .09448 L
.27236 .09448 L
.27257 .09448 L
.27278 .09448 L
.27299 .09448 L
.2732 .09448 L
.27341 .09448 L
.27363 .09448 L
.27384 .09448 L
.27404 .09448 L
.27426 .09448 L
.27447 .09448 L
.27469 .09448 L
.2749 .09448 L
.27511 .09448 L
.27533 .09448 L
.27554 .09448 L
.27574 .09448 L
.27596 .09448 L
.27616 .09448 L
.27638 .09448 L
.2766 .09448 L
.2768 .09448 L
.27702 .09448 L
.27723 .09448 L
.27745 .09448 L
.27766 .09448 L
Mistroke
.27787 .09448 L
.27809 .09448 L
.2783 .09448 L
.2785 .09448 L
.27872 .09448 L
.27893 .09448 L
.27915 .09448 L
.27936 .09448 L
.27957 .09448 L
.27979 .09448 L
.28 .09448 L
.2802 .09448 L
.28041 .09448 L
.28062 .09448 L
.28084 .09448 L
.28105 .09448 L
.28126 .09448 L
.28147 .09448 L
.28168 .09448 L
.2819 .09448 L
.28212 .09448 L
.28232 .09448 L
.28254 .09448 L
.28275 .09448 L
.28296 .09448 L
.28317 .09448 L
.28338 .09448 L
.2836 .09448 L
.28381 .09448 L
.28402 .09448 L
.28423 .09448 L
.28444 .09448 L
.28465 .09448 L
.28486 .09448 L
.28507 .09448 L
.28529 .09448 L
.2855 .09448 L
.2857 .09448 L
.28592 .09448 L
.28613 .09448 L
.28635 .09448 L
.28656 .09448 L
.28677 .09448 L
.28699 .09448 L
.2872 .09448 L
.2874 .09448 L
.28761 .09448 L
.28782 .09448 L
.28804 .09448 L
.28825 .09448 L
Mistroke
.28846 .09448 L
.28867 .09448 L
.28888 .09448 L
.28911 .09448 L
.28932 .09448 L
.28953 .09448 L
.28975 .09448 L
.28996 .09448 L
.29016 .09448 L
.29038 .09448 L
.29058 .09448 L
.2908 .09448 L
.29102 .09448 L
.29122 .09448 L
.29144 .09448 L
.29165 .09448 L
.29185 .09448 L
.29207 .09448 L
.29227 .09448 L
.29249 .09448 L
.29271 .09448 L
.29291 .09448 L
.29313 .09448 L
.29333 .09448 L
.29356 .09448 L
.29377 .09448 L
.29398 .09448 L
.29419 .09448 L
.2944 .09448 L
.29461 .09448 L
.29482 .09448 L
.29503 .09448 L
.29525 .09448 L
.29546 .09448 L
.29567 .09448 L
.29589 .09448 L
.29609 .09448 L
.29632 .09448 L
.29653 .09448 L
.29674 .09448 L
.29696 .09448 L
.29717 .09448 L
.29737 .09448 L
.29759 .09448 L
.2978 .09448 L
.29802 .09448 L
.29823 .09448 L
.29844 .09448 L
.29865 .09448 L
.29886 .09448 L
Mistroke
.29907 .09448 L
.29928 .09448 L
.29949 .09448 L
.29971 .09448 L
.29992 .09448 L
.30013 .09448 L
.30034 .09448 L
.30055 .09448 L
.30077 .09448 L
.30099 .09448 L
.30119 .09448 L
.30141 .09448 L
.30162 .09448 L
.30183 .09448 L
.30204 .09448 L
.30225 .09448 L
.30247 .09448 L
.30268 .09448 L
.30289 .09448 L
.30311 .09448 L
.30332 .09448 L
.30352 .09448 L
.30373 .09448 L
.30394 .09448 L
.30416 .09448 L
.30437 .09448 L
.30457 .09448 L
.30479 .09448 L
.305 .09448 L
.30522 .09448 L
.30543 .09448 L
.30564 .09448 L
.30586 .09448 L
.30607 .09448 L
.30627 .09448 L
.30649 .09448 L
.30669 .09448 L
.30691 .09448 L
.30713 .09448 L
.30733 .09448 L
.30755 .09448 L
.30776 .09448 L
.30798 .09448 L
.30819 .09448 L
.3084 .09448 L
.30862 .09448 L
.30883 .09448 L
.30903 .09448 L
.30925 .09448 L
.30946 .09448 L
Mistroke
.30968 .09448 L
.30989 .09448 L
.3101 .09448 L
.31031 .09448 L
.31052 .09448 L
.31073 .09448 L
.31094 .09448 L
.31115 .09448 L
.31137 .09448 L
.31158 .09448 L
.31178 .09448 L
.312 .09448 L
.31221 .09448 L
.31243 .09448 L
.31265 .09448 L
.31285 .09448 L
.31307 .09448 L
.31328 .09448 L
.31348 .09448 L
.3137 .09448 L
.31391 .09448 L
.31413 .09448 L
.31434 .09448 L
.31454 .09448 L
.31476 .09448 L
.31497 .09448 L
.31519 .09448 L
.31541 .09448 L
.31562 .09448 L
.31584 .09448 L
.31605 .09448 L
.31625 .09448 L
.31647 .09448 L
.31667 .09448 L
.3169 .09448 L
.31711 .09448 L
.31731 .09448 L
.31753 .09448 L
.31774 .09448 L
.31795 .09448 L
.31816 .09448 L
.31837 .09448 L
.31859 .09448 L
.3188 .09448 L
.319 .09448 L
.31922 .09448 L
.31943 .09448 L
.31965 .09448 L
.31987 .09448 L
.32007 .09448 L
Mistroke
.32029 .09448 L
.3205 .09448 L
.32071 .09448 L
.32092 .09448 L
.32113 .09448 L
.32135 .09448 L
.32156 .09448 L
.32177 .09448 L
.32199 .09448 L
.3222 .09448 L
.3224 .09448 L
.32261 .09448 L
.32282 .09448 L
.32304 .09448 L
.32325 .09448 L
.32346 .09448 L
.32367 .09448 L
.32388 .09448 L
.3241 .09448 L
.32432 .09448 L
.32452 .09448 L
.32474 .09448 L
.32495 .09448 L
.32515 .09448 L
.32537 .09448 L
.32558 .09448 L
.3258 .09448 L
.32601 .09448 L
.32621 .09448 L
.32643 .09448 L
.32664 .09448 L
.32686 .09448 L
.32708 .09448 L
.32728 .09448 L
.3275 .09448 L
.32771 .09448 L
.32792 .09448 L
.32813 .09448 L
.32834 .09448 L
.32856 .09448 L
.32878 .09448 L
.32898 .09448 L
.3292 .09448 L
.32941 .09448 L
.32961 .09448 L
.32983 .09448 L
.33003 .09448 L
.33025 .09448 L
.33047 .09448 L
.33067 .09448 L
Mistroke
.33089 .09448 L
.3311 .09448 L
.33132 .09448 L
.33153 .09448 L
.33174 .09448 L
.33196 .09448 L
.33217 .09448 L
.33237 .09448 L
.33259 .09448 L
.33279 .09448 L
.33301 .09448 L
.33323 .09448 L
.33343 .09448 L
.33365 .09448 L
.33386 .09448 L
.33406 .09448 L
.33428 .09448 L
.33448 .09448 L
.3347 .09448 L
.33491 .09448 L
.33512 .09448 L
.33533 .09448 L
.33554 .09448 L
.33576 .09448 L
.33598 .09448 L
.33618 .09448 L
.3364 .09448 L
.33661 .09448 L
.33681 .09448 L
.33703 .09448 L
.33724 .09448 L
.33746 .09448 L
.33767 .09448 L
.33787 .09448 L
.33809 .09448 L
.3383 .09448 L
.33852 .09448 L
.33874 .09448 L
.33894 .09448 L
.33916 .09448 L
.33937 .09448 L
.33957 .09448 L
.33979 .09448 L
.34 .09448 L
.34022 .09448 L
.34043 .09448 L
.34064 .09448 L
.34086 .09448 L
.34107 .09448 L
.34127 .09448 L
Mistroke
.34127 .09448 L
Mfstroke
.34127 .17224 m
.34148 .17224 L
.3417 .17224 L
.34191 .17224 L
.34212 .17224 L
.34233 .17224 L
.34254 .17224 L
.34276 .17224 L
.34298 .17224 L
.34318 .17224 L
.3434 .17224 L
.34361 .17224 L
.34381 .17224 L
.34403 .17224 L
.34423 .17224 L
.34446 .17224 L
.34467 .17224 L
.34487 .17224 L
.34509 .17224 L
.3453 .17224 L
.34552 .17224 L
.34573 .17224 L
.34594 .17224 L
.34616 .17224 L
.34637 .17224 L
.34657 .17224 L
.34679 .17224 L
.347 .17224 L
.34722 .17224 L
.34743 .17224 L
.34764 .17224 L
.34785 .17224 L
.34806 .17224 L
.34827 .17224 L
.34848 .17224 L
.34869 .17224 L
.34891 .17224 L
.34912 .17224 L
.34932 .17224 L
.34954 .17224 L
.34975 .17224 L
.34997 .17224 L
.35018 .17224 L
.35039 .17224 L
.35061 .17224 L
.35082 .17224 L
.35102 .17224 L
.35124 .17224 L
.35144 .17224 L
.35166 .17224 L
Mistroke
.35188 .17224 L
.35208 .17224 L
.3523 .17224 L
.35251 .17224 L
.35273 .17224 L
.35294 .17224 L
.35315 .17224 L
.35337 .17224 L
.35358 .17224 L
.35378 .17224 L
.354 .17224 L
.35421 .17224 L
.35443 .17224 L
.35464 .17224 L
.35485 .17224 L
.35507 .17224 L
.35528 .17224 L
.35548 .17224 L
.35569 .17224 L
.3559 .17224 L
.35612 .17224 L
.35633 .17224 L
.35654 .17224 L
.35675 .17224 L
.35696 .17224 L
.35719 .17224 L
.3574 .17224 L
.35761 .17224 L
.35782 .17224 L
.35804 .17224 L
.35824 .17224 L
.35845 .17224 L
.35866 .17224 L
.35888 .17224 L
.3591 .17224 L
.3593 .17224 L
.35952 .17224 L
.35973 .17224 L
.35993 .17224 L
.36014 .17224 L
.36035 .17224 L
.36057 .17224 L
.36078 .17224 L
.36098 .17224 L
.3612 .17224 L
.36141 .17224 L
.36163 .17224 L
.36184 .17224 L
.36205 .17224 L
.36227 .17224 L
Mistroke
.36248 .17224 L
.36268 .17224 L
.3629 .17224 L
.3631 .17224 L
.36332 .17224 L
.36354 .17224 L
.36374 .17224 L
.36396 .17224 L
.36417 .17224 L
.36439 .17224 L
.3646 .17224 L
.36481 .17224 L
.36503 .17224 L
.36524 .17224 L
.36544 .17224 L
.36566 .17224 L
.36587 .17224 L
.36609 .17224 L
.3663 .17224 L
.36651 .17224 L
.36673 .17224 L
.36694 .17224 L
.36714 .17224 L
.36735 .17224 L
.36756 .17224 L
.36778 .17224 L
.36799 .17224 L
.36819 .17224 L
.36841 .17224 L
.36862 .17224 L
.36884 .17224 L
.36906 .17224 L
.36926 .17224 L
.36948 .17224 L
.36969 .17224 L
.36989 .17224 L
.37011 .17224 L
.37032 .17224 L
.37054 .17224 L
.37075 .17224 L
.37095 .17224 L
.37117 .17224 L
.37138 .17224 L
.3716 .17224 L
.37182 .17224 L
.37202 .17224 L
.37224 .17224 L
.37246 .17224 L
.37266 .17224 L
.37288 .17224 L
Mistroke
.37308 .17224 L
.37331 .17224 L
.37352 .17224 L
.37372 .17224 L
.37394 .17224 L
.37415 .17224 L
.37435 .17224 L
.37457 .17224 L
.37478 .17224 L
.375 .17224 L
.37521 .17224 L
.37541 .17224 L
.37563 .17224 L
.37584 .17224 L
.37606 .17224 L
.37628 .17224 L
.37648 .17224 L
.3767 .17224 L
.37691 .17224 L
.37711 .17224 L
.37733 .17224 L
.37754 .17224 L
.37776 .17224 L
.37797 .17224 L
.37818 .17224 L
.37839 .17224 L
.3786 .17224 L
.37881 .17224 L
.37902 .17224 L
.37923 .17224 L
.37945 .17224 L
.37966 .17224 L
.37986 .17224 L
.38008 .17224 L
.38029 .17224 L
.38051 .17224 L
.38072 .17224 L
.38093 .17224 L
.38115 .17224 L
.38136 .17224 L
.38156 .17224 L
.38178 .17224 L
.38198 .17224 L
.3822 .17224 L
.38242 .17224 L
.38262 .17224 L
.38284 .17224 L
.38305 .17224 L
.38327 .17224 L
.38348 .17224 L
Mistroke
.38369 .17224 L
.38391 .17224 L
.38412 .17224 L
.38432 .17224 L
.38454 .17224 L
.38475 .17224 L
.38497 .17224 L
.38518 .17224 L
.38539 .17224 L
.38561 .17224 L
.38582 .17224 L
.38602 .17224 L
.38623 .17224 L
.38644 .17224 L
.38666 .17224 L
.38687 .17224 L
.38708 .17224 L
.38729 .17224 L
.3875 .17224 L
.38772 .17224 L
.38794 .17224 L
.38814 .17224 L
.38836 .17224 L
.38857 .17224 L
.38878 .17224 L
.38899 .17224 L
.3892 .17224 L
.38942 .17224 L
.38963 .17224 L
.38984 .17224 L
.39005 .17224 L
.39026 .17224 L
.39047 .17224 L
.39068 .17224 L
.39089 .17224 L
.39111 .17224 L
.39132 .17224 L
.39152 .17224 L
.39174 .17224 L
.39195 .17224 L
.39217 .17224 L
.39238 .17224 L
.39259 .17224 L
.39281 .17224 L
.39302 .17224 L
.39322 .17224 L
.39343 .17224 L
.39364 .17224 L
.39386 .17224 L
.39407 .17224 L
Mistroke
.39428 .17224 L
.39449 .17224 L
.3947 .17224 L
.39493 .17224 L
.39514 .17224 L
.39535 .17224 L
.39557 .17224 L
.39578 .17224 L
.39598 .17224 L
.3962 .17224 L
.3964 .17224 L
.39662 .17224 L
.39684 .17224 L
.39704 .17224 L
.39726 .17224 L
.39747 .17224 L
.39767 .17224 L
.39789 .17224 L
.39809 .17224 L
.39831 .17224 L
.39853 .17224 L
.39873 .17224 L
.39895 .17224 L
.39915 .17224 L
.39938 .17224 L
.39959 .17224 L
.3998 .17224 L
.40001 .17224 L
.40022 .17224 L
.40043 .17224 L
.40064 .17224 L
.40085 .17224 L
.40107 .17224 L
.40128 .17224 L
.40149 .17224 L
.40171 .17224 L
.40192 .17224 L
.40214 .17224 L
.40235 .17224 L
.40256 .17224 L
.40278 .17224 L
.40299 .17224 L
.40319 .17224 L
.40341 .17224 L
.40362 .17224 L
.40384 .17224 L
.40405 .17224 L
.40426 .17224 L
.40447 .17224 L
.40469 .17224 L
Mistroke
.40489 .17224 L
.4051 .17224 L
.40531 .17224 L
.40553 .17224 L
.40574 .17224 L
.40595 .17224 L
.40616 .17224 L
.40637 .17224 L
.40659 .17224 L
.40681 .17224 L
.40701 .17224 L
.40723 .17224 L
.40744 .17224 L
.40765 .17224 L
.40786 .17224 L
.40807 .17224 L
.40829 .17224 L
.4085 .17224 L
.40871 .17224 L
.40893 .17224 L
.40914 .17224 L
.40934 .17224 L
.40955 .17224 L
.40976 .17224 L
.40998 .17224 L
.41019 .17224 L
.41039 .17224 L
.41061 .17224 L
.41082 .17224 L
.41104 .17224 L
.41125 .17224 L
.41146 .17224 L
.41168 .17224 L
.41189 .17224 L
.41209 .17224 L
.41231 .17224 L
.41251 .17224 L
.41273 .17224 L
.41295 .17224 L
.41315 .17224 L
.41337 .17224 L
.41358 .17224 L
.4138 .17224 L
.41401 .17224 L
.41422 .17224 L
.41444 .17224 L
.41465 .17224 L
.41485 .17224 L
.41507 .17224 L
.41528 .17224 L
Mistroke
.4155 .17224 L
.41571 .17224 L
.41592 .17224 L
.41614 .17224 L
.41635 .17224 L
.41655 .17224 L
.41676 .17224 L
.41697 .17224 L
.41719 .17224 L
.4174 .17224 L
.4176 .17224 L
.41782 .17224 L
.41803 .17224 L
.41825 .17224 L
.41847 .17224 L
.41867 .17224 L
.41889 .17224 L
.4191 .17224 L
.4193 .17224 L
.41952 .17224 L
.41973 .17224 L
.41995 .17224 L
.42016 .17224 L
.42037 .17224 L
.42058 .17224 L
.42079 .17224 L
.42101 .17224 L
.42123 .17224 L
.42144 .17224 L
.42166 .17224 L
.42187 .17224 L
.42207 .17224 L
.42229 .17224 L
.4225 .17224 L
.42272 .17224 L
.42293 .17224 L
.42314 .17224 L
.42335 .17224 L
.42356 .17224 L
.42377 .17224 L
.42398 .17224 L
.42419 .17224 L
.42441 .17224 L
.42462 .17224 L
.42482 .17224 L
.42504 .17224 L
.42525 .17224 L
.42547 .17224 L
.42569 .17224 L
.42589 .17224 L
Mistroke
.42611 .17224 L
.42632 .17224 L
.42653 .17224 L
.42674 .17224 L
.42695 .17224 L
.42717 .17224 L
.42738 .17224 L
.42759 .17224 L
.42781 .17224 L
.42802 .17224 L
.42822 .17224 L
.42843 .17224 L
.42864 .17224 L
.42886 .17224 L
.42907 .17224 L
.42928 .17224 L
.42949 .17224 L
.4297 .17224 L
.42992 .17224 L
.43014 .17224 L
.43034 .17224 L
.43056 .17224 L
.43077 .17224 L
.43097 .17224 L
.43119 .17224 L
.4314 .17224 L
.43162 .17224 L
.43183 .17224 L
.43203 .17224 L
.43225 .17224 L
.43246 .17224 L
.43268 .17224 L
.4329 .17224 L
.4331 .17224 L
.43332 .17224 L
.43353 .17224 L
.43374 .17224 L
.43395 .17224 L
.43416 .17224 L
.43438 .17224 L
.4346 .17224 L
.4348 .17224 L
.43502 .17224 L
.43523 .17224 L
.43543 .17224 L
.43565 .17224 L
.43585 .17224 L
.43607 .17224 L
.43629 .17224 L
.43649 .17224 L
Mistroke
.43671 .17224 L
.43692 .17224 L
.43714 .17224 L
.43735 .17224 L
.43756 .17224 L
.43778 .17224 L
.43799 .17224 L
.43819 .17224 L
.43841 .17224 L
.43861 .17224 L
.43883 .17224 L
.43905 .17224 L
.43925 .17224 L
.43947 .17224 L
.43968 .17224 L
.43988 .17224 L
.4401 .17224 L
.4403 .17224 L
.44052 .17224 L
.44073 .17224 L
.44094 .17224 L
.44115 .17224 L
.44136 .17224 L
.44158 .17224 L
.4418 .17224 L
.442 .17224 L
.44222 .17224 L
.44243 .17224 L
.44263 .17224 L
.44285 .17224 L
.44306 .17224 L
.44328 .17224 L
.44349 .17224 L
.44369 .17224 L
.44391 .17224 L
.44412 .17224 L
.44434 .17224 L
.44456 .17224 L
.44476 .17224 L
.44498 .17224 L
.44519 .17224 L
.44539 .17224 L
.44561 .17224 L
.44582 .17224 L
.44604 .17224 L
.44625 .17224 L
.44646 .17224 L
.44668 .17224 L
.44689 .17224 L
.44709 .17224 L
Mistroke
.44709 .17224 L
Mfstroke
.44709 .25 m
.4471 .25 L
.4471 .25 L
.44711 .25 L
.44711 .25 L
.44712 .25 L
.44713 .25 L
.44713 .25 L
.44714 .25 L
.44714 .25 L
.44715 .25 L
.44716 .25 L
.44716 .25 L
.44717 .25 L
.44717 .25 L
.44718 .25 L
.44718 .25 L
.44719 .25 L
.44719 .25 L
.4472 .25 L
.4472 .25 L
.44721 .25 L
.44721 .25 L
.44722 .25 L
.44722 .25 L
.44722 .25 L
.44723 .25 L
.44723 .25 L
.44724 .25 L
.44725 .25 L
.44725 .25 L
.44726 .25 L
.44726 .25 L
.44727 .25 L
.44728 .25 L
.44728 .25 L
.44729 .25 L
.4473 .25 L
.4473 .25 L
.4473 .25 L
.44731 .25 L
.44731 .25 L
.44732 .25 L
.44732 .25 L
.44733 .25 L
.44733 .25 L
.44734 .25 L
.44734 .25 L
.44735 .25 L
.44735 .25 L
Mistroke
.44736 .25 L
.44736 .25 L
.44736 .25 L
.44737 .25 L
.44737 .25 L
.44738 .25 L
.44738 .25 L
.44738 .25 L
.44739 .25 L
.44739 .25 L
.4474 .25 L
.4474 .25 L
.44741 .25 L
.44741 .25 L
.44741 .25 L
.44742 .25 L
.44743 .25 L
.44743 .25 L
.44744 .25 L
.44744 .25 L
.44745 .25 L
.44746 .25 L
.44746 .25 L
.44747 .25 L
.44747 .25 L
.44747 .25 L
.44748 .25 L
.44748 .25 L
.44749 .25 L
.44749 .25 L
.4475 .25 L
.4475 .25 L
.44751 .25 L
.44751 .25 L
.44752 .25 L
.44753 .25 L
.44753 .25 L
.44754 .25 L
.44755 .25 L
.44755 .25 L
.44756 .25 L
.44756 .25 L
.44757 .25 L
.44757 .25 L
.44758 .25 L
.44758 .25 L
.44758 .25 L
.44759 .25 L
.44759 .25 L
.4476 .25 L
Mistroke
.4476 .25 L
.44761 .25 L
.44761 .25 L
.44762 .25 L
.44763 .25 L
.44763 .25 L
.44764 .25 L
.44765 .25 L
.44765 .25 L
.44766 .25 L
.44766 .25 L
.44767 .25 L
.44768 .25 L
.44768 .25 L
.44769 .25 L
.44769 .25 L
.4477 .25 L
.44771 .25 L
.44771 .25 L
.44771 .25 L
.44772 .25 L
.44773 .25 L
.44773 .25 L
.44774 .25 L
.44775 .25 L
.44775 .25 L
.44776 .25 L
.44776 .25 L
.44777 .25 L
.44778 .25 L
.44778 .25 L
.44779 .25 L
.4478 .25 L
.4478 .25 L
.44781 .25 L
.44781 .25 L
.44782 .25 L
.44782 .25 L
.44783 .25 L
.44784 .25 L
.44784 .25 L
.44785 .25 L
.44785 .25 L
.44786 .25 L
.44787 .25 L
.44787 .25 L
.44788 .25 L
.44788 .25 L
.44789 .25 L
.4479 .25 L
Mistroke
.4479 .25 L
.44791 .25 L
.44791 .25 L
.44792 .25 L
.44792 .25 L
.44793 .25 L
.44793 .25 L
.44794 .25 L
.44795 .25 L
.44795 .25 L
.44796 .25 L
.44797 .25 L
.44797 .25 L
.44798 .25 L
.44799 .25 L
.44799 .25 L
.448 .25 L
.448 .25 L
.44801 .25 L
.44802 .25 L
.44802 .25 L
.44803 .25 L
.44803 .25 L
.44804 .25 L
.44804 .25 L
.44805 .25 L
.44806 .25 L
.44806 .25 L
.44807 .25 L
.44807 .25 L
.44808 .25 L
.44809 .25 L
.44809 .25 L
.4481 .25 L
.4481 .25 L
.44811 .25 L
.44811 .25 L
.44812 .25 L
.44812 .25 L
.44813 .25 L
.44814 .25 L
.44814 .25 L
.44815 .25 L
.44816 .25 L
.44816 .25 L
.44817 .25 L
.44817 .25 L
.44818 .25 L
.44819 .25 L
.44819 .25 L
Mistroke
.4482 .25 L
.44821 .25 L
.44821 .25 L
.44822 .25 L
.44822 .25 L
.44823 .25 L
.44823 .25 L
.44824 .25 L
.44825 .25 L
.44825 .25 L
.44826 .25 L
.44826 .25 L
.44827 .25 L
.44828 .25 L
.44828 .25 L
.44829 .25 L
.44829 .25 L
.4483 .25 L
.44831 .25 L
.44831 .25 L
.44832 .25 L
.44832 .25 L
.44833 .25 L
.44833 .25 L
.44834 .25 L
.44835 .25 L
.44835 .25 L
.44836 .25 L
.44836 .25 L
.44837 .25 L
.44838 .25 L
.44838 .25 L
.44839 .25 L
.4484 .25 L
.4484 .25 L
.44841 .25 L
.44842 .25 L
.44842 .25 L
.44842 .25 L
.44843 .25 L
.44844 .25 L
.44844 .25 L
.44845 .25 L
.44846 .25 L
.44846 .25 L
.44847 .25 L
.44847 .25 L
.44848 .25 L
.44848 .25 L
.44849 .25 L
Mistroke
.4485 .25 L
.4485 .25 L
.44851 .25 L
.44852 .25 L
.44852 .25 L
.44852 .25 L
.44853 .25 L
.44854 .25 L
.44854 .25 L
.44855 .25 L
.44855 .25 L
.44856 .25 L
.44856 .25 L
.44857 .25 L
.44857 .25 L
.44858 .25 L
.44859 .25 L
.44859 .25 L
.4486 .25 L
.4486 .25 L
.44861 .25 L
.44861 .25 L
.44861 .25 L
.44862 .25 L
.44863 .25 L
.44863 .25 L
.44864 .25 L
.44865 .25 L
.44865 .25 L
.44866 .25 L
.44866 .25 L
.44867 .25 L
.44868 .25 L
.44868 .25 L
.44869 .25 L
.44869 .25 L
.4487 .25 L
.44871 .25 L
.44871 .25 L
.44872 .25 L
.44873 .25 L
.44873 .25 L
.44874 .25 L
.44875 .25 L
.44875 .25 L
.44876 .25 L
.44876 .25 L
.44876 .25 L
.44877 .25 L
.44877 .25 L
Mistroke
.44878 .25 L
.44879 .25 L
.44879 .25 L
.4488 .25 L
.44881 .25 L
.44881 .25 L
.44882 .25 L
.44882 .25 L
.44883 .25 L
.44884 .25 L
.44884 .25 L
.44885 .25 L
.44886 .25 L
.44886 .25 L
.44887 .25 L
.44888 .25 L
.44888 .25 L
.44888 .25 L
.44889 .25 L
.44889 .25 L
.4489 .25 L
.4489 .25 L
.4489 .25 L
.44891 .25 L
.44892 .25 L
.44892 .25 L
.44892 .25 L
.44893 .25 L
.44893 .25 L
.44893 .25 L
.44894 .25 L
.44894 .25 L
.44895 .25 L
.44895 .25 L
.44896 .25 L
.44897 .25 L
.44897 .25 L
.44898 .25 L
.44899 .25 L
.44899 .25 L
.449 .25 L
.44901 .25 L
.44901 .25 L
.44902 .25 L
.44902 .25 L
.44903 .25 L
.44904 .25 L
.44904 .25 L
.44905 .25 L
.44905 .25 L
Mistroke
.44906 .25 L
.44906 .25 L
.44907 .25 L
.44908 .25 L
.44908 .25 L
.44909 .25 L
.44909 .25 L
.4491 .25 L
.44911 .25 L
.44911 .25 L
.44912 .25 L
.44912 .25 L
.44913 .25 L
.44914 .25 L
.44914 .25 L
.44914 .25 L
.44915 .25 L
.44916 .25 L
.44916 .25 L
.44917 .25 L
.44918 .25 L
.44918 .25 L
.44919 .25 L
.4492 .25 L
.4492 .25 L
.44921 .25 L
.44921 .25 L
.44922 .25 L
.44923 .25 L
.44923 .25 L
.44924 .25 L
.44924 .25 L
.44925 .25 L
.44926 .25 L
.44926 .25 L
.44927 .25 L
.44927 .25 L
.44928 .25 L
.44929 .25 L
.44929 .25 L
.4493 .25 L
.4493 .25 L
.44931 .25 L
.44931 .25 L
.44932 .25 L
.44933 .25 L
.44933 .25 L
.44934 .25 L
.44934 .25 L
.44935 .25 L
Mistroke
.44935 .25 L
.44936 .25 L
.44937 .25 L
.44937 .25 L
.44937 .25 L
.44938 .25 L
.44939 .25 L
.44939 .25 L
.4494 .25 L
.4494 .25 L
.44941 .25 L
.44942 .25 L
.44942 .25 L
.44942 .25 L
.44943 .25 L
.44944 .25 L
.44944 .25 L
.44945 .25 L
.44945 .25 L
.44946 .25 L
.44946 .25 L
.44947 .25 L
.44948 .25 L
.44948 .25 L
.44949 .25 L
.44949 .25 L
.4495 .25 L
.44951 .25 L
.44951 .25 L
.44952 .25 L
.44952 .25 L
.44953 .25 L
.44954 .25 L
.44954 .25 L
.44955 .25 L
.44956 .25 L
.44956 .25 L
.44957 .25 L
.44958 .25 L
.44958 .25 L
.44958 .25 L
.44959 .25 L
.44959 .25 L
.4496 .25 L
.4496 .25 L
.44961 .25 L
.44962 .25 L
.44962 .25 L
.44963 .25 L
.44964 .25 L
Mistroke
.44964 .25 L
.44965 .25 L
.44965 .25 L
.44966 .25 L
.44967 .25 L
.44967 .25 L
.44968 .25 L
.44969 .25 L
.44969 .25 L
.4497 .25 L
.4497 .25 L
.44971 .25 L
.44971 .25 L
.44972 .25 L
.44972 .25 L
.44972 .25 L
.44973 .25 L
.44974 .25 L
.44974 .25 L
.44974 .25 L
.44975 .25 L
.44975 .25 L
.44975 .25 L
.44976 .25 L
.44976 .25 L
.44977 .25 L
.44977 .25 L
.44978 .25 L
.44979 .25 L
.44979 .25 L
.4498 .25 L
.44981 .25 L
.44981 .25 L
.44982 .25 L
.44982 .25 L
.44983 .25 L
.44984 .25 L
.44984 .25 L
.44985 .25 L
.44986 .25 L
.44986 .25 L
.44987 .25 L
.44987 .25 L
.44988 .25 L
.44988 .25 L
.44989 .25 L
.4499 .25 L
.4499 .25 L
.44991 .25 L
.44991 .25 L
Mistroke
.44992 .25 L
.44992 .25 L
.44993 .25 L
.44994 .25 L
.44994 .25 L
.44995 .25 L
.44995 .25 L
.44996 .25 L
.44996 .25 L
.44997 .25 L
.44997 .25 L
.44998 .25 L
.44999 .25 L
.44999 .25 L
.45 .25 L
.45001 .25 L
.45001 .25 L
.45002 .25 L
.45003 .25 L
.45003 .25 L
.45004 .25 L
.45005 .25 L
.45005 .25 L
.45006 .25 L
.45006 .25 L
.45007 .25 L
.45007 .25 L
.45008 .25 L
.45009 .25 L
.45009 .25 L
.4501 .25 L
.4501 .25 L
.45011 .25 L
.45012 .25 L
.45012 .25 L
.45013 .25 L
.45013 .25 L
.45014 .25 L
.45015 .25 L
.45015 .25 L
.45016 .25 L
.45016 .25 L
.45017 .25 L
.45017 .25 L
.45018 .25 L
.45018 .25 L
.45019 .25 L
.45019 .25 L
.4502 .25 L
.4502 .25 L
Mistroke
.45021 .25 L
.45022 .25 L
.45022 .25 L
.45023 .25 L
.45023 .25 L
.45024 .25 L
.45024 .25 L
.45025 .25 L
.45026 .25 L
.45026 .25 L
.45026 .25 L
.45027 .25 L
.45028 .25 L
.45028 .25 L
.45029 .25 L
.45029 .25 L
.4503 .25 L
.45031 .25 L
.45031 .25 L
.45032 .25 L
.45032 .25 L
.45033 .25 L
.45034 .25 L
.45034 .25 L
.45035 .25 L
.45035 .25 L
.45036 .25 L
.45037 .25 L
.45037 .25 L
.45038 .25 L
.45039 .25 L
.45039 .25 L
.4504 .25 L
.4504 .25 L
.45041 .25 L
.45041 .25 L
.45041 .25 L
.45042 .25 L
.45043 .25 L
.45043 .25 L
.45044 .25 L
.45045 .25 L
.45045 .25 L
.45046 .25 L
.45046 .25 L
.45047 .25 L
.45048 .25 L
.45048 .25 L
.45049 .25 L
.4505 .25 L
Mistroke
.4505 .25 L
.45051 .25 L
.45052 .25 L
.45052 .25 L
.45053 .25 L
.45053 .25 L
.45054 .25 L
.45054 .25 L
.45055 .25 L
.45055 .25 L
.45055 .25 L
.45056 .25 L
.45056 .25 L
.45057 .25 L
.45057 .25 L
.45057 .25 L
.45058 .25 L
.45058 .25 L
.45059 .25 L
.45059 .25 L
.4506 .25 L
.4506 .25 L
.45061 .25 L
.45062 .25 L
.45062 .25 L
.45063 .25 L
.45064 .25 L
.45064 .25 L
.45065 .25 L
.45065 .25 L
.45066 .25 L
.45067 .25 L
.45067 .25 L
.45068 .25 L
.45069 .25 L
.45069 .25 L
.45069 .25 L
.4507 .25 L
.45071 .25 L
.45071 .25 L
.45072 .25 L
.45073 .25 L
.45073 .25 L
.45074 .25 L
.45074 .25 L
.45075 .25 L
.45075 .25 L
.45076 .25 L
.45077 .25 L
.45077 .25 L
Mistroke
.45078 .25 L
.45078 .25 L
.45079 .25 L
.45079 .25 L
.4508 .25 L
.4508 .25 L
.45081 .25 L
.45082 .25 L
.45083 .25 L
.45083 .25 L
.45084 .25 L
.45084 .25 L
.45085 .25 L
.45086 .25 L
.45086 .25 L
.45087 .25 L
.45087 .25 L
.45088 .25 L
.45089 .25 L
.45089 .25 L
.4509 .25 L
.4509 .25 L
.45091 .25 L
.45092 .25 L
.45092 .25 L
.45093 .25 L
.45093 .25 L
.45094 .25 L
.45094 .25 L
.45095 .25 L
.45096 .25 L
.45096 .25 L
.45097 .25 L
.45098 .25 L
.45098 .25 L
.45099 .25 L
.45099 .25 L
.45099 .25 L
.451 .25 L
.45101 .25 L
.45101 .25 L
.45102 .25 L
.45102 .25 L
.45103 .25 L
.45103 .25 L
.45104 .25 L
.45105 .25 L
.45105 .25 L
.45106 .25 L
.45106 .25 L
Mistroke
.45107 .25 L
.45107 .25 L
.45108 .25 L
.45108 .25 L
.45109 .25 L
.45109 .25 L
.4511 .25 L
.45111 .25 L
.45111 .25 L
.45112 .25 L
.45112 .25 L
.45113 .25 L
.45113 .25 L
.45114 .25 L
.45115 .25 L
.45115 .25 L
.45116 .25 L
.45117 .25 L
.45117 .25 L
.45118 .25 L
.45118 .25 L
.45119 .25 L
.4512 .25 L
.4512 .25 L
.45121 .25 L
.45122 .25 L
.45122 .25 L
.45123 .25 L
.45123 .25 L
.45123 .25 L
.45124 .25 L
.45124 .25 L
.45125 .25 L
.45126 .25 L
.45126 .25 L
.45127 .25 L
.45128 .25 L
.45128 .25 L
.45129 .25 L
.45129 .25 L
.4513 .25 L
.45131 .25 L
.45131 .25 L
.45132 .25 L
.45133 .25 L
.45133 .25 L
.45134 .25 L
.45135 .25 L
.45135 .25 L
.45135 .25 L
Mistroke
.45136 .25 L
.45137 .25 L
.45137 .25 L
.45137 .25 L
.45138 .25 L
.45138 .25 L
.45139 .25 L
.45139 .25 L
.45139 .25 L
.4514 .25 L
.4514 .25 L
.45141 .25 L
.45141 .25 L
.45141 .25 L
.45142 .25 L
.45143 .25 L
.45143 .25 L
.45144 .25 L
.45145 .25 L
.45145 .25 L
.45146 .25 L
.45146 .25 L
.45147 .25 L
.45148 .25 L
.45148 .25 L
.45149 .25 L
.4515 .25 L
.4515 .25 L
.45151 .25 L
.45151 .25 L
.45152 .25 L
.45152 .25 L
.45153 .25 L
.45154 .25 L
.45154 .25 L
.45155 .25 L
.45155 .25 L
.45156 .25 L
.45157 .25 L
.45157 .25 L
.45158 .25 L
.45158 .25 L
.45159 .25 L
.4516 .25 L
.4516 .25 L
.45161 .25 L
.45161 .25 L
.45162 .25 L
.45162 .25 L
.45163 .25 L
Mistroke
.45163 .25 L
.45164 .25 L
.45165 .25 L
.45165 .25 L
.45166 .25 L
.45167 .25 L
.45167 .25 L
.45168 .25 L
.45169 .25 L
.45169 .25 L
.4517 .25 L
.4517 .25 L
.45171 .25 L
.45172 .25 L
.45172 .25 L
.45173 .25 L
.45173 .25 L
.45174 .25 L
.45174 .25 L
.45175 .25 L
.45176 .25 L
.45176 .25 L
.45177 .25 L
.45177 .25 L
.45178 .25 L
.45179 .25 L
.45179 .25 L
.4518 .25 L
.4518 .25 L
.45181 .25 L
.45181 .25 L
.45182 .25 L
.45182 .25 L
.45183 .25 L
.45184 .25 L
.45184 .25 L
.45184 .25 L
.45185 .25 L
.45186 .25 L
.45186 .25 L
.45187 .25 L
.45187 .25 L
.45188 .25 L
.45189 .25 L
.45189 .25 L
.4519 .25 L
.4519 .25 L
.45191 .25 L
.45191 .25 L
.45192 .25 L
Mistroke
.45192 .25 L
.45193 .25 L
.45194 .25 L
.45194 .25 L
.45195 .25 L
.45195 .25 L
.45196 .25 L
.45196 .25 L
.45197 .25 L
.45198 .25 L
.45198 .25 L
.45199 .25 L
.452 .25 L
.452 .25 L
.45201 .25 L
.45201 .25 L
.45202 .25 L
.45203 .25 L
.45203 .25 L
.45204 .25 L
.45205 .25 L
.45205 .25 L
.45205 .25 L
.45206 .25 L
.45206 .25 L
.45207 .25 L
.45207 .25 L
.45208 .25 L
.45209 .25 L
.45209 .25 L
.4521 .25 L
.45211 .25 L
.45211 .25 L
.45212 .25 L
.45213 .25 L
.45213 .25 L
.45214 .25 L
.45214 .25 L
.45215 .25 L
.45216 .25 L
.45216 .25 L
.45217 .25 L
.45217 .25 L
.45218 .25 L
.45219 .25 L
.45219 .25 L
.45219 .25 L
.4522 .25 L
.4522 .25 L
.45221 .25 L
Mistroke
.45221 .25 L
.45221 .25 L
.45222 .25 L
.45222 .25 L
.45223 .25 L
.45223 .25 L
.45223 .25 L
.45224 .25 L
.45224 .25 L
.45225 .25 L
.45226 .25 L
.45226 .25 L
.45227 .25 L
.45228 .25 L
.45228 .25 L
.45229 .25 L
.45229 .25 L
.4523 .25 L
.45231 .25 L
.45231 .25 L
.45232 .25 L
.45233 .25 L
.45233 .25 L
.45234 .25 L
.45234 .25 L
.45235 .25 L
.45235 .25 L
.45236 .25 L
.45237 .25 L
.45237 .25 L
.45238 .25 L
.45238 .25 L
.45239 .25 L
.45239 .25 L
.4524 .25 L
.45241 .25 L
.45241 .25 L
.45242 .25 L
.45243 .25 L
.45243 .25 L
.45244 .25 L
.45244 .25 L
.45245 .25 L
.45245 .25 L
.45246 .25 L
.45247 .25 L
.45247 .25 L
.45248 .25 L
.45248 .25 L
.45249 .25 L
Mistroke
.4525 .25 L
.4525 .25 L
.45251 .25 L
.45252 .25 L
.45252 .25 L
.45253 .25 L
.45254 .25 L
.45254 .25 L
.45254 .25 L
.45255 .25 L
.45256 .25 L
.45256 .25 L
.45257 .25 L
.45257 .25 L
.45258 .25 L
.45259 .25 L
.45259 .25 L
.4526 .25 L
.4526 .25 L
.45261 .25 L
.45262 .25 L
.45262 .25 L
.45263 .25 L
.45263 .25 L
.45264 .25 L
.45264 .25 L
.45265 .25 L
.45265 .25 L
.45266 .25 L
.45267 .25 L
.45267 .25 L
.45268 .25 L
.45269 .25 L
.45269 .25 L
.4527 .25 L
.4527 .25 L
.45271 .25 L
.45272 .25 L
.45272 .25 L
.45273 .25 L
.45274 .25 L
.45274 .25 L
.45275 .25 L
.45275 .25 L
.45276 .25 L
.45276 .25 L
.45277 .25 L
.45278 .25 L
.45278 .25 L
.45279 .25 L
Mistroke
.45279 .25 L
.4528 .25 L
.45281 .25 L
.45281 .25 L
.45282 .25 L
.45282 .25 L
.45283 .25 L
.45284 .25 L
.45284 .25 L
.45284 .25 L
.45285 .25 L
.45286 .25 L
.45286 .25 L
.45287 .25 L
.45287 .25 L
.45288 .25 L
.45288 .25 L
.45289 .25 L
.45289 .25 L
.4529 .25 L
.45291 .25 L
.45291 .25 L
.45292 .25 L
.45292 .25 L
.45293 .25 L
.45293 .25 L
.45294 .25 L
.45294 .25 L
.45295 .25 L
.45296 .25 L
.45296 .25 L
.45297 .25 L
.45297 .25 L
.45298 .25 L
.45298 .25 L
.45299 .25 L
.453 .25 L
.453 .25 L
.45301 .25 L
.45302 .25 L
.45302 .25 L
.45303 .25 L
.45303 .25 L
.45304 .25 L
.45305 .25 L
.45305 .25 L
.45306 .25 L
.45307 .25 L
.45307 .25 L
.45308 .25 L
Mistroke
.45308 .25 L
.45308 .25 L
.45309 .25 L
.45309 .25 L
.4531 .25 L
.45311 .25 L
.45311 .25 L
.45312 .25 L
.45313 .25 L
.45313 .25 L
.45314 .25 L
.45314 .25 L
.45315 .25 L
.45316 .25 L
.45316 .25 L
.45317 .25 L
.45318 .25 L
.45318 .25 L
.45319 .25 L
.4532 .25 L
.4532 .25 L
.4532 .25 L
.45321 .25 L
.45321 .25 L
.45322 .25 L
.45322 .25 L
.45323 .25 L
.45323 .25 L
.45324 .25 L
.45324 .25 L
.45324 .25 L
.45325 .25 L
.45325 .25 L
.45326 .25 L
.45326 .25 L
.45326 .25 L
.45327 .25 L
.45328 .25 L
.45328 .25 L
.45329 .25 L
.4533 .25 L
.4533 .25 L
.45331 .25 L
.45331 .25 L
.45332 .25 L
.45333 .25 L
.45333 .25 L
.45334 .25 L
.45335 .25 L
.45335 .25 L
Mistroke
.45336 .25 L
.45336 .25 L
.45337 .25 L
.45337 .25 L
.45338 .25 L
.45339 .25 L
.45339 .25 L
.4534 .25 L
.4534 .25 L
.45341 .25 L
.45342 .25 L
.45342 .25 L
.45343 .25 L
.45343 .25 L
.45344 .25 L
.45345 .25 L
.45345 .25 L
.45346 .25 L
.45346 .25 L
.45347 .25 L
.45347 .25 L
.45348 .25 L
.45348 .25 L
.45349 .25 L
.4535 .25 L
.4535 .25 L
.45351 .25 L
.45352 .25 L
.45352 .25 L
.45353 .25 L
.45354 .25 L
.45354 .25 L
.45355 .25 L
.45355 .25 L
.45356 .25 L
.45357 .25 L
.45357 .25 L
.45358 .25 L
.45358 .25 L
.45359 .25 L
.45359 .25 L
.4536 .25 L
.45361 .25 L
.45361 .25 L
.45362 .25 L
.45362 .25 L
.45363 .25 L
.45364 .25 L
.45364 .25 L
.45365 .25 L
Mistroke
.45365 .25 L
.45366 .25 L
.45366 .25 L
.45367 .25 L
.45367 .25 L
.45368 .25 L
.45369 .25 L
.45369 .25 L
.45369 .25 L
.4537 .25 L
.45371 .25 L
.45371 .25 L
.45372 .25 L
.45372 .25 L
.45373 .25 L
.45374 .25 L
.45374 .25 L
.45375 .25 L
.45375 .25 L
.45376 .25 L
.45376 .25 L
.45377 .25 L
.45377 .25 L
.45378 .25 L
.45379 .25 L
.45379 .25 L
.4538 .25 L
.4538 .25 L
.45381 .25 L
.45381 .25 L
.45382 .25 L
.45383 .25 L
.45383 .25 L
.45384 .25 L
.45385 .25 L
.45385 .25 L
.45386 .25 L
.45386 .25 L
.45387 .25 L
.45388 .25 L
.45388 .25 L
.45389 .25 L
.4539 .25 L
.4539 .25 L
.4539 .25 L
.45391 .25 L
.45391 .25 L
.45392 .25 L
.45392 .25 L
.45393 .25 L
Mistroke
.45394 .25 L
.45394 .25 L
.45395 .25 L
.45396 .25 L
.45396 .25 L
.45397 .25 L
.45398 .25 L
.45398 .25 L
.45399 .25 L
.45399 .25 L
.454 .25 L
.45401 .25 L
.45401 .25 L
.45402 .25 L
.45402 .25 L
.45403 .25 L
.45404 .25 L
.45404 .25 L
.45404 .25 L
.45405 .25 L
.45405 .25 L
.45406 .25 L
.45406 .25 L
.45406 .25 L
.45407 .25 L
.45407 .25 L
.45408 .25 L
.45408 .25 L
.45408 .25 L
.45409 .25 L
.45409 .25 L
.4541 .25 L
.45411 .25 L
.45411 .25 L
.45412 .25 L
.45413 .25 L
.45413 .25 L
.45414 .25 L
.45414 .25 L
.45415 .25 L
.45416 .25 L
.45416 .25 L
.45417 .25 L
.45418 .25 L
.45418 .25 L
.45419 .25 L
.45419 .25 L
.4542 .25 L
.4542 .25 L
.45421 .25 L
Mistroke
.45422 .25 L
.45422 .25 L
.45423 .25 L
.45423 .25 L
.45424 .25 L
.45425 .25 L
.45425 .25 L
.45426 .25 L
.45426 .25 L
.45427 .25 L
.45428 .25 L
.45428 .25 L
.45429 .25 L
.45429 .25 L
.4543 .25 L
.4543 .25 L
.45431 .25 L
.45432 .25 L
.45432 .25 L
.45433 .25 L
.45433 .25 L
.45434 .25 L
.45435 .25 L
.45435 .25 L
.45436 .25 L
.45437 .25 L
.45437 .25 L
.45438 .25 L
.45439 .25 L
.45439 .25 L
.45439 .25 L
.4544 .25 L
.45441 .25 L
.45441 .25 L
.45442 .25 L
.45443 .25 L
.45443 .25 L
.45444 .25 L
.45444 .25 L
.45445 .25 L
.45445 .25 L
.45446 .25 L
.45447 .25 L
.45447 .25 L
.45448 .25 L
.45448 .25 L
.45449 .25 L
.45449 .25 L
.4545 .25 L
.4545 .25 L
Mistroke
.45451 .25 L
.45451 .25 L
.45452 .25 L
.45452 .25 L
.45453 .25 L
.45454 .25 L
.45454 .25 L
.45455 .25 L
.45456 .25 L
.45456 .25 L
.45457 .25 L
.45457 .25 L
.45458 .25 L
.45458 .25 L
.45458 .25 L
.45459 .25 L
.4546 .25 L
.4546 .25 L
.45461 .25 L
.45462 .25 L
.45462 .25 L
.45463 .25 L
.45463 .25 L
.45464 .25 L
.45464 .25 L
.45465 .25 L
.45466 .25 L
.45466 .25 L
.45467 .25 L
.45468 .25 L
.45468 .25 L
.45469 .25 L
.45469 .25 L
.4547 .25 L
.45471 .25 L
.45471 .25 L
.45472 .25 L
.45472 .25 L
.45473 .25 L
.45473 .25 L
.45474 .25 L
.45474 .25 L
.45475 .25 L
.45475 .25 L
.45476 .25 L
.45477 .25 L
.45477 .25 L
.45478 .25 L
.45479 .25 L
.45479 .25 L
Mistroke
.4548 .25 L
.45481 .25 L
.45481 .25 L
.45482 .25 L
.45483 .25 L
.45483 .25 L
.45484 .25 L
.45484 .25 L
.45485 .25 L
.45485 .25 L
.45486 .25 L
.45486 .25 L
.45487 .25 L
.45487 .25 L
.45487 .25 L
.45488 .25 L
.45488 .25 L
.45489 .25 L
.45489 .25 L
.4549 .25 L
.4549 .25 L
.4549 .25 L
.45491 .25 L
.45491 .25 L
.45492 .25 L
.45492 .25 L
.45493 .25 L
.45494 .25 L
.45494 .25 L
.45495 .25 L
.45496 .25 L
.45496 .25 L
.45497 .25 L
.45497 .25 L
.45498 .25 L
.45499 .25 L
.45499 .25 L
.455 .25 L
.45501 .25 L
.45501 .25 L
.45501 .25 L
.45502 .25 L
.45503 .25 L
.45503 .25 L
.45504 .25 L
.45505 .25 L
.45505 .25 L
.45506 .25 L
.45506 .25 L
.45507 .25 L
Mistroke
.45507 .25 L
.45508 .25 L
.45509 .25 L
.45509 .25 L
.4551 .25 L
.45511 .25 L
.45511 .25 L
.45511 .25 L
.45512 .25 L
.45513 .25 L
.45513 .25 L
.45514 .25 L
.45515 .25 L
.45515 .25 L
.45516 .25 L
.45516 .25 L
.45517 .25 L
.45518 .25 L
.45518 .25 L
.45519 .25 L
.4552 .25 L
.4552 .25 L
.45521 .25 L
.45521 .25 L
.45522 .25 L
.45522 .25 L
.45523 .25 L
.45524 .25 L
.45524 .25 L
.45525 .25 L
.45525 .25 L
.45526 .25 L
.45527 .25 L
.45527 .25 L
.45528 .25 L
.45528 .25 L
.45529 .25 L
.4553 .25 L
.4553 .25 L
.45531 .25 L
.45531 .25 L
.45532 .25 L
.45532 .25 L
.45533 .25 L
.45533 .25 L
.45534 .25 L
.45534 .25 L
.45535 .25 L
.45535 .25 L
.45536 .25 L
Mistroke
.45537 .25 L
.45537 .25 L
.45538 .25 L
.45539 .25 L
.45539 .25 L
.45539 .25 L
.4554 .25 L
.4554 .25 L
.45541 .25 L
.45541 .25 L
.45542 .25 L
.45543 .25 L
.45543 .25 L
.45544 .25 L
.45544 .25 L
.45545 .25 L
.45546 .25 L
.45546 .25 L
.45547 .25 L
.45547 .25 L
.45548 .25 L
.45549 .25 L
.45549 .25 L
.4555 .25 L
.4555 .25 L
.45551 .25 L
.45552 .25 L
.45552 .25 L
.45553 .25 L
.45554 .25 L
.45554 .25 L
.45555 .25 L
.45555 .25 L
.45556 .25 L
.45556 .25 L
.45557 .25 L
.45557 .25 L
.45558 .25 L
.45559 .25 L
.45559 .25 L
.4556 .25 L
.4556 .25 L
.45561 .25 L
.45562 .25 L
.45562 .25 L
.45563 .25 L
.45564 .25 L
.45564 .25 L
.45565 .25 L
.45566 .25 L
Mistroke
.45566 .25 L
.45567 .25 L
.45567 .25 L
.45568 .25 L
.45568 .25 L
.45569 .25 L
.45569 .25 L
.45569 .25 L
.4557 .25 L
.4557 .25 L
.45571 .25 L
.45571 .25 L
.45571 .25 L
.45572 .25 L
.45572 .25 L
.45573 .25 L
.45573 .25 L
.45573 .25 L
.45574 .25 L
.45575 .25 L
.45575 .25 L
.45576 .25 L
.45577 .25 L
.45577 .25 L
.45578 .25 L
.45578 .25 L
.45579 .25 L
.4558 .25 L
.4558 .25 L
.45581 .25 L
.45582 .25 L
.45582 .25 L
.45583 .25 L
.45583 .25 L
.45584 .25 L
.45584 .25 L
.45585 .25 L
.45586 .25 L
.45586 .25 L
.45587 .25 L
.45588 .25 L
.45588 .25 L
.45589 .25 L
.45589 .25 L
.4559 .25 L
.4559 .25 L
.45591 .25 L
.45592 .25 L
.45592 .25 L
.45593 .25 L
Mistroke
.45593 .25 L
.45594 .25 L
.45594 .25 L
.45595 .25 L
.45596 .25 L
.45596 .25 L
.45597 .25 L
.45598 .25 L
.45598 .25 L
.45599 .25 L
.45599 .25 L
.456 .25 L
.45601 .25 L
.45601 .25 L
.45602 .25 L
.45603 .25 L
.45603 .25 L
.45604 .25 L
.45604 .25 L
.45605 .25 L
.45605 .25 L
.45606 .25 L
.45607 .25 L
.45607 .25 L
.45608 .25 L
.45608 .25 L
.45609 .25 L
.45609 .25 L
.4561 .25 L
.45611 .25 L
.45611 .25 L
.45612 .25 L
.45612 .25 L
.45613 .25 L
.45614 .25 L
.45614 .25 L
.45614 .25 L
.45615 .25 L
.45616 .25 L
.45616 .25 L
.45617 .25 L
.45618 .25 L
.45618 .25 L
.45619 .25 L
.4562 .25 L
.4562 .25 L
.45621 .25 L
.45622 .25 L
.45622 .25 L
.45623 .25 L
Mistroke
.45624 .25 L
.45624 .25 L
.45624 .25 L
.45625 .25 L
.45626 .25 L
.45626 .25 L
.45627 .25 L
.45627 .25 L
.45628 .25 L
.45629 .25 L
.45629 .25 L
.4563 .25 L
.4563 .25 L
.45631 .25 L
.45632 .25 L
.45632 .25 L
.45633 .25 L
.45633 .25 L
.45634 .25 L
.45634 .25 L
.45635 .25 L
.45635 .25 L
.45636 .25 L
.45636 .25 L
.45637 .25 L
.45637 .25 L
.45638 .25 L
.45639 .25 L
.45639 .25 L
.4564 .25 L
.4564 .25 L
.45641 .25 L
.45642 .25 L
.45642 .25 L
.45643 .25 L
.45643 .25 L
.45643 .25 L
.45644 .25 L
.45645 .25 L
.45645 .25 L
.45646 .25 L
.45646 .25 L
.45647 .25 L
.45648 .25 L
.45648 .25 L
.45649 .25 L
.45649 .25 L
.4565 .25 L
.45651 .25 L
.45651 .25 L
Mistroke
.45652 .25 L
.45652 .25 L
.45653 .25 L
.45654 .25 L
.45654 .25 L
.45655 .25 L
.45656 .25 L
.45656 .25 L
.45657 .25 L
.45657 .25 L
.45658 .25 L
.45658 .25 L
.45659 .25 L
.45659 .25 L
.4566 .25 L
.4566 .25 L
.45661 .25 L
.45662 .25 L
.45662 .25 L
.45663 .25 L
.45664 .25 L
.45664 .25 L
.45665 .25 L
.45666 .25 L
.45666 .25 L
.45667 .25 L
.45667 .25 L
.45668 .25 L
.45669 .25 L
.45669 .25 L
.4567 .25 L
.4567 .25 L
.45671 .25 L
.45671 .25 L
.45672 .25 L
.45672 .25 L
.45672 .25 L
.45673 .25 L
.45673 .25 L
.45674 .25 L
.45674 .25 L
.45675 .25 L
.45675 .25 L
.45675 .25 L
.45676 .25 L
.45676 .25 L
.45677 .25 L
.45677 .25 L
.45678 .25 L
.45679 .25 L
Mistroke
.45679 .25 L
.4568 .25 L
.45681 .25 L
.45681 .25 L
.45682 .25 L
.45682 .25 L
.45683 .25 L
.45684 .25 L
.45684 .25 L
.45685 .25 L
.45686 .25 L
.45686 .25 L
.45686 .25 L
.45687 .25 L
.45688 .25 L
.45688 .25 L
.45689 .25 L
.4569 .25 L
.4569 .25 L
.45691 .25 L
.45691 .25 L
.45692 .25 L
.45692 .25 L
.45693 .25 L
.45694 .25 L
.45694 .25 L
.45695 .25 L
.45696 .25 L
.45696 .25 L
.45696 .25 L
.45697 .25 L
.45698 .25 L
.45698 .25 L
.45699 .25 L
.457 .25 L
.457 .25 L
.45701 .25 L
.45701 .25 L
.45702 .25 L
.45703 .25 L
.45703 .25 L
.45704 .25 L
.45705 .25 L
.45705 .25 L
.45706 .25 L
.45706 .25 L
.45707 .25 L
.45707 .25 L
.45708 .25 L
.45709 .25 L
Mistroke
.45709 .25 L
.4571 .25 L
.4571 .25 L
.45711 .25 L
.45712 .25 L
.45712 .25 L
.45713 .25 L
.45713 .25 L
.45714 .25 L
.45715 .25 L
.45715 .25 L
.45716 .25 L
.45716 .25 L
.45717 .25 L
.45717 .25 L
.45718 .25 L
.45718 .25 L
.45719 .25 L
.45719 .25 L
.4572 .25 L
.4572 .25 L
.45721 .25 L
.45722 .25 L
.45722 .25 L
.45723 .25 L
.45724 .25 L
.45724 .25 L
.45724 .25 L
.45725 .25 L
.45725 .25 L
.45726 .25 L
.45726 .25 L
.45727 .25 L
.45728 .25 L
.45728 .25 L
.45729 .25 L
.45729 .25 L
.4573 .25 L
.45731 .25 L
.45731 .25 L
.45732 .25 L
.45732 .25 L
.45733 .25 L
.45734 .25 L
.45734 .25 L
.45735 .25 L
.45736 .25 L
.45736 .25 L
.45737 .25 L
.45737 .25 L
Mistroke
.45738 .25 L
.45739 .25 L
.45739 .25 L
.4574 .25 L
.4574 .25 L
.45741 .25 L
.45741 .25 L
.45742 .25 L
.45742 .25 L
.45743 .25 L
.45744 .25 L
.45744 .25 L
.45745 .25 L
.45745 .25 L
.45746 .25 L
.45747 .25 L
.45747 .25 L
.45748 .25 L
.45749 .25 L
.45749 .25 L
.4575 .25 L
.45751 .25 L
.45751 .25 L
.45752 .25 L
.45752 .25 L
.45753 .25 L
.45753 .25 L
.45754 .25 L
.45754 .25 L
.45754 .25 L
.45755 .25 L
.45755 .25 L
.45756 .25 L
.45756 .25 L
.45757 .25 L
.45757 .25 L
.45757 .25 L
.45758 .25 L
.45758 .25 L
.45758 .25 L
.45759 .25 L
.4576 .25 L
.4576 .25 L
.45761 .25 L
.45762 .25 L
.45762 .25 L
.45763 .25 L
.45764 .25 L
.45764 .25 L
.45765 .25 L
Mistroke
.45765 .25 L
.45766 .25 L
.45767 .25 L
.45767 .25 L
.45768 .25 L
.45768 .25 L
.45769 .25 L
.4577 .25 L
.4577 .25 L
.45771 .25 L
.45771 .25 L
.45772 .25 L
.45773 .25 L
.45773 .25 L
.45774 .25 L
.45774 .25 L
.45775 .25 L
.45775 .25 L
.45776 .25 L
.45777 .25 L
.45777 .25 L
.45778 .25 L
.45778 .25 L
.45779 .25 L
.45779 .25 L
.4578 .25 L
.45781 .25 L
.45781 .25 L
.45782 .25 L
.45783 .25 L
.45783 .25 L
.45784 .25 L
.45784 .25 L
.45785 .25 L
.45786 .25 L
.45786 .25 L
.45787 .25 L
.45788 .25 L
.45788 .25 L
.45789 .25 L
.45789 .25 L
.4579 .25 L
.4579 .25 L
.45791 .25 L
.45792 .25 L
.45792 .25 L
.45793 .25 L
.45793 .25 L
.45794 .25 L
.45795 .25 L
Mistroke
.45795 .25 L
.45796 .25 L
.45796 .25 L
.45797 .25 L
.45798 .25 L
.45798 .25 L
.45799 .25 L
.45799 .25 L
.458 .25 L
.458 .25 L
.45801 .25 L
.45801 .25 L
.45802 .25 L
.45802 .25 L
.45803 .25 L
.45803 .25 L
.45804 .25 L
.45805 .25 L
.45805 .25 L
.45806 .25 L
.45806 .25 L
.45807 .25 L
.45807 .25 L
.45808 .25 L
.45808 .25 L
.45809 .25 L
.45809 .25 L
.4581 .25 L
.45811 .25 L
.45811 .25 L
.45812 .25 L
.45812 .25 L
.45813 .25 L
.45814 .25 L
.45814 .25 L
.45815 .25 L
.45815 .25 L
.45816 .25 L
.45817 .25 L
.45817 .25 L
.45818 .25 L
.45819 .25 L
.45819 .25 L
.4582 .25 L
.4582 .25 L
.45821 .25 L
.45822 .25 L
.45822 .25 L
.45823 .25 L
.45823 .25 L
Mistroke
.45823 .25 L
.45824 .25 L
.45825 .25 L
.45825 .25 L
.45826 .25 L
.45827 .25 L
.45827 .25 L
.45828 .25 L
.45828 .25 L
.45829 .25 L
.4583 .25 L
.4583 .25 L
.45831 .25 L
.45832 .25 L
.45832 .25 L
.45833 .25 L
.45834 .25 L
.45834 .25 L
.45835 .25 L
.45835 .25 L
.45836 .25 L
.45836 .25 L
.45836 .25 L
.45837 .25 L
.45837 .25 L
.45838 .25 L
.45838 .25 L
.45839 .25 L
.45839 .25 L
.45839 .25 L
.4584 .25 L
.4584 .25 L
.4584 .25 L
.45841 .25 L
.45841 .25 L
.45842 .25 L
.45843 .25 L
.45843 .25 L
.45844 .25 L
.45845 .25 L
.45845 .25 L
.45846 .25 L
.45847 .25 L
.45847 .25 L
.45848 .25 L
.45848 .25 L
.45849 .25 L
.4585 .25 L
.4585 .25 L
.45851 .25 L
Mistroke
.45851 .25 L
.45852 .25 L
.45853 .25 L
.45853 .25 L
.45854 .25 L
.45854 .25 L
.45855 .25 L
.45856 .25 L
.45856 .25 L
.45857 .25 L
.45857 .25 L
.45858 .25 L
.45858 .25 L
.45859 .25 L
.4586 .25 L
.4586 .25 L
.45861 .25 L
.45861 .25 L
.45862 .25 L
.45862 .25 L
.45863 .25 L
.45864 .25 L
.45864 .25 L
.45865 .25 L
.45866 .25 L
.45866 .25 L
.45867 .25 L
.45867 .25 L
.45868 .25 L
.45869 .25 L
.45869 .25 L
.4587 .25 L
.45871 .25 L
.45871 .25 L
.45871 .25 L
.45872 .25 L
.45873 .25 L
.45873 .25 L
.45874 .25 L
.45875 .25 L
.45875 .25 L
.45876 .25 L
.45876 .25 L
.45877 .25 L
.45877 .25 L
.45878 .25 L
.45879 .25 L
.45879 .25 L
.4588 .25 L
.45881 .25 L
Mistroke
.45881 .25 L
.45881 .25 L
.45882 .25 L
.45883 .25 L
.45883 .25 L
.45884 .25 L
.45884 .25 L
.45885 .25 L
.45885 .25 L
.45886 .25 L
.45886 .25 L
.45887 .25 L
.45888 .25 L
.45888 .25 L
.45889 .25 L
.45889 .25 L
.4589 .25 L
.4589 .25 L
.4589 .25 L
.45891 .25 L
.45892 .25 L
.45892 .25 L
.45893 .25 L
.45894 .25 L
.45894 .25 L
.45895 .25 L
.45895 .25 L
.45896 .25 L
.45897 .25 L
.45897 .25 L
.45898 .25 L
.45898 .25 L
.45899 .25 L
.459 .25 L
.459 .25 L
.45901 .25 L
.45902 .25 L
.45902 .25 L
.45903 .25 L
.45904 .25 L
.45904 .25 L
.45905 .25 L
.45905 .25 L
.45905 .25 L
.45906 .25 L
.45906 .25 L
.45907 .25 L
.45908 .25 L
.45908 .25 L
.45909 .25 L
Mistroke
.4591 .25 L
.4591 .25 L
.45911 .25 L
.45911 .25 L
.45912 .25 L
.45913 .25 L
.45913 .25 L
.45914 .25 L
.45915 .25 L
.45915 .25 L
.45916 .25 L
.45917 .25 L
.45917 .25 L
.45917 .25 L
.45918 .25 L
.45918 .25 L
.45919 .25 L
.45919 .25 L
.45919 .25 L
.4592 .25 L
.45921 .25 L
.45921 .25 L
.45921 .25 L
.45922 .25 L
.45922 .25 L
.45922 .25 L
.45923 .25 L
.45923 .25 L
.45924 .25 L
.45924 .25 L
.45925 .25 L
.45926 .25 L
.45926 .25 L
.45927 .25 L
.45928 .25 L
.45928 .25 L
.45929 .25 L
.45929 .25 L
.4593 .25 L
.45931 .25 L
.45931 .25 L
.45932 .25 L
.45933 .25 L
.45933 .25 L
.45934 .25 L
.45934 .25 L
.45935 .25 L
.45935 .25 L
.45936 .25 L
.45937 .25 L
Mistroke
.45937 .25 L
.45938 .25 L
.45938 .25 L
.45939 .25 L
.4594 .25 L
.4594 .25 L
.45941 .25 L
.45941 .25 L
.45942 .25 L
.45943 .25 L
.45943 .25 L
.45943 .25 L
.45944 .25 L
.45945 .25 L
.45945 .25 L
.45946 .25 L
.45947 .25 L
.45947 .25 L
.45948 .25 L
.45948 .25 L
.45949 .25 L
.4595 .25 L
.4595 .25 L
.45951 .25 L
.45952 .25 L
.45952 .25 L
.45953 .25 L
.45953 .25 L
.45954 .25 L
.45954 .25 L
.45955 .25 L
.45956 .25 L
.45956 .25 L
.45957 .25 L
.45958 .25 L
.45958 .25 L
.45959 .25 L
.45959 .25 L
.4596 .25 L
.4596 .25 L
.45961 .25 L
.45962 .25 L
.45962 .25 L
.45963 .25 L
.45963 .25 L
.45964 .25 L
.45964 .25 L
.45965 .25 L
.45966 .25 L
.45966 .25 L
Mistroke
.45967 .25 L
.45968 .25 L
.45968 .25 L
.45969 .25 L
.45969 .25 L
.4597 .25 L
.45971 .25 L
.45971 .25 L
.45972 .25 L
.45973 .25 L
.45973 .25 L
.45974 .25 L
.45974 .25 L
.45975 .25 L
.45975 .25 L
.45976 .25 L
.45977 .25 L
.45977 .25 L
.45978 .25 L
.45978 .25 L
.45979 .25 L
.45979 .25 L
.4598 .25 L
.45981 .25 L
.45981 .25 L
.45982 .25 L
.45983 .25 L
.45983 .25 L
.45984 .25 L
.45984 .25 L
.45985 .25 L
.45985 .25 L
.45986 .25 L
.45986 .25 L
.45987 .25 L
.45987 .25 L
.45988 .25 L
.45988 .25 L
.45989 .25 L
.4599 .25 L
.4599 .25 L
.45991 .25 L
.45991 .25 L
.45992 .25 L
.45992 .25 L
.45993 .25 L
.45993 .25 L
.45994 .25 L
.45994 .25 L
.45995 .25 L
Mistroke
.45996 .25 L
.45996 .25 L
.45997 .25 L
.45997 .25 L
.45998 .25 L
.45999 .25 L
.45999 .25 L
.46 .25 L
.46 .25 L
.46001 .25 L
.46002 .25 L
.46002 .25 L
.46003 .25 L
.46004 .25 L
.46004 .25 L
.46005 .25 L
.46005 .25 L
.46006 .25 L
.46007 .25 L
.46007 .25 L
.46008 .25 L
.46008 .25 L
.46008 .25 L
.46009 .25 L
.4601 .25 L
.4601 .25 L
.46011 .25 L
.46012 .25 L
.46012 .25 L
.46013 .25 L
.46013 .25 L
.46014 .25 L
.46015 .25 L
.46015 .25 L
.46016 .25 L
.46017 .25 L
.46017 .25 L
.46018 .25 L
.46018 .25 L
.46019 .25 L
.4602 .25 L
.4602 .25 L
.46021 .25 L
.46021 .25 L
.46021 .25 L
.46022 .25 L
.46022 .25 L
.46023 .25 L
.46023 .25 L
.46024 .25 L
Mistroke
.46024 .25 L
.46024 .25 L
.46025 .25 L
.46025 .25 L
.46025 .25 L
.46026 .25 L
.46026 .25 L
.46027 .25 L
.46028 .25 L
.46028 .25 L
.46029 .25 L
.4603 .25 L
.4603 .25 L
.46031 .25 L
.46032 .25 L
.46032 .25 L
.46033 .25 L
.46033 .25 L
.46034 .25 L
.46035 .25 L
.46035 .25 L
.46036 .25 L
.46036 .25 L
.46037 .25 L
.46038 .25 L
.46038 .25 L
.46039 .25 L
.46039 .25 L
.4604 .25 L
.46041 .25 L
.46041 .25 L
.46042 .25 L
.46042 .25 L
.46043 .25 L
.46043 .25 L
.46044 .25 L
.46045 .25 L
.46045 .25 L
.46046 .25 L
.46046 .25 L
.46047 .25 L
.46047 .25 L
.46048 .25 L
.46049 .25 L
.46049 .25 L
.4605 .25 L
.46051 .25 L
.46051 .25 L
.46052 .25 L
.46052 .25 L
Mistroke
.46053 .25 L
.46054 .25 L
.46054 .25 L
.46055 .25 L
.46056 .25 L
.46056 .25 L
.46056 .25 L
.46057 .25 L
.46058 .25 L
.46058 .25 L
.46059 .25 L
.4606 .25 L
.4606 .25 L
.46061 .25 L
.46061 .25 L
.46062 .25 L
.46062 .25 L
.46063 .25 L
.46064 .25 L
.46064 .25 L
.46065 .25 L
.46066 .25 L
.46066 .25 L
.46066 .25 L
.46067 .25 L
.46068 .25 L
.46068 .25 L
.46069 .25 L
.46069 .25 L
.4607 .25 L
.4607 .25 L
.46071 .25 L
.46071 .25 L
.46072 .25 L
.46073 .25 L
.46073 .25 L
.46074 .25 L
.46074 .25 L
.46075 .25 L
.46075 .25 L
.46075 .25 L
.46076 .25 L
.46077 .25 L
.46077 .25 L
.46078 .25 L
.46079 .25 L
.46079 .25 L
.4608 .25 L
.4608 .25 L
.46081 .25 L
Mistroke
.46082 .25 L
.46082 .25 L
.46083 .25 L
.46083 .25 L
.46084 .25 L
.46085 .25 L
.46085 .25 L
.46086 .25 L
.46087 .25 L
.46087 .25 L
.46088 .25 L
.46089 .25 L
.46089 .25 L
.4609 .25 L
.4609 .25 L
.4609 .25 L
.46091 .25 L
.46091 .25 L
.46092 .25 L
.46093 .25 L
.46093 .25 L
.46094 .25 L
.46095 .25 L
.46095 .25 L
.46096 .25 L
.46096 .25 L
.46097 .25 L
.46098 .25 L
.46098 .25 L
.46099 .25 L
.461 .25 L
.461 .25 L
.46101 .25 L
.46102 .25 L
.46102 .25 L
.46102 .25 L
.46103 .25 L
.46103 .25 L
.46104 .25 L
.46104 .25 L
.46104 .25 L
.46105 .25 L
.46106 .25 L
.46106 .25 L
.46106 .25 L
.46107 .25 L
.46107 .25 L
.46107 .25 L
.46108 .25 L
.46108 .25 L
Mistroke
.46109 .25 L
.46109 .25 L
.4611 .25 L
.46111 .25 L
.46112 .25 L
.46112 .25 L
.46113 .25 L
.46113 .25 L
.46114 .25 L
.46115 .25 L
.46115 .25 L
.46116 .25 L
.46116 .25 L
.46117 .25 L
.46118 .25 L
.46118 .25 L
.46119 .25 L
.46119 .25 L
.4612 .25 L
.46121 .25 L
.46121 .25 L
.46122 .25 L
.46122 .25 L
.46123 .25 L
.46123 .25 L
.46124 .25 L
.46125 .25 L
.46125 .25 L
.46126 .25 L
.46127 .25 L
.46127 .25 L
.46128 .25 L
.46128 .25 L
.46128 .25 L
.46129 .25 L
.4613 .25 L
.4613 .25 L
.46131 .25 L
.46132 .25 L
.46132 .25 L
.46133 .25 L
.46134 .25 L
.46134 .25 L
.46135 .25 L
.46135 .25 L
.46136 .25 L
.46137 .25 L
.46137 .25 L
.46138 .25 L
.46138 .25 L
Mistroke
.46139 .25 L
.4614 .25 L
.4614 .25 L
.46141 .25 L
.46141 .25 L
.46142 .25 L
.46143 .25 L
.46143 .25 L
.46144 .25 L
.46144 .25 L
.46145 .25 L
.46145 .25 L
.46146 .25 L
.46147 .25 L
.46147 .25 L
.46148 .25 L
.46148 .25 L
.46149 .25 L
.46149 .25 L
.4615 .25 L
.46151 .25 L
.46151 .25 L
.46151 .25 L
.46152 .25 L
.46153 .25 L
.46153 .25 L
.46154 .25 L
.46154 .25 L
.46155 .25 L
.46156 .25 L
.46156 .25 L
.46156 .25 L
.46157 .25 L
.46158 .25 L
.46158 .25 L
.46159 .25 L
.46159 .25 L
.4616 .25 L
.4616 .25 L
.46161 .25 L
.46162 .25 L
.46162 .25 L
.46163 .25 L
.46163 .25 L
.46164 .25 L
.46165 .25 L
.46165 .25 L
.46166 .25 L
.46166 .25 L
.46167 .25 L
Mistroke
.46168 .25 L
.46168 .25 L
.46169 .25 L
.4617 .25 L
.4617 .25 L
.46171 .25 L
.46172 .25 L
.46172 .25 L
.46172 .25 L
.46173 .25 L
.46173 .25 L
.46174 .25 L
.46174 .25 L
.46175 .25 L
.46176 .25 L
.46176 .25 L
.46177 .25 L
.46178 .25 L
.46178 .25 L
.46179 .25 L
.46179 .25 L
.4618 .25 L
.46181 .25 L
.46181 .25 L
.46182 .25 L
.46183 .25 L
.46183 .25 L
.46184 .25 L
.46184 .25 L
.46185 .25 L
.46185 .25 L
.46186 .25 L
.46186 .25 L
.46186 .25 L
.46187 .25 L
.46188 .25 L
.46188 .25 L
.46188 .25 L
.46189 .25 L
.46189 .25 L
.46189 .25 L
.4619 .25 L
.4619 .25 L
.46191 .25 L
.46191 .25 L
.46192 .25 L
.46193 .25 L
.46193 .25 L
.46194 .25 L
.46195 .25 L
Mistroke
.46195 .25 L
.46196 .25 L
.46196 .25 L
.46197 .25 L
.46198 .25 L
.46198 .25 L
.46199 .25 L
.462 .25 L
.462 .25 L
.46201 .25 L
.46201 .25 L
.46202 .25 L
.46202 .25 L
.46203 .25 L
.46203 .25 L
.46204 .25 L
.46205 .25 L
.46205 .25 L
.46206 .25 L
.46206 .25 L
.46207 .25 L
.46208 .25 L
.46208 .25 L
.46209 .25 L
.46209 .25 L
.4621 .25 L
.4621 .25 L
.46211 .25 L
.46211 .25 L
.46212 .25 L
.46213 .25 L
.46213 .25 L
.46214 .25 L
.46215 .25 L
.46215 .25 L
.46216 .25 L
.46217 .25 L
.46217 .25 L
.46218 .25 L
.46218 .25 L
.46219 .25 L
.4622 .25 L
.4622 .25 L
.46221 .25 L
.46221 .25 L
.46222 .25 L
.46223 .25 L
.46223 .25 L
.46224 .25 L
.46224 .25 L
Mistroke
.46225 .25 L
.46226 .25 L
.46226 .25 L
.46227 .25 L
.46227 .25 L
.46228 .25 L
.46229 .25 L
.46229 .25 L
.4623 .25 L
.4623 .25 L
.46231 .25 L
.46231 .25 L
.46232 .25 L
.46232 .25 L
.46233 .25 L
.46233 .25 L
.46234 .25 L
.46234 .25 L
.46235 .25 L
.46236 .25 L
.46236 .25 L
.46237 .25 L
.46237 .25 L
.46238 .25 L
.46238 .25 L
.46239 .25 L
.46239 .25 L
.4624 .25 L
.4624 .25 L
.46241 .25 L
.46242 .25 L
.46242 .25 L
.46243 .25 L
.46243 .25 L
.46244 .25 L
.46245 .25 L
.46245 .25 L
.46246 .25 L
.46246 .25 L
.46247 .25 L
.46248 .25 L
.46248 .25 L
.46249 .25 L
.46249 .25 L
.4625 .25 L
.46251 .25 L
.46251 .25 L
.46252 .25 L
.46253 .25 L
.46253 .25 L
Mistroke
.46254 .25 L
.46254 .25 L
.46255 .25 L
.46255 .25 L
.46255 .25 L
.46256 .25 L
.46257 .25 L
.46257 .25 L
.46258 .25 L
.46259 .25 L
.46259 .25 L
.4626 .25 L
.4626 .25 L
.46261 .25 L
.46262 .25 L
.46262 .25 L
.46263 .25 L
.46264 .25 L
.46264 .25 L
.46265 .25 L
.46266 .25 L
.46266 .25 L
.46267 .25 L
.46267 .25 L
.46268 .25 L
.46268 .25 L
.46268 .25 L
.46269 .25 L
.46269 .25 L
.4627 .25 L
.4627 .25 L
.46271 .25 L
.46271 .25 L
.46271 .25 L
.46272 .25 L
.46272 .25 L
.46273 .25 L
.46273 .25 L
.46274 .25 L
.46274 .25 L
.46275 .25 L
.46276 .25 L
.46276 .25 L
.46277 .25 L
.46277 .25 L
.46278 .25 L
.46279 .25 L
.46279 .25 L
.4628 .25 L
.46281 .25 L
Mistroke
.46281 .25 L
.46282 .25 L
.46283 .25 L
.46283 .25 L
.46283 .25 L
.46284 .25 L
.46285 .25 L
.46285 .25 L
.46286 .25 L
.46286 .25 L
.46287 .25 L
.46288 .25 L
.46288 .25 L
.46289 .25 L
.46289 .25 L
.4629 .25 L
.46291 .25 L
.46291 .25 L
.46292 .25 L
.46292 .25 L
.46293 .25 L
.46293 .25 L
.46294 .25 L
.46294 .25 L
.46295 .25 L
.46296 .25 L
.46296 .25 L
.46297 .25 L
.46298 .25 L
.46298 .25 L
.46299 .25 L
.46299 .25 L
.463 .25 L
.46301 .25 L
.46301 .25 L
.46302 .25 L
.46303 .25 L
.46303 .25 L
.46304 .25 L
.46304 .25 L
.46305 .25 L
.46305 .25 L
.46306 .25 L
.46307 .25 L
.46307 .25 L
.46308 .25 L
.46308 .25 L
.46309 .25 L
.4631 .25 L
.4631 .25 L
Mistroke
.46311 .25 L
.46311 .25 L
.46312 .25 L
.46313 .25 L
.46313 .25 L
.46313 .25 L
.46314 .25 L
.46315 .25 L
.46315 .25 L
.46316 .25 L
.46317 .25 L
.46317 .25 L
.46318 .25 L
.46318 .25 L
.46319 .25 L
.4632 .25 L
.4632 .25 L
.46321 .25 L
.46322 .25 L
.46322 .25 L
.46323 .25 L
.46323 .25 L
.46324 .25 L
.46324 .25 L
.46325 .25 L
.46326 .25 L
.46326 .25 L
.46327 .25 L
.46328 .25 L
.46328 .25 L
.46329 .25 L
.46329 .25 L
.4633 .25 L
.4633 .25 L
.46331 .25 L
.46332 .25 L
.46332 .25 L
.46333 .25 L
.46333 .25 L
.46334 .25 L
.46334 .25 L
.46335 .25 L
.46336 .25 L
.46336 .25 L
.46336 .25 L
.46337 .25 L
.46338 .25 L
.46338 .25 L
.46339 .25 L
.46339 .25 L
Mistroke
.4634 .25 L
.46341 .25 L
.46341 .25 L
.46341 .25 L
.46342 .25 L
.46342 .25 L
.46343 .25 L
.46343 .25 L
.46344 .25 L
.46345 .25 L
.46345 .25 L
.46346 .25 L
.46347 .25 L
.46347 .25 L
.46348 .25 L
.46348 .25 L
.46349 .25 L
.4635 .25 L
.4635 .25 L
.46351 .25 L
.46351 .25 L
.46352 .25 L
.46353 .25 L
.46353 .25 L
.46354 .25 L
.46355 .25 L
.46355 .25 L
.46356 .25 L
.46357 .25 L
.46357 .25 L
.46357 .25 L
.46358 .25 L
.46358 .25 L
.46359 .25 L
.46359 .25 L
.4636 .25 L
.46361 .25 L
.46361 .25 L
.46362 .25 L
.46363 .25 L
.46363 .25 L
.46364 .25 L
.46364 .25 L
.46365 .25 L
.46366 .25 L
.46366 .25 L
.46367 .25 L
.46368 .25 L
.46368 .25 L
.46369 .25 L
Mistroke
.46369 .25 L
.4637 .25 L
.4637 .25 L
.46371 .25 L
.46371 .25 L
.46371 .25 L
.46372 .25 L
.46373 .25 L
.46373 .25 L
.46373 .25 L
.46374 .25 L
.46374 .25 L
.46374 .25 L
.46375 .25 L
.46375 .25 L
.46376 .25 L
.46376 .25 L
.46377 .25 L
.46378 .25 L
.46378 .25 L
.46379 .25 L
.4638 .25 L
.4638 .25 L
.46381 .25 L
.46381 .25 L
.46382 .25 L
.46383 .25 L
.46383 .25 L
.46384 .25 L
.46385 .25 L
.46385 .25 L
.46386 .25 L
.46386 .25 L
.46387 .25 L
.46387 .25 L
.46388 .25 L
.46389 .25 L
.46389 .25 L
.4639 .25 L
.4639 .25 L
.46391 .25 L
.46391 .25 L
.46392 .25 L
.46393 .25 L
.46393 .25 L
.46394 .25 L
.46394 .25 L
.46395 .25 L
.46395 .25 L
.46396 .25 L
Mistroke
.46396 .25 L
.46397 .25 L
.46398 .25 L
.46398 .25 L
.46399 .25 L
.464 .25 L
.464 .25 L
.46401 .25 L
.46402 .25 L
.46402 .25 L
.46403 .25 L
.46404 .25 L
.46404 .25 L
.46405 .25 L
.46405 .25 L
.46406 .25 L
.46406 .25 L
.46407 .25 L
.46408 .25 L
.46408 .25 L
.46409 .25 L
.46409 .25 L
.4641 .25 L
.46411 .25 L
.46411 .25 L
.46412 .25 L
.46412 .25 L
.46413 .25 L
.46414 .25 L
.46414 .25 L
.46415 .25 L
.46415 .25 L
.46416 .25 L
.46416 .25 L
.46417 .25 L
.46417 .25 L
.46418 .25 L
.46418 .25 L
.46419 .25 L
.46419 .25 L
.4642 .25 L
.46421 .25 L
.46421 .25 L
.46422 .25 L
.46422 .25 L
.46423 .25 L
.46423 .25 L
.46424 .25 L
.46425 .25 L
.46425 .25 L
Mistroke
.46425 .25 L
.46426 .25 L
.46427 .25 L
.46427 .25 L
.46428 .25 L
.46428 .25 L
.46429 .25 L
.4643 .25 L
.4643 .25 L
.46431 .25 L
.46431 .25 L
.46432 .25 L
.46433 .25 L
.46433 .25 L
.46434 .25 L
.46434 .25 L
.46435 .25 L
.46436 .25 L
.46436 .25 L
.46437 .25 L
.46438 .25 L
.46438 .25 L
.46439 .25 L
.46439 .25 L
.4644 .25 L
.4644 .25 L
.4644 .25 L
.46441 .25 L
.46442 .25 L
.46442 .25 L
.46443 .25 L
.46444 .25 L
.46444 .25 L
.46445 .25 L
.46446 .25 L
.46446 .25 L
.46447 .25 L
.46448 .25 L
.46448 .25 L
.46449 .25 L
.46449 .25 L
.4645 .25 L
.46451 .25 L
.46451 .25 L
.46452 .25 L
.46452 .25 L
.46453 .25 L
.46453 .25 L
.46454 .25 L
.46454 .25 L
Mistroke
.46454 .25 L
.46455 .25 L
.46455 .25 L
.46456 .25 L
.46456 .25 L
.46457 .25 L
.46457 .25 L
.46457 .25 L
.46458 .25 L
.46458 .25 L
.46459 .25 L
.46459 .25 L
.4646 .25 L
.46461 .25 L
.46461 .25 L
.46462 .25 L
.46463 .25 L
.46463 .25 L
.46464 .25 L
.46464 .25 L
.46465 .25 L
.46466 .25 L
.46466 .25 L
.46467 .25 L
.46468 .25 L
.46468 .25 L
.46468 .25 L
.46469 .25 L
.4647 .25 L
.4647 .25 L
.46471 .25 L
.46472 .25 L
.46472 .25 L
.46473 .25 L
.46473 .25 L
.46474 .25 L
.46474 .25 L
.46475 .25 L
.46476 .25 L
.46476 .25 L
.46477 .25 L
.46478 .25 L
.46478 .25 L
.46478 .25 L
.46479 .25 L
.4648 .25 L
.4648 .25 L
.46481 .25 L
.46482 .25 L
.46482 .25 L
Mistroke
.46483 .25 L
.46483 .25 L
.46484 .25 L
.46485 .25 L
.46485 .25 L
.46486 .25 L
.46487 .25 L
.46487 .25 L
.46488 .25 L
.46488 .25 L
.46489 .25 L
.46489 .25 L
.4649 .25 L
.46491 .25 L
.46491 .25 L
.46492 .25 L
.46492 .25 L
.46493 .25 L
.46494 .25 L
.46494 .25 L
.46495 .25 L
.46495 .25 L
.46496 .25 L
.46497 .25 L
.46497 .25 L
.46498 .25 L
.46498 .25 L
.46498 .25 L
.46499 .25 L
.465 .25 L
.465 .25 L
.46501 .25 L
.46501 .25 L
.46502 .25 L
.46502 .25 L
.46503 .25 L
.46504 .25 L
.46504 .25 L
.46505 .25 L
.46505 .25 L
.46506 .25 L
.46506 .25 L
.46507 .25 L
.46507 .25 L
.46508 .25 L
.46508 .25 L
.46509 .25 L
.4651 .25 L
.4651 .25 L
.46511 .25 L
Mistroke
.46511 .25 L
.46512 .25 L
.46513 .25 L
.46513 .25 L
.46514 .25 L
.46514 .25 L
.46515 .25 L
.46516 .25 L
.46516 .25 L
.46517 .25 L
.46517 .25 L
.46518 .25 L
.46519 .25 L
.46519 .25 L
.4652 .25 L
.46521 .25 L
.46521 .25 L
.46522 .25 L
.46522 .25 L
.46522 .25 L
.46523 .25 L
.46524 .25 L
.46524 .25 L
.46525 .25 L
.46526 .25 L
.46526 .25 L
.46527 .25 L
.46527 .25 L
.46528 .25 L
.46529 .25 L
.46529 .25 L
.4653 .25 L
.4653 .25 L
.46531 .25 L
.46532 .25 L
.46532 .25 L
.46533 .25 L
.46534 .25 L
.46534 .25 L
.46535 .25 L
.46535 .25 L
.46536 .25 L
.46536 .25 L
.46536 .25 L
.46537 .25 L
.46537 .25 L
.46538 .25 L
.46538 .25 L
.46538 .25 L
.46539 .25 L
Mistroke
.46539 .25 L
.4654 .25 L
.4654 .25 L
.4654 .25 L
.46541 .25 L
.46542 .25 L
.46542 .25 L
.46543 .25 L
.46544 .25 L
.46544 .25 L
.46545 .25 L
.46545 .25 L
.46546 .25 L
.46547 .25 L
.46547 .25 L
.46548 .25 L
.46549 .25 L
.46549 .25 L
.4655 .25 L
.4655 .25 L
.46551 .25 L
.46551 .25 L
.46552 .25 L
.46553 .25 L
.46553 .25 L
.46554 .25 L
.46555 .25 L
.46555 .25 L
.46556 .25 L
.46556 .25 L
.46557 .25 L
.46557 .25 L
.46558 .25 L
.46559 .25 L
.46559 .25 L
.4656 .25 L
.4656 .25 L
.46561 .25 L
.46561 .25 L
.46562 .25 L
.46563 .25 L
.46563 .25 L
.46564 .25 L
.46565 .25 L
.46565 .25 L
.46566 .25 L
.46566 .25 L
.46567 .25 L
.46568 .25 L
.46568 .25 L
Mistroke
.46569 .25 L
.4657 .25 L
.4657 .25 L
.46571 .25 L
.46571 .25 L
.46572 .25 L
.46572 .25 L
.46573 .25 L
.46574 .25 L
.46574 .25 L
.46575 .25 L
.46575 .25 L
.46576 .25 L
.46576 .25 L
.46577 .25 L
.46578 .25 L
.46578 .25 L
.46579 .25 L
.46579 .25 L
.4658 .25 L
.46581 .25 L
.46581 .25 L
.46581 .25 L
.46582 .25 L
.46583 .25 L
.46583 .25 L
.46584 .25 L
.46584 .25 L
.46585 .25 L
.46585 .25 L
.46586 .25 L
.46587 .25 L
.46587 .25 L
.46588 .25 L
.46588 .25 L
.46589 .25 L
.46589 .25 L
.4659 .25 L
.4659 .25 L
.46591 .25 L
.46591 .25 L
.46592 .25 L
.46593 .25 L
.46593 .25 L
.46594 .25 L
.46594 .25 L
.46595 .25 L
.46596 .25 L
.46596 .25 L
.46597 .25 L
Mistroke
.46597 .25 L
.46598 .25 L
.46599 .25 L
.46599 .25 L
.466 .25 L
.466 .25 L
.46601 .25 L
.46602 .25 L
.46602 .25 L
.46603 .25 L
.46604 .25 L
.46604 .25 L
.46604 .25 L
.46605 .25 L
.46605 .25 L
.46606 .25 L
.46607 .25 L
.46607 .25 L
.46608 .25 L
.46608 .25 L
.46609 .25 L
.4661 .25 L
.4661 .25 L
.46611 .25 L
.46612 .25 L
.46612 .25 L
.46613 .25 L
.46614 .25 L
.46614 .25 L
.46615 .25 L
.46615 .25 L
.46616 .25 L
.46617 .25 L
.46617 .25 L
.46618 .25 L
.46618 .25 L
.46618 .25 L
.46619 .25 L
.46619 .25 L
.4662 .25 L
.4662 .25 L
.4662 .25 L
.46621 .25 L
.46621 .25 L
.46622 .25 L
.46622 .25 L
.46622 .25 L
.46623 .25 L
.46623 .25 L
.46624 .25 L
Mistroke
.46625 .25 L
.46625 .25 L
.46626 .25 L
.46627 .25 L
.46627 .25 L
.46628 .25 L
.46628 .25 L
.46629 .25 L
.4663 .25 L
.4663 .25 L
.46631 .25 L
.46632 .25 L
.46632 .25 L
.46633 .25 L
.46633 .25 L
.46634 .25 L
.46634 .25 L
.46635 .25 L
.46636 .25 L
.46636 .25 L
.46637 .25 L
.46637 .25 L
.46638 .25 L
.46639 .25 L
.46639 .25 L
.4664 .25 L
.4664 .25 L
.46641 .25 L
.46642 .25 L
.46642 .25 L
.46643 .25 L
.46643 .25 L
.46644 .25 L
.46644 .25 L
.46645 .25 L
.46646 .25 L
.46646 .25 L
.46647 .25 L
.46647 .25 L
.46648 .25 L
.46649 .25 L
.46649 .25 L
.4665 .25 L
.46651 .25 L
.46651 .25 L
.46652 .25 L
.46653 .25 L
.46653 .25 L
.46653 .25 L
.46654 .25 L
Mistroke
.46655 .25 L
.46655 .25 L
.46656 .25 L
.46657 .25 L
.46657 .25 L
.46658 .25 L
.46658 .25 L
.46659 .25 L
.46659 .25 L
.4666 .25 L
.46661 .25 L
.46661 .25 L
.46662 .25 L
.46662 .25 L
.46663 .25 L
.46663 .25 L
.46664 .25 L
.46664 .25 L
.46665 .25 L
.46666 .25 L
.46666 .25 L
.46666 .25 L
.46667 .25 L
.46668 .25 L
.46668 .25 L
.46669 .25 L
.4667 .25 L
.4667 .25 L
.46671 .25 L
.46671 .25 L
.46672 .25 L
.46672 .25 L
.46672 .25 L
.46673 .25 L
.46674 .25 L
.46674 .25 L
.46675 .25 L
.46676 .25 L
.46676 .25 L
.46677 .25 L
.46677 .25 L
.46678 .25 L
.46679 .25 L
.46679 .25 L
.4668 .25 L
.4668 .25 L
.46681 .25 L
.46682 .25 L
.46682 .25 L
.46683 .25 L
Mistroke
.46684 .25 L
.46684 .25 L
.46685 .25 L
.46685 .25 L
.46686 .25 L
.46686 .25 L
.46687 .25 L
.46687 .25 L
.46688 .25 L
.46688 .25 L
.46689 .25 L
.4669 .25 L
.4669 .25 L
.46691 .25 L
.46691 .25 L
.46692 .25 L
.46693 .25 L
.46693 .25 L
.46694 .25 L
.46695 .25 L
.46695 .25 L
.46696 .25 L
.46697 .25 L
.46697 .25 L
.46698 .25 L
.46698 .25 L
.46699 .25 L
.46699 .25 L
.467 .25 L
.467 .25 L
.46701 .25 L
.46701 .25 L
.46701 .25 L
.46702 .25 L
.46702 .25 L
.46703 .25 L
.46703 .25 L
.46704 .25 L
.46704 .25 L
.46704 .25 L
.46705 .25 L
.46705 .25 L
.46706 .25 L
.46706 .25 L
.46707 .25 L
.46708 .25 L
.46708 .25 L
.46709 .25 L
.4671 .25 L
.4671 .25 L
Mistroke
.46711 .25 L
.46711 .25 L
.46712 .25 L
.46713 .25 L
.46713 .25 L
.46714 .25 L
.46715 .25 L
.46715 .25 L
.46715 .25 L
.46716 .25 L
.46717 .25 L
.46717 .25 L
.46718 .25 L
.46719 .25 L
.46719 .25 L
.4672 .25 L
.4672 .25 L
.46721 .25 L
.46721 .25 L
.46722 .25 L
.46723 .25 L
.46723 .25 L
.46724 .25 L
.46725 .25 L
.46725 .25 L
.46725 .25 L
.46726 .25 L
.46727 .25 L
.46727 .25 L
.46728 .25 L
.46729 .25 L
.46729 .25 L
.4673 .25 L
.4673 .25 L
.46731 .25 L
.46732 .25 L
.46732 .25 L
.46733 .25 L
.46734 .25 L
.46734 .25 L
.46735 .25 L
.46735 .25 L
.46736 .25 L
.46736 .25 L
.46737 .25 L
.46738 .25 L
.46738 .25 L
.46739 .25 L
.46739 .25 L
.4674 .25 L
Mistroke
.46741 .25 L
.46741 .25 L
.46742 .25 L
.46742 .25 L
.46743 .25 L
.46744 .25 L
.46744 .25 L
.46745 .25 L
.46745 .25 L
.46746 .25 L
.46746 .25 L
.46747 .25 L
.46747 .25 L
.46748 .25 L
.46749 .25 L
.46749 .25 L
.4675 .25 L
.46751 .25 L
.46751 .25 L
.46752 .25 L
.46753 .25 L
.46753 .25 L
.46754 .25 L
.46754 .25 L
.46755 .25 L
.46756 .25 L
.46756 .25 L
.46757 .25 L
.46757 .25 L
.46758 .25 L
.46758 .25 L
.46759 .25 L
.4676 .25 L
.4676 .25 L
.46761 .25 L
.46761 .25 L
.46762 .25 L
.46763 .25 L
.46763 .25 L
.46764 .25 L
.46764 .25 L
.46765 .25 L
.46765 .25 L
.46766 .25 L
.46766 .25 L
.46767 .25 L
.46768 .25 L
.46768 .25 L
.46768 .25 L
.46769 .25 L
Mistroke
.4677 .25 L
.4677 .25 L
.46771 .25 L
.46771 .25 L
.46772 .25 L
.46773 .25 L
.46773 .25 L
.46774 .25 L
.46774 .25 L
.46775 .25 L
.46775 .25 L
.46776 .25 L
.46776 .25 L
.46777 .25 L
.46778 .25 L
.46778 .25 L
.46779 .25 L
.46779 .25 L
.4678 .25 L
.4678 .25 L
.46781 .25 L
.46782 .25 L
.46782 .25 L
.46783 .25 L
.46784 .25 L
.46784 .25 L
.46785 .25 L
.46785 .25 L
.46786 .25 L
.46787 .25 L
.46787 .25 L
.46788 .25 L
.46789 .25 L
.46789 .25 L
.46789 .25 L
.4679 .25 L
.4679 .25 L
.46791 .25 L
.46791 .25 L
.46792 .25 L
.46793 .25 L
.46793 .25 L
.46794 .25 L
.46795 .25 L
.46795 .25 L
.46796 .25 L
.46797 .25 L
.46797 .25 L
.46798 .25 L
.46798 .25 L
Mistroke
.46799 .25 L
.468 .25 L
.468 .25 L
.46801 .25 L
.46801 .25 L
.46802 .25 L
.46803 .25 L
.46803 .25 L
.46803 .25 L
.46804 .25 L
.46804 .25 L
.46805 .25 L
.46805 .25 L
.46805 .25 L
.46806 .25 L
.46806 .25 L
.46807 .25 L
.46807 .25 L
.46807 .25 L
.46808 .25 L
.46808 .25 L
.46809 .25 L
.4681 .25 L
.4681 .25 L
.46811 .25 L
.46812 .25 L
.46812 .25 L
.46813 .25 L
.46813 .25 L
.46814 .25 L
.46815 .25 L
.46815 .25 L
.46816 .25 L
.46817 .25 L
.46817 .25 L
.46818 .25 L
.46818 .25 L
.46819 .25 L
.46819 .25 L
.4682 .25 L
.46821 .25 L
.46821 .25 L
.46822 .25 L
.46822 .25 L
.46823 .25 L
.46824 .25 L
.46824 .25 L
.46825 .25 L
.46825 .25 L
.46826 .25 L
Mistroke
.46827 .25 L
.46827 .25 L
.46828 .25 L
.46828 .25 L
.46829 .25 L
.46829 .25 L
.4683 .25 L
.46831 .25 L
.46831 .25 L
.46832 .25 L
.46832 .25 L
.46833 .25 L
.46834 .25 L
.46834 .25 L
.46835 .25 L
.46836 .25 L
.46836 .25 L
.46837 .25 L
.46838 .25 L
.46838 .25 L
.46838 .25 L
.46839 .25 L
.4684 .25 L
.4684 .25 L
.46841 .25 L
.46842 .25 L
.46842 .25 L
.46843 .25 L
.46843 .25 L
.46844 .25 L
.46844 .25 L
.46845 .25 L
.46846 .25 L
.46846 .25 L
.46847 .25 L
.46847 .25 L
.46848 .25 L
.46848 .25 L
.46849 .25 L
.46849 .25 L
.4685 .25 L
.4685 .25 L
.46851 .25 L
.46851 .25 L
.46852 .25 L
.46853 .25 L
.46853 .25 L
.46854 .25 L
.46855 .25 L
.46855 .25 L
Mistroke
.46856 .25 L
.46856 .25 L
.46857 .25 L
.46857 .25 L
.46857 .25 L
.46858 .25 L
.46859 .25 L
.46859 .25 L
.4686 .25 L
.46861 .25 L
.46861 .25 L
.46862 .25 L
.46862 .25 L
.46863 .25 L
.46864 .25 L
.46864 .25 L
.46865 .25 L
.46865 .25 L
.46866 .25 L
.46867 .25 L
.46867 .25 L
.46868 .25 L
.46869 .25 L
.46869 .25 L
.4687 .25 L
.4687 .25 L
.46871 .25 L
.46871 .25 L
.46872 .25 L
.46872 .25 L
.46873 .25 L
.46873 .25 L
.46874 .25 L
.46875 .25 L
.46875 .25 L
.46876 .25 L
.46876 .25 L
.46877 .25 L
.46878 .25 L
.46878 .25 L
.46879 .25 L
.4688 .25 L
.4688 .25 L
.46881 .25 L
.46882 .25 L
.46882 .25 L
.46883 .25 L
.46883 .25 L
.46884 .25 L
.46884 .25 L
Mistroke
.46885 .25 L
.46885 .25 L
.46886 .25 L
.46886 .25 L
.46886 .25 L
.46887 .25 L
.46887 .25 L
.46888 .25 L
.46888 .25 L
.46889 .25 L
.46889 .25 L
.46889 .25 L
.4689 .25 L
.4689 .25 L
.46891 .25 L
.46891 .25 L
.46892 .25 L
.46893 .25 L
.46893 .25 L
.46894 .25 L
.46895 .25 L
.46895 .25 L
.46896 .25 L
.46896 .25 L
.46897 .25 L
.46898 .25 L
.46898 .25 L
.46899 .25 L
.469 .25 L
.469 .25 L
.469 .25 L
.46901 .25 L
.46902 .25 L
.46902 .25 L
.46903 .25 L
.46904 .25 L
.46904 .25 L
.46905 .25 L
.46905 .25 L
.46906 .25 L
.46907 .25 L
.46907 .25 L
.46908 .25 L
.46908 .25 L
.46909 .25 L
.4691 .25 L
.4691 .25 L
.4691 .25 L
.46911 .25 L
.46912 .25 L
Mistroke
.46912 .25 L
.46913 .25 L
.46914 .25 L
.46914 .25 L
.46915 .25 L
.46915 .25 L
.46916 .25 L
.46917 .25 L
.46917 .25 L
.46918 .25 L
.46919 .25 L
.46919 .25 L
.4692 .25 L
.4692 .25 L
.46921 .25 L
.46921 .25 L
.46922 .25 L
.46923 .25 L
.46923 .25 L
.46924 .25 L
.46925 .25 L
.46925 .25 L
.46926 .25 L
.46926 .25 L
.46927 .25 L
.46927 .25 L
.46928 .25 L
.46929 .25 L
.46929 .25 L
.4693 .25 L
.4693 .25 L
.46931 .25 L
.46931 .25 L
.46932 .25 L
.46933 .25 L
.46933 .25 L
.46933 .25 L
.46934 .25 L
.46935 .25 L
.46935 .25 L
.46936 .25 L
.46936 .25 L
.46937 .25 L
.46938 .25 L
.46938 .25 L
.46938 .25 L
.46939 .25 L
.46939 .25 L
.4694 .25 L
.4694 .25 L
Mistroke
.46941 .25 L
.46942 .25 L
.46942 .25 L
.46943 .25 L
.46944 .25 L
.46944 .25 L
.46945 .25 L
.46945 .25 L
.46946 .25 L
.46947 .25 L
.46947 .25 L
.46948 .25 L
.46948 .25 L
.46949 .25 L
.4695 .25 L
.4695 .25 L
.46951 .25 L
.46951 .25 L
.46952 .25 L
.46953 .25 L
.46953 .25 L
.46954 .25 L
.46954 .25 L
.46955 .25 L
.46955 .25 L
.46956 .25 L
.46956 .25 L
.46957 .25 L
.46958 .25 L
.46958 .25 L
.46959 .25 L
.46959 .25 L
.4696 .25 L
.46961 .25 L
.46961 .25 L
.46962 .25 L
.46963 .25 L
.46963 .25 L
.46964 .25 L
.46965 .25 L
.46965 .25 L
.46966 .25 L
.46966 .25 L
.46967 .25 L
.46967 .25 L
.46968 .25 L
.46968 .25 L
.46968 .25 L
.46969 .25 L
.46969 .25 L
Mistroke
.4697 .25 L
.4697 .25 L
.46971 .25 L
.46971 .25 L
.46971 .25 L
.46972 .25 L
.46972 .25 L
.46972 .25 L
.46973 .25 L
.46974 .25 L
.46974 .25 L
.46975 .25 L
.46976 .25 L
.46976 .25 L
.46977 .25 L
.46978 .25 L
.46978 .25 L
.46979 .25 L
.46979 .25 L
.4698 .25 L
.46981 .25 L
.46981 .25 L
.46982 .25 L
.46982 .25 L
.46983 .25 L
.46984 .25 L
.46984 .25 L
.46985 .25 L
.46985 .25 L
.46986 .25 L
.46987 .25 L
.46987 .25 L
.46988 .25 L
.46988 .25 L
.46989 .25 L
.46989 .25 L
.4699 .25 L
.46991 .25 L
.46991 .25 L
.46992 .25 L
.46992 .25 L
.46993 .25 L
.46993 .25 L
.46994 .25 L
.46995 .25 L
.46995 .25 L
.46996 .25 L
.46997 .25 L
.46997 .25 L
.46998 .25 L
Mistroke
.46998 .25 L
.46999 .25 L
.47 .25 L
.47 .25 L
.47001 .25 L
.47002 .25 L
.47002 .25 L
.47003 .25 L
.47003 .25 L
.47004 .25 L
.47004 .25 L
.47005 .25 L
.47006 .25 L
.47006 .25 L
.47007 .25 L
.47007 .25 L
.47008 .25 L
.47009 .25 L
.47009 .25 L
.4701 .25 L
.4701 .25 L
.47011 .25 L
.47012 .25 L
.47012 .25 L
.47013 .25 L
.47013 .25 L
.47014 .25 L
.47014 .25 L
.47015 .25 L
.47015 .25 L
.47016 .25 L
.47016 .25 L
.47017 .25 L
.47017 .25 L
.47018 .25 L
.47019 .25 L
.47019 .25 L
.4702 .25 L
.4702 .25 L
.47021 .25 L
.47021 .25 L
.47022 .25 L
.47022 .25 L
.47023 .25 L
.47023 .25 L
.47024 .25 L
.47025 .25 L
.47025 .25 L
.47026 .25 L
.47026 .25 L
Mistroke
.47027 .25 L
.47028 .25 L
.47028 .25 L
.47029 .25 L
.47029 .25 L
.4703 .25 L
.47031 .25 L
.47031 .25 L
.47032 .25 L
.47033 .25 L
.47033 .25 L
.47034 .25 L
.47034 .25 L
.47035 .25 L
.47036 .25 L
.47036 .25 L
.47037 .25 L
.47037 .25 L
.47037 .25 L
.47038 .25 L
.47039 .25 L
.47039 .25 L
.4704 .25 L
.47041 .25 L
.47041 .25 L
.47042 .25 L
.47042 .25 L
.47043 .25 L
.47044 .25 L
.47044 .25 L
.47045 .25 L
.47046 .25 L
.47046 .25 L
.47047 .25 L
.47047 .25 L
.47048 .25 L
.47049 .25 L
.47049 .25 L
.4705 .25 L
.4705 .25 L
.4705 .25 L
.47051 .25 L
.47051 .25 L
.47052 .25 L
.47052 .25 L
.47053 .25 L
.47053 .25 L
.47053 .25 L
.47054 .25 L
.47054 .25 L
Mistroke
.47054 .25 L
.47055 .25 L
.47055 .25 L
.47056 .25 L
.47057 .25 L
.47057 .25 L
.47058 .25 L
.47059 .25 L
.47059 .25 L
.4706 .25 L
.47061 .25 L
.47061 .25 L
.47062 .25 L
.47062 .25 L
.47063 .25 L
.47064 .25 L
.47064 .25 L
.47065 .25 L
.47065 .25 L
.47066 .25 L
.47067 .25 L
.47067 .25 L
.47068 .25 L
.47068 .25 L
.47069 .25 L
.4707 .25 L
.4707 .25 L
.47071 .25 L
.47071 .25 L
.47072 .25 L
.47072 .25 L
.47073 .25 L
.47074 .25 L
.47074 .25 L
.47075 .25 L
.47075 .25 L
.47076 .25 L
.47076 .25 L
.47077 .25 L
.47078 .25 L
.47078 .25 L
.47079 .25 L
.4708 .25 L
.4708 .25 L
.47081 .25 L
.47081 .25 L
.47082 .25 L
.47083 .25 L
.47083 .25 L
.47084 .25 L
Mistroke
.47085 .25 L
.47085 .25 L
.47085 .25 L
.47086 .25 L
.47087 .25 L
.47087 .25 L
.47088 .25 L
.47089 .25 L
.47089 .25 L
.4709 .25 L
.4709 .25 L
.47091 .25 L
.47091 .25 L
.47092 .25 L
.47093 .25 L
.47093 .25 L
.47094 .25 L
.47095 .25 L
.47095 .25 L
.47095 .25 L
.47096 .25 L
.47097 .25 L
.47097 .25 L
.47098 .25 L
.47099 .25 L
.47099 .25 L
.471 .25 L
.471 .25 L
.47101 .25 L
.47102 .25 L
.47102 .25 L
.47103 .25 L
.47104 .25 L
.47104 .25 L
.47105 .25 L
.47105 .25 L
.47106 .25 L
.47106 .25 L
.47107 .25 L
.47108 .25 L
.47108 .25 L
.47109 .25 L
.47109 .25 L
.4711 .25 L
.47111 .25 L
.47111 .25 L
.47112 .25 L
.47112 .25 L
.47113 .25 L
.47114 .25 L
Mistroke
.47114 .25 L
.47115 .25 L
.47115 .25 L
.47116 .25 L
.47116 .25 L
.47117 .25 L
.47117 .25 L
.47118 .25 L
.47118 .25 L
.47119 .25 L
.47119 .25 L
.4712 .25 L
.47121 .25 L
.47121 .25 L
.47122 .25 L
.47123 .25 L
.47123 .25 L
.47123 .25 L
.47124 .25 L
.47124 .25 L
.47125 .25 L
.47125 .25 L
.47126 .25 L
.47127 .25 L
.47127 .25 L
.47128 .25 L
.47128 .25 L
.47129 .25 L
.4713 .25 L
.4713 .25 L
.47131 .25 L
.47131 .25 L
.47132 .25 L
.47133 .25 L
.47133 .25 L
.47134 .25 L
.47134 .25 L
.47135 .25 L
.47136 .25 L
.47136 .25 L
.47137 .25 L
.47138 .25 L
.47138 .25 L
.47139 .25 L
.47139 .25 L
.4714 .25 L
.4714 .25 L
.47141 .25 L
.47141 .25 L
.47142 .25 L
Mistroke
.47143 .25 L
.47143 .25 L
.47144 .25 L
.47144 .25 L
.47145 .25 L
.47146 .25 L
.47146 .25 L
.47147 .25 L
.47148 .25 L
.47148 .25 L
.47149 .25 L
.4715 .25 L
.4715 .25 L
.47151 .25 L
.47151 .25 L
.47152 .25 L
.47152 .25 L
.47153 .25 L
.47153 .25 L
.47153 .25 L
.47154 .25 L
.47154 .25 L
.47155 .25 L
.47155 .25 L
.47156 .25 L
.47156 .25 L
.47156 .25 L
.47157 .25 L
.47157 .25 L
.47157 .25 L
.47158 .25 L
.47159 .25 L
.47159 .25 L
.4716 .25 L
.47161 .25 L
.47161 .25 L
.47162 .25 L
.47163 .25 L
.47163 .25 L
.47164 .25 L
.47164 .25 L
.47165 .25 L
.47166 .25 L
.47166 .25 L
.47167 .25 L
.47167 .25 L
.47168 .25 L
.47169 .25 L
.47169 .25 L
.4717 .25 L
Mistroke
.4717 .25 L
.47171 .25 L
.47172 .25 L
.47172 .25 L
.47173 .25 L
.47173 .25 L
.47174 .25 L
.47174 .25 L
.47175 .25 L
.47176 .25 L
.47176 .25 L
.47177 .25 L
.47177 .25 L
.47178 .25 L
.47178 .25 L
.47179 .25 L
.4718 .25 L
.4718 .25 L
.47181 .25 L
.47182 .25 L
.47182 .25 L
.47183 .25 L
.47183 .25 L
.47184 .25 L
.47185 .25 L
.47185 .25 L
.47186 .25 L
.47187 .25 L
.47187 .25 L
.47188 .25 L
.47188 .25 L
.47189 .25 L
.47189 .25 L
.4719 .25 L
.47191 .25 L
.47191 .25 L
.47192 .25 L
.47192 .25 L
.47193 .25 L
.47194 .25 L
.47194 .25 L
.47195 .25 L
.47195 .25 L
.47196 .25 L
.47197 .25 L
.47197 .25 L
.47198 .25 L
.47198 .25 L
.47199 .25 L
.47199 .25 L
Mistroke
.472 .25 L
.472 .25 L
.47201 .25 L
.47201 .25 L
.47202 .25 L
.47202 .25 L
.47203 .25 L
.47204 .25 L
.47204 .25 L
.47205 .25 L
.47205 .25 L
.47206 .25 L
.47206 .25 L
.47207 .25 L
.47207 .25 L
.47208 .25 L
.47208 .25 L
.47209 .25 L
.4721 .25 L
.4721 .25 L
.47211 .25 L
.47211 .25 L
.47212 .25 L
.47213 .25 L
.47213 .25 L
.47214 .25 L
.47214 .25 L
.47215 .25 L
.47216 .25 L
.47216 .25 L
.47217 .25 L
.47218 .25 L
.47218 .25 L
.47219 .25 L
.47219 .25 L
.4722 .25 L
.47221 .25 L
.47221 .25 L
.47222 .25 L
.47222 .25 L
.47222 .25 L
.47223 .25 L
.47224 .25 L
.47224 .25 L
.47225 .25 L
.47226 .25 L
.47226 .25 L
.47227 .25 L
.47227 .25 L
.47228 .25 L
Mistroke
.47229 .25 L
.47229 .25 L
.4723 .25 L
.47231 .25 L
.47231 .25 L
.47232 .25 L
.47233 .25 L
.47233 .25 L
.47234 .25 L
.47234 .25 L
.47235 .25 L
.47235 .25 L
.47235 .25 L
.47236 .25 L
.47236 .25 L
.47237 .25 L
.47237 .25 L
.47238 .25 L
.47238 .25 L
.47238 .25 L
.47239 .25 L
.47239 .25 L
.47239 .25 L
.4724 .25 L
.4724 .25 L
.47241 .25 L
.47242 .25 L
.47242 .25 L
.47243 .25 L
.47244 .25 L
.47244 .25 L
.47245 .25 L
.47246 .25 L
.47246 .25 L
.47247 .25 L
.47248 .25 L
.47248 .25 L
.47249 .25 L
.47249 .25 L
.4725 .25 L
.4725 .25 L
.47251 .25 L
.47252 .25 L
.47252 .25 L
.47253 .25 L
.47253 .25 L
.47254 .25 L
.47255 .25 L
.47255 .25 L
.47256 .25 L
Mistroke
.47256 .25 L
.47257 .25 L
.47258 .25 L
.47258 .25 L
.47259 .25 L
.47259 .25 L
.4726 .25 L
.4726 .25 L
.47261 .25 L
.47261 .25 L
.47262 .25 L
.47263 .25 L
.47263 .25 L
.47264 .25 L
.47265 .25 L
.47265 .25 L
.47266 .25 L
.47266 .25 L
.47267 .25 L
.47268 .25 L
.47268 .25 L
.47269 .25 L
.4727 .25 L
.4727 .25 L
.4727 .25 L
.47271 .25 L
.47272 .25 L
.47272 .25 L
.47273 .25 L
.47274 .25 L
.47274 .25 L
.47275 .25 L
.47275 .25 L
.47276 .25 L
.47277 .25 L
.47277 .25 L
.47278 .25 L
.47278 .25 L
.47279 .25 L
.4728 .25 L
.4728 .25 L
.4728 .25 L
.47281 .25 L
.47282 .25 L
.47282 .25 L
.47283 .25 L
.47283 .25 L
.47284 .25 L
.47284 .25 L
.47285 .25 L
Mistroke
.47285 .25 L
.47286 .25 L
.47287 .25 L
.47287 .25 L
.47288 .25 L
.47288 .25 L
.47289 .25 L
.47289 .25 L
.47289 .25 L
.4729 .25 L
.47291 .25 L
.47291 .25 L
.47292 .25 L
.47293 .25 L
.47293 .25 L
.47294 .25 L
.47294 .25 L
.47295 .25 L
.47296 .25 L
.47296 .25 L
.47297 .25 L
.47297 .25 L
.47298 .25 L
.47299 .25 L
.47299 .25 L
.473 .25 L
.47301 .25 L
.47301 .25 L
.47302 .25 L
.47303 .25 L
.47303 .25 L
.47304 .25 L
.47304 .25 L
.47304 .25 L
.47305 .25 L
.47305 .25 L
.47306 .25 L
.47307 .25 L
.47307 .25 L
.47308 .25 L
.47309 .25 L
.47309 .25 L
.4731 .25 L
.4731 .25 L
.47311 .25 L
.47312 .25 L
.47312 .25 L
.47313 .25 L
.47314 .25 L
.47314 .25 L
Mistroke
.47315 .25 L
.47316 .25 L
.47316 .25 L
.47316 .25 L
.47317 .25 L
.47317 .25 L
.47318 .25 L
.47318 .25 L
.47318 .25 L
.47319 .25 L
.4732 .25 L
.4732 .25 L
.4732 .25 L
.47321 .25 L
.47321 .25 L
.47321 .25 L
.47322 .25 L
.47322 .25 L
.47323 .25 L
.47323 .25 L
.47324 .25 L
.47325 .25 L
.47326 .25 L
.47326 .25 L
.47327 .25 L
.47327 .25 L
.47328 .25 L
.47329 .25 L
.47329 .25 L
.4733 .25 L
.4733 .25 L
.47331 .25 L
.47332 .25 L
.47332 .25 L
.47333 .25 L
.47333 .25 L
.47334 .25 L
.47334 .25 L
.47335 .25 L
.47336 .25 L
.47336 .25 L
.47337 .25 L
.47337 .25 L
.47338 .25 L
.47339 .25 L
.47339 .25 L
.4734 .25 L
.4734 .25 L
.47341 .25 L
.47342 .25 L
Mistroke
.47342 .25 L
.47342 .25 L
.47343 .25 L
.47344 .25 L
.47344 .25 L
.47345 .25 L
.47346 .25 L
.47346 .25 L
.47347 .25 L
.47348 .25 L
.47348 .25 L
.47349 .25 L
.47349 .25 L
.4735 .25 L
.47351 .25 L
.47351 .25 L
.47352 .25 L
.47352 .25 L
.47353 .25 L
.47354 .25 L
.47354 .25 L
.47355 .25 L
.47355 .25 L
.47356 .25 L
.47357 .25 L
.47357 .25 L
.47358 .25 L
.47358 .25 L
.47359 .25 L
.47359 .25 L
.4736 .25 L
.47361 .25 L
.47361 .25 L
.47362 .25 L
.47362 .25 L
.47363 .25 L
.47363 .25 L
.47364 .25 L
.47365 .25 L
.47365 .25 L
.47365 .25 L
.47366 .25 L
.47367 .25 L
.47367 .25 L
.47368 .25 L
.47368 .25 L
.47369 .25 L
.4737 .25 L
.4737 .25 L
.4737 .25 L
Mistroke
.47371 .25 L
.47371 .25 L
.47372 .25 L
.47372 .25 L
.47373 .25 L
.47374 .25 L
.47374 .25 L
.47375 .25 L
.47376 .25 L
.47376 .25 L
.47377 .25 L
.47377 .25 L
.47378 .25 L
.47379 .25 L
.47379 .25 L
.4738 .25 L
.4738 .25 L
.47381 .25 L
.47382 .25 L
.47382 .25 L
.47383 .25 L
.47384 .25 L
.47384 .25 L
.47385 .25 L
.47386 .25 L
.47386 .25 L
.47386 .25 L
.47387 .25 L
.47387 .25 L
.47388 .25 L
.47388 .25 L
.47389 .25 L
.4739 .25 L
.4739 .25 L
.47391 .25 L
.47392 .25 L
.47392 .25 L
.47393 .25 L
.47393 .25 L
.47394 .25 L
.47395 .25 L
.47395 .25 L
.47396 .25 L
.47397 .25 L
.47397 .25 L
.47398 .25 L
.47398 .25 L
.47399 .25 L
.47399 .25 L
.474 .25 L
Mistroke
.474 .25 L
.474 .25 L
.47401 .25 L
.47402 .25 L
.47402 .25 L
.47402 .25 L
.47403 .25 L
.47403 .25 L
.47403 .25 L
.47404 .25 L
.47404 .25 L
.47405 .25 L
.47405 .25 L
.47406 .25 L
.47406 .25 L
.47407 .25 L
.47408 .25 L
.47408 .25 L
.47409 .25 L
.4741 .25 L
.4741 .25 L
.47411 .25 L
.47412 .25 L
.47412 .25 L
.47413 .25 L
.47413 .25 L
.47414 .25 L
.47415 .25 L
.47415 .25 L
.47416 .25 L
.47416 .25 L
.47417 .25 L
.47417 .25 L
.47418 .25 L
.47419 .25 L
.47419 .25 L
.4742 .25 L
.4742 .25 L
.47421 .25 L
.47422 .25 L
.47422 .25 L
.47423 .25 L
.47423 .25 L
.47424 .25 L
.47424 .25 L
.47425 .25 L
.47425 .25 L
.47426 .25 L
.47427 .25 L
.47427 .25 L
Mistroke
.47428 .25 L
.47429 .25 L
.47429 .25 L
.4743 .25 L
.4743 .25 L
.47431 .25 L
.47432 .25 L
.47432 .25 L
.47433 .25 L
.47434 .25 L
.47434 .25 L
.47435 .25 L
.47435 .25 L
.47436 .25 L
.47437 .25 L
.47437 .25 L
.47438 .25 L
.47438 .25 L
.47439 .25 L
.4744 .25 L
.4744 .25 L
.47441 .25 L
.47441 .25 L
.47442 .25 L
.47442 .25 L
.47443 .25 L
.47444 .25 L
.47444 .25 L
.47445 .25 L
.47445 .25 L
.47446 .25 L
.47446 .25 L
.47447 .25 L
.47448 .25 L
.47448 .25 L
.47449 .25 L
.47449 .25 L
.4745 .25 L
.47451 .25 L
.47451 .25 L
.47452 .25 L
.47453 .25 L
.47453 .25 L
.47454 .25 L
.47455 .25 L
.47455 .25 L
.47455 .25 L
.47456 .25 L
.47457 .25 L
.47457 .25 L
Mistroke
.47458 .25 L
.47459 .25 L
.47459 .25 L
.4746 .25 L
.4746 .25 L
.47461 .25 L
.47461 .25 L
.47462 .25 L
.47463 .25 L
.47463 .25 L
.47464 .25 L
.47465 .25 L
.47465 .25 L
.47465 .25 L
.47466 .25 L
.47467 .25 L
.47467 .25 L
.47468 .25 L
.47468 .25 L
.47469 .25 L
.47469 .25 L
.4747 .25 L
.4747 .25 L
.47471 .25 L
.47472 .25 L
.47472 .25 L
.47473 .25 L
.47473 .25 L
.47474 .25 L
.47474 .25 L
.47474 .25 L
.47475 .25 L
.47476 .25 L
.47476 .25 L
.47477 .25 L
.47478 .25 L
.47478 .25 L
.47479 .25 L
.47479 .25 L
.4748 .25 L
.47481 .25 L
.47481 .25 L
.47482 .25 L
.47482 .25 L
.47483 .25 L
.47484 .25 L
.47484 .25 L
.47485 .25 L
.47486 .25 L
.47486 .25 L
Mistroke
.47487 .25 L
.47488 .25 L
.47488 .25 L
.47489 .25 L
.47489 .25 L
.47489 .25 L
.4749 .25 L
.4749 .25 L
.47491 .25 L
.47492 .25 L
.47492 .25 L
.47493 .25 L
.47494 .25 L
.47494 .25 L
.47495 .25 L
.47495 .25 L
.47496 .25 L
.47497 .25 L
.47497 .25 L
.47498 .25 L
.47499 .25 L
.47499 .25 L
.475 .25 L
.47501 .25 L
.47501 .25 L
.47501 .25 L
.47502 .25 L
.47502 .25 L
.47503 .25 L
.47503 .25 L
.47503 .25 L
.47504 .25 L
.47505 .25 L
.47505 .25 L
.47505 .25 L
.47506 .25 L
.47506 .25 L
.47506 .25 L
.47507 .25 L
.47507 .25 L
.47508 .25 L
.47508 .25 L
.47509 .25 L
.4751 .25 L
.4751 .25 L
.47511 .25 L
.47512 .25 L
.47512 .25 L
.47513 .25 L
.47514 .25 L
Mistroke
.47514 .25 L
.47515 .25 L
.47515 .25 L
.47516 .25 L
.47517 .25 L
.47517 .25 L
.47518 .25 L
.47518 .25 L
.47519 .25 L
.47519 .25 L
.4752 .25 L
.47521 .25 L
.47521 .25 L
.47522 .25 L
.47522 .25 L
.47523 .25 L
.47524 .25 L
.47524 .25 L
.47525 .25 L
.47525 .25 L
.47526 .25 L
.47527 .25 L
.47527 .25 L
.47527 .25 L
.47528 .25 L
.47529 .25 L
.47529 .25 L
.4753 .25 L
.47531 .25 L
.47531 .25 L
.47532 .25 L
.47533 .25 L
.47533 .25 L
.47534 .25 L
.47534 .25 L
.47535 .25 L
.47536 .25 L
.47536 .25 L
.47537 .25 L
.47537 .25 L
.47538 .25 L
.47539 .25 L
.47539 .25 L
.4754 .25 L
.4754 .25 L
.47541 .25 L
.47542 .25 L
.47542 .25 L
.47543 .25 L
.47543 .25 L
Mistroke
.47544 .25 L
.47544 .25 L
.47545 .25 L
.47546 .25 L
.47546 .25 L
.47547 .25 L
.47547 .25 L
.47548 .25 L
.47548 .25 L
.47549 .25 L
.4755 .25 L
.4755 .25 L
.4755 .25 L
.47551 .25 L
.47552 .25 L
.47552 .25 L
.47553 .25 L
.47553 .25 L
.47554 .25 L
.47555 .25 L
.47555 .25 L
.47555 .25 L
.47556 .25 L
.47557 .25 L
.47557 .25 L
.47558 .25 L
.47558 .25 L
.47559 .25 L
.47559 .25 L
.4756 .25 L
.47561 .25 L
.47561 .25 L
.47562 .25 L
.47562 .25 L
.47563 .25 L
.47564 .25 L
.47564 .25 L
.47565 .25 L
.47565 .25 L
.47566 .25 L
.47567 .25 L
.47567 .25 L
.47568 .25 L
.47569 .25 L
.47569 .25 L
.4757 .25 L
.47571 .25 L
.47571 .25 L
.47571 .25 L
.47572 .25 L
Mistroke
.47572 .25 L
.47573 .25 L
.47573 .25 L
.47574 .25 L
.47575 .25 L
.47575 .25 L
.47576 .25 L
.47577 .25 L
.47577 .25 L
.47578 .25 L
.47578 .25 L
.47579 .25 L
.4758 .25 L
.4758 .25 L
.47581 .25 L
.47582 .25 L
.47582 .25 L
.47583 .25 L
.47583 .25 L
.47584 .25 L
.47584 .25 L
.47585 .25 L
.47585 .25 L
.47585 .25 L
.47586 .25 L
.47587 .25 L
.47587 .25 L
.47587 .25 L
.47588 .25 L
.47588 .25 L
.47588 .25 L
.47589 .25 L
.47589 .25 L
.4759 .25 L
.4759 .25 L
.47591 .25 L
.47592 .25 L
.47592 .25 L
.47593 .25 L
.47594 .25 L
.47594 .25 L
.47595 .25 L
.47595 .25 L
.47596 .25 L
.47597 .25 L
.47597 .25 L
.47598 .25 L
.47599 .25 L
.47599 .25 L
.476 .25 L
Mistroke
.476 .25 L
.47601 .25 L
.47601 .25 L
.47602 .25 L
.47603 .25 L
.47603 .25 L
.47604 .25 L
.47604 .25 L
.47605 .25 L
.47605 .25 L
.47606 .25 L
.47607 .25 L
.47607 .25 L
.47608 .25 L
.47608 .25 L
.47609 .25 L
.47609 .25 L
.4761 .25 L
.4761 .25 L
.47611 .25 L
.47612 .25 L
.47612 .25 L
.47613 .25 L
.47614 .25 L
.47614 .25 L
.47615 .25 L
.47616 .25 L
.47616 .25 L
.47617 .25 L
.47618 .25 L
.47618 .25 L
.47619 .25 L
.47619 .25 L
.4762 .25 L
.4762 .25 L
.47621 .25 L
.47622 .25 L
.47622 .25 L
.47623 .25 L
.47623 .25 L
.47624 .25 L
.47625 .25 L
.47625 .25 L
.47626 .25 L
.47626 .25 L
.47627 .25 L
.47628 .25 L
.47628 .25 L
.47629 .25 L
.47629 .25 L
Mistroke
.4763 .25 L
.4763 .25 L
.47631 .25 L
.47631 .25 L
.47632 .25 L
.47632 .25 L
.47633 .25 L
.47633 .25 L
.47634 .25 L
.47635 .25 L
.47635 .25 L
.47636 .25 L
.47636 .25 L
.47637 .25 L
.47637 .25 L
.47638 .25 L
.47639 .25 L
.47639 .25 L
.47639 .25 L
.4764 .25 L
.47641 .25 L
.47641 .25 L
.47642 .25 L
.47642 .25 L
.47643 .25 L
.47644 .25 L
.47644 .25 L
.47645 .25 L
.47645 .25 L
.47646 .25 L
.47647 .25 L
.47647 .25 L
.47648 .25 L
.47648 .25 L
.47649 .25 L
.4765 .25 L
.4765 .25 L
.47651 .25 L
.47652 .25 L
.47652 .25 L
.47653 .25 L
.47653 .25 L
.47654 .25 L
.47654 .25 L
.47654 .25 L
.47655 .25 L
.47656 .25 L
.47656 .25 L
.47657 .25 L
.47658 .25 L
Mistroke
.47658 .25 L
.47659 .25 L
.47659 .25 L
.4766 .25 L
.47661 .25 L
.47661 .25 L
.47662 .25 L
.47663 .25 L
.47663 .25 L
.47664 .25 L
.47665 .25 L
.47665 .25 L
.47666 .25 L
.47666 .25 L
.47667 .25 L
.47667 .25 L
.47668 .25 L
.47668 .25 L
.47668 .25 L
.47669 .25 L
.47669 .25 L
.4767 .25 L
.4767 .25 L
.4767 .25 L
.47671 .25 L
.47671 .25 L
.47672 .25 L
.47672 .25 L
.47673 .25 L
.47673 .25 L
.47674 .25 L
.47675 .25 L
.47675 .25 L
.47676 .25 L
.47676 .25 L
.47677 .25 L
.47678 .25 L
.47678 .25 L
.47679 .25 L
.4768 .25 L
.4768 .25 L
.47681 .25 L
.47682 .25 L
.47682 .25 L
.47682 .25 L
.47683 .25 L
.47684 .25 L
.47684 .25 L
.47685 .25 L
.47686 .25 L
Mistroke
.47686 .25 L
.47687 .25 L
.47687 .25 L
.47688 .25 L
.47688 .25 L
.47689 .25 L
.4769 .25 L
.4769 .25 L
.47691 .25 L
.47691 .25 L
.47692 .25 L
.47692 .25 L
.47693 .25 L
.47693 .25 L
.47694 .25 L
.47695 .25 L
.47695 .25 L
.47696 .25 L
.47697 .25 L
.47697 .25 L
.47698 .25 L
.47699 .25 L
.47699 .25 L
.477 .25 L
.477 .25 L
.47701 .25 L
.47702 .25 L
.47702 .25 L
.47703 .25 L
.47703 .25 L
.47704 .25 L
.47705 .25 L
.47705 .25 L
.47706 .25 L
.47706 .25 L
.47707 .25 L
.47707 .25 L
.47708 .25 L
.47709 .25 L
.47709 .25 L
.4771 .25 L
.47711 .25 L
.47711 .25 L
.47712 .25 L
.47712 .25 L
.47712 .25 L
.47713 .25 L
.47714 .25 L
.47714 .25 L
.47715 .25 L
Mistroke
.47715 .25 L
.47716 .25 L
.47716 .25 L
.47717 .25 L
.47718 .25 L
.47718 .25 L
.47719 .25 L
.47719 .25 L
.4772 .25 L
.4772 .25 L
.47721 .25 L
.47721 .25 L
.47722 .25 L
.47722 .25 L
.47723 .25 L
.47724 .25 L
.47724 .25 L
.47725 .25 L
.47725 .25 L
.47726 .25 L
.47726 .25 L
.47727 .25 L
.47728 .25 L
.47728 .25 L
.47729 .25 L
.4773 .25 L
.4773 .25 L
.47731 .25 L
.47731 .25 L
.47732 .25 L
.47733 .25 L
.47733 .25 L
.47734 .25 L
.47735 .25 L
.47735 .25 L
.47736 .25 L
.47736 .25 L
.47736 .25 L
.47737 .25 L
.47737 .25 L
.47738 .25 L
.47739 .25 L
.47739 .25 L
.4774 .25 L
.47741 .25 L
.47741 .25 L
.47742 .25 L
.47742 .25 L
.47743 .25 L
.47744 .25 L
Mistroke
.47744 .25 L
.47745 .25 L
.47746 .25 L
.47746 .25 L
.47747 .25 L
.47748 .25 L
.47748 .25 L
.47748 .25 L
.47749 .25 L
.4775 .25 L
.4775 .25 L
.4775 .25 L
.47751 .25 L
.47751 .25 L
.47752 .25 L
.47752 .25 L
.47752 .25 L
.47753 .25 L
.47753 .25 L
.47754 .25 L
.47754 .25 L
.47754 .25 L
.47755 .25 L
.47756 .25 L
.47756 .25 L
.47757 .25 L
.47758 .25 L
.47758 .25 L
.47759 .25 L
.47759 .25 L
.4776 .25 L
.47761 .25 L
.47761 .25 L
.47762 .25 L
.47763 .25 L
.47763 .25 L
.47764 .25 L
.47764 .25 L
.47765 .25 L
.47765 .25 L
.47766 .25 L
.47767 .25 L
.47767 .25 L
.47768 .25 L
.47768 .25 L
.47769 .25 L
.4777 .25 L
.4777 .25 L
.47771 .25 L
.47771 .25 L
Mistroke
.47772 .25 L
.47773 .25 L
.47773 .25 L
.47774 .25 L
.47774 .25 L
.47775 .25 L
.47775 .25 L
.47776 .25 L
.47776 .25 L
.47777 .25 L
.47778 .25 L
.47778 .25 L
.47779 .25 L
.4778 .25 L
.4778 .25 L
.47781 .25 L
.47782 .25 L
.47782 .25 L
.47783 .25 L
.47783 .25 L
.47784 .25 L
.47785 .25 L
.47785 .25 L
.47786 .25 L
.47786 .25 L
.47787 .25 L
.47787 .25 L
.47788 .25 L
.47789 .25 L
.47789 .25 L
.4779 .25 L
.4779 .25 L
.47791 .25 L
.47792 .25 L
.47792 .25 L
.47793 .25 L
.47793 .25 L
.47794 .25 L
.47794 .25 L
.47795 .25 L
.47795 .25 L
.47796 .25 L
.47797 .25 L
.47797 .25 L
.47798 .25 L
.47799 .25 L
.47799 .25 L
.478 .25 L
.47801 .25 L
.47801 .25 L
Mistroke
.47802 .25 L
.47802 .25 L
.47803 .25 L
.47804 .25 L
.47804 .25 L
.47805 .25 L
.47805 .25 L
.47806 .25 L
.47807 .25 L
.47807 .25 L
.47808 .25 L
.47808 .25 L
.47809 .25 L
.4781 .25 L
.4781 .25 L
.47811 .25 L
.47811 .25 L
.47812 .25 L
.47813 .25 L
.47813 .25 L
.47814 .25 L
.47814 .25 L
.47815 .25 L
.47815 .25 L
.47816 .25 L
.47816 .25 L
.47817 .25 L
.47817 .25 L
.47818 .25 L
.47818 .25 L
.47819 .25 L
.4782 .25 L
.4782 .25 L
.47821 .25 L
.47821 .25 L
.47822 .25 L
.47822 .25 L
.47823 .25 L
.47823 .25 L
.47824 .25 L
.47824 .25 L
.47825 .25 L
.47826 .25 L
.47826 .25 L
.47827 .25 L
.47827 .25 L
.47828 .25 L
.47829 .25 L
.47829 .25 L
.4783 .25 L
Mistroke
.4783 .25 L
.47831 .25 L
.47832 .25 L
.47832 .25 L
.47833 .25 L
.47833 .25 L
.47834 .25 L
.47835 .25 L
.47835 .25 L
.47836 .25 L
.47837 .25 L
.47837 .25 L
.47838 .25 L
.47838 .25 L
.47839 .25 L
.47839 .25 L
.47839 .25 L
.4784 .25 L
.47841 .25 L
.47841 .25 L
.47842 .25 L
.47843 .25 L
.47843 .25 L
.47844 .25 L
.47844 .25 L
.47845 .25 L
.47846 .25 L
.47846 .25 L
.47847 .25 L
.47848 .25 L
.47848 .25 L
.47849 .25 L
.4785 .25 L
.4785 .25 L
.47851 .25 L
.47851 .25 L
.47852 .25 L
.47852 .25 L
.47853 .25 L
.47853 .25 L
.47853 .25 L
.47854 .25 L
.47854 .25 L
.47855 .25 L
.47855 .25 L
.47855 .25 L
.47856 .25 L
.47856 .25 L
.47857 .25 L
.47857 .25 L
Mistroke
.47858 .25 L
.47858 .25 L
.47859 .25 L
.4786 .25 L
.4786 .25 L
.47861 .25 L
.47862 .25 L
.47862 .25 L
.47863 .25 L
.47863 .25 L
.47864 .25 L
.47865 .25 L
.47865 .25 L
.47866 .25 L
.47867 .25 L
.47867 .25 L
.47867 .25 L
.47868 .25 L
.47869 .25 L
.47869 .25 L
.4787 .25 L
.47871 .25 L
.47871 .25 L
.47872 .25 L
.47872 .25 L
.47873 .25 L
.47873 .25 L
.47874 .25 L
.47875 .25 L
.47875 .25 L
.47876 .25 L
.47876 .25 L
.47877 .25 L
.47877 .25 L
.47878 .25 L
.47878 .25 L
.47879 .25 L
.4788 .25 L
.47881 .25 L
.47881 .25 L
.47882 .25 L
.47882 .25 L
.47883 .25 L
.47884 .25 L
.47884 .25 L
.47885 .25 L
.47885 .25 L
.47886 .25 L
.47887 .25 L
.47887 .25 L
Mistroke
.47888 .25 L
.47888 .25 L
.47889 .25 L
.4789 .25 L
.4789 .25 L
.47891 .25 L
.47891 .25 L
.47892 .25 L
.47892 .25 L
.47893 .25 L
.47894 .25 L
.47894 .25 L
.47895 .25 L
.47896 .25 L
.47896 .25 L
.47897 .25 L
.47897 .25 L
.47897 .25 L
.47898 .25 L
.47899 .25 L
.47899 .25 L
.479 .25 L
.479 .25 L
.47901 .25 L
.47901 .25 L
.47902 .25 L
.47903 .25 L
.47903 .25 L
.47904 .25 L
.47904 .25 L
.47905 .25 L
.47905 .25 L
.47906 .25 L
.47906 .25 L
.47907 .25 L
.47907 .25 L
.47908 .25 L
.47909 .25 L
.47909 .25 L
.4791 .25 L
.4791 .25 L
.47911 .25 L
.47912 .25 L
.47912 .25 L
.47913 .25 L
.47913 .25 L
.47914 .25 L
.47915 .25 L
.47915 .25 L
.47916 .25 L
Mistroke
.47916 .25 L
.47917 .25 L
.47918 .25 L
.47918 .25 L
.47919 .25 L
.4792 .25 L
.4792 .25 L
.47921 .25 L
.47921 .25 L
.47921 .25 L
.47922 .25 L
.47923 .25 L
.47923 .25 L
.47924 .25 L
.47925 .25 L
.47925 .25 L
.47926 .25 L
.47926 .25 L
.47927 .25 L
.47928 .25 L
.47928 .25 L
.47929 .25 L
.47929 .25 L
.4793 .25 L
.47931 .25 L
.47931 .25 L
.47932 .25 L
.47933 .25 L
.47933 .25 L
.47934 .25 L
.47934 .25 L
.47935 .25 L
.47935 .25 L
.47935 .25 L
.47936 .25 L
.47936 .25 L
.47937 .25 L
.47937 .25 L
.47937 .25 L
.47938 .25 L
.47938 .25 L
.47939 .25 L
.47939 .25 L
.47939 .25 L
.4794 .25 L
.47941 .25 L
.47941 .25 L
.47942 .25 L
.47943 .25 L
.47943 .25 L
Mistroke
.47944 .25 L
.47944 .25 L
.47945 .25 L
.47946 .25 L
.47946 .25 L
.47947 .25 L
.47948 .25 L
.47948 .25 L
.47949 .25 L
.47949 .25 L
.4795 .25 L
.4795 .25 L
.47951 .25 L
.47952 .25 L
.47952 .25 L
.47953 .25 L
.47954 .25 L
.47954 .25 L
.47955 .25 L
.47955 .25 L
.47956 .25 L
.47956 .25 L
.47957 .25 L
.47958 .25 L
.47958 .25 L
.47959 .25 L
.47959 .25 L
.4796 .25 L
.4796 .25 L
.47961 .25 L
.47962 .25 L
.47962 .25 L
.47963 .25 L
.47964 .25 L
.47964 .25 L
.47965 .25 L
.47965 .25 L
.47966 .25 L
.47967 .25 L
.47967 .25 L
.47968 .25 L
.47969 .25 L
.47969 .25 L
.4797 .25 L
.4797 .25 L
.47971 .25 L
.47971 .25 L
.47972 .25 L
.47973 .25 L
.47973 .25 L
Mistroke
.47974 .25 L
.47974 .25 L
.47975 .25 L
.47975 .25 L
.47976 .25 L
.47977 .25 L
.47977 .25 L
.47978 .25 L
.47978 .25 L
.47979 .25 L
.4798 .25 L
.4798 .25 L
.4798 .25 L
.47981 .25 L
.47982 .25 L
.47982 .25 L
.47983 .25 L
.47983 .25 L
.47984 .25 L
.47984 .25 L
.47985 .25 L
.47986 .25 L
.47986 .25 L
.47987 .25 L
.47987 .25 L
.47988 .25 L
.47988 .25 L
.47989 .25 L
.47989 .25 L
.4799 .25 L
.4799 .25 L
.47991 .25 L
.47992 .25 L
.47992 .25 L
.47993 .25 L
.47993 .25 L
.47994 .25 L
.47995 .25 L
.47995 .25 L
.47996 .25 L
.47996 .25 L
.47997 .25 L
.47998 .25 L
.47998 .25 L
.47999 .25 L
.47999 .25 L
.48 .25 L
.48001 .25 L
.48001 .25 L
.48002 .25 L
Mistroke
.48003 .25 L
.48003 .25 L
.48003 .25 L
.48004 .25 L
.48004 .25 L
.48005 .25 L
.48006 .25 L
.48006 .25 L
.48007 .25 L
.48007 .25 L
.48008 .25 L
.48009 .25 L
.48009 .25 L
.4801 .25 L
.48011 .25 L
.48011 .25 L
.48012 .25 L
.48013 .25 L
.48013 .25 L
.48014 .25 L
.48014 .25 L
.48015 .25 L
.48016 .25 L
.48016 .25 L
.48017 .25 L
.48017 .25 L
.48017 .25 L
.48018 .25 L
.48018 .25 L
.48019 .25 L
.48019 .25 L
.48019 .25 L
.4802 .25 L
.4802 .25 L
.48021 .25 L
.48021 .25 L
.48021 .25 L
.48022 .25 L
.48022 .25 L
.48023 .25 L
.48024 .25 L
.48024 .25 L
.48025 .25 L
.48026 .25 L
.48026 .25 L
.48027 .25 L
.48027 .25 L
.48028 .25 L
.48029 .25 L
.48029 .25 L
Mistroke
.4803 .25 L
.48031 .25 L
.48031 .25 L
.48032 .25 L
.48032 .25 L
.48033 .25 L
.48033 .25 L
.48034 .25 L
.48035 .25 L
.48035 .25 L
.48036 .25 L
.48036 .25 L
.48037 .25 L
.48038 .25 L
.48038 .25 L
.48039 .25 L
.48039 .25 L
.4804 .25 L
.48041 .25 L
.48041 .25 L
.48042 .25 L
.48042 .25 L
.48043 .25 L
.48043 .25 L
.48044 .25 L
.48045 .25 L
.48045 .25 L
.48046 .25 L
.48047 .25 L
.48047 .25 L
.48048 .25 L
.48048 .25 L
.48049 .25 L
.4805 .25 L
.4805 .25 L
.48051 .25 L
.48052 .25 L
.48052 .25 L
.48052 .25 L
.48053 .25 L
.48054 .25 L
.48054 .25 L
.48055 .25 L
.48056 .25 L
.48056 .25 L
.48057 .25 L
.48057 .25 L
.48058 .25 L
.48058 .25 L
.48059 .25 L
Mistroke
.4806 .25 L
.4806 .25 L
.48061 .25 L
.48062 .25 L
.48062 .25 L
.48062 .25 L
.48063 .25 L
.48064 .25 L
.48064 .25 L
.48065 .25 L
.48065 .25 L
.48066 .25 L
.48066 .25 L
.48067 .25 L
.48067 .25 L
.48068 .25 L
.48069 .25 L
.48069 .25 L
.4807 .25 L
.4807 .25 L
.48071 .25 L
.48071 .25 L
.48071 .25 L
.48072 .25 L
.48073 .25 L
.48073 .25 L
.48074 .25 L
.48075 .25 L
.48075 .25 L
.48076 .25 L
.48076 .25 L
.48077 .25 L
.48078 .25 L
.48078 .25 L
.48079 .25 L
.48079 .25 L
.4808 .25 L
.48081 .25 L
.48081 .25 L
.48082 .25 L
.48083 .25 L
.48083 .25 L
.48084 .25 L
.48084 .25 L
.48085 .25 L
.48085 .25 L
.48086 .25 L
.48086 .25 L
.48087 .25 L
.48087 .25 L
Mistroke
.48088 .25 L
.48089 .25 L
.48089 .25 L
.4809 .25 L
.4809 .25 L
.48091 .25 L
.48092 .25 L
.48092 .25 L
.48093 .25 L
.48094 .25 L
.48094 .25 L
.48095 .25 L
.48096 .25 L
.48096 .25 L
.48097 .25 L
.48098 .25 L
.48098 .25 L
.48098 .25 L
.48099 .25 L
.48099 .25 L
.481 .25 L
.481 .25 L
.481 .25 L
.48101 .25 L
.48101 .25 L
.48102 .25 L
.48102 .25 L
.48103 .25 L
.48103 .25 L
.48103 .25 L
.48104 .25 L
.48104 .25 L
.48105 .25 L
.48105 .25 L
.48106 .25 L
.48107 .25 L
.48107 .25 L
.48108 .25 L
.48109 .25 L
.48109 .25 L
.4811 .25 L
.4811 .25 L
.48111 .25 L
.48112 .25 L
.48112 .25 L
.48113 .25 L
.48114 .25 L
.48114 .25 L
.48114 .25 L
.48115 .25 L
Mistroke
.48116 .25 L
.48116 .25 L
.48117 .25 L
.48118 .25 L
.48118 .25 L
.48119 .25 L
.48119 .25 L
.4812 .25 L
.48121 .25 L
.48121 .25 L
.48122 .25 L
.48122 .25 L
.48123 .25 L
.48124 .25 L
.48124 .25 L
.48124 .25 L
.48125 .25 L
.48126 .25 L
.48126 .25 L
.48127 .25 L
.48128 .25 L
.48128 .25 L
.48129 .25 L
.48129 .25 L
.4813 .25 L
.48131 .25 L
.48131 .25 L
.48132 .25 L
.48133 .25 L
.48133 .25 L
.48134 .25 L
.48134 .25 L
.48135 .25 L
.48135 .25 L
.48136 .25 L
.48137 .25 L
.48137 .25 L
.48138 .25 L
.48139 .25 L
.48139 .25 L
.4814 .25 L
.4814 .25 L
.48141 .25 L
.48141 .25 L
.48142 .25 L
.48143 .25 L
.48143 .25 L
.48144 .25 L
.48144 .25 L
.48145 .25 L
Mistroke
.48145 .25 L
.48146 .25 L
.48147 .25 L
.48147 .25 L
.48147 .25 L
.48148 .25 L
.48149 .25 L
.48149 .25 L
.4815 .25 L
.4815 .25 L
.48151 .25 L
.48152 .25 L
.48152 .25 L
.48152 .25 L
.48153 .25 L
.48153 .25 L
.48154 .25 L
.48154 .25 L
.48155 .25 L
.48156 .25 L
.48156 .25 L
.48157 .25 L
.48158 .25 L
.48158 .25 L
.48159 .25 L
.48159 .25 L
.4816 .25 L
.48161 .25 L
.48161 .25 L
.48162 .25 L
.48162 .25 L
.48163 .25 L
.48164 .25 L
.48164 .25 L
.48165 .25 L
.48165 .25 L
.48166 .25 L
.48167 .25 L
.48167 .25 L
.48168 .25 L
.48168 .25 L
.48169 .25 L
.48169 .25 L
.4817 .25 L
.4817 .25 L
.48171 .25 L
.48172 .25 L
.48172 .25 L
.48173 .25 L
.48173 .25 L
Mistroke
.48174 .25 L
.48175 .25 L
.48175 .25 L
.48176 .25 L
.48177 .25 L
.48177 .25 L
.48178 .25 L
.48179 .25 L
.48179 .25 L
.4818 .25 L
.4818 .25 L
.48181 .25 L
.48181 .25 L
.48182 .25 L
.48182 .25 L
.48182 .25 L
.48183 .25 L
.48183 .25 L
.48184 .25 L
.48184 .25 L
.48185 .25 L
.48185 .25 L
.48185 .25 L
.48186 .25 L
.48186 .25 L
.48186 .25 L
.48187 .25 L
.48188 .25 L
.48188 .25 L
.48189 .25 L
.4819 .25 L
.4819 .25 L
.48191 .25 L
.48192 .25 L
.48192 .25 L
.48193 .25 L
.48193 .25 L
.48194 .25 L
.48195 .25 L
.48195 .25 L
.48196 .25 L
.48196 .25 L
.48197 .25 L
.48198 .25 L
.48198 .25 L
.48199 .25 L
.48199 .25 L
.482 .25 L
.48201 .25 L
.48201 .25 L
Mistroke
.48202 .25 L
.48202 .25 L
.48203 .25 L
.48203 .25 L
.48204 .25 L
.48205 .25 L
.48205 .25 L
.48206 .25 L
.48206 .25 L
.48207 .25 L
.48207 .25 L
.48208 .25 L
.48209 .25 L
.48209 .25 L
.4821 .25 L
.48211 .25 L
.48211 .25 L
.48212 .25 L
.48212 .25 L
.48213 .25 L
.48214 .25 L
.48214 .25 L
.48215 .25 L
.48216 .25 L
.48216 .25 L
.48217 .25 L
.48217 .25 L
.48218 .25 L
.48218 .25 L
.48219 .25 L
.4822 .25 L
.4822 .25 L
.48221 .25 L
.48221 .25 L
.48222 .25 L
.48222 .25 L
.48223 .25 L
.48224 .25 L
.48224 .25 L
.48225 .25 L
.48226 .25 L
.48226 .25 L
.48227 .25 L
.48227 .25 L
.48228 .25 L
.48228 .25 L
.48229 .25 L
.4823 .25 L
.4823 .25 L
.48231 .25 L
Mistroke
.48231 .25 L
.48232 .25 L
.48233 .25 L
.48233 .25 L
.48234 .25 L
.48235 .25 L
.48235 .25 L
.48236 .25 L
.48237 .25 L
.48237 .25 L
.48237 .25 L
.48238 .25 L
.48239 .25 L
.48239 .25 L
.4824 .25 L
.4824 .25 L
.48241 .25 L
.48242 .25 L
.48242 .25 L
.48243 .25 L
.48243 .25 L
.48244 .25 L
.48245 .25 L
.48245 .25 L
.48246 .25 L
.48246 .25 L
.48247 .25 L
.48247 .25 L
.48248 .25 L
.48248 .25 L
.48249 .25 L
.48249 .25 L
.4825 .25 L
.4825 .25 L
.48251 .25 L
.48252 .25 L
.48252 .25 L
.48253 .25 L
.48254 .25 L
.48254 .25 L
.48255 .25 L
.48255 .25 L
.48256 .25 L
.48256 .25 L
.48256 .25 L
.48257 .25 L
.48258 .25 L
.48258 .25 L
.48259 .25 L
.4826 .25 L
Mistroke
.4826 .25 L
.48261 .25 L
.48261 .25 L
.48262 .25 L
.48262 .25 L
.48263 .25 L
.48264 .25 L
.48264 .25 L
.48265 .25 L
.48266 .25 L
.48266 .25 L
.48267 .25 L
.48267 .25 L
.48268 .25 L
.48269 .25 L
.48269 .25 L
.4827 .25 L
.4827 .25 L
.48271 .25 L
.48271 .25 L
.48272 .25 L
.48272 .25 L
.48273 .25 L
.48274 .25 L
.48274 .25 L
.48275 .25 L
.48275 .25 L
.48276 .25 L
.48277 .25 L
.48277 .25 L
.48278 .25 L
.48279 .25 L
.48279 .25 L
.4828 .25 L
.48281 .25 L
.48281 .25 L
.48282 .25 L
.48282 .25 L
.48283 .25 L
.48283 .25 L
.48284 .25 L
.48284 .25 L
.48285 .25 L
.48285 .25 L
.48285 .25 L
.48286 .25 L
.48286 .25 L
.48287 .25 L
.48287 .25 L
.48288 .25 L
Mistroke
.48288 .25 L
.48288 .25 L
.48289 .25 L
.48289 .25 L
.4829 .25 L
.4829 .25 L
.48291 .25 L
.48292 .25 L
.48292 .25 L
.48293 .25 L
.48294 .25 L
.48294 .25 L
.48295 .25 L
.48295 .25 L
.48296 .25 L
.48297 .25 L
.48297 .25 L
.48298 .25 L
.48299 .25 L
.48299 .25 L
.48299 .25 L
.483 .25 L
.48301 .25 L
.48301 .25 L
.48302 .25 L
.48303 .25 L
.48303 .25 L
.48304 .25 L
.48304 .25 L
.48305 .25 L
.48306 .25 L
.48306 .25 L
.48307 .25 L
.48307 .25 L
.48308 .25 L
.48309 .25 L
.48309 .25 L
.48309 .25 L
.4831 .25 L
.48311 .25 L
.48311 .25 L
.48312 .25 L
.48313 .25 L
.48313 .25 L
.48314 .25 L
.48314 .25 L
.48315 .25 L
.48316 .25 L
.48316 .25 L
.48317 .25 L
Mistroke
.48318 .25 L
.48318 .25 L
.48319 .25 L
.48319 .25 L
.4832 .25 L
.4832 .25 L
.48321 .25 L
.48322 .25 L
.48322 .25 L
.48323 .25 L
.48324 .25 L
.48324 .25 L
.48325 .25 L
.48325 .25 L
.48326 .25 L
.48326 .25 L
.48327 .25 L
.48328 .25 L
.48328 .25 L
.48329 .25 L
.48329 .25 L
.4833 .25 L
.4833 .25 L
.48331 .25 L
.48332 .25 L
.48332 .25 L
.48332 .25 L
.48333 .25 L
.48333 .25 L
.48334 .25 L
.48335 .25 L
.48335 .25 L
.48336 .25 L
.48337 .25 L
.48337 .25 L
.48337 .25 L
.48338 .25 L
.48338 .25 L
.48339 .25 L
.48339 .25 L
.4834 .25 L
.48341 .25 L
.48341 .25 L
.48342 .25 L
.48343 .25 L
.48343 .25 L
.48344 .25 L
.48344 .25 L
.48345 .25 L
.48346 .25 L
Mistroke
.48346 .25 L
.48347 .25 L
.48347 .25 L
.48348 .25 L
.48349 .25 L
.48349 .25 L
.4835 .25 L
.4835 .25 L
.48351 .25 L
.48352 .25 L
.48352 .25 L
.48353 .25 L
.48353 .25 L
.48354 .25 L
.48354 .25 L
.48355 .25 L
.48355 .25 L
.48356 .25 L
.48357 .25 L
.48357 .25 L
.48358 .25 L
.48358 .25 L
.48359 .25 L
.4836 .25 L
.4836 .25 L
.48361 .25 L
.48362 .25 L
.48362 .25 L
.48363 .25 L
.48364 .25 L
.48364 .25 L
.48365 .25 L
.48365 .25 L
.48366 .25 L
.48366 .25 L
.48367 .25 L
.48367 .25 L
.48367 .25 L
.48368 .25 L
.48368 .25 L
.48369 .25 L
.48369 .25 L
.4837 .25 L
.4837 .25 L
.4837 .25 L
.48371 .25 L
.48371 .25 L
.48371 .25 L
.48372 .25 L
.48373 .25 L
Mistroke
.48373 .25 L
.48374 .25 L
.48375 .25 L
.48375 .25 L
.48376 .25 L
.48377 .25 L
.48377 .25 L
.48378 .25 L
.48378 .25 L
.48379 .25 L
.4838 .25 L
.4838 .25 L
.48381 .25 L
.48381 .25 L
.48382 .25 L
.48383 .25 L
.48383 .25 L
.48384 .25 L
.48384 .25 L
.48385 .25 L
.48386 .25 L
.48386 .25 L
.48387 .25 L
.48387 .25 L
.48388 .25 L
.48388 .25 L
.48389 .25 L
.4839 .25 L
.4839 .25 L
.48391 .25 L
.48391 .25 L
.48392 .25 L
.48392 .25 L
.48393 .25 L
.48394 .25 L
.48394 .25 L
.48395 .25 L
.48396 .25 L
.48396 .25 L
.48397 .25 L
.48397 .25 L
.48398 .25 L
.48399 .25 L
.48399 .25 L
.484 .25 L
.48401 .25 L
.48401 .25 L
.48402 .25 L
.48402 .25 L
.48403 .25 L
Mistroke
.48403 .25 L
.48404 .25 L
.48405 .25 L
.48405 .25 L
.48406 .25 L
.48406 .25 L
.48407 .25 L
.48408 .25 L
.48408 .25 L
.48409 .25 L
.48409 .25 L
.4841 .25 L
.48411 .25 L
.48411 .25 L
.48412 .25 L
.48412 .25 L
.48413 .25 L
.48413 .25 L
.48414 .25 L
.48414 .25 L
.48415 .25 L
.48415 .25 L
.48416 .25 L
.48416 .25 L
.48417 .25 L
.48418 .25 L
.48418 .25 L
.48419 .25 L
.48419 .25 L
.4842 .25 L
.4842 .25 L
.48421 .25 L
.48421 .25 L
.48422 .25 L
.48422 .25 L
.48423 .25 L
.48424 .25 L
.48424 .25 L
.48425 .25 L
.48425 .25 L
.48426 .25 L
.48427 .25 L
.48427 .25 L
.48428 .25 L
.48428 .25 L
.48429 .25 L
.4843 .25 L
.4843 .25 L
.48431 .25 L
.48432 .25 L
Mistroke
.48432 .25 L
.48433 .25 L
.48434 .25 L
.48434 .25 L
.48435 .25 L
.48435 .25 L
.48436 .25 L
.48436 .25 L
.48436 .25 L
.48437 .25 L
.48438 .25 L
.48438 .25 L
.48439 .25 L
.4844 .25 L
.4844 .25 L
.48441 .25 L
.48441 .25 L
.48442 .25 L
.48443 .25 L
.48443 .25 L
.48444 .25 L
.48445 .25 L
.48445 .25 L
.48446 .25 L
.48447 .25 L
.48447 .25 L
.48448 .25 L
.48448 .25 L
.48449 .25 L
.48449 .25 L
.48449 .25 L
.4845 .25 L
.4845 .25 L
.48451 .25 L
.48451 .25 L
.48452 .25 L
.48452 .25 L
.48452 .25 L
.48453 .25 L
.48453 .25 L
.48453 .25 L
.48454 .25 L
.48454 .25 L
.48455 .25 L
.48456 .25 L
.48456 .25 L
.48457 .25 L
.48458 .25 L
.48458 .25 L
.48459 .25 L
Mistroke
.4846 .25 L
.4846 .25 L
.48461 .25 L
.48462 .25 L
.48462 .25 L
.48463 .25 L
.48463 .25 L
.48464 .25 L
.48464 .25 L
.48465 .25 L
.48466 .25 L
.48466 .25 L
.48467 .25 L
.48467 .25 L
.48468 .25 L
.48469 .25 L
.48469 .25 L
.4847 .25 L
.4847 .25 L
.48471 .25 L
.48472 .25 L
.48472 .25 L
.48473 .25 L
.48473 .25 L
.48474 .25 L
.48474 .25 L
.48475 .25 L
.48475 .25 L
.48476 .25 L
.48477 .25 L
.48477 .25 L
.48478 .25 L
.48479 .25 L
.48479 .25 L
.4848 .25 L
.4848 .25 L
.48481 .25 L
.48482 .25 L
.48482 .25 L
.48483 .25 L
.48484 .25 L
.48484 .25 L
.48484 .25 L
.48485 .25 L
.48486 .25 L
.48486 .25 L
.48487 .25 L
.48488 .25 L
.48488 .25 L
.48489 .25 L
Mistroke
.48489 .25 L
.4849 .25 L
.4849 .25 L
.48491 .25 L
.48492 .25 L
.48492 .25 L
.48493 .25 L
.48494 .25 L
.48494 .25 L
.48494 .25 L
.48495 .25 L
.48496 .25 L
.48496 .25 L
.48497 .25 L
.48497 .25 L
.48498 .25 L
.48498 .25 L
.48499 .25 L
.48499 .25 L
.485 .25 L
.48501 .25 L
.48501 .25 L
.48502 .25 L
.48502 .25 L
.48503 .25 L
.48503 .25 L
.48503 .25 L
.48504 .25 L
.48505 .25 L
.48505 .25 L
.48506 .25 L
.48507 .25 L
.48507 .25 L
.48508 .25 L
.48508 .25 L
.48509 .25 L
.4851 .25 L
.4851 .25 L
.48511 .25 L
.48511 .25 L
.48512 .25 L
.48513 .25 L
.48513 .25 L
.48514 .25 L
.48515 .25 L
.48515 .25 L
.48516 .25 L
.48517 .25 L
.48517 .25 L
.48518 .25 L
Mistroke
.48518 .25 L
.48518 .25 L
.48519 .25 L
.48519 .25 L
.4852 .25 L
.48521 .25 L
.48521 .25 L
.48522 .25 L
.48523 .25 L
.48523 .25 L
.48524 .25 L
.48524 .25 L
.48525 .25 L
.48526 .25 L
.48526 .25 L
.48527 .25 L
.48528 .25 L
.48528 .25 L
.48529 .25 L
.4853 .25 L
.4853 .25 L
.4853 .25 L
.48531 .25 L
.48531 .25 L
.48532 .25 L
.48532 .25 L
.48532 .25 L
.48533 .25 L
.48534 .25 L
.48534 .25 L
.48534 .25 L
.48535 .25 L
.48535 .25 L
.48535 .25 L
.48536 .25 L
.48536 .25 L
.48537 .25 L
.48537 .25 L
.48538 .25 L
.48539 .25 L
.48539 .25 L
.4854 .25 L
.48541 .25 L
.48541 .25 L
.48542 .25 L
.48542 .25 L
.48543 .25 L
.48544 .25 L
.48544 .25 L
.48545 .25 L
Mistroke
.48546 .25 L
.48546 .25 L
.48547 .25 L
.48547 .25 L
.48548 .25 L
.48548 .25 L
.48549 .25 L
.4855 .25 L
.4855 .25 L
.48551 .25 L
.48551 .25 L
.48552 .25 L
.48553 .25 L
.48553 .25 L
.48554 .25 L
.48554 .25 L
.48555 .25 L
.48556 .25 L
.48556 .25 L
.48556 .25 L
.48557 .25 L
.48558 .25 L
.48558 .25 L
.48559 .25 L
.4856 .25 L
.4856 .25 L
.48561 .25 L
.48561 .25 L
.48562 .25 L
.48563 .25 L
.48563 .25 L
.48564 .25 L
.48565 .25 L
.48565 .25 L
.48566 .25 L
.48566 .25 L
.48567 .25 L
.48567 .25 L
.48568 .25 L
.48569 .25 L
.48569 .25 L
.4857 .25 L
.48571 .25 L
.48571 .25 L
.48572 .25 L
.48572 .25 L
.48573 .25 L
.48573 .25 L
.48574 .25 L
.48575 .25 L
Mistroke
.48575 .25 L
.48576 .25 L
.48576 .25 L
.48577 .25 L
.48577 .25 L
.48578 .25 L
.48579 .25 L
.48579 .25 L
.4858 .25 L
.48581 .25 L
.48581 .25 L
.48582 .25 L
.48582 .25 L
.48583 .25 L
.48584 .25 L
.48584 .25 L
.48585 .25 L
.48586 .25 L
.48586 .25 L
.48587 .25 L
.48587 .25 L
.48588 .25 L
.48588 .25 L
.48589 .25 L
.4859 .25 L
.4859 .25 L
.48591 .25 L
.48591 .25 L
.48592 .25 L
.48593 .25 L
.48593 .25 L
.48594 .25 L
.48594 .25 L
.48595 .25 L
.48596 .25 L
.48596 .25 L
.48597 .25 L
.48597 .25 L
.48598 .25 L
.48598 .25 L
.48599 .25 L
.48599 .25 L
.486 .25 L
.486 .25 L
.48601 .25 L
.48601 .25 L
.48602 .25 L
.48603 .25 L
.48603 .25 L
.48604 .25 L
Mistroke
.48604 .25 L
.48605 .25 L
.48605 .25 L
.48606 .25 L
.48606 .25 L
.48607 .25 L
.48607 .25 L
.48608 .25 L
.48609 .25 L
.48609 .25 L
.4861 .25 L
.4861 .25 L
.48611 .25 L
.48612 .25 L
.48612 .25 L
.48613 .25 L
.48613 .25 L
.48614 .25 L
.48615 .25 L
.48615 .25 L
.48616 .25 L
.48617 .25 L
.48617 .25 L
.48618 .25 L
.48618 .25 L
.48619 .25 L
.4862 .25 L
.4862 .25 L
.48621 .25 L
.48621 .25 L
.48621 .25 L
.48622 .25 L
.48623 .25 L
.48623 .25 L
.48624 .25 L
.48625 .25 L
.48625 .25 L
.48626 .25 L
.48626 .25 L
.48627 .25 L
.48628 .25 L
.48628 .25 L
.48629 .25 L
.4863 .25 L
.4863 .25 L
.48631 .25 L
.48631 .25 L
.48632 .25 L
.48633 .25 L
.48633 .25 L
Mistroke
.48634 .25 L
.48634 .25 L
.48634 .25 L
.48635 .25 L
.48635 .25 L
.48636 .25 L
.48636 .25 L
.48637 .25 L
.48637 .25 L
.48637 .25 L
.48638 .25 L
.48638 .25 L
.48638 .25 L
.48639 .25 L
.48639 .25 L
.4864 .25 L
.48641 .25 L
.48641 .25 L
.48642 .25 L
.48643 .25 L
.48643 .25 L
.48644 .25 L
.48645 .25 L
.48645 .25 L
.48646 .25 L
.48646 .25 L
.48647 .25 L
.48648 .25 L
.48648 .25 L
.48649 .25 L
.48649 .25 L
.4865 .25 L
.48651 .25 L
.48651 .25 L
.48652 .25 L
.48652 .25 L
.48653 .25 L
.48654 .25 L
.48654 .25 L
.48655 .25 L
.48655 .25 L
.48656 .25 L
.48656 .25 L
.48657 .25 L
.48658 .25 L
.48658 .25 L
.48659 .25 L
.48659 .25 L
.4866 .25 L
.4866 .25 L
Mistroke
.48661 .25 L
.48662 .25 L
.48662 .25 L
.48663 .25 L
.48664 .25 L
.48664 .25 L
.48665 .25 L
.48665 .25 L
.48666 .25 L
.48667 .25 L
.48667 .25 L
.48668 .25 L
.48669 .25 L
.48669 .25 L
.48669 .25 L
.4867 .25 L
.48671 .25 L
.48671 .25 L
.48672 .25 L
.48673 .25 L
.48673 .25 L
.48674 .25 L
.48674 .25 L
.48675 .25 L
.48675 .25 L
.48676 .25 L
.48677 .25 L
.48677 .25 L
.48678 .25 L
.48679 .25 L
.48679 .25 L
.48679 .25 L
.4868 .25 L
.48681 .25 L
.48681 .25 L
.48682 .25 L
.48682 .25 L
.48683 .25 L
.48683 .25 L
.48684 .25 L
.48684 .25 L
.48685 .25 L
.48686 .25 L
.48686 .25 L
.48687 .25 L
.48687 .25 L
.48688 .25 L
.48688 .25 L
.48688 .25 L
.48689 .25 L
Mistroke
.4869 .25 L
.4869 .25 L
.48691 .25 L
.48692 .25 L
.48692 .25 L
.48693 .25 L
.48693 .25 L
.48694 .25 L
.48695 .25 L
.48695 .25 L
.48696 .25 L
.48696 .25 L
.48697 .25 L
.48698 .25 L
.48698 .25 L
.48699 .25 L
.487 .25 L
.487 .25 L
.48701 .25 L
.48702 .25 L
.48702 .25 L
.48703 .25 L
.48703 .25 L
.48703 .25 L
.48704 .25 L
.48704 .25 L
.48705 .25 L
.48706 .25 L
.48706 .25 L
.48707 .25 L
.48708 .25 L
.48708 .25 L
.48709 .25 L
.48709 .25 L
.4871 .25 L
.48711 .25 L
.48711 .25 L
.48712 .25 L
.48713 .25 L
.48713 .25 L
.48714 .25 L
.48715 .25 L
.48715 .25 L
.48715 .25 L
.48716 .25 L
.48716 .25 L
.48717 .25 L
.48717 .25 L
.48717 .25 L
.48718 .25 L
Mistroke
.48719 .25 L
.48719 .25 L
.48719 .25 L
.4872 .25 L
.4872 .25 L
.4872 .25 L
.48721 .25 L
.48721 .25 L
.48722 .25 L
.48722 .25 L
.48723 .25 L
.48724 .25 L
.48725 .25 L
.48725 .25 L
.48726 .25 L
.48726 .25 L
.48727 .25 L
.48728 .25 L
.48728 .25 L
.48729 .25 L
.48729 .25 L
.4873 .25 L
.48731 .25 L
.48731 .25 L
.48732 .25 L
.48732 .25 L
.48733 .25 L
.48733 .25 L
.48734 .25 L
.48735 .25 L
.48735 .25 L
.48736 .25 L
.48736 .25 L
.48737 .25 L
.48738 .25 L
.48738 .25 L
.48739 .25 L
.48739 .25 L
.4874 .25 L
.48741 .25 L
.48741 .25 L
.48741 .25 L
.48742 .25 L
.48743 .25 L
.48743 .25 L
.48744 .25 L
.48745 .25 L
.48745 .25 L
.48746 .25 L
.48747 .25 L
Mistroke
.48747 .25 L
.48748 .25 L
.48748 .25 L
.48749 .25 L
.4875 .25 L
.4875 .25 L
.48751 .25 L
.48751 .25 L
.48752 .25 L
.48753 .25 L
.48753 .25 L
.48754 .25 L
.48754 .25 L
.48755 .25 L
.48756 .25 L
.48756 .25 L
.48757 .25 L
.48757 .25 L
.48758 .25 L
.48758 .25 L
.48759 .25 L
.4876 .25 L
.4876 .25 L
.48761 .25 L
.48761 .25 L
.48762 .25 L
.48762 .25 L
.48763 .25 L
.48764 .25 L
.48764 .25 L
.48764 .25 L
.48765 .25 L
.48766 .25 L
.48766 .25 L
.48767 .25 L
.48767 .25 L
.48768 .25 L
.48769 .25 L
.48769 .25 L
.48769 .25 L
.4877 .25 L
.4877 .25 L
.48771 .25 L
.48771 .25 L
.48772 .25 L
.48773 .25 L
.48773 .25 L
.48774 .25 L
.48775 .25 L
.48775 .25 L
Mistroke
.48776 .25 L
.48776 .25 L
.48777 .25 L
.48778 .25 L
.48778 .25 L
.48779 .25 L
.48779 .25 L
.4878 .25 L
.48781 .25 L
.48781 .25 L
.48782 .25 L
.48783 .25 L
.48783 .25 L
.48784 .25 L
.48785 .25 L
.48785 .25 L
.48785 .25 L
.48786 .25 L
.48786 .25 L
.48787 .25 L
.48787 .25 L
.48788 .25 L
.48789 .25 L
.48789 .25 L
.4879 .25 L
.48791 .25 L
.48791 .25 L
.48792 .25 L
.48792 .25 L
.48793 .25 L
.48794 .25 L
.48794 .25 L
.48795 .25 L
.48796 .25 L
.48796 .25 L
.48797 .25 L
.48797 .25 L
.48798 .25 L
.48798 .25 L
.48799 .25 L
.48799 .25 L
.48799 .25 L
.488 .25 L
.48801 .25 L
.48801 .25 L
.48801 .25 L
.48802 .25 L
.48802 .25 L
.48802 .25 L
.48803 .25 L
Mistroke
.48803 .25 L
.48804 .25 L
.48804 .25 L
.48805 .25 L
.48806 .25 L
.48806 .25 L
.48807 .25 L
.48807 .25 L
.48808 .25 L
.48809 .25 L
.48809 .25 L
.4881 .25 L
.48811 .25 L
.48811 .25 L
.48812 .25 L
.48812 .25 L
.48813 .25 L
.48814 .25 L
.48814 .25 L
.48815 .25 L
.48815 .25 L
.48816 .25 L
.48816 .25 L
.48817 .25 L
.48818 .25 L
.48818 .25 L
.48819 .25 L
.48819 .25 L
.4882 .25 L
.48821 .25 L
.48821 .25 L
.48822 .25 L
.48822 .25 L
.48823 .25 L
.48823 .25 L
.48824 .25 L
.48824 .25 L
.48825 .25 L
.48826 .25 L
.48826 .25 L
.48827 .25 L
.48828 .25 L
.48828 .25 L
.48829 .25 L
.4883 .25 L
.4883 .25 L
.48831 .25 L
.48831 .25 L
.48832 .25 L
.48833 .25 L
Mistroke
.48833 .25 L
.48834 .25 L
.48834 .25 L
.48835 .25 L
.48836 .25 L
.48836 .25 L
.48837 .25 L
.48837 .25 L
.48838 .25 L
.48839 .25 L
.48839 .25 L
.4884 .25 L
.4884 .25 L
.48841 .25 L
.48841 .25 L
.48842 .25 L
.48843 .25 L
.48843 .25 L
.48844 .25 L
.48844 .25 L
.48845 .25 L
.48845 .25 L
.48846 .25 L
.48846 .25 L
.48847 .25 L
.48847 .25 L
.48848 .25 L
.48849 .25 L
.48849 .25 L
.4885 .25 L
.4885 .25 L
.48851 .25 L
.48851 .25 L
.48852 .25 L
.48852 .25 L
.48853 .25 L
.48853 .25 L
.48854 .25 L
.48855 .25 L
.48855 .25 L
.48856 .25 L
.48856 .25 L
.48857 .25 L
.48858 .25 L
.48858 .25 L
.48859 .25 L
.48859 .25 L
.4886 .25 L
.48861 .25 L
.48861 .25 L
Mistroke
.48862 .25 L
.48862 .25 L
.48863 .25 L
.48864 .25 L
.48864 .25 L
.48865 .25 L
.48866 .25 L
.48866 .25 L
.48867 .25 L
.48867 .25 L
.48868 .25 L
.48868 .25 L
.48868 .25 L
.48869 .25 L
.4887 .25 L
.4887 .25 L
.48871 .25 L
.48872 .25 L
.48872 .25 L
.48873 .25 L
.48873 .25 L
.48874 .25 L
.48875 .25 L
.48875 .25 L
.48876 .25 L
.48877 .25 L
.48877 .25 L
.48878 .25 L
.48879 .25 L
.48879 .25 L
.4888 .25 L
.4888 .25 L
.48881 .25 L
.48881 .25 L
.48881 .25 L
.48882 .25 L
.48882 .25 L
.48883 .25 L
.48883 .25 L
.48884 .25 L
.48884 .25 L
.48884 .25 L
.48885 .25 L
.48885 .25 L
.48886 .25 L
.48886 .25 L
.48887 .25 L
.48887 .25 L
.48888 .25 L
.48889 .25 L
Mistroke
.48889 .25 L
.4889 .25 L
.4889 .25 L
.48891 .25 L
.48892 .25 L
.48892 .25 L
.48893 .25 L
.48894 .25 L
.48894 .25 L
.48895 .25 L
.48896 .25 L
.48896 .25 L
.48896 .25 L
.48897 .25 L
.48898 .25 L
.48898 .25 L
.48899 .25 L
.48899 .25 L
.489 .25 L
.48901 .25 L
.48901 .25 L
.48902 .25 L
.48902 .25 L
.48903 .25 L
.48904 .25 L
.48904 .25 L
.48905 .25 L
.48905 .25 L
.48906 .25 L
.48906 .25 L
.48907 .25 L
.48907 .25 L
.48908 .25 L
.48909 .25 L
.48909 .25 L
.4891 .25 L
.48911 .25 L
.48911 .25 L
.48912 .25 L
.48912 .25 L
.48913 .25 L
.48914 .25 L
.48914 .25 L
.48915 .25 L
.48916 .25 L
.48916 .25 L
.48917 .25 L
.48917 .25 L
.48918 .25 L
.48918 .25 L
Mistroke
.48919 .25 L
.4892 .25 L
.4892 .25 L
.48921 .25 L
.48921 .25 L
.48922 .25 L
.48923 .25 L
.48923 .25 L
.48924 .25 L
.48924 .25 L
.48925 .25 L
.48926 .25 L
.48926 .25 L
.48926 .25 L
.48927 .25 L
.48928 .25 L
.48928 .25 L
.48929 .25 L
.4893 .25 L
.4893 .25 L
.48931 .25 L
.48931 .25 L
.48932 .25 L
.48933 .25 L
.48933 .25 L
.48934 .25 L
.48935 .25 L
.48935 .25 L
.48936 .25 L
.48936 .25 L
.48937 .25 L
.48937 .25 L
.48938 .25 L
.48939 .25 L
.48939 .25 L
.4894 .25 L
.48941 .25 L
.48941 .25 L
.48942 .25 L
.48942 .25 L
.48943 .25 L
.48943 .25 L
.48944 .25 L
.48945 .25 L
.48945 .25 L
.48946 .25 L
.48946 .25 L
.48947 .25 L
.48947 .25 L
.48948 .25 L
Mistroke
.48949 .25 L
.48949 .25 L
.48949 .25 L
.4895 .25 L
.48951 .25 L
.48951 .25 L
.48952 .25 L
.48952 .25 L
.48953 .25 L
.48954 .25 L
.48954 .25 L
.48954 .25 L
.48955 .25 L
.48955 .25 L
.48956 .25 L
.48956 .25 L
.48957 .25 L
.48958 .25 L
.48958 .25 L
.48959 .25 L
.4896 .25 L
.4896 .25 L
.48961 .25 L
.48961 .25 L
.48962 .25 L
.48963 .25 L
.48963 .25 L
.48964 .25 L
.48964 .25 L
.48965 .25 L
.48966 .25 L
.48966 .25 L
.48967 .25 L
.48968 .25 L
.48968 .25 L
.48969 .25 L
.4897 .25 L
.4897 .25 L
.4897 .25 L
.48971 .25 L
.48971 .25 L
.48972 .25 L
.48972 .25 L
.48973 .25 L
.48974 .25 L
.48974 .25 L
.48975 .25 L
.48976 .25 L
.48976 .25 L
.48977 .25 L
Mistroke
.48977 .25 L
.48978 .25 L
.48979 .25 L
.48979 .25 L
.4898 .25 L
.48981 .25 L
.48981 .25 L
.48982 .25 L
.48982 .25 L
.48983 .25 L
.48983 .25 L
.48984 .25 L
.48984 .25 L
.48984 .25 L
.48985 .25 L
.48986 .25 L
.48986 .25 L
.48986 .25 L
.48987 .25 L
.48987 .25 L
.48987 .25 L
.48988 .25 L
.48988 .25 L
.48989 .25 L
.48989 .25 L
.4899 .25 L
.4899 .25 L
.48991 .25 L
.48992 .25 L
.48992 .25 L
.48993 .25 L
.48994 .25 L
.48994 .25 L
.48995 .25 L
.48996 .25 L
.48996 .25 L
.48997 .25 L
.48997 .25 L
.48998 .25 L
.48999 .25 L
.48999 .25 L
.49 .25 L
.49 .25 L
.49001 .25 L
.49001 .25 L
.49002 .25 L
.49003 .25 L
.49003 .25 L
.49004 .25 L
.49004 .25 L
Mistroke
.49005 .25 L
.49006 .25 L
.49006 .25 L
.49007 .25 L
.49007 .25 L
.49008 .25 L
.49008 .25 L
.49009 .25 L
.49009 .25 L
.4901 .25 L
.49011 .25 L
.49011 .25 L
.49012 .25 L
.49013 .25 L
.49013 .25 L
.49014 .25 L
.49015 .25 L
.49015 .25 L
.49016 .25 L
.49016 .25 L
.49017 .25 L
.49018 .25 L
.49018 .25 L
.49019 .25 L
.49019 .25 L
.4902 .25 L
.49021 .25 L
.49021 .25 L
.49022 .25 L
.49022 .25 L
.49023 .25 L
.49024 .25 L
.49024 .25 L
.49025 .25 L
.49025 .25 L
.49026 .25 L
.49026 .25 L
.49027 .25 L
.49028 .25 L
.49028 .25 L
.49029 .25 L
.49029 .25 L
.4903 .25 L
.4903 .25 L
.49031 .25 L
.49031 .25 L
.49032 .25 L
.49032 .25 L
.49033 .25 L
.49034 .25 L
Mistroke
.49034 .25 L
.49035 .25 L
.49035 .25 L
.49036 .25 L
.49036 .25 L
.49037 .25 L
.49037 .25 L
.49038 .25 L
.49038 .25 L
.49039 .25 L
.4904 .25 L
.4904 .25 L
.49041 .25 L
.49041 .25 L
.49042 .25 L
.49043 .25 L
.49043 .25 L
.49044 .25 L
.49044 .25 L
.49045 .25 L
.49046 .25 L
.49046 .25 L
.49047 .25 L
.49047 .25 L
.49048 .25 L
.49049 .25 L
.49049 .25 L
.4905 .25 L
.49051 .25 L
.49051 .25 L
.49052 .25 L
.49052 .25 L
.49053 .25 L
.49053 .25 L
.49053 .25 L
.49054 .25 L
.49055 .25 L
.49055 .25 L
.49056 .25 L
.49057 .25 L
.49057 .25 L
.49058 .25 L
.49058 .25 L
.49059 .25 L
.4906 .25 L
.4906 .25 L
.49061 .25 L
.49062 .25 L
.49062 .25 L
.49063 .25 L
Mistroke
.49064 .25 L
.49064 .25 L
.49065 .25 L
.49065 .25 L
.49066 .25 L
.49066 .25 L
.49066 .25 L
.49067 .25 L
.49067 .25 L
.49068 .25 L
.49068 .25 L
.49069 .25 L
.49069 .25 L
.49069 .25 L
.4907 .25 L
.4907 .25 L
.49071 .25 L
.49071 .25 L
.49072 .25 L
.49072 .25 L
.49073 .25 L
.49074 .25 L
.49074 .25 L
.49075 .25 L
.49075 .25 L
.49076 .25 L
.49077 .25 L
.49077 .25 L
.49078 .25 L
.49079 .25 L
.49079 .25 L
.4908 .25 L
.49081 .25 L
.49081 .25 L
.49081 .25 L
.49082 .25 L
.49083 .25 L
.49083 .25 L
.49084 .25 L
.49085 .25 L
.49085 .25 L
.49086 .25 L
.49086 .25 L
.49087 .25 L
.49087 .25 L
.49088 .25 L
.49089 .25 L
.49089 .25 L
.4909 .25 L
.4909 .25 L
Mistroke
.49091 .25 L
.49091 .25 L
.49092 .25 L
.49092 .25 L
.49093 .25 L
.49094 .25 L
.49094 .25 L
.49095 .25 L
.49096 .25 L
.49096 .25 L
.49097 .25 L
.49098 .25 L
.49098 .25 L
.49099 .25 L
.49099 .25 L
.491 .25 L
.49101 .25 L
.49101 .25 L
.49102 .25 L
.49102 .25 L
.49103 .25 L
.49103 .25 L
.49104 .25 L
.49105 .25 L
.49105 .25 L
.49106 .25 L
.49106 .25 L
.49107 .25 L
.49108 .25 L
.49108 .25 L
.49109 .25 L
.4911 .25 L
.4911 .25 L
.49111 .25 L
.49111 .25 L
.49111 .25 L
.49112 .25 L
.49113 .25 L
.49113 .25 L
.49114 .25 L
.49114 .25 L
.49115 .25 L
.49115 .25 L
.49116 .25 L
.49117 .25 L
.49117 .25 L
.49118 .25 L
.49118 .25 L
.49119 .25 L
.49119 .25 L
Mistroke
.4912 .25 L
.4912 .25 L
.49121 .25 L
.49121 .25 L
.49122 .25 L
.49123 .25 L
.49123 .25 L
.49124 .25 L
.49124 .25 L
.49125 .25 L
.49125 .25 L
.49126 .25 L
.49127 .25 L
.49127 .25 L
.49128 .25 L
.49129 .25 L
.49129 .25 L
.4913 .25 L
.4913 .25 L
.49131 .25 L
.49132 .25 L
.49132 .25 L
.49133 .25 L
.49134 .25 L
.49134 .25 L
.49135 .25 L
.49135 .25 L
.49135 .25 L
.49136 .25 L
.49136 .25 L
.49137 .25 L
.49138 .25 L
.49138 .25 L
.49139 .25 L
.4914 .25 L
.4914 .25 L
.49141 .25 L
.49141 .25 L
.49142 .25 L
.49143 .25 L
.49143 .25 L
.49144 .25 L
.49145 .25 L
.49145 .25 L
.49146 .25 L
.49147 .25 L
.49147 .25 L
.49147 .25 L
.49148 .25 L
.49149 .25 L
Mistroke
.49149 .25 L
.49149 .25 L
.4915 .25 L
.4915 .25 L
.49151 .25 L
.49151 .25 L
.49151 .25 L
.49152 .25 L
.49152 .25 L
.49153 .25 L
.49153 .25 L
.49153 .25 L
.49154 .25 L
.49155 .25 L
.49155 .25 L
.49156 .25 L
.49157 .25 L
.49157 .25 L
.49158 .25 L
.49158 .25 L
.49159 .25 L
.4916 .25 L
.4916 .25 L
.49161 .25 L
.49162 .25 L
.49162 .25 L
.49163 .25 L
.49163 .25 L
.49164 .25 L
.49164 .25 L
.49165 .25 L
.49166 .25 L
.49166 .25 L
.49167 .25 L
.49167 .25 L
.49168 .25 L
.49169 .25 L
.49169 .25 L
.4917 .25 L
.4917 .25 L
.49171 .25 L
.49172 .25 L
.49172 .25 L
.49173 .25 L
.49173 .25 L
.49174 .25 L
.49174 .25 L
.49175 .25 L
.49175 .25 L
.49176 .25 L
Mistroke
.49177 .25 L
.49177 .25 L
.49178 .25 L
.49179 .25 L
.49179 .25 L
.4918 .25 L
.49181 .25 L
.49181 .25 L
.49182 .25 L
.49182 .25 L
.49183 .25 L
.49184 .25 L
.49184 .25 L
.49185 .25 L
.49185 .25 L
.49186 .25 L
.49186 .25 L
.49187 .25 L
.49188 .25 L
.49188 .25 L
.49189 .25 L
.49189 .25 L
.4919 .25 L
.49191 .25 L
.49191 .25 L
.49192 .25 L
.49192 .25 L
.49193 .25 L
.49193 .25 L
.49194 .25 L
.49194 .25 L
.49195 .25 L
.49196 .25 L
.49196 .25 L
.49196 .25 L
.49197 .25 L
.49198 .25 L
.49198 .25 L
.49199 .25 L
.49199 .25 L
.492 .25 L
.49201 .25 L
.49201 .25 L
.49202 .25 L
.49202 .25 L
.49203 .25 L
.49203 .25 L
.49204 .25 L
.49204 .25 L
.49205 .25 L
Mistroke
.49206 .25 L
.49206 .25 L
.49207 .25 L
.49207 .25 L
.49208 .25 L
.49208 .25 L
.49209 .25 L
.4921 .25 L
.4921 .25 L
.49211 .25 L
.49212 .25 L
.49212 .25 L
.49213 .25 L
.49213 .25 L
.49214 .25 L
.49215 .25 L
.49215 .25 L
.49216 .25 L
.49217 .25 L
.49217 .25 L
.49217 .25 L
.49218 .25 L
.49218 .25 L
.49219 .25 L
.49219 .25 L
.4922 .25 L
.49221 .25 L
.49221 .25 L
.49222 .25 L
.49223 .25 L
.49223 .25 L
.49224 .25 L
.49225 .25 L
.49225 .25 L
.49226 .25 L
.49226 .25 L
.49227 .25 L
.49228 .25 L
.49228 .25 L
.49229 .25 L
.49229 .25 L
.4923 .25 L
.49231 .25 L
.49231 .25 L
.49231 .25 L
.49232 .25 L
.49232 .25 L
.49233 .25 L
.49233 .25 L
.49233 .25 L
Mistroke
.49234 .25 L
.49234 .25 L
.49235 .25 L
.49235 .25 L
.49235 .25 L
.49236 .25 L
.49236 .25 L
.49237 .25 L
.49238 .25 L
.49238 .25 L
.49239 .25 L
.4924 .25 L
.4924 .25 L
.49241 .25 L
.49241 .25 L
.49242 .25 L
.49243 .25 L
.49243 .25 L
.49244 .25 L
.49245 .25 L
.49245 .25 L
.49246 .25 L
.49246 .25 L
.49247 .25 L
.49247 .25 L
.49248 .25 L
.49249 .25 L
.49249 .25 L
.4925 .25 L
.4925 .25 L
.49251 .25 L
.49251 .25 L
.49252 .25 L
.49253 .25 L
.49253 .25 L
.49254 .25 L
.49255 .25 L
.49255 .25 L
.49256 .25 L
.49256 .25 L
.49257 .25 L
.49257 .25 L
.49258 .25 L
.49259 .25 L
.49259 .25 L
.4926 .25 L
.4926 .25 L
.49261 .25 L
.49262 .25 L
.49262 .25 L
Mistroke
.49263 .25 L
.49264 .25 L
.49264 .25 L
.49265 .25 L
.49266 .25 L
.49266 .25 L
.49266 .25 L
.49267 .25 L
.49268 .25 L
.49268 .25 L
.49269 .25 L
.49269 .25 L
.4927 .25 L
.49271 .25 L
.49271 .25 L
.49272 .25 L
.49272 .25 L
.49273 .25 L
.49274 .25 L
.49274 .25 L
.49275 .25 L
.49275 .25 L
.49276 .25 L
.49276 .25 L
.49277 .25 L
.49277 .25 L
.49278 .25 L
.49279 .25 L
.49279 .25 L
.4928 .25 L
.49281 .25 L
.49281 .25 L
.49282 .25 L
.49282 .25 L
.49283 .25 L
.49284 .25 L
.49284 .25 L
.49285 .25 L
.49286 .25 L
.49286 .25 L
.49287 .25 L
.49287 .25 L
.49288 .25 L
.49288 .25 L
.49289 .25 L
.4929 .25 L
.4929 .25 L
.49291 .25 L
.49291 .25 L
.49292 .25 L
Mistroke
.49293 .25 L
.49293 .25 L
.49294 .25 L
.49294 .25 L
.49295 .25 L
.49296 .25 L
.49296 .25 L
.49296 .25 L
.49297 .25 L
.49298 .25 L
.49298 .25 L
.49299 .25 L
.49299 .25 L
.493 .25 L
.493 .25 L
.49301 .25 L
.49301 .25 L
.49302 .25 L
.49303 .25 L
.49303 .25 L
.49304 .25 L
.49304 .25 L
.49305 .25 L
.49305 .25 L
.49306 .25 L
.49306 .25 L
.49307 .25 L
.49308 .25 L
.49308 .25 L
.49309 .25 L
.49309 .25 L
.4931 .25 L
.4931 .25 L
.49311 .25 L
.49312 .25 L
.49312 .25 L
.49313 .25 L
.49314 .25 L
.49314 .25 L
.49315 .25 L
.49315 .25 L
.49316 .25 L
.49317 .25 L
.49317 .25 L
.49318 .25 L
.49319 .25 L
.49319 .25 L
.4932 .25 L
.4932 .25 L
.4932 .25 L
Mistroke
.49321 .25 L
.49321 .25 L
.49322 .25 L
.49323 .25 L
.49323 .25 L
.49324 .25 L
.49325 .25 L
.49325 .25 L
.49326 .25 L
.49326 .25 L
.49327 .25 L
.49328 .25 L
.49328 .25 L
.49329 .25 L
.4933 .25 L
.4933 .25 L
.49331 .25 L
.49332 .25 L
.49332 .25 L
.49332 .25 L
.49333 .25 L
.49333 .25 L
.49334 .25 L
.49334 .25 L
.49335 .25 L
.49335 .25 L
.49336 .25 L
.49336 .25 L
.49336 .25 L
.49337 .25 L
.49337 .25 L
.49338 .25 L
.49338 .25 L
.49338 .25 L
.49339 .25 L
.4934 .25 L
.4934 .25 L
.49341 .25 L
.49342 .25 L
.49342 .25 L
.49343 .25 L
.49343 .25 L
.49344 .25 L
.49345 .25 L
.49345 .25 L
.49346 .25 L
.49347 .25 L
.49347 .25 L
.49348 .25 L
.49348 .25 L
Mistroke
.49349 .25 L
.49349 .25 L
.4935 .25 L
.49351 .25 L
.49351 .25 L
.49352 .25 L
.49353 .25 L
.49353 .25 L
.49354 .25 L
.49354 .25 L
.49355 .25 L
.49355 .25 L
.49356 .25 L
.49357 .25 L
.49357 .25 L
.49358 .25 L
.49358 .25 L
.49359 .25 L
.49359 .25 L
.4936 .25 L
.4936 .25 L
.49361 .25 L
.49362 .25 L
.49362 .25 L
.49363 .25 L
.49364 .25 L
.49364 .25 L
.49365 .25 L
.49366 .25 L
.49366 .25 L
.49367 .25 L
.49368 .25 L
.49368 .25 L
.49369 .25 L
.49369 .25 L
.4937 .25 L
.4937 .25 L
.49371 .25 L
.49372 .25 L
.49372 .25 L
.49373 .25 L
.49373 .25 L
.49374 .25 L
.49374 .25 L
.49375 .25 L
.49376 .25 L
.49376 .25 L
.49377 .25 L
.49377 .25 L
.49378 .25 L
Mistroke
.49378 .25 L
.49379 .25 L
.49379 .25 L
.4938 .25 L
.49381 .25 L
.49381 .25 L
.49381 .25 L
.49382 .25 L
.49383 .25 L
.49383 .25 L
.49384 .25 L
.49385 .25 L
.49385 .25 L
.49386 .25 L
.49386 .25 L
.49387 .25 L
.49387 .25 L
.49388 .25 L
.49388 .25 L
.49389 .25 L
.49389 .25 L
.4939 .25 L
.49391 .25 L
.49391 .25 L
.49392 .25 L
.49392 .25 L
.49393 .25 L
.49393 .25 L
.49394 .25 L
.49395 .25 L
.49395 .25 L
.49396 .25 L
.49397 .25 L
.49397 .25 L
.49398 .25 L
.49398 .25 L
.49399 .25 L
.494 .25 L
.494 .25 L
.49401 .25 L
.49402 .25 L
.49402 .25 L
.49402 .25 L
.49403 .25 L
.49403 .25 L
.49404 .25 L
.49404 .25 L
.49405 .25 L
.49406 .25 L
.49406 .25 L
Mistroke
.49407 .25 L
.49408 .25 L
.49408 .25 L
.49409 .25 L
.4941 .25 L
.4941 .25 L
.49411 .25 L
.49411 .25 L
.49412 .25 L
.49413 .25 L
.49413 .25 L
.49414 .25 L
.49415 .25 L
.49415 .25 L
.49416 .25 L
.49416 .25 L
.49416 .25 L
.49417 .25 L
.49417 .25 L
.49418 .25 L
.49418 .25 L
.49418 .25 L
.49419 .25 L
.49419 .25 L
.4942 .25 L
.4942 .25 L
.4942 .25 L
.49421 .25 L
.49421 .25 L
.49422 .25 L
.49423 .25 L
.49423 .25 L
.49424 .25 L
.49425 .25 L
.49425 .25 L
.49426 .25 L
.49426 .25 L
.49427 .25 L
.49428 .25 L
.49428 .25 L
.49429 .25 L
.4943 .25 L
.4943 .25 L
.49431 .25 L
.49431 .25 L
.49432 .25 L
.49432 .25 L
.49433 .25 L
.49434 .25 L
.49434 .25 L
Mistroke
.49435 .25 L
.49435 .25 L
.49436 .25 L
.49437 .25 L
.49437 .25 L
.49438 .25 L
.49438 .25 L
.49439 .25 L
.4944 .25 L
.4944 .25 L
.49441 .25 L
.49441 .25 L
.49442 .25 L
.49442 .25 L
.49443 .25 L
.49444 .25 L
.49444 .25 L
.49445 .25 L
.49446 .25 L
.49446 .25 L
.49447 .25 L
.49447 .25 L
.49448 .25 L
.49449 .25 L
.49449 .25 L
.4945 .25 L
.49451 .25 L
.49451 .25 L
.49451 .25 L
.49452 .25 L
.49453 .25 L
.49453 .25 L
.49454 .25 L
.49455 .25 L
.49455 .25 L
.49456 .25 L
.49456 .25 L
.49457 .25 L
.49457 .25 L
.49458 .25 L
.49459 .25 L
.49459 .25 L
.4946 .25 L
.49461 .25 L
.49461 .25 L
.49461 .25 L
.49462 .25 L
.49463 .25 L
.49463 .25 L
.49464 .25 L
Mistroke
.49464 .25 L
.49464 .25 L
.49465 .25 L
.49466 .25 L
.49466 .25 L
.49467 .25 L
.49468 .25 L
.49468 .25 L
.49469 .25 L
.49469 .25 L
.4947 .25 L
.4947 .25 L
.4947 .25 L
.49471 .25 L
.49472 .25 L
.49472 .25 L
.49473 .25 L
.49474 .25 L
.49474 .25 L
.49475 .25 L
.49475 .25 L
.49476 .25 L
.49477 .25 L
.49477 .25 L
.49478 .25 L
.49478 .25 L
.49479 .25 L
.4948 .25 L
.4948 .25 L
.49481 .25 L
.49482 .25 L
.49482 .25 L
.49483 .25 L
.49483 .25 L
.49484 .25 L
.49484 .25 L
.49485 .25 L
.49485 .25 L
.49486 .25 L
.49486 .25 L
.49487 .25 L
.49488 .25 L
.49488 .25 L
.49489 .25 L
.49489 .25 L
.4949 .25 L
.49491 .25 L
.49491 .25 L
.49492 .25 L
.49493 .25 L
Mistroke
.49493 .25 L
.49494 .25 L
.49495 .25 L
.49495 .25 L
.49496 .25 L
.49497 .25 L
.49497 .25 L
.49497 .25 L
.49498 .25 L
.49498 .25 L
.49499 .25 L
.49499 .25 L
.49499 .25 L
.495 .25 L
.495 .25 L
.49501 .25 L
.49501 .25 L
.49502 .25 L
.49502 .25 L
.49502 .25 L
.49503 .25 L
.49503 .25 L
.49504 .25 L
.49504 .25 L
.49505 .25 L
.49506 .25 L
.49506 .25 L
.49507 .25 L
.49508 .25 L
.49508 .25 L
.49509 .25 L
.49509 .25 L
.4951 .25 L
.49511 .25 L
.49511 .25 L
.49512 .25 L
.49513 .25 L
.49513 .25 L
.49513 .25 L
.49514 .25 L
.49515 .25 L
.49515 .25 L
.49516 .25 L
.49517 .25 L
.49517 .25 L
.49518 .25 L
.49518 .25 L
.49519 .25 L
.4952 .25 L
.4952 .25 L
Mistroke
.49521 .25 L
.49521 .25 L
.49522 .25 L
.49523 .25 L
.49523 .25 L
.49523 .25 L
.49524 .25 L
.49525 .25 L
.49525 .25 L
.49526 .25 L
.49527 .25 L
.49527 .25 L
.49528 .25 L
.49528 .25 L
.49529 .25 L
.4953 .25 L
.4953 .25 L
.49531 .25 L
.49532 .25 L
.49532 .25 L
.49533 .25 L
.49533 .25 L
.49534 .25 L
.49534 .25 L
.49535 .25 L
.49536 .25 L
.49536 .25 L
.49537 .25 L
.49538 .25 L
.49538 .25 L
.49539 .25 L
.49539 .25 L
.4954 .25 L
.4954 .25 L
.49541 .25 L
.49542 .25 L
.49542 .25 L
.49543 .25 L
.49543 .25 L
.49544 .25 L
.49544 .25 L
.49545 .25 L
.49546 .25 L
.49546 .25 L
.49546 .25 L
.49547 .25 L
.49548 .25 L
.49548 .25 L
.49549 .25 L
.49549 .25 L
Mistroke
.4955 .25 L
.49551 .25 L
.49551 .25 L
.49551 .25 L
.49552 .25 L
.49552 .25 L
.49553 .25 L
.49553 .25 L
.49554 .25 L
.49555 .25 L
.49555 .25 L
.49556 .25 L
.49557 .25 L
.49557 .25 L
.49558 .25 L
.49558 .25 L
.49559 .25 L
.4956 .25 L
.4956 .25 L
.49561 .25 L
.49561 .25 L
.49562 .25 L
.49563 .25 L
.49563 .25 L
.49564 .25 L
.49565 .25 L
.49565 .25 L
.49566 .25 L
.49566 .25 L
.49567 .25 L
.49567 .25 L
.49568 .25 L
.49568 .25 L
.49569 .25 L
.49569 .25 L
.4957 .25 L
.49571 .25 L
.49571 .25 L
.49572 .25 L
.49572 .25 L
.49573 .25 L
.49574 .25 L
.49574 .25 L
.49575 .25 L
.49576 .25 L
.49576 .25 L
.49577 .25 L
.49578 .25 L
.49578 .25 L
.49579 .25 L
Mistroke
.49579 .25 L
.4958 .25 L
.4958 .25 L
.49581 .25 L
.49581 .25 L
.49581 .25 L
.49582 .25 L
.49582 .25 L
.49583 .25 L
.49583 .25 L
.49584 .25 L
.49584 .25 L
.49584 .25 L
.49585 .25 L
.49585 .25 L
.49585 .25 L
.49586 .25 L
.49587 .25 L
.49587 .25 L
.49588 .25 L
.49589 .25 L
.49589 .25 L
.4959 .25 L
.49591 .25 L
.49591 .25 L
.49592 .25 L
.49592 .25 L
.49593 .25 L
.49594 .25 L
.49594 .25 L
.49595 .25 L
.49595 .25 L
.49596 .25 L
.49597 .25 L
.49597 .25 L
.49598 .25 L
.49598 .25 L
.49599 .25 L
.496 .25 L
.496 .25 L
.49601 .25 L
.49601 .25 L
.49602 .25 L
.49602 .25 L
.49603 .25 L
.49604 .25 L
.49604 .25 L
.49605 .25 L
.49605 .25 L
.49606 .25 L
Mistroke
.49606 .25 L
.49607 .25 L
.49608 .25 L
.49608 .25 L
.49609 .25 L
.4961 .25 L
.4961 .25 L
.49611 .25 L
.49611 .25 L
.49612 .25 L
.49613 .25 L
.49613 .25 L
.49614 .25 L
.49615 .25 L
.49615 .25 L
.49616 .25 L
.49616 .25 L
.49617 .25 L
.49617 .25 L
.49618 .25 L
.49619 .25 L
.49619 .25 L
.4962 .25 L
.4962 .25 L
.49621 .25 L
.49622 .25 L
.49622 .25 L
.49623 .25 L
.49623 .25 L
.49624 .25 L
.49625 .25 L
.49625 .25 L
.49626 .25 L
.49626 .25 L
.49627 .25 L
.49627 .25 L
.49628 .25 L
.49629 .25 L
.49629 .25 L
.4963 .25 L
.4963 .25 L
.49631 .25 L
.49632 .25 L
.49632 .25 L
.49633 .25 L
.49634 .25 L
.49634 .25 L
.49635 .25 L
.49636 .25 L
.49636 .25 L
Mistroke
.49636 .25 L
.49637 .25 L
.49638 .25 L
.49638 .25 L
.49639 .25 L
.4964 .25 L
.4964 .25 L
.49641 .25 L
.49641 .25 L
.49642 .25 L
.49642 .25 L
.49643 .25 L
.49644 .25 L
.49644 .25 L
.49645 .25 L
.49645 .25 L
.49646 .25 L
.49646 .25 L
.49647 .25 L
.49647 .25 L
.49648 .25 L
.49649 .25 L
.49649 .25 L
.49649 .25 L
.4965 .25 L
.49651 .25 L
.49651 .25 L
.49652 .25 L
.49653 .25 L
.49653 .25 L
.49654 .25 L
.49654 .25 L
.49655 .25 L
.49655 .25 L
.49655 .25 L
.49656 .25 L
.49657 .25 L
.49657 .25 L
.49658 .25 L
.49659 .25 L
.49659 .25 L
.4966 .25 L
.4966 .25 L
.49661 .25 L
.49662 .25 L
.49662 .25 L
.49663 .25 L
.49663 .25 L
.49664 .25 L
.49665 .25 L
Mistroke
.49665 .25 L
.49666 .25 L
.49667 .25 L
.49667 .25 L
.49668 .25 L
.49668 .25 L
.49669 .25 L
.49669 .25 L
.4967 .25 L
.4967 .25 L
.49671 .25 L
.49671 .25 L
.49672 .25 L
.49673 .25 L
.49673 .25 L
.49674 .25 L
.49674 .25 L
.49675 .25 L
.49676 .25 L
.49676 .25 L
.49677 .25 L
.49678 .25 L
.49678 .25 L
.49679 .25 L
.4968 .25 L
.4968 .25 L
.49681 .25 L
.49682 .25 L
.49682 .25 L
.49682 .25 L
.49683 .25 L
.49683 .25 L
.49684 .25 L
.49684 .25 L
.49684 .25 L
.49685 .25 L
.49685 .25 L
.49686 .25 L
.49686 .25 L
.49687 .25 L
.49687 .25 L
.49687 .25 L
.49688 .25 L
.49688 .25 L
.49689 .25 L
.49689 .25 L
.4969 .25 L
.49691 .25 L
.49691 .25 L
.49692 .25 L
Mistroke
.49693 .25 L
.49693 .25 L
.49694 .25 L
.49694 .25 L
.49695 .25 L
.49696 .25 L
.49696 .25 L
.49697 .25 L
.49698 .25 L
.49698 .25 L
.49699 .25 L
.49699 .25 L
.497 .25 L
.497 .25 L
.49701 .25 L
.49702 .25 L
.49702 .25 L
.49703 .25 L
.49703 .25 L
.49704 .25 L
.49705 .25 L
.49705 .25 L
.49706 .25 L
.49706 .25 L
.49707 .25 L
.49708 .25 L
.49708 .25 L
.49708 .25 L
.49709 .25 L
.4971 .25 L
.4971 .25 L
.49711 .25 L
.49712 .25 L
.49712 .25 L
.49713 .25 L
.49713 .25 L
.49714 .25 L
.49715 .25 L
.49715 .25 L
.49716 .25 L
.49717 .25 L
.49717 .25 L
.49718 .25 L
.49718 .25 L
.49719 .25 L
.49719 .25 L
.4972 .25 L
.49721 .25 L
.49721 .25 L
.49722 .25 L
Mistroke
.49723 .25 L
.49723 .25 L
.49724 .25 L
.49724 .25 L
.49725 .25 L
.49725 .25 L
.49726 .25 L
.49727 .25 L
.49727 .25 L
.49728 .25 L
.49728 .25 L
.49729 .25 L
.49729 .25 L
.4973 .25 L
.49731 .25 L
.49731 .25 L
.49731 .25 L
.49732 .25 L
.49733 .25 L
.49733 .25 L
.49734 .25 L
.49734 .25 L
.49735 .25 L
.49736 .25 L
.49736 .25 L
.49736 .25 L
.49737 .25 L
.49737 .25 L
.49738 .25 L
.49738 .25 L
.49739 .25 L
.4974 .25 L
.4974 .25 L
.49741 .25 L
.49742 .25 L
.49742 .25 L
.49743 .25 L
.49743 .25 L
.49744 .25 L
.49745 .25 L
.49745 .25 L
.49746 .25 L
.49746 .25 L
.49747 .25 L
.49748 .25 L
.49748 .25 L
.49749 .25 L
.4975 .25 L
.4975 .25 L
.49751 .25 L
Mistroke
.49752 .25 L
.49752 .25 L
.49752 .25 L
.49753 .25 L
.49753 .25 L
.49754 .25 L
.49754 .25 L
.49755 .25 L
.49756 .25 L
.49756 .25 L
.49757 .25 L
.49758 .25 L
.49758 .25 L
.49759 .25 L
.49759 .25 L
.4976 .25 L
.49761 .25 L
.49761 .25 L
.49762 .25 L
.49763 .25 L
.49763 .25 L
.49764 .25 L
.49764 .25 L
.49765 .25 L
.49765 .25 L
.49766 .25 L
.49766 .25 L
.49766 .25 L
.49767 .25 L
.49768 .25 L
.49768 .25 L
.49768 .25 L
.49769 .25 L
.49769 .25 L
.49769 .25 L
.4977 .25 L
.4977 .25 L
.49771 .25 L
.49771 .25 L
.49772 .25 L
.49772 .25 L
.49773 .25 L
.49774 .25 L
.49774 .25 L
.49775 .25 L
.49776 .25 L
.49776 .25 L
.49777 .25 L
.49778 .25 L
.49778 .25 L
Mistroke
.49779 .25 L
.49779 .25 L
.4978 .25 L
.49781 .25 L
.49781 .25 L
.49782 .25 L
.49782 .25 L
.49783 .25 L
.49783 .25 L
.49784 .25 L
.49785 .25 L
.49785 .25 L
.49786 .25 L
.49786 .25 L
.49787 .25 L
.49788 .25 L
.49788 .25 L
.49789 .25 L
.49789 .25 L
.4979 .25 L
.4979 .25 L
.49791 .25 L
.49791 .25 L
.49792 .25 L
.49793 .25 L
.49793 .25 L
.49794 .25 L
.49795 .25 L
.49795 .25 L
.49796 .25 L
.49797 .25 L
.49797 .25 L
.49798 .25 L
.49798 .25 L
.49799 .25 L
.498 .25 L
.498 .25 L
.49801 .25 L
.49801 .25 L
.49802 .25 L
.49803 .25 L
.49803 .25 L
.49804 .25 L
.49804 .25 L
.49805 .25 L
.49806 .25 L
.49806 .25 L
.49807 .25 L
.49807 .25 L
.49808 .25 L
Mistroke
.49808 .25 L
.49809 .25 L
.4981 .25 L
.4981 .25 L
.49811 .25 L
.49811 .25 L
.49812 .25 L
.49812 .25 L
.49813 .25 L
.49813 .25 L
.49814 .25 L
.49814 .25 L
.49815 .25 L
.49816 .25 L
.49816 .25 L
.49817 .25 L
.49817 .25 L
.49818 .25 L
.49818 .25 L
.49819 .25 L
.49819 .25 L
.4982 .25 L
.4982 .25 L
.49821 .25 L
.49822 .25 L
.49822 .25 L
.49823 .25 L
.49823 .25 L
.49824 .25 L
.49825 .25 L
.49825 .25 L
.49826 .25 L
.49826 .25 L
.49827 .25 L
.49828 .25 L
.49828 .25 L
.49829 .25 L
.49829 .25 L
.4983 .25 L
.49831 .25 L
.49831 .25 L
.49832 .25 L
.49833 .25 L
.49833 .25 L
.49834 .25 L
.49834 .25 L
.49835 .25 L
.49835 .25 L
.49835 .25 L
.49836 .25 L
Mistroke
.49837 .25 L
.49837 .25 L
.49838 .25 L
.49839 .25 L
.49839 .25 L
.4984 .25 L
.4984 .25 L
.49841 .25 L
.49842 .25 L
.49842 .25 L
.49843 .25 L
.49844 .25 L
.49844 .25 L
.49845 .25 L
.49846 .25 L
.49846 .25 L
.49847 .25 L
.49847 .25 L
.49848 .25 L
.49848 .25 L
.49848 .25 L
.49849 .25 L
.49849 .25 L
.4985 .25 L
.4985 .25 L
.49851 .25 L
.49851 .25 L
.49851 .25 L
.49852 .25 L
.49852 .25 L
.49853 .25 L
.49853 .25 L
.49854 .25 L
.49854 .25 L
.49855 .25 L
.49856 .25 L
.49856 .25 L
.49857 .25 L
.49857 .25 L
.49858 .25 L
.49859 .25 L
.49859 .25 L
.4986 .25 L
.49861 .25 L
.49861 .25 L
.49862 .25 L
.49863 .25 L
.49863 .25 L
.49863 .25 L
.49864 .25 L
Mistroke
.49865 .25 L
.49865 .25 L
.49866 .25 L
.49866 .25 L
.49867 .25 L
.49868 .25 L
.49868 .25 L
.49869 .25 L
.49869 .25 L
.4987 .25 L
.49871 .25 L
.49871 .25 L
.49872 .25 L
.49872 .25 L
.49873 .25 L
.49873 .25 L
.49874 .25 L
.49874 .25 L
.49875 .25 L
.49876 .25 L
.49876 .25 L
.49877 .25 L
.49878 .25 L
.49878 .25 L
.49879 .25 L
.49879 .25 L
.4988 .25 L
.49881 .25 L
.49881 .25 L
.49882 .25 L
.49883 .25 L
.49883 .25 L
.49884 .25 L
.49884 .25 L
.49885 .25 L
.49885 .25 L
.49886 .25 L
.49887 .25 L
.49887 .25 L
.49888 .25 L
.49888 .25 L
.49889 .25 L
.4989 .25 L
.4989 .25 L
.49891 .25 L
.49891 .25 L
.49892 .25 L
.49893 .25 L
.49893 .25 L
.49893 .25 L
Mistroke
.49894 .25 L
.49895 .25 L
.49895 .25 L
.49896 .25 L
.49896 .25 L
.49897 .25 L
.49897 .25 L
.49898 .25 L
.49898 .25 L
.49899 .25 L
.499 .25 L
.499 .25 L
.49901 .25 L
.49901 .25 L
.49902 .25 L
.49902 .25 L
.49903 .25 L
.49903 .25 L
.49904 .25 L
.49905 .25 L
.49905 .25 L
.49906 .25 L
.49906 .25 L
.49907 .25 L
.49907 .25 L
.49908 .25 L
.49909 .25 L
.49909 .25 L
.4991 .25 L
.49911 .25 L
.49911 .25 L
.49912 .25 L
.49912 .25 L
.49913 .25 L
.49914 .25 L
.49914 .25 L
.49915 .25 L
.49916 .25 L
.49916 .25 L
.49917 .25 L
.49917 .25 L
.49917 .25 L
.49918 .25 L
.49918 .25 L
.49919 .25 L
.4992 .25 L
.4992 .25 L
.49921 .25 L
.49922 .25 L
.49922 .25 L
Mistroke
.49923 .25 L
.49923 .25 L
.49924 .25 L
.49925 .25 L
.49925 .25 L
.49926 .25 L
.49927 .25 L
.49927 .25 L
.49928 .25 L
.49929 .25 L
.49929 .25 L
.49929 .25 L
.4993 .25 L
.4993 .25 L
.49931 .25 L
.49931 .25 L
.49932 .25 L
.49932 .25 L
.49933 .25 L
.49933 .25 L
.49933 .25 L
.49934 .25 L
.49934 .25 L
.49935 .25 L
.49935 .25 L
.49935 .25 L
.49936 .25 L
.49937 .25 L
.49937 .25 L
.49938 .25 L
.49939 .25 L
.49939 .25 L
.4994 .25 L
.4994 .25 L
.49941 .25 L
.49942 .25 L
.49942 .25 L
.49943 .25 L
.49944 .25 L
.49944 .25 L
.49945 .25 L
.49945 .25 L
.49946 .25 L
.49946 .25 L
.49947 .25 L
.49948 .25 L
.49948 .25 L
.49949 .25 L
.49949 .25 L
.4995 .25 L
Mistroke
.49951 .25 L
.49951 .25 L
.49952 .25 L
.49952 .25 L
.49953 .25 L
.49954 .25 L
.49954 .25 L
.49955 .25 L
.49955 .25 L
.49956 .25 L
.49956 .25 L
.49957 .25 L
.49957 .25 L
.49958 .25 L
.49959 .25 L
.49959 .25 L
.4996 .25 L
.49961 .25 L
.49961 .25 L
.49962 .25 L
.49963 .25 L
.49963 .25 L
.49964 .25 L
.49964 .25 L
.49965 .25 L
.49966 .25 L
.49966 .25 L
.49967 .25 L
.49967 .25 L
.49968 .25 L
.49968 .25 L
.49969 .25 L
.4997 .25 L
.4997 .25 L
.49971 .25 L
.49971 .25 L
.49972 .25 L
.49973 .25 L
.49973 .25 L
.49974 .25 L
.49974 .25 L
.49975 .25 L
.49975 .25 L
.49976 .25 L
.49976 .25 L
.49977 .25 L
.49978 .25 L
.49978 .25 L
.49978 .25 L
.49979 .25 L
Mistroke
.4998 .25 L
.4998 .25 L
.49981 .25 L
.49981 .25 L
.49982 .25 L
.49983 .25 L
.49983 .25 L
.49983 .25 L
.49984 .25 L
.49985 .25 L
.49985 .25 L
.49986 .25 L
.49986 .25 L
.49987 .25 L
.49988 .25 L
.49988 .25 L
.49989 .25 L
.49989 .25 L
.4999 .25 L
.4999 .25 L
.49991 .25 L
.49992 .25 L
.49992 .25 L
.49993 .25 L
.49994 .25 L
.49994 .25 L
.49995 .25 L
.49995 .25 L
.49996 .25 L
.49997 .25 L
.49997 .25 L
.49998 .25 L
.49999 .25 L
.49999 .25 L
.49999 .25 L
.5 .25 L
.5 .25 L
.50001 .25 L
.50001 .25 L
.50002 .25 L
.50003 .25 L
.50003 .25 L
.50004 .25 L
.50005 .25 L
.50005 .25 L
.50006 .25 L
.50006 .25 L
.50007 .25 L
.50008 .25 L
.50008 .25 L
Mistroke
.50009 .25 L
.5001 .25 L
.5001 .25 L
.50011 .25 L
.50011 .25 L
.50012 .25 L
.50012 .25 L
.50013 .25 L
.50013 .25 L
.50014 .25 L
.50014 .25 L
.50015 .25 L
.50015 .25 L
.50015 .25 L
.50016 .25 L
.50016 .25 L
.50016 .25 L
.50017 .25 L
.50017 .25 L
.50018 .25 L
.50018 .25 L
.50019 .25 L
.5002 .25 L
.5002 .25 L
.50021 .25 L
.50022 .25 L
.50022 .25 L
.50023 .25 L
.50023 .25 L
.50024 .25 L
.50025 .25 L
.50025 .25 L
.50026 .25 L
.50027 .25 L
.50027 .25 L
.50028 .25 L
.50028 .25 L
.50029 .25 L
.50029 .25 L
.5003 .25 L
.50031 .25 L
.50031 .25 L
.50032 .25 L
.50032 .25 L
.50033 .25 L
.50033 .25 L
.50034 .25 L
.50035 .25 L
.50035 .25 L
.50036 .25 L
Mistroke
.50036 .25 L
.50037 .25 L
.50037 .25 L
.50038 .25 L
.50038 .25 L
.50039 .25 L
.5004 .25 L
.5004 .25 L
.50041 .25 L
.50042 .25 L
.50042 .25 L
.50043 .25 L
.50044 .25 L
.50044 .25 L
.50045 .25 L
.50046 .25 L
.50046 .25 L
.50047 .25 L
.50047 .25 L
.50048 .25 L
.50048 .25 L
.50049 .25 L
.5005 .25 L
.5005 .25 L
.50051 .25 L
.50051 .25 L
.50052 .25 L
.50053 .25 L
.50053 .25 L
.50054 .25 L
.50054 .25 L
.50055 .25 L
.50056 .25 L
.50056 .25 L
.50057 .25 L
.50057 .25 L
.50058 .25 L
.50058 .25 L
.50059 .25 L
.50059 .25 L
.5006 .25 L
.50061 .25 L
.50061 .25 L
.50062 .25 L
.50063 .25 L
.50063 .25 L
.50064 .25 L
.50064 .25 L
.50065 .25 L
.50066 .25 L
Mistroke
.50066 .25 L
.50067 .25 L
.50068 .25 L
.50068 .25 L
.50068 .25 L
.50069 .25 L
.5007 .25 L
.5007 .25 L
.50071 .25 L
.50072 .25 L
.50072 .25 L
.50073 .25 L
.50073 .25 L
.50074 .25 L
.50075 .25 L
.50075 .25 L
.50076 .25 L
.50076 .25 L
.50077 .25 L
.50078 .25 L
.50078 .25 L
.50078 .25 L
.50079 .25 L
.5008 .25 L
.5008 .25 L
.50081 .25 L
.50081 .25 L
.50082 .25 L
.50082 .25 L
.50083 .25 L
.50083 .25 L
.50084 .25 L
.50085 .25 L
.50085 .25 L
.50086 .25 L
.50086 .25 L
.50087 .25 L
.50087 .25 L
.50088 .25 L
.50088 .25 L
.50089 .25 L
.5009 .25 L
.5009 .25 L
.50091 .25 L
.50091 .25 L
.50092 .25 L
.50092 .25 L
.50093 .25 L
.50094 .25 L
.50094 .25 L
Mistroke
.50095 .25 L
.50096 .25 L
.50096 .25 L
.50097 .25 L
.50097 .25 L
.50098 .25 L
.50099 .25 L
.50099 .25 L
.501 .25 L
.50101 .25 L
.50101 .25 L
.50102 .25 L
.50102 .25 L
.50102 .25 L
.50103 .25 L
.50103 .25 L
.50104 .25 L
.50105 .25 L
.50105 .25 L
.50106 .25 L
.50107 .25 L
.50107 .25 L
.50108 .25 L
.50108 .25 L
.50109 .25 L
.5011 .25 L
.5011 .25 L
.50111 .25 L
.50112 .25 L
.50112 .25 L
.50113 .25 L
.50114 .25 L
.50114 .25 L
.50114 .25 L
.50115 .25 L
.50115 .25 L
.50116 .25 L
.50116 .25 L
.50117 .25 L
.50117 .25 L
.50118 .25 L
.50118 .25 L
.50118 .25 L
.50119 .25 L
.50119 .25 L
.5012 .25 L
.5012 .25 L
.5012 .25 L
.50121 .25 L
.50122 .25 L
Mistroke
.50122 .25 L
.50123 .25 L
.50124 .25 L
.50124 .25 L
.50125 .25 L
.50125 .25 L
.50126 .25 L
.50127 .25 L
.50127 .25 L
.50128 .25 L
.50129 .25 L
.50129 .25 L
.5013 .25 L
.5013 .25 L
.50131 .25 L
.50131 .25 L
.50132 .25 L
.50133 .25 L
.50133 .25 L
.50134 .25 L
.50134 .25 L
.50135 .25 L
.50136 .25 L
.50136 .25 L
.50137 .25 L
.50137 .25 L
.50138 .25 L
.50139 .25 L
.50139 .25 L
.5014 .25 L
.5014 .25 L
.5014 .25 L
.50141 .25 L
.50142 .25 L
.50142 .25 L
.50143 .25 L
.50144 .25 L
.50144 .25 L
.50145 .25 L
.50146 .25 L
.50146 .25 L
.50147 .25 L
.50147 .25 L
.50148 .25 L
.50149 .25 L
.50149 .25 L
.5015 .25 L
.50151 .25 L
.50151 .25 L
.50152 .25 L
Mistroke
.50152 .25 L
.50153 .25 L
.50153 .25 L
.50154 .25 L
.50155 .25 L
.50155 .25 L
.50156 .25 L
.50156 .25 L
.50157 .25 L
.50158 .25 L
.50158 .25 L
.50159 .25 L
.50159 .25 L
.5016 .25 L
.5016 .25 L
.50161 .25 L
.50161 .25 L
.50162 .25 L
.50163 .25 L
.50163 .25 L
.50163 .25 L
.50164 .25 L
.50165 .25 L
.50165 .25 L
.50166 .25 L
.50166 .25 L
.50167 .25 L
.50168 .25 L
.50168 .25 L
.50168 .25 L
.50169 .25 L
.5017 .25 L
.5017 .25 L
.50171 .25 L
.50171 .25 L
.50172 .25 L
.50173 .25 L
.50173 .25 L
.50174 .25 L
.50174 .25 L
.50175 .25 L
.50175 .25 L
.50176 .25 L
.50177 .25 L
.50177 .25 L
.50178 .25 L
.50179 .25 L
.50179 .25 L
.5018 .25 L
.5018 .25 L
Mistroke
.50181 .25 L
.50182 .25 L
.50182 .25 L
.50183 .25 L
.50184 .25 L
.50184 .25 L
.50184 .25 L
.50185 .25 L
.50185 .25 L
.50186 .25 L
.50186 .25 L
.50187 .25 L
.50188 .25 L
.50188 .25 L
.50189 .25 L
.5019 .25 L
.5019 .25 L
.50191 .25 L
.50192 .25 L
.50192 .25 L
.50193 .25 L
.50193 .25 L
.50194 .25 L
.50195 .25 L
.50195 .25 L
.50196 .25 L
.50196 .25 L
.50197 .25 L
.50197 .25 L
.50198 .25 L
.50198 .25 L
.50199 .25 L
.50199 .25 L
.502 .25 L
.502 .25 L
.502 .25 L
.50201 .25 L
.50201 .25 L
.50202 .25 L
.50202 .25 L
.50202 .25 L
.50203 .25 L
.50203 .25 L
.50204 .25 L
.50205 .25 L
.50205 .25 L
.50206 .25 L
.50207 .25 L
.50207 .25 L
.50208 .25 L
Mistroke
.50208 .25 L
.50209 .25 L
.5021 .25 L
.5021 .25 L
.50211 .25 L
.50212 .25 L
.50212 .25 L
.50213 .25 L
.50213 .25 L
.50214 .25 L
.50214 .25 L
.50215 .25 L
.50216 .25 L
.50216 .25 L
.50217 .25 L
.50217 .25 L
.50218 .25 L
.50218 .25 L
.50219 .25 L
.5022 .25 L
.5022 .25 L
.50221 .25 L
.50222 .25 L
.50222 .25 L
.50223 .25 L
.50223 .25 L
.50224 .25 L
.50224 .25 L
.50225 .25 L
.50226 .25 L
.50226 .25 L
.50227 .25 L
.50227 .25 L
.50228 .25 L
.50229 .25 L
.50229 .25 L
.5023 .25 L
.50231 .25 L
.50231 .25 L
.50232 .25 L
.50233 .25 L
.50233 .25 L
.50233 .25 L
.50234 .25 L
.50235 .25 L
.50235 .25 L
.50236 .25 L
.50236 .25 L
.50237 .25 L
.50238 .25 L
Mistroke
.50238 .25 L
.50239 .25 L
.50239 .25 L
.5024 .25 L
.50241 .25 L
.50241 .25 L
.50242 .25 L
.50242 .25 L
.50243 .25 L
.50243 .25 L
.50244 .25 L
.50244 .25 L
.50245 .25 L
.50245 .25 L
.50246 .25 L
.50246 .25 L
.50247 .25 L
.50248 .25 L
.50248 .25 L
.50249 .25 L
.50249 .25 L
.5025 .25 L
.50251 .25 L
.50251 .25 L
.50252 .25 L
.50252 .25 L
.50252 .25 L
.50253 .25 L
.50254 .25 L
.50254 .25 L
.50255 .25 L
.50255 .25 L
.50256 .25 L
.50257 .25 L
.50257 .25 L
.50258 .25 L
.50258 .25 L
.50259 .25 L
.5026 .25 L
.5026 .25 L
.50261 .25 L
.50261 .25 L
.50262 .25 L
.50263 .25 L
.50263 .25 L
.50264 .25 L
.50265 .25 L
.50265 .25 L
.50266 .25 L
.50266 .25 L
Mistroke
.50267 .25 L
.50267 .25 L
.50268 .25 L
.50268 .25 L
.50269 .25 L
.50269 .25 L
.5027 .25 L
.50271 .25 L
.50271 .25 L
.50272 .25 L
.50273 .25 L
.50273 .25 L
.50274 .25 L
.50275 .25 L
.50275 .25 L
.50276 .25 L
.50276 .25 L
.50277 .25 L
.50278 .25 L
.50278 .25 L
.50279 .25 L
.50279 .25 L
.5028 .25 L
.5028 .25 L
.50281 .25 L
.50281 .25 L
.50281 .25 L
.50282 .25 L
.50282 .25 L
.50283 .25 L
.50283 .25 L
.50284 .25 L
.50284 .25 L
.50284 .25 L
.50285 .25 L
.50285 .25 L
.50286 .25 L
.50286 .25 L
.50287 .25 L
.50288 .25 L
.50288 .25 L
.50289 .25 L
.5029 .25 L
.5029 .25 L
.50291 .25 L
.50291 .25 L
.50292 .25 L
.50293 .25 L
.50293 .25 L
.50294 .25 L
Mistroke
.50295 .25 L
.50295 .25 L
.50295 .25 L
.50296 .25 L
.50297 .25 L
.50297 .25 L
.50298 .25 L
.50299 .25 L
.50299 .25 L
.503 .25 L
.503 .25 L
.50301 .25 L
.50301 .25 L
.50302 .25 L
.50303 .25 L
.50303 .25 L
.50304 .25 L
.50305 .25 L
.50305 .25 L
.50305 .25 L
.50306 .25 L
.50307 .25 L
.50307 .25 L
.50308 .25 L
.50309 .25 L
.50309 .25 L
.5031 .25 L
.5031 .25 L
.50311 .25 L
.50312 .25 L
.50312 .25 L
.50313 .25 L
.50314 .25 L
.50314 .25 L
.50315 .25 L
.50315 .25 L
.50316 .25 L
.50316 .25 L
.50317 .25 L
.50318 .25 L
.50318 .25 L
.50319 .25 L
.50319 .25 L
.5032 .25 L
.50321 .25 L
.50321 .25 L
.50322 .25 L
.50322 .25 L
.50323 .25 L
.50324 .25 L
Mistroke
.50324 .25 L
.50325 .25 L
.50325 .25 L
.50325 .25 L
.50326 .25 L
.50327 .25 L
.50327 .25 L
.50328 .25 L
.50328 .25 L
.50329 .25 L
.50329 .25 L
.5033 .25 L
.50331 .25 L
.50331 .25 L
.50332 .25 L
.50332 .25 L
.50333 .25 L
.50333 .25 L
.50334 .25 L
.50334 .25 L
.50335 .25 L
.50335 .25 L
.50336 .25 L
.50337 .25 L
.50337 .25 L
.50338 .25 L
.50338 .25 L
.50339 .25 L
.5034 .25 L
.5034 .25 L
.50341 .25 L
.50341 .25 L
.50342 .25 L
.50343 .25 L
.50343 .25 L
.50344 .25 L
.50344 .25 L
.50345 .25 L
.50346 .25 L
.50346 .25 L
.50347 .25 L
.50348 .25 L
.50348 .25 L
.50349 .25 L
.50349 .25 L
.50349 .25 L
.5035 .25 L
.50351 .25 L
.50351 .25 L
.50352 .25 L
Mistroke
.50353 .25 L
.50353 .25 L
.50354 .25 L
.50354 .25 L
.50355 .25 L
.50356 .25 L
.50356 .25 L
.50357 .25 L
.50357 .25 L
.50358 .25 L
.50359 .25 L
.50359 .25 L
.5036 .25 L
.50361 .25 L
.50361 .25 L
.50362 .25 L
.50362 .25 L
.50363 .25 L
.50363 .25 L
.50363 .25 L
.50364 .25 L
.50364 .25 L
.50365 .25 L
.50365 .25 L
.50365 .25 L
.50366 .25 L
.50366 .25 L
.50367 .25 L
.50367 .25 L
.50367 .25 L
.50368 .25 L
.50369 .25 L
.50369 .25 L
.5037 .25 L
.50371 .25 L
.50371 .25 L
.50372 .25 L
.50372 .25 L
.50373 .25 L
.50374 .25 L
.50374 .25 L
.50375 .25 L
.50376 .25 L
.50376 .25 L
.50377 .25 L
.50377 .25 L
.50378 .25 L
.50378 .25 L
.50379 .25 L
.5038 .25 L
Mistroke
.5038 .25 L
.50381 .25 L
.50382 .25 L
.50382 .25 L
.50383 .25 L
.50383 .25 L
.50384 .25 L
.50384 .25 L
.50385 .25 L
.50386 .25 L
.50386 .25 L
.50387 .25 L
.50387 .25 L
.50388 .25 L
.50388 .25 L
.50389 .25 L
.5039 .25 L
.5039 .25 L
.50391 .25 L
.50392 .25 L
.50392 .25 L
.50393 .25 L
.50393 .25 L
.50394 .25 L
.50395 .25 L
.50395 .25 L
.50396 .25 L
.50397 .25 L
.50397 .25 L
.50398 .25 L
.50398 .25 L
.50399 .25 L
.50399 .25 L
.504 .25 L
.50401 .25 L
.50401 .25 L
.50402 .25 L
.50402 .25 L
.50403 .25 L
.50403 .25 L
.50404 .25 L
.50405 .25 L
.50405 .25 L
.50406 .25 L
.50406 .25 L
.50407 .25 L
.50407 .25 L
.50408 .25 L
.50408 .25 L
.50409 .25 L
Mistroke
.5041 .25 L
.5041 .25 L
.50411 .25 L
.50412 .25 L
.50412 .25 L
.50413 .25 L
.50414 .25 L
.50414 .25 L
.50415 .25 L
.50416 .25 L
.50416 .25 L
.50417 .25 L
.50417 .25 L
.50418 .25 L
.50418 .25 L
.50419 .25 L
.5042 .25 L
.5042 .25 L
.50421 .25 L
.50421 .25 L
.50422 .25 L
.50423 .25 L
.50423 .25 L
.50424 .25 L
.50424 .25 L
.50425 .25 L
.50426 .25 L
.50426 .25 L
.50427 .25 L
.50427 .25 L
.50428 .25 L
.50428 .25 L
.50429 .25 L
.50429 .25 L
.5043 .25 L
.5043 .25 L
.50431 .25 L
.50431 .25 L
.50432 .25 L
.50433 .25 L
.50433 .25 L
.50434 .25 L
.50434 .25 L
.50435 .25 L
.50435 .25 L
.50436 .25 L
.50437 .25 L
.50437 .25 L
.50437 .25 L
.50438 .25 L
Mistroke
.50439 .25 L
.50439 .25 L
.5044 .25 L
.5044 .25 L
.50441 .25 L
.50442 .25 L
.50442 .25 L
.50443 .25 L
.50443 .25 L
.50444 .25 L
.50445 .25 L
.50445 .25 L
.50446 .25 L
.50446 .25 L
.50447 .25 L
.50448 .25 L
.50448 .25 L
.50449 .25 L
.5045 .25 L
.5045 .25 L
.50451 .25 L
.50451 .25 L
.50452 .25 L
.50452 .25 L
.50452 .25 L
.50453 .25 L
.50454 .25 L
.50454 .25 L
.50455 .25 L
.50456 .25 L
.50456 .25 L
.50457 .25 L
.50458 .25 L
.50458 .25 L
.50459 .25 L
.5046 .25 L
.5046 .25 L
.50461 .25 L
.50461 .25 L
.50462 .25 L
.50463 .25 L
.50463 .25 L
.50464 .25 L
.50464 .25 L
.50465 .25 L
.50465 .25 L
.50466 .25 L
.50466 .25 L
.50466 .25 L
.50467 .25 L
Mistroke
.50467 .25 L
.50468 .25 L
.50468 .25 L
.50469 .25 L
.50469 .25 L
.50469 .25 L
.5047 .25 L
.5047 .25 L
.50471 .25 L
.50471 .25 L
.50472 .25 L
.50473 .25 L
.50473 .25 L
.50474 .25 L
.50475 .25 L
.50475 .25 L
.50476 .25 L
.50476 .25 L
.50477 .25 L
.50478 .25 L
.50478 .25 L
.50479 .25 L
.5048 .25 L
.5048 .25 L
.5048 .25 L
.50481 .25 L
.50482 .25 L
.50482 .25 L
.50483 .25 L
.50484 .25 L
.50484 .25 L
.50485 .25 L
.50485 .25 L
.50486 .25 L
.50486 .25 L
.50487 .25 L
.50488 .25 L
.50488 .25 L
.50489 .25 L
.5049 .25 L
.5049 .25 L
.5049 .25 L
.50491 .25 L
.50492 .25 L
.50492 .25 L
.50493 .25 L
.50494 .25 L
.50494 .25 L
.50495 .25 L
.50495 .25 L
Mistroke
.50496 .25 L
.50497 .25 L
.50497 .25 L
.50498 .25 L
.50499 .25 L
.50499 .25 L
.505 .25 L
.505 .25 L
.50501 .25 L
.50501 .25 L
.50502 .25 L
.50503 .25 L
.50503 .25 L
.50504 .25 L
.50504 .25 L
.50505 .25 L
.50506 .25 L
.50506 .25 L
.50507 .25 L
.50507 .25 L
.50508 .25 L
.50509 .25 L
.50509 .25 L
.5051 .25 L
.5051 .25 L
.5051 .25 L
.50511 .25 L
.50512 .25 L
.50512 .25 L
.50513 .25 L
.50513 .25 L
.50514 .25 L
.50514 .25 L
.50515 .25 L
.50516 .25 L
.50516 .25 L
.50517 .25 L
.50518 .25 L
.50518 .25 L
.50518 .25 L
.50519 .25 L
.50519 .25 L
.5052 .25 L
.5052 .25 L
.50521 .25 L
.50522 .25 L
.50522 .25 L
.50523 .25 L
.50523 .25 L
.50524 .25 L
Mistroke
.50525 .25 L
.50525 .25 L
.50526 .25 L
.50526 .25 L
.50527 .25 L
.50528 .25 L
.50528 .25 L
.50529 .25 L
.50529 .25 L
.5053 .25 L
.50531 .25 L
.50531 .25 L
.50532 .25 L
.50533 .25 L
.50533 .25 L
.50534 .25 L
.50534 .25 L
.50535 .25 L
.50535 .25 L
.50536 .25 L
.50536 .25 L
.50537 .25 L
.50538 .25 L
.50538 .25 L
.50539 .25 L
.50539 .25 L
.5054 .25 L
.50541 .25 L
.50541 .25 L
.50542 .25 L
.50543 .25 L
.50543 .25 L
.50544 .25 L
.50545 .25 L
.50545 .25 L
.50546 .25 L
.50546 .25 L
.50547 .25 L
.50547 .25 L
.50548 .25 L
.50548 .25 L
.50548 .25 L
.50549 .25 L
.50549 .25 L
.5055 .25 L
.5055 .25 L
.5055 .25 L
.50551 .25 L
.50551 .25 L
.50552 .25 L
Mistroke
.50552 .25 L
.50552 .25 L
.50553 .25 L
.50554 .25 L
.50554 .25 L
.50555 .25 L
.50556 .25 L
.50556 .25 L
.50557 .25 L
.50557 .25 L
.50558 .25 L
.50559 .25 L
.50559 .25 L
.5056 .25 L
.50561 .25 L
.50561 .25 L
.50562 .25 L
.50562 .25 L
.50563 .25 L
.50563 .25 L
.50564 .25 L
.50565 .25 L
.50565 .25 L
.50566 .25 L
.50567 .25 L
.50567 .25 L
.50568 .25 L
.50568 .25 L
.50569 .25 L
.50569 .25 L
.5057 .25 L
.50571 .25 L
.50571 .25 L
.50572 .25 L
.50572 .25 L
.50573 .25 L
.50573 .25 L
.50574 .25 L
.50575 .25 L
.50575 .25 L
.50576 .25 L
.50577 .25 L
.50577 .25 L
.50578 .25 L
.50578 .25 L
.50579 .25 L
.5058 .25 L
.5058 .25 L
.50581 .25 L
.50582 .25 L
Mistroke
.50582 .25 L
.50583 .25 L
.50583 .25 L
.50584 .25 L
.50584 .25 L
.50585 .25 L
.50586 .25 L
.50586 .25 L
.50587 .25 L
.50587 .25 L
.50588 .25 L
.50589 .25 L
.50589 .25 L
.5059 .25 L
.5059 .25 L
.50591 .25 L
.50592 .25 L
.50592 .25 L
.50593 .25 L
.50593 .25 L
.50594 .25 L
.50594 .25 L
.50595 .25 L
.50595 .25 L
.50596 .25 L
.50596 .25 L
.50597 .25 L
.50597 .25 L
.50598 .25 L
.50599 .25 L
.50599 .25 L
.506 .25 L
.506 .25 L
.50601 .25 L
.50601 .25 L
.50602 .25 L
.50602 .25 L
.50603 .25 L
.50603 .25 L
.50604 .25 L
.50605 .25 L
.50605 .25 L
.50606 .25 L
.50606 .25 L
.50607 .25 L
.50608 .25 L
.50608 .25 L
.50609 .25 L
.50609 .25 L
.5061 .25 L
Mistroke
.50611 .25 L
.50611 .25 L
.50612 .25 L
.50613 .25 L
.50613 .25 L
.50614 .25 L
.50614 .25 L
.50615 .25 L
.50616 .25 L
.50616 .25 L
.50617 .25 L
.50617 .25 L
.50617 .25 L
.50618 .25 L
.50619 .25 L
.50619 .25 L
.5062 .25 L
.50621 .25 L
.50621 .25 L
.50622 .25 L
.50622 .25 L
.50623 .25 L
.50624 .25 L
.50624 .25 L
.50625 .25 L
.50626 .25 L
.50626 .25 L
.50627 .25 L
.50627 .25 L
.50628 .25 L
.50629 .25 L
.50629 .25 L
.5063 .25 L
.5063 .25 L
.5063 .25 L
.50631 .25 L
.50631 .25 L
.50632 .25 L
.50632 .25 L
.50632 .25 L
.50633 .25 L
.50633 .25 L
.50634 .25 L
.50634 .25 L
.50634 .25 L
.50635 .25 L
.50635 .25 L
.50636 .25 L
.50637 .25 L
.50637 .25 L
Mistroke
.50638 .25 L
.50639 .25 L
.50639 .25 L
.5064 .25 L
.5064 .25 L
.50641 .25 L
.50642 .25 L
.50642 .25 L
.50643 .25 L
.50644 .25 L
.50644 .25 L
.50645 .25 L
.50645 .25 L
.50646 .25 L
.50647 .25 L
.50647 .25 L
.50648 .25 L
.50648 .25 L
.50649 .25 L
.5065 .25 L
.5065 .25 L
.50651 .25 L
.50651 .25 L
.50652 .25 L
.50652 .25 L
.50653 .25 L
.50654 .25 L
.50654 .25 L
.50655 .25 L
.50655 .25 L
.50656 .25 L
.50656 .25 L
.50657 .25 L
.50658 .25 L
.50658 .25 L
.50659 .25 L
.5066 .25 L
.5066 .25 L
.50661 .25 L
.50661 .25 L
.50662 .25 L
.50663 .25 L
.50663 .25 L
.50664 .25 L
.50665 .25 L
.50665 .25 L
.50665 .25 L
.50666 .25 L
.50667 .25 L
.50667 .25 L
Mistroke
.50668 .25 L
.50669 .25 L
.50669 .25 L
.5067 .25 L
.5067 .25 L
.50671 .25 L
.50671 .25 L
.50672 .25 L
.50673 .25 L
.50673 .25 L
.50674 .25 L
.50675 .25 L
.50675 .25 L
.50675 .25 L
.50676 .25 L
.50677 .25 L
.50677 .25 L
.50678 .25 L
.50678 .25 L
.50679 .25 L
.50679 .25 L
.5068 .25 L
.5068 .25 L
.50681 .25 L
.50682 .25 L
.50682 .25 L
.50683 .25 L
.50683 .25 L
.50684 .25 L
.50684 .25 L
.50684 .25 L
.50685 .25 L
.50686 .25 L
.50686 .25 L
.50687 .25 L
.50688 .25 L
.50688 .25 L
.50689 .25 L
.50689 .25 L
.5069 .25 L
.50691 .25 L
.50691 .25 L
.50692 .25 L
.50692 .25 L
.50693 .25 L
.50694 .25 L
.50694 .25 L
.50695 .25 L
.50696 .25 L
.50696 .25 L
Mistroke
.50697 .25 L
.50698 .25 L
.50698 .25 L
.50698 .25 L
.50699 .25 L
.50699 .25 L
.507 .25 L
.507 .25 L
.50701 .25 L
.50702 .25 L
.50702 .25 L
.50703 .25 L
.50703 .25 L
.50704 .25 L
.50705 .25 L
.50705 .25 L
.50706 .25 L
.50707 .25 L
.50707 .25 L
.50708 .25 L
.50709 .25 L
.50709 .25 L
.5071 .25 L
.50711 .25 L
.50711 .25 L
.50711 .25 L
.50712 .25 L
.50712 .25 L
.50713 .25 L
.50713 .25 L
.50713 .25 L
.50714 .25 L
.50714 .25 L
.50715 .25 L
.50715 .25 L
.50716 .25 L
.50716 .25 L
.50716 .25 L
.50717 .25 L
.50717 .25 L
.50718 .25 L
.50718 .25 L
.50719 .25 L
.5072 .25 L
.5072 .25 L
.50721 .25 L
.50722 .25 L
.50722 .25 L
.50723 .25 L
.50723 .25 L
Mistroke
.50724 .25 L
.50725 .25 L
.50725 .25 L
.50726 .25 L
.50727 .25 L
.50727 .25 L
.50727 .25 L
.50728 .25 L
.50729 .25 L
.50729 .25 L
.5073 .25 L
.50731 .25 L
.50731 .25 L
.50732 .25 L
.50732 .25 L
.50733 .25 L
.50734 .25 L
.50734 .25 L
.50735 .25 L
.50735 .25 L
.50736 .25 L
.50737 .25 L
.50737 .25 L
.50737 .25 L
.50738 .25 L
.50739 .25 L
.50739 .25 L
.5074 .25 L
.50741 .25 L
.50741 .25 L
.50742 .25 L
.50742 .25 L
.50743 .25 L
.50744 .25 L
.50744 .25 L
.50745 .25 L
.50746 .25 L
.50746 .25 L
.50747 .25 L
.50747 .25 L
.50748 .25 L
.50748 .25 L
.50749 .25 L
.5075 .25 L
.5075 .25 L
.50751 .25 L
.50752 .25 L
.50752 .25 L
.50753 .25 L
.50753 .25 L
Mistroke
.50754 .25 L
.50754 .25 L
.50755 .25 L
.50756 .25 L
.50756 .25 L
.50757 .25 L
.50757 .25 L
.50758 .25 L
.50758 .25 L
.50759 .25 L
.5076 .25 L
.5076 .25 L
.50761 .25 L
.50762 .25 L
.50762 .25 L
.50763 .25 L
.50763 .25 L
.50764 .25 L
.50765 .25 L
.50765 .25 L
.50766 .25 L
.50767 .25 L
.50767 .25 L
.50768 .25 L
.50768 .25 L
.50769 .25 L
.50769 .25 L
.5077 .25 L
.50771 .25 L
.50771 .25 L
.50772 .25 L
.50772 .25 L
.50773 .25 L
.50773 .25 L
.50774 .25 L
.50775 .25 L
.50775 .25 L
.50776 .25 L
.50776 .25 L
.50777 .25 L
.50778 .25 L
.50778 .25 L
.50778 .25 L
.50779 .25 L
.5078 .25 L
.5078 .25 L
.5078 .25 L
.50781 .25 L
.50782 .25 L
.50782 .25 L
Mistroke
.50783 .25 L
.50784 .25 L
.50784 .25 L
.50785 .25 L
.50785 .25 L
.50786 .25 L
.50786 .25 L
.50787 .25 L
.50787 .25 L
.50788 .25 L
.50788 .25 L
.50789 .25 L
.5079 .25 L
.5079 .25 L
.50791 .25 L
.50791 .25 L
.50792 .25 L
.50793 .25 L
.50793 .25 L
.50794 .25 L
.50794 .25 L
.50795 .25 L
.50796 .25 L
.50796 .25 L
.50797 .25 L
.50797 .25 L
.50798 .25 L
.50799 .25 L
.50799 .25 L
.508 .25 L
.50801 .25 L
.50801 .25 L
.50801 .25 L
.50802 .25 L
.50802 .25 L
.50803 .25 L
.50804 .25 L
.50804 .25 L
.50805 .25 L
.50805 .25 L
.50806 .25 L
.50807 .25 L
.50807 .25 L
.50808 .25 L
.50809 .25 L
.50809 .25 L
.5081 .25 L
.50811 .25 L
.50811 .25 L
.50812 .25 L
Mistroke
.50812 .25 L
.50813 .25 L
.50814 .25 L
.50814 .25 L
.50815 .25 L
.50815 .25 L
.50815 .25 L
.50816 .25 L
.50816 .25 L
.50817 .25 L
.50817 .25 L
.50817 .25 L
.50818 .25 L
.50818 .25 L
.50819 .25 L
.50819 .25 L
.50819 .25 L
.5082 .25 L
.5082 .25 L
.50821 .25 L
.50822 .25 L
.50822 .25 L
.50823 .25 L
.50824 .25 L
.50824 .25 L
.50825 .25 L
.50825 .25 L
.50826 .25 L
.50827 .25 L
.50827 .25 L
.50828 .25 L
.50829 .25 L
.50829 .25 L
.5083 .25 L
.5083 .25 L
.50831 .25 L
.50832 .25 L
.50832 .25 L
.50833 .25 L
.50833 .25 L
.50834 .25 L
.50835 .25 L
.50835 .25 L
.50836 .25 L
.50836 .25 L
.50837 .25 L
.50837 .25 L
.50838 .25 L
.50839 .25 L
.50839 .25 L
Mistroke
.5084 .25 L
.5084 .25 L
.50841 .25 L
.50841 .25 L
.50842 .25 L
.50843 .25 L
.50843 .25 L
.50844 .25 L
.50845 .25 L
.50845 .25 L
.50846 .25 L
.50846 .25 L
.50847 .25 L
.50848 .25 L
.50848 .25 L
.50849 .25 L
.5085 .25 L
.5085 .25 L
.5085 .25 L
.50851 .25 L
.50852 .25 L
.50852 .25 L
.50853 .25 L
.50854 .25 L
.50854 .25 L
.50855 .25 L
.50855 .25 L
.50856 .25 L
.50856 .25 L
.50857 .25 L
.50858 .25 L
.50858 .25 L
.50859 .25 L
.5086 .25 L
.5086 .25 L
.5086 .25 L
.50861 .25 L
.50862 .25 L
.50862 .25 L
.50863 .25 L
.50863 .25 L
.50864 .25 L
.50864 .25 L
.50865 .25 L
.50865 .25 L
.50866 .25 L
.50867 .25 L
.50867 .25 L
.50868 .25 L
.50868 .25 L
Mistroke
.50869 .25 L
.50869 .25 L
.50869 .25 L
.5087 .25 L
.50871 .25 L
.50871 .25 L
.50872 .25 L
.50873 .25 L
.50873 .25 L
.50874 .25 L
.50874 .25 L
.50875 .25 L
.50876 .25 L
.50876 .25 L
.50877 .25 L
.50877 .25 L
.50878 .25 L
.50879 .25 L
.50879 .25 L
.5088 .25 L
.50881 .25 L
.50881 .25 L
.50882 .25 L
.50883 .25 L
.50883 .25 L
.50884 .25 L
.50884 .25 L
.50884 .25 L
.50885 .25 L
.50885 .25 L
.50886 .25 L
.50887 .25 L
.50887 .25 L
.50888 .25 L
.50889 .25 L
.50889 .25 L
.5089 .25 L
.5089 .25 L
.50891 .25 L
.50892 .25 L
.50892 .25 L
.50893 .25 L
.50894 .25 L
.50894 .25 L
.50895 .25 L
.50896 .25 L
.50896 .25 L
.50896 .25 L
.50897 .25 L
.50897 .25 L
Mistroke
.50898 .25 L
.50898 .25 L
.50898 .25 L
.50899 .25 L
.509 .25 L
.509 .25 L
.509 .25 L
.50901 .25 L
.50901 .25 L
.50901 .25 L
.50902 .25 L
.50902 .25 L
.50903 .25 L
.50903 .25 L
.50904 .25 L
.50905 .25 L
.50905 .25 L
.50906 .25 L
.50907 .25 L
.50907 .25 L
.50908 .25 L
.50909 .25 L
.50909 .25 L
.5091 .25 L
.5091 .25 L
.50911 .25 L
.50912 .25 L
.50912 .25 L
.50913 .25 L
.50913 .25 L
.50914 .25 L
.50914 .25 L
.50915 .25 L
.50916 .25 L
.50916 .25 L
.50917 .25 L
.50917 .25 L
.50918 .25 L
.50919 .25 L
.50919 .25 L
.5092 .25 L
.5092 .25 L
.50921 .25 L
.50922 .25 L
.50922 .25 L
.50922 .25 L
.50923 .25 L
.50924 .25 L
.50924 .25 L
.50925 .25 L
Mistroke
.50926 .25 L
.50926 .25 L
.50927 .25 L
.50928 .25 L
.50928 .25 L
.50929 .25 L
.50929 .25 L
.5093 .25 L
.50931 .25 L
.50931 .25 L
.50932 .25 L
.50932 .25 L
.50933 .25 L
.50934 .25 L
.50934 .25 L
.50935 .25 L
.50935 .25 L
.50936 .25 L
.50937 .25 L
.50937 .25 L
.50938 .25 L
.50938 .25 L
.50939 .25 L
.50939 .25 L
.5094 .25 L
.50941 .25 L
.50941 .25 L
.50942 .25 L
.50942 .25 L
.50943 .25 L
.50943 .25 L
.50944 .25 L
.50945 .25 L
.50945 .25 L
.50945 .25 L
.50946 .25 L
.50947 .25 L
.50947 .25 L
.50948 .25 L
.50948 .25 L
.50949 .25 L
.5095 .25 L
.5095 .25 L
.5095 .25 L
.50951 .25 L
.50951 .25 L
.50952 .25 L
.50952 .25 L
.50953 .25 L
.50954 .25 L
Mistroke
.50954 .25 L
.50955 .25 L
.50956 .25 L
.50956 .25 L
.50957 .25 L
.50957 .25 L
.50958 .25 L
.50959 .25 L
.50959 .25 L
.5096 .25 L
.5096 .25 L
.50961 .25 L
.50962 .25 L
.50962 .25 L
.50963 .25 L
.50964 .25 L
.50964 .25 L
.50965 .25 L
.50966 .25 L
.50966 .25 L
.50966 .25 L
.50967 .25 L
.50967 .25 L
.50968 .25 L
.50968 .25 L
.50969 .25 L
.5097 .25 L
.5097 .25 L
.50971 .25 L
.50972 .25 L
.50972 .25 L
.50973 .25 L
.50973 .25 L
.50974 .25 L
.50975 .25 L
.50975 .25 L
.50976 .25 L
.50977 .25 L
.50977 .25 L
.50978 .25 L
.50978 .25 L
.50979 .25 L
.50979 .25 L
.5098 .25 L
.5098 .25 L
.5098 .25 L
.50981 .25 L
.50982 .25 L
.50982 .25 L
.50982 .25 L
Mistroke
.50983 .25 L
.50983 .25 L
.50983 .25 L
.50984 .25 L
.50984 .25 L
.50985 .25 L
.50985 .25 L
.50986 .25 L
.50986 .25 L
.50987 .25 L
.50988 .25 L
.50988 .25 L
.50989 .25 L
.5099 .25 L
.5099 .25 L
.50991 .25 L
.50992 .25 L
.50992 .25 L
.50993 .25 L
.50993 .25 L
.50994 .25 L
.50995 .25 L
.50995 .25 L
.50996 .25 L
.50996 .25 L
.50997 .25 L
.50997 .25 L
.50998 .25 L
.50999 .25 L
.50999 .25 L
.51 .25 L
.51 .25 L
.51001 .25 L
.51002 .25 L
.51002 .25 L
.51003 .25 L
.51003 .25 L
.51004 .25 L
.51004 .25 L
.51005 .25 L
.51005 .25 L
.51006 .25 L
.51007 .25 L
.51007 .25 L
.51008 .25 L
.51009 .25 L
.51009 .25 L
.5101 .25 L
.51011 .25 L
.51011 .25 L
Mistroke
.51012 .25 L
.51012 .25 L
.51013 .25 L
.51014 .25 L
.51014 .25 L
.51015 .25 L
.51015 .25 L
.51016 .25 L
.51017 .25 L
.51017 .25 L
.51018 .25 L
.51018 .25 L
.51019 .25 L
.5102 .25 L
.5102 .25 L
.51021 .25 L
.51021 .25 L
.51022 .25 L
.51022 .25 L
.51023 .25 L
.51024 .25 L
.51024 .25 L
.51025 .25 L
.51025 .25 L
.51026 .25 L
.51026 .25 L
.51027 .25 L
.51027 .25 L
.51028 .25 L
.51028 .25 L
.51029 .25 L
.5103 .25 L
.5103 .25 L
.51031 .25 L
.51031 .25 L
.51032 .25 L
.51032 .25 L
.51033 .25 L
.51033 .25 L
.51034 .25 L
.51034 .25 L
.51035 .25 L
.51036 .25 L
.51036 .25 L
.51037 .25 L
.51037 .25 L
.51038 .25 L
.51039 .25 L
.51039 .25 L
.5104 .25 L
Mistroke
.5104 .25 L
.51041 .25 L
.51042 .25 L
.51042 .25 L
.51043 .25 L
.51043 .25 L
.51044 .25 L
.51045 .25 L
.51045 .25 L
.51046 .25 L
.51047 .25 L
.51047 .25 L
.51048 .25 L
.51048 .25 L
.51049 .25 L
.51049 .25 L
.51049 .25 L
.5105 .25 L
.51051 .25 L
.51051 .25 L
.51052 .25 L
.51053 .25 L
.51053 .25 L
.51054 .25 L
.51054 .25 L
.51055 .25 L
.51056 .25 L
.51056 .25 L
.51057 .25 L
.51058 .25 L
.51058 .25 L
.51059 .25 L
.5106 .25 L
.5106 .25 L
.51061 .25 L
.51061 .25 L
.51062 .25 L
.51062 .25 L
.51062 .25 L
.51063 .25 L
.51063 .25 L
.51064 .25 L
.51064 .25 L
.51065 .25 L
.51065 .25 L
.51065 .25 L
.51066 .25 L
.51066 .25 L
.51067 .25 L
.51067 .25 L
Mistroke
.51068 .25 L
.51068 .25 L
.51069 .25 L
.5107 .25 L
.5107 .25 L
.51071 .25 L
.51071 .25 L
.51072 .25 L
.51073 .25 L
.51073 .25 L
.51074 .25 L
.51075 .25 L
.51075 .25 L
.51076 .25 L
.51077 .25 L
.51077 .25 L
.51077 .25 L
.51078 .25 L
.51079 .25 L
.51079 .25 L
.5108 .25 L
.5108 .25 L
.51081 .25 L
.51082 .25 L
.51082 .25 L
.51083 .25 L
.51083 .25 L
.51084 .25 L
.51085 .25 L
.51085 .25 L
.51086 .25 L
.51086 .25 L
.51087 .25 L
.51087 .25 L
.51088 .25 L
.51088 .25 L
.51089 .25 L
.5109 .25 L
.5109 .25 L
.51091 .25 L
.51092 .25 L
.51092 .25 L
.51093 .25 L
.51093 .25 L
.51094 .25 L
.51095 .25 L
.51095 .25 L
.51096 .25 L
.51097 .25 L
.51097 .25 L
Mistroke
.51098 .25 L
.51098 .25 L
.51099 .25 L
.51099 .25 L
.511 .25 L
.51101 .25 L
.51101 .25 L
.51102 .25 L
.51102 .25 L
.51103 .25 L
.51104 .25 L
.51104 .25 L
.51105 .25 L
.51105 .25 L
.51106 .25 L
.51107 .25 L
.51107 .25 L
.51107 .25 L
.51108 .25 L
.51109 .25 L
.51109 .25 L
.5111 .25 L
.51111 .25 L
.51111 .25 L
.51112 .25 L
.51112 .25 L
.51113 .25 L
.51114 .25 L
.51114 .25 L
.51115 .25 L
.51116 .25 L
.51116 .25 L
.51117 .25 L
.51117 .25 L
.51118 .25 L
.51118 .25 L
.51119 .25 L
.5112 .25 L
.5112 .25 L
.51121 .25 L
.51122 .25 L
.51122 .25 L
.51123 .25 L
.51123 .25 L
.51124 .25 L
.51124 .25 L
.51125 .25 L
.51126 .25 L
.51126 .25 L
.51127 .25 L
Mistroke
.51127 .25 L
.51128 .25 L
.51128 .25 L
.51129 .25 L
.5113 .25 L
.5113 .25 L
.5113 .25 L
.51131 .25 L
.51132 .25 L
.51132 .25 L
.51133 .25 L
.51133 .25 L
.51134 .25 L
.51135 .25 L
.51135 .25 L
.51135 .25 L
.51136 .25 L
.51136 .25 L
.51137 .25 L
.51137 .25 L
.51138 .25 L
.51139 .25 L
.51139 .25 L
.5114 .25 L
.51141 .25 L
.51141 .25 L
.51142 .25 L
.51142 .25 L
.51143 .25 L
.51144 .25 L
.51144 .25 L
.51145 .25 L
.51145 .25 L
.51146 .25 L
.51147 .25 L
.51147 .25 L
.51148 .25 L
.51149 .25 L
.51149 .25 L
.5115 .25 L
.51151 .25 L
.51151 .25 L
.51151 .25 L
.51152 .25 L
.51152 .25 L
.51153 .25 L
.51153 .25 L
.51154 .25 L
.51155 .25 L
.51155 .25 L
Mistroke
.51156 .25 L
.51157 .25 L
.51157 .25 L
.51158 .25 L
.51158 .25 L
.51159 .25 L
.5116 .25 L
.5116 .25 L
.51161 .25 L
.51162 .25 L
.51162 .25 L
.51163 .25 L
.51163 .25 L
.51164 .25 L
.51164 .25 L
.51165 .25 L
.51165 .25 L
.51165 .25 L
.51166 .25 L
.51167 .25 L
.51167 .25 L
.51167 .25 L
.51168 .25 L
.51168 .25 L
.51168 .25 L
.51169 .25 L
.51169 .25 L
.5117 .25 L
.5117 .25 L
.51171 .25 L
.51172 .25 L
.51172 .25 L
.51173 .25 L
.51173 .25 L
.51174 .25 L
.51175 .25 L
.51175 .25 L
.51176 .25 L
.51177 .25 L
.51177 .25 L
.51178 .25 L
.51178 .25 L
.51179 .25 L
.5118 .25 L
.5118 .25 L
.51181 .25 L
.51181 .25 L
.51182 .25 L
.51182 .25 L
.51183 .25 L
Mistroke
.51184 .25 L
.51184 .25 L
.51185 .25 L
.51185 .25 L
.51186 .25 L
.51187 .25 L
.51187 .25 L
.51188 .25 L
.51188 .25 L
.51189 .25 L
.51189 .25 L
.5119 .25 L
.5119 .25 L
.51191 .25 L
.51192 .25 L
.51192 .25 L
.51193 .25 L
.51194 .25 L
.51194 .25 L
.51195 .25 L
.51196 .25 L
.51196 .25 L
.51197 .25 L
.51198 .25 L
.51198 .25 L
.51199 .25 L
.51199 .25 L
.512 .25 L
.512 .25 L
.51201 .25 L
.51202 .25 L
.51202 .25 L
.51203 .25 L
.51203 .25 L
.51204 .25 L
.51205 .25 L
.51205 .25 L
.51206 .25 L
.51206 .25 L
.51207 .25 L
.51208 .25 L
.51208 .25 L
.51209 .25 L
.51209 .25 L
.5121 .25 L
.5121 .25 L
.51211 .25 L
.51211 .25 L
.51212 .25 L
.51212 .25 L
Mistroke
.51213 .25 L
.51213 .25 L
.51214 .25 L
.51215 .25 L
.51215 .25 L
.51216 .25 L
.51216 .25 L
.51217 .25 L
.51217 .25 L
.51218 .25 L
.51219 .25 L
.51219 .25 L
.51219 .25 L
.5122 .25 L
.51221 .25 L
.51221 .25 L
.51222 .25 L
.51222 .25 L
.51223 .25 L
.51224 .25 L
.51224 .25 L
.51225 .25 L
.51225 .25 L
.51226 .25 L
.51227 .25 L
.51227 .25 L
.51228 .25 L
.51228 .25 L
.51229 .25 L
.5123 .25 L
.5123 .25 L
.51231 .25 L
.51232 .25 L
.51232 .25 L
.51233 .25 L
.51233 .25 L
.51234 .25 L
.51234 .25 L
.51234 .25 L
.51235 .25 L
.51236 .25 L
.51236 .25 L
.51237 .25 L
.51238 .25 L
.51238 .25 L
.51239 .25 L
.51239 .25 L
.5124 .25 L
.51241 .25 L
.51241 .25 L
Mistroke
.51242 .25 L
.51243 .25 L
.51243 .25 L
.51244 .25 L
.51245 .25 L
.51245 .25 L
.51246 .25 L
.51246 .25 L
.51247 .25 L
.51247 .25 L
.51248 .25 L
.51248 .25 L
.51248 .25 L
.51249 .25 L
.51249 .25 L
.5125 .25 L
.5125 .25 L
.5125 .25 L
.51251 .25 L
.51251 .25 L
.51252 .25 L
.51252 .25 L
.51253 .25 L
.51253 .25 L
.51254 .25 L
.51255 .25 L
.51255 .25 L
.51256 .25 L
.51257 .25 L
.51257 .25 L
.51258 .25 L
.51258 .25 L
.51259 .25 L
.5126 .25 L
.5126 .25 L
.51261 .25 L
.51262 .25 L
.51262 .25 L
.51262 .25 L
.51263 .25 L
.51264 .25 L
.51264 .25 L
.51265 .25 L
.51266 .25 L
.51266 .25 L
.51267 .25 L
.51267 .25 L
.51268 .25 L
.51268 .25 L
.51269 .25 L
Mistroke
.5127 .25 L
.5127 .25 L
.51271 .25 L
.51271 .25 L
.51272 .25 L
.51272 .25 L
.51273 .25 L
.51274 .25 L
.51274 .25 L
.51275 .25 L
.51276 .25 L
.51276 .25 L
.51277 .25 L
.51277 .25 L
.51278 .25 L
.51279 .25 L
.51279 .25 L
.5128 .25 L
.51281 .25 L
.51281 .25 L
.51282 .25 L
.51282 .25 L
.51283 .25 L
.51283 .25 L
.51284 .25 L
.51285 .25 L
.51285 .25 L
.51286 .25 L
.51286 .25 L
.51287 .25 L
.51287 .25 L
.51288 .25 L
.51289 .25 L
.51289 .25 L
.5129 .25 L
.51291 .25 L
.51291 .25 L
.51292 .25 L
.51292 .25 L
.51292 .25 L
.51293 .25 L
.51294 .25 L
.51294 .25 L
.51295 .25 L
.51295 .25 L
.51296 .25 L
.51296 .25 L
.51297 .25 L
.51298 .25 L
.51298 .25 L
Mistroke
.51299 .25 L
.51299 .25 L
.513 .25 L
.513 .25 L
.51301 .25 L
.51301 .25 L
.51302 .25 L
.51302 .25 L
.51303 .25 L
.51304 .25 L
.51304 .25 L
.51305 .25 L
.51305 .25 L
.51306 .25 L
.51307 .25 L
.51307 .25 L
.51308 .25 L
.51308 .25 L
.51309 .25 L
.5131 .25 L
.5131 .25 L
.51311 .25 L
.51311 .25 L
.51312 .25 L
.51313 .25 L
.51313 .25 L
.51314 .25 L
.51315 .25 L
.51315 .25 L
.51316 .25 L
.51316 .25 L
.51316 .25 L
.51317 .25 L
.51318 .25 L
.51318 .25 L
.51319 .25 L
.5132 .25 L
.5132 .25 L
.51321 .25 L
.51321 .25 L
.51322 .25 L
.51323 .25 L
.51323 .25 L
.51324 .25 L
.51324 .25 L
.51325 .25 L
.51326 .25 L
.51326 .25 L
.51327 .25 L
.51328 .25 L
Mistroke
.51328 .25 L
.51329 .25 L
.51329 .25 L
.5133 .25 L
.5133 .25 L
.5133 .25 L
.51331 .25 L
.51331 .25 L
.51332 .25 L
.51332 .25 L
.51332 .25 L
.51333 .25 L
.51333 .25 L
.51334 .25 L
.51334 .25 L
.51334 .25 L
.51335 .25 L
.51336 .25 L
.51336 .25 L
.51337 .25 L
.51338 .25 L
.51338 .25 L
.51339 .25 L
.51339 .25 L
.5134 .25 L
.51341 .25 L
.51341 .25 L
.51342 .25 L
.51343 .25 L
.51343 .25 L
.51344 .25 L
.51344 .25 L
.51345 .25 L
.51345 .25 L
.51346 .25 L
.51347 .25 L
.51347 .25 L
.51348 .25 L
.51349 .25 L
.51349 .25 L
.5135 .25 L
.5135 .25 L
.51351 .25 L
.51351 .25 L
.51352 .25 L
.51353 .25 L
.51353 .25 L
.51354 .25 L
.51354 .25 L
.51355 .25 L
Mistroke
.51355 .25 L
.51356 .25 L
.51357 .25 L
.51357 .25 L
.51358 .25 L
.51359 .25 L
.51359 .25 L
.5136 .25 L
.5136 .25 L
.51361 .25 L
.51362 .25 L
.51362 .25 L
.51363 .25 L
.51364 .25 L
.51364 .25 L
.51365 .25 L
.51365 .25 L
.51366 .25 L
.51366 .25 L
.51367 .25 L
.51368 .25 L
.51368 .25 L
.51369 .25 L
.51369 .25 L
.5137 .25 L
.5137 .25 L
.51371 .25 L
.51372 .25 L
.51372 .25 L
.51373 .25 L
.51373 .25 L
.51374 .25 L
.51374 .25 L
.51375 .25 L
.51375 .25 L
.51376 .25 L
.51377 .25 L
.51377 .25 L
.51377 .25 L
.51378 .25 L
.51379 .25 L
.51379 .25 L
.5138 .25 L
.51381 .25 L
.51381 .25 L
.51382 .25 L
.51382 .25 L
.51383 .25 L
.51383 .25 L
.51384 .25 L
Mistroke
.51384 .25 L
.51385 .25 L
.51385 .25 L
.51386 .25 L
.51387 .25 L
.51387 .25 L
.51388 .25 L
.51388 .25 L
.51389 .25 L
.51389 .25 L
.5139 .25 L
.51391 .25 L
.51391 .25 L
.51392 .25 L
.51393 .25 L
.51393 .25 L
.51394 .25 L
.51394 .25 L
.51395 .25 L
.51396 .25 L
.51396 .25 L
.51397 .25 L
.51398 .25 L
.51398 .25 L
.51398 .25 L
.51399 .25 L
.51399 .25 L
.514 .25 L
.514 .25 L
.51401 .25 L
.51402 .25 L
.51402 .25 L
.51403 .25 L
.51404 .25 L
.51404 .25 L
.51405 .25 L
.51406 .25 L
.51406 .25 L
.51407 .25 L
.51407 .25 L
.51408 .25 L
.51409 .25 L
.51409 .25 L
.5141 .25 L
.51411 .25 L
.51411 .25 L
.51412 .25 L
.51412 .25 L
.51412 .25 L
.51413 .25 L
Mistroke
.51413 .25 L
.51414 .25 L
.51414 .25 L
.51414 .25 L
.51415 .25 L
.51415 .25 L
.51416 .25 L
.51416 .25 L
.51416 .25 L
.51417 .25 L
.51417 .25 L
.51418 .25 L
.51419 .25 L
.51419 .25 L
.5142 .25 L
.51421 .25 L
.51421 .25 L
.51422 .25 L
.51422 .25 L
.51423 .25 L
.51424 .25 L
.51424 .25 L
.51425 .25 L
.51426 .25 L
.51426 .25 L
.51427 .25 L
.51427 .25 L
.51428 .25 L
.51428 .25 L
.51429 .25 L
.5143 .25 L
.5143 .25 L
.51431 .25 L
.51431 .25 L
.51432 .25 L
.51433 .25 L
.51433 .25 L
.51434 .25 L
.51434 .25 L
.51435 .25 L
.51436 .25 L
.51436 .25 L
.51437 .25 L
.51437 .25 L
.51438 .25 L
.51438 .25 L
.51439 .25 L
.5144 .25 L
.5144 .25 L
.51441 .25 L
Mistroke
.51441 .25 L
.51442 .25 L
.51443 .25 L
.51443 .25 L
.51444 .25 L
.51445 .25 L
.51445 .25 L
.51446 .25 L
.51447 .25 L
.51447 .25 L
.51447 .25 L
.51448 .25 L
.51449 .25 L
.51449 .25 L
.5145 .25 L
.51451 .25 L
.51451 .25 L
.51452 .25 L
.51452 .25 L
.51453 .25 L
.51453 .25 L
.51454 .25 L
.51455 .25 L
.51455 .25 L
.51456 .25 L
.51456 .25 L
.51457 .25 L
.51457 .25 L
.51458 .25 L
.51458 .25 L
.51459 .25 L
.51459 .25 L
.5146 .25 L
.5146 .25 L
.51461 .25 L
.51462 .25 L
.51462 .25 L
.51463 .25 L
.51464 .25 L
.51464 .25 L
.51465 .25 L
.51465 .25 L
.51466 .25 L
.51466 .25 L
.51466 .25 L
.51467 .25 L
.51468 .25 L
.51468 .25 L
.51469 .25 L
.5147 .25 L
Mistroke
.5147 .25 L
.51471 .25 L
.51471 .25 L
.51472 .25 L
.51472 .25 L
.51473 .25 L
.51474 .25 L
.51474 .25 L
.51475 .25 L
.51476 .25 L
.51476 .25 L
.51477 .25 L
.51478 .25 L
.51478 .25 L
.51479 .25 L
.51479 .25 L
.5148 .25 L
.5148 .25 L
.51481 .25 L
.51481 .25 L
.51482 .25 L
.51482 .25 L
.51483 .25 L
.51484 .25 L
.51484 .25 L
.51485 .25 L
.51485 .25 L
.51486 .25 L
.51487 .25 L
.51487 .25 L
.51488 .25 L
.51489 .25 L
.51489 .25 L
.5149 .25 L
.51491 .25 L
.51491 .25 L
.51492 .25 L
.51492 .25 L
.51493 .25 L
.51493 .25 L
.51494 .25 L
.51494 .25 L
.51495 .25 L
.51495 .25 L
.51495 .25 L
.51496 .25 L
.51496 .25 L
.51497 .25 L
.51497 .25 L
.51498 .25 L
Mistroke
.51498 .25 L
.51498 .25 L
.51499 .25 L
.51499 .25 L
.515 .25 L
.515 .25 L
.51501 .25 L
.51502 .25 L
.51502 .25 L
.51503 .25 L
.51504 .25 L
.51504 .25 L
.51505 .25 L
.51505 .25 L
.51506 .25 L
.51507 .25 L
.51507 .25 L
.51508 .25 L
.51509 .25 L
.51509 .25 L
.51509 .25 L
.5151 .25 L
.51511 .25 L
.51511 .25 L
.51512 .25 L
.51513 .25 L
.51513 .25 L
.51514 .25 L
.51514 .25 L
.51515 .25 L
.51515 .25 L
.51516 .25 L
.51517 .25 L
.51517 .25 L
.51518 .25 L
.51519 .25 L
.51519 .25 L
.51519 .25 L
.5152 .25 L
.51521 .25 L
.51521 .25 L
.51522 .25 L
.51523 .25 L
.51523 .25 L
.51524 .25 L
.51524 .25 L
.51525 .25 L
.51526 .25 L
.51526 .25 L
.51527 .25 L
Mistroke
.51528 .25 L
.51528 .25 L
.51529 .25 L
.51529 .25 L
.5153 .25 L
.5153 .25 L
.51531 .25 L
.51532 .25 L
.51532 .25 L
.51533 .25 L
.51533 .25 L
.51534 .25 L
.51535 .25 L
.51535 .25 L
.51536 .25 L
.51536 .25 L
.51537 .25 L
.51538 .25 L
.51538 .25 L
.51539 .25 L
.51539 .25 L
.5154 .25 L
.5154 .25 L
.51541 .25 L
.51541 .25 L
.51542 .25 L
.51543 .25 L
.51543 .25 L
.51544 .25 L
.51545 .25 L
.51545 .25 L
.51546 .25 L
.51547 .25 L
.51547 .25 L
.51548 .25 L
.51548 .25 L
.51549 .25 L
.5155 .25 L
.5155 .25 L
.51551 .25 L
.51551 .25 L
.51552 .25 L
.51552 .25 L
.51553 .25 L
.51554 .25 L
.51554 .25 L
.51555 .25 L
.51555 .25 L
.51556 .25 L
.51557 .25 L
Mistroke
.51557 .25 L
.51558 .25 L
.51558 .25 L
.51559 .25 L
.51559 .25 L
.5156 .25 L
.5156 .25 L
.51561 .25 L
.51562 .25 L
.51562 .25 L
.51562 .25 L
.51563 .25 L
.51564 .25 L
.51564 .25 L
.51565 .25 L
.51565 .25 L
.51566 .25 L
.51567 .25 L
.51567 .25 L
.51568 .25 L
.51568 .25 L
.51569 .25 L
.51569 .25 L
.5157 .25 L
.5157 .25 L
.51571 .25 L
.51572 .25 L
.51572 .25 L
.51573 .25 L
.51573 .25 L
.51574 .25 L
.51574 .25 L
.51575 .25 L
.51576 .25 L
.51576 .25 L
.51577 .25 L
.51578 .25 L
.51578 .25 L
.51579 .25 L
.51579 .25 L
.5158 .25 L
.51581 .25 L
.51581 .25 L
.51582 .25 L
.51583 .25 L
.51583 .25 L
.51583 .25 L
.51584 .25 L
.51584 .25 L
.51585 .25 L
Mistroke
.51585 .25 L
.51586 .25 L
.51587 .25 L
.51587 .25 L
.51588 .25 L
.51589 .25 L
.51589 .25 L
.5159 .25 L
.51591 .25 L
.51591 .25 L
.51592 .25 L
.51592 .25 L
.51593 .25 L
.51594 .25 L
.51594 .25 L
.51595 .25 L
.51595 .25 L
.51596 .25 L
.51597 .25 L
.51597 .25 L
.51597 .25 L
.51598 .25 L
.51598 .25 L
.51599 .25 L
.51599 .25 L
.51599 .25 L
.516 .25 L
.516 .25 L
.51601 .25 L
.51601 .25 L
.51601 .25 L
.51602 .25 L
.51602 .25 L
.51603 .25 L
.51604 .25 L
.51604 .25 L
.51605 .25 L
.51606 .25 L
.51606 .25 L
.51607 .25 L
.51607 .25 L
.51608 .25 L
.51609 .25 L
.51609 .25 L
.5161 .25 L
.51611 .25 L
.51611 .25 L
.51612 .25 L
.51612 .25 L
.51613 .25 L
Mistroke
.51613 .25 L
.51614 .25 L
.51615 .25 L
.51615 .25 L
.51616 .25 L
.51616 .25 L
.51617 .25 L
.51618 .25 L
.51618 .25 L
.51619 .25 L
.51619 .25 L
.5162 .25 L
.51621 .25 L
.51621 .25 L
.51622 .25 L
.51622 .25 L
.51623 .25 L
.51623 .25 L
.51624 .25 L
.51625 .25 L
.51625 .25 L
.51626 .25 L
.51626 .25 L
.51627 .25 L
.51628 .25 L
.51628 .25 L
.51629 .25 L
.5163 .25 L
.5163 .25 L
.51631 .25 L
.51632 .25 L
.51632 .25 L
.51632 .25 L
.51633 .25 L
.51634 .25 L
.51634 .25 L
.51635 .25 L
.51636 .25 L
.51636 .25 L
.51637 .25 L
.51637 .25 L
.51638 .25 L
.51638 .25 L
.51639 .25 L
.5164 .25 L
.5164 .25 L
.51641 .25 L
.51641 .25 L
.51642 .25 L
.51642 .25 L
Mistroke
.51643 .25 L
.51643 .25 L
.51644 .25 L
.51644 .25 L
.51645 .25 L
.51645 .25 L
.51646 .25 L
.51647 .25 L
.51647 .25 L
.51648 .25 L
.51649 .25 L
.51649 .25 L
.5165 .25 L
.5165 .25 L
.51651 .25 L
.51651 .25 L
.51651 .25 L
.51652 .25 L
.51653 .25 L
.51653 .25 L
.51654 .25 L
.51655 .25 L
.51655 .25 L
.51656 .25 L
.51656 .25 L
.51657 .25 L
.51658 .25 L
.51658 .25 L
.51659 .25 L
.51659 .25 L
.5166 .25 L
.51661 .25 L
.51661 .25 L
.51662 .25 L
.51663 .25 L
.51663 .25 L
.51664 .25 L
.51664 .25 L
.51665 .25 L
.51665 .25 L
.51666 .25 L
.51666 .25 L
.51667 .25 L
.51667 .25 L
.51668 .25 L
.51669 .25 L
.51669 .25 L
.5167 .25 L
.5167 .25 L
.51671 .25 L
Mistroke
.51672 .25 L
.51672 .25 L
.51673 .25 L
.51674 .25 L
.51674 .25 L
.51675 .25 L
.51676 .25 L
.51676 .25 L
.51677 .25 L
.51677 .25 L
.51678 .25 L
.51678 .25 L
.51679 .25 L
.51679 .25 L
.5168 .25 L
.5168 .25 L
.5168 .25 L
.51681 .25 L
.51681 .25 L
.51682 .25 L
.51682 .25 L
.51683 .25 L
.51683 .25 L
.51683 .25 L
.51684 .25 L
.51684 .25 L
.51685 .25 L
.51685 .25 L
.51686 .25 L
.51687 .25 L
.51687 .25 L
.51688 .25 L
.51689 .25 L
.51689 .25 L
.5169 .25 L
.5169 .25 L
.51691 .25 L
.51692 .25 L
.51692 .25 L
.51693 .25 L
.51694 .25 L
.51694 .25 L
.51694 .25 L
.51695 .25 L
.51696 .25 L
.51696 .25 L
.51697 .25 L
.51698 .25 L
.51698 .25 L
.51699 .25 L
Mistroke
.51699 .25 L
.517 .25 L
.51701 .25 L
.51701 .25 L
.51702 .25 L
.51702 .25 L
.51703 .25 L
.51704 .25 L
.51704 .25 L
.51704 .25 L
.51705 .25 L
.51706 .25 L
.51706 .25 L
.51707 .25 L
.51708 .25 L
.51708 .25 L
.51709 .25 L
.51709 .25 L
.5171 .25 L
.51711 .25 L
.51711 .25 L
.51712 .25 L
.51713 .25 L
.51713 .25 L
.51714 .25 L
.51714 .25 L
.51715 .25 L
.51715 .25 L
.51716 .25 L
.51717 .25 L
.51717 .25 L
.51718 .25 L
.51719 .25 L
.51719 .25 L
.5172 .25 L
.5172 .25 L
.51721 .25 L
.51721 .25 L
.51722 .25 L
.51723 .25 L
.51723 .25 L
.51724 .25 L
.51724 .25 L
.51725 .25 L
.51725 .25 L
.51726 .25 L
.51727 .25 L
.51727 .25 L
.51727 .25 L
.51728 .25 L
Mistroke
.51728 .25 L
.51729 .25 L
.5173 .25 L
.5173 .25 L
.51731 .25 L
.51732 .25 L
.51732 .25 L
.51732 .25 L
.51733 .25 L
.51733 .25 L
.51734 .25 L
.51734 .25 L
.51735 .25 L
.51736 .25 L
.51736 .25 L
.51737 .25 L
.51738 .25 L
.51738 .25 L
.51739 .25 L
.51739 .25 L
.5174 .25 L
.51741 .25 L
.51741 .25 L
.51742 .25 L
.51742 .25 L
.51743 .25 L
.51744 .25 L
.51744 .25 L
.51745 .25 L
.51745 .25 L
.51746 .25 L
.51747 .25 L
.51747 .25 L
.51748 .25 L
.51748 .25 L
.51749 .25 L
.51749 .25 L
.5175 .25 L
.5175 .25 L
.51751 .25 L
.51752 .25 L
.51752 .25 L
.51753 .25 L
.51753 .25 L
.51754 .25 L
.51755 .25 L
.51755 .25 L
.51756 .25 L
.51757 .25 L
.51757 .25 L
Mistroke
.51758 .25 L
.51759 .25 L
.51759 .25 L
.5176 .25 L
.5176 .25 L
.51761 .25 L
.51761 .25 L
.51762 .25 L
.51762 .25 L
.51762 .25 L
.51763 .25 L
.51763 .25 L
.51764 .25 L
.51764 .25 L
.51765 .25 L
.51765 .25 L
.51765 .25 L
.51766 .25 L
.51766 .25 L
.51766 .25 L
.51767 .25 L
.51768 .25 L
.51768 .25 L
.51769 .25 L
.5177 .25 L
.5177 .25 L
.51771 .25 L
.51772 .25 L
.51772 .25 L
.51773 .25 L
.51773 .25 L
.51774 .25 L
.51775 .25 L
.51775 .25 L
.51776 .25 L
.51776 .25 L
.51777 .25 L
.51778 .25 L
.51778 .25 L
.51779 .25 L
.51779 .25 L
.5178 .25 L
.51781 .25 L
.51781 .25 L
.51782 .25 L
.51782 .25 L
.51783 .25 L
.51783 .25 L
.51784 .25 L
.51785 .25 L
Mistroke
.51785 .25 L
.51786 .25 L
.51786 .25 L
.51787 .25 L
.51787 .25 L
.51788 .25 L
.51789 .25 L
.51789 .25 L
.5179 .25 L
.51791 .25 L
.51791 .25 L
.51792 .25 L
.51792 .25 L
.51793 .25 L
.51794 .25 L
.51794 .25 L
.51795 .25 L
.51796 .25 L
.51796 .25 L
.51797 .25 L
.51797 .25 L
.51798 .25 L
.51798 .25 L
.51799 .25 L
.518 .25 L
.518 .25 L
.51801 .25 L
.51801 .25 L
.51802 .25 L
.51803 .25 L
.51803 .25 L
.51804 .25 L
.51804 .25 L
.51805 .25 L
.51806 .25 L
.51806 .25 L
.51807 .25 L
.51807 .25 L
.51808 .25 L
.51808 .25 L
.51809 .25 L
.51809 .25 L
.5181 .25 L
.5181 .25 L
.51811 .25 L
.51811 .25 L
.51812 .25 L
.51813 .25 L
.51813 .25 L
.51814 .25 L
Mistroke
.51814 .25 L
.51815 .25 L
.51815 .25 L
.51816 .25 L
.51816 .25 L
.51817 .25 L
.51817 .25 L
.51818 .25 L
.51819 .25 L
.51819 .25 L
.5182 .25 L
.5182 .25 L
.51821 .25 L
.51822 .25 L
.51822 .25 L
.51823 .25 L
.51823 .25 L
.51824 .25 L
.51825 .25 L
.51825 .25 L
.51826 .25 L
.51827 .25 L
.51827 .25 L
.51828 .25 L
.51828 .25 L
.51829 .25 L
.5183 .25 L
.5183 .25 L
.51831 .25 L
.51831 .25 L
.51831 .25 L
.51832 .25 L
.51833 .25 L
.51833 .25 L
.51834 .25 L
.51835 .25 L
.51835 .25 L
.51836 .25 L
.51836 .25 L
.51837 .25 L
.51838 .25 L
.51838 .25 L
.51839 .25 L
.5184 .25 L
.5184 .25 L
.51841 .25 L
.51841 .25 L
.51842 .25 L
.51843 .25 L
.51843 .25 L
Mistroke
.51844 .25 L
.51844 .25 L
.51844 .25 L
.51845 .25 L
.51845 .25 L
.51846 .25 L
.51846 .25 L
.51846 .25 L
.51847 .25 L
.51847 .25 L
.51848 .25 L
.51848 .25 L
.51848 .25 L
.51849 .25 L
.51849 .25 L
.5185 .25 L
.51851 .25 L
.51851 .25 L
.51852 .25 L
.51853 .25 L
.51853 .25 L
.51854 .25 L
.51855 .25 L
.51855 .25 L
.51856 .25 L
.51856 .25 L
.51857 .25 L
.51858 .25 L
.51858 .25 L
.51859 .25 L
.51859 .25 L
.5186 .25 L
.51861 .25 L
.51861 .25 L
.51862 .25 L
.51862 .25 L
.51863 .25 L
.51864 .25 L
.51864 .25 L
.51865 .25 L
.51865 .25 L
.51866 .25 L
.51866 .25 L
.51867 .25 L
.51868 .25 L
.51868 .25 L
.51869 .25 L
.51869 .25 L
.5187 .25 L
.5187 .25 L
Mistroke
.51871 .25 L
.51872 .25 L
.51872 .25 L
.51873 .25 L
.51874 .25 L
.51874 .25 L
.51875 .25 L
.51875 .25 L
.51876 .25 L
.51877 .25 L
.51877 .25 L
.51878 .25 L
.51879 .25 L
.51879 .25 L
.51879 .25 L
.5188 .25 L
.51881 .25 L
.51881 .25 L
.51882 .25 L
.51883 .25 L
.51883 .25 L
.51884 .25 L
.51884 .25 L
.51885 .25 L
.51885 .25 L
.51886 .25 L
.51887 .25 L
.51887 .25 L
.51888 .25 L
.51889 .25 L
.51889 .25 L
.51889 .25 L
.5189 .25 L
.51891 .25 L
.51891 .25 L
.51892 .25 L
.51893 .25 L
.51893 .25 L
.51894 .25 L
.51894 .25 L
.51895 .25 L
.51896 .25 L
.51896 .25 L
.51897 .25 L
.51898 .25 L
.51898 .25 L
.51899 .25 L
.51899 .25 L
.519 .25 L
.519 .25 L
Mistroke
.51901 .25 L
.51902 .25 L
.51902 .25 L
.51903 .25 L
.51903 .25 L
.51904 .25 L
.51905 .25 L
.51905 .25 L
.51906 .25 L
.51906 .25 L
.51907 .25 L
.51908 .25 L
.51908 .25 L
.51909 .25 L
.51909 .25 L
.5191 .25 L
.5191 .25 L
.51911 .25 L
.51911 .25 L
.51912 .25 L
.51912 .25 L
.51913 .25 L
.51913 .25 L
.51914 .25 L
.51915 .25 L
.51915 .25 L
.51916 .25 L
.51917 .25 L
.51917 .25 L
.51917 .25 L
.51918 .25 L
.51918 .25 L
.51919 .25 L
.51919 .25 L
.5192 .25 L
.51921 .25 L
.51921 .25 L
.51922 .25 L
.51922 .25 L
.51923 .25 L
.51924 .25 L
.51924 .25 L
.51925 .25 L
.51925 .25 L
.51926 .25 L
.51927 .25 L
.51927 .25 L
.51928 .25 L
.51928 .25 L
.51929 .25 L
Mistroke
.5193 .25 L
.5193 .25 L
.51931 .25 L
.51932 .25 L
.51932 .25 L
.51933 .25 L
.51933 .25 L
.51934 .25 L
.51934 .25 L
.51935 .25 L
.51935 .25 L
.51936 .25 L
.51937 .25 L
.51937 .25 L
.51938 .25 L
.51938 .25 L
.51939 .25 L
.5194 .25 L
.5194 .25 L
.51941 .25 L
.51942 .25 L
.51942 .25 L
.51943 .25 L
.51944 .25 L
.51944 .25 L
.51945 .25 L
.51945 .25 L
.51946 .25 L
.51946 .25 L
.51947 .25 L
.51947 .25 L
.51947 .25 L
.51948 .25 L
.51948 .25 L
.51949 .25 L
.51949 .25 L
.5195 .25 L
.5195 .25 L
.5195 .25 L
.51951 .25 L
.51951 .25 L
.51951 .25 L
.51952 .25 L
.51953 .25 L
.51953 .25 L
.51954 .25 L
.51955 .25 L
.51955 .25 L
.51956 .25 L
.51957 .25 L
Mistroke
.51957 .25 L
.51958 .25 L
.51958 .25 L
.51959 .25 L
.5196 .25 L
.5196 .25 L
.51961 .25 L
.51961 .25 L
.51962 .25 L
.51963 .25 L
.51963 .25 L
.51964 .25 L
.51964 .25 L
.51965 .25 L
.51966 .25 L
.51966 .25 L
.51967 .25 L
.51967 .25 L
.51968 .25 L
.51968 .25 L
.51969 .25 L
.5197 .25 L
.5197 .25 L
.51971 .25 L
.51971 .25 L
.51972 .25 L
.51972 .25 L
.51973 .25 L
.51974 .25 L
.51974 .25 L
.51975 .25 L
.51976 .25 L
.51976 .25 L
.51977 .25 L
.51977 .25 L
.51978 .25 L
.51979 .25 L
.51979 .25 L
.5198 .25 L
.51981 .25 L
.51981 .25 L
.51982 .25 L
.51982 .25 L
.51983 .25 L
.51983 .25 L
.51984 .25 L
.51985 .25 L
.51985 .25 L
.51986 .25 L
.51986 .25 L
Mistroke
.51987 .25 L
.51988 .25 L
.51988 .25 L
.51989 .25 L
.51989 .25 L
.5199 .25 L
.51991 .25 L
.51991 .25 L
.51992 .25 L
.51992 .25 L
.51993 .25 L
.51993 .25 L
.51994 .25 L
.51994 .25 L
.51995 .25 L
.51995 .25 L
.51996 .25 L
.51996 .25 L
.51997 .25 L
.51998 .25 L
.51998 .25 L
.51999 .25 L
.51999 .25 L
.52 .25 L
.52 .25 L
.52001 .25 L
.52001 .25 L
.52002 .25 L
.52002 .25 L
.52003 .25 L
.52004 .25 L
.52004 .25 L
.52005 .25 L
.52005 .25 L
.52006 .25 L
.52007 .25 L
.52007 .25 L
.52008 .25 L
.52008 .25 L
.52009 .25 L
.5201 .25 L
.5201 .25 L
.52011 .25 L
.52012 .25 L
.52012 .25 L
.52013 .25 L
.52013 .25 L
.52014 .25 L
.52015 .25 L
.52015 .25 L
Mistroke
.52016 .25 L
.52016 .25 L
.52016 .25 L
.52017 .25 L
.52018 .25 L
.52018 .25 L
.52019 .25 L
.5202 .25 L
.5202 .25 L
.52021 .25 L
.52021 .25 L
.52022 .25 L
.52023 .25 L
.52023 .25 L
.52024 .25 L
.52025 .25 L
.52025 .25 L
.52026 .25 L
.52027 .25 L
.52027 .25 L
.52028 .25 L
.52028 .25 L
.52029 .25 L
.52029 .25 L
.52029 .25 L
.5203 .25 L
.5203 .25 L
.52031 .25 L
.52031 .25 L
.52032 .25 L
.52032 .25 L
.52032 .25 L
.52033 .25 L
.52033 .25 L
.52033 .25 L
.52034 .25 L
.52034 .25 L
.52035 .25 L
.52036 .25 L
.52036 .25 L
.52037 .25 L
.52038 .25 L
.52038 .25 L
.52039 .25 L
.5204 .25 L
.5204 .25 L
.52041 .25 L
.52042 .25 L
.52042 .25 L
.52043 .25 L
Mistroke
.52043 .25 L
.52044 .25 L
.52044 .25 L
.52045 .25 L
.52046 .25 L
.52046 .25 L
.52047 .25 L
.52047 .25 L
.52048 .25 L
.52049 .25 L
.52049 .25 L
.5205 .25 L
.5205 .25 L
.52051 .25 L
.52052 .25 L
.52052 .25 L
.52053 .25 L
.52053 .25 L
.52054 .25 L
.52054 .25 L
.52055 .25 L
.52055 .25 L
.52056 .25 L
.52057 .25 L
.52057 .25 L
.52058 .25 L
.52059 .25 L
.52059 .25 L
.5206 .25 L
.5206 .25 L
.52061 .25 L
.52062 .25 L
.52062 .25 L
.52063 .25 L
.52064 .25 L
.52064 .25 L
.52064 .25 L
.52065 .25 L
.52066 .25 L
.52066 .25 L
.52067 .25 L
.52068 .25 L
.52068 .25 L
.52069 .25 L
.52069 .25 L
.5207 .25 L
.52071 .25 L
.52071 .25 L
.52072 .25 L
.52072 .25 L
Mistroke
.52073 .25 L
.52074 .25 L
.52074 .25 L
.52074 .25 L
.52075 .25 L
.52076 .25 L
.52076 .25 L
.52077 .25 L
.52077 .25 L
.52078 .25 L
.52078 .25 L
.52079 .25 L
.52079 .25 L
.5208 .25 L
.52081 .25 L
.52081 .25 L
.52082 .25 L
.52082 .25 L
.52083 .25 L
.52083 .25 L
.52083 .25 L
.52084 .25 L
.52085 .25 L
.52085 .25 L
.52086 .25 L
.52087 .25 L
.52087 .25 L
.52088 .25 L
.52088 .25 L
.52089 .25 L
.5209 .25 L
.5209 .25 L
.52091 .25 L
.52091 .25 L
.52092 .25 L
.52093 .25 L
.52093 .25 L
.52094 .25 L
.52095 .25 L
.52095 .25 L
.52096 .25 L
.52097 .25 L
.52097 .25 L
.52098 .25 L
.52098 .25 L
.52098 .25 L
.52099 .25 L
.52099 .25 L
.521 .25 L
.52101 .25 L
Mistroke
.52101 .25 L
.52102 .25 L
.52103 .25 L
.52103 .25 L
.52104 .25 L
.52104 .25 L
.52105 .25 L
.52106 .25 L
.52106 .25 L
.52107 .25 L
.52108 .25 L
.52108 .25 L
.52109 .25 L
.5211 .25 L
.5211 .25 L
.5211 .25 L
.52111 .25 L
.52111 .25 L
.52112 .25 L
.52112 .25 L
.52112 .25 L
.52113 .25 L
.52114 .25 L
.52114 .25 L
.52114 .25 L
.52115 .25 L
.52115 .25 L
.52115 .25 L
.52116 .25 L
.52116 .25 L
.52117 .25 L
.52117 .25 L
.52118 .25 L
.52119 .25 L
.5212 .25 L
.5212 .25 L
.52121 .25 L
.52121 .25 L
.52122 .25 L
.52123 .25 L
.52123 .25 L
.52124 .25 L
.52124 .25 L
.52125 .25 L
.52126 .25 L
.52126 .25 L
.52127 .25 L
.52127 .25 L
.52128 .25 L
.52128 .25 L
Mistroke
.52129 .25 L
.5213 .25 L
.5213 .25 L
.52131 .25 L
.52131 .25 L
.52132 .25 L
.52133 .25 L
.52133 .25 L
.52134 .25 L
.52134 .25 L
.52135 .25 L
.52136 .25 L
.52136 .25 L
.52136 .25 L
.52137 .25 L
.52138 .25 L
.52138 .25 L
.52139 .25 L
.5214 .25 L
.5214 .25 L
.52141 .25 L
.52142 .25 L
.52142 .25 L
.52143 .25 L
.52143 .25 L
.52144 .25 L
.52145 .25 L
.52145 .25 L
.52146 .25 L
.52146 .25 L
.52147 .25 L
.52148 .25 L
.52148 .25 L
.52149 .25 L
.52149 .25 L
.5215 .25 L
.52151 .25 L
.52151 .25 L
.52152 .25 L
.52152 .25 L
.52153 .25 L
.52153 .25 L
.52154 .25 L
.52155 .25 L
.52155 .25 L
.52156 .25 L
.52156 .25 L
.52157 .25 L
.52157 .25 L
.52158 .25 L
Mistroke
.52159 .25 L
.52159 .25 L
.52159 .25 L
.5216 .25 L
.52161 .25 L
.52161 .25 L
.52162 .25 L
.52162 .25 L
.52163 .25 L
.52164 .25 L
.52164 .25 L
.52164 .25 L
.52165 .25 L
.52165 .25 L
.52166 .25 L
.52166 .25 L
.52167 .25 L
.52168 .25 L
.52168 .25 L
.52169 .25 L
.5217 .25 L
.5217 .25 L
.52171 .25 L
.52171 .25 L
.52172 .25 L
.52173 .25 L
.52173 .25 L
.52174 .25 L
.52174 .25 L
.52175 .25 L
.52176 .25 L
.52176 .25 L
.52177 .25 L
.52178 .25 L
.52178 .25 L
.52179 .25 L
.5218 .25 L
.5218 .25 L
.5218 .25 L
.52181 .25 L
.52181 .25 L
.52182 .25 L
.52182 .25 L
.52183 .25 L
.52184 .25 L
.52184 .25 L
.52185 .25 L
.52186 .25 L
.52186 .25 L
.52187 .25 L
Mistroke
.52187 .25 L
.52188 .25 L
.52189 .25 L
.52189 .25 L
.5219 .25 L
.52191 .25 L
.52191 .25 L
.52192 .25 L
.52192 .25 L
.52193 .25 L
.52193 .25 L
.52194 .25 L
.52194 .25 L
.52194 .25 L
.52195 .25 L
.52196 .25 L
.52196 .25 L
.52196 .25 L
.52197 .25 L
.52197 .25 L
.52197 .25 L
.52198 .25 L
.52198 .25 L
.52199 .25 L
.52199 .25 L
.522 .25 L
.522 .25 L
.52201 .25 L
.52202 .25 L
.52202 .25 L
.52203 .25 L
.52204 .25 L
.52204 .25 L
.52205 .25 L
.52206 .25 L
.52206 .25 L
.52207 .25 L
.52207 .25 L
.52208 .25 L
.52209 .25 L
.52209 .25 L
.5221 .25 L
.5221 .25 L
.52211 .25 L
.52211 .25 L
.52212 .25 L
.52213 .25 L
.52213 .25 L
.52214 .25 L
.52214 .25 L
Mistroke
.52215 .25 L
.52216 .25 L
.52216 .25 L
.52217 .25 L
.52217 .25 L
.52218 .25 L
.52218 .25 L
.52219 .25 L
.52219 .25 L
.5222 .25 L
.52221 .25 L
.52221 .25 L
.52222 .25 L
.52223 .25 L
.52223 .25 L
.52224 .25 L
.52224 .25 L
.52225 .25 L
.52226 .25 L
.52226 .25 L
.52227 .25 L
.52228 .25 L
.52228 .25 L
.52229 .25 L
.52229 .25 L
.5223 .25 L
.52231 .25 L
.52231 .25 L
.52232 .25 L
.52232 .25 L
.52233 .25 L
.52234 .25 L
.52234 .25 L
.52235 .25 L
.52235 .25 L
.52236 .25 L
.52236 .25 L
.52237 .25 L
.52238 .25 L
.52238 .25 L
.52239 .25 L
.52239 .25 L
.5224 .25 L
.5224 .25 L
.52241 .25 L
.52242 .25 L
.52242 .25 L
.52243 .25 L
.52243 .25 L
.52244 .25 L
Mistroke
.52245 .25 L
.52245 .25 L
.52246 .25 L
.52247 .25 L
.52247 .25 L
.52248 .25 L
.52249 .25 L
.52249 .25 L
.52249 .25 L
.5225 .25 L
.52251 .25 L
.52251 .25 L
.52252 .25 L
.52253 .25 L
.52253 .25 L
.52254 .25 L
.52254 .25 L
.52255 .25 L
.52255 .25 L
.52256 .25 L
.52257 .25 L
.52257 .25 L
.52258 .25 L
.52259 .25 L
.52259 .25 L
.52259 .25 L
.5226 .25 L
.52261 .25 L
.52261 .25 L
.52262 .25 L
.52262 .25 L
.52263 .25 L
.52263 .25 L
.52264 .25 L
.52264 .25 L
.52265 .25 L
.52266 .25 L
.52266 .25 L
.52267 .25 L
.52267 .25 L
.52268 .25 L
.52268 .25 L
.52268 .25 L
.52269 .25 L
.5227 .25 L
.5227 .25 L
.52271 .25 L
.52272 .25 L
.52272 .25 L
.52273 .25 L
Mistroke
.52273 .25 L
.52274 .25 L
.52275 .25 L
.52275 .25 L
.52276 .25 L
.52276 .25 L
.52277 .25 L
.52278 .25 L
.52278 .25 L
.52279 .25 L
.5228 .25 L
.5228 .25 L
.52281 .25 L
.52282 .25 L
.52282 .25 L
.52283 .25 L
.52283 .25 L
.52283 .25 L
.52284 .25 L
.52284 .25 L
.52285 .25 L
.52286 .25 L
.52286 .25 L
.52287 .25 L
.52288 .25 L
.52288 .25 L
.52289 .25 L
.52289 .25 L
.5229 .25 L
.52291 .25 L
.52291 .25 L
.52292 .25 L
.52293 .25 L
.52293 .25 L
.52294 .25 L
.52295 .25 L
.52295 .25 L
.52295 .25 L
.52296 .25 L
.52296 .25 L
.52297 .25 L
.52297 .25 L
.52297 .25 L
.52298 .25 L
.52299 .25 L
.52299 .25 L
.52299 .25 L
.523 .25 L
.523 .25 L
.523 .25 L
Mistroke
.52301 .25 L
.52301 .25 L
.52302 .25 L
.52302 .25 L
.52303 .25 L
.52304 .25 L
.52305 .25 L
.52305 .25 L
.52306 .25 L
.52306 .25 L
.52307 .25 L
.52308 .25 L
.52308 .25 L
.52309 .25 L
.52309 .25 L
.5231 .25 L
.52311 .25 L
.52311 .25 L
.52312 .25 L
.52312 .25 L
.52313 .25 L
.52313 .25 L
.52314 .25 L
.52315 .25 L
.52315 .25 L
.52316 .25 L
.52316 .25 L
.52317 .25 L
.52318 .25 L
.52318 .25 L
.52319 .25 L
.52319 .25 L
.5232 .25 L
.52321 .25 L
.52321 .25 L
.52321 .25 L
.52322 .25 L
.52323 .25 L
.52323 .25 L
.52324 .25 L
.52325 .25 L
.52325 .25 L
.52326 .25 L
.52327 .25 L
.52327 .25 L
.52328 .25 L
.52328 .25 L
.52329 .25 L
.5233 .25 L
.5233 .25 L
Mistroke
.52331 .25 L
.52331 .25 L
.52332 .25 L
.52333 .25 L
.52333 .25 L
.52334 .25 L
.52334 .25 L
.52335 .25 L
.52336 .25 L
.52336 .25 L
.52337 .25 L
.52337 .25 L
.52338 .25 L
.52338 .25 L
.52339 .25 L
.5234 .25 L
.5234 .25 L
.52341 .25 L
.52341 .25 L
.52342 .25 L
.52342 .25 L
.52343 .25 L
.52344 .25 L
.52344 .25 L
.52344 .25 L
.52345 .25 L
.52346 .25 L
.52346 .25 L
.52347 .25 L
.52347 .25 L
.52348 .25 L
.52349 .25 L
.52349 .25 L
.52349 .25 L
.5235 .25 L
.52351 .25 L
.52351 .25 L
.52352 .25 L
.52352 .25 L
.52353 .25 L
.52353 .25 L
.52354 .25 L
.52355 .25 L
.52355 .25 L
.52356 .25 L
.52356 .25 L
.52357 .25 L
.52358 .25 L
.52358 .25 L
.52359 .25 L
Mistroke
.5236 .25 L
.5236 .25 L
.52361 .25 L
.52361 .25 L
.52362 .25 L
.52363 .25 L
.52363 .25 L
.52364 .25 L
.52365 .25 L
.52365 .25 L
.52365 .25 L
.52366 .25 L
.52366 .25 L
.52367 .25 L
.52367 .25 L
.52368 .25 L
.52369 .25 L
.52369 .25 L
.5237 .25 L
.52371 .25 L
.52371 .25 L
.52372 .25 L
.52372 .25 L
.52373 .25 L
.52374 .25 L
.52374 .25 L
.52375 .25 L
.52376 .25 L
.52376 .25 L
.52377 .25 L
.52377 .25 L
.52378 .25 L
.52378 .25 L
.52379 .25 L
.52379 .25 L
.5238 .25 L
.5238 .25 L
.52381 .25 L
.52381 .25 L
.52381 .25 L
.52382 .25 L
.52382 .25 L
.52382 .25 L
.52383 .25 L
.52383 .25 L
.52384 .25 L
.52384 .25 L
.52385 .25 L
.52386 .25 L
.52386 .25 L
Mistroke
.52387 .25 L
.52388 .25 L
.52388 .25 L
.52389 .25 L
.52389 .25 L
.5239 .25 L
.52391 .25 L
.52391 .25 L
.52392 .25 L
.52393 .25 L
.52393 .25 L
.52394 .25 L
.52394 .25 L
.52395 .25 L
.52395 .25 L
.52396 .25 L
.52397 .25 L
.52397 .25 L
.52398 .25 L
.52398 .25 L
.52399 .25 L
.52399 .25 L
.524 .25 L
.52401 .25 L
.52401 .25 L
.52402 .25 L
.52402 .25 L
.52403 .25 L
.52403 .25 L
.52404 .25 L
.52404 .25 L
.52405 .25 L
.52406 .25 L
.52406 .25 L
.52407 .25 L
.52408 .25 L
.52408 .25 L
.52409 .25 L
.5241 .25 L
.5241 .25 L
.52411 .25 L
.52412 .25 L
.52412 .25 L
.52413 .25 L
.52413 .25 L
.52414 .25 L
.52414 .25 L
.52415 .25 L
.52416 .25 L
.52416 .25 L
Mistroke
.52417 .25 L
.52417 .25 L
.52418 .25 L
.52419 .25 L
.52419 .25 L
.5242 .25 L
.5242 .25 L
.52421 .25 L
.52422 .25 L
.52422 .25 L
.52423 .25 L
.52423 .25 L
.52424 .25 L
.52424 .25 L
.52425 .25 L
.52425 .25 L
.52426 .25 L
.52426 .25 L
.52427 .25 L
.52427 .25 L
.52428 .25 L
.52429 .25 L
.52429 .25 L
.5243 .25 L
.5243 .25 L
.52431 .25 L
.52431 .25 L
.52432 .25 L
.52433 .25 L
.52433 .25 L
.52433 .25 L
.52434 .25 L
.52435 .25 L
.52435 .25 L
.52436 .25 L
.52436 .25 L
.52437 .25 L
.52438 .25 L
.52438 .25 L
.52439 .25 L
.52439 .25 L
.5244 .25 L
.52441 .25 L
.52441 .25 L
.52442 .25 L
.52442 .25 L
.52443 .25 L
.52444 .25 L
.52444 .25 L
.52445 .25 L
Mistroke
.52446 .25 L
.52446 .25 L
.52447 .25 L
.52447 .25 L
.52448 .25 L
.52448 .25 L
.52448 .25 L
.52449 .25 L
.5245 .25 L
.5245 .25 L
.52451 .25 L
.52452 .25 L
.52452 .25 L
.52453 .25 L
.52453 .25 L
.52454 .25 L
.52455 .25 L
.52455 .25 L
.52456 .25 L
.52457 .25 L
.52457 .25 L
.52458 .25 L
.52459 .25 L
.52459 .25 L
.5246 .25 L
.5246 .25 L
.52461 .25 L
.52461 .25 L
.52462 .25 L
.52462 .25 L
.52462 .25 L
.52463 .25 L
.52463 .25 L
.52464 .25 L
.52464 .25 L
.52464 .25 L
.52465 .25 L
.52465 .25 L
.52466 .25 L
.52466 .25 L
.52467 .25 L
.52467 .25 L
.52468 .25 L
.52469 .25 L
.52469 .25 L
.5247 .25 L
.52471 .25 L
.52471 .25 L
.52472 .25 L
.52472 .25 L
Mistroke
.52473 .25 L
.52474 .25 L
.52474 .25 L
.52475 .25 L
.52476 .25 L
.52476 .25 L
.52476 .25 L
.52477 .25 L
.52478 .25 L
.52478 .25 L
.52479 .25 L
.5248 .25 L
.5248 .25 L
.52481 .25 L
.52481 .25 L
.52482 .25 L
.52482 .25 L
.52483 .25 L
.52484 .25 L
.52484 .25 L
.52485 .25 L
.52485 .25 L
.52486 .25 L
.52486 .25 L
.52487 .25 L
.52487 .25 L
.52488 .25 L
.52489 .25 L
.5249 .25 L
.5249 .25 L
.52491 .25 L
.52491 .25 L
.52492 .25 L
.52493 .25 L
.52493 .25 L
.52494 .25 L
.52494 .25 L
.52495 .25 L
.52496 .25 L
.52496 .25 L
.52497 .25 L
.52497 .25 L
.52498 .25 L
.52499 .25 L
.52499 .25 L
.525 .25 L
.525 .25 L
.52501 .25 L
.52501 .25 L
.52502 .25 L
Mistroke
.52503 .25 L
.52503 .25 L
.52504 .25 L
.52505 .25 L
.52505 .25 L
.52506 .25 L
.52506 .25 L
.52506 .25 L
.52507 .25 L
.52508 .25 L
.52508 .25 L
.52509 .25 L
.52509 .25 L
.5251 .25 L
.5251 .25 L
.52511 .25 L
.52512 .25 L
.52512 .25 L
.52513 .25 L
.52513 .25 L
.52514 .25 L
.52514 .25 L
.52515 .25 L
.52515 .25 L
.52516 .25 L
.52516 .25 L
.52517 .25 L
.52518 .25 L
.52518 .25 L
.52519 .25 L
.52519 .25 L
.5252 .25 L
.5252 .25 L
.52521 .25 L
.52522 .25 L
.52522 .25 L
.52523 .25 L
.52524 .25 L
.52524 .25 L
.52525 .25 L
.52525 .25 L
.52526 .25 L
.52527 .25 L
.52527 .25 L
.52528 .25 L
.52529 .25 L
.52529 .25 L
.5253 .25 L
.5253 .25 L
.5253 .25 L
Mistroke
.52531 .25 L
.52531 .25 L
.52532 .25 L
.52533 .25 L
.52533 .25 L
.52534 .25 L
.52535 .25 L
.52535 .25 L
.52536 .25 L
.52536 .25 L
.52537 .25 L
.52538 .25 L
.52538 .25 L
.52539 .25 L
.5254 .25 L
.5254 .25 L
.52541 .25 L
.52542 .25 L
.52542 .25 L
.52542 .25 L
.52543 .25 L
.52544 .25 L
.52544 .25 L
.52544 .25 L
.52545 .25 L
.52545 .25 L
.52546 .25 L
.52546 .25 L
.52546 .25 L
.52547 .25 L
.52547 .25 L
.52548 .25 L
.52548 .25 L
.52548 .25 L
.52549 .25 L
.5255 .25 L
.5255 .25 L
.52551 .25 L
.52552 .25 L
.52552 .25 L
.52553 .25 L
.52553 .25 L
.52554 .25 L
.52555 .25 L
.52555 .25 L
.52556 .25 L
.52557 .25 L
.52557 .25 L
.52558 .25 L
.52558 .25 L
Mistroke
.52559 .25 L
.52559 .25 L
.5256 .25 L
.52561 .25 L
.52561 .25 L
.52562 .25 L
.52562 .25 L
.52563 .25 L
.52564 .25 L
.52564 .25 L
.52565 .25 L
.52565 .25 L
.52566 .25 L
.52567 .25 L
.52567 .25 L
.52568 .25 L
.52568 .25 L
.52569 .25 L
.52569 .25 L
.5257 .25 L
.5257 .25 L
.52571 .25 L
.52572 .25 L
.52572 .25 L
.52573 .25 L
.52574 .25 L
.52574 .25 L
.52575 .25 L
.52576 .25 L
.52576 .25 L
.52577 .25 L
.52577 .25 L
.52578 .25 L
.52579 .25 L
.52579 .25 L
.5258 .25 L
.5258 .25 L
.52581 .25 L
.52581 .25 L
.52582 .25 L
.52583 .25 L
.52583 .25 L
.52584 .25 L
.52584 .25 L
.52585 .25 L
.52586 .25 L
.52586 .25 L
.52587 .25 L
.52587 .25 L
.52588 .25 L
Mistroke
.52588 .25 L
.52589 .25 L
.52589 .25 L
.5259 .25 L
.52591 .25 L
.52591 .25 L
.52592 .25 L
.52593 .25 L
.52593 .25 L
.52594 .25 L
.52595 .25 L
.52595 .25 L
.52596 .25 L
.52596 .25 L
.52597 .25 L
.52598 .25 L
.52598 .25 L
.52599 .25 L
.52599 .25 L
.526 .25 L
.52601 .25 L
.52601 .25 L
.52602 .25 L
.52602 .25 L
.52603 .25 L
.52604 .25 L
.52604 .25 L
.52605 .25 L
.52605 .25 L
.52606 .25 L
.52607 .25 L
.52607 .25 L
.52608 .25 L
.52608 .25 L
.52609 .25 L
.52609 .25 L
.5261 .25 L
.5261 .25 L
.52611 .25 L
.52611 .25 L
.52612 .25 L
.52612 .25 L
.52613 .25 L
.52614 .25 L
.52614 .25 L
.52615 .25 L
.52615 .25 L
.52616 .25 L
.52616 .25 L
.52617 .25 L
Mistroke
.52617 .25 L
.52618 .25 L
.52618 .25 L
.52619 .25 L
.5262 .25 L
.5262 .25 L
.52621 .25 L
.52621 .25 L
.52622 .25 L
.52623 .25 L
.52623 .25 L
.52624 .25 L
.52624 .25 L
.52625 .25 L
.52626 .25 L
.52626 .25 L
.52627 .25 L
.52627 .25 L
.52628 .25 L
.52629 .25 L
.52629 .25 L
.5263 .25 L
.52631 .25 L
.52631 .25 L
.52632 .25 L
.52632 .25 L
.52633 .25 L
.52633 .25 L
.52633 .25 L
.52634 .25 L
.52635 .25 L
.52635 .25 L
.52636 .25 L
.52637 .25 L
.52637 .25 L
.52638 .25 L
.52638 .25 L
.52639 .25 L
.5264 .25 L
.5264 .25 L
.52641 .25 L
.52642 .25 L
.52642 .25 L
.52643 .25 L
.52644 .25 L
.52644 .25 L
.52645 .25 L
.52645 .25 L
.52646 .25 L
.52646 .25 L
Mistroke
.52647 .25 L
.52647 .25 L
.52647 .25 L
.52648 .25 L
.52648 .25 L
.52649 .25 L
.52649 .25 L
.52649 .25 L
.5265 .25 L
.5265 .25 L
.52651 .25 L
.52651 .25 L
.52652 .25 L
.52652 .25 L
.52653 .25 L
.52654 .25 L
.52654 .25 L
.52655 .25 L
.52656 .25 L
.52656 .25 L
.52657 .25 L
.52657 .25 L
.52658 .25 L
.52659 .25 L
.52659 .25 L
.5266 .25 L
.52661 .25 L
.52661 .25 L
.52661 .25 L
.52662 .25 L
.52663 .25 L
.52663 .25 L
.52664 .25 L
.52665 .25 L
.52665 .25 L
.52666 .25 L
.52666 .25 L
.52667 .25 L
.52667 .25 L
.52668 .25 L
.52669 .25 L
.52669 .25 L
.5267 .25 L
.52671 .25 L
.52671 .25 L
.52671 .25 L
.52672 .25 L
.52673 .25 L
.52673 .25 L
.52674 .25 L
Mistroke
.52675 .25 L
.52675 .25 L
.52676 .25 L
.52676 .25 L
.52677 .25 L
.52678 .25 L
.52678 .25 L
.52679 .25 L
.5268 .25 L
.5268 .25 L
.52681 .25 L
.52681 .25 L
.52682 .25 L
.52682 .25 L
.52683 .25 L
.52684 .25 L
.52684 .25 L
.52685 .25 L
.52685 .25 L
.52686 .25 L
.52687 .25 L
.52687 .25 L
.52688 .25 L
.52688 .25 L
.52689 .25 L
.5269 .25 L
.5269 .25 L
.52691 .25 L
.52691 .25 L
.52691 .25 L
.52692 .25 L
.52693 .25 L
.52693 .25 L
.52694 .25 L
.52694 .25 L
.52695 .25 L
.52695 .25 L
.52696 .25 L
.52697 .25 L
.52697 .25 L
.52698 .25 L
.52698 .25 L
.52699 .25 L
.52699 .25 L
.527 .25 L
.527 .25 L
.52701 .25 L
.52701 .25 L
.52702 .25 L
.52703 .25 L
Mistroke
.52703 .25 L
.52704 .25 L
.52704 .25 L
.52705 .25 L
.52706 .25 L
.52706 .25 L
.52707 .25 L
.52707 .25 L
.52708 .25 L
.52709 .25 L
.52709 .25 L
.5271 .25 L
.5271 .25 L
.52711 .25 L
.52712 .25 L
.52712 .25 L
.52713 .25 L
.52714 .25 L
.52714 .25 L
.52715 .25 L
.52715 .25 L
.52716 .25 L
.52716 .25 L
.52717 .25 L
.52717 .25 L
.52718 .25 L
.52719 .25 L
.52719 .25 L
.5272 .25 L
.5272 .25 L
.52721 .25 L
.52722 .25 L
.52722 .25 L
.52723 .25 L
.52724 .25 L
.52724 .25 L
.52725 .25 L
.52725 .25 L
.52726 .25 L
.52727 .25 L
.52727 .25 L
.52728 .25 L
.52728 .25 L
.52729 .25 L
.52729 .25 L
.52729 .25 L
.5273 .25 L
.5273 .25 L
.52731 .25 L
.52731 .25 L
Mistroke
.52731 .25 L
.52732 .25 L
.52732 .25 L
.52733 .25 L
.52733 .25 L
.52733 .25 L
.52734 .25 L
.52735 .25 L
.52735 .25 L
.52736 .25 L
.52737 .25 L
.52737 .25 L
.52738 .25 L
.52738 .25 L
.52739 .25 L
.5274 .25 L
.5274 .25 L
.52741 .25 L
.52742 .25 L
.52742 .25 L
.52743 .25 L
.52743 .25 L
.52744 .25 L
.52744 .25 L
.52745 .25 L
.52746 .25 L
.52746 .25 L
.52747 .25 L
.52748 .25 L
.52748 .25 L
.52749 .25 L
.52749 .25 L
.5275 .25 L
.5275 .25 L
.52751 .25 L
.52752 .25 L
.52752 .25 L
.52753 .25 L
.52753 .25 L
.52754 .25 L
.52754 .25 L
.52755 .25 L
.52756 .25 L
.52756 .25 L
.52757 .25 L
.52758 .25 L
.52758 .25 L
.52759 .25 L
.52759 .25 L
.5276 .25 L
Mistroke
.52761 .25 L
.52761 .25 L
.52762 .25 L
.52763 .25 L
.52763 .25 L
.52764 .25 L
.52764 .25 L
.52765 .25 L
.52765 .25 L
.52766 .25 L
.52767 .25 L
.52767 .25 L
.52768 .25 L
.52768 .25 L
.52769 .25 L
.5277 .25 L
.5277 .25 L
.52771 .25 L
.52771 .25 L
.52772 .25 L
.52773 .25 L
.52773 .25 L
.52774 .25 L
.52774 .25 L
.52775 .25 L
.52775 .25 L
.52776 .25 L
.52776 .25 L
.52777 .25 L
.52777 .25 L
.52778 .25 L
.52778 .25 L
.52779 .25 L
.5278 .25 L
.5278 .25 L
.52781 .25 L
.52781 .25 L
.52782 .25 L
.52782 .25 L
.52783 .25 L
.52783 .25 L
.52784 .25 L
.52784 .25 L
.52785 .25 L
.52786 .25 L
.52786 .25 L
.52787 .25 L
.52787 .25 L
.52788 .25 L
.52789 .25 L
Mistroke
.52789 .25 L
.5279 .25 L
.5279 .25 L
.52791 .25 L
.52792 .25 L
.52792 .25 L
.52793 .25 L
.52794 .25 L
.52794 .25 L
.52795 .25 L
.52795 .25 L
.52796 .25 L
.52797 .25 L
.52797 .25 L
.52798 .25 L
.52798 .25 L
.52798 .25 L
.52799 .25 L
.528 .25 L
.528 .25 L
.52801 .25 L
.52802 .25 L
.52802 .25 L
.52803 .25 L
.52803 .25 L
.52804 .25 L
.52805 .25 L
.52805 .25 L
.52806 .25 L
.52807 .25 L
.52807 .25 L
.52808 .25 L
.52808 .25 L
.52809 .25 L
.5281 .25 L
.5281 .25 L
.52811 .25 L
.52811 .25 L
.52811 .25 L
.52812 .25 L
.52812 .25 L
.52813 .25 L
.52813 .25 L
.52813 .25 L
.52814 .25 L
.52814 .25 L
.52815 .25 L
.52815 .25 L
.52815 .25 L
.52816 .25 L
Mistroke
.52816 .25 L
.52817 .25 L
.52818 .25 L
.52818 .25 L
.52819 .25 L
.5282 .25 L
.5282 .25 L
.52821 .25 L
.52822 .25 L
.52822 .25 L
.52823 .25 L
.52823 .25 L
.52824 .25 L
.52825 .25 L
.52825 .25 L
.52826 .25 L
.52826 .25 L
.52827 .25 L
.52828 .25 L
.52828 .25 L
.52829 .25 L
.52829 .25 L
.5283 .25 L
.52831 .25 L
.52831 .25 L
.52832 .25 L
.52832 .25 L
.52833 .25 L
.52833 .25 L
.52834 .25 L
.52835 .25 L
.52835 .25 L
.52836 .25 L
.52836 .25 L
.52837 .25 L
.52837 .25 L
.52838 .25 L
.52839 .25 L
.52839 .25 L
.5284 .25 L
.52841 .25 L
.52841 .25 L
.52842 .25 L
.52842 .25 L
.52843 .25 L
.52844 .25 L
.52844 .25 L
.52845 .25 L
.52846 .25 L
.52846 .25 L
Mistroke
.52846 .25 L
.52847 .25 L
.52848 .25 L
.52848 .25 L
.52849 .25 L
.5285 .25 L
.5285 .25 L
.52851 .25 L
.52851 .25 L
.52852 .25 L
.52852 .25 L
.52853 .25 L
.52854 .25 L
.52854 .25 L
.52855 .25 L
.52856 .25 L
.52856 .25 L
.52856 .25 L
.52857 .25 L
.52858 .25 L
.52858 .25 L
.52859 .25 L
.52859 .25 L
.5286 .25 L
.5286 .25 L
.52861 .25 L
.52861 .25 L
.52862 .25 L
.52863 .25 L
.52863 .25 L
.52864 .25 L
.52864 .25 L
.52865 .25 L
.52865 .25 L
.52865 .25 L
.52866 .25 L
.52867 .25 L
.52867 .25 L
.52868 .25 L
.52869 .25 L
.52869 .25 L
.5287 .25 L
.5287 .25 L
.52871 .25 L
.52872 .25 L
.52872 .25 L
.52873 .25 L
.52873 .25 L
.52874 .25 L
.52875 .25 L
Mistroke
.52875 .25 L
.52876 .25 L
.52877 .25 L
.52877 .25 L
.52878 .25 L
.52879 .25 L
.52879 .25 L
.5288 .25 L
.5288 .25 L
.5288 .25 L
.52881 .25 L
.52881 .25 L
.52882 .25 L
.52883 .25 L
.52883 .25 L
.52884 .25 L
.52885 .25 L
.52885 .25 L
.52886 .25 L
.52886 .25 L
.52887 .25 L
.52888 .25 L
.52888 .25 L
.52889 .25 L
.5289 .25 L
.5289 .25 L
.52891 .25 L
.52892 .25 L
.52892 .25 L
.52892 .25 L
.52893 .25 L
.52893 .25 L
.52894 .25 L
.52894 .25 L
.52894 .25 L
.52895 .25 L
.52895 .25 L
.52896 .25 L
.52896 .25 L
.52897 .25 L
.52897 .25 L
.52897 .25 L
.52898 .25 L
.52898 .25 L
.52899 .25 L
.52899 .25 L
.529 .25 L
.52901 .25 L
.52901 .25 L
.52902 .25 L
Mistroke
.52903 .25 L
.52903 .25 L
.52904 .25 L
.52904 .25 L
.52905 .25 L
.52906 .25 L
.52906 .25 L
.52907 .25 L
.52908 .25 L
.52908 .25 L
.52909 .25 L
.52909 .25 L
.5291 .25 L
.5291 .25 L
.52911 .25 L
.52912 .25 L
.52912 .25 L
.52913 .25 L
.52913 .25 L
.52914 .25 L
.52915 .25 L
.52915 .25 L
.52916 .25 L
.52916 .25 L
.52917 .25 L
.52918 .25 L
.52918 .25 L
.52918 .25 L
.52919 .25 L
.5292 .25 L
.5292 .25 L
.52921 .25 L
.52922 .25 L
.52922 .25 L
.52923 .25 L
.52923 .25 L
.52924 .25 L
.52925 .25 L
.52925 .25 L
.52926 .25 L
.52927 .25 L
.52927 .25 L
.52928 .25 L
.52928 .25 L
.52929 .25 L
.52929 .25 L
.5293 .25 L
.52931 .25 L
.52931 .25 L
.52932 .25 L
Mistroke
.52933 .25 L
.52933 .25 L
.52934 .25 L
.52934 .25 L
.52935 .25 L
.52935 .25 L
.52936 .25 L
.52937 .25 L
.52937 .25 L
.52938 .25 L
.52938 .25 L
.52939 .25 L
.52939 .25 L
.5294 .25 L
.52941 .25 L
.52941 .25 L
.52941 .25 L
.52942 .25 L
.52943 .25 L
.52943 .25 L
.52944 .25 L
.52944 .25 L
.52945 .25 L
.52946 .25 L
.52946 .25 L
.52946 .25 L
.52947 .25 L
.52947 .25 L
.52948 .25 L
.52948 .25 L
.52949 .25 L
.5295 .25 L
.5295 .25 L
.52951 .25 L
.52952 .25 L
.52952 .25 L
.52953 .25 L
.52953 .25 L
.52954 .25 L
.52955 .25 L
.52955 .25 L
.52956 .25 L
.52956 .25 L
.52957 .25 L
.52958 .25 L
.52958 .25 L
.52959 .25 L
.5296 .25 L
.5296 .25 L
.52961 .25 L
Mistroke
.52962 .25 L
.52962 .25 L
.52962 .25 L
.52963 .25 L
.52963 .25 L
.52964 .25 L
.52964 .25 L
.52965 .25 L
.52966 .25 L
.52966 .25 L
.52967 .25 L
.52967 .25 L
.52968 .25 L
.52969 .25 L
.52969 .25 L
.5297 .25 L
.52971 .25 L
.52971 .25 L
.52972 .25 L
.52973 .25 L
.52973 .25 L
.52974 .25 L
.52974 .25 L
.52975 .25 L
.52975 .25 L
.52976 .25 L
.52976 .25 L
.52976 .25 L
.52977 .25 L
.52977 .25 L
.52978 .25 L
.52978 .25 L
.52979 .25 L
.52979 .25 L
.52979 .25 L
.5298 .25 L
.5298 .25 L
.5298 .25 L
.52981 .25 L
.52982 .25 L
.52982 .25 L
.52983 .25 L
.52984 .25 L
.52984 .25 L
.52985 .25 L
.52986 .25 L
.52986 .25 L
.52987 .25 L
.52987 .25 L
.52988 .25 L
Mistroke
.52989 .25 L
.52989 .25 L
.5299 .25 L
.5299 .25 L
.52991 .25 L
.52992 .25 L
.52992 .25 L
.52993 .25 L
.52993 .25 L
.52994 .25 L
.52995 .25 L
.52995 .25 L
.52996 .25 L
.52996 .25 L
.52997 .25 L
.52997 .25 L
.52998 .25 L
.52999 .25 L
.52999 .25 L
.53 .25 L
.53 .25 L
.53001 .25 L
.53001 .25 L
.53002 .25 L
.53003 .25 L
.53003 .25 L
.53004 .25 L
.53005 .25 L
.53005 .25 L
.53006 .25 L
.53006 .25 L
.53007 .25 L
.53008 .25 L
.53008 .25 L
.53009 .25 L
.5301 .25 L
.5301 .25 L
.53011 .25 L
.53011 .25 L
.53012 .25 L
.53012 .25 L
.53013 .25 L
.53014 .25 L
.53014 .25 L
.53015 .25 L
.53015 .25 L
.53016 .25 L
.53017 .25 L
.53017 .25 L
.53018 .25 L
Mistroke
.53018 .25 L
.53019 .25 L
.5302 .25 L
.5302 .25 L
.53021 .25 L
.53021 .25 L
.53022 .25 L
.53022 .25 L
.53023 .25 L
.53024 .25 L
.53024 .25 L
.53025 .25 L
.53025 .25 L
.53026 .25 L
.53027 .25 L
.53027 .25 L
.53028 .25 L
.53029 .25 L
.53029 .25 L
.5303 .25 L
.53031 .25 L
.53031 .25 L
.53031 .25 L
.53032 .25 L
.53033 .25 L
.53033 .25 L
.53034 .25 L
.53035 .25 L
.53035 .25 L
.53036 .25 L
.53036 .25 L
.53037 .25 L
.53037 .25 L
.53038 .25 L
.53039 .25 L
.53039 .25 L
.5304 .25 L
.5304 .25 L
.53041 .25 L
.53041 .25 L
.53042 .25 L
.53042 .25 L
.53043 .25 L
.53043 .25 L
.53044 .25 L
.53044 .25 L
.53045 .25 L
.53046 .25 L
.53046 .25 L
.53047 .25 L
Mistroke
.53048 .25 L
.53048 .25 L
.53049 .25 L
.53049 .25 L
.5305 .25 L
.5305 .25 L
.5305 .25 L
.53051 .25 L
.53052 .25 L
.53052 .25 L
.53053 .25 L
.53054 .25 L
.53054 .25 L
.53055 .25 L
.53055 .25 L
.53056 .25 L
.53057 .25 L
.53057 .25 L
.53058 .25 L
.53058 .25 L
.53059 .25 L
.5306 .25 L
.5306 .25 L
.53061 .25 L
.53062 .25 L
.53062 .25 L
.53063 .25 L
.53063 .25 L
.53064 .25 L
.53064 .25 L
.53065 .25 L
.53065 .25 L
.53066 .25 L
.53066 .25 L
.53067 .25 L
.53068 .25 L
.53068 .25 L
.53069 .25 L
.53069 .25 L
.5307 .25 L
.53071 .25 L
.53071 .25 L
.53072 .25 L
.53073 .25 L
.53073 .25 L
.53074 .25 L
.53075 .25 L
.53075 .25 L
.53076 .25 L
.53076 .25 L
Mistroke
.53077 .25 L
.53077 .25 L
.53078 .25 L
.53078 .25 L
.53079 .25 L
.53079 .25 L
.53079 .25 L
.5308 .25 L
.5308 .25 L
.53081 .25 L
.53081 .25 L
.53082 .25 L
.53082 .25 L
.53082 .25 L
.53083 .25 L
.53083 .25 L
.53084 .25 L
.53084 .25 L
.53085 .25 L
.53086 .25 L
.53086 .25 L
.53087 .25 L
.53088 .25 L
.53088 .25 L
.53089 .25 L
.53089 .25 L
.5309 .25 L
.53091 .25 L
.53091 .25 L
.53092 .25 L
.53093 .25 L
.53093 .25 L
.53093 .25 L
.53094 .25 L
.53095 .25 L
.53095 .25 L
.53096 .25 L
.53097 .25 L
.53097 .25 L
.53098 .25 L
.53098 .25 L
.53099 .25 L
.531 .25 L
.531 .25 L
.53101 .25 L
.53101 .25 L
.53102 .25 L
.53103 .25 L
.53103 .25 L
.53103 .25 L
Mistroke
.53104 .25 L
.53105 .25 L
.53105 .25 L
.53106 .25 L
.53107 .25 L
.53107 .25 L
.53108 .25 L
.53108 .25 L
.53109 .25 L
.5311 .25 L
.5311 .25 L
.53111 .25 L
.53112 .25 L
.53112 .25 L
.53113 .25 L
.53113 .25 L
.53114 .25 L
.53114 .25 L
.53115 .25 L
.53116 .25 L
.53116 .25 L
.53117 .25 L
.53118 .25 L
.53118 .25 L
.53119 .25 L
.53119 .25 L
.5312 .25 L
.5312 .25 L
.53121 .25 L
.53122 .25 L
.53122 .25 L
.53123 .25 L
.53123 .25 L
.53124 .25 L
.53124 .25 L
.53125 .25 L
.53126 .25 L
.53126 .25 L
.53126 .25 L
.53127 .25 L
.53128 .25 L
.53128 .25 L
.53129 .25 L
.53129 .25 L
.5313 .25 L
.53131 .25 L
.53131 .25 L
.53131 .25 L
.53132 .25 L
.53132 .25 L
Mistroke
.53133 .25 L
.53133 .25 L
.53134 .25 L
.53135 .25 L
.53135 .25 L
.53136 .25 L
.53137 .25 L
.53137 .25 L
.53138 .25 L
.53138 .25 L
.53139 .25 L
.5314 .25 L
.5314 .25 L
.53141 .25 L
.53141 .25 L
.53142 .25 L
.53143 .25 L
.53143 .25 L
.53144 .25 L
.53145 .25 L
.53145 .25 L
.53146 .25 L
.53147 .25 L
.53147 .25 L
.53147 .25 L
.53148 .25 L
.53148 .25 L
.53149 .25 L
.53149 .25 L
.5315 .25 L
.53151 .25 L
.53151 .25 L
.53152 .25 L
.53152 .25 L
.53153 .25 L
.53154 .25 L
.53154 .25 L
.53155 .25 L
.53156 .25 L
.53156 .25 L
.53157 .25 L
.53158 .25 L
.53158 .25 L
.53159 .25 L
.53159 .25 L
.5316 .25 L
.5316 .25 L
.53161 .25 L
.53161 .25 L
.53161 .25 L
Mistroke
.53162 .25 L
.53162 .25 L
.53163 .25 L
.53163 .25 L
.53164 .25 L
.53164 .25 L
.53164 .25 L
.53165 .25 L
.53165 .25 L
.53165 .25 L
.53166 .25 L
.53167 .25 L
.53167 .25 L
.53168 .25 L
.53169 .25 L
.53169 .25 L
.5317 .25 L
.53171 .25 L
.53171 .25 L
.53172 .25 L
.53172 .25 L
.53173 .25 L
.53174 .25 L
.53174 .25 L
.53175 .25 L
.53176 .25 L
.53176 .25 L
.53177 .25 L
.53177 .25 L
.53178 .25 L
.53178 .25 L
.53179 .25 L
.5318 .25 L
.5318 .25 L
.53181 .25 L
.53181 .25 L
.53182 .25 L
.53183 .25 L
.53183 .25 L
.53184 .25 L
.53184 .25 L
.53185 .25 L
.53185 .25 L
.53186 .25 L
.53186 .25 L
.53187 .25 L
.53188 .25 L
.53188 .25 L
.53189 .25 L
.5319 .25 L
Mistroke
.5319 .25 L
.53191 .25 L
.53191 .25 L
.53192 .25 L
.53193 .25 L
.53193 .25 L
.53194 .25 L
.53195 .25 L
.53195 .25 L
.53196 .25 L
.53196 .25 L
.53197 .25 L
.53197 .25 L
.53198 .25 L
.53199 .25 L
.53199 .25 L
.532 .25 L
.532 .25 L
.53201 .25 L
.53202 .25 L
.53202 .25 L
.53203 .25 L
.53203 .25 L
.53204 .25 L
.53205 .25 L
.53205 .25 L
.53206 .25 L
.53206 .25 L
.53207 .25 L
.53207 .25 L
.53208 .25 L
.53208 .25 L
.53209 .25 L
.53209 .25 L
.5321 .25 L
.5321 .25 L
.53211 .25 L
.53212 .25 L
.53212 .25 L
.53213 .25 L
.53213 .25 L
.53214 .25 L
.53214 .25 L
.53215 .25 L
.53215 .25 L
.53216 .25 L
.53216 .25 L
.53217 .25 L
.53218 .25 L
.53218 .25 L
Mistroke
.53219 .25 L
.53219 .25 L
.5322 .25 L
.53221 .25 L
.53221 .25 L
.53222 .25 L
.53222 .25 L
.53223 .25 L
.53224 .25 L
.53224 .25 L
.53225 .25 L
.53226 .25 L
.53226 .25 L
.53227 .25 L
.53228 .25 L
.53228 .25 L
.53229 .25 L
.53229 .25 L
.5323 .25 L
.5323 .25 L
.5323 .25 L
.53231 .25 L
.53232 .25 L
.53232 .25 L
.53233 .25 L
.53234 .25 L
.53234 .25 L
.53235 .25 L
.53235 .25 L
.53236 .25 L
.53237 .25 L
.53237 .25 L
.53238 .25 L
.53239 .25 L
.53239 .25 L
.5324 .25 L
.53241 .25 L
.53241 .25 L
.53242 .25 L
.53242 .25 L
.53243 .25 L
.53243 .25 L
.53243 .25 L
.53244 .25 L
.53244 .25 L
.53245 .25 L
.53245 .25 L
.53246 .25 L
.53246 .25 L
.53246 .25 L
Mistroke
.53247 .25 L
.53247 .25 L
.53247 .25 L
.53248 .25 L
.53248 .25 L
.53249 .25 L
.5325 .25 L
.5325 .25 L
.53251 .25 L
.53252 .25 L
.53252 .25 L
.53253 .25 L
.53254 .25 L
.53254 .25 L
.53255 .25 L
.53256 .25 L
.53256 .25 L
.53257 .25 L
.53257 .25 L
.53258 .25 L
.53258 .25 L
.53259 .25 L
.5326 .25 L
.5326 .25 L
.53261 .25 L
.53261 .25 L
.53262 .25 L
.53263 .25 L
.53263 .25 L
.53264 .25 L
.53264 .25 L
.53265 .25 L
.53266 .25 L
.53266 .25 L
.53267 .25 L
.53267 .25 L
.53268 .25 L
.53268 .25 L
.53269 .25 L
.53269 .25 L
.5327 .25 L
.53271 .25 L
.53271 .25 L
.53272 .25 L
.53273 .25 L
.53273 .25 L
.53274 .25 L
.53274 .25 L
.53275 .25 L
.53276 .25 L
Mistroke
.53276 .25 L
.53277 .25 L
.53278 .25 L
.53278 .25 L
.53278 .25 L
.53279 .25 L
.5328 .25 L
.5328 .25 L
.53281 .25 L
.53282 .25 L
.53282 .25 L
.53283 .25 L
.53283 .25 L
.53284 .25 L
.53285 .25 L
.53285 .25 L
.53286 .25 L
.53286 .25 L
.53287 .25 L
.53288 .25 L
.53288 .25 L
.53288 .25 L
.53289 .25 L
.5329 .25 L
.5329 .25 L
.53291 .25 L
.53291 .25 L
.53292 .25 L
.53292 .25 L
.53293 .25 L
.53293 .25 L
.53294 .25 L
.53295 .25 L
.53295 .25 L
.53296 .25 L
.53296 .25 L
.53297 .25 L
.53297 .25 L
.53297 .25 L
.53298 .25 L
.53299 .25 L
.53299 .25 L
.533 .25 L
.53301 .25 L
.53301 .25 L
.53302 .25 L
.53302 .25 L
.53303 .25 L
.53304 .25 L
.53304 .25 L
Mistroke
.53305 .25 L
.53306 .25 L
.53306 .25 L
.53307 .25 L
.53307 .25 L
.53308 .25 L
.53309 .25 L
.53309 .25 L
.5331 .25 L
.53311 .25 L
.53311 .25 L
.53312 .25 L
.53312 .25 L
.53312 .25 L
.53313 .25 L
.53313 .25 L
.53314 .25 L
.53315 .25 L
.53315 .25 L
.53316 .25 L
.53317 .25 L
.53317 .25 L
.53318 .25 L
.53318 .25 L
.53319 .25 L
.5332 .25 L
.5332 .25 L
.53321 .25 L
.53322 .25 L
.53322 .25 L
.53323 .25 L
.53324 .25 L
.53324 .25 L
.53324 .25 L
.53325 .25 L
.53325 .25 L
.53326 .25 L
.53326 .25 L
.53326 .25 L
.53327 .25 L
.53328 .25 L
.53328 .25 L
.53328 .25 L
.53329 .25 L
.53329 .25 L
.53329 .25 L
.5333 .25 L
.5333 .25 L
.53331 .25 L
.53331 .25 L
Mistroke
.53332 .25 L
.53333 .25 L
.53333 .25 L
.53334 .25 L
.53335 .25 L
.53335 .25 L
.53336 .25 L
.53337 .25 L
.53337 .25 L
.53338 .25 L
.53338 .25 L
.53339 .25 L
.5334 .25 L
.5334 .25 L
.53341 .25 L
.53341 .25 L
.53342 .25 L
.53342 .25 L
.53343 .25 L
.53344 .25 L
.53344 .25 L
.53345 .25 L
.53345 .25 L
.53346 .25 L
.53347 .25 L
.53347 .25 L
.53348 .25 L
.53348 .25 L
.53349 .25 L
.5335 .25 L
.5335 .25 L
.5335 .25 L
.53351 .25 L
.53352 .25 L
.53352 .25 L
.53353 .25 L
.53354 .25 L
.53354 .25 L
.53355 .25 L
.53355 .25 L
.53356 .25 L
.53357 .25 L
.53357 .25 L
.53358 .25 L
.53359 .25 L
.53359 .25 L
.5336 .25 L
.5336 .25 L
.53361 .25 L
.53361 .25 L
Mistroke
.53362 .25 L
.53363 .25 L
.53363 .25 L
.53364 .25 L
.53365 .25 L
.53365 .25 L
.53366 .25 L
.53366 .25 L
.53367 .25 L
.53367 .25 L
.53368 .25 L
.53369 .25 L
.53369 .25 L
.5337 .25 L
.5337 .25 L
.53371 .25 L
.53371 .25 L
.53372 .25 L
.53373 .25 L
.53373 .25 L
.53374 .25 L
.53375 .25 L
.53375 .25 L
.53376 .25 L
.53376 .25 L
.53377 .25 L
.53378 .25 L
.53378 .25 L
.53379 .25 L
.5338 .25 L
.5338 .25 L
.53381 .25 L
.53381 .25 L
.53382 .25 L
.53382 .25 L
.53383 .25 L
.53384 .25 L
.53384 .25 L
.53385 .25 L
.53385 .25 L
.53386 .25 L
.53387 .25 L
.53387 .25 L
.53388 .25 L
.53388 .25 L
.53389 .25 L
.5339 .25 L
.5339 .25 L
.53391 .25 L
.53391 .25 L
Mistroke
.53392 .25 L
.53392 .25 L
.53393 .25 L
.53393 .25 L
.53394 .25 L
.53394 .25 L
.53395 .25 L
.53395 .25 L
.53396 .25 L
.53397 .25 L
.53397 .25 L
.53398 .25 L
.53398 .25 L
.53399 .25 L
.53399 .25 L
.534 .25 L
.534 .25 L
.53401 .25 L
.53401 .25 L
.53402 .25 L
.53403 .25 L
.53403 .25 L
.53404 .25 L
.53404 .25 L
.53405 .25 L
.53406 .25 L
.53406 .25 L
.53407 .25 L
.53407 .25 L
.53408 .25 L
.53409 .25 L
.53409 .25 L
.5341 .25 L
.53411 .25 L
.53411 .25 L
.53412 .25 L
.53412 .25 L
.53413 .25 L
.53414 .25 L
.53414 .25 L
.53415 .25 L
.53415 .25 L
.53415 .25 L
.53416 .25 L
.53417 .25 L
.53417 .25 L
.53418 .25 L
.53419 .25 L
.53419 .25 L
.5342 .25 L
Mistroke
.5342 .25 L
.53421 .25 L
.53422 .25 L
.53422 .25 L
.53423 .25 L
.53424 .25 L
.53424 .25 L
.53425 .25 L
.53426 .25 L
.53426 .25 L
.53427 .25 L
.53427 .25 L
.53428 .25 L
.53428 .25 L
.53428 .25 L
.53429 .25 L
.53429 .25 L
.5343 .25 L
.5343 .25 L
.53431 .25 L
.53431 .25 L
.53431 .25 L
.53432 .25 L
.53432 .25 L
.53432 .25 L
.53433 .25 L
.53433 .25 L
.53434 .25 L
.53435 .25 L
.53435 .25 L
.53436 .25 L
.53437 .25 L
.53437 .25 L
.53438 .25 L
.53439 .25 L
.53439 .25 L
.5344 .25 L
.53441 .25 L
.53441 .25 L
.53442 .25 L
.53442 .25 L
.53443 .25 L
.53443 .25 L
.53444 .25 L
.53445 .25 L
.53445 .25 L
.53446 .25 L
.53446 .25 L
.53447 .25 L
.53448 .25 L
Mistroke
.53448 .25 L
.53449 .25 L
.53449 .25 L
.5345 .25 L
.53451 .25 L
.53451 .25 L
.53452 .25 L
.53452 .25 L
.53453 .25 L
.53453 .25 L
.53454 .25 L
.53454 .25 L
.53455 .25 L
.53456 .25 L
.53456 .25 L
.53457 .25 L
.53458 .25 L
.53458 .25 L
.53459 .25 L
.53459 .25 L
.5346 .25 L
.53461 .25 L
.53461 .25 L
.53462 .25 L
.53463 .25 L
.53463 .25 L
.53463 .25 L
.53464 .25 L
.53465 .25 L
.53465 .25 L
.53466 .25 L
.53467 .25 L
.53467 .25 L
.53468 .25 L
.53468 .25 L
.53469 .25 L
.5347 .25 L
.5347 .25 L
.53471 .25 L
.53471 .25 L
.53472 .25 L
.53473 .25 L
.53473 .25 L
.53473 .25 L
.53474 .25 L
.53475 .25 L
.53475 .25 L
.53476 .25 L
.53476 .25 L
.53477 .25 L
Mistroke
.53477 .25 L
.53478 .25 L
.53478 .25 L
.53479 .25 L
.5348 .25 L
.5348 .25 L
.53481 .25 L
.53481 .25 L
.53482 .25 L
.53482 .25 L
.53483 .25 L
.53483 .25 L
.53484 .25 L
.53484 .25 L
.53485 .25 L
.53486 .25 L
.53486 .25 L
.53487 .25 L
.53487 .25 L
.53488 .25 L
.53489 .25 L
.53489 .25 L
.5349 .25 L
.53491 .25 L
.53491 .25 L
.53492 .25 L
.53492 .25 L
.53493 .25 L
.53494 .25 L
.53494 .25 L
.53495 .25 L
.53496 .25 L
.53496 .25 L
.53497 .25 L
.53497 .25 L
.53497 .25 L
.53498 .25 L
.53498 .25 L
.53499 .25 L
.535 .25 L
.535 .25 L
.53501 .25 L
.53502 .25 L
.53502 .25 L
.53503 .25 L
.53503 .25 L
.53504 .25 L
.53505 .25 L
.53505 .25 L
.53506 .25 L
Mistroke
.53507 .25 L
.53507 .25 L
.53508 .25 L
.53509 .25 L
.53509 .25 L
.53509 .25 L
.5351 .25 L
.5351 .25 L
.53511 .25 L
.53511 .25 L
.53512 .25 L
.53512 .25 L
.53513 .25 L
.53513 .25 L
.53513 .25 L
.53514 .25 L
.53514 .25 L
.53514 .25 L
.53515 .25 L
.53515 .25 L
.53516 .25 L
.53517 .25 L
.53517 .25 L
.53518 .25 L
.53519 .25 L
.53519 .25 L
.5352 .25 L
.5352 .25 L
.53521 .25 L
.53522 .25 L
.53522 .25 L
.53523 .25 L
.53524 .25 L
.53524 .25 L
.53525 .25 L
.53525 .25 L
.53526 .25 L
.53526 .25 L
.53527 .25 L
.53528 .25 L
.53528 .25 L
.53529 .25 L
.53529 .25 L
.5353 .25 L
.5353 .25 L
.53531 .25 L
.53532 .25 L
.53532 .25 L
.53533 .25 L
.53534 .25 L
Mistroke
.53534 .25 L
.53535 .25 L
.53535 .25 L
.53535 .25 L
.53536 .25 L
.53537 .25 L
.53537 .25 L
.53538 .25 L
.53539 .25 L
.53539 .25 L
.5354 .25 L
.53541 .25 L
.53541 .25 L
.53542 .25 L
.53542 .25 L
.53543 .25 L
.53544 .25 L
.53544 .25 L
.53545 .25 L
.53545 .25 L
.53546 .25 L
.53547 .25 L
.53547 .25 L
.53548 .25 L
.53548 .25 L
.53549 .25 L
.5355 .25 L
.5355 .25 L
.53551 .25 L
.53551 .25 L
.53552 .25 L
.53553 .25 L
.53553 .25 L
.53554 .25 L
.53554 .25 L
.53555 .25 L
.53555 .25 L
.53556 .25 L
.53556 .25 L
.53557 .25 L
.53558 .25 L
.53558 .25 L
.53558 .25 L
.53559 .25 L
.5356 .25 L
.5356 .25 L
.53561 .25 L
.53561 .25 L
.53562 .25 L
.53563 .25 L
Mistroke
.53563 .25 L
.53563 .25 L
.53564 .25 L
.53565 .25 L
.53565 .25 L
.53566 .25 L
.53566 .25 L
.53567 .25 L
.53567 .25 L
.53568 .25 L
.53569 .25 L
.53569 .25 L
.5357 .25 L
.5357 .25 L
.53571 .25 L
.53572 .25 L
.53572 .25 L
.53573 .25 L
.53574 .25 L
.53574 .25 L
.53575 .25 L
.53575 .25 L
.53576 .25 L
.53577 .25 L
.53577 .25 L
.53578 .25 L
.53579 .25 L
.53579 .25 L
.53579 .25 L
.5358 .25 L
.5358 .25 L
.53581 .25 L
.53581 .25 L
.53582 .25 L
.53583 .25 L
.53583 .25 L
.53584 .25 L
.53585 .25 L
.53585 .25 L
.53586 .25 L
.53586 .25 L
.53587 .25 L
.53588 .25 L
.53588 .25 L
.53589 .25 L
.5359 .25 L
.5359 .25 L
.53591 .25 L
.53591 .25 L
.53592 .25 L
Mistroke
.53592 .25 L
.53593 .25 L
.53593 .25 L
.53594 .25 L
.53594 .25 L
.53595 .25 L
.53595 .25 L
.53595 .25 L
.53596 .25 L
.53596 .25 L
.53596 .25 L
.53597 .25 L
.53597 .25 L
.53598 .25 L
.53598 .25 L
.53599 .25 L
.536 .25 L
.536 .25 L
.53601 .25 L
.53602 .25 L
.53602 .25 L
.53603 .25 L
.53603 .25 L
.53604 .25 L
.53605 .25 L
.53605 .25 L
.53606 .25 L
.53607 .25 L
.53607 .25 L
.53608 .25 L
.53608 .25 L
.53609 .25 L
.53609 .25 L
.5361 .25 L
.53611 .25 L
.53611 .25 L
.53612 .25 L
.53612 .25 L
.53613 .25 L
.53613 .25 L
.53614 .25 L
.53615 .25 L
.53615 .25 L
.53616 .25 L
.53616 .25 L
.53617 .25 L
.53617 .25 L
.53618 .25 L
.53618 .25 L
.53619 .25 L
Mistroke
.5362 .25 L
.5362 .25 L
.53621 .25 L
.53622 .25 L
.53622 .25 L
.53623 .25 L
.53624 .25 L
.53624 .25 L
.53625 .25 L
.53626 .25 L
.53626 .25 L
.53627 .25 L
.53627 .25 L
.53628 .25 L
.53628 .25 L
.53629 .25 L
.5363 .25 L
.5363 .25 L
.53631 .25 L
.53631 .25 L
.53632 .25 L
.53633 .25 L
.53633 .25 L
.53634 .25 L
.53634 .25 L
.53635 .25 L
.53636 .25 L
.53636 .25 L
.53637 .25 L
.53637 .25 L
.53638 .25 L
.53638 .25 L
.53639 .25 L
.53639 .25 L
.5364 .25 L
.5364 .25 L
.53641 .25 L
.53641 .25 L
.53642 .25 L
.53643 .25 L
.53643 .25 L
.53644 .25 L
.53644 .25 L
.53645 .25 L
.53645 .25 L
.53646 .25 L
.53646 .25 L
.53647 .25 L
.53647 .25 L
.53648 .25 L
Mistroke
.53649 .25 L
.53649 .25 L
.5365 .25 L
.5365 .25 L
.53651 .25 L
.53652 .25 L
.53652 .25 L
.53653 .25 L
.53653 .25 L
.53654 .25 L
.53655 .25 L
.53655 .25 L
.53656 .25 L
.53656 .25 L
.53657 .25 L
.53658 .25 L
.53658 .25 L
.53659 .25 L
.5366 .25 L
.5366 .25 L
.53661 .25 L
.53661 .25 L
.53662 .25 L
.53662 .25 L
.53662 .25 L
.53663 .25 L
.53664 .25 L
.53664 .25 L
.53665 .25 L
.53666 .25 L
.53666 .25 L
.53667 .25 L
.53667 .25 L
.53668 .25 L
.53669 .25 L
.53669 .25 L
.5367 .25 L
.53671 .25 L
.53671 .25 L
.53672 .25 L
.53673 .25 L
.53673 .25 L
.53674 .25 L
.53674 .25 L
.53675 .25 L
.53675 .25 L
.53675 .25 L
.53676 .25 L
.53676 .25 L
.53677 .25 L
Mistroke
.53677 .25 L
.53678 .25 L
.53678 .25 L
.53678 .25 L
.53679 .25 L
.53679 .25 L
.5368 .25 L
.5368 .25 L
.53681 .25 L
.53681 .25 L
.53682 .25 L
.53683 .25 L
.53683 .25 L
.53684 .25 L
.53684 .25 L
.53685 .25 L
.53686 .25 L
.53686 .25 L
.53687 .25 L
.53688 .25 L
.53688 .25 L
.53689 .25 L
.5369 .25 L
.5369 .25 L
.5369 .25 L
.53691 .25 L
.53692 .25 L
.53692 .25 L
.53693 .25 L
.53693 .25 L
.53694 .25 L
.53695 .25 L
.53695 .25 L
.53696 .25 L
.53696 .25 L
.53697 .25 L
.53698 .25 L
.53698 .25 L
.53699 .25 L
.53699 .25 L
.537 .25 L
.537 .25 L
.53701 .25 L
.53701 .25 L
.53702 .25 L
.53703 .25 L
.53703 .25 L
.53704 .25 L
.53705 .25 L
.53705 .25 L
Mistroke
.53706 .25 L
.53706 .25 L
.53707 .25 L
.53708 .25 L
.53708 .25 L
.53709 .25 L
.5371 .25 L
.5371 .25 L
.53711 .25 L
.53711 .25 L
.53712 .25 L
.53712 .25 L
.53713 .25 L
.53714 .25 L
.53714 .25 L
.53715 .25 L
.53715 .25 L
.53716 .25 L
.53717 .25 L
.53717 .25 L
.53718 .25 L
.53718 .25 L
.53719 .25 L
.5372 .25 L
.5372 .25 L
.5372 .25 L
.53721 .25 L
.53722 .25 L
.53722 .25 L
.53723 .25 L
.53724 .25 L
.53724 .25 L
.53725 .25 L
.53725 .25 L
.53726 .25 L
.53727 .25 L
.53727 .25 L
.53728 .25 L
.53729 .25 L
.53729 .25 L
.5373 .25 L
.5373 .25 L
.53731 .25 L
.53732 .25 L
.53732 .25 L
.53733 .25 L
.53733 .25 L
.53734 .25 L
.53735 .25 L
.53735 .25 L
Mistroke
.53736 .25 L
.53736 .25 L
.53737 .25 L
.53737 .25 L
.53738 .25 L
.53739 .25 L
.53739 .25 L
.5374 .25 L
.5374 .25 L
.53741 .25 L
.53741 .25 L
.53742 .25 L
.53743 .25 L
.53743 .25 L
.53743 .25 L
.53744 .25 L
.53745 .25 L
.53745 .25 L
.53746 .25 L
.53746 .25 L
.53747 .25 L
.53748 .25 L
.53748 .25 L
.53748 .25 L
.53749 .25 L
.53749 .25 L
.5375 .25 L
.5375 .25 L
.53751 .25 L
.53752 .25 L
.53752 .25 L
.53753 .25 L
.53754 .25 L
.53754 .25 L
.53755 .25 L
.53755 .25 L
.53756 .25 L
.53757 .25 L
.53757 .25 L
.53758 .25 L
.53758 .25 L
.53759 .25 L
.5376 .25 L
.5376 .25 L
.53761 .25 L
.53762 .25 L
.53762 .25 L
.53763 .25 L
.53764 .25 L
.53764 .25 L
Mistroke
.53764 .25 L
.53765 .25 L
.53765 .25 L
.53766 .25 L
.53766 .25 L
.53767 .25 L
.53768 .25 L
.53768 .25 L
.53769 .25 L
.5377 .25 L
.5377 .25 L
.53771 .25 L
.53771 .25 L
.53772 .25 L
.53773 .25 L
.53773 .25 L
.53774 .25 L
.53775 .25 L
.53775 .25 L
.53776 .25 L
.53776 .25 L
.53777 .25 L
.53777 .25 L
.53778 .25 L
.53778 .25 L
.53778 .25 L
.53779 .25 L
.5378 .25 L
.5378 .25 L
.5378 .25 L
.53781 .25 L
.53781 .25 L
.53781 .25 L
.53782 .25 L
.53782 .25 L
.53783 .25 L
.53783 .25 L
.53784 .25 L
.53785 .25 L
.53785 .25 L
.53786 .25 L
.53787 .25 L
.53787 .25 L
.53788 .25 L
.53788 .25 L
.53789 .25 L
.5379 .25 L
.5379 .25 L
.53791 .25 L
.53792 .25 L
Mistroke
.53792 .25 L
.53793 .25 L
.53793 .25 L
.53794 .25 L
.53794 .25 L
.53795 .25 L
.53796 .25 L
.53796 .25 L
.53797 .25 L
.53797 .25 L
.53798 .25 L
.53798 .25 L
.53799 .25 L
.538 .25 L
.538 .25 L
.53801 .25 L
.53801 .25 L
.53802 .25 L
.53802 .25 L
.53803 .25 L
.53803 .25 L
.53804 .25 L
.53805 .25 L
.53805 .25 L
.53806 .25 L
.53807 .25 L
.53807 .25 L
.53808 .25 L
.53809 .25 L
.53809 .25 L
.5381 .25 L
.53811 .25 L
.53811 .25 L
.53812 .25 L
.53812 .25 L
.53813 .25 L
.53813 .25 L
.53814 .25 L
.53815 .25 L
.53815 .25 L
.53816 .25 L
.53816 .25 L
.53817 .25 L
.53818 .25 L
.53818 .25 L
.53819 .25 L
.53819 .25 L
.5382 .25 L
.53821 .25 L
.53821 .25 L
Mistroke
.53822 .25 L
.53822 .25 L
.53823 .25 L
.53823 .25 L
.53824 .25 L
.53824 .25 L
.53825 .25 L
.53825 .25 L
.53826 .25 L
.53826 .25 L
.53827 .25 L
.53828 .25 L
.53828 .25 L
.53829 .25 L
.53829 .25 L
.5383 .25 L
.5383 .25 L
.53831 .25 L
.53832 .25 L
.53832 .25 L
.53832 .25 L
.53833 .25 L
.53834 .25 L
.53834 .25 L
.53835 .25 L
.53835 .25 L
.53836 .25 L
.53837 .25 L
.53837 .25 L
.53838 .25 L
.53838 .25 L
.53839 .25 L
.5384 .25 L
.5384 .25 L
.53841 .25 L
.53841 .25 L
.53842 .25 L
.53843 .25 L
.53843 .25 L
.53844 .25 L
.53845 .25 L
.53845 .25 L
.53846 .25 L
.53846 .25 L
.53847 .25 L
.53847 .25 L
.53847 .25 L
.53848 .25 L
.53849 .25 L
.53849 .25 L
Mistroke
.5385 .25 L
.53851 .25 L
.53851 .25 L
.53852 .25 L
.53853 .25 L
.53853 .25 L
.53854 .25 L
.53854 .25 L
.53855 .25 L
.53856 .25 L
.53856 .25 L
.53857 .25 L
.53858 .25 L
.53858 .25 L
.53859 .25 L
.53859 .25 L
.5386 .25 L
.5386 .25 L
.53861 .25 L
.53861 .25 L
.53861 .25 L
.53862 .25 L
.53862 .25 L
.53863 .25 L
.53863 .25 L
.53864 .25 L
.53864 .25 L
.53864 .25 L
.53865 .25 L
.53865 .25 L
.53866 .25 L
.53866 .25 L
.53867 .25 L
.53868 .25 L
.53868 .25 L
.53869 .25 L
.5387 .25 L
.5387 .25 L
.53871 .25 L
.53871 .25 L
.53872 .25 L
.53873 .25 L
.53873 .25 L
.53874 .25 L
.53875 .25 L
.53875 .25 L
.53875 .25 L
.53876 .25 L
.53877 .25 L
.53877 .25 L
Mistroke
.53878 .25 L
.53879 .25 L
.53879 .25 L
.5388 .25 L
.5388 .25 L
.53881 .25 L
.53881 .25 L
.53882 .25 L
.53883 .25 L
.53883 .25 L
.53884 .25 L
.53885 .25 L
.53885 .25 L
.53885 .25 L
.53886 .25 L
.53887 .25 L
.53887 .25 L
.53888 .25 L
.53889 .25 L
.53889 .25 L
.5389 .25 L
.5389 .25 L
.53891 .25 L
.53892 .25 L
.53892 .25 L
.53893 .25 L
.53894 .25 L
.53894 .25 L
.53895 .25 L
.53895 .25 L
.53896 .25 L
.53896 .25 L
.53897 .25 L
.53898 .25 L
.53898 .25 L
.53899 .25 L
.53899 .25 L
.539 .25 L
.53901 .25 L
.53901 .25 L
.53902 .25 L
.53902 .25 L
.53903 .25 L
.53904 .25 L
.53904 .25 L
.53905 .25 L
.53905 .25 L
.53905 .25 L
.53906 .25 L
.53907 .25 L
Mistroke
.53907 .25 L
.53908 .25 L
.53908 .25 L
.53909 .25 L
.53909 .25 L
.5391 .25 L
.53911 .25 L
.53911 .25 L
.53912 .25 L
.53912 .25 L
.53913 .25 L
.53913 .25 L
.53914 .25 L
.53914 .25 L
.53915 .25 L
.53915 .25 L
.53916 .25 L
.53917 .25 L
.53917 .25 L
.53918 .25 L
.53918 .25 L
.53919 .25 L
.5392 .25 L
.5392 .25 L
.53921 .25 L
.53921 .25 L
.53922 .25 L
.53923 .25 L
.53923 .25 L
.53924 .25 L
.53924 .25 L
.53925 .25 L
.53926 .25 L
.53926 .25 L
.53927 .25 L
.53928 .25 L
.53928 .25 L
.53929 .25 L
.53929 .25 L
.53929 .25 L
.5393 .25 L
.53931 .25 L
.53931 .25 L
.53932 .25 L
.53933 .25 L
.53933 .25 L
.53934 .25 L
.53934 .25 L
.53935 .25 L
.53936 .25 L
Mistroke
.53936 .25 L
.53937 .25 L
.53937 .25 L
.53938 .25 L
.53939 .25 L
.53939 .25 L
.5394 .25 L
.53941 .25 L
.53941 .25 L
.53942 .25 L
.53942 .25 L
.53943 .25 L
.53943 .25 L
.53943 .25 L
.53944 .25 L
.53944 .25 L
.53945 .25 L
.53945 .25 L
.53945 .25 L
.53946 .25 L
.53946 .25 L
.53947 .25 L
.53947 .25 L
.53947 .25 L
.53948 .25 L
.53949 .25 L
.53949 .25 L
.5395 .25 L
.53951 .25 L
.53951 .25 L
.53952 .25 L
.53952 .25 L
.53953 .25 L
.53954 .25 L
.53954 .25 L
.53955 .25 L
.53956 .25 L
.53956 .25 L
.53957 .25 L
.53957 .25 L
.53958 .25 L
.53958 .25 L
.53959 .25 L
.5396 .25 L
.5396 .25 L
.53961 .25 L
.53962 .25 L
.53962 .25 L
.53963 .25 L
.53963 .25 L
Mistroke
.53964 .25 L
.53964 .25 L
.53965 .25 L
.53966 .25 L
.53966 .25 L
.53967 .25 L
.53967 .25 L
.53968 .25 L
.53968 .25 L
.53969 .25 L
.5397 .25 L
.5397 .25 L
.53971 .25 L
.53972 .25 L
.53972 .25 L
.53973 .25 L
.53973 .25 L
.53974 .25 L
.53975 .25 L
.53975 .25 L
.53976 .25 L
.53977 .25 L
.53977 .25 L
.53978 .25 L
.53978 .25 L
.53979 .25 L
.53979 .25 L
.5398 .25 L
.53981 .25 L
.53981 .25 L
.53982 .25 L
.53982 .25 L
.53983 .25 L
.53983 .25 L
.53984 .25 L
.53985 .25 L
.53985 .25 L
.53986 .25 L
.53986 .25 L
.53987 .25 L
.53987 .25 L
.53988 .25 L
.53988 .25 L
.53989 .25 L
.5399 .25 L
.5399 .25 L
.5399 .25 L
.53991 .25 L
.53992 .25 L
.53992 .25 L
Mistroke
.53993 .25 L
.53994 .25 L
.53994 .25 L
.53995 .25 L
.53995 .25 L
.53996 .25 L
.53996 .25 L
.53997 .25 L
.53997 .25 L
.53998 .25 L
.53998 .25 L
.53999 .25 L
.54 .25 L
.54 .25 L
.54001 .25 L
.54001 .25 L
.54002 .25 L
.54002 .25 L
.54003 .25 L
.54004 .25 L
.54004 .25 L
.54005 .25 L
.54006 .25 L
.54006 .25 L
.54007 .25 L
.54007 .25 L
.54008 .25 L
.54009 .25 L
.54009 .25 L
.5401 .25 L
.54011 .25 L
.54011 .25 L
.54011 .25 L
.54012 .25 L
.54012 .25 L
.54013 .25 L
.54013 .25 L
.54014 .25 L
.54015 .25 L
.54015 .25 L
.54016 .25 L
.54017 .25 L
.54017 .25 L
.54018 .25 L
.54019 .25 L
.54019 .25 L
.5402 .25 L
.5402 .25 L
.54021 .25 L
.54022 .25 L
Mistroke
.54022 .25 L
.54023 .25 L
.54024 .25 L
.54024 .25 L
.54025 .25 L
.54025 .25 L
.54025 .25 L
.54026 .25 L
.54026 .25 L
.54027 .25 L
.54027 .25 L
.54027 .25 L
.54028 .25 L
.54028 .25 L
.54029 .25 L
.54029 .25 L
.54029 .25 L
.5403 .25 L
.5403 .25 L
.54031 .25 L
.54032 .25 L
.54032 .25 L
.54033 .25 L
.54034 .25 L
.54034 .25 L
.54035 .25 L
.54035 .25 L
.54036 .25 L
.54037 .25 L
.54037 .25 L
.54038 .25 L
.54039 .25 L
.54039 .25 L
.5404 .25 L
.5404 .25 L
.54041 .25 L
.54041 .25 L
.54042 .25 L
.54043 .25 L
.54043 .25 L
.54044 .25 L
.54044 .25 L
.54045 .25 L
.54046 .25 L
.54046 .25 L
.54047 .25 L
.54047 .25 L
.54048 .25 L
.54049 .25 L
.54049 .25 L
Mistroke
.5405 .25 L
.5405 .25 L
.54051 .25 L
.54051 .25 L
.54052 .25 L
.54053 .25 L
.54053 .25 L
.54054 .25 L
.54054 .25 L
.54055 .25 L
.54056 .25 L
.54056 .25 L
.54057 .25 L
.54058 .25 L
.54058 .25 L
.54059 .25 L
.5406 .25 L
.5406 .25 L
.5406 .25 L
.54061 .25 L
.54062 .25 L
.54062 .25 L
.54063 .25 L
.54064 .25 L
.54064 .25 L
.54065 .25 L
.54065 .25 L
.54066 .25 L
.54066 .25 L
.54067 .25 L
.54068 .25 L
.54068 .25 L
.54069 .25 L
.54069 .25 L
.5407 .25 L
.5407 .25 L
.54071 .25 L
.54071 .25 L
.54072 .25 L
.54073 .25 L
.54073 .25 L
.54074 .25 L
.54075 .25 L
.54075 .25 L
.54076 .25 L
.54077 .25 L
.54077 .25 L
.54078 .25 L
.54078 .25 L
.54079 .25 L
Mistroke
.5408 .25 L
.5408 .25 L
.54081 .25 L
.54081 .25 L
.54082 .25 L
.54083 .25 L
.54083 .25 L
.54084 .25 L
.54084 .25 L
.54085 .25 L
.54085 .25 L
.54086 .25 L
.54087 .25 L
.54087 .25 L
.54088 .25 L
.54089 .25 L
.54089 .25 L
.5409 .25 L
.5409 .25 L
.5409 .25 L
.54091 .25 L
.54092 .25 L
.54092 .25 L
.54093 .25 L
.54093 .25 L
.54094 .25 L
.54094 .25 L
.54095 .25 L
.54096 .25 L
.54096 .25 L
.54097 .25 L
.54097 .25 L
.54098 .25 L
.54098 .25 L
.54099 .25 L
.54099 .25 L
.541 .25 L
.541 .25 L
.54101 .25 L
.54102 .25 L
.54102 .25 L
.54103 .25 L
.54103 .25 L
.54104 .25 L
.54104 .25 L
.54105 .25 L
.54106 .25 L
.54106 .25 L
.54107 .25 L
.54108 .25 L
Mistroke
.54108 .25 L
.54109 .25 L
.54109 .25 L
.5411 .25 L
.54111 .25 L
.54111 .25 L
.54112 .25 L
.54113 .25 L
.54113 .25 L
.54114 .25 L
.54114 .25 L
.54114 .25 L
.54115 .25 L
.54116 .25 L
.54116 .25 L
.54117 .25 L
.54118 .25 L
.54118 .25 L
.54119 .25 L
.54119 .25 L
.5412 .25 L
.54121 .25 L
.54121 .25 L
.54122 .25 L
.54122 .25 L
.54123 .25 L
.54124 .25 L
.54124 .25 L
.54125 .25 L
.54126 .25 L
.54126 .25 L
.54127 .25 L
.54127 .25 L
.54128 .25 L
.54128 .25 L
.54128 .25 L
.54129 .25 L
.54129 .25 L
.5413 .25 L
.5413 .25 L
.5413 .25 L
.54131 .25 L
.54131 .25 L
.54132 .25 L
.54132 .25 L
.54132 .25 L
.54133 .25 L
.54134 .25 L
.54134 .25 L
.54135 .25 L
Mistroke
.54136 .25 L
.54136 .25 L
.54137 .25 L
.54137 .25 L
.54138 .25 L
.54139 .25 L
.54139 .25 L
.5414 .25 L
.54141 .25 L
.54141 .25 L
.54142 .25 L
.54142 .25 L
.54143 .25 L
.54143 .25 L
.54144 .25 L
.54145 .25 L
.54145 .25 L
.54146 .25 L
.54147 .25 L
.54147 .25 L
.54148 .25 L
.54148 .25 L
.54149 .25 L
.54149 .25 L
.5415 .25 L
.54151 .25 L
.54151 .25 L
.54152 .25 L
.54152 .25 L
.54153 .25 L
.54153 .25 L
.54154 .25 L
.54155 .25 L
.54155 .25 L
.54156 .25 L
.54157 .25 L
.54157 .25 L
.54158 .25 L
.54158 .25 L
.54159 .25 L
.5416 .25 L
.5416 .25 L
.54161 .25 L
.54162 .25 L
.54162 .25 L
.54163 .25 L
.54163 .25 L
.54164 .25 L
.54164 .25 L
.54165 .25 L
Mistroke
.54166 .25 L
.54166 .25 L
.54167 .25 L
.54167 .25 L
.54168 .25 L
.54168 .25 L
.54169 .25 L
.5417 .25 L
.5417 .25 L
.54171 .25 L
.54171 .25 L
.54172 .25 L
.54173 .25 L
.54173 .25 L
.54173 .25 L
.54174 .25 L
.54175 .25 L
.54175 .25 L
.54176 .25 L
.54176 .25 L
.54177 .25 L
.54177 .25 L
.54178 .25 L
.54179 .25 L
.54179 .25 L
.5418 .25 L
.5418 .25 L
.54181 .25 L
.54181 .25 L
.54182 .25 L
.54182 .25 L
.54183 .25 L
.54183 .25 L
.54184 .25 L
.54185 .25 L
.54185 .25 L
.54186 .25 L
.54186 .25 L
.54187 .25 L
.54188 .25 L
.54188 .25 L
.54189 .25 L
.54189 .25 L
.5419 .25 L
.54191 .25 L
.54191 .25 L
.54192 .25 L
.54193 .25 L
.54193 .25 L
.54194 .25 L
Mistroke
.54194 .25 L
.54195 .25 L
.54196 .25 L
.54196 .25 L
.54197 .25 L
.54197 .25 L
.54197 .25 L
.54198 .25 L
.54199 .25 L
.54199 .25 L
.542 .25 L
.54201 .25 L
.54201 .25 L
.54202 .25 L
.54202 .25 L
.54203 .25 L
.54204 .25 L
.54204 .25 L
.54205 .25 L
.54206 .25 L
.54206 .25 L
.54207 .25 L
.54207 .25 L
.54208 .25 L
.54209 .25 L
.54209 .25 L
.5421 .25 L
.5421 .25 L
.5421 .25 L
.54211 .25 L
.54211 .25 L
.54212 .25 L
.54212 .25 L
.54212 .25 L
.54213 .25 L
.54213 .25 L
.54214 .25 L
.54214 .25 L
.54214 .25 L
.54215 .25 L
.54215 .25 L
.54216 .25 L
.54217 .25 L
.54217 .25 L
.54218 .25 L
.54219 .25 L
.54219 .25 L
.5422 .25 L
.54221 .25 L
.54221 .25 L
Mistroke
.54222 .25 L
.54222 .25 L
.54223 .25 L
.54224 .25 L
.54224 .25 L
.54225 .25 L
.54225 .25 L
.54226 .25 L
.54227 .25 L
.54227 .25 L
.54228 .25 L
.54228 .25 L
.54229 .25 L
.5423 .25 L
.5423 .25 L
.54231 .25 L
.54231 .25 L
.54232 .25 L
.54232 .25 L
.54233 .25 L
.54234 .25 L
.54234 .25 L
.54235 .25 L
.54235 .25 L
.54236 .25 L
.54236 .25 L
.54237 .25 L
.54238 .25 L
.54238 .25 L
.54239 .25 L
.5424 .25 L
.5424 .25 L
.54241 .25 L
.54241 .25 L
.54242 .25 L
.54243 .25 L
.54243 .25 L
.54244 .25 L
.54245 .25 L
.54245 .25 L
.54245 .25 L
.54246 .25 L
.54247 .25 L
.54247 .25 L
.54248 .25 L
.54249 .25 L
.54249 .25 L
.5425 .25 L
.5425 .25 L
.54251 .25 L
Mistroke
.54251 .25 L
.54252 .25 L
.54253 .25 L
.54253 .25 L
.54254 .25 L
.54255 .25 L
.54255 .25 L
.54255 .25 L
.54256 .25 L
.54257 .25 L
.54257 .25 L
.54258 .25 L
.54258 .25 L
.54259 .25 L
.54259 .25 L
.5426 .25 L
.5426 .25 L
.54261 .25 L
.54262 .25 L
.54262 .25 L
.54263 .25 L
.54263 .25 L
.54264 .25 L
.54264 .25 L
.54264 .25 L
.54265 .25 L
.54266 .25 L
.54266 .25 L
.54267 .25 L
.54268 .25 L
.54268 .25 L
.54269 .25 L
.54269 .25 L
.5427 .25 L
.54271 .25 L
.54271 .25 L
.54272 .25 L
.54272 .25 L
.54273 .25 L
.54274 .25 L
.54274 .25 L
.54275 .25 L
.54276 .25 L
.54276 .25 L
.54277 .25 L
.54278 .25 L
.54278 .25 L
.54279 .25 L
.54279 .25 L
.54279 .25 L
Mistroke
.5428 .25 L
.5428 .25 L
.54281 .25 L
.54282 .25 L
.54282 .25 L
.54283 .25 L
.54284 .25 L
.54284 .25 L
.54285 .25 L
.54285 .25 L
.54286 .25 L
.54287 .25 L
.54287 .25 L
.54288 .25 L
.54289 .25 L
.54289 .25 L
.5429 .25 L
.54291 .25 L
.54291 .25 L
.54291 .25 L
.54292 .25 L
.54292 .25 L
.54293 .25 L
.54293 .25 L
.54293 .25 L
.54294 .25 L
.54295 .25 L
.54295 .25 L
.54295 .25 L
.54296 .25 L
.54296 .25 L
.54296 .25 L
.54297 .25 L
.54297 .25 L
.54298 .25 L
.54298 .25 L
.54299 .25 L
.543 .25 L
.543 .25 L
.54301 .25 L
.54302 .25 L
.54302 .25 L
.54303 .25 L
.54303 .25 L
.54304 .25 L
.54305 .25 L
.54305 .25 L
.54306 .25 L
.54307 .25 L
.54307 .25 L
Mistroke
.54308 .25 L
.54308 .25 L
.54309 .25 L
.54309 .25 L
.5431 .25 L
.54311 .25 L
.54311 .25 L
.54312 .25 L
.54312 .25 L
.54313 .25 L
.54314 .25 L
.54314 .25 L
.54315 .25 L
.54315 .25 L
.54316 .25 L
.54317 .25 L
.54317 .25 L
.54317 .25 L
.54318 .25 L
.54319 .25 L
.54319 .25 L
.5432 .25 L
.54321 .25 L
.54321 .25 L
.54322 .25 L
.54322 .25 L
.54323 .25 L
.54324 .25 L
.54324 .25 L
.54325 .25 L
.54326 .25 L
.54326 .25 L
.54327 .25 L
.54327 .25 L
.54328 .25 L
.54328 .25 L
.54329 .25 L
.5433 .25 L
.5433 .25 L
.54331 .25 L
.54332 .25 L
.54332 .25 L
.54333 .25 L
.54333 .25 L
.54334 .25 L
.54334 .25 L
.54335 .25 L
.54336 .25 L
.54336 .25 L
.54337 .25 L
Mistroke
.54337 .25 L
.54338 .25 L
.54338 .25 L
.54339 .25 L
.5434 .25 L
.5434 .25 L
.5434 .25 L
.54341 .25 L
.54342 .25 L
.54342 .25 L
.54343 .25 L
.54343 .25 L
.54344 .25 L
.54345 .25 L
.54345 .25 L
.54345 .25 L
.54346 .25 L
.54346 .25 L
.54347 .25 L
.54347 .25 L
.54348 .25 L
.54349 .25 L
.54349 .25 L
.5435 .25 L
.54351 .25 L
.54351 .25 L
.54352 .25 L
.54352 .25 L
.54353 .25 L
.54354 .25 L
.54354 .25 L
.54355 .25 L
.54355 .25 L
.54356 .25 L
.54357 .25 L
.54357 .25 L
.54358 .25 L
.54359 .25 L
.54359 .25 L
.5436 .25 L
.54361 .25 L
.54361 .25 L
.54361 .25 L
.54362 .25 L
.54362 .25 L
.54363 .25 L
.54363 .25 L
.54364 .25 L
.54365 .25 L
.54365 .25 L
Mistroke
.54366 .25 L
.54366 .25 L
.54367 .25 L
.54368 .25 L
.54368 .25 L
.54369 .25 L
.5437 .25 L
.5437 .25 L
.54371 .25 L
.54372 .25 L
.54372 .25 L
.54373 .25 L
.54373 .25 L
.54374 .25 L
.54374 .25 L
.54375 .25 L
.54375 .25 L
.54375 .25 L
.54376 .25 L
.54376 .25 L
.54377 .25 L
.54377 .25 L
.54378 .25 L
.54378 .25 L
.54378 .25 L
.54379 .25 L
.54379 .25 L
.54379 .25 L
.5438 .25 L
.54381 .25 L
.54381 .25 L
.54382 .25 L
.54383 .25 L
.54383 .25 L
.54384 .25 L
.54385 .25 L
.54385 .25 L
.54386 .25 L
.54387 .25 L
.54387 .25 L
.54388 .25 L
.54388 .25 L
.54389 .25 L
.5439 .25 L
.5439 .25 L
.54391 .25 L
.54391 .25 L
.54392 .25 L
.54392 .25 L
.54393 .25 L
Mistroke
.54394 .25 L
.54394 .25 L
.54395 .25 L
.54395 .25 L
.54396 .25 L
.54397 .25 L
.54397 .25 L
.54398 .25 L
.54398 .25 L
.54399 .25 L
.54399 .25 L
.544 .25 L
.544 .25 L
.54401 .25 L
.54402 .25 L
.54402 .25 L
.54403 .25 L
.54404 .25 L
.54404 .25 L
.54405 .25 L
.54405 .25 L
.54406 .25 L
.54407 .25 L
.54407 .25 L
.54408 .25 L
.54409 .25 L
.54409 .25 L
.5441 .25 L
.5441 .25 L
.54411 .25 L
.54411 .25 L
.54412 .25 L
.54413 .25 L
.54413 .25 L
.54414 .25 L
.54414 .25 L
.54415 .25 L
.54416 .25 L
.54416 .25 L
.54417 .25 L
.54417 .25 L
.54418 .25 L
.54419 .25 L
.54419 .25 L
.5442 .25 L
.5442 .25 L
.54421 .25 L
.54421 .25 L
.54422 .25 L
.54422 .25 L
Mistroke
.54423 .25 L
.54423 .25 L
.54424 .25 L
.54425 .25 L
.54425 .25 L
.54426 .25 L
.54426 .25 L
.54427 .25 L
.54427 .25 L
.54428 .25 L
.54428 .25 L
.54429 .25 L
.54429 .25 L
.5443 .25 L
.5443 .25 L
.54431 .25 L
.54432 .25 L
.54432 .25 L
.54433 .25 L
.54433 .25 L
.54434 .25 L
.54435 .25 L
.54435 .25 L
.54436 .25 L
.54437 .25 L
.54437 .25 L
.54438 .25 L
.54438 .25 L
.54439 .25 L
.5444 .25 L
.5444 .25 L
.54441 .25 L
.54442 .25 L
.54442 .25 L
.54443 .25 L
.54443 .25 L
.54444 .25 L
.54444 .25 L
.54444 .25 L
.54445 .25 L
.54446 .25 L
.54446 .25 L
.54447 .25 L
.54448 .25 L
.54448 .25 L
.54449 .25 L
.54449 .25 L
.5445 .25 L
.54451 .25 L
.54451 .25 L
Mistroke
.54452 .25 L
.54453 .25 L
.54453 .25 L
.54454 .25 L
.54455 .25 L
.54455 .25 L
.54456 .25 L
.54456 .25 L
.54457 .25 L
.54457 .25 L
.54457 .25 L
.54458 .25 L
.54458 .25 L
.54459 .25 L
.54459 .25 L
.5446 .25 L
.5446 .25 L
.5446 .25 L
.54461 .25 L
.54461 .25 L
.54461 .25 L
.54462 .25 L
.54462 .25 L
.54463 .25 L
.54464 .25 L
.54464 .25 L
.54465 .25 L
.54466 .25 L
.54466 .25 L
.54467 .25 L
.54468 .25 L
.54468 .25 L
.54469 .25 L
.5447 .25 L
.5447 .25 L
.54471 .25 L
.54471 .25 L
.54472 .25 L
.54472 .25 L
.54473 .25 L
.54474 .25 L
.54474 .25 L
.54475 .25 L
.54475 .25 L
.54476 .25 L
.54477 .25 L
.54477 .25 L
.54478 .25 L
.54478 .25 L
.54479 .25 L
Mistroke
.5448 .25 L
.5448 .25 L
.54481 .25 L
.54481 .25 L
.54482 .25 L
.54482 .25 L
.54483 .25 L
.54483 .25 L
.54484 .25 L
.54485 .25 L
.54485 .25 L
.54486 .25 L
.54487 .25 L
.54487 .25 L
.54488 .25 L
.54488 .25 L
.54489 .25 L
.5449 .25 L
.5449 .25 L
.54491 .25 L
.54492 .25 L
.54492 .25 L
.54492 .25 L
.54493 .25 L
.54494 .25 L
.54494 .25 L
.54495 .25 L
.54496 .25 L
.54496 .25 L
.54497 .25 L
.54497 .25 L
.54498 .25 L
.54498 .25 L
.54499 .25 L
.545 .25 L
.545 .25 L
.54501 .25 L
.54502 .25 L
.54502 .25 L
.54502 .25 L
.54503 .25 L
.54504 .25 L
.54504 .25 L
.54505 .25 L
.54506 .25 L
.54506 .25 L
.54507 .25 L
.54507 .25 L
.54508 .25 L
.54509 .25 L
Mistroke
.54509 .25 L
.5451 .25 L
.54511 .25 L
.54511 .25 L
.54512 .25 L
.54512 .25 L
.54513 .25 L
.54513 .25 L
.54514 .25 L
.54515 .25 L
.54515 .25 L
.54516 .25 L
.54517 .25 L
.54517 .25 L
.54518 .25 L
.54518 .25 L
.54519 .25 L
.54519 .25 L
.5452 .25 L
.54521 .25 L
.54521 .25 L
.54522 .25 L
.54522 .25 L
.54523 .25 L
.54523 .25 L
.54524 .25 L
.54525 .25 L
.54525 .25 L
.54525 .25 L
.54526 .25 L
.54527 .25 L
.54527 .25 L
.54528 .25 L
.54528 .25 L
.54529 .25 L
.5453 .25 L
.5453 .25 L
.5453 .25 L
.54531 .25 L
.54531 .25 L
.54532 .25 L
.54532 .25 L
.54533 .25 L
.54534 .25 L
.54534 .25 L
.54535 .25 L
.54536 .25 L
.54536 .25 L
.54537 .25 L
.54537 .25 L
Mistroke
.54538 .25 L
.54539 .25 L
.54539 .25 L
.5454 .25 L
.5454 .25 L
.54541 .25 L
.54542 .25 L
.54542 .25 L
.54543 .25 L
.54543 .25 L
.54544 .25 L
.54545 .25 L
.54545 .25 L
.54546 .25 L
.54546 .25 L
.54547 .25 L
.54547 .25 L
.54548 .25 L
.54548 .25 L
.54549 .25 L
.5455 .25 L
.5455 .25 L
.54551 .25 L
.54551 .25 L
.54552 .25 L
.54553 .25 L
.54553 .25 L
.54554 .25 L
.54555 .25 L
.54555 .25 L
.54556 .25 L
.54557 .25 L
.54557 .25 L
.54558 .25 L
.54558 .25 L
.54559 .25 L
.54559 .25 L
.5456 .25 L
.5456 .25 L
.5456 .25 L
.54561 .25 L
.54561 .25 L
.54562 .25 L
.54562 .25 L
.54563 .25 L
.54563 .25 L
.54563 .25 L
.54564 .25 L
.54564 .25 L
.54564 .25 L
Mistroke
.54565 .25 L
.54566 .25 L
.54566 .25 L
.54567 .25 L
.54568 .25 L
.54568 .25 L
.54569 .25 L
.5457 .25 L
.5457 .25 L
.54571 .25 L
.54571 .25 L
.54572 .25 L
.54573 .25 L
.54573 .25 L
.54574 .25 L
.54575 .25 L
.54575 .25 L
.54576 .25 L
.54576 .25 L
.54577 .25 L
.54577 .25 L
.54578 .25 L
.54579 .25 L
.54579 .25 L
.5458 .25 L
.5458 .25 L
.54581 .25 L
.54582 .25 L
.54582 .25 L
.54583 .25 L
.54583 .25 L
.54584 .25 L
.54584 .25 L
.54585 .25 L
.54585 .25 L
.54586 .25 L
.54587 .25 L
.54587 .25 L
.54588 .25 L
.54589 .25 L
.54589 .25 L
.5459 .25 L
.5459 .25 L
.54591 .25 L
.54592 .25 L
.54592 .25 L
.54593 .25 L
.54594 .25 L
.54594 .25 L
.54595 .25 L
Mistroke
.54595 .25 L
.54596 .25 L
.54596 .25 L
.54597 .25 L
.54598 .25 L
.54598 .25 L
.54599 .25 L
.54599 .25 L
.546 .25 L
.54601 .25 L
.54601 .25 L
.54602 .25 L
.54602 .25 L
.54603 .25 L
.54604 .25 L
.54604 .25 L
.54605 .25 L
.54605 .25 L
.54606 .25 L
.54606 .25 L
.54607 .25 L
.54607 .25 L
.54608 .25 L
.54608 .25 L
.54609 .25 L
.54609 .25 L
.5461 .25 L
.54611 .25 L
.54611 .25 L
.54612 .25 L
.54612 .25 L
.54613 .25 L
.54613 .25 L
.54614 .25 L
.54614 .25 L
.54615 .25 L
.54615 .25 L
.54616 .25 L
.54617 .25 L
.54617 .25 L
.54618 .25 L
.54618 .25 L
.54619 .25 L
.5462 .25 L
.5462 .25 L
.54621 .25 L
.54622 .25 L
.54622 .25 L
.54623 .25 L
.54623 .25 L
Mistroke
.54624 .25 L
.54625 .25 L
.54625 .25 L
.54626 .25 L
.54627 .25 L
.54627 .25 L
.54628 .25 L
.54628 .25 L
.54629 .25 L
.54629 .25 L
.54629 .25 L
.5463 .25 L
.54631 .25 L
.54631 .25 L
.54632 .25 L
.54633 .25 L
.54633 .25 L
.54634 .25 L
.54634 .25 L
.54635 .25 L
.54636 .25 L
.54636 .25 L
.54637 .25 L
.54638 .25 L
.54638 .25 L
.54639 .25 L
.5464 .25 L
.5464 .25 L
.54641 .25 L
.54641 .25 L
.54642 .25 L
.54642 .25 L
.54642 .25 L
.54643 .25 L
.54643 .25 L
.54644 .25 L
.54644 .25 L
.54645 .25 L
.54645 .25 L
.54645 .25 L
.54646 .25 L
.54646 .25 L
.54646 .25 L
.54647 .25 L
.54647 .25 L
.54648 .25 L
.54649 .25 L
.5465 .25 L
.5465 .25 L
.54651 .25 L
Mistroke
.54651 .25 L
.54652 .25 L
.54653 .25 L
.54653 .25 L
.54654 .25 L
.54655 .25 L
.54655 .25 L
.54656 .25 L
.54656 .25 L
.54657 .25 L
.54657 .25 L
.54658 .25 L
.54659 .25 L
.54659 .25 L
.5466 .25 L
.5466 .25 L
.54661 .25 L
.54662 .25 L
.54662 .25 L
.54663 .25 L
.54663 .25 L
.54664 .25 L
.54665 .25 L
.54665 .25 L
.54666 .25 L
.54666 .25 L
.54667 .25 L
.54667 .25 L
.54668 .25 L
.54668 .25 L
.54669 .25 L
.5467 .25 L
.5467 .25 L
.54671 .25 L
.54672 .25 L
.54672 .25 L
.54673 .25 L
.54673 .25 L
.54674 .25 L
.54675 .25 L
.54675 .25 L
.54676 .25 L
.54677 .25 L
.54677 .25 L
.54677 .25 L
.54678 .25 L
.54679 .25 L
.54679 .25 L
.5468 .25 L
.54681 .25 L
Mistroke
.54681 .25 L
.54682 .25 L
.54682 .25 L
.54683 .25 L
.54684 .25 L
.54684 .25 L
.54685 .25 L
.54685 .25 L
.54686 .25 L
.54687 .25 L
.54687 .25 L
.54687 .25 L
.54688 .25 L
.54689 .25 L
.54689 .25 L
.5469 .25 L
.5469 .25 L
.54691 .25 L
.54691 .25 L
.54692 .25 L
.54692 .25 L
.54693 .25 L
.54694 .25 L
.54694 .25 L
.54695 .25 L
.54695 .25 L
.54696 .25 L
.54696 .25 L
.54697 .25 L
.54697 .25 L
.54698 .25 L
.54699 .25 L
.54699 .25 L
.547 .25 L
.547 .25 L
.54701 .25 L
.54701 .25 L
.54702 .25 L
.54703 .25 L
.54703 .25 L
.54704 .25 L
.54705 .25 L
.54705 .25 L
.54706 .25 L
.54706 .25 L
.54707 .25 L
.54708 .25 L
.54708 .25 L
.54709 .25 L
.5471 .25 L
Mistroke
.5471 .25 L
.54711 .25 L
.54711 .25 L
.54711 .25 L
.54712 .25 L
.54712 .25 L
.54713 .25 L
.54714 .25 L
.54714 .25 L
.54715 .25 L
.54716 .25 L
.54716 .25 L
.54717 .25 L
.54717 .25 L
.54718 .25 L
.54719 .25 L
.54719 .25 L
.5472 .25 L
.54721 .25 L
.54721 .25 L
.54722 .25 L
.54723 .25 L
.54723 .25 L
.54723 .25 L
.54724 .25 L
.54724 .25 L
.54725 .25 L
.54725 .25 L
.54726 .25 L
.54726 .25 L
.54727 .25 L
.54727 .25 L
.54727 .25 L
.54728 .25 L
.54728 .25 L
.54728 .25 L
.54729 .25 L
.54729 .25 L
.5473 .25 L
.54731 .25 L
.54731 .25 L
.54732 .25 L
.54733 .25 L
.54733 .25 L
.54734 .25 L
.54734 .25 L
.54735 .25 L
.54736 .25 L
.54736 .25 L
.54737 .25 L
Mistroke
.54738 .25 L
.54738 .25 L
.54739 .25 L
.54739 .25 L
.5474 .25 L
.5474 .25 L
.54741 .25 L
.54742 .25 L
.54742 .25 L
.54743 .25 L
.54743 .25 L
.54744 .25 L
.54744 .25 L
.54745 .25 L
.54746 .25 L
.54746 .25 L
.54747 .25 L
.54748 .25 L
.54748 .25 L
.54749 .25 L
.54749 .25 L
.54749 .25 L
.5475 .25 L
.54751 .25 L
.54751 .25 L
.54752 .25 L
.54753 .25 L
.54753 .25 L
.54754 .25 L
.54755 .25 L
.54755 .25 L
.54756 .25 L
.54756 .25 L
.54757 .25 L
.54758 .25 L
.54758 .25 L
.54759 .25 L
.54759 .25 L
.5476 .25 L
.54761 .25 L
.54761 .25 L
.54762 .25 L
.54762 .25 L
.54763 .25 L
.54764 .25 L
.54764 .25 L
.54765 .25 L
.54765 .25 L
.54766 .25 L
.54767 .25 L
Mistroke
.54767 .25 L
.54768 .25 L
.54768 .25 L
.54769 .25 L
.54769 .25 L
.5477 .25 L
.5477 .25 L
.54771 .25 L
.54772 .25 L
.54772 .25 L
.54772 .25 L
.54773 .25 L
.54774 .25 L
.54774 .25 L
.54775 .25 L
.54775 .25 L
.54776 .25 L
.54777 .25 L
.54777 .25 L
.54777 .25 L
.54778 .25 L
.54779 .25 L
.54779 .25 L
.5478 .25 L
.5478 .25 L
.54781 .25 L
.54781 .25 L
.54782 .25 L
.54783 .25 L
.54783 .25 L
.54784 .25 L
.54784 .25 L
.54785 .25 L
.54786 .25 L
.54786 .25 L
.54787 .25 L
.54787 .25 L
.54788 .25 L
.54789 .25 L
.54789 .25 L
.5479 .25 L
.54791 .25 L
.54791 .25 L
.54792 .25 L
.54793 .25 L
.54793 .25 L
.54793 .25 L
.54794 .25 L
.54794 .25 L
.54795 .25 L
Mistroke
.54795 .25 L
.54796 .25 L
.54797 .25 L
.54797 .25 L
.54798 .25 L
.54799 .25 L
.54799 .25 L
.548 .25 L
.548 .25 L
.54801 .25 L
.54802 .25 L
.54802 .25 L
.54803 .25 L
.54804 .25 L
.54804 .25 L
.54805 .25 L
.54805 .25 L
.54806 .25 L
.54806 .25 L
.54807 .25 L
.54807 .25 L
.54807 .25 L
.54808 .25 L
.54809 .25 L
.54809 .25 L
.54809 .25 L
.5481 .25 L
.5481 .25 L
.5481 .25 L
.54811 .25 L
.54811 .25 L
.54812 .25 L
.54812 .25 L
.54813 .25 L
.54814 .25 L
.54814 .25 L
.54815 .25 L
.54815 .25 L
.54816 .25 L
.54817 .25 L
.54817 .25 L
.54818 .25 L
.54819 .25 L
.54819 .25 L
.5482 .25 L
.5482 .25 L
.54821 .25 L
.54822 .25 L
.54822 .25 L
.54823 .25 L
Mistroke
.54823 .25 L
.54824 .25 L
.54824 .25 L
.54825 .25 L
.54826 .25 L
.54826 .25 L
.54827 .25 L
.54827 .25 L
.54828 .25 L
.54829 .25 L
.54829 .25 L
.5483 .25 L
.5483 .25 L
.54831 .25 L
.54831 .25 L
.54832 .25 L
.54832 .25 L
.54833 .25 L
.54834 .25 L
.54834 .25 L
.54835 .25 L
.54836 .25 L
.54836 .25 L
.54837 .25 L
.54838 .25 L
.54838 .25 L
.54839 .25 L
.54839 .25 L
.5484 .25 L
.54841 .25 L
.54841 .25 L
.54842 .25 L
.54842 .25 L
.54843 .25 L
.54844 .25 L
.54844 .25 L
.54845 .25 L
.54845 .25 L
.54846 .25 L
.54847 .25 L
.54847 .25 L
.54848 .25 L
.54848 .25 L
.54849 .25 L
.54849 .25 L
.5485 .25 L
.54851 .25 L
.54851 .25 L
.54852 .25 L
.54852 .25 L
Mistroke
.54853 .25 L
.54853 .25 L
.54854 .25 L
.54855 .25 L
.54855 .25 L
.54856 .25 L
.54857 .25 L
.54857 .25 L
.54858 .25 L
.54858 .25 L
.54859 .25 L
.5486 .25 L
.5486 .25 L
.54861 .25 L
.54862 .25 L
.54862 .25 L
.54862 .25 L
.54863 .25 L
.54864 .25 L
.54864 .25 L
.54865 .25 L
.54866 .25 L
.54866 .25 L
.54867 .25 L
.54867 .25 L
.54868 .25 L
.54868 .25 L
.54869 .25 L
.5487 .25 L
.5487 .25 L
.54871 .25 L
.54872 .25 L
.54872 .25 L
.54872 .25 L
.54873 .25 L
.54874 .25 L
.54874 .25 L
.54875 .25 L
.54875 .25 L
.54876 .25 L
.54876 .25 L
.54877 .25 L
.54877 .25 L
.54878 .25 L
.54879 .25 L
.54879 .25 L
.5488 .25 L
.5488 .25 L
.54881 .25 L
.54881 .25 L
Mistroke
.54881 .25 L
.54882 .25 L
.54883 .25 L
.54883 .25 L
.54884 .25 L
.54885 .25 L
.54885 .25 L
.54886 .25 L
.54886 .25 L
.54887 .25 L
.54888 .25 L
.54888 .25 L
.54889 .25 L
.54889 .25 L
.5489 .25 L
.54891 .25 L
.54891 .25 L
.54892 .25 L
.54893 .25 L
.54893 .25 L
.54894 .25 L
.54895 .25 L
.54895 .25 L
.54896 .25 L
.54896 .25 L
.54896 .25 L
.54897 .25 L
.54897 .25 L
.54898 .25 L
.54899 .25 L
.54899 .25 L
.549 .25 L
.54901 .25 L
.54901 .25 L
.54902 .25 L
.54902 .25 L
.54903 .25 L
.54904 .25 L
.54904 .25 L
.54905 .25 L
.54906 .25 L
.54906 .25 L
.54907 .25 L
.54908 .25 L
.54908 .25 L
.54908 .25 L
.54909 .25 L
.54909 .25 L
.5491 .25 L
.5491 .25 L
Mistroke
.5491 .25 L
.54911 .25 L
.54912 .25 L
.54912 .25 L
.54912 .25 L
.54913 .25 L
.54913 .25 L
.54913 .25 L
.54914 .25 L
.54914 .25 L
.54915 .25 L
.54915 .25 L
.54916 .25 L
.54917 .25 L
.54918 .25 L
.54918 .25 L
.54919 .25 L
.54919 .25 L
.5492 .25 L
.54921 .25 L
.54921 .25 L
.54922 .25 L
.54922 .25 L
.54923 .25 L
.54924 .25 L
.54924 .25 L
.54925 .25 L
.54925 .25 L
.54926 .25 L
.54927 .25 L
.54927 .25 L
.54928 .25 L
.54928 .25 L
.54929 .25 L
.54929 .25 L
.5493 .25 L
.54931 .25 L
.54931 .25 L
.54932 .25 L
.54933 .25 L
.54933 .25 L
.54934 .25 L
.54934 .25 L
.54934 .25 L
.54935 .25 L
.54936 .25 L
.54936 .25 L
.54937 .25 L
.54938 .25 L
.54938 .25 L
Mistroke
.54939 .25 L
.5494 .25 L
.5494 .25 L
.54941 .25 L
.54941 .25 L
.54942 .25 L
.54943 .25 L
.54943 .25 L
.54944 .25 L
.54944 .25 L
.54945 .25 L
.54946 .25 L
.54946 .25 L
.54947 .25 L
.54947 .25 L
.54948 .25 L
.54949 .25 L
.54949 .25 L
.5495 .25 L
.5495 .25 L
.54951 .25 L
.54952 .25 L
.54952 .25 L
.54953 .25 L
.54953 .25 L
.54954 .25 L
.54954 .25 L
.54955 .25 L
.54955 .25 L
.54956 .25 L
.54957 .25 L
.54957 .25 L
.54957 .25 L
.54958 .25 L
.54959 .25 L
.54959 .25 L
.5496 .25 L
.5496 .25 L
.54961 .25 L
.54962 .25 L
.54962 .25 L
.54962 .25 L
.54963 .25 L
.54964 .25 L
.54964 .25 L
.54965 .25 L
.54965 .25 L
.54966 .25 L
.54966 .25 L
.54967 .25 L
Mistroke
.54968 .25 L
.54968 .25 L
.54969 .25 L
.54969 .25 L
.5497 .25 L
.54971 .25 L
.54971 .25 L
.54972 .25 L
.54973 .25 L
.54973 .25 L
.54974 .25 L
.54974 .25 L
.54975 .25 L
.54976 .25 L
.54976 .25 L
.54977 .25 L
.54978 .25 L
.54978 .25 L
.54978 .25 L
.54979 .25 L
.54979 .25 L
.5498 .25 L
.5498 .25 L
.54981 .25 L
.54982 .25 L
.54982 .25 L
.54983 .25 L
.54984 .25 L
.54984 .25 L
.54985 .25 L
.54985 .25 L
.54986 .25 L
.54987 .25 L
.54987 .25 L
.54988 .25 L
.54989 .25 L
.54989 .25 L
.5499 .25 L
.5499 .25 L
.54991 .25 L
.54991 .25 L
.54992 .25 L
.54992 .25 L
.54993 .25 L
.54993 .25 L
.54994 .25 L
.54994 .25 L
.54994 .25 L
.54995 .25 L
.54995 .25 L
Mistroke
.54995 .25 L
.54996 .25 L
.54996 .25 L
.54997 .25 L
.54997 .25 L
.54998 .25 L
.54999 .25 L
.54999 .25 L
.55 .25 L
.55001 .25 L
.55001 .25 L
.55002 .25 L
.55002 .25 L
.55003 .25 L
.55004 .25 L
.55004 .25 L
.55005 .25 L
.55006 .25 L
.55006 .25 L
.55007 .25 L
.55007 .25 L
.55008 .25 L
.55008 .25 L
.55009 .25 L
.5501 .25 L
.5501 .25 L
.55011 .25 L
.55011 .25 L
.55012 .25 L
.55012 .25 L
.55013 .25 L
.55014 .25 L
.55014 .25 L
.55015 .25 L
.55015 .25 L
.55016 .25 L
.55016 .25 L
.55017 .25 L
.55017 .25 L
.55018 .25 L
.55019 .25 L
.55019 .25 L
.5502 .25 L
.55021 .25 L
.55021 .25 L
.55022 .25 L
.55023 .25 L
.55023 .25 L
.55024 .25 L
.55025 .25 L
Mistroke
.55025 .25 L
.55026 .25 L
.55026 .25 L
.55027 .25 L
.55027 .25 L
.55028 .25 L
.55029 .25 L
.55029 .25 L
.5503 .25 L
.5503 .25 L
.55031 .25 L
.55032 .25 L
.55032 .25 L
.55033 .25 L
.55033 .25 L
.55034 .25 L
.55035 .25 L
.55035 .25 L
.55036 .25 L
.55036 .25 L
.55037 .25 L
.55037 .25 L
.55038 .25 L
.55038 .25 L
.55039 .25 L
.55039 .25 L
.5504 .25 L
.5504 .25 L
.55041 .25 L
.55042 .25 L
.55042 .25 L
.55043 .25 L
.55043 .25 L
.55044 .25 L
.55044 .25 L
.55045 .25 L
.55046 .25 L
.55046 .25 L
.55046 .25 L
.55047 .25 L
.55048 .25 L
.55048 .25 L
.55049 .25 L
.55049 .25 L
.5505 .25 L
.55051 .25 L
.55051 .25 L
.55052 .25 L
.55052 .25 L
.55053 .25 L
Mistroke
.55054 .25 L
.55054 .25 L
.55055 .25 L
.55055 .25 L
.55056 .25 L
.55057 .25 L
.55057 .25 L
.55058 .25 L
.55059 .25 L
.55059 .25 L
.5506 .25 L
.5506 .25 L
.55061 .25 L
.55061 .25 L
.55061 .25 L
.55062 .25 L
.55063 .25 L
.55063 .25 L
.55064 .25 L
.55065 .25 L
.55065 .25 L
.55066 .25 L
.55066 .25 L
.55067 .25 L
.55068 .25 L
.55068 .25 L
.55069 .25 L
.5507 .25 L
.5507 .25 L
.55071 .25 L
.55072 .25 L
.55072 .25 L
.55073 .25 L
.55073 .25 L
.55074 .25 L
.55074 .25 L
.55075 .25 L
.55075 .25 L
.55075 .25 L
.55076 .25 L
.55076 .25 L
.55077 .25 L
.55077 .25 L
.55077 .25 L
.55078 .25 L
.55078 .25 L
.55079 .25 L
.55079 .25 L
.5508 .25 L
.5508 .25 L
Mistroke
.55081 .25 L
.55082 .25 L
.55082 .25 L
.55083 .25 L
.55084 .25 L
.55084 .25 L
.55085 .25 L
.55085 .25 L
.55086 .25 L
.55087 .25 L
.55087 .25 L
.55088 .25 L
.55089 .25 L
.55089 .25 L
.55089 .25 L
.5509 .25 L
.55091 .25 L
.55091 .25 L
.55092 .25 L
.55093 .25 L
.55093 .25 L
.55094 .25 L
.55094 .25 L
.55095 .25 L
.55095 .25 L
.55096 .25 L
.55097 .25 L
.55097 .25 L
.55098 .25 L
.55098 .25 L
.55099 .25 L
.55099 .25 L
.551 .25 L
.551 .25 L
.55101 .25 L
.55102 .25 L
.55102 .25 L
.55103 .25 L
.55104 .25 L
.55104 .25 L
.55105 .25 L
.55106 .25 L
.55106 .25 L
.55107 .25 L
.55107 .25 L
.55108 .25 L
.55109 .25 L
.55109 .25 L
.5511 .25 L
.5511 .25 L
Mistroke
.55111 .25 L
.55112 .25 L
.55112 .25 L
.55113 .25 L
.55113 .25 L
.55114 .25 L
.55114 .25 L
.55115 .25 L
.55116 .25 L
.55116 .25 L
.55117 .25 L
.55118 .25 L
.55118 .25 L
.55119 .25 L
.55119 .25 L
.55119 .25 L
.5512 .25 L
.55121 .25 L
.55121 .25 L
.55122 .25 L
.55122 .25 L
.55123 .25 L
.55123 .25 L
.55124 .25 L
.55125 .25 L
.55125 .25 L
.55126 .25 L
.55126 .25 L
.55127 .25 L
.55127 .25 L
.55128 .25 L
.55128 .25 L
.55129 .25 L
.55129 .25 L
.5513 .25 L
.55131 .25 L
.55131 .25 L
.55132 .25 L
.55132 .25 L
.55133 .25 L
.55133 .25 L
.55134 .25 L
.55135 .25 L
.55135 .25 L
.55136 .25 L
.55137 .25 L
.55137 .25 L
.55138 .25 L
.55138 .25 L
.55139 .25 L
Mistroke
.5514 .25 L
.5514 .25 L
.55141 .25 L
.55142 .25 L
.55142 .25 L
.55143 .25 L
.55143 .25 L
.55143 .25 L
.55144 .25 L
.55144 .25 L
.55145 .25 L
.55146 .25 L
.55146 .25 L
.55147 .25 L
.55148 .25 L
.55148 .25 L
.55149 .25 L
.55149 .25 L
.5515 .25 L
.55151 .25 L
.55151 .25 L
.55152 .25 L
.55153 .25 L
.55153 .25 L
.55154 .25 L
.55155 .25 L
.55155 .25 L
.55155 .25 L
.55156 .25 L
.55157 .25 L
.55157 .25 L
.55157 .25 L
.55158 .25 L
.55158 .25 L
.55159 .25 L
.55159 .25 L
.55159 .25 L
.5516 .25 L
.5516 .25 L
.55161 .25 L
.55161 .25 L
.55161 .25 L
.55162 .25 L
.55163 .25 L
.55163 .25 L
.55164 .25 L
.55165 .25 L
.55165 .25 L
.55166 .25 L
.55166 .25 L
Mistroke
.55167 .25 L
.55168 .25 L
.55168 .25 L
.55169 .25 L
.5517 .25 L
.5517 .25 L
.55171 .25 L
.55171 .25 L
.55172 .25 L
.55172 .25 L
.55173 .25 L
.55174 .25 L
.55174 .25 L
.55175 .25 L
.55175 .25 L
.55176 .25 L
.55177 .25 L
.55177 .25 L
.55178 .25 L
.55178 .25 L
.55179 .25 L
.5518 .25 L
.5518 .25 L
.55181 .25 L
.55181 .25 L
.55182 .25 L
.55182 .25 L
.55183 .25 L
.55183 .25 L
.55184 .25 L
.55185 .25 L
.55185 .25 L
.55186 .25 L
.55187 .25 L
.55187 .25 L
.55188 .25 L
.55189 .25 L
.55189 .25 L
.5519 .25 L
.5519 .25 L
.55191 .25 L
.55192 .25 L
.55192 .25 L
.55193 .25 L
.55193 .25 L
.55194 .25 L
.55194 .25 L
.55195 .25 L
.55196 .25 L
.55196 .25 L
Mistroke
.55197 .25 L
.55197 .25 L
.55198 .25 L
.55199 .25 L
.55199 .25 L
.552 .25 L
.552 .25 L
.55201 .25 L
.55201 .25 L
.55202 .25 L
.55202 .25 L
.55203 .25 L
.55204 .25 L
.55204 .25 L
.55205 .25 L
.55206 .25 L
.55206 .25 L
.55207 .25 L
.55208 .25 L
.55208 .25 L
.55209 .25 L
.55209 .25 L
.5521 .25 L
.55211 .25 L
.55211 .25 L
.55212 .25 L
.55212 .25 L
.55213 .25 L
.55214 .25 L
.55214 .25 L
.55215 .25 L
.55215 .25 L
.55216 .25 L
.55217 .25 L
.55217 .25 L
.55218 .25 L
.55218 .25 L
.55219 .25 L
.55219 .25 L
.5522 .25 L
.55221 .25 L
.55221 .25 L
.55222 .25 L
.55222 .25 L
.55223 .25 L
.55223 .25 L
.55224 .25 L
.55224 .25 L
.55225 .25 L
.55225 .25 L
Mistroke
.55226 .25 L
.55227 .25 L
.55227 .25 L
.55228 .25 L
.55228 .25 L
.55229 .25 L
.55229 .25 L
.5523 .25 L
.5523 .25 L
.55231 .25 L
.55231 .25 L
.55232 .25 L
.55233 .25 L
.55233 .25 L
.55234 .25 L
.55234 .25 L
.55235 .25 L
.55236 .25 L
.55236 .25 L
.55237 .25 L
.55237 .25 L
.55238 .25 L
.55239 .25 L
.55239 .25 L
.5524 .25 L
.5524 .25 L
.55241 .25 L
.55242 .25 L
.55242 .25 L
.55243 .25 L
.55244 .25 L
.55244 .25 L
.55245 .25 L
.55245 .25 L
.55246 .25 L
.55246 .25 L
.55246 .25 L
.55247 .25 L
.55248 .25 L
.55248 .25 L
.55249 .25 L
.5525 .25 L
.5525 .25 L
.55251 .25 L
.55251 .25 L
.55252 .25 L
.55253 .25 L
.55253 .25 L
.55254 .25 L
.55255 .25 L
Mistroke
.55255 .25 L
.55256 .25 L
.55257 .25 L
.55257 .25 L
.55258 .25 L
.55258 .25 L
.55259 .25 L
.55259 .25 L
.5526 .25 L
.5526 .25 L
.5526 .25 L
.55261 .25 L
.55261 .25 L
.55262 .25 L
.55262 .25 L
.55262 .25 L
.55263 .25 L
.55263 .25 L
.55264 .25 L
.55264 .25 L
.55265 .25 L
.55265 .25 L
.55266 .25 L
.55267 .25 L
.55267 .25 L
.55268 .25 L
.55268 .25 L
.55269 .25 L
.5527 .25 L
.5527 .25 L
.55271 .25 L
.55272 .25 L
.55272 .25 L
.55273 .25 L
.55274 .25 L
.55274 .25 L
.55274 .25 L
.55275 .25 L
.55276 .25 L
.55276 .25 L
.55277 .25 L
.55278 .25 L
.55278 .25 L
.55279 .25 L
.55279 .25 L
.5528 .25 L
.5528 .25 L
.55281 .25 L
.55282 .25 L
.55282 .25 L
Mistroke
.55283 .25 L
.55283 .25 L
.55284 .25 L
.55284 .25 L
.55285 .25 L
.55285 .25 L
.55286 .25 L
.55286 .25 L
.55287 .25 L
.55288 .25 L
.55288 .25 L
.55288 .25 L
.55289 .25 L
.5529 .25 L
.5529 .25 L
.5529 .25 L
.55291 .25 L
Mfstroke
.55291 .25 m
.55292 .25 L
.55292 .25 L
.55293 .25 L
.55294 .25 L
.55294 .25 L
.55295 .25 L
.55295 .25 L
.55296 .25 L
.55296 .25 L
.55297 .25 L
.55298 .25 L
.55298 .25 L
.55299 .25 L
.55299 .25 L
.553 .25 L
.553 .25 L
.55301 .25 L
.55301 .25 L
.55302 .25 L
.55302 .25 L
.55303 .25 L
.55303 .25 L
.55304 .25 L
.55304 .25 L
.55304 .25 L
.55305 .25 L
.55305 .25 L
.55306 .25 L
.55307 .25 L
.55307 .25 L
.55308 .25 L
.55308 .25 L
.55309 .25 L
.5531 .25 L
.5531 .25 L
.55311 .25 L
.55312 .25 L
.55312 .25 L
.55312 .25 L
.55313 .25 L
.55313 .25 L
.55314 .25 L
.55314 .25 L
.55315 .25 L
.55315 .25 L
.55316 .25 L
.55316 .25 L
.55317 .25 L
.55317 .25 L
Mistroke
.55318 .25 L
.55318 .25 L
.55318 .25 L
.55319 .25 L
.55319 .25 L
.5532 .25 L
.5532 .25 L
.5532 .25 L
.55321 .25 L
.55321 .25 L
.55322 .25 L
.55322 .25 L
.55323 .25 L
.55323 .25 L
.55323 .25 L
.55324 .25 L
.55325 .25 L
.55325 .25 L
.55326 .25 L
.55326 .25 L
.55327 .25 L
.55328 .25 L
.55328 .25 L
.55329 .25 L
.55329 .25 L
.55329 .25 L
.5533 .25 L
.5533 .25 L
.55331 .25 L
.55331 .25 L
.55332 .25 L
.55332 .25 L
.55333 .25 L
.55334 .25 L
.55334 .25 L
.55335 .25 L
.55335 .25 L
.55336 .25 L
.55337 .25 L
.55337 .25 L
.55338 .25 L
.55338 .25 L
.55339 .25 L
.55339 .25 L
.5534 .25 L
.5534 .25 L
.5534 .25 L
.55341 .25 L
.55341 .25 L
.55342 .25 L
Mistroke
.55342 .25 L
.55343 .25 L
.55343 .25 L
.55344 .25 L
.55345 .25 L
.55345 .25 L
.55346 .25 L
.55347 .25 L
.55347 .25 L
.55348 .25 L
.55348 .25 L
.55349 .25 L
.5535 .25 L
.5535 .25 L
.55351 .25 L
.55351 .25 L
.55352 .25 L
.55353 .25 L
.55353 .25 L
.55353 .25 L
.55354 .25 L
.55355 .25 L
.55355 .25 L
.55356 .25 L
.55357 .25 L
.55357 .25 L
.55358 .25 L
.55358 .25 L
.55359 .25 L
.5536 .25 L
.5536 .25 L
.55361 .25 L
.55362 .25 L
.55362 .25 L
.55363 .25 L
.55363 .25 L
.55364 .25 L
.55364 .25 L
.55365 .25 L
.55366 .25 L
.55366 .25 L
.55367 .25 L
.55367 .25 L
.55368 .25 L
.55369 .25 L
.55369 .25 L
.5537 .25 L
.5537 .25 L
.55371 .25 L
.55372 .25 L
Mistroke
.55372 .25 L
.55373 .25 L
.55373 .25 L
.55374 .25 L
.55374 .25 L
.55375 .25 L
.55375 .25 L
.55376 .25 L
.55377 .25 L
.55377 .25 L
.55378 .25 L
.55379 .25 L
.55379 .25 L
.5538 .25 L
.55381 .25 L
.55381 .25 L
.55382 .25 L
.55382 .25 L
.55383 .25 L
.55384 .25 L
.55384 .25 L
.55385 .25 L
.55385 .25 L
.55386 .25 L
.55386 .25 L
.55387 .25 L
.55388 .25 L
.55388 .25 L
.55389 .25 L
.55389 .25 L
.5539 .25 L
.55391 .25 L
.55391 .25 L
.55392 .25 L
.55392 .25 L
.55393 .25 L
.55393 .25 L
.55394 .25 L
.55394 .25 L
.55395 .25 L
.55396 .25 L
.55396 .25 L
.55397 .25 L
.55398 .25 L
.55398 .25 L
.55399 .25 L
.55399 .25 L
.554 .25 L
.55401 .25 L
.55401 .25 L
Mistroke
.55402 .25 L
.55403 .25 L
.55403 .25 L
.55404 .25 L
.55404 .25 L
.55405 .25 L
.55405 .25 L
.55406 .25 L
.55407 .25 L
.55407 .25 L
.55408 .25 L
.55409 .25 L
.55409 .25 L
.5541 .25 L
.5541 .25 L
.55411 .25 L
.55411 .25 L
.55412 .25 L
.55413 .25 L
.55413 .25 L
.55414 .25 L
.55414 .25 L
.55415 .25 L
.55415 .25 L
.55416 .25 L
.55417 .25 L
.55417 .25 L
.55418 .25 L
.55418 .25 L
.55419 .25 L
.5542 .25 L
.5542 .25 L
.55421 .25 L
.55422 .25 L
.55422 .25 L
.55423 .25 L
.55424 .25 L
.55424 .25 L
.55424 .25 L
.55425 .25 L
.55426 .25 L
.55426 .25 L
.55427 .25 L
.55428 .25 L
.55428 .25 L
.55429 .25 L
.55429 .25 L
.5543 .25 L
.5543 .25 L
.55431 .25 L
Mistroke
.55432 .25 L
.55432 .25 L
.55433 .25 L
.55434 .25 L
.55434 .25 L
.55434 .25 L
.55435 .25 L
.55436 .25 L
.55436 .25 L
.55437 .25 L
.55437 .25 L
.55438 .25 L
.55438 .25 L
.55439 .25 L
.55439 .25 L
.5544 .25 L
.55441 .25 L
.55441 .25 L
.55442 .25 L
.55442 .25 L
.55443 .25 L
.55443 .25 L
.55443 .25 L
.55444 .25 L
.55445 .25 L
.55445 .25 L
.55446 .25 L
.55447 .25 L
.55447 .25 L
.55448 .25 L
.55448 .25 L
.55449 .25 L
.5545 .25 L
.5545 .25 L
.55451 .25 L
.55451 .25 L
.55452 .25 L
.55453 .25 L
.55453 .25 L
.55454 .25 L
.55455 .25 L
.55455 .25 L
.55456 .25 L
.55457 .25 L
.55457 .25 L
.55458 .25 L
.55458 .25 L
.55458 .25 L
.55459 .25 L
.55459 .25 L
Mistroke
.5546 .25 L
.55461 .25 L
.55461 .25 L
.55462 .25 L
.55463 .25 L
.55463 .25 L
.55464 .25 L
.55464 .25 L
.55465 .25 L
.55466 .25 L
.55466 .25 L
.55467 .25 L
.55468 .25 L
.55468 .25 L
.55469 .25 L
.5547 .25 L
.5547 .25 L
.5547 .25 L
.55471 .25 L
.55471 .25 L
.55472 .25 L
.55472 .25 L
.55472 .25 L
.55473 .25 L
.55474 .25 L
.55474 .25 L
.55474 .25 L
.55475 .25 L
.55475 .25 L
.55475 .25 L
.55476 .25 L
.55476 .25 L
.55477 .25 L
.55477 .25 L
.55478 .25 L
.55479 .25 L
.55479 .25 L
.5548 .25 L
.55481 .25 L
.55481 .25 L
.55482 .25 L
.55483 .25 L
.55483 .25 L
.55484 .25 L
.55484 .25 L
.55485 .25 L
.55486 .25 L
.55486 .25 L
.55487 .25 L
.55487 .25 L
Mistroke
.55488 .25 L
.55488 .25 L
.55489 .25 L
.5549 .25 L
.5549 .25 L
.55491 .25 L
.55491 .25 L
.55492 .25 L
.55493 .25 L
.55493 .25 L
.55494 .25 L
.55494 .25 L
.55495 .25 L
.55496 .25 L
.55496 .25 L
.55496 .25 L
.55497 .25 L
.55498 .25 L
.55498 .25 L
.55499 .25 L
.555 .25 L
.555 .25 L
.55501 .25 L
.55502 .25 L
.55502 .25 L
.55503 .25 L
.55503 .25 L
.55504 .25 L
.55505 .25 L
.55505 .25 L
.55506 .25 L
.55506 .25 L
.55507 .25 L
.55508 .25 L
.55508 .25 L
.55509 .25 L
.55509 .25 L
.5551 .25 L
.55511 .25 L
.55511 .25 L
.55512 .25 L
.55512 .25 L
.55513 .25 L
.55513 .25 L
.55514 .25 L
.55515 .25 L
.55515 .25 L
.55516 .25 L
.55516 .25 L
.55517 .25 L
Mistroke
.55517 .25 L
.55518 .25 L
.55519 .25 L
.55519 .25 L
.55519 .25 L
.5552 .25 L
.55521 .25 L
.55521 .25 L
.55522 .25 L
.55522 .25 L
.55523 .25 L
.55524 .25 L
.55524 .25 L
.55524 .25 L
.55525 .25 L
.55526 .25 L
.55526 .25 L
.55527 .25 L
.55527 .25 L
.55528 .25 L
.55528 .25 L
.55529 .25 L
.5553 .25 L
.5553 .25 L
.55531 .25 L
.55531 .25 L
.55532 .25 L
.55533 .25 L
.55533 .25 L
.55534 .25 L
.55535 .25 L
.55535 .25 L
.55536 .25 L
.55536 .25 L
.55537 .25 L
.55538 .25 L
.55538 .25 L
.55539 .25 L
.5554 .25 L
.5554 .25 L
.5554 .25 L
.55541 .25 L
.55541 .25 L
.55542 .25 L
.55542 .25 L
.55543 .25 L
.55544 .25 L
.55544 .25 L
.55545 .25 L
.55546 .25 L
Mistroke
.55546 .25 L
.55547 .25 L
.55547 .25 L
.55548 .25 L
.55549 .25 L
.55549 .25 L
.5555 .25 L
.55551 .25 L
.55551 .25 L
.55552 .25 L
.55552 .25 L
.55553 .25 L
.55553 .25 L
.55554 .25 L
.55554 .25 L
.55555 .25 L
.55555 .25 L
.55556 .25 L
.55556 .25 L
.55556 .25 L
.55557 .25 L
.55557 .25 L
.55557 .25 L
.55558 .25 L
.55558 .25 L
.55559 .25 L
.55559 .25 L
.5556 .25 L
.55561 .25 L
.55561 .25 L
.55562 .25 L
.55563 .25 L
.55563 .25 L
.55564 .25 L
.55564 .25 L
.55565 .25 L
.55566 .25 L
.55566 .25 L
.55567 .25 L
.55568 .25 L
.55568 .25 L
.55569 .25 L
.55569 .25 L
.5557 .25 L
.5557 .25 L
.55571 .25 L
.55572 .25 L
.55572 .25 L
.55573 .25 L
.55573 .25 L
Mistroke
.55574 .25 L
.55574 .25 L
.55575 .25 L
.55576 .25 L
.55576 .25 L
.55577 .25 L
.55577 .25 L
.55578 .25 L
.55578 .25 L
.55579 .25 L
.55579 .25 L
.5558 .25 L
.55581 .25 L
.55581 .25 L
.55582 .25 L
.55583 .25 L
.55583 .25 L
.55584 .25 L
.55585 .25 L
.55585 .25 L
.55586 .25 L
.55587 .25 L
.55587 .25 L
.55588 .25 L
.55588 .25 L
.55589 .25 L
.55589 .25 L
.5559 .25 L
.55591 .25 L
.55591 .25 L
.55592 .25 L
.55592 .25 L
.55593 .25 L
.55594 .25 L
.55594 .25 L
.55595 .25 L
.55595 .25 L
.55596 .25 L
.55597 .25 L
.55597 .25 L
.55598 .25 L
.55598 .25 L
.55599 .25 L
.55599 .25 L
.556 .25 L
.556 .25 L
.55601 .25 L
.55601 .25 L
.55602 .25 L
.55602 .25 L
Mistroke
.55603 .25 L
.55604 .25 L
.55604 .25 L
.55605 .25 L
.55605 .25 L
.55606 .25 L
.55606 .25 L
.55607 .25 L
.55608 .25 L
.55608 .25 L
.55608 .25 L
.55609 .25 L
.5561 .25 L
.5561 .25 L
.55611 .25 L
.55611 .25 L
.55612 .25 L
.55613 .25 L
.55613 .25 L
.55614 .25 L
.55614 .25 L
.55615 .25 L
.55616 .25 L
.55616 .25 L
.55617 .25 L
.55617 .25 L
.55618 .25 L
.55619 .25 L
.55619 .25 L
.5562 .25 L
.55621 .25 L
.55621 .25 L
.55622 .25 L
.55622 .25 L
.55623 .25 L
.55623 .25 L
.55623 .25 L
.55624 .25 L
.55625 .25 L
.55625 .25 L
.55626 .25 L
.55627 .25 L
.55627 .25 L
.55628 .25 L
.55629 .25 L
.55629 .25 L
.5563 .25 L
.5563 .25 L
.55631 .25 L
.55632 .25 L
Mistroke
.55632 .25 L
.55633 .25 L
.55634 .25 L
.55634 .25 L
.55635 .25 L
.55635 .25 L
.55636 .25 L
.55636 .25 L
.55637 .25 L
.55637 .25 L
.55637 .25 L
.55638 .25 L
.55638 .25 L
.55639 .25 L
.55639 .25 L
.55639 .25 L
.5564 .25 L
.5564 .25 L
.55641 .25 L
.55641 .25 L
.55642 .25 L
.55642 .25 L
.55643 .25 L
.55644 .25 L
.55644 .25 L
.55645 .25 L
.55646 .25 L
.55646 .25 L
.55647 .25 L
.55647 .25 L
.55648 .25 L
.55649 .25 L
.55649 .25 L
.5565 .25 L
.55651 .25 L
.55651 .25 L
.55651 .25 L
.55652 .25 L
.55653 .25 L
.55653 .25 L
.55654 .25 L
.55655 .25 L
.55655 .25 L
.55656 .25 L
.55656 .25 L
.55657 .25 L
.55657 .25 L
.55658 .25 L
.55659 .25 L
.55659 .25 L
Mistroke
.5566 .25 L
.55661 .25 L
.55661 .25 L
.55661 .25 L
.55662 .25 L
.55663 .25 L
.55663 .25 L
.55664 .25 L
.55665 .25 L
.55665 .25 L
.55666 .25 L
.55666 .25 L
.55667 .25 L
.55668 .25 L
.55668 .25 L
.55669 .25 L
.5567 .25 L
.5567 .25 L
.55671 .25 L
.55671 .25 L
.55672 .25 L
.55672 .25 L
.55673 .25 L
.55674 .25 L
.55674 .25 L
.55675 .25 L
.55675 .25 L
.55676 .25 L
.55676 .25 L
.55677 .25 L
.55678 .25 L
.55678 .25 L
.55679 .25 L
.5568 .25 L
.5568 .25 L
.55681 .25 L
.55681 .25 L
.55681 .25 L
.55682 .25 L
.55683 .25 L
.55683 .25 L
.55684 .25 L
.55684 .25 L
.55685 .25 L
.55685 .25 L
.55686 .25 L
.55687 .25 L
.55687 .25 L
.55688 .25 L
.55688 .25 L
Mistroke
.55689 .25 L
.55689 .25 L
.5569 .25 L
.5569 .25 L
.55691 .25 L
.55691 .25 L
.55692 .25 L
.55693 .25 L
.55693 .25 L
.55694 .25 L
.55694 .25 L
.55695 .25 L
.55695 .25 L
.55696 .25 L
.55697 .25 L
.55697 .25 L
.55698 .25 L
.55699 .25 L
.55699 .25 L
.557 .25 L
.557 .25 L
.55701 .25 L
.55702 .25 L
.55702 .25 L
.55703 .25 L
.55704 .25 L
.55704 .25 L
.55705 .25 L
.55705 .25 L
.55705 .25 L
.55706 .25 L
.55707 .25 L
.55707 .25 L
.55708 .25 L
.55708 .25 L
.55709 .25 L
.5571 .25 L
.5571 .25 L
.55711 .25 L
.55712 .25 L
.55712 .25 L
.55713 .25 L
.55713 .25 L
.55714 .25 L
.55715 .25 L
.55715 .25 L
.55716 .25 L
.55717 .25 L
.55717 .25 L
.55718 .25 L
Mistroke
.55718 .25 L
.55719 .25 L
.55719 .25 L
.55719 .25 L
.5572 .25 L
.5572 .25 L
.55721 .25 L
.55721 .25 L
.55721 .25 L
.55722 .25 L
.55722 .25 L
.55723 .25 L
.55723 .25 L
.55723 .25 L
.55724 .25 L
.55725 .25 L
.55725 .25 L
.55726 .25 L
.55727 .25 L
.55727 .25 L
.55728 .25 L
.55728 .25 L
.55729 .25 L
.5573 .25 L
.5573 .25 L
.55731 .25 L
.55732 .25 L
.55732 .25 L
.55733 .25 L
.55733 .25 L
.55734 .25 L
.55734 .25 L
.55735 .25 L
.55736 .25 L
.55736 .25 L
.55737 .25 L
.55738 .25 L
.55738 .25 L
.55739 .25 L
.55739 .25 L
.5574 .25 L
.5574 .25 L
.55741 .25 L
.55742 .25 L
.55742 .25 L
.55743 .25 L
.55743 .25 L
.55744 .25 L
.55744 .25 L
.55745 .25 L
Mistroke
.55746 .25 L
.55746 .25 L
.55747 .25 L
.55747 .25 L
.55748 .25 L
.55749 .25 L
.55749 .25 L
.5575 .25 L
.55751 .25 L
.55751 .25 L
.55752 .25 L
.55753 .25 L
.55753 .25 L
.55754 .25 L
.55754 .25 L
.55755 .25 L
.55755 .25 L
.55756 .25 L
.55756 .25 L
.55757 .25 L
.55758 .25 L
.55758 .25 L
.55759 .25 L
.55759 .25 L
.5576 .25 L
.55761 .25 L
.55761 .25 L
.55762 .25 L
.55762 .25 L
.55763 .25 L
.55763 .25 L
.55764 .25 L
.55764 .25 L
.55765 .25 L
.55766 .25 L
.55766 .25 L
.55766 .25 L
.55767 .25 L
.55768 .25 L
.55768 .25 L
.55769 .25 L
.55769 .25 L
.5577 .25 L
.55771 .25 L
.55771 .25 L
.55772 .25 L
.55772 .25 L
.55773 .25 L
.55773 .25 L
.55774 .25 L
Mistroke
.55774 .25 L
.55775 .25 L
.55776 .25 L
.55776 .25 L
.55777 .25 L
.55777 .25 L
.55778 .25 L
.55778 .25 L
.55779 .25 L
.5578 .25 L
.5578 .25 L
.55781 .25 L
.55782 .25 L
.55782 .25 L
.55783 .25 L
.55783 .25 L
.55784 .25 L
.55785 .25 L
.55785 .25 L
.55786 .25 L
.55787 .25 L
.55787 .25 L
.55787 .25 L
.55788 .25 L
.55788 .25 L
.55789 .25 L
.55789 .25 L
.5579 .25 L
.55791 .25 L
.55791 .25 L
.55792 .25 L
.55793 .25 L
.55793 .25 L
.55794 .25 L
.55795 .25 L
.55795 .25 L
.55796 .25 L
.55796 .25 L
.55797 .25 L
.55798 .25 L
.55798 .25 L
.55799 .25 L
.55799 .25 L
.558 .25 L
.55801 .25 L
.55801 .25 L
.55801 .25 L
.55802 .25 L
.55802 .25 L
.55803 .25 L
Mistroke
.55803 .25 L
.55803 .25 L
.55804 .25 L
.55804 .25 L
.55805 .25 L
.55805 .25 L
.55805 .25 L
.55806 .25 L
.55806 .25 L
.55807 .25 L
.55808 .25 L
.55808 .25 L
.55809 .25 L
.5581 .25 L
.5581 .25 L
.55811 .25 L
.55811 .25 L
.55812 .25 L
.55813 .25 L
.55813 .25 L
.55814 .25 L
.55815 .25 L
.55815 .25 L
.55816 .25 L
.55816 .25 L
.55817 .25 L
.55817 .25 L
.55818 .25 L
.55819 .25 L
.55819 .25 L
.5582 .25 L
.5582 .25 L
.55821 .25 L
.55821 .25 L
.55822 .25 L
.55823 .25 L
.55823 .25 L
.55824 .25 L
.55825 .25 L
.55825 .25 L
.55826 .25 L
.55826 .25 L
.55827 .25 L
.55827 .25 L
.55828 .25 L
.55829 .25 L
.55829 .25 L
.5583 .25 L
.5583 .25 L
.55831 .25 L
Mistroke
.55832 .25 L
.55832 .25 L
.55833 .25 L
.55834 .25 L
.55834 .25 L
.55835 .25 L
.55836 .25 L
.55836 .25 L
.55836 .25 L
.55837 .25 L
.55838 .25 L
.55838 .25 L
.55839 .25 L
.55839 .25 L
.5584 .25 L
.55841 .25 L
.55841 .25 L
.55842 .25 L
.55842 .25 L
.55843 .25 L
.55844 .25 L
.55844 .25 L
.55845 .25 L
.55845 .25 L
.55846 .25 L
.55846 .25 L
.55847 .25 L
.55847 .25 L
.55848 .25 L
.55849 .25 L
.55849 .25 L
.5585 .25 L
.55851 .25 L
.55851 .25 L
.55852 .25 L
.55852 .25 L
.55853 .25 L
.55854 .25 L
.55854 .25 L
.55855 .25 L
.55856 .25 L
.55856 .25 L
.55857 .25 L
.55857 .25 L
.55858 .25 L
.55858 .25 L
.55859 .25 L
.5586 .25 L
.5586 .25 L
.55861 .25 L
Mistroke
.55861 .25 L
.55862 .25 L
.55863 .25 L
.55863 .25 L
.55864 .25 L
.55864 .25 L
.55865 .25 L
.55866 .25 L
.55866 .25 L
.55866 .25 L
.55867 .25 L
.55868 .25 L
.55868 .25 L
.55869 .25 L
.55869 .25 L
.5587 .25 L
.5587 .25 L
.55871 .25 L
.55871 .25 L
.55872 .25 L
.55873 .25 L
.55873 .25 L
.55874 .25 L
.55874 .25 L
.55875 .25 L
.55875 .25 L
.55876 .25 L
.55876 .25 L
.55877 .25 L
.55878 .25 L
.55878 .25 L
.55879 .25 L
.55879 .25 L
.5588 .25 L
.5588 .25 L
.55881 .25 L
.55882 .25 L
.55882 .25 L
.55883 .25 L
.55884 .25 L
.55884 .25 L
.55885 .25 L
.55885 .25 L
.55886 .25 L
.55887 .25 L
.55887 .25 L
.55888 .25 L
.55889 .25 L
.55889 .25 L
.5589 .25 L
Mistroke
.5589 .25 L
.5589 .25 L
.55891 .25 L
.55891 .25 L
.55892 .25 L
.55893 .25 L
.55893 .25 L
.55894 .25 L
.55895 .25 L
.55895 .25 L
.55896 .25 L
.55896 .25 L
.55897 .25 L
.55898 .25 L
.55898 .25 L
.55899 .25 L
.559 .25 L
.559 .25 L
.55901 .25 L
.55902 .25 L
.55902 .25 L
.55902 .25 L
.55903 .25 L
.55903 .25 L
.55904 .25 L
.55904 .25 L
.55905 .25 L
.55905 .25 L
.55906 .25 L
.55906 .25 L
.55906 .25 L
.55907 .25 L
.55907 .25 L
.55908 .25 L
.55908 .25 L
.55908 .25 L
.55909 .25 L
.5591 .25 L
.5591 .25 L
.55911 .25 L
.55912 .25 L
.55912 .25 L
.55913 .25 L
.55913 .25 L
.55914 .25 L
.55915 .25 L
.55915 .25 L
.55916 .25 L
.55917 .25 L
.55917 .25 L
Mistroke
.55918 .25 L
.55918 .25 L
.55919 .25 L
.55919 .25 L
.5592 .25 L
.55921 .25 L
.55921 .25 L
.55922 .25 L
.55922 .25 L
.55923 .25 L
.55924 .25 L
.55924 .25 L
.55925 .25 L
.55925 .25 L
.55926 .25 L
.55927 .25 L
.55927 .25 L
.55928 .25 L
.55928 .25 L
.55929 .25 L
.55929 .25 L
.5593 .25 L
.5593 .25 L
.55931 .25 L
.55932 .25 L
.55932 .25 L
.55933 .25 L
.55934 .25 L
.55934 .25 L
.55935 .25 L
.55936 .25 L
.55936 .25 L
.55937 .25 L
.55937 .25 L
.55938 .25 L
.55939 .25 L
.55939 .25 L
.5594 .25 L
.5594 .25 L
.55941 .25 L
.55941 .25 L
.55942 .25 L
.55943 .25 L
.55943 .25 L
.55944 .25 L
.55944 .25 L
.55945 .25 L
.55946 .25 L
.55946 .25 L
.55947 .25 L
Mistroke
.55947 .25 L
.55948 .25 L
.55948 .25 L
.55949 .25 L
.55949 .25 L
.5595 .25 L
.55951 .25 L
.55951 .25 L
.55951 .25 L
.55952 .25 L
.55953 .25 L
.55953 .25 L
.55954 .25 L
.55954 .25 L
.55955 .25 L
.55956 .25 L
.55956 .25 L
.55957 .25 L
.55957 .25 L
.55958 .25 L
.55958 .25 L
.55959 .25 L
.55959 .25 L
.5596 .25 L
.55961 .25 L
.55961 .25 L
.55962 .25 L
.55962 .25 L
.55963 .25 L
.55963 .25 L
.55964 .25 L
.55965 .25 L
.55965 .25 L
.55966 .25 L
.55967 .25 L
.55967 .25 L
.55968 .25 L
.55968 .25 L
.55969 .25 L
.5597 .25 L
.5597 .25 L
.55971 .25 L
.55972 .25 L
.55972 .25 L
.55972 .25 L
.55973 .25 L
.55973 .25 L
.55974 .25 L
.55974 .25 L
.55975 .25 L
Mistroke
.55976 .25 L
.55976 .25 L
.55977 .25 L
.55978 .25 L
.55978 .25 L
.55979 .25 L
.5598 .25 L
.5598 .25 L
.55981 .25 L
.55981 .25 L
.55982 .25 L
.55983 .25 L
.55983 .25 L
.55984 .25 L
.55985 .25 L
.55985 .25 L
.55986 .25 L
.55986 .25 L
.55986 .25 L
.55987 .25 L
.55987 .25 L
.55988 .25 L
.55988 .25 L
.55988 .25 L
.55989 .25 L
.55989 .25 L
.5599 .25 L
.5599 .25 L
.5599 .25 L
.55991 .25 L
.55991 .25 L
.55992 .25 L
.55993 .25 L
.55993 .25 L
.55994 .25 L
.55995 .25 L
.55995 .25 L
.55996 .25 L
.55996 .25 L
.55997 .25 L
.55998 .25 L
.55998 .25 L
.55999 .25 L
.56 .25 L
.56 .25 L
.56001 .25 L
.56001 .25 L
.56002 .25 L
.56002 .25 L
.56003 .25 L
Mistroke
.56004 .25 L
.56004 .25 L
.56005 .25 L
.56005 .25 L
.56006 .25 L
.56007 .25 L
.56007 .25 L
.56008 .25 L
.56008 .25 L
.56009 .25 L
.5601 .25 L
.5601 .25 L
.56011 .25 L
.56011 .25 L
.56012 .25 L
.56012 .25 L
.56013 .25 L
.56014 .25 L
.56014 .25 L
.56015 .25 L
.56015 .25 L
.56016 .25 L
.56017 .25 L
.56017 .25 L
.56018 .25 L
.56019 .25 L
.56019 .25 L
.5602 .25 L
.56021 .25 L
.56021 .25 L
.56021 .25 L
.56022 .25 L
.56023 .25 L
.56023 .25 L
.56024 .25 L
.56025 .25 L
.56025 .25 L
.56026 .25 L
.56026 .25 L
.56027 .25 L
.56027 .25 L
.56028 .25 L
.56029 .25 L
.56029 .25 L
.5603 .25 L
.5603 .25 L
.56031 .25 L
.56031 .25 L
.56032 .25 L
.56032 .25 L
Mistroke
.56033 .25 L
.56033 .25 L
.56034 .25 L
.56034 .25 L
.56035 .25 L
.56036 .25 L
.56036 .25 L
.56037 .25 L
.56038 .25 L
.56038 .25 L
.56039 .25 L
.56039 .25 L
.5604 .25 L
.5604 .25 L
.5604 .25 L
.56041 .25 L
.56042 .25 L
.56042 .25 L
.56043 .25 L
.56044 .25 L
.56044 .25 L
.56045 .25 L
.56045 .25 L
.56046 .25 L
.56046 .25 L
.56047 .25 L
.56048 .25 L
.56048 .25 L
.56049 .25 L
.5605 .25 L
.5605 .25 L
.56051 .25 L
.56052 .25 L
.56052 .25 L
.56053 .25 L
.56053 .25 L
.56054 .25 L
.56054 .25 L
.56055 .25 L
.56055 .25 L
.56056 .25 L
.56056 .25 L
.56057 .25 L
.56058 .25 L
.56058 .25 L
.56059 .25 L
.56059 .25 L
.5606 .25 L
.56061 .25 L
.56061 .25 L
Mistroke
.56062 .25 L
.56063 .25 L
.56063 .25 L
.56064 .25 L
.56065 .25 L
.56065 .25 L
.56066 .25 L
.56066 .25 L
.56067 .25 L
.56067 .25 L
.56068 .25 L
.56068 .25 L
.56069 .25 L
.56069 .25 L
.56069 .25 L
.5607 .25 L
.5607 .25 L
.56071 .25 L
.56071 .25 L
.56072 .25 L
.56072 .25 L
.56072 .25 L
.56073 .25 L
.56073 .25 L
.56074 .25 L
.56074 .25 L
.56075 .25 L
.56076 .25 L
.56076 .25 L
.56077 .25 L
.56078 .25 L
.56078 .25 L
.56079 .25 L
.56079 .25 L
.5608 .25 L
.56081 .25 L
.56081 .25 L
.56082 .25 L
.56083 .25 L
.56083 .25 L
.56083 .25 L
.56084 .25 L
.56085 .25 L
.56085 .25 L
.56086 .25 L
.56087 .25 L
.56087 .25 L
.56088 .25 L
.56088 .25 L
.56089 .25 L
Mistroke
.56089 .25 L
.5609 .25 L
.56091 .25 L
.56091 .25 L
.56092 .25 L
.56093 .25 L
.56093 .25 L
.56093 .25 L
.56094 .25 L
.56095 .25 L
.56095 .25 L
.56096 .25 L
.56097 .25 L
.56097 .25 L
.56098 .25 L
.56098 .25 L
.56099 .25 L
.561 .25 L
.561 .25 L
.56101 .25 L
.56102 .25 L
.56102 .25 L
.56103 .25 L
.56103 .25 L
.56104 .25 L
.56104 .25 L
.56105 .25 L
.56106 .25 L
.56106 .25 L
.56107 .25 L
.56107 .25 L
.56108 .25 L
.56109 .25 L
.56109 .25 L
.5611 .25 L
.5611 .25 L
.56111 .25 L
.56112 .25 L
.56112 .25 L
.56113 .25 L
.56113 .25 L
.56114 .25 L
.56114 .25 L
.56115 .25 L
.56115 .25 L
.56116 .25 L
.56116 .25 L
.56117 .25 L
.56117 .25 L
.56118 .25 L
Mistroke
.56119 .25 L
.56119 .25 L
.5612 .25 L
.56121 .25 L
.56121 .25 L
.56121 .25 L
.56122 .25 L
.56122 .25 L
.56123 .25 L
.56123 .25 L
.56124 .25 L
.56125 .25 L
.56125 .25 L
.56126 .25 L
.56126 .25 L
.56127 .25 L
.56128 .25 L
.56128 .25 L
.56129 .25 L
.56129 .25 L
.5613 .25 L
.56131 .25 L
.56131 .25 L
.56132 .25 L
.56132 .25 L
.56133 .25 L
.56134 .25 L
.56134 .25 L
.56135 .25 L
.56136 .25 L
.56136 .25 L
.56137 .25 L
.56137 .25 L
.56138 .25 L
.56138 .25 L
.56139 .25 L
.56139 .25 L
.5614 .25 L
.56141 .25 L
.56141 .25 L
.56142 .25 L
.56142 .25 L
.56143 .25 L
.56144 .25 L
.56144 .25 L
.56145 .25 L
.56146 .25 L
.56146 .25 L
.56147 .25 L
.56148 .25 L
Mistroke
.56148 .25 L
.56149 .25 L
.56149 .25 L
.5615 .25 L
.5615 .25 L
.56151 .25 L
.56151 .25 L
.56151 .25 L
.56152 .25 L
.56152 .25 L
.56153 .25 L
.56153 .25 L
.56154 .25 L
.56154 .25 L
.56154 .25 L
.56155 .25 L
.56155 .25 L
.56155 .25 L
.56156 .25 L
.56157 .25 L
.56157 .25 L
.56158 .25 L
.56159 .25 L
.56159 .25 L
.5616 .25 L
.5616 .25 L
.56161 .25 L
.56162 .25 L
.56162 .25 L
.56163 .25 L
.56164 .25 L
.56164 .25 L
.56165 .25 L
.56165 .25 L
.56166 .25 L
.56166 .25 L
.56167 .25 L
.56168 .25 L
.56168 .25 L
.56169 .25 L
.5617 .25 L
.5617 .25 L
.56171 .25 L
.56171 .25 L
.56172 .25 L
.56172 .25 L
.56173 .25 L
.56174 .25 L
.56174 .25 L
.56175 .25 L
Mistroke
.56175 .25 L
.56176 .25 L
.56176 .25 L
.56177 .25 L
.56178 .25 L
.56178 .25 L
.56179 .25 L
.5618 .25 L
.5618 .25 L
.56181 .25 L
.56181 .25 L
.56182 .25 L
.56183 .25 L
.56183 .25 L
.56184 .25 L
.56185 .25 L
.56185 .25 L
.56186 .25 L
.56186 .25 L
.56187 .25 L
.56187 .25 L
.56188 .25 L
.56189 .25 L
.56189 .25 L
.5619 .25 L
.5619 .25 L
.56191 .25 L
.56191 .25 L
.56192 .25 L
.56193 .25 L
.56193 .25 L
.56194 .25 L
.56194 .25 L
.56195 .25 L
.56196 .25 L
.56196 .25 L
.56196 .25 L
.56197 .25 L
.56198 .25 L
.56199 .25 L
.56199 .25 L
.562 .25 L
.562 .25 L
.56201 .25 L
.56202 .25 L
.56202 .25 L
.56203 .25 L
.56204 .25 L
.56204 .25 L
.56205 .25 L
Mistroke
.56206 .25 L
.56206 .25 L
.56206 .25 L
.56207 .25 L
.56208 .25 L
.56208 .25 L
.56209 .25 L
.56209 .25 L
.5621 .25 L
.56211 .25 L
.56211 .25 L
.56212 .25 L
.56212 .25 L
.56213 .25 L
.56214 .25 L
.56214 .25 L
.56215 .25 L
.56215 .25 L
.56216 .25 L
.56216 .25 L
.56217 .25 L
.56217 .25 L
.56218 .25 L
.56218 .25 L
.56219 .25 L
.56219 .25 L
.5622 .25 L
.56221 .25 L
.56221 .25 L
.56222 .25 L
.56222 .25 L
.56223 .25 L
.56224 .25 L
.56224 .25 L
.56225 .25 L
.56225 .25 L
.56225 .25 L
.56226 .25 L
.56227 .25 L
.56227 .25 L
.56228 .25 L
.56228 .25 L
.56229 .25 L
.5623 .25 L
.5623 .25 L
.56231 .25 L
.56231 .25 L
.56232 .25 L
.56233 .25 L
.56233 .25 L
Mistroke
.56234 .25 L
.56235 .25 L
.56235 .25 L
.56236 .25 L
.56236 .25 L
.56237 .25 L
.56238 .25 L
.56238 .25 L
.56239 .25 L
.56239 .25 L
.5624 .25 L
.5624 .25 L
.56241 .25 L
.56241 .25 L
.56242 .25 L
.56242 .25 L
.56243 .25 L
.56244 .25 L
.56244 .25 L
.56245 .25 L
.56246 .25 L
.56246 .25 L
.56247 .25 L
.56248 .25 L
.56248 .25 L
.56249 .25 L
.56249 .25 L
.5625 .25 L
.56251 .25 L
.56251 .25 L
.56252 .25 L
.56252 .25 L
.56253 .25 L
.56253 .25 L
.56254 .25 L
.56254 .25 L
.56254 .25 L
.56255 .25 L
.56255 .25 L
.56256 .25 L
.56256 .25 L
.56257 .25 L
.56257 .25 L
.56257 .25 L
.56258 .25 L
.56258 .25 L
.56259 .25 L
.56259 .25 L
.5626 .25 L
.56261 .25 L
Mistroke
.56261 .25 L
.56262 .25 L
.56263 .25 L
.56263 .25 L
.56264 .25 L
.56264 .25 L
.56265 .25 L
.56266 .25 L
.56266 .25 L
.56267 .25 L
.56268 .25 L
.56268 .25 L
.56268 .25 L
.56269 .25 L
.5627 .25 L
.5627 .25 L
.56271 .25 L
.56272 .25 L
.56272 .25 L
.56273 .25 L
.56273 .25 L
.56274 .25 L
.56274 .25 L
.56275 .25 L
.56276 .25 L
.56276 .25 L
.56277 .25 L
.56278 .25 L
.56278 .25 L
.56278 .25 L
.56279 .25 L
.5628 .25 L
.5628 .25 L
.56281 .25 L
.56282 .25 L
.56282 .25 L
.56283 .25 L
.56283 .25 L
.56284 .25 L
.56285 .25 L
.56285 .25 L
.56286 .25 L
.56287 .25 L
.56287 .25 L
.56288 .25 L
.56288 .25 L
.56289 .25 L
.56289 .25 L
.5629 .25 L
.56291 .25 L
Mistroke
.56291 .25 L
.56292 .25 L
.56292 .25 L
.56293 .25 L
.56294 .25 L
.56294 .25 L
.56295 .25 L
.56295 .25 L
.56296 .25 L
.56297 .25 L
.56297 .25 L
.56298 .25 L
.56298 .25 L
.56299 .25 L
.56299 .25 L
.563 .25 L
.563 .25 L
.56301 .25 L
.56301 .25 L
.56302 .25 L
.56302 .25 L
.56303 .25 L
.56304 .25 L
.56304 .25 L
.56305 .25 L
.56306 .25 L
.56306 .25 L
.56306 .25 L
.56307 .25 L
.56307 .25 L
.56308 .25 L
.56308 .25 L
.56309 .25 L
.5631 .25 L
.5631 .25 L
.56311 .25 L
.56311 .25 L
.56312 .25 L
.56313 .25 L
.56313 .25 L
.56314 .25 L
.56314 .25 L
.56315 .25 L
.56316 .25 L
.56316 .25 L
.56317 .25 L
.56318 .25 L
.56318 .25 L
.56319 .25 L
.56319 .25 L
Mistroke
.5632 .25 L
.56321 .25 L
.56321 .25 L
.56322 .25 L
.56322 .25 L
.56323 .25 L
.56323 .25 L
.56324 .25 L
.56324 .25 L
.56325 .25 L
.56326 .25 L
.56326 .25 L
.56327 .25 L
.56327 .25 L
.56328 .25 L
.56329 .25 L
.56329 .25 L
.5633 .25 L
.56331 .25 L
.56331 .25 L
.56332 .25 L
.56333 .25 L
.56333 .25 L
.56334 .25 L
.56334 .25 L
.56335 .25 L
.56335 .25 L
.56336 .25 L
.56336 .25 L
.56336 .25 L
.56337 .25 L
.56337 .25 L
.56338 .25 L
.56338 .25 L
.56339 .25 L
.56339 .25 L
.56339 .25 L
.5634 .25 L
.5634 .25 L
.5634 .25 L
.56341 .25 L
.56342 .25 L
.56342 .25 L
.56343 .25 L
.56344 .25 L
.56344 .25 L
.56345 .25 L
.56346 .25 L
.56346 .25 L
.56347 .25 L
Mistroke
.56347 .25 L
.56348 .25 L
.56349 .25 L
.56349 .25 L
.5635 .25 L
.5635 .25 L
.56351 .25 L
.56352 .25 L
.56352 .25 L
.56353 .25 L
.56353 .25 L
.56354 .25 L
.56355 .25 L
.56355 .25 L
.56356 .25 L
.56356 .25 L
.56357 .25 L
.56357 .25 L
.56358 .25 L
.56359 .25 L
.56359 .25 L
.5636 .25 L
.5636 .25 L
.56361 .25 L
.56361 .25 L
.56362 .25 L
.56363 .25 L
.56363 .25 L
.56364 .25 L
.56365 .25 L
.56365 .25 L
.56366 .25 L
.56366 .25 L
.56367 .25 L
.56368 .25 L
.56368 .25 L
.56369 .25 L
.5637 .25 L
.5637 .25 L
.56371 .25 L
.56371 .25 L
.56372 .25 L
.56372 .25 L
.56373 .25 L
.56374 .25 L
.56374 .25 L
.56375 .25 L
.56375 .25 L
.56376 .25 L
.56377 .25 L
Mistroke
.56377 .25 L
.56378 .25 L
.56378 .25 L
.56379 .25 L
.5638 .25 L
.5638 .25 L
.56381 .25 L
.56381 .25 L
.56382 .25 L
.56382 .25 L
.56383 .25 L
.56383 .25 L
.56384 .25 L
.56384 .25 L
.56385 .25 L
.56385 .25 L
.56386 .25 L
.56387 .25 L
.56387 .25 L
.56388 .25 L
.56388 .25 L
.56389 .25 L
.56389 .25 L
.5639 .25 L
.5639 .25 L
.56391 .25 L
.56391 .25 L
.56392 .25 L
.56393 .25 L
.56393 .25 L
.56394 .25 L
.56394 .25 L
.56395 .25 L
.56396 .25 L
.56396 .25 L
.56397 .25 L
.56397 .25 L
.56398 .25 L
.56399 .25 L
.56399 .25 L
.564 .25 L
.56401 .25 L
.56401 .25 L
.56402 .25 L
.56402 .25 L
.56403 .25 L
.56404 .25 L
.56404 .25 L
.56405 .25 L
.56405 .25 L
Mistroke
.56405 .25 L
.56406 .25 L
.56407 .25 L
.56407 .25 L
.56408 .25 L
.56409 .25 L
.56409 .25 L
.5641 .25 L
.5641 .25 L
.56411 .25 L
.56412 .25 L
.56412 .25 L
.56413 .25 L
.56414 .25 L
.56414 .25 L
.56415 .25 L
.56416 .25 L
.56416 .25 L
.56417 .25 L
.56417 .25 L
.56418 .25 L
.56418 .25 L
.56418 .25 L
.56419 .25 L
.56419 .25 L
.5642 .25 L
.5642 .25 L
.56421 .25 L
.56421 .25 L
.56421 .25 L
.56422 .25 L
.56422 .25 L
.56422 .25 L
.56423 .25 L
.56423 .25 L
.56424 .25 L
.56425 .25 L
.56425 .25 L
.56426 .25 L
.56427 .25 L
.56427 .25 L
.56428 .25 L
.56429 .25 L
.56429 .25 L
.5643 .25 L
.5643 .25 L
.56431 .25 L
.56432 .25 L
.56432 .25 L
.56433 .25 L
Mistroke
.56433 .25 L
.56434 .25 L
.56435 .25 L
.56435 .25 L
.56436 .25 L
.56436 .25 L
.56437 .25 L
.56438 .25 L
.56438 .25 L
.56439 .25 L
.56439 .25 L
.5644 .25 L
.5644 .25 L
.56441 .25 L
.56442 .25 L
.56442 .25 L
.56443 .25 L
.56443 .25 L
.56444 .25 L
.56444 .25 L
.56445 .25 L
.56446 .25 L
.56446 .25 L
.56447 .25 L
.56448 .25 L
.56448 .25 L
.56449 .25 L
.56449 .25 L
.5645 .25 L
.56451 .25 L
.56451 .25 L
.56452 .25 L
.56453 .25 L
.56453 .25 L
.56453 .25 L
.56454 .25 L
.56455 .25 L
.56455 .25 L
.56456 .25 L
.56457 .25 L
.56457 .25 L
.56458 .25 L
.56458 .25 L
.56459 .25 L
.56459 .25 L
.5646 .25 L
.56461 .25 L
.56461 .25 L
.56462 .25 L
.56463 .25 L
Mistroke
.56463 .25 L
.56463 .25 L
.56464 .25 L
.56465 .25 L
.56465 .25 L
.56466 .25 L
.56466 .25 L
.56467 .25 L
.56467 .25 L
.56468 .25 L
.56468 .25 L
.56469 .25 L
.5647 .25 L
.5647 .25 L
.56471 .25 L
.56471 .25 L
.56472 .25 L
.56472 .25 L
.56472 .25 L
.56473 .25 L
.56474 .25 L
.56474 .25 L
.56475 .25 L
.56476 .25 L
.56476 .25 L
.56477 .25 L
.56477 .25 L
.56478 .25 L
.56479 .25 L
.56479 .25 L
.5648 .25 L
.5648 .25 L
.56481 .25 L
.56482 .25 L
.56482 .25 L
.56483 .25 L
.56484 .25 L
.56484 .25 L
.56485 .25 L
.56486 .25 L
.56486 .25 L
.56487 .25 L
.56487 .25 L
.56487 .25 L
.56488 .25 L
.56488 .25 L
.56489 .25 L
.5649 .25 L
.5649 .25 L
.56491 .25 L
Mistroke
.56492 .25 L
.56492 .25 L
.56493 .25 L
.56493 .25 L
.56494 .25 L
.56495 .25 L
.56495 .25 L
.56496 .25 L
.56497 .25 L
.56497 .25 L
.56498 .25 L
.56499 .25 L
.56499 .25 L
.56499 .25 L
.565 .25 L
.565 .25 L
.56501 .25 L
.56501 .25 L
.56501 .25 L
.56502 .25 L
.56503 .25 L
.56503 .25 L
.56503 .25 L
.56504 .25 L
.56504 .25 L
.56504 .25 L
.56505 .25 L
.56505 .25 L
.56506 .25 L
.56506 .25 L
.56507 .25 L
.56508 .25 L
.56508 .25 L
.56509 .25 L
.5651 .25 L
.5651 .25 L
.56511 .25 L
.56511 .25 L
.56512 .25 L
.56513 .25 L
.56513 .25 L
.56514 .25 L
.56515 .25 L
.56515 .25 L
.56516 .25 L
.56516 .25 L
.56517 .25 L
.56517 .25 L
.56518 .25 L
.56519 .25 L
Mistroke
.56519 .25 L
.5652 .25 L
.5652 .25 L
.56521 .25 L
.56522 .25 L
.56522 .25 L
.56523 .25 L
.56523 .25 L
.56524 .25 L
.56525 .25 L
.56525 .25 L
.56525 .25 L
.56526 .25 L
.56527 .25 L
.56527 .25 L
.56528 .25 L
.56529 .25 L
.56529 .25 L
.5653 .25 L
.5653 .25 L
.56531 .25 L
.56532 .25 L
.56532 .25 L
.56533 .25 L
.56534 .25 L
.56534 .25 L
.56535 .25 L
.56535 .25 L
.56536 .25 L
.56536 .25 L
.56537 .25 L
.56538 .25 L
.56538 .25 L
.56539 .25 L
.5654 .25 L
.5654 .25 L
.56541 .25 L
.56541 .25 L
.56542 .25 L
.56542 .25 L
.56543 .25 L
.56544 .25 L
.56544 .25 L
.56545 .25 L
.56545 .25 L
.56546 .25 L
.56546 .25 L
.56547 .25 L
.56548 .25 L
.56548 .25 L
Mistroke
.56549 .25 L
.5655 .25 L
.5655 .25 L
.56551 .25 L
.56551 .25 L
.56552 .25 L
.56553 .25 L
.56553 .25 L
.56554 .25 L
.56555 .25 L
.56555 .25 L
.56556 .25 L
.56556 .25 L
.56557 .25 L
.56557 .25 L
.56558 .25 L
.56559 .25 L
.56559 .25 L
.5656 .25 L
.5656 .25 L
.56561 .25 L
.56562 .25 L
.56562 .25 L
.56563 .25 L
.56563 .25 L
.56564 .25 L
.56565 .25 L
.56565 .25 L
.56566 .25 L
.56566 .25 L
.56567 .25 L
.56567 .25 L
.56568 .25 L
.56568 .25 L
.56569 .25 L
.56569 .25 L
.5657 .25 L
.5657 .25 L
.56571 .25 L
.56572 .25 L
.56572 .25 L
.56573 .25 L
.56573 .25 L
.56574 .25 L
.56574 .25 L
.56575 .25 L
.56575 .25 L
.56576 .25 L
.56576 .25 L
.56577 .25 L
Mistroke
.56578 .25 L
.56578 .25 L
.56579 .25 L
.56579 .25 L
.5658 .25 L
.56581 .25 L
.56581 .25 L
.56582 .25 L
.56582 .25 L
.56583 .25 L
.56584 .25 L
.56584 .25 L
.56585 .25 L
.56586 .25 L
.56586 .25 L
.56587 .25 L
.56587 .25 L
.56588 .25 L
.56589 .25 L
.56589 .25 L
.5659 .25 L
.5659 .25 L
.5659 .25 L
.56591 .25 L
.56592 .25 L
.56592 .25 L
.56593 .25 L
.56594 .25 L
.56594 .25 L
.56595 .25 L
.56595 .25 L
.56596 .25 L
.56597 .25 L
.56597 .25 L
.56598 .25 L
.56599 .25 L
.56599 .25 L
.566 .25 L
.56601 .25 L
.56601 .25 L
.56602 .25 L
.56602 .25 L
.56603 .25 L
.56603 .25 L
.56603 .25 L
.56604 .25 L
.56604 .25 L
.56605 .25 L
.56605 .25 L
.56606 .25 L
Mistroke
.56606 .25 L
.56606 .25 L
.56607 .25 L
.56607 .25 L
.56607 .25 L
.56608 .25 L
.56608 .25 L
.56609 .25 L
.5661 .25 L
.5661 .25 L
.56611 .25 L
.56612 .25 L
.56612 .25 L
.56613 .25 L
.56614 .25 L
.56614 .25 L
.56615 .25 L
.56615 .25 L
.56616 .25 L
.56617 .25 L
.56617 .25 L
.56618 .25 L
.56618 .25 L
.56619 .25 L
.5662 .25 L
.5662 .25 L
.56621 .25 L
.56621 .25 L
.56622 .25 L
.56623 .25 L
.56623 .25 L
.56624 .25 L
.56624 .25 L
.56625 .25 L
.56626 .25 L
.56626 .25 L
.56627 .25 L
.56627 .25 L
.56628 .25 L
.56628 .25 L
.56629 .25 L
.56629 .25 L
.5663 .25 L
.56631 .25 L
.56631 .25 L
.56632 .25 L
.56633 .25 L
.56633 .25 L
.56634 .25 L
.56634 .25 L
Mistroke
.56635 .25 L
.56636 .25 L
.56636 .25 L
.56637 .25 L
.56638 .25 L
.56638 .25 L
.56638 .25 L
.56639 .25 L
.5664 .25 L
.5664 .25 L
.56641 .25 L
.56642 .25 L
.56642 .25 L
.56643 .25 L
.56643 .25 L
.56644 .25 L
.56644 .25 L
.56645 .25 L
.56646 .25 L
.56646 .25 L
.56647 .25 L
.56648 .25 L
.56648 .25 L
.56648 .25 L
.56649 .25 L
.5665 .25 L
.5665 .25 L
.56651 .25 L
.56651 .25 L
.56652 .25 L
.56652 .25 L
.56653 .25 L
.56653 .25 L
.56654 .25 L
.56655 .25 L
.56655 .25 L
.56656 .25 L
.56656 .25 L
.56657 .25 L
.56657 .25 L
.56657 .25 L
.56658 .25 L
.56659 .25 L
.56659 .25 L
.5666 .25 L
.56661 .25 L
.56661 .25 L
.56662 .25 L
.56662 .25 L
.56663 .25 L
Mistroke
.56664 .25 L
.56664 .25 L
.56665 .25 L
.56666 .25 L
.56666 .25 L
.56667 .25 L
.56667 .25 L
.56668 .25 L
.56669 .25 L
.56669 .25 L
.5667 .25 L
.56671 .25 L
.56671 .25 L
.56672 .25 L
.56672 .25 L
.56672 .25 L
.56673 .25 L
.56673 .25 L
.56674 .25 L
.56675 .25 L
.56675 .25 L
.56676 .25 L
.56677 .25 L
.56677 .25 L
.56678 .25 L
.56678 .25 L
.56679 .25 L
.5668 .25 L
.5668 .25 L
.56681 .25 L
.56682 .25 L
.56682 .25 L
.56683 .25 L
.56684 .25 L
.56684 .25 L
.56684 .25 L
.56685 .25 L
.56685 .25 L
.56686 .25 L
.56686 .25 L
.56687 .25 L
.56687 .25 L
.56688 .25 L
.56688 .25 L
.56688 .25 L
.56689 .25 L
.56689 .25 L
.56689 .25 L
.5669 .25 L
.5669 .25 L
Mistroke
.56691 .25 L
.56692 .25 L
.56692 .25 L
.56693 .25 L
.56694 .25 L
.56694 .25 L
.56695 .25 L
.56695 .25 L
.56696 .25 L
.56697 .25 L
.56697 .25 L
.56698 .25 L
.56698 .25 L
.56699 .25 L
.567 .25 L
.567 .25 L
.56701 .25 L
.56701 .25 L
.56702 .25 L
.56703 .25 L
.56703 .25 L
.56704 .25 L
.56704 .25 L
.56705 .25 L
.56705 .25 L
.56706 .25 L
.56707 .25 L
.56707 .25 L
.56708 .25 L
.56709 .25 L
.56709 .25 L
.5671 .25 L
.5671 .25 L
.5671 .25 L
.56711 .25 L
.56712 .25 L
.56712 .25 L
.56713 .25 L
.56714 .25 L
.56714 .25 L
.56715 .25 L
.56716 .25 L
.56716 .25 L
.56717 .25 L
.56717 .25 L
.56718 .25 L
.56719 .25 L
.56719 .25 L
.5672 .25 L
.5672 .25 L
Mistroke
.56721 .25 L
.56722 .25 L
.56722 .25 L
.56723 .25 L
.56723 .25 L
.56724 .25 L
.56725 .25 L
.56725 .25 L
.56726 .25 L
.56726 .25 L
.56727 .25 L
.56728 .25 L
.56728 .25 L
.56729 .25 L
.56729 .25 L
.5673 .25 L
.5673 .25 L
.56731 .25 L
.56731 .25 L
.56732 .25 L
.56733 .25 L
.56733 .25 L
.56733 .25 L
.56734 .25 L
.56735 .25 L
.56735 .25 L
.56736 .25 L
.56736 .25 L
.56737 .25 L
.56738 .25 L
.56738 .25 L
.56738 .25 L
.56739 .25 L
.5674 .25 L
.5674 .25 L
.56741 .25 L
.56741 .25 L
.56742 .25 L
.56742 .25 L
.56743 .25 L
.56744 .25 L
.56744 .25 L
.56745 .25 L
.56745 .25 L
.56746 .25 L
.56747 .25 L
.56747 .25 L
.56748 .25 L
.56749 .25 L
.56749 .25 L
Mistroke
.5675 .25 L
.5675 .25 L
.56751 .25 L
.56752 .25 L
.56752 .25 L
.56753 .25 L
.56754 .25 L
.56754 .25 L
.56754 .25 L
.56755 .25 L
.56755 .25 L
.56756 .25 L
.56756 .25 L
.56757 .25 L
.56758 .25 L
.56758 .25 L
.56759 .25 L
.5676 .25 L
.5676 .25 L
.56761 .25 L
.56761 .25 L
.56762 .25 L
.56763 .25 L
.56763 .25 L
.56764 .25 L
.56765 .25 L
.56765 .25 L
.56766 .25 L
.56766 .25 L
.56767 .25 L
.56767 .25 L
.56768 .25 L
.56768 .25 L
.56769 .25 L
.56769 .25 L
.5677 .25 L
.5677 .25 L
.5677 .25 L
.56771 .25 L
.56771 .25 L
.56771 .25 L
.56772 .25 L
.56772 .25 L
.56773 .25 L
.56773 .25 L
.56774 .25 L
.56775 .25 L
.56775 .25 L
.56776 .25 L
.56777 .25 L
Mistroke
.56777 .25 L
.56778 .25 L
.56778 .25 L
.56779 .25 L
.5678 .25 L
.5678 .25 L
.56781 .25 L
.56782 .25 L
.56782 .25 L
.56783 .25 L
.56783 .25 L
.56784 .25 L
.56784 .25 L
.56785 .25 L
.56786 .25 L
.56786 .25 L
.56787 .25 L
.56787 .25 L
.56788 .25 L
.56788 .25 L
.56789 .25 L
.5679 .25 L
.5679 .25 L
.56791 .25 L
.56791 .25 L
.56792 .25 L
.56792 .25 L
.56793 .25 L
.56793 .25 L
.56794 .25 L
.56795 .25 L
.56795 .25 L
.56796 .25 L
.56797 .25 L
.56797 .25 L
.56798 .25 L
.56799 .25 L
.56799 .25 L
.568 .25 L
.56801 .25 L
.56801 .25 L
.56802 .25 L
.56802 .25 L
.56803 .25 L
.56803 .25 L
.56804 .25 L
.56805 .25 L
.56805 .25 L
.56806 .25 L
.56806 .25 L
Mistroke
.56807 .25 L
.56808 .25 L
.56808 .25 L
.56809 .25 L
.56809 .25 L
.5681 .25 L
.56811 .25 L
.56811 .25 L
.56812 .25 L
.56812 .25 L
.56813 .25 L
.56813 .25 L
.56814 .25 L
.56814 .25 L
.56815 .25 L
.56815 .25 L
.56816 .25 L
.56816 .25 L
.56817 .25 L
.56818 .25 L
.56818 .25 L
.56819 .25 L
.56819 .25 L
.5682 .25 L
.5682 .25 L
.56821 .25 L
.56821 .25 L
.56822 .25 L
.56822 .25 L
.56823 .25 L
.56824 .25 L
.56824 .25 L
.56825 .25 L
.56825 .25 L
.56826 .25 L
.56827 .25 L
.56827 .25 L
.56828 .25 L
.56828 .25 L
.56829 .25 L
.5683 .25 L
.5683 .25 L
.56831 .25 L
.56831 .25 L
.56832 .25 L
.56833 .25 L
.56833 .25 L
.56834 .25 L
.56835 .25 L
.56835 .25 L
Mistroke
.56836 .25 L
.56836 .25 L
.56837 .25 L
.56837 .25 L
.56837 .25 L
.56838 .25 L
.56839 .25 L
.56839 .25 L
.5684 .25 L
.56841 .25 L
.56841 .25 L
.56842 .25 L
.56842 .25 L
.56843 .25 L
.56844 .25 L
.56844 .25 L
.56845 .25 L
.56846 .25 L
.56846 .25 L
.56847 .25 L
.56848 .25 L
.56848 .25 L
.56849 .25 L
.56849 .25 L
.5685 .25 L
.5685 .25 L
.5685 .25 L
.56851 .25 L
.56851 .25 L
.56852 .25 L
.56852 .25 L
.56853 .25 L
.56853 .25 L
.56853 .25 L
.56854 .25 L
.56854 .25 L
.56855 .25 L
.56855 .25 L
.56856 .25 L
.56856 .25 L
.56857 .25 L
.56858 .25 L
.56858 .25 L
.56859 .25 L
.56859 .25 L
.5686 .25 L
.56861 .25 L
.56861 .25 L
.56862 .25 L
.56863 .25 L
Mistroke
.56863 .25 L
.56864 .25 L
.56865 .25 L
.56865 .25 L
.56865 .25 L
.56866 .25 L
.56867 .25 L
.56867 .25 L
.56868 .25 L
.56869 .25 L
.56869 .25 L
.5687 .25 L
.5687 .25 L
.56871 .25 L
.56871 .25 L
.56872 .25 L
.56873 .25 L
.56873 .25 L
.56874 .25 L
.56874 .25 L
.56875 .25 L
.56875 .25 L
.56876 .25 L
.56876 .25 L
.56877 .25 L
.56878 .25 L
.56878 .25 L
.56879 .25 L
.5688 .25 L
.5688 .25 L
.56881 .25 L
.56881 .25 L
.56882 .25 L
.56883 .25 L
.56883 .25 L
.56884 .25 L
.56885 .25 L
.56885 .25 L
.56886 .25 L
.56886 .25 L
.56887 .25 L
.56887 .25 L
.56888 .25 L
.56889 .25 L
.56889 .25 L
.5689 .25 L
.5689 .25 L
.56891 .25 L
.56892 .25 L
.56892 .25 L
Mistroke
.56893 .25 L
.56893 .25 L
.56894 .25 L
.56895 .25 L
.56895 .25 L
.56895 .25 L
.56896 .25 L
.56897 .25 L
.56897 .25 L
.56898 .25 L
.56899 .25 L
.56899 .25 L
.569 .25 L
.56901 .25 L
.56901 .25 L
.56902 .25 L
.56902 .25 L
.56903 .25 L
.56904 .25 L
.56904 .25 L
.56905 .25 L
.56905 .25 L
.56906 .25 L
.56907 .25 L
.56907 .25 L
.56908 .25 L
.56908 .25 L
.56909 .25 L
.5691 .25 L
.5691 .25 L
.56911 .25 L
.56911 .25 L
.56912 .25 L
.56912 .25 L
.56913 .25 L
.56914 .25 L
.56914 .25 L
.56915 .25 L
.56915 .25 L
.56916 .25 L
.56916 .25 L
.56917 .25 L
.56918 .25 L
.56918 .25 L
.56918 .25 L
.56919 .25 L
.5692 .25 L
.5692 .25 L
.56921 .25 L
.56921 .25 L
Mistroke
.56922 .25 L
.56923 .25 L
.56923 .25 L
.56923 .25 L
.56924 .25 L
.56925 .25 L
.56925 .25 L
.56926 .25 L
.56926 .25 L
.56927 .25 L
.56927 .25 L
.56928 .25 L
.56929 .25 L
.56929 .25 L
.5693 .25 L
.5693 .25 L
.56931 .25 L
.56932 .25 L
.56932 .25 L
.56933 .25 L
.56934 .25 L
.56934 .25 L
.56935 .25 L
.56935 .25 L
.56936 .25 L
.56937 .25 L
.56937 .25 L
.56938 .25 L
.56939 .25 L
.56939 .25 L
.56939 .25 L
.5694 .25 L
.5694 .25 L
.56941 .25 L
.56941 .25 L
.56942 .25 L
.56943 .25 L
.56943 .25 L
.56944 .25 L
.56945 .25 L
.56945 .25 L
.56946 .25 L
.56946 .25 L
.56947 .25 L
.56948 .25 L
.56948 .25 L
.56949 .25 L
.5695 .25 L
.5695 .25 L
.56951 .25 L
Mistroke
.56951 .25 L
.56952 .25 L
.56952 .25 L
.56953 .25 L
.56953 .25 L
.56954 .25 L
.56954 .25 L
.56955 .25 L
.56955 .25 L
.56955 .25 L
.56956 .25 L
.56956 .25 L
.56956 .25 L
.56957 .25 L
.56957 .25 L
.56958 .25 L
.56958 .25 L
.56959 .25 L
.5696 .25 L
.5696 .25 L
.56961 .25 L
.56962 .25 L
.56962 .25 L
.56963 .25 L
.56963 .25 L
.56964 .25 L
.56965 .25 L
.56965 .25 L
.56966 .25 L
.56967 .25 L
.56967 .25 L
.56968 .25 L
.56968 .25 L
.56969 .25 L
.56969 .25 L
.5697 .25 L
.56971 .25 L
.56971 .25 L
.56972 .25 L
.56972 .25 L
.56973 .25 L
.56973 .25 L
.56974 .25 L
.56975 .25 L
.56975 .25 L
.56976 .25 L
.56976 .25 L
.56977 .25 L
.56977 .25 L
.56978 .25 L
Mistroke
.56978 .25 L
.56979 .25 L
.5698 .25 L
.5698 .25 L
.56981 .25 L
.56982 .25 L
.56982 .25 L
.56983 .25 L
.56984 .25 L
.56984 .25 L
.56985 .25 L
.56986 .25 L
.56986 .25 L
.56987 .25 L
.56987 .25 L
.56988 .25 L
.56988 .25 L
.56989 .25 L
.5699 .25 L
.5699 .25 L
.56991 .25 L
.56991 .25 L
.56992 .25 L
.56993 .25 L
.56993 .25 L
.56994 .25 L
.56994 .25 L
.56995 .25 L
.56996 .25 L
.56996 .25 L
.56997 .25 L
.56997 .25 L
.56998 .25 L
.56998 .25 L
.56999 .25 L
.56999 .25 L
.57 .25 L
.57 .25 L
.57001 .25 L
.57001 .25 L
.57002 .25 L
.57003 .25 L
.57003 .25 L
.57004 .25 L
.57004 .25 L
.57005 .25 L
.57005 .25 L
.57006 .25 L
.57007 .25 L
.57007 .25 L
Mistroke
.57007 .25 L
.57008 .25 L
.57009 .25 L
.57009 .25 L
.5701 .25 L
.5701 .25 L
.57011 .25 L
.57012 .25 L
.57012 .25 L
.57013 .25 L
.57013 .25 L
.57014 .25 L
.57015 .25 L
.57015 .25 L
.57016 .25 L
.57016 .25 L
.57017 .25 L
.57018 .25 L
.57018 .25 L
.57019 .25 L
.5702 .25 L
.5702 .25 L
.57021 .25 L
.57021 .25 L
.57022 .25 L
.57022 .25 L
.57022 .25 L
.57023 .25 L
.57024 .25 L
.57024 .25 L
.57025 .25 L
.57026 .25 L
.57026 .25 L
.57027 .25 L
.57028 .25 L
.57028 .25 L
.57029 .25 L
.5703 .25 L
.5703 .25 L
.57031 .25 L
.57031 .25 L
.57032 .25 L
.57033 .25 L
.57033 .25 L
.57034 .25 L
.57034 .25 L
.57035 .25 L
.57035 .25 L
.57036 .25 L
.57036 .25 L
Mistroke
.57036 .25 L
.57037 .25 L
.57037 .25 L
.57038 .25 L
.57038 .25 L
.57039 .25 L
.57039 .25 L
.57039 .25 L
.5704 .25 L
.5704 .25 L
.57041 .25 L
.57041 .25 L
.57042 .25 L
.57043 .25 L
.57043 .25 L
.57044 .25 L
.57045 .25 L
.57045 .25 L
.57046 .25 L
.57046 .25 L
.57047 .25 L
.57048 .25 L
.57048 .25 L
.57049 .25 L
.5705 .25 L
.5705 .25 L
.5705 .25 L
.57051 .25 L
.57052 .25 L
.57052 .25 L
.57053 .25 L
.57054 .25 L
.57054 .25 L
.57055 .25 L
.57055 .25 L
.57056 .25 L
.57056 .25 L
.57057 .25 L
.57058 .25 L
.57058 .25 L
.57059 .25 L
.5706 .25 L
.5706 .25 L
.5706 .25 L
.57061 .25 L
.57062 .25 L
.57062 .25 L
.57063 .25 L
.57064 .25 L
.57064 .25 L
Mistroke
.57065 .25 L
.57065 .25 L
.57066 .25 L
.57067 .25 L
.57067 .25 L
.57068 .25 L
.57069 .25 L
.57069 .25 L
.5707 .25 L
.5707 .25 L
.57071 .25 L
.57071 .25 L
.57072 .25 L
.57073 .25 L
.57073 .25 L
.57074 .25 L
.57074 .25 L
.57075 .25 L
.57076 .25 L
.57076 .25 L
.57077 .25 L
.57077 .25 L
.57078 .25 L
.57079 .25 L
.57079 .25 L
.5708 .25 L
.5708 .25 L
.5708 .25 L
.57081 .25 L
.57082 .25 L
.57082 .25 L
.57083 .25 L
.57083 .25 L
.57084 .25 L
.57084 .25 L
.57085 .25 L
.57086 .25 L
.57086 .25 L
.57087 .25 L
.57088 .25 L
.57088 .25 L
.57088 .25 L
.57089 .25 L
.57089 .25 L
.5709 .25 L
.5709 .25 L
.57091 .25 L
.57092 .25 L
.57092 .25 L
.57093 .25 L
Mistroke
.57093 .25 L
.57094 .25 L
.57095 .25 L
.57095 .25 L
.57096 .25 L
.57096 .25 L
.57097 .25 L
.57098 .25 L
.57098 .25 L
.57099 .25 L
.57099 .25 L
.571 .25 L
.57101 .25 L
.57101 .25 L
.57102 .25 L
.57103 .25 L
.57103 .25 L
.57104 .25 L
.57104 .25 L
.57105 .25 L
.57105 .25 L
.57106 .25 L
.57106 .25 L
.57107 .25 L
.57108 .25 L
.57108 .25 L
.57109 .25 L
.57109 .25 L
.5711 .25 L
.57111 .25 L
.57111 .25 L
.57112 .25 L
.57113 .25 L
.57113 .25 L
.57114 .25 L
.57115 .25 L
.57115 .25 L
.57116 .25 L
.57116 .25 L
.57117 .25 L
.57117 .25 L
.57118 .25 L
.57118 .25 L
.57118 .25 L
.57119 .25 L
.57119 .25 L
.5712 .25 L
.5712 .25 L
.5712 .25 L
.57121 .25 L
Mistroke
.57121 .25 L
.57122 .25 L
.57122 .25 L
.57122 .25 L
.57123 .25 L
.57124 .25 L
.57124 .25 L
.57125 .25 L
.57126 .25 L
.57126 .25 L
.57127 .25 L
.57127 .25 L
.57128 .25 L
.57129 .25 L
.57129 .25 L
.5713 .25 L
.57131 .25 L
.57131 .25 L
.57132 .25 L
.57132 .25 L
.57133 .25 L
.57133 .25 L
.57134 .25 L
.57135 .25 L
.57135 .25 L
.57136 .25 L
.57137 .25 L
.57137 .25 L
.57138 .25 L
.57138 .25 L
.57139 .25 L
.57139 .25 L
.5714 .25 L
.57141 .25 L
.57141 .25 L
.57142 .25 L
.57142 .25 L
.57143 .25 L
.57143 .25 L
.57144 .25 L
.57145 .25 L
.57145 .25 L
.57146 .25 L
.57147 .25 L
.57147 .25 L
.57148 .25 L
.57148 .25 L
.57149 .25 L
.5715 .25 L
.5715 .25 L
Mistroke
.57151 .25 L
.57152 .25 L
.57152 .25 L
.57153 .25 L
.57153 .25 L
.57154 .25 L
.57154 .25 L
.57155 .25 L
.57156 .25 L
.57156 .25 L
.57157 .25 L
.57157 .25 L
.57158 .25 L
.57158 .25 L
.57159 .25 L
.5716 .25 L
.5716 .25 L
.57161 .25 L
.57161 .25 L
.57162 .25 L
.57163 .25 L
.57163 .25 L
.57163 .25 L
.57164 .25 L
.57165 .25 L
.57165 .25 L
.57166 .25 L
.57166 .25 L
.57167 .25 L
.57167 .25 L
.57168 .25 L
.57169 .25 L
.57169 .25 L
.5717 .25 L
.5717 .25 L
.57171 .25 L
.57171 .25 L
.57172 .25 L
.57172 .25 L
.57173 .25 L
.57173 .25 L
.57174 .25 L
.57175 .25 L
.57175 .25 L
.57176 .25 L
.57176 .25 L
.57177 .25 L
.57178 .25 L
.57178 .25 L
.57179 .25 L
Mistroke
.57179 .25 L
.5718 .25 L
.57181 .25 L
.57181 .25 L
.57182 .25 L
.57182 .25 L
.57183 .25 L
.57184 .25 L
.57184 .25 L
.57185 .25 L
.57186 .25 L
.57186 .25 L
.57186 .25 L
.57187 .25 L
.57187 .25 L
.57188 .25 L
.57189 .25 L
.57189 .25 L
.5719 .25 L
.5719 .25 L
.57191 .25 L
.57192 .25 L
.57192 .25 L
.57193 .25 L
.57194 .25 L
.57194 .25 L
.57195 .25 L
.57196 .25 L
.57196 .25 L
.57197 .25 L
.57197 .25 L
.57198 .25 L
.57199 .25 L
.57199 .25 L
.572 .25 L
.572 .25 L
.572 .25 L
.57201 .25 L
.57201 .25 L
.57202 .25 L
.57202 .25 L
.57202 .25 L
.57203 .25 L
.57203 .25 L
.57204 .25 L
.57204 .25 L
.57204 .25 L
.57205 .25 L
.57205 .25 L
.57206 .25 L
Mistroke
.57207 .25 L
.57207 .25 L
.57208 .25 L
.57209 .25 L
.57209 .25 L
.5721 .25 L
.5721 .25 L
.57211 .25 L
.57212 .25 L
.57212 .25 L
.57213 .25 L
.57214 .25 L
.57214 .25 L
.57215 .25 L
.57215 .25 L
.57216 .25 L
.57216 .25 L
.57217 .25 L
.57218 .25 L
.57218 .25 L
.57219 .25 L
.57219 .25 L
.5722 .25 L
.57221 .25 L
.57221 .25 L
.57222 .25 L
.57222 .25 L
.57223 .25 L
.57224 .25 L
.57224 .25 L
.57225 .25 L
.57225 .25 L
.57226 .25 L
.57226 .25 L
.57227 .25 L
.57228 .25 L
.57228 .25 L
.57229 .25 L
.5723 .25 L
.5723 .25 L
.57231 .25 L
.57231 .25 L
.57232 .25 L
.57233 .25 L
.57233 .25 L
.57234 .25 L
.57235 .25 L
.57235 .25 L
.57235 .25 L
.57236 .25 L
Mistroke
.57237 .25 L
.57237 .25 L
.57238 .25 L
.57239 .25 L
.57239 .25 L
.5724 .25 L
.5724 .25 L
.57241 .25 L
.57241 .25 L
.57242 .25 L
.57243 .25 L
.57243 .25 L
.57244 .25 L
.57245 .25 L
.57245 .25 L
.57245 .25 L
.57246 .25 L
.57247 .25 L
.57247 .25 L
.57248 .25 L
.57248 .25 L
.57248 .25 L
.57249 .25 L
.5725 .25 L
.5725 .25 L
.57251 .25 L
.57252 .25 L
.57252 .25 L
.57253 .25 L
.57253 .25 L
.57254 .25 L
.57254 .25 L
.57254 .25 L
.57255 .25 L
.57256 .25 L
.57256 .25 L
.57257 .25 L
.57258 .25 L
.57258 .25 L
.57259 .25 L
.57259 .25 L
.5726 .25 L
.57261 .25 L
.57261 .25 L
.57262 .25 L
.57262 .25 L
.57263 .25 L
.57264 .25 L
.57264 .25 L
.57265 .25 L
Mistroke
.57266 .25 L
.57266 .25 L
.57267 .25 L
.57267 .25 L
.57268 .25 L
.57268 .25 L
.57269 .25 L
.57269 .25 L
.5727 .25 L
.5727 .25 L
.57271 .25 L
.57272 .25 L
.57272 .25 L
.57273 .25 L
.57273 .25 L
.57274 .25 L
.57275 .25 L
.57275 .25 L
.57276 .25 L
.57277 .25 L
.57277 .25 L
.57278 .25 L
.57279 .25 L
.57279 .25 L
.5728 .25 L
.5728 .25 L
.57281 .25 L
.57281 .25 L
.57282 .25 L
.57282 .25 L
.57283 .25 L
.57283 .25 L
.57283 .25 L
.57284 .25 L
.57284 .25 L
.57285 .25 L
.57285 .25 L
.57286 .25 L
.57286 .25 L
.57286 .25 L
.57287 .25 L
.57287 .25 L
.57288 .25 L
.57288 .25 L
.57289 .25 L
.5729 .25 L
.5729 .25 L
.57291 .25 L
.57292 .25 L
.57292 .25 L
Mistroke
.57293 .25 L
.57293 .25 L
.57294 .25 L
.57295 .25 L
.57295 .25 L
.57296 .25 L
.57297 .25 L
.57297 .25 L
.57297 .25 L
.57298 .25 L
.57299 .25 L
.57299 .25 L
.573 .25 L
.57301 .25 L
.57301 .25 L
.57302 .25 L
.57302 .25 L
.57303 .25 L
.57303 .25 L
.57304 .25 L
.57305 .25 L
.57305 .25 L
.57306 .25 L
.57307 .25 L
.57307 .25 L
.57307 .25 L
.57308 .25 L
.57309 .25 L
.57309 .25 L
.5731 .25 L
.57311 .25 L
.57311 .25 L
.57312 .25 L
.57312 .25 L
.57313 .25 L
.57314 .25 L
.57314 .25 L
.57315 .25 L
.57316 .25 L
.57316 .25 L
.57317 .25 L
.57317 .25 L
.57318 .25 L
.57318 .25 L
.57319 .25 L
.5732 .25 L
.5732 .25 L
.57321 .25 L
.57321 .25 L
.57322 .25 L
Mistroke
.57323 .25 L
.57323 .25 L
.57324 .25 L
.57324 .25 L
.57325 .25 L
.57326 .25 L
.57326 .25 L
.57327 .25 L
.57327 .25 L
.57328 .25 L
.57328 .25 L
.57329 .25 L
.57329 .25 L
.5733 .25 L
.57331 .25 L
.57331 .25 L
.57332 .25 L
.57333 .25 L
.57333 .25 L
.57334 .25 L
.57335 .25 L
.57335 .25 L
.57336 .25 L
.57336 .25 L
.57337 .25 L
.57338 .25 L
.57338 .25 L
.57339 .25 L
.57339 .25 L
.5734 .25 L
.5734 .25 L
.57341 .25 L
.57342 .25 L
.57342 .25 L
.57343 .25 L
.57343 .25 L
.57344 .25 L
.57345 .25 L
.57345 .25 L
.57346 .25 L
.57346 .25 L
.57347 .25 L
.57347 .25 L
.57348 .25 L
.57348 .25 L
.57349 .25 L
.5735 .25 L
.5735 .25 L
.5735 .25 L
.57351 .25 L
Mistroke
.57352 .25 L
.57352 .25 L
.57353 .25 L
.57353 .25 L
.57354 .25 L
.57355 .25 L
.57355 .25 L
.57356 .25 L
.57356 .25 L
.57357 .25 L
.57357 .25 L
.57358 .25 L
.57358 .25 L
.57359 .25 L
.5736 .25 L
.5736 .25 L
.57361 .25 L
.57361 .25 L
.57362 .25 L
.57362 .25 L
.57363 .25 L
.57364 .25 L
.57364 .25 L
.57365 .25 L
.57366 .25 L
.57366 .25 L
.57367 .25 L
.57367 .25 L
.57368 .25 L
.57369 .25 L
.57369 .25 L
.5737 .25 L
.57371 .25 L
.57371 .25 L
.57371 .25 L
.57372 .25 L
.57372 .25 L
.57373 .25 L
.57373 .25 L
.57374 .25 L
.57375 .25 L
.57375 .25 L
.57376 .25 L
.57377 .25 L
.57377 .25 L
.57378 .25 L
.57379 .25 L
.57379 .25 L
.5738 .25 L
.5738 .25 L
Mistroke
.57381 .25 L
.57382 .25 L
.57382 .25 L
.57383 .25 L
.57384 .25 L
.57384 .25 L
.57385 .25 L
.57385 .25 L
.57385 .25 L
.57386 .25 L
.57386 .25 L
.57387 .25 L
.57387 .25 L
.57387 .25 L
.57388 .25 L
.57388 .25 L
.57389 .25 L
.57389 .25 L
.57389 .25 L
.5739 .25 L
.5739 .25 L
.57391 .25 L
.57392 .25 L
.57392 .25 L
.57393 .25 L
.57394 .25 L
.57394 .25 L
.57395 .25 L
.57395 .25 L
.57396 .25 L
.57397 .25 L
.57397 .25 L
.57398 .25 L
.57399 .25 L
.57399 .25 L
.574 .25 L
.574 .25 L
.57401 .25 L
.57401 .25 L
.57402 .25 L
.57403 .25 L
.57403 .25 L
.57404 .25 L
.57404 .25 L
.57405 .25 L
.57406 .25 L
.57406 .25 L
.57407 .25 L
.57407 .25 L
.57408 .25 L
Mistroke
.57409 .25 L
.57409 .25 L
.5741 .25 L
.5741 .25 L
.57411 .25 L
.57411 .25 L
.57412 .25 L
.57413 .25 L
.57413 .25 L
.57414 .25 L
.57414 .25 L
.57415 .25 L
.57416 .25 L
.57416 .25 L
.57417 .25 L
.57418 .25 L
.57418 .25 L
.57419 .25 L
.5742 .25 L
.5742 .25 L
.5742 .25 L
.57421 .25 L
.57422 .25 L
.57422 .25 L
.57423 .25 L
.57424 .25 L
.57424 .25 L
.57425 .25 L
.57425 .25 L
.57426 .25 L
.57426 .25 L
.57427 .25 L
.57428 .25 L
.57428 .25 L
.57429 .25 L
.57429 .25 L
.5743 .25 L
.5743 .25 L
.57431 .25 L
.57431 .25 L
.57432 .25 L
.57433 .25 L
.57433 .25 L
.57433 .25 L
.57434 .25 L
.57435 .25 L
.57435 .25 L
.57436 .25 L
.57437 .25 L
.57437 .25 L
Mistroke
.57438 .25 L
.57438 .25 L
.57439 .25 L
.57439 .25 L
.57439 .25 L
.5744 .25 L
.57441 .25 L
.57441 .25 L
.57442 .25 L
.57443 .25 L
.57443 .25 L
.57444 .25 L
.57444 .25 L
.57445 .25 L
.57446 .25 L
.57446 .25 L
.57447 .25 L
.57447 .25 L
.57448 .25 L
.57449 .25 L
.57449 .25 L
.5745 .25 L
.57451 .25 L
.57451 .25 L
.57452 .25 L
.57452 .25 L
.57453 .25 L
.57453 .25 L
.57454 .25 L
.57454 .25 L
.57455 .25 L
.57455 .25 L
.57456 .25 L
.57457 .25 L
.57457 .25 L
.57458 .25 L
.57458 .25 L
.57459 .25 L
.5746 .25 L
.5746 .25 L
.57461 .25 L
.57462 .25 L
.57462 .25 L
.57463 .25 L
.57464 .25 L
.57464 .25 L
.57465 .25 L
.57466 .25 L
.57466 .25 L
.57466 .25 L
Mistroke
.57467 .25 L
.57467 .25 L
.57468 .25 L
.57468 .25 L
.57468 .25 L
.57469 .25 L
.57469 .25 L
.5747 .25 L
.5747 .25 L
.57471 .25 L
.57471 .25 L
.57471 .25 L
.57472 .25 L
.57472 .25 L
.57473 .25 L
.57473 .25 L
.57474 .25 L
.57475 .25 L
.57475 .25 L
.57476 .25 L
.57477 .25 L
.57477 .25 L
.57478 .25 L
.57478 .25 L
.57479 .25 L
.5748 .25 L
.5748 .25 L
.57481 .25 L
.57482 .25 L
.57482 .25 L
.57482 .25 L
.57483 .25 L
.57484 .25 L
.57484 .25 L
.57485 .25 L
.57486 .25 L
.57486 .25 L
.57487 .25 L
.57487 .25 L
.57488 .25 L
.57489 .25 L
.57489 .25 L
.5749 .25 L
.5749 .25 L
.57491 .25 L
.57492 .25 L
.57492 .25 L
.57492 .25 L
.57493 .25 L
.57494 .25 L
Mistroke
.57494 .25 L
.57495 .25 L
.57496 .25 L
.57496 .25 L
.57497 .25 L
.57497 .25 L
.57498 .25 L
.57499 .25 L
.57499 .25 L
.575 .25 L
.57501 .25 L
.57501 .25 L
.57502 .25 L
.57502 .25 L
.57503 .25 L
.57503 .25 L
.57504 .25 L
.57505 .25 L
.57505 .25 L
.57506 .25 L
.57507 .25 L
.57507 .25 L
.57508 .25 L
.57508 .25 L
.57509 .25 L
.57509 .25 L
.5751 .25 L
.57511 .25 L
.57511 .25 L
.57512 .25 L
.57512 .25 L
.57513 .25 L
.57513 .25 L
.57514 .25 L
.57515 .25 L
.57515 .25 L
.57515 .25 L
.57516 .25 L
.57517 .25 L
.57517 .25 L
.57518 .25 L
.57518 .25 L
.57519 .25 L
.5752 .25 L
.5752 .25 L
.5752 .25 L
.57521 .25 L
.57521 .25 L
.57522 .25 L
.57522 .25 L
Mistroke
.57523 .25 L
.57524 .25 L
.57524 .25 L
.57525 .25 L
.57526 .25 L
.57526 .25 L
.57527 .25 L
.57527 .25 L
.57528 .25 L
.57529 .25 L
.57529 .25 L
.5753 .25 L
.5753 .25 L
.57531 .25 L
.57532 .25 L
.57532 .25 L
.57533 .25 L
.57533 .25 L
.57534 .25 L
.57535 .25 L
.57535 .25 L
.57536 .25 L
.57536 .25 L
.57537 .25 L
.57537 .25 L
.57538 .25 L
.57538 .25 L
.57539 .25 L
.5754 .25 L
.5754 .25 L
.57541 .25 L
.57541 .25 L
.57542 .25 L
.57543 .25 L
.57543 .25 L
.57544 .25 L
.57545 .25 L
.57545 .25 L
.57546 .25 L
.57547 .25 L
.57547 .25 L
.57548 .25 L
.57548 .25 L
.57549 .25 L
.57549 .25 L
.5755 .25 L
.5755 .25 L
.5755 .25 L
.57551 .25 L
.57551 .25 L
Mistroke
.57552 .25 L
.57552 .25 L
.57553 .25 L
.57553 .25 L
.57553 .25 L
.57554 .25 L
.57554 .25 L
.57554 .25 L
.57555 .25 L
.57556 .25 L
.57556 .25 L
.57557 .25 L
.57558 .25 L
.57558 .25 L
.57559 .25 L
.5756 .25 L
.5756 .25 L
.57561 .25 L
.57561 .25 L
.57562 .25 L
.57563 .25 L
.57563 .25 L
.57564 .25 L
.57564 .25 L
.57565 .25 L
.57566 .25 L
.57566 .25 L
.57567 .25 L
.57567 .25 L
.57568 .25 L
.57569 .25 L
.57569 .25 L
.5757 .25 L
.5757 .25 L
.57571 .25 L
.57571 .25 L
.57572 .25 L
.57573 .25 L
.57573 .25 L
.57574 .25 L
.57574 .25 L
.57575 .25 L
.57575 .25 L
.57576 .25 L
.57577 .25 L
.57577 .25 L
.57578 .25 L
.57579 .25 L
.57579 .25 L
.5758 .25 L
Mistroke
.5758 .25 L
.57581 .25 L
.57582 .25 L
.57582 .25 L
.57583 .25 L
.57584 .25 L
.57584 .25 L
.57585 .25 L
.57585 .25 L
.57586 .25 L
.57586 .25 L
.57587 .25 L
.57588 .25 L
.57588 .25 L
.57589 .25 L
.57589 .25 L
.5759 .25 L
.57591 .25 L
.57591 .25 L
.57592 .25 L
.57592 .25 L
.57593 .25 L
.57594 .25 L
.57594 .25 L
.57595 .25 L
.57595 .25 L
.57596 .25 L
.57596 .25 L
.57597 .25 L
.57597 .25 L
.57598 .25 L
.57598 .25 L
.57599 .25 L
.57599 .25 L
.576 .25 L
.57601 .25 L
.57601 .25 L
.57602 .25 L
.57602 .25 L
.57603 .25 L
.57603 .25 L
.57604 .25 L
.57604 .25 L
.57605 .25 L
.57605 .25 L
.57606 .25 L
.57607 .25 L
.57607 .25 L
.57608 .25 L
.57608 .25 L
Mistroke
.57609 .25 L
.5761 .25 L
.5761 .25 L
.57611 .25 L
.57611 .25 L
.57612 .25 L
.57613 .25 L
.57613 .25 L
.57614 .25 L
.57615 .25 L
.57615 .25 L
.57616 .25 L
.57616 .25 L
.57617 .25 L
.57618 .25 L
.57618 .25 L
.57619 .25 L
.57619 .25 L
.57619 .25 L
.5762 .25 L
.57621 .25 L
.57621 .25 L
.57622 .25 L
.57623 .25 L
.57623 .25 L
.57624 .25 L
.57624 .25 L
.57625 .25 L
.57626 .25 L
.57626 .25 L
.57627 .25 L
.57628 .25 L
.57628 .25 L
.57629 .25 L
.5763 .25 L
.5763 .25 L
.57631 .25 L
.57631 .25 L
.57632 .25 L
.57632 .25 L
.57632 .25 L
.57633 .25 L
.57633 .25 L
.57634 .25 L
.57634 .25 L
.57635 .25 L
.57635 .25 L
.57635 .25 L
.57636 .25 L
.57636 .25 L
Mistroke
.57636 .25 L
.57637 .25 L
.57637 .25 L
.57638 .25 L
.57639 .25 L
.57639 .25 L
.5764 .25 L
.57641 .25 L
.57641 .25 L
.57642 .25 L
.57643 .25 L
.57643 .25 L
.57644 .25 L
.57644 .25 L
.57645 .25 L
.57646 .25 L
.57646 .25 L
.57647 .25 L
.57647 .25 L
.57648 .25 L
.57649 .25 L
.57649 .25 L
.5765 .25 L
.5765 .25 L
.57651 .25 L
.57652 .25 L
.57652 .25 L
.57653 .25 L
.57653 .25 L
.57654 .25 L
.57654 .25 L
.57655 .25 L
.57656 .25 L
.57656 .25 L
.57657 .25 L
.57657 .25 L
.57658 .25 L
.57658 .25 L
.57659 .25 L
.5766 .25 L
.5766 .25 L
.57661 .25 L
.57662 .25 L
.57662 .25 L
.57663 .25 L
.57663 .25 L
.57664 .25 L
.57665 .25 L
.57665 .25 L
.57666 .25 L
Mistroke
.57667 .25 L
.57667 .25 L
.57667 .25 L
.57668 .25 L
.57669 .25 L
.57669 .25 L
.5767 .25 L
.57671 .25 L
.57671 .25 L
.57672 .25 L
.57672 .25 L
.57673 .25 L
.57673 .25 L
.57674 .25 L
.57675 .25 L
.57675 .25 L
.57676 .25 L
.57677 .25 L
.57677 .25 L
.57677 .25 L
.57678 .25 L
.57679 .25 L
.57679 .25 L
.5768 .25 L
.57681 .25 L
.57681 .25 L
.57682 .25 L
.57682 .25 L
.57683 .25 L
.57684 .25 L
.57684 .25 L
.57685 .25 L
.57686 .25 L
.57686 .25 L
.57687 .25 L
.57687 .25 L
.57688 .25 L
.57688 .25 L
.57689 .25 L
.5769 .25 L
.5769 .25 L
.57691 .25 L
.57691 .25 L
.57692 .25 L
.57693 .25 L
.57693 .25 L
.57694 .25 L
.57694 .25 L
.57695 .25 L
.57696 .25 L
Mistroke
.57696 .25 L
.57697 .25 L
.57697 .25 L
.57698 .25 L
.57698 .25 L
.57699 .25 L
.57699 .25 L
.577 .25 L
.577 .25 L
.57701 .25 L
.57701 .25 L
.57702 .25 L
.57703 .25 L
.57703 .25 L
.57704 .25 L
.57705 .25 L
.57705 .25 L
.57705 .25 L
.57706 .25 L
.57706 .25 L
.57707 .25 L
.57707 .25 L
.57708 .25 L
.57709 .25 L
.57709 .25 L
.5771 .25 L
.5771 .25 L
.57711 .25 L
.57712 .25 L
.57712 .25 L
.57713 .25 L
.57713 .25 L
.57714 .25 L
.57715 .25 L
.57715 .25 L
.57716 .25 L
.57717 .25 L
.57717 .25 L
.57718 .25 L
.57718 .25 L
.57719 .25 L
.5772 .25 L
.5772 .25 L
.57721 .25 L
.57721 .25 L
.57722 .25 L
.57722 .25 L
.57723 .25 L
.57723 .25 L
.57724 .25 L
Mistroke
.57725 .25 L
.57725 .25 L
.57726 .25 L
.57726 .25 L
.57727 .25 L
.57728 .25 L
.57728 .25 L
.57729 .25 L
.5773 .25 L
.5773 .25 L
.57731 .25 L
.57732 .25 L
.57732 .25 L
.57733 .25 L
.57733 .25 L
.57734 .25 L
.57734 .25 L
.57735 .25 L
.57735 .25 L
.57735 .25 L
.57736 .25 L
.57736 .25 L
.57737 .25 L
.57737 .25 L
.57738 .25 L
.57738 .25 L
.57738 .25 L
.57739 .25 L
.57739 .25 L
.57739 .25 L
.5774 .25 L
.57741 .25 L
.57741 .25 L
.57742 .25 L
.57743 .25 L
.57743 .25 L
.57744 .25 L
.57745 .25 L
.57745 .25 L
.57746 .25 L
.57746 .25 L
.57747 .25 L
.57748 .25 L
.57748 .25 L
.57749 .25 L
.57749 .25 L
.5775 .25 L
.57751 .25 L
.57751 .25 L
.57752 .25 L
Mistroke
.57752 .25 L
.57753 .25 L
.57754 .25 L
.57754 .25 L
.57755 .25 L
.57755 .25 L
.57756 .25 L
.57756 .25 L
.57757 .25 L
.57758 .25 L
.57758 .25 L
.57759 .25 L
.57759 .25 L
.5776 .25 L
.5776 .25 L
.57761 .25 L
.57762 .25 L
.57762 .25 L
.57763 .25 L
.57764 .25 L
.57764 .25 L
.57765 .25 L
.57765 .25 L
.57766 .25 L
.57767 .25 L
.57767 .25 L
.57768 .25 L
.57769 .25 L
.57769 .25 L
.5777 .25 L
.5777 .25 L
.57771 .25 L
.57771 .25 L
.57772 .25 L
.57773 .25 L
.57773 .25 L
.57774 .25 L
.57774 .25 L
.57775 .25 L
.57776 .25 L
.57776 .25 L
.57777 .25 L
.57777 .25 L
.57778 .25 L
.57779 .25 L
.57779 .25 L
.5778 .25 L
.5778 .25 L
.57781 .25 L
.57781 .25 L
Mistroke
.57782 .25 L
.57782 .25 L
.57783 .25 L
.57783 .25 L
.57784 .25 L
.57784 .25 L
.57785 .25 L
.57786 .25 L
.57786 .25 L
.57787 .25 L
.57787 .25 L
.57788 .25 L
.57788 .25 L
.57789 .25 L
.57789 .25 L
.5779 .25 L
.5779 .25 L
.57791 .25 L
.57792 .25 L
.57792 .25 L
.57793 .25 L
.57793 .25 L
.57794 .25 L
.57795 .25 L
.57795 .25 L
.57796 .25 L
.57796 .25 L
.57797 .25 L
.57798 .25 L
.57798 .25 L
.57799 .25 L
.578 .25 L
.578 .25 L
.57801 .25 L
.57802 .25 L
.57802 .25 L
.57803 .25 L
.57803 .25 L
.57804 .25 L
.57804 .25 L
.57804 .25 L
.57805 .25 L
.57806 .25 L
.57806 .25 L
.57807 .25 L
.57808 .25 L
.57808 .25 L
.57809 .25 L
.57809 .25 L
.5781 .25 L
Mistroke
.57811 .25 L
.57811 .25 L
.57812 .25 L
.57813 .25 L
.57813 .25 L
.57814 .25 L
.57815 .25 L
.57815 .25 L
.57816 .25 L
.57816 .25 L
.57817 .25 L
.57817 .25 L
.57817 .25 L
.57818 .25 L
.57818 .25 L
.57819 .25 L
.57819 .25 L
.5782 .25 L
.5782 .25 L
.5782 .25 L
.57821 .25 L
.57821 .25 L
.57821 .25 L
.57822 .25 L
.57822 .25 L
.57823 .25 L
.57824 .25 L
.57824 .25 L
.57825 .25 L
.57826 .25 L
.57826 .25 L
.57827 .25 L
.57828 .25 L
.57828 .25 L
.57829 .25 L
.5783 .25 L
.5783 .25 L
.57831 .25 L
.57831 .25 L
.57832 .25 L
.57832 .25 L
.57833 .25 L
.57834 .25 L
.57834 .25 L
.57835 .25 L
.57835 .25 L
.57836 .25 L
.57837 .25 L
.57837 .25 L
.57838 .25 L
Mistroke
.57838 .25 L
.57839 .25 L
.5784 .25 L
.5784 .25 L
.57841 .25 L
.57841 .25 L
.57842 .25 L
.57842 .25 L
.57843 .25 L
.57843 .25 L
.57844 .25 L
.57845 .25 L
.57845 .25 L
.57846 .25 L
.57847 .25 L
.57847 .25 L
.57848 .25 L
.57848 .25 L
.57849 .25 L
.5785 .25 L
.5785 .25 L
.57851 .25 L
.57852 .25 L
.57852 .25 L
.57852 .25 L
.57853 .25 L
.57854 .25 L
.57854 .25 L
.57855 .25 L
.57856 .25 L
.57856 .25 L
.57857 .25 L
.57857 .25 L
.57858 .25 L
.57859 .25 L
.57859 .25 L
.5786 .25 L
.5786 .25 L
.57861 .25 L
.57862 .25 L
.57862 .25 L
.57862 .25 L
.57863 .25 L
.57864 .25 L
.57864 .25 L
.57865 .25 L
.57865 .25 L
.57866 .25 L
.57866 .25 L
.57867 .25 L
Mistroke
.57867 .25 L
.57868 .25 L
.57869 .25 L
.57869 .25 L
.5787 .25 L
.5787 .25 L
.57871 .25 L
.57871 .25 L
.57871 .25 L
.57872 .25 L
.57873 .25 L
.57873 .25 L
.57874 .25 L
.57875 .25 L
.57875 .25 L
.57876 .25 L
.57876 .25 L
.57877 .25 L
.57878 .25 L
.57878 .25 L
.57879 .25 L
.5788 .25 L
.5788 .25 L
.57881 .25 L
.57881 .25 L
.57882 .25 L
.57883 .25 L
.57883 .25 L
.57884 .25 L
.57885 .25 L
.57885 .25 L
.57886 .25 L
.57886 .25 L
.57886 .25 L
.57887 .25 L
.57887 .25 L
.57888 .25 L
.57889 .25 L
.57889 .25 L
.5789 .25 L
.57891 .25 L
.57891 .25 L
.57892 .25 L
.57892 .25 L
.57893 .25 L
.57894 .25 L
.57894 .25 L
.57895 .25 L
.57896 .25 L
.57896 .25 L
Mistroke
.57897 .25 L
.57898 .25 L
.57898 .25 L
.57898 .25 L
.57899 .25 L
.57899 .25 L
.579 .25 L
.579 .25 L
.57901 .25 L
.57901 .25 L
.57902 .25 L
.57902 .25 L
.57902 .25 L
.57903 .25 L
.57903 .25 L
.57903 .25 L
.57904 .25 L
.57904 .25 L
.57905 .25 L
.57906 .25 L
.57906 .25 L
.57907 .25 L
.57908 .25 L
.57908 .25 L
.57909 .25 L
.57909 .25 L
.5791 .25 L
.57911 .25 L
.57911 .25 L
.57912 .25 L
.57912 .25 L
.57913 .25 L
.57914 .25 L
.57914 .25 L
.57915 .25 L
.57915 .25 L
.57916 .25 L
.57917 .25 L
.57917 .25 L
.57918 .25 L
.57918 .25 L
.57919 .25 L
.57919 .25 L
.5792 .25 L
.57921 .25 L
.57921 .25 L
.57922 .25 L
.57923 .25 L
.57923 .25 L
.57924 .25 L
Mistroke
.57924 .25 L
.57924 .25 L
.57925 .25 L
.57926 .25 L
.57926 .25 L
.57927 .25 L
.57928 .25 L
.57928 .25 L
.57929 .25 L
.5793 .25 L
.5793 .25 L
.57931 .25 L
.57931 .25 L
.57932 .25 L
.57933 .25 L
.57933 .25 L
.57934 .25 L
.57934 .25 L
.57935 .25 L
.57936 .25 L
.57936 .25 L
.57937 .25 L
.57937 .25 L
.57938 .25 L
.57939 .25 L
.57939 .25 L
.5794 .25 L
.5794 .25 L
.57941 .25 L
.57941 .25 L
.57942 .25 L
.57943 .25 L
.57943 .25 L
.57944 .25 L
.57944 .25 L
.57945 .25 L
.57945 .25 L
.57946 .25 L
.57947 .25 L
.57947 .25 L
.57947 .25 L
.57948 .25 L
.57949 .25 L
.57949 .25 L
.5795 .25 L
.5795 .25 L
.57951 .25 L
.57952 .25 L
.57952 .25 L
.57952 .25 L
Mistroke
.57953 .25 L
.57953 .25 L
.57954 .25 L
.57954 .25 L
.57955 .25 L
.57956 .25 L
.57956 .25 L
.57957 .25 L
.57958 .25 L
.57958 .25 L
.57959 .25 L
.57959 .25 L
.5796 .25 L
.57961 .25 L
.57961 .25 L
.57962 .25 L
.57962 .25 L
.57963 .25 L
.57964 .25 L
.57964 .25 L
.57965 .25 L
.57966 .25 L
.57966 .25 L
.57967 .25 L
.57968 .25 L
.57968 .25 L
.57968 .25 L
.57969 .25 L
.57969 .25 L
.5797 .25 L
.5797 .25 L
.57971 .25 L
.57972 .25 L
.57972 .25 L
.57973 .25 L
.57974 .25 L
.57974 .25 L
.57975 .25 L
.57975 .25 L
.57976 .25 L
.57977 .25 L
.57977 .25 L
.57978 .25 L
.57979 .25 L
.57979 .25 L
.5798 .25 L
.5798 .25 L
.57981 .25 L
.57981 .25 L
.57982 .25 L
Mistroke
.57982 .25 L
.57982 .25 L
.57983 .25 L
.57984 .25 L
.57984 .25 L
.57984 .25 L
.57985 .25 L
.57985 .25 L
.57985 .25 L
.57986 .25 L
.57986 .25 L
.57987 .25 L
.57987 .25 L
.57988 .25 L
.57988 .25 L
.57989 .25 L
.5799 .25 L
.5799 .25 L
.57991 .25 L
.57992 .25 L
.57992 .25 L
.57993 .25 L
.57994 .25 L
.57994 .25 L
.57995 .25 L
.57995 .25 L
.57996 .25 L
.57997 .25 L
.57997 .25 L
.57998 .25 L
.57998 .25 L
.57999 .25 L
.57999 .25 L
.58 .25 L
.58001 .25 L
.58001 .25 L
.58002 .25 L
.58002 .25 L
.58003 .25 L
.58004 .25 L
.58004 .25 L
.58005 .25 L
.58005 .25 L
.58006 .25 L
.58006 .25 L
.58007 .25 L
.58007 .25 L
.58008 .25 L
.58009 .25 L
.58009 .25 L
Mistroke
.5801 .25 L
.58011 .25 L
.58011 .25 L
.58012 .25 L
.58012 .25 L
.58013 .25 L
.58014 .25 L
.58014 .25 L
.58015 .25 L
.58016 .25 L
.58016 .25 L
.58017 .25 L
.58017 .25 L
.58018 .25 L
.58019 .25 L
.58019 .25 L
.5802 .25 L
.5802 .25 L
.58021 .25 L
.58022 .25 L
.58022 .25 L
.58023 .25 L
.58023 .25 L
.58024 .25 L
.58024 .25 L
.58025 .25 L
.58026 .25 L
.58026 .25 L
.58027 .25 L
.58027 .25 L
.58028 .25 L
.58028 .25 L
.58029 .25 L
.5803 .25 L
.5803 .25 L
.58031 .25 L
.58031 .25 L
.58032 .25 L
.58033 .25 L
.58033 .25 L
.58034 .25 L
.58035 .25 L
.58035 .25 L
.58036 .25 L
.58037 .25 L
.58037 .25 L
.58037 .25 L
.58038 .25 L
.58039 .25 L
.58039 .25 L
Mistroke
.5804 .25 L
.58041 .25 L
.58041 .25 L
.58042 .25 L
.58042 .25 L
.58043 .25 L
.58043 .25 L
.58044 .25 L
.58045 .25 L
.58045 .25 L
.58046 .25 L
.58047 .25 L
.58047 .25 L
.58047 .25 L
.58048 .25 L
.58049 .25 L
.58049 .25 L
.5805 .25 L
.5805 .25 L
.58051 .25 L
.58051 .25 L
.58052 .25 L
.58052 .25 L
.58053 .25 L
.58054 .25 L
.58054 .25 L
.58055 .25 L
.58055 .25 L
.58056 .25 L
.58056 .25 L
.58056 .25 L
.58057 .25 L
.58058 .25 L
.58058 .25 L
.58059 .25 L
.5806 .25 L
.5806 .25 L
.58061 .25 L
.58061 .25 L
.58062 .25 L
.58063 .25 L
.58063 .25 L
.58064 .25 L
.58064 .25 L
.58065 .25 L
.58066 .25 L
.58066 .25 L
.58067 .25 L
.58068 .25 L
.58068 .25 L
Mistroke
.58069 .25 L
.5807 .25 L
.5807 .25 L
.58071 .25 L
.58071 .25 L
.58071 .25 L
.58072 .25 L
.58072 .25 L
.58073 .25 L
.58074 .25 L
.58074 .25 L
.58075 .25 L
.58076 .25 L
.58076 .25 L
.58077 .25 L
.58077 .25 L
.58078 .25 L
.58079 .25 L
.58079 .25 L
.5808 .25 L
.58081 .25 L
.58081 .25 L
.58082 .25 L
.58083 .25 L
.58083 .25 L
.58083 .25 L
.58084 .25 L
.58084 .25 L
.58085 .25 L
.58085 .25 L
.58085 .25 L
.58086 .25 L
.58087 .25 L
.58087 .25 L
.58087 .25 L
.58088 .25 L
.58088 .25 L
.58088 .25 L
.58089 .25 L
.58089 .25 L
.5809 .25 L
.5809 .25 L
.58091 .25 L
.58092 .25 L
.58093 .25 L
.58093 .25 L
.58094 .25 L
.58094 .25 L
.58095 .25 L
.58096 .25 L
Mistroke
.58096 .25 L
.58097 .25 L
.58097 .25 L
.58098 .25 L
.58099 .25 L
.58099 .25 L
.581 .25 L
.581 .25 L
.58101 .25 L
.58102 .25 L
.58102 .25 L
.58103 .25 L
.58103 .25 L
.58104 .25 L
.58104 .25 L
.58105 .25 L
.58106 .25 L
.58106 .25 L
.58107 .25 L
.58108 .25 L
.58108 .25 L
.58109 .25 L
.58109 .25 L
.58109 .25 L
.5811 .25 L
.58111 .25 L
.58111 .25 L
.58112 .25 L
.58113 .25 L
.58113 .25 L
.58114 .25 L
.58115 .25 L
.58115 .25 L
.58116 .25 L
.58116 .25 L
.58117 .25 L
.58118 .25 L
.58118 .25 L
.58119 .25 L
.58119 .25 L
.5812 .25 L
.58121 .25 L
.58121 .25 L
.58122 .25 L
.58122 .25 L
.58123 .25 L
.58124 .25 L
.58124 .25 L
.58125 .25 L
.58125 .25 L
Mistroke
.58126 .25 L
.58126 .25 L
.58127 .25 L
.58128 .25 L
.58128 .25 L
.58129 .25 L
.58129 .25 L
.5813 .25 L
.5813 .25 L
.58131 .25 L
.58132 .25 L
.58132 .25 L
.58132 .25 L
.58133 .25 L
.58134 .25 L
.58134 .25 L
.58135 .25 L
.58135 .25 L
.58136 .25 L
.58137 .25 L
.58137 .25 L
.58137 .25 L
.58138 .25 L
.58139 .25 L
.58139 .25 L
.5814 .25 L
.5814 .25 L
.58141 .25 L
.58141 .25 L
.58142 .25 L
.58143 .25 L
.58143 .25 L
.58144 .25 L
.58144 .25 L
.58145 .25 L
.58146 .25 L
.58146 .25 L
.58147 .25 L
.58148 .25 L
.58148 .25 L
.58149 .25 L
.58149 .25 L
.5815 .25 L
.58151 .25 L
.58151 .25 L
.58152 .25 L
.58153 .25 L
.58153 .25 L
.58153 .25 L
.58154 .25 L
Mistroke
.58154 .25 L
.58155 .25 L
.58155 .25 L
.58156 .25 L
.58157 .25 L
.58157 .25 L
.58158 .25 L
.58159 .25 L
.58159 .25 L
.5816 .25 L
.5816 .25 L
.58161 .25 L
.58162 .25 L
.58162 .25 L
.58163 .25 L
.58164 .25 L
.58164 .25 L
.58165 .25 L
.58165 .25 L
.58166 .25 L
.58166 .25 L
.58167 .25 L
.58167 .25 L
.58168 .25 L
.58168 .25 L
.58169 .25 L
.58169 .25 L
.58169 .25 L
.5817 .25 L
.5817 .25 L
.5817 .25 L
.58171 .25 L
.58171 .25 L
.58172 .25 L
.58172 .25 L
.58173 .25 L
.58174 .25 L
.58174 .25 L
.58175 .25 L
.58176 .25 L
.58176 .25 L
.58177 .25 L
.58177 .25 L
.58178 .25 L
.58179 .25 L
.58179 .25 L
.5818 .25 L
.58181 .25 L
.58181 .25 L
.58182 .25 L
Mistroke
.58182 .25 L
.58183 .25 L
.58183 .25 L
.58184 .25 L
.58185 .25 L
.58185 .25 L
.58186 .25 L
.58186 .25 L
.58187 .25 L
.58187 .25 L
.58188 .25 L
.58189 .25 L
.58189 .25 L
.5819 .25 L
.5819 .25 L
.58191 .25 L
.58191 .25 L
.58192 .25 L
.58192 .25 L
.58193 .25 L
.58194 .25 L
.58194 .25 L
.58195 .25 L
.58196 .25 L
.58196 .25 L
.58197 .25 L
.58198 .25 L
.58198 .25 L
.58199 .25 L
.582 .25 L
.582 .25 L
.58201 .25 L
.58201 .25 L
.58202 .25 L
.58202 .25 L
.58203 .25 L
.58204 .25 L
.58204 .25 L
.58205 .25 L
.58205 .25 L
.58206 .25 L
.58207 .25 L
.58207 .25 L
.58208 .25 L
.58208 .25 L
.58209 .25 L
.5821 .25 L
.5821 .25 L
.58211 .25 L
.58211 .25 L
Mistroke
.58212 .25 L
.58212 .25 L
.58213 .25 L
.58213 .25 L
.58214 .25 L
.58214 .25 L
.58215 .25 L
.58215 .25 L
.58216 .25 L
.58217 .25 L
.58217 .25 L
.58218 .25 L
.58218 .25 L
.58219 .25 L
.58219 .25 L
.5822 .25 L
.58221 .25 L
.58221 .25 L
.58221 .25 L
.58222 .25 L
.58223 .25 L
.58223 .25 L
.58224 .25 L
.58224 .25 L
.58225 .25 L
.58226 .25 L
.58226 .25 L
.58227 .25 L
.58227 .25 L
.58228 .25 L
.58229 .25 L
.58229 .25 L
.5823 .25 L
.5823 .25 L
.58231 .25 L
.58232 .25 L
.58232 .25 L
.58233 .25 L
.58234 .25 L
.58234 .25 L
.58235 .25 L
.58235 .25 L
.58236 .25 L
.58236 .25 L
.58236 .25 L
.58237 .25 L
.58238 .25 L
.58238 .25 L
.58239 .25 L
.5824 .25 L
Mistroke
.5824 .25 L
.58241 .25 L
.58241 .25 L
.58242 .25 L
.58243 .25 L
.58243 .25 L
.58244 .25 L
.58245 .25 L
.58245 .25 L
.58246 .25 L
.58247 .25 L
.58247 .25 L
.58248 .25 L
.58248 .25 L
.58249 .25 L
.58249 .25 L
.5825 .25 L
.5825 .25 L
.5825 .25 L
.58251 .25 L
.58251 .25 L
.58252 .25 L
.58252 .25 L
.58252 .25 L
.58253 .25 L
.58253 .25 L
.58254 .25 L
.58254 .25 L
.58255 .25 L
.58255 .25 L
.58256 .25 L
.58257 .25 L
.58257 .25 L
.58258 .25 L
.58259 .25 L
.58259 .25 L
.5826 .25 L
.5826 .25 L
.58261 .25 L
.58262 .25 L
.58262 .25 L
.58263 .25 L
.58264 .25 L
.58264 .25 L
.58264 .25 L
.58265 .25 L
.58266 .25 L
.58266 .25 L
.58267 .25 L
.58268 .25 L
Mistroke
.58268 .25 L
.58269 .25 L
.58269 .25 L
.5827 .25 L
.5827 .25 L
.58271 .25 L
.58272 .25 L
.58272 .25 L
.58273 .25 L
.58273 .25 L
.58274 .25 L
.58274 .25 L
.58275 .25 L
.58275 .25 L
.58276 .25 L
.58277 .25 L
.58278 .25 L
.58278 .25 L
.58279 .25 L
.58279 .25 L
.5828 .25 L
.58281 .25 L
.58281 .25 L
.58282 .25 L
.58282 .25 L
.58283 .25 L
.58284 .25 L
.58284 .25 L
.58285 .25 L
.58285 .25 L
.58286 .25 L
.58287 .25 L
.58287 .25 L
.58288 .25 L
.58288 .25 L
.58289 .25 L
.58289 .25 L
.5829 .25 L
.58291 .25 L
.58291 .25 L
.58292 .25 L
.58293 .25 L
.58293 .25 L
.58294 .25 L
.58294 .25 L
.58294 .25 L
.58295 .25 L
.58296 .25 L
.58296 .25 L
.58297 .25 L
Mistroke
.58297 .25 L
.58298 .25 L
.58298 .25 L
.58299 .25 L
.583 .25 L
.583 .25 L
.58301 .25 L
.58301 .25 L
.58302 .25 L
.58302 .25 L
.58303 .25 L
.58303 .25 L
.58304 .25 L
.58304 .25 L
.58305 .25 L
.58306 .25 L
.58306 .25 L
.58307 .25 L
.58307 .25 L
.58308 .25 L
.58308 .25 L
.58309 .25 L
.5831 .25 L
.5831 .25 L
.58311 .25 L
.58312 .25 L
.58312 .25 L
.58313 .25 L
.58313 .25 L
.58314 .25 L
.58315 .25 L
.58315 .25 L
.58316 .25 L
.58317 .25 L
.58317 .25 L
.58318 .25 L
.58318 .25 L
.58318 .25 L
.58319 .25 L
.58319 .25 L
.5832 .25 L
.58321 .25 L
.58321 .25 L
.58322 .25 L
.58323 .25 L
.58323 .25 L
.58324 .25 L
.58324 .25 L
.58325 .25 L
.58326 .25 L
Mistroke
.58326 .25 L
.58327 .25 L
.58328 .25 L
.58328 .25 L
.58329 .25 L
.5833 .25 L
.5833 .25 L
.5833 .25 L
.58331 .25 L
.58332 .25 L
.58332 .25 L
.58332 .25 L
.58333 .25 L
.58333 .25 L
.58334 .25 L
.58334 .25 L
.58334 .25 L
.58335 .25 L
.58335 .25 L
.58336 .25 L
.58336 .25 L
.58336 .25 L
.58337 .25 L
.58338 .25 L
.58338 .25 L
.58339 .25 L
.5834 .25 L
.5834 .25 L
.58341 .25 L
.58341 .25 L
.58342 .25 L
.58343 .25 L
.58343 .25 L
.58344 .25 L
.58345 .25 L
.58345 .25 L
.58346 .25 L
.58346 .25 L
.58347 .25 L
.58347 .25 L
.58348 .25 L
.58349 .25 L
.58349 .25 L
.5835 .25 L
.5835 .25 L
.58351 .25 L
.58352 .25 L
.58352 .25 L
.58353 .25 L
.58353 .25 L
Mistroke
.58354 .25 L
.58355 .25 L
.58355 .25 L
.58356 .25 L
.58356 .25 L
.58357 .25 L
.58357 .25 L
.58358 .25 L
.58358 .25 L
.58359 .25 L
.5836 .25 L
.5836 .25 L
.58361 .25 L
.58362 .25 L
.58362 .25 L
.58363 .25 L
.58364 .25 L
.58364 .25 L
.58365 .25 L
.58365 .25 L
.58366 .25 L
.58367 .25 L
.58367 .25 L
.58368 .25 L
.58368 .25 L
.58369 .25 L
.58369 .25 L
.5837 .25 L
.58371 .25 L
.58371 .25 L
.58372 .25 L
.58372 .25 L
.58373 .25 L
.58374 .25 L
.58374 .25 L
.58375 .25 L
.58375 .25 L
.58376 .25 L
.58376 .25 L
.58377 .25 L
.58377 .25 L
.58378 .25 L
.58379 .25 L
.58379 .25 L
.5838 .25 L
.58381 .25 L
.58381 .25 L
.58382 .25 L
.58383 .25 L
.58383 .25 L
Mistroke
.58384 .25 L
.58384 .25 L
.58385 .25 L
.58386 .25 L
.58386 .25 L
.58387 .25 L
.58387 .25 L
.58388 .25 L
.58389 .25 L
.58389 .25 L
.5839 .25 L
.5839 .25 L
.58391 .25 L
.58392 .25 L
.58392 .25 L
.58393 .25 L
.58393 .25 L
.58394 .25 L
.58395 .25 L
.58395 .25 L
.58396 .25 L
.58396 .25 L
.58397 .25 L
.58397 .25 L
.58398 .25 L
.58398 .25 L
.58399 .25 L
.58399 .25 L
.584 .25 L
.584 .25 L
.58401 .25 L
.58402 .25 L
.58402 .25 L
.58403 .25 L
.58403 .25 L
.58404 .25 L
.58404 .25 L
.58405 .25 L
.58405 .25 L
.58406 .25 L
.58406 .25 L
.58407 .25 L
.58408 .25 L
.58408 .25 L
.58409 .25 L
.58409 .25 L
.5841 .25 L
.58411 .25 L
.58411 .25 L
.58412 .25 L
Mistroke
.58412 .25 L
.58413 .25 L
.58414 .25 L
.58414 .25 L
.58415 .25 L
.58415 .25 L
.58416 .25 L
.58417 .25 L
.58417 .25 L
.58418 .25 L
.58419 .25 L
.58419 .25 L
.5842 .25 L
.5842 .25 L
.58421 .25 L
.58421 .25 L
.58421 .25 L
.58422 .25 L
.58423 .25 L
.58423 .25 L
.58424 .25 L
.58425 .25 L
.58425 .25 L
.58426 .25 L
.58426 .25 L
.58427 .25 L
.58428 .25 L
.58428 .25 L
.58429 .25 L
.5843 .25 L
.5843 .25 L
.58431 .25 L
.58432 .25 L
.58432 .25 L
.58433 .25 L
.58433 .25 L
.58434 .25 L
.58434 .25 L
.58435 .25 L
.58435 .25 L
.58435 .25 L
.58436 .25 L
.58436 .25 L
.58437 .25 L
.58437 .25 L
.58437 .25 L
.58438 .25 L
.58438 .25 L
.58439 .25 L
.58439 .25 L
Mistroke
.5844 .25 L
.5844 .25 L
.58441 .25 L
.58442 .25 L
.58442 .25 L
.58443 .25 L
.58444 .25 L
.58444 .25 L
.58445 .25 L
.58445 .25 L
.58446 .25 L
.58447 .25 L
.58447 .25 L
.58448 .25 L
.58449 .25 L
.58449 .25 L
.58449 .25 L
.5845 .25 L
.58451 .25 L
.58451 .25 L
.58452 .25 L
.58453 .25 L
.58453 .25 L
.58454 .25 L
.58454 .25 L
.58455 .25 L
.58455 .25 L
.58456 .25 L
.58457 .25 L
.58457 .25 L
.58458 .25 L
.58459 .25 L
.58459 .25 L
.58459 .25 L
.5846 .25 L
.58461 .25 L
.58461 .25 L
.58462 .25 L
.58463 .25 L
.58463 .25 L
.58464 .25 L
.58464 .25 L
.58465 .25 L
.58466 .25 L
.58466 .25 L
.58467 .25 L
.58468 .25 L
.58468 .25 L
.58469 .25 L
.58469 .25 L
Mistroke
.5847 .25 L
.5847 .25 L
.58471 .25 L
.58472 .25 L
.58472 .25 L
.58473 .25 L
.58473 .25 L
.58474 .25 L
.58475 .25 L
.58475 .25 L
.58476 .25 L
.58476 .25 L
.58477 .25 L
.58478 .25 L
.58478 .25 L
.58479 .25 L
.58479 .25 L
.58479 .25 L
.5848 .25 L
.58481 .25 L
.58481 .25 L
.58482 .25 L
.58482 .25 L
.58483 .25 L
.58483 .25 L
.58484 .25 L
.58485 .25 L
.58485 .25 L
.58486 .25 L
.58486 .25 L
.58487 .25 L
.58487 .25 L
.58488 .25 L
.58488 .25 L
.58489 .25 L
.58489 .25 L
.5849 .25 L
.58491 .25 L
.58491 .25 L
.58492 .25 L
.58492 .25 L
.58493 .25 L
.58494 .25 L
.58494 .25 L
.58495 .25 L
.58495 .25 L
.58496 .25 L
.58497 .25 L
.58497 .25 L
.58498 .25 L
Mistroke
.58498 .25 L
.58499 .25 L
.585 .25 L
.585 .25 L
.58501 .25 L
.58502 .25 L
.58502 .25 L
.58503 .25 L
.58503 .25 L
.58504 .25 L
.58504 .25 L
.58505 .25 L
.58505 .25 L
.58506 .25 L
.58507 .25 L
.58507 .25 L
.58508 .25 L
.58508 .25 L
.58509 .25 L
.5851 .25 L
.5851 .25 L
.58511 .25 L
.58512 .25 L
.58512 .25 L
.58513 .25 L
.58513 .25 L
.58514 .25 L
.58515 .25 L
.58515 .25 L
.58516 .25 L
.58516 .25 L
.58517 .25 L
.58517 .25 L
.58517 .25 L
.58518 .25 L
.58518 .25 L
.58519 .25 L
.58519 .25 L
.58519 .25 L
.5852 .25 L
.5852 .25 L
.58521 .25 L
.58521 .25 L
.58521 .25 L
.58522 .25 L
.58523 .25 L
.58523 .25 L
.58524 .25 L
.58525 .25 L
.58525 .25 L
Mistroke
.58526 .25 L
.58526 .25 L
.58527 .25 L
.58528 .25 L
.58528 .25 L
.58529 .25 L
.5853 .25 L
.5853 .25 L
.58531 .25 L
.58531 .25 L
.58532 .25 L
.58532 .25 L
.58533 .25 L
.58534 .25 L
.58534 .25 L
.58535 .25 L
.58536 .25 L
.58536 .25 L
.58537 .25 L
.58537 .25 L
.58538 .25 L
.58538 .25 L
.58539 .25 L
.5854 .25 L
.5854 .25 L
.58541 .25 L
.58541 .25 L
.58542 .25 L
.58542 .25 L
.58543 .25 L
.58544 .25 L
.58544 .25 L
.58545 .25 L
.58546 .25 L
.58546 .25 L
.58547 .25 L
.58547 .25 L
.58548 .25 L
.58549 .25 L
.58549 .25 L
.5855 .25 L
.58551 .25 L
.58551 .25 L
.58552 .25 L
.58552 .25 L
.58553 .25 L
.58553 .25 L
.58554 .25 L
.58555 .25 L
.58555 .25 L
Mistroke
.58556 .25 L
.58556 .25 L
.58557 .25 L
.58558 .25 L
.58558 .25 L
.58559 .25 L
.58559 .25 L
.5856 .25 L
.58561 .25 L
.58561 .25 L
.58562 .25 L
.58562 .25 L
.58563 .25 L
.58563 .25 L
.58564 .25 L
.58564 .25 L
.58565 .25 L
.58565 .25 L
.58566 .25 L
.58566 .25 L
.58567 .25 L
.58568 .25 L
.58568 .25 L
.58569 .25 L
.58569 .25 L
.5857 .25 L
.5857 .25 L
.58571 .25 L
.58571 .25 L
.58572 .25 L
.58572 .25 L
.58573 .25 L
.58574 .25 L
.58574 .25 L
.58575 .25 L
.58575 .25 L
.58576 .25 L
.58577 .25 L
.58577 .25 L
.58578 .25 L
.58578 .25 L
.58579 .25 L
.5858 .25 L
.5858 .25 L
.58581 .25 L
.58582 .25 L
.58582 .25 L
.58583 .25 L
.58583 .25 L
.58584 .25 L
Mistroke
.58585 .25 L
.58585 .25 L
.58586 .25 L
.58586 .25 L
.58586 .25 L
.58587 .25 L
.58588 .25 L
.58588 .25 L
.58589 .25 L
.5859 .25 L
.5859 .25 L
.58591 .25 L
.58591 .25 L
.58592 .25 L
.58593 .25 L
.58593 .25 L
.58594 .25 L
.58595 .25 L
.58595 .25 L
.58596 .25 L
.58596 .25 L
.58597 .25 L
.58598 .25 L
.58598 .25 L
.58599 .25 L
.58599 .25 L
.58599 .25 L
.586 .25 L
.586 .25 L
.58601 .25 L
.58601 .25 L
.58601 .25 L
.58602 .25 L
.58602 .25 L
.58603 .25 L
.58603 .25 L
.58603 .25 L
.58604 .25 L
.58604 .25 L
.58605 .25 L
.58606 .25 L
.58606 .25 L
.58607 .25 L
.58608 .25 L
.58608 .25 L
.58609 .25 L
.58609 .25 L
.5861 .25 L
.58611 .25 L
.58611 .25 L
Mistroke
.58612 .25 L
.58613 .25 L
.58613 .25 L
.58614 .25 L
.58614 .25 L
.58615 .25 L
.58616 .25 L
.58616 .25 L
.58617 .25 L
.58617 .25 L
.58618 .25 L
.58619 .25 L
.58619 .25 L
.5862 .25 L
.5862 .25 L
.58621 .25 L
.58621 .25 L
.58622 .25 L
.58623 .25 L
.58623 .25 L
.58624 .25 L
.58624 .25 L
.58625 .25 L
.58625 .25 L
.58626 .25 L
.58627 .25 L
.58627 .25 L
.58628 .25 L
.58629 .25 L
.58629 .25 L
.5863 .25 L
.5863 .25 L
.58631 .25 L
.58632 .25 L
.58632 .25 L
.58633 .25 L
.58634 .25 L
.58634 .25 L
.58634 .25 L
.58635 .25 L
.58636 .25 L
.58636 .25 L
.58637 .25 L
.58638 .25 L
.58638 .25 L
.58639 .25 L
.58639 .25 L
.5864 .25 L
.5864 .25 L
.58641 .25 L
Mistroke
.58642 .25 L
.58642 .25 L
.58643 .25 L
.58644 .25 L
.58644 .25 L
.58644 .25 L
.58645 .25 L
.58646 .25 L
.58646 .25 L
.58647 .25 L
.58647 .25 L
.58648 .25 L
.58648 .25 L
.58649 .25 L
.58649 .25 L
.5865 .25 L
.58651 .25 L
.58651 .25 L
.58652 .25 L
.58652 .25 L
.58653 .25 L
.58653 .25 L
.58653 .25 L
.58654 .25 L
.58655 .25 L
.58655 .25 L
.58656 .25 L
.58657 .25 L
.58657 .25 L
.58658 .25 L
.58658 .25 L
.58659 .25 L
.5866 .25 L
.5866 .25 L
.58661 .25 L
.58661 .25 L
.58662 .25 L
.58663 .25 L
.58663 .25 L
.58664 .25 L
.58665 .25 L
.58665 .25 L
.58666 .25 L
.58667 .25 L
.58667 .25 L
.58667 .25 L
.58668 .25 L
.58668 .25 L
.58669 .25 L
.58669 .25 L
Mistroke
.5867 .25 L
.58671 .25 L
.58671 .25 L
.58672 .25 L
.58673 .25 L
.58673 .25 L
.58674 .25 L
.58674 .25 L
.58675 .25 L
.58676 .25 L
.58676 .25 L
.58677 .25 L
.58678 .25 L
.58678 .25 L
.58679 .25 L
.5868 .25 L
.5868 .25 L
.5868 .25 L
.58681 .25 L
.58681 .25 L
.58682 .25 L
.58682 .25 L
.58682 .25 L
.58683 .25 L
.58683 .25 L
.58684 .25 L
.58684 .25 L
.58685 .25 L
.58685 .25 L
.58685 .25 L
.58686 .25 L
.58686 .25 L
.58687 .25 L
.58687 .25 L
.58688 .25 L
.58689 .25 L
.58689 .25 L
.5869 .25 L
.58691 .25 L
.58691 .25 L
.58692 .25 L
.58692 .25 L
.58693 .25 L
.58694 .25 L
.58694 .25 L
.58695 .25 L
.58696 .25 L
.58696 .25 L
.58697 .25 L
.58697 .25 L
Mistroke
.58698 .25 L
.58698 .25 L
.58699 .25 L
.587 .25 L
.587 .25 L
.58701 .25 L
.58701 .25 L
.58702 .25 L
.58703 .25 L
.58703 .25 L
.58704 .25 L
.58704 .25 L
.58705 .25 L
.58706 .25 L
.58706 .25 L
.58706 .25 L
.58707 .25 L
.58708 .25 L
.58708 .25 L
.58709 .25 L
.5871 .25 L
.5871 .25 L
.58711 .25 L
.58711 .25 L
.58712 .25 L
.58713 .25 L
.58713 .25 L
.58714 .25 L
.58715 .25 L
.58715 .25 L
.58716 .25 L
.58716 .25 L
.58717 .25 L
.58717 .25 L
.58718 .25 L
.58719 .25 L
.58719 .25 L
.5872 .25 L
.58721 .25 L
.58721 .25 L
.58722 .25 L
.58722 .25 L
.58723 .25 L
.58723 .25 L
.58724 .25 L
.58725 .25 L
.58725 .25 L
.58726 .25 L
.58726 .25 L
.58727 .25 L
Mistroke
.58727 .25 L
.58728 .25 L
.58729 .25 L
.58729 .25 L
.58729 .25 L
.5873 .25 L
.58731 .25 L
.58731 .25 L
.58732 .25 L
.58732 .25 L
.58733 .25 L
.58734 .25 L
.58734 .25 L
.58734 .25 L
.58735 .25 L
.58735 .25 L
.58736 .25 L
.58736 .25 L
.58737 .25 L
.58738 .25 L
.58738 .25 L
.58739 .25 L
.5874 .25 L
.5874 .25 L
.58741 .25 L
.58741 .25 L
.58742 .25 L
.58743 .25 L
.58743 .25 L
.58744 .25 L
.58744 .25 L
.58745 .25 L
.58746 .25 L
.58746 .25 L
.58747 .25 L
.58747 .25 L
.58748 .25 L
.58749 .25 L
.58749 .25 L
.5875 .25 L
.5875 .25 L
.58751 .25 L
.58751 .25 L
.58752 .25 L
.58752 .25 L
.58753 .25 L
.58754 .25 L
.58754 .25 L
.58755 .25 L
.58755 .25 L
Mistroke
.58756 .25 L
.58757 .25 L
.58757 .25 L
.58758 .25 L
.58759 .25 L
.58759 .25 L
.5876 .25 L
.58761 .25 L
.58761 .25 L
.58762 .25 L
.58762 .25 L
.58763 .25 L
.58763 .25 L
.58764 .25 L
.58764 .25 L
.58764 .25 L
.58765 .25 L
.58765 .25 L
.58766 .25 L
.58766 .25 L
.58767 .25 L
.58767 .25 L
.58767 .25 L
.58768 .25 L
.58768 .25 L
.58768 .25 L
.58769 .25 L
.5877 .25 L
.5877 .25 L
.58771 .25 L
.58772 .25 L
.58772 .25 L
.58773 .25 L
.58774 .25 L
.58774 .25 L
.58775 .25 L
.58775 .25 L
.58776 .25 L
.58777 .25 L
.58777 .25 L
.58778 .25 L
.58778 .25 L
.58779 .25 L
.5878 .25 L
.5878 .25 L
.58781 .25 L
.58781 .25 L
.58782 .25 L
.58783 .25 L
.58783 .25 L
Mistroke
.58784 .25 L
.58784 .25 L
.58785 .25 L
.58785 .25 L
.58786 .25 L
.58787 .25 L
.58787 .25 L
.58788 .25 L
.58788 .25 L
.58789 .25 L
.58789 .25 L
.5879 .25 L
.58791 .25 L
.58791 .25 L
.58792 .25 L
.58793 .25 L
.58793 .25 L
.58794 .25 L
.58794 .25 L
.58795 .25 L
.58796 .25 L
.58796 .25 L
.58797 .25 L
.58798 .25 L
.58798 .25 L
.58799 .25 L
.58799 .25 L
.588 .25 L
.588 .25 L
.58801 .25 L
.58802 .25 L
.58802 .25 L
.58803 .25 L
.58803 .25 L
.58804 .25 L
.58805 .25 L
.58805 .25 L
.58806 .25 L
.58806 .25 L
.58807 .25 L
.58808 .25 L
.58808 .25 L
.58809 .25 L
.58809 .25 L
.5881 .25 L
.5881 .25 L
.58811 .25 L
.58812 .25 L
.58812 .25 L
.58813 .25 L
Mistroke
.58813 .25 L
.58814 .25 L
.58815 .25 L
.58815 .25 L
.58816 .25 L
.58817 .25 L
.58817 .25 L
.58818 .25 L
.58819 .25 L
.58819 .25 L
.58819 .25 L
.5882 .25 L
.58821 .25 L
.58821 .25 L
.58822 .25 L
.58823 .25 L
.58823 .25 L
.58824 .25 L
.58824 .25 L
.58825 .25 L
.58825 .25 L
.58826 .25 L
.58827 .25 L
.58827 .25 L
.58828 .25 L
.58828 .25 L
.58829 .25 L
.58829 .25 L
.5883 .25 L
.5883 .25 L
.58831 .25 L
.58831 .25 L
.58832 .25 L
.58832 .25 L
.58833 .25 L
.58834 .25 L
.58834 .25 L
.58835 .25 L
.58836 .25 L
.58836 .25 L
.58837 .25 L
.58837 .25 L
.58838 .25 L
.58838 .25 L
.58838 .25 L
.58839 .25 L
.5884 .25 L
.5884 .25 L
.58841 .25 L
.58842 .25 L
Mistroke
.58842 .25 L
.58843 .25 L
.58843 .25 L
.58844 .25 L
.58845 .25 L
.58845 .25 L
.58846 .25 L
.58846 .25 L
.58847 .25 L
.58848 .25 L
.58848 .25 L
.58849 .25 L
.5885 .25 L
.5885 .25 L
.58851 .25 L
.58851 .25 L
.58852 .25 L
.58852 .25 L
.58853 .25 L
.58853 .25 L
.58854 .25 L
.58854 .25 L
.58855 .25 L
.58856 .25 L
.58856 .25 L
.58857 .25 L
.58857 .25 L
.58858 .25 L
.58859 .25 L
.58859 .25 L
.5886 .25 L
.58861 .25 L
.58861 .25 L
.58862 .25 L
.58863 .25 L
.58863 .25 L
.58864 .25 L
.58864 .25 L
.58865 .25 L
.58865 .25 L
.58866 .25 L
.58866 .25 L
.58867 .25 L
.58867 .25 L
.58867 .25 L
.58868 .25 L
.58868 .25 L
.58869 .25 L
.58869 .25 L
.5887 .25 L
Mistroke
.5887 .25 L
.5887 .25 L
.58871 .25 L
.58871 .25 L
.58872 .25 L
.58872 .25 L
.58873 .25 L
.58874 .25 L
.58874 .25 L
.58875 .25 L
.58876 .25 L
.58876 .25 L
.58877 .25 L
.58877 .25 L
.58878 .25 L
.58879 .25 L
.58879 .25 L
.5888 .25 L
.58881 .25 L
.58881 .25 L
.58881 .25 L
.58882 .25 L
.58883 .25 L
.58883 .25 L
.58884 .25 L
.58885 .25 L
.58885 .25 L
.58886 .25 L
.58886 .25 L
.58887 .25 L
.58888 .25 L
.58888 .25 L
.58889 .25 L
.58889 .25 L
.5889 .25 L
.58891 .25 L
.58891 .25 L
.58891 .25 L
.58892 .25 L
.58893 .25 L
.58893 .25 L
.58894 .25 L
.58895 .25 L
.58895 .25 L
.58896 .25 L
.58896 .25 L
.58897 .25 L
.58898 .25 L
.58898 .25 L
.58899 .25 L
Mistroke
.589 .25 L
.589 .25 L
.58901 .25 L
.58901 .25 L
.58902 .25 L
.58902 .25 L
.58903 .25 L
.58904 .25 L
.58904 .25 L
.58905 .25 L
.58906 .25 L
.58906 .25 L
.58907 .25 L
.58907 .25 L
.58908 .25 L
.58908 .25 L
.58909 .25 L
.5891 .25 L
.5891 .25 L
.58911 .25 L
.58911 .25 L
.58912 .25 L
.58912 .25 L
.58913 .25 L
.58914 .25 L
.58914 .25 L
.58914 .25 L
.58915 .25 L
.58916 .25 L
.58916 .25 L
.58917 .25 L
.58917 .25 L
.58918 .25 L
.58919 .25 L
.58919 .25 L
.58919 .25 L
.5892 .25 L
.5892 .25 L
.58921 .25 L
.58921 .25 L
.58922 .25 L
.58923 .25 L
.58923 .25 L
.58924 .25 L
.58925 .25 L
.58925 .25 L
.58926 .25 L
.58926 .25 L
.58927 .25 L
.58928 .25 L
Mistroke
.58928 .25 L
.58929 .25 L
.58929 .25 L
.5893 .25 L
.58931 .25 L
.58931 .25 L
.58932 .25 L
.58932 .25 L
.58933 .25 L
.58934 .25 L
.58934 .25 L
.58935 .25 L
.58935 .25 L
.58936 .25 L
.58936 .25 L
.58937 .25 L
.58937 .25 L
.58938 .25 L
.58939 .25 L
.58939 .25 L
.5894 .25 L
.5894 .25 L
.58941 .25 L
.58942 .25 L
.58942 .25 L
.58943 .25 L
.58944 .25 L
.58944 .25 L
.58945 .25 L
.58946 .25 L
.58946 .25 L
.58947 .25 L
.58947 .25 L
.58948 .25 L
.58948 .25 L
.58949 .25 L
.58949 .25 L
.58949 .25 L
.5895 .25 L
.5895 .25 L
.58951 .25 L
.58951 .25 L
.58952 .25 L
.58952 .25 L
.58952 .25 L
.58953 .25 L
.58953 .25 L
.58953 .25 L
.58954 .25 L
.58955 .25 L
Mistroke
.58955 .25 L
.58956 .25 L
.58957 .25 L
.58957 .25 L
.58958 .25 L
.58959 .25 L
.58959 .25 L
.5896 .25 L
.5896 .25 L
.58961 .25 L
.58962 .25 L
.58962 .25 L
.58963 .25 L
.58963 .25 L
.58964 .25 L
.58965 .25 L
.58965 .25 L
.58966 .25 L
.58966 .25 L
.58967 .25 L
.58968 .25 L
.58968 .25 L
.58969 .25 L
.58969 .25 L
.5897 .25 L
.58971 .25 L
.58971 .25 L
.58972 .25 L
.58972 .25 L
.58973 .25 L
.58973 .25 L
.58974 .25 L
.58974 .25 L
.58975 .25 L
.58976 .25 L
.58976 .25 L
.58977 .25 L
.58978 .25 L
.58978 .25 L
.58979 .25 L
.58979 .25 L
.5898 .25 L
.58981 .25 L
.58981 .25 L
.58982 .25 L
.58983 .25 L
.58983 .25 L
.58984 .25 L
.58984 .25 L
.58985 .25 L
Mistroke
.58985 .25 L
.58986 .25 L
.58987 .25 L
.58987 .25 L
.58988 .25 L
.58988 .25 L
.58989 .25 L
.5899 .25 L
.5899 .25 L
.58991 .25 L
.58991 .25 L
.58992 .25 L
.58993 .25 L
.58993 .25 L
.58994 .25 L
.58994 .25 L
.58995 .25 L
.58995 .25 L
.58996 .25 L
.58996 .25 L
.58997 .25 L
.58997 .25 L
.58998 .25 L
.58998 .25 L
.58999 .25 L
.59 .25 L
.59 .25 L
.59001 .25 L
.59001 .25 L
.59002 .25 L
.59002 .25 L
.59003 .25 L
.59003 .25 L
.59004 .25 L
.59004 .25 L
.59005 .25 L
.59006 .25 L
.59006 .25 L
.59007 .25 L
.59007 .25 L
.59008 .25 L
.59009 .25 L
.59009 .25 L
.5901 .25 L
.5901 .25 L
.59011 .25 L
.59012 .25 L
.59012 .25 L
.59013 .25 L
.59014 .25 L
Mistroke
.59014 .25 L
.59015 .25 L
.59016 .25 L
.59016 .25 L
.59017 .25 L
.59017 .25 L
.59018 .25 L
.59018 .25 L
.59018 .25 L
.59019 .25 L
.5902 .25 L
.5902 .25 L
.59021 .25 L
.59022 .25 L
.59022 .25 L
.59023 .25 L
.59023 .25 L
.59024 .25 L
.59025 .25 L
.59025 .25 L
.59026 .25 L
.59027 .25 L
.59027 .25 L
.59028 .25 L
.59029 .25 L
.59029 .25 L
.5903 .25 L
.5903 .25 L
.59031 .25 L
.59031 .25 L
.59031 .25 L
.59032 .25 L
.59032 .25 L
.59033 .25 L
.59033 .25 L
.59034 .25 L
.59034 .25 L
.59034 .25 L
.59035 .25 L
.59035 .25 L
.59035 .25 L
.59036 .25 L
.59036 .25 L
.59037 .25 L
.59038 .25 L
.59038 .25 L
.59039 .25 L
.5904 .25 L
.5904 .25 L
.59041 .25 L
Mistroke
.59042 .25 L
.59042 .25 L
.59043 .25 L
.59044 .25 L
.59044 .25 L
.59045 .25 L
.59045 .25 L
.59046 .25 L
.59046 .25 L
.59047 .25 L
.59048 .25 L
.59048 .25 L
.59049 .25 L
.59049 .25 L
.5905 .25 L
.59051 .25 L
.59051 .25 L
.59052 .25 L
.59052 .25 L
.59053 .25 L
.59054 .25 L
.59054 .25 L
.59055 .25 L
.59055 .25 L
.59056 .25 L
.59056 .25 L
.59057 .25 L
.59057 .25 L
.59058 .25 L
.59059 .25 L
.59059 .25 L
.5906 .25 L
.59061 .25 L
.59061 .25 L
.59062 .25 L
.59062 .25 L
.59063 .25 L
.59064 .25 L
.59064 .25 L
.59065 .25 L
.59066 .25 L
.59066 .25 L
.59066 .25 L
.59067 .25 L
.59068 .25 L
.59068 .25 L
.59069 .25 L
.5907 .25 L
.5907 .25 L
.59071 .25 L
Mistroke
.59071 .25 L
.59072 .25 L
.59072 .25 L
.59073 .25 L
.59074 .25 L
.59074 .25 L
.59075 .25 L
.59076 .25 L
.59076 .25 L
.59076 .25 L
.59077 .25 L
.59078 .25 L
.59078 .25 L
.59079 .25 L
.59079 .25 L
.5908 .25 L
.5908 .25 L
.59081 .25 L
.59081 .25 L
.59082 .25 L
.59083 .25 L
.59083 .25 L
.59084 .25 L
.59084 .25 L
.59085 .25 L
.59085 .25 L
.59085 .25 L
.59086 .25 L
.59087 .25 L
.59087 .25 L
.59088 .25 L
.59089 .25 L
.59089 .25 L
.5909 .25 L
.5909 .25 L
.59091 .25 L
.59092 .25 L
.59092 .25 L
.59093 .25 L
.59093 .25 L
.59094 .25 L
.59095 .25 L
.59095 .25 L
.59096 .25 L
.59097 .25 L
.59097 .25 L
.59098 .25 L
.59099 .25 L
.59099 .25 L
.591 .25 L
Mistroke
.591 .25 L
.591 .25 L
.59101 .25 L
.59101 .25 L
.59102 .25 L
.59103 .25 L
.59103 .25 L
.59104 .25 L
.59105 .25 L
.59105 .25 L
.59106 .25 L
.59106 .25 L
.59107 .25 L
.59108 .25 L
.59108 .25 L
.59109 .25 L
.5911 .25 L
.5911 .25 L
.59111 .25 L
.59112 .25 L
.59112 .25 L
.59112 .25 L
.59113 .25 L
.59113 .25 L
.59114 .25 L
.59114 .25 L
.59114 .25 L
.59115 .25 L
.59116 .25 L
.59116 .25 L
.59116 .25 L
.59117 .25 L
.59117 .25 L
.59117 .25 L
.59118 .25 L
.59118 .25 L
.59119 .25 L
.59119 .25 L
.5912 .25 L
.59121 .25 L
.59121 .25 L
.59122 .25 L
.59123 .25 L
.59123 .25 L
.59124 .25 L
.59124 .25 L
.59125 .25 L
.59126 .25 L
.59126 .25 L
.59127 .25 L
Mistroke
.59128 .25 L
.59128 .25 L
.59129 .25 L
.59129 .25 L
.5913 .25 L
.5913 .25 L
.59131 .25 L
.59132 .25 L
.59132 .25 L
.59133 .25 L
.59133 .25 L
.59134 .25 L
.59135 .25 L
.59135 .25 L
.59136 .25 L
.59136 .25 L
.59137 .25 L
.59138 .25 L
.59138 .25 L
.59138 .25 L
.59139 .25 L
.5914 .25 L
.5914 .25 L
.59141 .25 L
.59142 .25 L
.59142 .25 L
.59143 .25 L
.59143 .25 L
.59144 .25 L
.59145 .25 L
.59145 .25 L
.59146 .25 L
.59147 .25 L
.59147 .25 L
.59148 .25 L
.59148 .25 L
.59149 .25 L
.59149 .25 L
.5915 .25 L
.59151 .25 L
.59151 .25 L
.59152 .25 L
.59153 .25 L
.59153 .25 L
.59154 .25 L
.59154 .25 L
.59155 .25 L
.59155 .25 L
.59156 .25 L
.59157 .25 L
Mistroke
.59157 .25 L
.59158 .25 L
.59158 .25 L
.59159 .25 L
.59159 .25 L
.5916 .25 L
.59161 .25 L
.59161 .25 L
.59162 .25 L
.59163 .25 L
.59163 .25 L
.59164 .25 L
.59164 .25 L
.59165 .25 L
.59166 .25 L
.59166 .25 L
.59167 .25 L
.59168 .25 L
.59168 .25 L
.59169 .25 L
.59169 .25 L
.5917 .25 L
.5917 .25 L
.59171 .25 L
.59172 .25 L
.59172 .25 L
.59173 .25 L
.59173 .25 L
.59174 .25 L
.59175 .25 L
.59175 .25 L
.59176 .25 L
.59176 .25 L
.59177 .25 L
.59178 .25 L
.59178 .25 L
.59179 .25 L
.59179 .25 L
.5918 .25 L
.5918 .25 L
.59181 .25 L
.59181 .25 L
.59182 .25 L
.59182 .25 L
.59183 .25 L
.59183 .25 L
.59184 .25 L
.59185 .25 L
.59185 .25 L
.59186 .25 L
Mistroke
.59186 .25 L
.59187 .25 L
.59187 .25 L
.59188 .25 L
.59188 .25 L
.59189 .25 L
.59189 .25 L
.5919 .25 L
.59191 .25 L
.59191 .25 L
.59192 .25 L
.59192 .25 L
.59193 .25 L
.59194 .25 L
.59194 .25 L
.59195 .25 L
.59195 .25 L
.59196 .25 L
.59197 .25 L
.59197 .25 L
.59198 .25 L
.59199 .25 L
.59199 .25 L
.592 .25 L
.592 .25 L
.59201 .25 L
.59202 .25 L
.59202 .25 L
.59203 .25 L
.59203 .25 L
.59203 .25 L
.59204 .25 L
.59205 .25 L
.59205 .25 L
.59206 .25 L
.59207 .25 L
.59207 .25 L
.59208 .25 L
.59208 .25 L
.59209 .25 L
.5921 .25 L
.5921 .25 L
.59211 .25 L
.59212 .25 L
.59212 .25 L
.59213 .25 L
.59214 .25 L
.59214 .25 L
.59215 .25 L
.59215 .25 L
Mistroke
.59216 .25 L
.59216 .25 L
.59216 .25 L
.59217 .25 L
.59217 .25 L
.59218 .25 L
.59218 .25 L
.59219 .25 L
.59219 .25 L
.59219 .25 L
.5922 .25 L
.5922 .25 L
.5922 .25 L
.59221 .25 L
.59221 .25 L
.59222 .25 L
.59223 .25 L
.59223 .25 L
.59224 .25 L
.59225 .25 L
.59225 .25 L
.59226 .25 L
.59227 .25 L
.59227 .25 L
.59228 .25 L
.59228 .25 L
.59229 .25 L
.5923 .25 L
.5923 .25 L
.59231 .25 L
.59231 .25 L
.59232 .25 L
.59233 .25 L
.59233 .25 L
.59234 .25 L
.59234 .25 L
.59235 .25 L
.59236 .25 L
.59236 .25 L
.59237 .25 L
.59237 .25 L
.59238 .25 L
.59239 .25 L
.59239 .25 L
.5924 .25 L
.5924 .25 L
.59241 .25 L
.59241 .25 L
.59242 .25 L
.59242 .25 L
Mistroke
.59243 .25 L
.59244 .25 L
.59244 .25 L
.59245 .25 L
.59246 .25 L
.59246 .25 L
.59247 .25 L
.59247 .25 L
.59248 .25 L
.59249 .25 L
.59249 .25 L
.5925 .25 L
.59251 .25 L
.59251 .25 L
.59251 .25 L
.59252 .25 L
.59253 .25 L
.59253 .25 L
.59254 .25 L
.59255 .25 L
.59255 .25 L
.59256 .25 L
.59256 .25 L
.59257 .25 L
.59257 .25 L
.59258 .25 L
.59259 .25 L
.59259 .25 L
.5926 .25 L
.59261 .25 L
.59261 .25 L
.59261 .25 L
.59262 .25 L
.59263 .25 L
.59263 .25 L
.59264 .25 L
.59264 .25 L
.59265 .25 L
.59265 .25 L
.59266 .25 L
.59266 .25 L
.59267 .25 L
.59268 .25 L
.59268 .25 L
.59269 .25 L
.59269 .25 L
.5927 .25 L
.5927 .25 L
.5927 .25 L
.59271 .25 L
Mistroke
.59272 .25 L
.59272 .25 L
.59273 .25 L
.59274 .25 L
.59274 .25 L
.59275 .25 L
.59275 .25 L
.59276 .25 L
.59277 .25 L
.59277 .25 L
.59278 .25 L
.59278 .25 L
.59279 .25 L
.5928 .25 L
.5928 .25 L
.59281 .25 L
.59282 .25 L
.59282 .25 L
.59283 .25 L
.59284 .25 L
.59284 .25 L
.59285 .25 L
.59285 .25 L
.59285 .25 L
.59286 .25 L
.59286 .25 L
.59287 .25 L
.59288 .25 L
.59288 .25 L
.59289 .25 L
.5929 .25 L
.5929 .25 L
.59291 .25 L
.59291 .25 L
.59292 .25 L
.59293 .25 L
.59293 .25 L
.59294 .25 L
.59295 .25 L
.59295 .25 L
.59296 .25 L
.59297 .25 L
.59297 .25 L
.59297 .25 L
.59298 .25 L
.59298 .25 L
.59299 .25 L
.59299 .25 L
.59299 .25 L
.593 .25 L
Mistroke
.59301 .25 L
.59301 .25 L
.59301 .25 L
.59302 .25 L
.59302 .25 L
.59302 .25 L
.59303 .25 L
.59303 .25 L
.59304 .25 L
.59305 .25 L
.59305 .25 L
.59306 .25 L
.59307 .25 L
.59307 .25 L
.59308 .25 L
.59308 .25 L
.59309 .25 L
.5931 .25 L
.5931 .25 L
.59311 .25 L
.59311 .25 L
.59312 .25 L
.59313 .25 L
.59313 .25 L
.59314 .25 L
.59314 .25 L
.59315 .25 L
.59316 .25 L
.59316 .25 L
.59317 .25 L
.59317 .25 L
.59318 .25 L
.59318 .25 L
.59319 .25 L
.5932 .25 L
.5932 .25 L
.59321 .25 L
.59322 .25 L
.59322 .25 L
.59323 .25 L
.59323 .25 L
.59323 .25 L
.59324 .25 L
.59325 .25 L
.59325 .25 L
.59326 .25 L
.59327 .25 L
.59327 .25 L
.59328 .25 L
.59329 .25 L
Mistroke
.59329 .25 L
.5933 .25 L
.5933 .25 L
.59331 .25 L
.59332 .25 L
.59332 .25 L
.59333 .25 L
.59333 .25 L
.59334 .25 L
.59335 .25 L
.59335 .25 L
.59336 .25 L
.59336 .25 L
.59337 .25 L
.59338 .25 L
.59338 .25 L
.59339 .25 L
.59339 .25 L
.5934 .25 L
.5934 .25 L
.59341 .25 L
.59342 .25 L
.59342 .25 L
.59343 .25 L
.59343 .25 L
.59344 .25 L
.59344 .25 L
.59345 .25 L
.59346 .25 L
.59346 .25 L
.59346 .25 L
.59347 .25 L
.59348 .25 L
.59348 .25 L
.59349 .25 L
.59349 .25 L
.5935 .25 L
.59351 .25 L
.59351 .25 L
.59351 .25 L
.59352 .25 L
.59353 .25 L
.59353 .25 L
.59354 .25 L
.59354 .25 L
.59355 .25 L
.59355 .25 L
.59356 .25 L
.59357 .25 L
.59357 .25 L
Mistroke
.59358 .25 L
.59358 .25 L
.59359 .25 L
.5936 .25 L
.5936 .25 L
.59361 .25 L
.59361 .25 L
.59362 .25 L
.59363 .25 L
.59363 .25 L
.59364 .25 L
.59365 .25 L
.59365 .25 L
.59366 .25 L
.59367 .25 L
.59367 .25 L
.59367 .25 L
.59368 .25 L
.59368 .25 L
.59369 .25 L
.59369 .25 L
.5937 .25 L
.59371 .25 L
.59371 .25 L
.59372 .25 L
.59373 .25 L
.59373 .25 L
.59374 .25 L
.59374 .25 L
.59375 .25 L
.59376 .25 L
.59376 .25 L
.59377 .25 L
.59378 .25 L
.59378 .25 L
.59379 .25 L
.59379 .25 L
.5938 .25 L
.5938 .25 L
.59381 .25 L
.59381 .25 L
.59381 .25 L
.59382 .25 L
.59383 .25 L
.59383 .25 L
.59383 .25 L
.59384 .25 L
.59384 .25 L
.59384 .25 L
.59385 .25 L
Mistroke
.59385 .25 L
.59386 .25 L
.59386 .25 L
.59387 .25 L
.59388 .25 L
.59388 .25 L
.59389 .25 L
.59389 .25 L
.5939 .25 L
.59391 .25 L
.59391 .25 L
.59392 .25 L
.59393 .25 L
.59393 .25 L
.59394 .25 L
.59394 .25 L
.59395 .25 L
.59396 .25 L
.59396 .25 L
.59397 .25 L
.59397 .25 L
.59398 .25 L
.59398 .25 L
.59399 .25 L
.594 .25 L
.594 .25 L
.59401 .25 L
.59401 .25 L
.59402 .25 L
.59403 .25 L
.59403 .25 L
.59404 .25 L
.59404 .25 L
.59405 .25 L
.59405 .25 L
.59406 .25 L
.59406 .25 L
.59407 .25 L
.59408 .25 L
.59408 .25 L
.59409 .25 L
.5941 .25 L
.5941 .25 L
.59411 .25 L
.59412 .25 L
.59412 .25 L
.59413 .25 L
.59413 .25 L
.59414 .25 L
.59415 .25 L
Mistroke
.59415 .25 L
.59416 .25 L
.59416 .25 L
.59417 .25 L
.59418 .25 L
.59418 .25 L
.59419 .25 L
.59419 .25 L
.5942 .25 L
.59421 .25 L
.59421 .25 L
.59422 .25 L
.59422 .25 L
.59423 .25 L
.59423 .25 L
.59424 .25 L
.59425 .25 L
.59425 .25 L
.59426 .25 L
.59426 .25 L
.59427 .25 L
.59427 .25 L
.59428 .25 L
.59428 .25 L
.59429 .25 L
.59429 .25 L
.5943 .25 L
.59431 .25 L
.59431 .25 L
.59432 .25 L
.59432 .25 L
.59433 .25 L
.59433 .25 L
.59434 .25 L
.59434 .25 L
.59435 .25 L
.59435 .25 L
.59436 .25 L
.59437 .25 L
.59437 .25 L
.59438 .25 L
.59438 .25 L
.59439 .25 L
.5944 .25 L
.5944 .25 L
.59441 .25 L
.59441 .25 L
.59442 .25 L
.59443 .25 L
.59443 .25 L
Mistroke
.59444 .25 L
.59444 .25 L
.59445 .25 L
.59446 .25 L
.59446 .25 L
.59447 .25 L
.59448 .25 L
.59448 .25 L
.59449 .25 L
.59449 .25 L
.5945 .25 L
.5945 .25 L
.5945 .25 L
.59451 .25 L
.59452 .25 L
.59452 .25 L
.59453 .25 L
.59454 .25 L
.59454 .25 L
.59455 .25 L
.59455 .25 L
.59456 .25 L
.59457 .25 L
.59457 .25 L
.59458 .25 L
.59459 .25 L
.59459 .25 L
.5946 .25 L
.59461 .25 L
.59461 .25 L
.59462 .25 L
.59462 .25 L
.59463 .25 L
.59463 .25 L
.59463 .25 L
.59464 .25 L
.59464 .25 L
.59465 .25 L
.59465 .25 L
.59466 .25 L
.59466 .25 L
.59466 .25 L
.59467 .25 L
.59467 .25 L
.59468 .25 L
.59468 .25 L
.59469 .25 L
.59469 .25 L
.5947 .25 L
.59471 .25 L
Mistroke
.59471 .25 L
.59472 .25 L
.59472 .25 L
.59473 .25 L
.59474 .25 L
.59474 .25 L
.59475 .25 L
.59476 .25 L
.59476 .25 L
.59477 .25 L
.59478 .25 L
.59478 .25 L
.59478 .25 L
.59479 .25 L
.5948 .25 L
.5948 .25 L
.59481 .25 L
.59481 .25 L
.59482 .25 L
.59483 .25 L
.59483 .25 L
.59484 .25 L
.59484 .25 L
.59485 .25 L
.59486 .25 L
.59486 .25 L
.59487 .25 L
.59487 .25 L
.59488 .25 L
.59488 .25 L
.59489 .25 L
.59489 .25 L
.5949 .25 L
.59491 .25 L
.59491 .25 L
.59492 .25 L
.59493 .25 L
.59493 .25 L
.59494 .25 L
.59494 .25 L
.59495 .25 L
.59496 .25 L
.59496 .25 L
.59497 .25 L
.59498 .25 L
.59498 .25 L
.59499 .25 L
.59499 .25 L
.595 .25 L
.595 .25 L
Mistroke
.59501 .25 L
.59502 .25 L
.59502 .25 L
.59503 .25 L
.59503 .25 L
.59504 .25 L
.59505 .25 L
.59505 .25 L
.59506 .25 L
.59506 .25 L
.59507 .25 L
.59508 .25 L
.59508 .25 L
.59508 .25 L
.59509 .25 L
.5951 .25 L
.5951 .25 L
.59511 .25 L
.59512 .25 L
.59512 .25 L
.59513 .25 L
.59513 .25 L
.59514 .25 L
.59515 .25 L
.59515 .25 L
.59516 .25 L
.59517 .25 L
.59517 .25 L
.59518 .25 L
.59518 .25 L
.59519 .25 L
.59519 .25 L
.5952 .25 L
.59521 .25 L
.59521 .25 L
.59522 .25 L
.59523 .25 L
.59523 .25 L
.59524 .25 L
.59524 .25 L
.59525 .25 L
.59525 .25 L
.59526 .25 L
.59527 .25 L
.59527 .25 L
.59528 .25 L
.59528 .25 L
.59529 .25 L
.59529 .25 L
.5953 .25 L
Mistroke
.59531 .25 L
.59531 .25 L
.59531 .25 L
.59532 .25 L
.59533 .25 L
.59533 .25 L
.59534 .25 L
.59534 .25 L
.59535 .25 L
.59536 .25 L
.59536 .25 L
.59536 .25 L
.59537 .25 L
.59537 .25 L
.59538 .25 L
.59538 .25 L
.59539 .25 L
.5954 .25 L
.5954 .25 L
.59541 .25 L
.59542 .25 L
.59542 .25 L
.59543 .25 L
.59543 .25 L
.59544 .25 L
.59545 .25 L
.59545 .25 L
.59546 .25 L
.59546 .25 L
.59547 .25 L
.59548 .25 L
.59548 .25 L
.59549 .25 L
.5955 .25 L
.5955 .25 L
.59551 .25 L
.59552 .25 L
.59552 .25 L
.59552 .25 L
.59553 .25 L
.59553 .25 L
.59554 .25 L
.59554 .25 L
.59555 .25 L
.59556 .25 L
.59556 .25 L
.59557 .25 L
.59558 .25 L
.59558 .25 L
.59559 .25 L
Mistroke
.59559 .25 L
.5956 .25 L
.59561 .25 L
.59561 .25 L
.59562 .25 L
.59563 .25 L
.59563 .25 L
.59564 .25 L
.59564 .25 L
.59565 .25 L
.59565 .25 L
.59566 .25 L
.59566 .25 L
.59566 .25 L
.59567 .25 L
.59568 .25 L
.59568 .25 L
.59568 .25 L
.59569 .25 L
.59569 .25 L
.59569 .25 L
.5957 .25 L
.5957 .25 L
.59571 .25 L
.59571 .25 L
.59572 .25 L
.59572 .25 L
.59573 .25 L
.59574 .25 L
.59574 .25 L
.59575 .25 L
.59576 .25 L
.59576 .25 L
.59577 .25 L
.59578 .25 L
.59578 .25 L
.59579 .25 L
.59579 .25 L
.5958 .25 L
.59581 .25 L
.59581 .25 L
.59582 .25 L
.59582 .25 L
.59583 .25 L
.59583 .25 L
.59584 .25 L
.59585 .25 L
.59585 .25 L
.59586 .25 L
.59586 .25 L
Mistroke
.59587 .25 L
.59588 .25 L
.59588 .25 L
.59589 .25 L
.59589 .25 L
.5959 .25 L
.5959 .25 L
.59591 .25 L
.59591 .25 L
.59592 .25 L
.59593 .25 L
.59593 .25 L
.59594 .25 L
.59595 .25 L
.59595 .25 L
.59596 .25 L
.59597 .25 L
.59597 .25 L
.59598 .25 L
.59598 .25 L
.59599 .25 L
.596 .25 L
.596 .25 L
.59601 .25 L
.59601 .25 L
.59602 .25 L
.59603 .25 L
.59603 .25 L
.59604 .25 L
.59604 .25 L
.59605 .25 L
.59606 .25 L
.59606 .25 L
.59607 .25 L
.59607 .25 L
.59608 .25 L
.59609 .25 L
.59609 .25 L
.5961 .25 L
.5961 .25 L
.59611 .25 L
.59611 .25 L
.59612 .25 L
.59612 .25 L
.59613 .25 L
.59613 .25 L
.59614 .25 L
.59614 .25 L
.59615 .25 L
.59616 .25 L
Mistroke
.59616 .25 L
.59617 .25 L
.59617 .25 L
.59618 .25 L
.59618 .25 L
.59619 .25 L
.59619 .25 L
.5962 .25 L
.5962 .25 L
.59621 .25 L
.59622 .25 L
.59622 .25 L
.59623 .25 L
.59623 .25 L
.59624 .25 L
.59625 .25 L
.59625 .25 L
.59626 .25 L
.59626 .25 L
.59627 .25 L
.59628 .25 L
.59628 .25 L
.59629 .25 L
.59629 .25 L
.5963 .25 L
.59631 .25 L
.59631 .25 L
.59632 .25 L
.59633 .25 L
.59633 .25 L
.59634 .25 L
.59634 .25 L
.59635 .25 L
.59635 .25 L
.59635 .25 L
.59636 .25 L
.59637 .25 L
.59637 .25 L
.59638 .25 L
.59639 .25 L
.59639 .25 L
.5964 .25 L
.5964 .25 L
.59641 .25 L
.59642 .25 L
.59642 .25 L
.59643 .25 L
.59644 .25 L
.59644 .25 L
.59645 .25 L
Mistroke
.59646 .25 L
.59646 .25 L
.59647 .25 L
.59647 .25 L
.59648 .25 L
.59648 .25 L
.59649 .25 L
.59649 .25 L
.59649 .25 L
.5965 .25 L
.5965 .25 L
.59651 .25 L
.59651 .25 L
.59651 .25 L
.59652 .25 L
.59652 .25 L
.59653 .25 L
.59653 .25 L
.59654 .25 L
.59654 .25 L
.59655 .25 L
.59656 .25 L
.59656 .25 L
.59657 .25 L
.59657 .25 L
.59658 .25 L
.59659 .25 L
.59659 .25 L
.5966 .25 L
.59661 .25 L
.59661 .25 L
.59662 .25 L
.59663 .25 L
.59663 .25 L
.59663 .25 L
.59664 .25 L
.59665 .25 L
.59665 .25 L
.59666 .25 L
.59667 .25 L
.59667 .25 L
.59668 .25 L
.59668 .25 L
.59669 .25 L
.59669 .25 L
.5967 .25 L
.59671 .25 L
.59671 .25 L
.59672 .25 L
.59672 .25 L
Mistroke
.59673 .25 L
.59673 .25 L
.59674 .25 L
.59674 .25 L
.59675 .25 L
.59676 .25 L
.59677 .25 L
.59677 .25 L
.59678 .25 L
.59678 .25 L
.59679 .25 L
.5968 .25 L
.5968 .25 L
.59681 .25 L
.59681 .25 L
.59682 .25 L
.59683 .25 L
.59683 .25 L
.59684 .25 L
.59684 .25 L
.59685 .25 L
.59686 .25 L
.59686 .25 L
.59687 .25 L
.59687 .25 L
.59688 .25 L
.59688 .25 L
.59689 .25 L
.5969 .25 L
.5969 .25 L
.59691 .25 L
.59692 .25 L
.59692 .25 L
.59693 .25 L
.59693 .25 L
.59693 .25 L
.59694 .25 L
.59695 .25 L
.59695 .25 L
.59696 .25 L
.59696 .25 L
.59697 .25 L
.59697 .25 L
.59698 .25 L
.59699 .25 L
.59699 .25 L
.597 .25 L
.597 .25 L
.59701 .25 L
.59701 .25 L
Mistroke
.59702 .25 L
.59702 .25 L
.59703 .25 L
.59703 .25 L
.59704 .25 L
.59705 .25 L
.59705 .25 L
.59706 .25 L
.59706 .25 L
.59707 .25 L
.59707 .25 L
.59708 .25 L
.59709 .25 L
.59709 .25 L
.5971 .25 L
.59711 .25 L
.59711 .25 L
.59712 .25 L
.59712 .25 L
.59713 .25 L
.59714 .25 L
.59714 .25 L
.59715 .25 L
.59716 .25 L
.59716 .25 L
.59717 .25 L
.59717 .25 L
.59717 .25 L
.59718 .25 L
.59718 .25 L
.59719 .25 L
.5972 .25 L
.5972 .25 L
.59721 .25 L
.59722 .25 L
.59722 .25 L
.59723 .25 L
.59723 .25 L
.59724 .25 L
.59725 .25 L
.59725 .25 L
.59726 .25 L
.59727 .25 L
.59727 .25 L
.59728 .25 L
.59729 .25 L
.59729 .25 L
.5973 .25 L
.5973 .25 L
.59731 .25 L
Mistroke
.59731 .25 L
.59731 .25 L
.59732 .25 L
.59732 .25 L
.59733 .25 L
.59733 .25 L
.59733 .25 L
.59734 .25 L
.59734 .25 L
.59735 .25 L
.59735 .25 L
.59735 .25 L
.59736 .25 L
.59737 .25 L
.59737 .25 L
.59738 .25 L
.59739 .25 L
.59739 .25 L
.5974 .25 L
.5974 .25 L
.59741 .25 L
.59742 .25 L
.59742 .25 L
.59743 .25 L
.59744 .25 L
.59744 .25 L
.59745 .25 L
.59745 .25 L
.59746 .25 L
.59746 .25 L
.59747 .25 L
.59748 .25 L
.59748 .25 L
.59749 .25 L
.5975 .25 L
.5975 .25 L
.59751 .25 L
.59751 .25 L
.59752 .25 L
.59752 .25 L
.59753 .25 L
.59754 .25 L
.59754 .25 L
.59755 .25 L
.59755 .25 L
.59756 .25 L
.59756 .25 L
.59757 .25 L
.59757 .25 L
.59758 .25 L
Mistroke
.59759 .25 L
.59759 .25 L
.5976 .25 L
.59761 .25 L
.59761 .25 L
.59762 .25 L
.59763 .25 L
.59763 .25 L
.59764 .25 L
.59764 .25 L
.59765 .25 L
.59766 .25 L
.59766 .25 L
.59767 .25 L
.59767 .25 L
.59768 .25 L
.59768 .25 L
.59769 .25 L
.5977 .25 L
.5977 .25 L
.59771 .25 L
.59771 .25 L
.59772 .25 L
.59773 .25 L
.59773 .25 L
.59774 .25 L
.59774 .25 L
.59775 .25 L
.59775 .25 L
.59776 .25 L
.59776 .25 L
.59777 .25 L
.59778 .25 L
.59778 .25 L
.59778 .25 L
.59779 .25 L
.5978 .25 L
.5978 .25 L
.59781 .25 L
.59781 .25 L
.59782 .25 L
.59783 .25 L
.59783 .25 L
.59784 .25 L
.59784 .25 L
.59785 .25 L
.59785 .25 L
.59786 .25 L
.59786 .25 L
.59787 .25 L
Mistroke
.59788 .25 L
.59788 .25 L
.59789 .25 L
.59789 .25 L
.5979 .25 L
.5979 .25 L
.59791 .25 L
.59792 .25 L
.59792 .25 L
.59793 .25 L
.59794 .25 L
.59794 .25 L
.59795 .25 L
.59795 .25 L
.59796 .25 L
.59797 .25 L
.59797 .25 L
.59798 .25 L
.59799 .25 L
.59799 .25 L
.59799 .25 L
.598 .25 L
.598 .25 L
.59801 .25 L
.59801 .25 L
.59802 .25 L
.59803 .25 L
.59803 .25 L
.59804 .25 L
.59805 .25 L
.59805 .25 L
.59806 .25 L
.59807 .25 L
.59807 .25 L
.59808 .25 L
.59808 .25 L
.59809 .25 L
.5981 .25 L
.5981 .25 L
.59811 .25 L
.59811 .25 L
.59812 .25 L
.59813 .25 L
.59813 .25 L
.59813 .25 L
.59814 .25 L
.59814 .25 L
.59815 .25 L
.59815 .25 L
.59815 .25 L
Mistroke
.59816 .25 L
.59816 .25 L
.59817 .25 L
.59817 .25 L
.59817 .25 L
.59818 .25 L
.59818 .25 L
.59819 .25 L
.5982 .25 L
.5982 .25 L
.59821 .25 L
.59822 .25 L
.59822 .25 L
.59823 .25 L
.59823 .25 L
.59824 .25 L
.59825 .25 L
.59825 .25 L
.59826 .25 L
.59827 .25 L
.59827 .25 L
.59828 .25 L
.59828 .25 L
.59829 .25 L
.59829 .25 L
.5983 .25 L
.59831 .25 L
.59831 .25 L
.59832 .25 L
.59832 .25 L
.59833 .25 L
.59834 .25 L
.59834 .25 L
.59835 .25 L
.59835 .25 L
.59836 .25 L
.59837 .25 L
.59837 .25 L
.59838 .25 L
.59838 .25 L
.59839 .25 L
.59839 .25 L
.5984 .25 L
.59841 .25 L
.59841 .25 L
.59842 .25 L
.59842 .25 L
.59843 .25 L
.59844 .25 L
.59844 .25 L
Mistroke
.59845 .25 L
.59846 .25 L
.59846 .25 L
.59847 .25 L
.59848 .25 L
.59848 .25 L
.59848 .25 L
.59849 .25 L
.5985 .25 L
.5985 .25 L
.59851 .25 L
.59851 .25 L
.59852 .25 L
.59853 .25 L
.59853 .25 L
.59854 .25 L
.59854 .25 L
.59855 .25 L
.59856 .25 L
.59856 .25 L
.59857 .25 L
.59857 .25 L
.59858 .25 L
.59858 .25 L
.59859 .25 L
.59859 .25 L
.5986 .25 L
.59861 .25 L
.59861 .25 L
.59862 .25 L
.59863 .25 L
.59863 .25 L
.59864 .25 L
.59864 .25 L
.59865 .25 L
.59866 .25 L
.59866 .25 L
.59867 .25 L
.59868 .25 L
.59868 .25 L
.59869 .25 L
.59869 .25 L
.5987 .25 L
.5987 .25 L
.59871 .25 L
.59872 .25 L
.59872 .25 L
.59873 .25 L
.59873 .25 L
.59874 .25 L
Mistroke
.59875 .25 L
.59875 .25 L
.59876 .25 L
.59876 .25 L
.59877 .25 L
.59878 .25 L
.59878 .25 L
.59878 .25 L
.59879 .25 L
.5988 .25 L
.5988 .25 L
.59881 .25 L
.59881 .25 L
.59882 .25 L
.59882 .25 L
.59883 .25 L
.59884 .25 L
.59884 .25 L
.59885 .25 L
.59885 .25 L
.59886 .25 L
.59886 .25 L
.59887 .25 L
.59887 .25 L
.59888 .25 L
.59888 .25 L
.59889 .25 L
.5989 .25 L
.5989 .25 L
.59891 .25 L
.59891 .25 L
.59892 .25 L
.59892 .25 L
.59893 .25 L
.59894 .25 L
.59894 .25 L
.59895 .25 L
.59896 .25 L
.59896 .25 L
.59897 .25 L
.59897 .25 L
.59898 .25 L
.59899 .25 L
.59899 .25 L
.599 .25 L
.59901 .25 L
.59901 .25 L
.59902 .25 L
.59902 .25 L
.59902 .25 L
Mistroke
.59903 .25 L
.59903 .25 L
.59904 .25 L
.59905 .25 L
.59905 .25 L
.59906 .25 L
.59907 .25 L
.59907 .25 L
.59908 .25 L
.59908 .25 L
.59909 .25 L
.5991 .25 L
.5991 .25 L
.59911 .25 L
.59912 .25 L
.59912 .25 L
.59913 .25 L
.59914 .25 L
.59914 .25 L
.59914 .25 L
.59915 .25 L
.59916 .25 L
.59916 .25 L
.59916 .25 L
.59917 .25 L
.59917 .25 L
.59918 .25 L
.59918 .25 L
.59918 .25 L
.59919 .25 L
.59919 .25 L
.5992 .25 L
.5992 .25 L
.5992 .25 L
.59921 .25 L
.59922 .25 L
.59922 .25 L
.59923 .25 L
.59924 .25 L
.59924 .25 L
.59925 .25 L
.59925 .25 L
.59926 .25 L
.59927 .25 L
.59927 .25 L
.59928 .25 L
.59929 .25 L
.59929 .25 L
.5993 .25 L
.5993 .25 L
Mistroke
.59931 .25 L
.59931 .25 L
.59932 .25 L
.59933 .25 L
.59933 .25 L
.59934 .25 L
.59935 .25 L
.59935 .25 L
.59936 .25 L
.59936 .25 L
.59937 .25 L
.59937 .25 L
.59938 .25 L
.59939 .25 L
.59939 .25 L
.5994 .25 L
.5994 .25 L
.59941 .25 L
.59941 .25 L
.59942 .25 L
.59943 .25 L
.59943 .25 L
.59944 .25 L
.59945 .25 L
.59945 .25 L
.59946 .25 L
.59946 .25 L
.59947 .25 L
.59948 .25 L
.59948 .25 L
.59949 .25 L
.5995 .25 L
.5995 .25 L
.59951 .25 L
.59951 .25 L
.59952 .25 L
.59952 .25 L
.59953 .25 L
.59954 .25 L
.59954 .25 L
.59955 .25 L
.59955 .25 L
.59956 .25 L
.59956 .25 L
.59957 .25 L
.59958 .25 L
.59958 .25 L
.59959 .25 L
.59959 .25 L
.5996 .25 L
Mistroke
.5996 .25 L
.59961 .25 L
.59961 .25 L
.59962 .25 L
.59963 .25 L
.59963 .25 L
.59963 .25 L
.59964 .25 L
.59965 .25 L
.59965 .25 L
.59966 .25 L
.59967 .25 L
.59967 .25 L
.59968 .25 L
.59968 .25 L
.59969 .25 L
.59969 .25 L
.5997 .25 L
.5997 .25 L
.59971 .25 L
.59971 .25 L
.59972 .25 L
.59973 .25 L
.59973 .25 L
.59974 .25 L
.59974 .25 L
.59975 .25 L
.59975 .25 L
.59976 .25 L
.59977 .25 L
.59977 .25 L
.59978 .25 L
.59979 .25 L
.59979 .25 L
.5998 .25 L
.5998 .25 L
.59981 .25 L
.59982 .25 L
.59982 .25 L
.59983 .25 L
.59984 .25 L
.59984 .25 L
.59984 .25 L
.59985 .25 L
.59985 .25 L
.59986 .25 L
.59987 .25 L
.59987 .25 L
.59988 .25 L
.59988 .25 L
Mistroke
.59989 .25 L
.5999 .25 L
.5999 .25 L
.59991 .25 L
.59992 .25 L
.59992 .25 L
.59993 .25 L
.59994 .25 L
.59994 .25 L
.59995 .25 L
.59995 .25 L
.59996 .25 L
.59997 .25 L
.59997 .25 L
.59998 .25 L
.59998 .25 L
.59998 .25 L
.59999 .25 L
.59999 .25 L
.6 .25 L
.6 .25 L
.6 .25 L
.60001 .25 L
.60001 .25 L
.60002 .25 L
.60002 .25 L
.60002 .25 L
.60003 .25 L
.60003 .25 L
.60004 .25 L
.60005 .25 L
.60005 .25 L
.60006 .25 L
.60007 .25 L
.60007 .25 L
.60008 .25 L
.60008 .25 L
.60009 .25 L
.6001 .25 L
.6001 .25 L
.60011 .25 L
.60012 .25 L
.60012 .25 L
.60013 .25 L
.60013 .25 L
.60014 .25 L
.60014 .25 L
.60015 .25 L
.60016 .25 L
.60016 .25 L
Mistroke
.60017 .25 L
.60017 .25 L
.60018 .25 L
.60019 .25 L
.60019 .25 L
.6002 .25 L
.6002 .25 L
.60021 .25 L
.60022 .25 L
.60022 .25 L
.60023 .25 L
.60023 .25 L
.60024 .25 L
.60024 .25 L
.60025 .25 L
.60026 .25 L
.60026 .25 L
.60027 .25 L
.60028 .25 L
.60028 .25 L
.60029 .25 L
.60029 .25 L
.6003 .25 L
.60031 .25 L
.60031 .25 L
.60032 .25 L
.60033 .25 L
.60033 .25 L
.60033 .25 L
.60034 .25 L
.60035 .25 L
.60035 .25 L
.60036 .25 L
.60037 .25 L
.60037 .25 L
.60038 .25 L
.60038 .25 L
.60039 .25 L
.60039 .25 L
.6004 .25 L
.60041 .25 L
.60041 .25 L
.60042 .25 L
.60043 .25 L
.60043 .25 L
.60043 .25 L
.60044 .25 L
.60045 .25 L
.60045 .25 L
.60046 .25 L
Mistroke
.60046 .25 L
.60047 .25 L
.60047 .25 L
.60048 .25 L
.60048 .25 L
.60049 .25 L
.6005 .25 L
.6005 .25 L
.60051 .25 L
.60051 .25 L
.60052 .25 L
.60052 .25 L
.60052 .25 L
.60053 .25 L
.60054 .25 L
.60054 .25 L
.60055 .25 L
.60056 .25 L
.60056 .25 L
.60057 .25 L
.60057 .25 L
.60058 .25 L
.60059 .25 L
.60059 .25 L
.6006 .25 L
.6006 .25 L
.60061 .25 L
.60062 .25 L
.60062 .25 L
.60063 .25 L
.60064 .25 L
.60064 .25 L
.60065 .25 L
.60066 .25 L
.60066 .25 L
.60066 .25 L
.60067 .25 L
.60067 .25 L
.60068 .25 L
.60068 .25 L
.60069 .25 L
.6007 .25 L
.6007 .25 L
.60071 .25 L
.60071 .25 L
.60072 .25 L
.60073 .25 L
.60073 .25 L
.60074 .25 L
.60075 .25 L
Mistroke
.60075 .25 L
.60076 .25 L
.60077 .25 L
.60077 .25 L
.60078 .25 L
.60079 .25 L
.60079 .25 L
.60079 .25 L
.6008 .25 L
.6008 .25 L
.60081 .25 L
.60081 .25 L
.60081 .25 L
.60082 .25 L
.60082 .25 L
.60083 .25 L
.60083 .25 L
.60084 .25 L
.60084 .25 L
.60084 .25 L
.60085 .25 L
.60085 .25 L
.60086 .25 L
.60086 .25 L
.60087 .25 L
.60088 .25 L
.60088 .25 L
.60089 .25 L
.6009 .25 L
.6009 .25 L
.60091 .25 L
.60091 .25 L
.60092 .25 L
.60093 .25 L
.60093 .25 L
.60094 .25 L
.60095 .25 L
.60095 .25 L
.60096 .25 L
.60096 .25 L
.60097 .25 L
.60097 .25 L
.60098 .25 L
.60099 .25 L
.60099 .25 L
.601 .25 L
.601 .25 L
.60101 .25 L
.60102 .25 L
.60102 .25 L
Mistroke
.60103 .25 L
.60103 .25 L
.60104 .25 L
.60105 .25 L
.60105 .25 L
.60105 .25 L
.60106 .25 L
.60107 .25 L
.60107 .25 L
.60108 .25 L
.60109 .25 L
.60109 .25 L
.6011 .25 L
.6011 .25 L
.60111 .25 L
.60112 .25 L
.60112 .25 L
.60113 .25 L
.60114 .25 L
.60114 .25 L
.60115 .25 L
.60115 .25 L
.60116 .25 L
.60116 .25 L
.60117 .25 L
.60118 .25 L
.60118 .25 L
.60119 .25 L
.6012 .25 L
.6012 .25 L
.60121 .25 L
.60121 .25 L
.60122 .25 L
.60122 .25 L
.60123 .25 L
.60124 .25 L
.60124 .25 L
.60125 .25 L
.60125 .25 L
.60126 .25 L
.60126 .25 L
.60127 .25 L
.60128 .25 L
.60128 .25 L
.60128 .25 L
.60129 .25 L
.6013 .25 L
.6013 .25 L
.60131 .25 L
.60131 .25 L
Mistroke
.60132 .25 L
.60133 .25 L
.60133 .25 L
.60133 .25 L
.60134 .25 L
.60134 .25 L
.60135 .25 L
.60135 .25 L
.60136 .25 L
.60137 .25 L
.60137 .25 L
.60138 .25 L
.60139 .25 L
.60139 .25 L
.6014 .25 L
.6014 .25 L
.60141 .25 L
.60142 .25 L
.60142 .25 L
.60143 .25 L
.60143 .25 L
.60144 .25 L
.60145 .25 L
.60145 .25 L
.60146 .25 L
.60147 .25 L
.60147 .25 L
.60148 .25 L
.60149 .25 L
.60149 .25 L
.60149 .25 L
.6015 .25 L
.6015 .25 L
.60151 .25 L
.60151 .25 L
.60152 .25 L
.60153 .25 L
.60153 .25 L
.60154 .25 L
.60154 .25 L
.60155 .25 L
.60156 .25 L
.60156 .25 L
.60157 .25 L
.60158 .25 L
.60158 .25 L
.60159 .25 L
.6016 .25 L
.6016 .25 L
.60161 .25 L
Mistroke
.60161 .25 L
.60162 .25 L
.60162 .25 L
.60163 .25 L
.60163 .25 L
.60163 .25 L
.60164 .25 L
.60164 .25 L
.60165 .25 L
.60165 .25 L
.60166 .25 L
.60166 .25 L
.60166 .25 L
.60167 .25 L
.60167 .25 L
.60167 .25 L
.60168 .25 L
.60169 .25 L
.60169 .25 L
.6017 .25 L
.60171 .25 L
.60171 .25 L
.60172 .25 L
.60173 .25 L
.60173 .25 L
.60174 .25 L
.60174 .25 L
.60175 .25 L
.60176 .25 L
.60176 .25 L
.60177 .25 L
.60177 .25 L
.60178 .25 L
.60179 .25 L
.60179 .25 L
.6018 .25 L
.6018 .25 L
.60181 .25 L
.60182 .25 L
.60182 .25 L
.60183 .25 L
.60183 .25 L
.60184 .25 L
.60185 .25 L
.60185 .25 L
.60186 .25 L
.60186 .25 L
.60187 .25 L
.60187 .25 L
.60188 .25 L
Mistroke
.60188 .25 L
.60189 .25 L
.6019 .25 L
.6019 .25 L
.60191 .25 L
.60192 .25 L
.60192 .25 L
.60193 .25 L
.60193 .25 L
.60194 .25 L
.60195 .25 L
.60195 .25 L
.60196 .25 L
.60197 .25 L
.60197 .25 L
.60198 .25 L
.60198 .25 L
.60199 .25 L
.60199 .25 L
.602 .25 L
.60201 .25 L
.60201 .25 L
.60202 .25 L
.60202 .25 L
.60203 .25 L
.60204 .25 L
.60204 .25 L
.60205 .25 L
.60205 .25 L
.60206 .25 L
.60207 .25 L
.60207 .25 L
.60208 .25 L
.60208 .25 L
.60209 .25 L
.60209 .25 L
.6021 .25 L
.60211 .25 L
.60211 .25 L
.60212 .25 L
.60212 .25 L
.60213 .25 L
.60214 .25 L
.60214 .25 L
.60215 .25 L
.60216 .25 L
.60216 .25 L
.60217 .25 L
.60218 .25 L
.60218 .25 L
Mistroke
.60218 .25 L
.60219 .25 L
.6022 .25 L
.6022 .25 L
.60221 .25 L
.60222 .25 L
.60222 .25 L
.60223 .25 L
.60223 .25 L
.60224 .25 L
.60224 .25 L
.60225 .25 L
.60226 .25 L
.60226 .25 L
.60227 .25 L
.60227 .25 L
.60228 .25 L
.60228 .25 L
.60229 .25 L
.6023 .25 L
.6023 .25 L
.60231 .25 L
.60231 .25 L
.60231 .25 L
.60232 .25 L
.60233 .25 L
.60233 .25 L
.60234 .25 L
.60235 .25 L
.60235 .25 L
.60236 .25 L
.60236 .25 L
.60237 .25 L
.60237 .25 L
.60237 .25 L
.60238 .25 L
.60239 .25 L
.60239 .25 L
.6024 .25 L
.60241 .25 L
.60241 .25 L
.60242 .25 L
.60242 .25 L
.60243 .25 L
.60244 .25 L
.60244 .25 L
.60245 .25 L
.60245 .25 L
.60246 .25 L
.60247 .25 L
Mistroke
.60247 .25 L
.60248 .25 L
.60249 .25 L
.60249 .25 L
.6025 .25 L
.6025 .25 L
.60251 .25 L
.60251 .25 L
.60252 .25 L
.60252 .25 L
.60253 .25 L
.60253 .25 L
.60254 .25 L
.60255 .25 L
.60255 .25 L
.60256 .25 L
.60257 .25 L
.60257 .25 L
.60258 .25 L
.60258 .25 L
.60259 .25 L
.6026 .25 L
.6026 .25 L
.60261 .25 L
.60262 .25 L
.60262 .25 L
.60263 .25 L
.60264 .25 L
.60264 .25 L
.60264 .25 L
.60265 .25 L
.60265 .25 L
.60266 .25 L
.60266 .25 L
.60266 .25 L
.60267 .25 L
.60267 .25 L
.60268 .25 L
.60268 .25 L
.60269 .25 L
.60269 .25 L
.60269 .25 L
.6027 .25 L
.6027 .25 L
.60271 .25 L
.60271 .25 L
.60272 .25 L
.60273 .25 L
.60273 .25 L
.60274 .25 L
Mistroke
.60275 .25 L
.60275 .25 L
.60276 .25 L
.60276 .25 L
.60277 .25 L
.60278 .25 L
.60278 .25 L
.60279 .25 L
.6028 .25 L
.6028 .25 L
.60281 .25 L
.60281 .25 L
.60282 .25 L
.60282 .25 L
.60283 .25 L
.60284 .25 L
.60284 .25 L
.60285 .25 L
.60285 .25 L
.60286 .25 L
.60287 .25 L
.60287 .25 L
.60288 .25 L
.60288 .25 L
.60289 .25 L
.6029 .25 L
.6029 .25 L
.6029 .25 L
.60291 .25 L
.60292 .25 L
.60292 .25 L
.60293 .25 L
.60294 .25 L
.60294 .25 L
.60295 .25 L
.60295 .25 L
.60296 .25 L
.60297 .25 L
.60297 .25 L
.60298 .25 L
.60299 .25 L
.60299 .25 L
.603 .25 L
.603 .25 L
.60301 .25 L
.60301 .25 L
.60302 .25 L
.60303 .25 L
.60303 .25 L
.60304 .25 L
Mistroke
.60305 .25 L
.60305 .25 L
.60306 .25 L
.60306 .25 L
.60307 .25 L
.60307 .25 L
.60308 .25 L
.60309 .25 L
.60309 .25 L
.6031 .25 L
.6031 .25 L
.60311 .25 L
.60311 .25 L
.60312 .25 L
.60313 .25 L
.60313 .25 L
.60313 .25 L
.60314 .25 L
.60315 .25 L
.60315 .25 L
.60316 .25 L
.60316 .25 L
.60317 .25 L
.60318 .25 L
.60318 .25 L
.60318 .25 L
.60319 .25 L
.60319 .25 L
.6032 .25 L
.6032 .25 L
.60321 .25 L
.60322 .25 L
.60322 .25 L
.60323 .25 L
.60324 .25 L
.60324 .25 L
.60325 .25 L
.60325 .25 L
.60326 .25 L
.60327 .25 L
.60327 .25 L
.60328 .25 L
.60328 .25 L
.60329 .25 L
.6033 .25 L
.6033 .25 L
.60331 .25 L
.60332 .25 L
.60332 .25 L
.60333 .25 L
Mistroke
.60334 .25 L
.60334 .25 L
.60334 .25 L
.60335 .25 L
.60335 .25 L
.60336 .25 L
.60336 .25 L
.60337 .25 L
.60338 .25 L
.60338 .25 L
.60339 .25 L
.6034 .25 L
.6034 .25 L
.60341 .25 L
.60341 .25 L
.60342 .25 L
.60343 .25 L
.60343 .25 L
.60344 .25 L
.60345 .25 L
.60345 .25 L
.60346 .25 L
.60346 .25 L
.60347 .25 L
.60347 .25 L
.60348 .25 L
.60348 .25 L
.60348 .25 L
.60349 .25 L
.6035 .25 L
.6035 .25 L
.6035 .25 L
.60351 .25 L
.60351 .25 L
.60351 .25 L
.60352 .25 L
.60352 .25 L
.60353 .25 L
.60353 .25 L
.60354 .25 L
.60354 .25 L
.60355 .25 L
.60356 .25 L
.60356 .25 L
.60357 .25 L
.60358 .25 L
.60358 .25 L
.60359 .25 L
.6036 .25 L
.6036 .25 L
Mistroke
.60361 .25 L
.60361 .25 L
.60362 .25 L
.60363 .25 L
.60363 .25 L
.60364 .25 L
.60364 .25 L
.60365 .25 L
.60365 .25 L
.60366 .25 L
.60367 .25 L
.60367 .25 L
.60368 .25 L
.60368 .25 L
.60369 .25 L
.6037 .25 L
.6037 .25 L
.60371 .25 L
.60371 .25 L
.60372 .25 L
.60372 .25 L
.60373 .25 L
.60373 .25 L
.60374 .25 L
.60375 .25 L
.60375 .25 L
.60376 .25 L
.60377 .25 L
.60377 .25 L
.60378 .25 L
.60379 .25 L
.60379 .25 L
.6038 .25 L
.6038 .25 L
.60381 .25 L
.60382 .25 L
.60382 .25 L
.60383 .25 L
.60383 .25 L
.60384 .25 L
.60385 .25 L
.60385 .25 L
.60386 .25 L
.60386 .25 L
.60387 .25 L
.60388 .25 L
.60388 .25 L
.60389 .25 L
.60389 .25 L
.6039 .25 L
Mistroke
.6039 .25 L
.60391 .25 L
.60392 .25 L
.60392 .25 L
.60393 .25 L
.60393 .25 L
.60394 .25 L
.60394 .25 L
.60395 .25 L
.60395 .25 L
.60396 .25 L
.60396 .25 L
.60397 .25 L
.60398 .25 L
.60398 .25 L
.60399 .25 L
.60399 .25 L
.604 .25 L
.604 .25 L
.60401 .25 L
.60401 .25 L
.60402 .25 L
.60402 .25 L
.60403 .25 L
.60404 .25 L
.60404 .25 L
.60405 .25 L
.60405 .25 L
.60406 .25 L
.60407 .25 L
.60407 .25 L
.60408 .25 L
.60408 .25 L
.60409 .25 L
.6041 .25 L
.6041 .25 L
.60411 .25 L
.60411 .25 L
.60412 .25 L
.60413 .25 L
.60413 .25 L
.60414 .25 L
.60415 .25 L
.60415 .25 L
.60416 .25 L
.60416 .25 L
.60417 .25 L
.60417 .25 L
.60417 .25 L
.60418 .25 L
Mistroke
.60419 .25 L
.60419 .25 L
.6042 .25 L
.60421 .25 L
.60421 .25 L
.60422 .25 L
.60422 .25 L
.60423 .25 L
.60424 .25 L
.60424 .25 L
.60425 .25 L
.60426 .25 L
.60426 .25 L
.60427 .25 L
.60428 .25 L
.60428 .25 L
.60429 .25 L
.60429 .25 L
.6043 .25 L
.6043 .25 L
.6043 .25 L
.60431 .25 L
.60431 .25 L
.60432 .25 L
.60432 .25 L
.60433 .25 L
.60433 .25 L
.60433 .25 L
.60434 .25 L
.60434 .25 L
.60435 .25 L
.60435 .25 L
.60436 .25 L
.60436 .25 L
.60437 .25 L
.60438 .25 L
.60438 .25 L
.60439 .25 L
.60439 .25 L
.6044 .25 L
.60441 .25 L
.60441 .25 L
.60442 .25 L
.60443 .25 L
.60443 .25 L
.60444 .25 L
.60445 .25 L
.60445 .25 L
.60445 .25 L
.60446 .25 L
Mistroke
.60447 .25 L
.60447 .25 L
.60448 .25 L
.60449 .25 L
.60449 .25 L
.6045 .25 L
.6045 .25 L
.60451 .25 L
.60451 .25 L
.60452 .25 L
.60453 .25 L
.60453 .25 L
.60454 .25 L
.60454 .25 L
.60455 .25 L
.60455 .25 L
.60456 .25 L
.60456 .25 L
.60457 .25 L
.60458 .25 L
.60458 .25 L
.60459 .25 L
.6046 .25 L
.6046 .25 L
.60461 .25 L
.60462 .25 L
.60462 .25 L
.60463 .25 L
.60463 .25 L
.60464 .25 L
.60465 .25 L
.60465 .25 L
.60466 .25 L
.60466 .25 L
.60467 .25 L
.60467 .25 L
.60468 .25 L
.60469 .25 L
.60469 .25 L
.6047 .25 L
.6047 .25 L
.60471 .25 L
.60472 .25 L
.60472 .25 L
.60473 .25 L
.60473 .25 L
.60474 .25 L
.60475 .25 L
.60475 .25 L
.60475 .25 L
Mistroke
.60476 .25 L
.60477 .25 L
.60477 .25 L
.60478 .25 L
.60478 .25 L
.60479 .25 L
.60479 .25 L
.6048 .25 L
.6048 .25 L
.60481 .25 L
.60482 .25 L
.60482 .25 L
.60483 .25 L
.60483 .25 L
.60484 .25 L
.60484 .25 L
.60485 .25 L
.60485 .25 L
.60486 .25 L
.60487 .25 L
.60487 .25 L
.60488 .25 L
.60488 .25 L
.60489 .25 L
.60489 .25 L
.6049 .25 L
.60491 .25 L
.60491 .25 L
.60492 .25 L
.60493 .25 L
.60493 .25 L
.60494 .25 L
.60494 .25 L
.60495 .25 L
.60496 .25 L
.60496 .25 L
.60497 .25 L
.60498 .25 L
.60498 .25 L
.60499 .25 L
.60499 .25 L
.60499 .25 L
.605 .25 L
.605 .25 L
.60501 .25 L
.60502 .25 L
.60502 .25 L
.60503 .25 L
.60504 .25 L
.60504 .25 L
Mistroke
.60505 .25 L
.60505 .25 L
.60506 .25 L
.60507 .25 L
.60507 .25 L
.60508 .25 L
.60509 .25 L
.60509 .25 L
.6051 .25 L
.60511 .25 L
.60511 .25 L
.60511 .25 L
.60512 .25 L
.60513 .25 L
.60513 .25 L
.60513 .25 L
.60514 .25 L
.60514 .25 L
.60515 .25 L
.60515 .25 L
.60515 .25 L
.60516 .25 L
.60516 .25 L
.60517 .25 L
.60517 .25 L
.60517 .25 L
.60518 .25 L
.60519 .25 L
.60519 .25 L
.6052 .25 L
.60521 .25 L
.60521 .25 L
.60522 .25 L
.60522 .25 L
.60523 .25 L
.60524 .25 L
.60524 .25 L
.60525 .25 L
.60526 .25 L
.60526 .25 L
.60527 .25 L
.60527 .25 L
.60528 .25 L
.60528 .25 L
.60529 .25 L
.6053 .25 L
.6053 .25 L
.60531 .25 L
.60531 .25 L
.60532 .25 L
Mistroke
.60533 .25 L
.60533 .25 L
.60534 .25 L
.60534 .25 L
.60535 .25 L
.60536 .25 L
.60536 .25 L
.60537 .25 L
.60537 .25 L
.60538 .25 L
.60538 .25 L
.60539 .25 L
.60539 .25 L
.6054 .25 L
.60541 .25 L
.60541 .25 L
.60542 .25 L
.60543 .25 L
.60543 .25 L
.60544 .25 L
.60545 .25 L
.60545 .25 L
.60546 .25 L
.60546 .25 L
.60547 .25 L
.60548 .25 L
.60548 .25 L
.60549 .25 L
.60549 .25 L
.6055 .25 L
.6055 .25 L
.60551 .25 L
.60552 .25 L
.60552 .25 L
.60553 .25 L
.60553 .25 L
.60554 .25 L
.60555 .25 L
.60555 .25 L
.60556 .25 L
.60556 .25 L
.60557 .25 L
.60557 .25 L
.60558 .25 L
.60558 .25 L
.60559 .25 L
.6056 .25 L
.6056 .25 L
.6056 .25 L
.60561 .25 L
Mistroke
.60562 .25 L
.60562 .25 L
.60563 .25 L
.60563 .25 L
.60564 .25 L
.60565 .25 L
.60565 .25 L
.60565 .25 L
.60566 .25 L
.60567 .25 L
.60567 .25 L
.60568 .25 L
.60568 .25 L
.60569 .25 L
.6057 .25 L
.6057 .25 L
.60571 .25 L
.60571 .25 L
.60572 .25 L
.60572 .25 L
.60573 .25 L
.60574 .25 L
.60574 .25 L
.60575 .25 L
.60576 .25 L
.60576 .25 L
.60577 .25 L
.60577 .25 L
.60578 .25 L
.60579 .25 L
.60579 .25 L
.6058 .25 L
.60581 .25 L
.60581 .25 L
.60581 .25 L
.60582 .25 L
.60582 .25 L
.60583 .25 L
.60583 .25 L
.60584 .25 L
.60585 .25 L
.60585 .25 L
.60586 .25 L
.60587 .25 L
.60587 .25 L
.60588 .25 L
.60588 .25 L
.60589 .25 L
.6059 .25 L
.6059 .25 L
Mistroke
.60591 .25 L
.60592 .25 L
.60592 .25 L
.60593 .25 L
.60593 .25 L
.60594 .25 L
.60594 .25 L
.60595 .25 L
.60595 .25 L
.60596 .25 L
.60596 .25 L
.60597 .25 L
.60597 .25 L
.60597 .25 L
.60598 .25 L
.60598 .25 L
.60599 .25 L
.60599 .25 L
.60599 .25 L
.606 .25 L
.606 .25 L
.60601 .25 L
.60602 .25 L
.60602 .25 L
.60603 .25 L
.60604 .25 L
.60604 .25 L
.60605 .25 L
.60605 .25 L
.60606 .25 L
.60607 .25 L
.60607 .25 L
.60608 .25 L
.60609 .25 L
.60609 .25 L
.6061 .25 L
.6061 .25 L
.60611 .25 L
.60611 .25 L
.60612 .25 L
.60613 .25 L
.60613 .25 L
.60614 .25 L
.60614 .25 L
.60615 .25 L
.60615 .25 L
.60616 .25 L
.60617 .25 L
.60617 .25 L
.60618 .25 L
Mistroke
.60618 .25 L
.60619 .25 L
.6062 .25 L
.6062 .25 L
.6062 .25 L
.60621 .25 L
.60622 .25 L
.60622 .25 L
.60623 .25 L
.60624 .25 L
.60624 .25 L
.60625 .25 L
.60626 .25 L
.60626 .25 L
.60627 .25 L
.60628 .25 L
.60628 .25 L
.60629 .25 L
.60629 .25 L
.6063 .25 L
.6063 .25 L
.60631 .25 L
.60632 .25 L
.60632 .25 L
.60633 .25 L
.60633 .25 L
.60634 .25 L
.60635 .25 L
.60635 .25 L
.60636 .25 L
.60636 .25 L
.60637 .25 L
.60638 .25 L
.60638 .25 L
.60639 .25 L
.60639 .25 L
.6064 .25 L
.6064 .25 L
.60641 .25 L
.60641 .25 L
.60642 .25 L
.60643 .25 L
.60643 .25 L
.60644 .25 L
.60645 .25 L
.60645 .25 L
.60646 .25 L
.60646 .25 L
.60647 .25 L
.60648 .25 L
Mistroke
.60648 .25 L
.60649 .25 L
.6065 .25 L
.6065 .25 L
.6065 .25 L
.60651 .25 L
.60652 .25 L
.60652 .25 L
.60653 .25 L
.60654 .25 L
.60654 .25 L
.60655 .25 L
.60655 .25 L
.60656 .25 L
.60657 .25 L
.60657 .25 L
.60658 .25 L
.60658 .25 L
.60659 .25 L
.6066 .25 L
.6066 .25 L
.6066 .25 L
.60661 .25 L
.60662 .25 L
.60662 .25 L
.60663 .25 L
.60663 .25 L
.60664 .25 L
.60664 .25 L
.60665 .25 L
.60665 .25 L
.60666 .25 L
.60667 .25 L
.60667 .25 L
.60668 .25 L
.60668 .25 L
.60669 .25 L
.60669 .25 L
.6067 .25 L
.6067 .25 L
.60671 .25 L
.60672 .25 L
.60672 .25 L
.60673 .25 L
.60673 .25 L
.60674 .25 L
.60674 .25 L
.60675 .25 L
.60676 .25 L
.60676 .25 L
Mistroke
.60677 .25 L
.60678 .25 L
.60678 .25 L
.60679 .25 L
.60679 .25 L
.6068 .25 L
.60681 .25 L
.60681 .25 L
.60682 .25 L
.60683 .25 L
.60683 .25 L
.60684 .25 L
.60684 .25 L
.60684 .25 L
.60685 .25 L
.60685 .25 L
.60686 .25 L
.60687 .25 L
.60687 .25 L
.60688 .25 L
.60689 .25 L
.60689 .25 L
.6069 .25 L
.6069 .25 L
.60691 .25 L
.60692 .25 L
.60692 .25 L
.60693 .25 L
.60694 .25 L
.60694 .25 L
.60695 .25 L
.60696 .25 L
.60696 .25 L
.60696 .25 L
.60697 .25 L
.60697 .25 L
.60698 .25 L
.60698 .25 L
.60699 .25 L
.60699 .25 L
.607 .25 L
.607 .25 L
.607 .25 L
.60701 .25 L
.60701 .25 L
.60702 .25 L
.60702 .25 L
.60702 .25 L
.60703 .25 L
.60704 .25 L
Mistroke
.60704 .25 L
.60705 .25 L
.60706 .25 L
.60706 .25 L
.60707 .25 L
.60707 .25 L
.60708 .25 L
.60709 .25 L
.60709 .25 L
.6071 .25 L
.60711 .25 L
.60711 .25 L
.60712 .25 L
.60712 .25 L
.60713 .25 L
.60713 .25 L
.60714 .25 L
.60715 .25 L
.60715 .25 L
.60716 .25 L
.60716 .25 L
.60717 .25 L
.60718 .25 L
.60718 .25 L
.60719 .25 L
.60719 .25 L
.6072 .25 L
.60721 .25 L
.60721 .25 L
.60722 .25 L
.60722 .25 L
.60723 .25 L
.60723 .25 L
.60724 .25 L
.60724 .25 L
.60725 .25 L
.60726 .25 L
.60726 .25 L
.60727 .25 L
.60728 .25 L
.60728 .25 L
.60729 .25 L
.6073 .25 L
.6073 .25 L
.60731 .25 L
.60731 .25 L
.60732 .25 L
.60733 .25 L
.60733 .25 L
.60734 .25 L
Mistroke
.60734 .25 L
.60735 .25 L
.60735 .25 L
.60736 .25 L
.60737 .25 L
.60737 .25 L
.60738 .25 L
.60738 .25 L
.60739 .25 L
.6074 .25 L
.6074 .25 L
.60741 .25 L
.60741 .25 L
.60742 .25 L
.60742 .25 L
.60743 .25 L
.60743 .25 L
.60744 .25 L
.60745 .25 L
.60745 .25 L
.60745 .25 L
.60746 .25 L
.60747 .25 L
.60747 .25 L
.60748 .25 L
.60748 .25 L
.60749 .25 L
.6075 .25 L
.6075 .25 L
.6075 .25 L
.60751 .25 L
.60752 .25 L
.60752 .25 L
.60753 .25 L
.60753 .25 L
.60754 .25 L
.60755 .25 L
.60755 .25 L
.60756 .25 L
.60756 .25 L
.60757 .25 L
.60757 .25 L
.60758 .25 L
.60759 .25 L
.60759 .25 L
.6076 .25 L
.60761 .25 L
.60761 .25 L
.60762 .25 L
.60762 .25 L
Mistroke
.60763 .25 L
.60764 .25 L
.60764 .25 L
.60765 .25 L
.60766 .25 L
.60766 .25 L
.60766 .25 L
.60767 .25 L
.60767 .25 L
.60768 .25 L
.60768 .25 L
.60769 .25 L
.6077 .25 L
.6077 .25 L
.60771 .25 L
.60772 .25 L
.60772 .25 L
.60773 .25 L
.60774 .25 L
.60774 .25 L
.60775 .25 L
.60775 .25 L
.60776 .25 L
.60777 .25 L
.60777 .25 L
.60778 .25 L
.60778 .25 L
.60779 .25 L
.60779 .25 L
.6078 .25 L
.6078 .25 L
.60781 .25 L
.60781 .25 L
.60782 .25 L
.60782 .25 L
.60782 .25 L
.60783 .25 L
.60783 .25 L
.60784 .25 L
.60784 .25 L
.60784 .25 L
.60785 .25 L
.60785 .25 L
.60786 .25 L
.60787 .25 L
.60787 .25 L
.60788 .25 L
.60789 .25 L
.60789 .25 L
.6079 .25 L
Mistroke
.6079 .25 L
.60791 .25 L
.60792 .25 L
.60792 .25 L
.60793 .25 L
.60794 .25 L
.60794 .25 L
.60795 .25 L
.60795 .25 L
.60796 .25 L
.60796 .25 L
.60797 .25 L
.60798 .25 L
.60798 .25 L
.60799 .25 L
.60799 .25 L
.608 .25 L
.608 .25 L
.60801 .25 L
.60802 .25 L
.60802 .25 L
.60803 .25 L
.60804 .25 L
.60804 .25 L
.60805 .25 L
.60805 .25 L
.60806 .25 L
.60806 .25 L
.60807 .25 L
.60808 .25 L
.60808 .25 L
.60809 .25 L
.60809 .25 L
.6081 .25 L
.60811 .25 L
.60811 .25 L
.60812 .25 L
.60813 .25 L
.60813 .25 L
.60814 .25 L
.60815 .25 L
.60815 .25 L
.60815 .25 L
.60816 .25 L
.60817 .25 L
.60817 .25 L
.60818 .25 L
.60818 .25 L
.60819 .25 L
.6082 .25 L
Mistroke
.6082 .25 L
.60821 .25 L
.60821 .25 L
.60822 .25 L
.60823 .25 L
.60823 .25 L
.60824 .25 L
.60824 .25 L
.60825 .25 L
.60825 .25 L
.60826 .25 L
.60826 .25 L
.60827 .25 L
.60827 .25 L
.60828 .25 L
.60828 .25 L
.60829 .25 L
.6083 .25 L
.6083 .25 L
.60831 .25 L
.60831 .25 L
.60832 .25 L
.60833 .25 L
.60833 .25 L
.60834 .25 L
.60834 .25 L
.60834 .25 L
.60835 .25 L
.60836 .25 L
.60836 .25 L
.60837 .25 L
.60837 .25 L
.60838 .25 L
.60839 .25 L
.60839 .25 L
.6084 .25 L
.6084 .25 L
.60841 .25 L
.60842 .25 L
.60842 .25 L
.60843 .25 L
.60844 .25 L
.60844 .25 L
.60845 .25 L
.60845 .25 L
.60846 .25 L
.60847 .25 L
.60847 .25 L
.60848 .25 L
.60848 .25 L
Mistroke
.60849 .25 L
.60849 .25 L
.6085 .25 L
.6085 .25 L
.60851 .25 L
.60851 .25 L
.60852 .25 L
.60853 .25 L
.60853 .25 L
.60854 .25 L
.60855 .25 L
.60855 .25 L
.60856 .25 L
.60857 .25 L
.60857 .25 L
.60858 .25 L
.60858 .25 L
.60859 .25 L
.6086 .25 L
.6086 .25 L
.60861 .25 L
.60861 .25 L
.60862 .25 L
.60862 .25 L
.60863 .25 L
.60863 .25 L
.60863 .25 L
.60864 .25 L
.60864 .25 L
.60865 .25 L
.60865 .25 L
.60866 .25 L
.60866 .25 L
.60866 .25 L
.60867 .25 L
.60867 .25 L
.60868 .25 L
.60868 .25 L
.60869 .25 L
.6087 .25 L
.6087 .25 L
.60871 .25 L
.60872 .25 L
.60872 .25 L
.60873 .25 L
.60873 .25 L
.60874 .25 L
.60875 .25 L
.60875 .25 L
.60876 .25 L
Mistroke
.60877 .25 L
.60877 .25 L
.60877 .25 L
.60878 .25 L
.60879 .25 L
.60879 .25 L
.6088 .25 L
.60881 .25 L
.60881 .25 L
.60882 .25 L
.60882 .25 L
.60883 .25 L
.60883 .25 L
.60884 .25 L
.60885 .25 L
.60885 .25 L
.60886 .25 L
.60887 .25 L
.60887 .25 L
.60887 .25 L
.60888 .25 L
.60889 .25 L
.60889 .25 L
.6089 .25 L
.60891 .25 L
.60891 .25 L
.60892 .25 L
.60892 .25 L
.60893 .25 L
.60894 .25 L
.60894 .25 L
.60895 .25 L
.60896 .25 L
.60896 .25 L
.60897 .25 L
.60897 .25 L
.60898 .25 L
.60898 .25 L
.60899 .25 L
.609 .25 L
.609 .25 L
.60901 .25 L
.60901 .25 L
.60902 .25 L
.60903 .25 L
.60903 .25 L
.60904 .25 L
.60904 .25 L
.60905 .25 L
.60906 .25 L
Mistroke
.60906 .25 L
.60907 .25 L
.60907 .25 L
.60907 .25 L
.60908 .25 L
.60909 .25 L
.60909 .25 L
.6091 .25 L
.6091 .25 L
.60911 .25 L
.60911 .25 L
.60912 .25 L
.60913 .25 L
.60913 .25 L
.60914 .25 L
.60915 .25 L
.60915 .25 L
.60915 .25 L
.60916 .25 L
.60916 .25 L
.60917 .25 L
.60917 .25 L
.60918 .25 L
.60919 .25 L
.60919 .25 L
.6092 .25 L
.6092 .25 L
.60921 .25 L
.60922 .25 L
.60922 .25 L
.60923 .25 L
.60923 .25 L
.60924 .25 L
.60925 .25 L
.60925 .25 L
.60926 .25 L
.60926 .25 L
.60927 .25 L
.60928 .25 L
.60928 .25 L
.60929 .25 L
.6093 .25 L
.6093 .25 L
.60931 .25 L
.60931 .25 L
.60932 .25 L
.60932 .25 L
.60933 .25 L
.60933 .25 L
.60934 .25 L
Mistroke
.60935 .25 L
.60935 .25 L
.60936 .25 L
.60936 .25 L
.60937 .25 L
.60938 .25 L
.60938 .25 L
.60939 .25 L
.60939 .25 L
.6094 .25 L
.60941 .25 L
.60941 .25 L
.60942 .25 L
.60943 .25 L
.60943 .25 L
.60944 .25 L
.60944 .25 L
.60945 .25 L
.60945 .25 L
.60945 .25 L
.60946 .25 L
.60946 .25 L
.60947 .25 L
.60947 .25 L
.60947 .25 L
.60948 .25 L
.60948 .25 L
.60949 .25 L
.60949 .25 L
.60949 .25 L
.6095 .25 L
.60951 .25 L
.60951 .25 L
.60952 .25 L
.60953 .25 L
.60953 .25 L
.60954 .25 L
.60954 .25 L
.60955 .25 L
.60956 .25 L
.60956 .25 L
.60957 .25 L
.60958 .25 L
.60958 .25 L
.60959 .25 L
.60959 .25 L
.6096 .25 L
.6096 .25 L
.60961 .25 L
.60962 .25 L
Mistroke
.60962 .25 L
.60963 .25 L
.60964 .25 L
.60964 .25 L
.60965 .25 L
.60965 .25 L
.60966 .25 L
.60966 .25 L
.60967 .25 L
.60968 .25 L
.60968 .25 L
.60969 .25 L
.60969 .25 L
.6097 .25 L
.6097 .25 L
.60971 .25 L
.60972 .25 L
.60972 .25 L
.60973 .25 L
.60974 .25 L
.60974 .25 L
.60975 .25 L
.60975 .25 L
.60976 .25 L
.60977 .25 L
.60977 .25 L
.60978 .25 L
.60979 .25 L
.60979 .25 L
.6098 .25 L
.6098 .25 L
.60981 .25 L
.60981 .25 L
.60982 .25 L
.60983 .25 L
.60983 .25 L
.60984 .25 L
.60984 .25 L
.60985 .25 L
.60985 .25 L
.60986 .25 L
.60987 .25 L
.60987 .25 L
.60988 .25 L
.60988 .25 L
.60989 .25 L
.60989 .25 L
.6099 .25 L
.6099 .25 L
.60991 .25 L
Mistroke
.60992 .25 L
.60992 .25 L
.60993 .25 L
.60994 .25 L
.60994 .25 L
.60995 .25 L
.60996 .25 L
.60996 .25 L
.60997 .25 L
.60998 .25 L
.60998 .25 L
.60999 .25 L
.60999 .25 L
.61 .25 L
.61 .25 L
.61001 .25 L
.61002 .25 L
.61002 .25 L
.61003 .25 L
.61003 .25 L
.61004 .25 L
.61005 .25 L
.61005 .25 L
.61006 .25 L
.61006 .25 L
.61007 .25 L
.61008 .25 L
.61008 .25 L
.61009 .25 L
.61009 .25 L
.6101 .25 L
.6101 .25 L
.61011 .25 L
.61011 .25 L
.61012 .25 L
.61012 .25 L
.61013 .25 L
.61013 .25 L
.61014 .25 L
.61015 .25 L
.61015 .25 L
.61016 .25 L
.61016 .25 L
.61017 .25 L
.61017 .25 L
.61018 .25 L
.61019 .25 L
.61019 .25 L
.61019 .25 L
.6102 .25 L
Mistroke
.61021 .25 L
.61021 .25 L
.61022 .25 L
.61022 .25 L
.61023 .25 L
.61024 .25 L
.61024 .25 L
.61025 .25 L
.61025 .25 L
.61026 .25 L
.61027 .25 L
.61027 .25 L
.61028 .25 L
.61028 .25 L
.61029 .25 L
.6103 .25 L
.6103 .25 L
.61031 .25 L
.61032 .25 L
.61032 .25 L
.61033 .25 L
.61033 .25 L
.61034 .25 L
.61034 .25 L
.61034 .25 L
.61035 .25 L
.61036 .25 L
.61036 .25 L
.61037 .25 L
.61038 .25 L
.61038 .25 L
.61039 .25 L
.6104 .25 L
.6104 .25 L
.61041 .25 L
.61042 .25 L
.61042 .25 L
.61043 .25 L
.61043 .25 L
.61044 .25 L
.61045 .25 L
.61045 .25 L
.61046 .25 L
.61046 .25 L
.61047 .25 L
.61047 .25 L
.61048 .25 L
.61048 .25 L
.61048 .25 L
.61049 .25 L
Mistroke
.61049 .25 L
.6105 .25 L
.6105 .25 L
.61051 .25 L
.61051 .25 L
.61051 .25 L
.61052 .25 L
.61052 .25 L
.61053 .25 L
.61053 .25 L
.61054 .25 L
.61055 .25 L
.61055 .25 L
.61056 .25 L
.61057 .25 L
.61057 .25 L
.61058 .25 L
.61058 .25 L
.61059 .25 L
.6106 .25 L
.6106 .25 L
.61061 .25 L
.61062 .25 L
.61062 .25 L
.61062 .25 L
.61063 .25 L
.61064 .25 L
.61064 .25 L
.61065 .25 L
.61066 .25 L
.61066 .25 L
.61067 .25 L
.61067 .25 L
.61068 .25 L
.61068 .25 L
.61069 .25 L
.6107 .25 L
.6107 .25 L
.61071 .25 L
.61072 .25 L
.61072 .25 L
.61072 .25 L
.61073 .25 L
.61074 .25 L
.61074 .25 L
.61075 .25 L
.61076 .25 L
.61076 .25 L
.61077 .25 L
.61077 .25 L
Mistroke
.61078 .25 L
.61079 .25 L
.61079 .25 L
.6108 .25 L
.61081 .25 L
.61081 .25 L
.61082 .25 L
.61082 .25 L
.61083 .25 L
.61083 .25 L
.61084 .25 L
.61085 .25 L
.61085 .25 L
.61086 .25 L
.61086 .25 L
.61087 .25 L
.61088 .25 L
.61088 .25 L
.61089 .25 L
.61089 .25 L
.6109 .25 L
.61091 .25 L
.61091 .25 L
.61092 .25 L
.61092 .25 L
.61093 .25 L
.61093 .25 L
.61094 .25 L
.61094 .25 L
.61095 .25 L
.61095 .25 L
.61096 .25 L
.61096 .25 L
.61097 .25 L
.61098 .25 L
.61098 .25 L
.61099 .25 L
.611 .25 L
.611 .25 L
.611 .25 L
.61101 .25 L
.61101 .25 L
.61102 .25 L
.61102 .25 L
.61103 .25 L
.61104 .25 L
.61104 .25 L
.61105 .25 L
.61105 .25 L
.61106 .25 L
Mistroke
.61107 .25 L
.61107 .25 L
.61108 .25 L
.61108 .25 L
.61109 .25 L
.6111 .25 L
.6111 .25 L
.61111 .25 L
.61111 .25 L
.61112 .25 L
.61113 .25 L
.61113 .25 L
.61114 .25 L
.61115 .25 L
.61115 .25 L
.61116 .25 L
.61116 .25 L
.61117 .25 L
.61117 .25 L
.61118 .25 L
.61118 .25 L
.61119 .25 L
.6112 .25 L
.6112 .25 L
.61121 .25 L
.61121 .25 L
.61122 .25 L
.61123 .25 L
.61123 .25 L
.61124 .25 L
.61125 .25 L
.61125 .25 L
.61126 .25 L
.61127 .25 L
.61127 .25 L
.61128 .25 L
.61128 .25 L
.61129 .25 L
.61129 .25 L
.6113 .25 L
.6113 .25 L
.6113 .25 L
.61131 .25 L
.61131 .25 L
.61132 .25 L
.61132 .25 L
.61133 .25 L
.61133 .25 L
.61133 .25 L
.61134 .25 L
Mistroke
.61134 .25 L
.61134 .25 L
.61135 .25 L
.61136 .25 L
.61136 .25 L
.61137 .25 L
.61138 .25 L
.61138 .25 L
.61139 .25 L
.6114 .25 L
.6114 .25 L
.61141 .25 L
.61141 .25 L
.61142 .25 L
.61143 .25 L
.61143 .25 L
.61144 .25 L
.61144 .25 L
.61145 .25 L
.61145 .25 L
.61146 .25 L
.61147 .25 L
.61147 .25 L
.61148 .25 L
.61149 .25 L
.61149 .25 L
.6115 .25 L
.6115 .25 L
.61151 .25 L
.61151 .25 L
.61152 .25 L
.61153 .25 L
.61153 .25 L
.61154 .25 L
.61154 .25 L
.61155 .25 L
.61155 .25 L
.61156 .25 L
.61157 .25 L
.61157 .25 L
.61158 .25 L
.61159 .25 L
.61159 .25 L
.6116 .25 L
.6116 .25 L
.61161 .25 L
.61162 .25 L
.61162 .25 L
.61163 .25 L
.61164 .25 L
Mistroke
.61164 .25 L
.61165 .25 L
.61165 .25 L
.61166 .25 L
.61166 .25 L
.61167 .25 L
.61168 .25 L
.61168 .25 L
.61169 .25 L
.61169 .25 L
.6117 .25 L
.61171 .25 L
.61171 .25 L
.61172 .25 L
.61172 .25 L
.61173 .25 L
.61174 .25 L
.61174 .25 L
.61175 .25 L
.61175 .25 L
.61176 .25 L
.61176 .25 L
.61177 .25 L
.61177 .25 L
.61178 .25 L
.61178 .25 L
.61179 .25 L
.61179 .25 L
.6118 .25 L
.61181 .25 L
.61181 .25 L
.61182 .25 L
.61182 .25 L
.61183 .25 L
.61183 .25 L
.61184 .25 L
.61184 .25 L
.61185 .25 L
.61185 .25 L
.61186 .25 L
.61187 .25 L
.61187 .25 L
.61188 .25 L
.61188 .25 L
.61189 .25 L
.6119 .25 L
.6119 .25 L
.61191 .25 L
.61191 .25 L
.61192 .25 L
Mistroke
.61193 .25 L
.61193 .25 L
.61194 .25 L
.61195 .25 L
.61195 .25 L
.61196 .25 L
.61196 .25 L
.61197 .25 L
.61198 .25 L
.61198 .25 L
.61199 .25 L
.61199 .25 L
.61199 .25 L
.612 .25 L
.61201 .25 L
.61201 .25 L
.61202 .25 L
.61203 .25 L
.61203 .25 L
.61204 .25 L
.61204 .25 L
.61205 .25 L
.61206 .25 L
.61206 .25 L
.61207 .25 L
.61208 .25 L
.61208 .25 L
.61209 .25 L
.61209 .25 L
.6121 .25 L
.61211 .25 L
.61211 .25 L
.61212 .25 L
.61212 .25 L
.61212 .25 L
.61213 .25 L
.61213 .25 L
.61214 .25 L
.61214 .25 L
.61214 .25 L
.61215 .25 L
.61215 .25 L
.61216 .25 L
.61216 .25 L
.61216 .25 L
.61217 .25 L
.61217 .25 L
.61218 .25 L
.61219 .25 L
.61219 .25 L
Mistroke
.6122 .25 L
.61221 .25 L
.61221 .25 L
.61222 .25 L
.61223 .25 L
.61223 .25 L
.61224 .25 L
.61224 .25 L
.61225 .25 L
.61226 .25 L
.61226 .25 L
.61227 .25 L
.61227 .25 L
.61228 .25 L
.61229 .25 L
.61229 .25 L
.6123 .25 L
.6123 .25 L
.61231 .25 L
.61232 .25 L
.61232 .25 L
.61233 .25 L
.61233 .25 L
.61234 .25 L
.61234 .25 L
.61235 .25 L
.61236 .25 L
.61236 .25 L
.61237 .25 L
.61237 .25 L
.61238 .25 L
.61238 .25 L
.61239 .25 L
.6124 .25 L
.6124 .25 L
.61241 .25 L
.61242 .25 L
.61242 .25 L
.61243 .25 L
.61243 .25 L
.61244 .25 L
.61245 .25 L
.61245 .25 L
.61246 .25 L
.61247 .25 L
.61247 .25 L
.61247 .25 L
.61248 .25 L
.61249 .25 L
.61249 .25 L
Mistroke
.6125 .25 L
.61251 .25 L
.61251 .25 L
.61252 .25 L
.61252 .25 L
.61253 .25 L
.61253 .25 L
.61254 .25 L
.61255 .25 L
.61255 .25 L
.61256 .25 L
.61257 .25 L
.61257 .25 L
.61257 .25 L
.61258 .25 L
.61259 .25 L
.61259 .25 L
.6126 .25 L
.6126 .25 L
.61261 .25 L
.61261 .25 L
.61262 .25 L
.61262 .25 L
.61263 .25 L
.61264 .25 L
.61264 .25 L
.61265 .25 L
.61265 .25 L
.61266 .25 L
.61266 .25 L
.61266 .25 L
.61267 .25 L
.61268 .25 L
.61268 .25 L
.61269 .25 L
.6127 .25 L
.6127 .25 L
.61271 .25 L
.61271 .25 L
.61272 .25 L
.61273 .25 L
.61273 .25 L
.61274 .25 L
.61274 .25 L
.61275 .25 L
.61276 .25 L
.61276 .25 L
.61277 .25 L
.61278 .25 L
.61278 .25 L
Mistroke
.61279 .25 L
.6128 .25 L
.6128 .25 L
.61281 .25 L
.61281 .25 L
.61281 .25 L
.61282 .25 L
.61282 .25 L
.61283 .25 L
.61284 .25 L
.61284 .25 L
.61285 .25 L
.61286 .25 L
.61286 .25 L
.61287 .25 L
.61287 .25 L
.61288 .25 L
.61289 .25 L
.61289 .25 L
.6129 .25 L
.61291 .25 L
.61291 .25 L
.61292 .25 L
.61293 .25 L
.61293 .25 L
.61293 .25 L
.61294 .25 L
.61294 .25 L
.61295 .25 L
.61295 .25 L
.61295 .25 L
.61296 .25 L
.61296 .25 L
.61297 .25 L
.61297 .25 L
.61298 .25 L
.61298 .25 L
.61298 .25 L
.61299 .25 L
.61299 .25 L
.613 .25 L
.613 .25 L
.61301 .25 L
.61302 .25 L
.61302 .25 L
.61303 .25 L
.61304 .25 L
.61304 .25 L
.61305 .25 L
.61305 .25 L
Mistroke
.61306 .25 L
.61307 .25 L
.61307 .25 L
.61308 .25 L
.61309 .25 L
.61309 .25 L
.6131 .25 L
.6131 .25 L
.61311 .25 L
.61311 .25 L
.61312 .25 L
.61313 .25 L
.61313 .25 L
.61314 .25 L
.61314 .25 L
.61315 .25 L
.61316 .25 L
.61316 .25 L
.61317 .25 L
.61317 .25 L
.61318 .25 L
.61319 .25 L
.61319 .25 L
.61319 .25 L
.6132 .25 L
.61321 .25 L
.61321 .25 L
.61322 .25 L
.61323 .25 L
.61323 .25 L
.61324 .25 L
.61324 .25 L
.61325 .25 L
.61326 .25 L
.61326 .25 L
.61327 .25 L
.61328 .25 L
.61328 .25 L
.61329 .25 L
.61329 .25 L
.6133 .25 L
.6133 .25 L
.61331 .25 L
.61332 .25 L
.61332 .25 L
.61333 .25 L
.61334 .25 L
.61334 .25 L
.61335 .25 L
.61335 .25 L
Mistroke
.61336 .25 L
.61336 .25 L
.61337 .25 L
.61338 .25 L
.61338 .25 L
.61339 .25 L
.61339 .25 L
.6134 .25 L
.6134 .25 L
.61341 .25 L
.61342 .25 L
.61342 .25 L
.61343 .25 L
.61344 .25 L
.61344 .25 L
.61345 .25 L
.61345 .25 L
.61346 .25 L
.61347 .25 L
.61347 .25 L
.61348 .25 L
.61349 .25 L
.61349 .25 L
.6135 .25 L
.6135 .25 L
.61351 .25 L
.61351 .25 L
.61352 .25 L
.61353 .25 L
.61353 .25 L
.61354 .25 L
.61354 .25 L
.61355 .25 L
.61355 .25 L
.61356 .25 L
.61357 .25 L
.61357 .25 L
.61358 .25 L
.61358 .25 L
.61359 .25 L
.6136 .25 L
.6136 .25 L
.6136 .25 L
.61361 .25 L
.61362 .25 L
.61362 .25 L
.61363 .25 L
.61363 .25 L
.61364 .25 L
.61364 .25 L
Mistroke
.61365 .25 L
.61366 .25 L
.61366 .25 L
.61367 .25 L
.61367 .25 L
.61368 .25 L
.61368 .25 L
.61369 .25 L
.61369 .25 L
.6137 .25 L
.6137 .25 L
.61371 .25 L
.61372 .25 L
.61372 .25 L
.61373 .25 L
.61373 .25 L
.61374 .25 L
.61375 .25 L
.61375 .25 L
.61376 .25 L
.61376 .25 L
.61377 .25 L
.61378 .25 L
.61378 .25 L
.61379 .25 L
.6138 .25 L
.6138 .25 L
.61381 .25 L
.61381 .25 L
.61382 .25 L
.61383 .25 L
.61383 .25 L
.61384 .25 L
.61384 .25 L
.61384 .25 L
.61385 .25 L
.61386 .25 L
.61386 .25 L
.61387 .25 L
.61388 .25 L
.61388 .25 L
.61389 .25 L
.61389 .25 L
.6139 .25 L
.61391 .25 L
.61391 .25 L
.61392 .25 L
.61393 .25 L
.61393 .25 L
.61394 .25 L
Mistroke
.61394 .25 L
.61395 .25 L
.61396 .25 L
.61396 .25 L
.61397 .25 L
.61397 .25 L
.61397 .25 L
.61398 .25 L
.61398 .25 L
.61399 .25 L
.61399 .25 L
.61399 .25 L
.614 .25 L
.614 .25 L
.61401 .25 L
.61401 .25 L
.61401 .25 L
.61402 .25 L
.61402 .25 L
.61403 .25 L
.61404 .25 L
.61404 .25 L
.61405 .25 L
.61406 .25 L
.61406 .25 L
.61407 .25 L
.61408 .25 L
.61408 .25 L
.61409 .25 L
.61409 .25 L
.6141 .25 L
.61411 .25 L
.61411 .25 L
.61412 .25 L
.61412 .25 L
.61413 .25 L
.61414 .25 L
.61414 .25 L
.61415 .25 L
.61415 .25 L
.61416 .25 L
.61417 .25 L
.61417 .25 L
.61418 .25 L
.61418 .25 L
.61419 .25 L
.61419 .25 L
.6142 .25 L
.61421 .25 L
.61421 .25 L
Mistroke
.61422 .25 L
.61422 .25 L
.61423 .25 L
.61423 .25 L
.61424 .25 L
.61425 .25 L
.61425 .25 L
.61426 .25 L
.61427 .25 L
.61427 .25 L
.61428 .25 L
.61428 .25 L
.61429 .25 L
.6143 .25 L
.6143 .25 L
.61431 .25 L
.61432 .25 L
.61432 .25 L
.61432 .25 L
.61433 .25 L
.61434 .25 L
.61434 .25 L
.61435 .25 L
.61436 .25 L
.61436 .25 L
.61437 .25 L
.61437 .25 L
.61438 .25 L
.61438 .25 L
.61439 .25 L
.6144 .25 L
.6144 .25 L
.61441 .25 L
.61442 .25 L
.61442 .25 L
.61442 .25 L
.61443 .25 L
.61444 .25 L
.61444 .25 L
.61445 .25 L
.61445 .25 L
.61446 .25 L
.61446 .25 L
.61447 .25 L
.61447 .25 L
.61448 .25 L
.61449 .25 L
.61449 .25 L
.6145 .25 L
.6145 .25 L
Mistroke
.61451 .25 L
.61451 .25 L
.61451 .25 L
.61452 .25 L
.61453 .25 L
.61453 .25 L
.61454 .25 L
.61455 .25 L
.61455 .25 L
.61456 .25 L
.61456 .25 L
.61457 .25 L
.61458 .25 L
.61458 .25 L
.61459 .25 L
.61459 .25 L
.6146 .25 L
.61461 .25 L
.61461 .25 L
.61462 .25 L
.61463 .25 L
.61463 .25 L
.61464 .25 L
.61465 .25 L
.61465 .25 L
.61466 .25 L
.61466 .25 L
.61466 .25 L
.61467 .25 L
.61467 .25 L
.61468 .25 L
.61469 .25 L
.61469 .25 L
.6147 .25 L
.61471 .25 L
.61471 .25 L
.61472 .25 L
.61472 .25 L
.61473 .25 L
.61474 .25 L
.61474 .25 L
.61475 .25 L
.61476 .25 L
.61476 .25 L
.61477 .25 L
.61478 .25 L
.61478 .25 L
.61478 .25 L
.61479 .25 L
.61479 .25 L
Mistroke
.6148 .25 L
.6148 .25 L
.6148 .25 L
.61481 .25 L
.61482 .25 L
.61482 .25 L
.61482 .25 L
.61483 .25 L
.61483 .25 L
.61483 .25 L
.61484 .25 L
.61484 .25 L
.61485 .25 L
.61485 .25 L
.61486 .25 L
.61487 .25 L
.61487 .25 L
.61488 .25 L
.61489 .25 L
.61489 .25 L
.6149 .25 L
.61491 .25 L
.61491 .25 L
.61492 .25 L
.61492 .25 L
.61493 .25 L
.61494 .25 L
.61494 .25 L
.61495 .25 L
.61495 .25 L
.61496 .25 L
.61496 .25 L
.61497 .25 L
.61498 .25 L
.61498 .25 L
.61499 .25 L
.61499 .25 L
.615 .25 L
.61501 .25 L
.61501 .25 L
.61502 .25 L
.61502 .25 L
.61503 .25 L
.61504 .25 L
.61504 .25 L
.61504 .25 L
.61505 .25 L
.61506 .25 L
.61506 .25 L
.61507 .25 L
Mistroke
.61508 .25 L
.61508 .25 L
.61509 .25 L
.6151 .25 L
.6151 .25 L
.61511 .25 L
.61511 .25 L
.61512 .25 L
.61513 .25 L
.61513 .25 L
.61514 .25 L
.61514 .25 L
.61515 .25 L
.61516 .25 L
.61516 .25 L
.61517 .25 L
.61517 .25 L
.61518 .25 L
.61519 .25 L
.61519 .25 L
.6152 .25 L
.6152 .25 L
.61521 .25 L
.61521 .25 L
.61522 .25 L
.61523 .25 L
.61523 .25 L
.61524 .25 L
.61524 .25 L
.61525 .25 L
.61525 .25 L
.61526 .25 L
.61527 .25 L
.61527 .25 L
.61527 .25 L
.61528 .25 L
.61529 .25 L
.61529 .25 L
.6153 .25 L
.6153 .25 L
.61531 .25 L
.61532 .25 L
.61532 .25 L
.61532 .25 L
.61533 .25 L
.61533 .25 L
.61534 .25 L
.61534 .25 L
.61535 .25 L
.61536 .25 L
Mistroke
.61536 .25 L
.61537 .25 L
.61538 .25 L
.61538 .25 L
.61539 .25 L
.61539 .25 L
.6154 .25 L
.61541 .25 L
.61541 .25 L
.61542 .25 L
.61542 .25 L
.61543 .25 L
.61544 .25 L
.61544 .25 L
.61545 .25 L
.61546 .25 L
.61546 .25 L
.61547 .25 L
.61548 .25 L
.61548 .25 L
.61548 .25 L
.61549 .25 L
.61549 .25 L
.6155 .25 L
.6155 .25 L
.61551 .25 L
.61552 .25 L
.61552 .25 L
.61553 .25 L
.61554 .25 L
.61554 .25 L
.61555 .25 L
.61555 .25 L
.61556 .25 L
.61557 .25 L
.61557 .25 L
.61558 .25 L
.61559 .25 L
.61559 .25 L
.6156 .25 L
.6156 .25 L
.61561 .25 L
.61561 .25 L
.61562 .25 L
.61562 .25 L
.61562 .25 L
.61563 .25 L
.61564 .25 L
.61564 .25 L
.61564 .25 L
Mistroke
.61565 .25 L
.61565 .25 L
.61565 .25 L
.61566 .25 L
.61566 .25 L
.61567 .25 L
.61567 .25 L
.61568 .25 L
.61569 .25 L
.61569 .25 L
.6157 .25 L
.6157 .25 L
.61571 .25 L
.61572 .25 L
.61572 .25 L
.61573 .25 L
.61574 .25 L
.61574 .25 L
.61575 .25 L
.61575 .25 L
.61576 .25 L
.61577 .25 L
.61577 .25 L
.61578 .25 L
.61578 .25 L
.61579 .25 L
.61579 .25 L
.6158 .25 L
.61581 .25 L
.61581 .25 L
.61582 .25 L
.61582 .25 L
.61583 .25 L
.61584 .25 L
.61584 .25 L
.61585 .25 L
.61585 .25 L
.61586 .25 L
.61586 .25 L
.61587 .25 L
.61587 .25 L
.61588 .25 L
.61589 .25 L
.61589 .25 L
.6159 .25 L
.61591 .25 L
.61591 .25 L
.61592 .25 L
.61593 .25 L
.61593 .25 L
Mistroke
.61594 .25 L
.61594 .25 L
.61595 .25 L
.61596 .25 L
.61596 .25 L
.61597 .25 L
.61597 .25 L
.61598 .25 L
.61599 .25 L
.61599 .25 L
.616 .25 L
.616 .25 L
.61601 .25 L
.61602 .25 L
.61602 .25 L
.61603 .25 L
.61603 .25 L
.61604 .25 L
.61604 .25 L
.61605 .25 L
.61606 .25 L
.61606 .25 L
.61607 .25 L
.61607 .25 L
.61608 .25 L
.61608 .25 L
.61609 .25 L
.61609 .25 L
.6161 .25 L
.6161 .25 L
.61611 .25 L
.61612 .25 L
.61612 .25 L
.61613 .25 L
.61613 .25 L
.61614 .25 L
.61614 .25 L
.61615 .25 L
.61615 .25 L
.61616 .25 L
.61616 .25 L
.61617 .25 L
.61618 .25 L
.61618 .25 L
.61619 .25 L
.61619 .25 L
.6162 .25 L
.61621 .25 L
.61621 .25 L
.61622 .25 L
Mistroke
.61622 .25 L
.61623 .25 L
.61624 .25 L
.61624 .25 L
.61625 .25 L
.61625 .25 L
.61626 .25 L
.61627 .25 L
.61627 .25 L
.61628 .25 L
.61629 .25 L
.61629 .25 L
.6163 .25 L
.6163 .25 L
.61631 .25 L
.61631 .25 L
.61631 .25 L
.61632 .25 L
.61633 .25 L
.61633 .25 L
.61634 .25 L
.61635 .25 L
.61635 .25 L
.61636 .25 L
.61636 .25 L
.61637 .25 L
.61638 .25 L
.61638 .25 L
.61639 .25 L
.6164 .25 L
.6164 .25 L
.61641 .25 L
.61642 .25 L
.61642 .25 L
.61643 .25 L
.61643 .25 L
.61644 .25 L
.61644 .25 L
.61644 .25 L
.61645 .25 L
.61645 .25 L
.61646 .25 L
.61646 .25 L
.61647 .25 L
.61647 .25 L
.61647 .25 L
.61648 .25 L
.61648 .25 L
.61649 .25 L
.61649 .25 L
Mistroke
.6165 .25 L
.6165 .25 L
.61651 .25 L
.61652 .25 L
.61652 .25 L
.61653 .25 L
.61653 .25 L
.61654 .25 L
.61655 .25 L
.61655 .25 L
.61656 .25 L
.61657 .25 L
.61657 .25 L
.61658 .25 L
.61659 .25 L
.61659 .25 L
.61659 .25 L
.6166 .25 L
.61661 .25 L
.61661 .25 L
.61662 .25 L
.61662 .25 L
.61663 .25 L
.61664 .25 L
.61664 .25 L
.61665 .25 L
.61665 .25 L
.61666 .25 L
.61667 .25 L
.61667 .25 L
.61668 .25 L
.61668 .25 L
.61669 .25 L
.61669 .25 L
.6167 .25 L
.6167 .25 L
.61671 .25 L
.61672 .25 L
.61672 .25 L
.61673 .25 L
.61674 .25 L
.61674 .25 L
.61675 .25 L
.61675 .25 L
.61676 .25 L
.61677 .25 L
.61677 .25 L
.61678 .25 L
.61679 .25 L
.61679 .25 L
Mistroke
.6168 .25 L
.6168 .25 L
.61681 .25 L
.61681 .25 L
.61682 .25 L
.61683 .25 L
.61683 .25 L
.61684 .25 L
.61684 .25 L
.61685 .25 L
.61686 .25 L
.61686 .25 L
.61687 .25 L
.61687 .25 L
.61688 .25 L
.61689 .25 L
.61689 .25 L
.61689 .25 L
.6169 .25 L
.61691 .25 L
.61691 .25 L
.61692 .25 L
.61693 .25 L
.61693 .25 L
.61694 .25 L
.61694 .25 L
.61695 .25 L
.61696 .25 L
.61696 .25 L
.61697 .25 L
.61698 .25 L
.61698 .25 L
.61699 .25 L
.61699 .25 L
.617 .25 L
.617 .25 L
.61701 .25 L
.61702 .25 L
.61702 .25 L
.61703 .25 L
.61704 .25 L
.61704 .25 L
.61705 .25 L
.61705 .25 L
.61706 .25 L
.61706 .25 L
.61707 .25 L
.61708 .25 L
.61708 .25 L
.61709 .25 L
Mistroke
.61709 .25 L
.6171 .25 L
.6171 .25 L
.61711 .25 L
.61712 .25 L
.61712 .25 L
.61712 .25 L
.61713 .25 L
.61714 .25 L
.61714 .25 L
.61715 .25 L
.61715 .25 L
.61716 .25 L
.61717 .25 L
.61717 .25 L
.61717 .25 L
.61718 .25 L
.61718 .25 L
.61719 .25 L
.61719 .25 L
.6172 .25 L
.61721 .25 L
.61721 .25 L
.61722 .25 L
.61723 .25 L
.61723 .25 L
.61724 .25 L
.61724 .25 L
.61725 .25 L
.61726 .25 L
.61726 .25 L
.61727 .25 L
.61727 .25 L
.61728 .25 L
.61729 .25 L
.61729 .25 L
.6173 .25 L
.61731 .25 L
.61731 .25 L
.61732 .25 L
.61733 .25 L
.61733 .25 L
.61733 .25 L
.61734 .25 L
.61734 .25 L
.61735 .25 L
.61735 .25 L
.61736 .25 L
.61737 .25 L
.61737 .25 L
Mistroke
.61738 .25 L
.61739 .25 L
.61739 .25 L
.6174 .25 L
.6174 .25 L
.61741 .25 L
.61742 .25 L
.61742 .25 L
.61743 .25 L
.61744 .25 L
.61744 .25 L
.61745 .25 L
.61745 .25 L
.61746 .25 L
.61746 .25 L
.61747 .25 L
.61747 .25 L
.61747 .25 L
.61748 .25 L
.61749 .25 L
.61749 .25 L
.61749 .25 L
.6175 .25 L
.6175 .25 L
.6175 .25 L
.61751 .25 L
.61751 .25 L
.61752 .25 L
.61752 .25 L
.61753 .25 L
.61754 .25 L
.61754 .25 L
.61755 .25 L
.61756 .25 L
.61756 .25 L
.61757 .25 L
.61757 .25 L
.61758 .25 L
.61759 .25 L
.61759 .25 L
.6176 .25 L
.61761 .25 L
.61761 .25 L
.61762 .25 L
.61762 .25 L
.61763 .25 L
.61763 .25 L
.61764 .25 L
.61765 .25 L
.61765 .25 L
Mistroke
.61766 .25 L
.61766 .25 L
.61767 .25 L
.61767 .25 L
.61768 .25 L
.61769 .25 L
.61769 .25 L
.6177 .25 L
.6177 .25 L
.61771 .25 L
.61771 .25 L
.61772 .25 L
.61772 .25 L
.61773 .25 L
.61774 .25 L
.61774 .25 L
.61775 .25 L
.61776 .25 L
.61776 .25 L
.61777 .25 L
.61778 .25 L
.61778 .25 L
.61779 .25 L
.6178 .25 L
.6178 .25 L
.61781 .25 L
.61781 .25 L
.61782 .25 L
.61782 .25 L
.61783 .25 L
.61784 .25 L
.61784 .25 L
.61785 .25 L
.61785 .25 L
.61786 .25 L
.61787 .25 L
.61787 .25 L
.61788 .25 L
.61788 .25 L
.61789 .25 L
.6179 .25 L
.6179 .25 L
.61791 .25 L
.61791 .25 L
.61792 .25 L
.61792 .25 L
.61793 .25 L
.61793 .25 L
.61794 .25 L
.61794 .25 L
Mistroke
.61795 .25 L
.61795 .25 L
.61796 .25 L
.61797 .25 L
.61797 .25 L
.61798 .25 L
.61798 .25 L
.61799 .25 L
.61799 .25 L
.618 .25 L
.61801 .25 L
.61801 .25 L
.61801 .25 L
.61802 .25 L
.61803 .25 L
.61803 .25 L
.61804 .25 L
.61804 .25 L
.61805 .25 L
.61806 .25 L
.61806 .25 L
.61807 .25 L
.61807 .25 L
.61808 .25 L
.61809 .25 L
.61809 .25 L
.6181 .25 L
.6181 .25 L
.61811 .25 L
.61812 .25 L
.61812 .25 L
.61813 .25 L
.61814 .25 L
.61814 .25 L
.61815 .25 L
.61815 .25 L
.61816 .25 L
.61816 .25 L
.61816 .25 L
.61817 .25 L
.61818 .25 L
.61818 .25 L
.61819 .25 L
.6182 .25 L
.6182 .25 L
.61821 .25 L
.61822 .25 L
.61822 .25 L
.61823 .25 L
.61824 .25 L
Mistroke
.61824 .25 L
.61825 .25 L
.61825 .25 L
.61826 .25 L
.61827 .25 L
.61827 .25 L
.61828 .25 L
.61828 .25 L
.61829 .25 L
.61829 .25 L
.6183 .25 L
.6183 .25 L
.6183 .25 L
.61831 .25 L
.61831 .25 L
.61832 .25 L
.61832 .25 L
.61833 .25 L
.61833 .25 L
.61833 .25 L
.61834 .25 L
.61834 .25 L
.61835 .25 L
.61835 .25 L
.61836 .25 L
.61837 .25 L
.61837 .25 L
.61838 .25 L
.61839 .25 L
.61839 .25 L
.6184 .25 L
.6184 .25 L
.61841 .25 L
.61842 .25 L
.61842 .25 L
.61843 .25 L
.61844 .25 L
.61844 .25 L
.61844 .25 L
.61845 .25 L
.61846 .25 L
.61846 .25 L
.61847 .25 L
.61848 .25 L
.61848 .25 L
.61849 .25 L
.61849 .25 L
.6185 .25 L
.6185 .25 L
.61851 .25 L
Mistroke
.61852 .25 L
.61852 .25 L
.61853 .25 L
.61854 .25 L
.61854 .25 L
.61854 .25 L
.61855 .25 L
.61856 .25 L
.61856 .25 L
.61857 .25 L
.61858 .25 L
.61858 .25 L
.61859 .25 L
.61859 .25 L
.6186 .25 L
.61861 .25 L
.61861 .25 L
.61862 .25 L
.61863 .25 L
.61863 .25 L
.61864 .25 L
.61864 .25 L
.61865 .25 L
.61865 .25 L
.61866 .25 L
.61867 .25 L
.61867 .25 L
.61868 .25 L
.61868 .25 L
.61869 .25 L
.6187 .25 L
.6187 .25 L
.61871 .25 L
.61871 .25 L
.61872 .25 L
.61873 .25 L
.61873 .25 L
.61874 .25 L
.61874 .25 L
.61874 .25 L
.61875 .25 L
.61876 .25 L
.61876 .25 L
.61877 .25 L
.61877 .25 L
.61878 .25 L
.61878 .25 L
.61879 .25 L
.6188 .25 L
.6188 .25 L
Mistroke
.61881 .25 L
.61881 .25 L
.61882 .25 L
.61882 .25 L
.61883 .25 L
.61883 .25 L
.61884 .25 L
.61884 .25 L
.61885 .25 L
.61886 .25 L
.61886 .25 L
.61887 .25 L
.61887 .25 L
.61888 .25 L
.61889 .25 L
.61889 .25 L
.6189 .25 L
.6189 .25 L
.61891 .25 L
.61892 .25 L
.61892 .25 L
.61893 .25 L
.61893 .25 L
.61894 .25 L
.61895 .25 L
.61895 .25 L
.61896 .25 L
.61897 .25 L
.61897 .25 L
.61898 .25 L
.61898 .25 L
.61898 .25 L
.61899 .25 L
.619 .25 L
.619 .25 L
.61901 .25 L
.61902 .25 L
.61902 .25 L
.61903 .25 L
.61903 .25 L
.61904 .25 L
.61905 .25 L
.61905 .25 L
.61906 .25 L
.61906 .25 L
.61907 .25 L
.61908 .25 L
.61908 .25 L
.61909 .25 L
.6191 .25 L
Mistroke
.6191 .25 L
.61911 .25 L
.61911 .25 L
.61912 .25 L
.61912 .25 L
.61912 .25 L
.61913 .25 L
.61913 .25 L
.61914 .25 L
.61914 .25 L
.61914 .25 L
.61915 .25 L
.61915 .25 L
.61916 .25 L
.61916 .25 L
.61916 .25 L
.61917 .25 L
.61918 .25 L
.61918 .25 L
.61919 .25 L
.6192 .25 L
.6192 .25 L
.61921 .25 L
.61921 .25 L
.61922 .25 L
.61923 .25 L
.61923 .25 L
.61924 .25 L
.61925 .25 L
.61925 .25 L
.61926 .25 L
.61926 .25 L
.61927 .25 L
.61927 .25 L
.61928 .25 L
.61929 .25 L
.61929 .25 L
.6193 .25 L
.61931 .25 L
.61931 .25 L
.61932 .25 L
.61932 .25 L
.61933 .25 L
.61933 .25 L
.61934 .25 L
.61935 .25 L
.61935 .25 L
.61936 .25 L
.61936 .25 L
.61937 .25 L
Mistroke
.61937 .25 L
.61938 .25 L
.61939 .25 L
.61939 .25 L
.6194 .25 L
.61941 .25 L
.61941 .25 L
.61942 .25 L
.61942 .25 L
.61943 .25 L
.61944 .25 L
.61944 .25 L
.61945 .25 L
.61946 .25 L
.61946 .25 L
.61947 .25 L
.61947 .25 L
.61948 .25 L
.61948 .25 L
.61949 .25 L
.6195 .25 L
.6195 .25 L
.61951 .25 L
.61951 .25 L
.61952 .25 L
.61952 .25 L
.61953 .25 L
.61954 .25 L
.61954 .25 L
.61955 .25 L
.61955 .25 L
.61956 .25 L
.61957 .25 L
.61957 .25 L
.61957 .25 L
.61958 .25 L
.61959 .25 L
.61959 .25 L
.6196 .25 L
.6196 .25 L
.61961 .25 L
.61961 .25 L
.61962 .25 L
.61963 .25 L
.61963 .25 L
.61964 .25 L
.61964 .25 L
.61965 .25 L
.61965 .25 L
.61966 .25 L
Mistroke
.61966 .25 L
.61967 .25 L
.61967 .25 L
.61968 .25 L
.61969 .25 L
.61969 .25 L
.6197 .25 L
.6197 .25 L
.61971 .25 L
.61972 .25 L
.61972 .25 L
.61973 .25 L
.61973 .25 L
.61974 .25 L
.61975 .25 L
.61975 .25 L
.61976 .25 L
.61976 .25 L
.61977 .25 L
.61978 .25 L
.61978 .25 L
.61979 .25 L
.6198 .25 L
.6198 .25 L
.6198 .25 L
.61981 .25 L
.61981 .25 L
.61982 .25 L
.61983 .25 L
.61983 .25 L
.61984 .25 L
.61984 .25 L
.61985 .25 L
.61986 .25 L
.61986 .25 L
.61987 .25 L
.61988 .25 L
.61988 .25 L
.61989 .25 L
.6199 .25 L
.6199 .25 L
.61991 .25 L
.61991 .25 L
.61992 .25 L
.61993 .25 L
.61993 .25 L
.61994 .25 L
.61994 .25 L
.61994 .25 L
.61995 .25 L
Mistroke
.61995 .25 L
.61996 .25 L
.61996 .25 L
.61996 .25 L
.61997 .25 L
.61997 .25 L
.61998 .25 L
.61998 .25 L
.61998 .25 L
.61999 .25 L
.61999 .25 L
.62 .25 L
.62001 .25 L
.62001 .25 L
.62002 .25 L
.62003 .25 L
.62003 .25 L
.62004 .25 L
.62004 .25 L
.62005 .25 L
.62006 .25 L
.62006 .25 L
.62007 .25 L
.62008 .25 L
.62008 .25 L
.62009 .25 L
.62009 .25 L
.6201 .25 L
.6201 .25 L
.62011 .25 L
.62012 .25 L
.62012 .25 L
.62013 .25 L
.62013 .25 L
.62014 .25 L
.62015 .25 L
.62015 .25 L
.62016 .25 L
.62016 .25 L
.62017 .25 L
.62018 .25 L
.62018 .25 L
.62019 .25 L
.62019 .25 L
.6202 .25 L
.6202 .25 L
.62021 .25 L
.62022 .25 L
.62022 .25 L
.62023 .25 L
Mistroke
.62023 .25 L
.62024 .25 L
.62025 .25 L
.62025 .25 L
.62026 .25 L
.62027 .25 L
.62027 .25 L
.62028 .25 L
.62029 .25 L
.62029 .25 L
.62029 .25 L
.6203 .25 L
.62031 .25 L
.62031 .25 L
.62032 .25 L
.62033 .25 L
.62033 .25 L
.62034 .25 L
.62034 .25 L
.62035 .25 L
.62035 .25 L
.62036 .25 L
.62037 .25 L
.62037 .25 L
.62038 .25 L
.62038 .25 L
.62039 .25 L
.62039 .25 L
.6204 .25 L
.6204 .25 L
.62041 .25 L
.62042 .25 L
.62042 .25 L
.62042 .25 L
.62043 .25 L
.62044 .25 L
.62044 .25 L
.62045 .25 L
.62046 .25 L
.62046 .25 L
.62047 .25 L
.62047 .25 L
.62048 .25 L
.62048 .25 L
.62048 .25 L
.62049 .25 L
.6205 .25 L
.6205 .25 L
.62051 .25 L
.62052 .25 L
Mistroke
.62052 .25 L
.62053 .25 L
.62053 .25 L
.62054 .25 L
.62055 .25 L
.62055 .25 L
.62056 .25 L
.62056 .25 L
.62057 .25 L
.62058 .25 L
.62058 .25 L
.62059 .25 L
.6206 .25 L
.6206 .25 L
.62061 .25 L
.62061 .25 L
.62062 .25 L
.62062 .25 L
.62063 .25 L
.62063 .25 L
.62064 .25 L
.62064 .25 L
.62065 .25 L
.62066 .25 L
.62066 .25 L
.62067 .25 L
.62067 .25 L
.62068 .25 L
.62069 .25 L
.62069 .25 L
.6207 .25 L
.62071 .25 L
.62071 .25 L
.62072 .25 L
.62073 .25 L
.62073 .25 L
.62074 .25 L
.62074 .25 L
.62075 .25 L
.62075 .25 L
.62076 .25 L
.62076 .25 L
.62077 .25 L
.62077 .25 L
.62077 .25 L
.62078 .25 L
.62078 .25 L
.62079 .25 L
.62079 .25 L
.6208 .25 L
Mistroke
.6208 .25 L
.6208 .25 L
.62081 .25 L
.62081 .25 L
.62082 .25 L
.62082 .25 L
.62083 .25 L
.62084 .25 L
.62084 .25 L
.62085 .25 L
.62086 .25 L
.62086 .25 L
.62087 .25 L
.62087 .25 L
.62088 .25 L
.62089 .25 L
.62089 .25 L
.6209 .25 L
.62091 .25 L
.62091 .25 L
.62091 .25 L
.62092 .25 L
.62093 .25 L
.62093 .25 L
.62094 .25 L
.62095 .25 L
.62095 .25 L
.62096 .25 L
.62096 .25 L
.62097 .25 L
.62097 .25 L
.62098 .25 L
.62099 .25 L
.62099 .25 L
.621 .25 L
.62101 .25 L
.62101 .25 L
.62101 .25 L
.62102 .25 L
.62103 .25 L
.62103 .25 L
.62104 .25 L
.62105 .25 L
.62105 .25 L
.62106 .25 L
.62106 .25 L
.62107 .25 L
.62108 .25 L
.62108 .25 L
.62109 .25 L
Mistroke
.6211 .25 L
.6211 .25 L
.62111 .25 L
.62111 .25 L
.62112 .25 L
.62112 .25 L
.62113 .25 L
.62114 .25 L
.62114 .25 L
.62115 .25 L
.62115 .25 L
.62116 .25 L
.62117 .25 L
.62117 .25 L
.62118 .25 L
.62118 .25 L
.62119 .25 L
.6212 .25 L
.6212 .25 L
.62121 .25 L
.62121 .25 L
.62122 .25 L
.62122 .25 L
.62123 .25 L
.62123 .25 L
.62124 .25 L
.62125 .25 L
.62125 .25 L
.62126 .25 L
.62127 .25 L
.62127 .25 L
.62128 .25 L
.62129 .25 L
.62129 .25 L
.6213 .25 L
.6213 .25 L
.62131 .25 L
.62132 .25 L
.62132 .25 L
.62133 .25 L
.62133 .25 L
.62134 .25 L
.62134 .25 L
.62135 .25 L
.62136 .25 L
.62136 .25 L
.62137 .25 L
.62137 .25 L
.62138 .25 L
.62139 .25 L
Mistroke
.62139 .25 L
.6214 .25 L
.6214 .25 L
.62141 .25 L
.62141 .25 L
.62142 .25 L
.62142 .25 L
.62143 .25 L
.62144 .25 L
.62144 .25 L
.62144 .25 L
.62145 .25 L
.62146 .25 L
.62146 .25 L
.62147 .25 L
.62147 .25 L
.62148 .25 L
.62149 .25 L
.62149 .25 L
.6215 .25 L
.6215 .25 L
.62151 .25 L
.62151 .25 L
.62152 .25 L
.62152 .25 L
.62153 .25 L
.62154 .25 L
.62154 .25 L
.62155 .25 L
.62155 .25 L
.62156 .25 L
.62156 .25 L
.62157 .25 L
.62158 .25 L
.62158 .25 L
.62159 .25 L
.6216 .25 L
.6216 .25 L
.62161 .25 L
.62161 .25 L
.62162 .25 L
.62163 .25 L
.62163 .25 L
.62164 .25 L
.62165 .25 L
.62165 .25 L
.62165 .25 L
.62166 .25 L
.62166 .25 L
.62167 .25 L
Mistroke
.62167 .25 L
.62168 .25 L
.62169 .25 L
.62169 .25 L
.6217 .25 L
.62171 .25 L
.62171 .25 L
.62172 .25 L
.62173 .25 L
.62173 .25 L
.62174 .25 L
.62174 .25 L
.62175 .25 L
.62176 .25 L
.62176 .25 L
.62177 .25 L
.62178 .25 L
.62178 .25 L
.62179 .25 L
.62179 .25 L
.62179 .25 L
.6218 .25 L
.6218 .25 L
.62181 .25 L
.62181 .25 L
.62181 .25 L
.62182 .25 L
.62182 .25 L
.62183 .25 L
.62183 .25 L
.62183 .25 L
.62184 .25 L
.62184 .25 L
.62185 .25 L
.62186 .25 L
.62186 .25 L
.62187 .25 L
.62188 .25 L
.62188 .25 L
.62189 .25 L
.62189 .25 L
.6219 .25 L
.62191 .25 L
.62191 .25 L
.62192 .25 L
.62193 .25 L
.62193 .25 L
.62194 .25 L
.62194 .25 L
.62195 .25 L
Mistroke
.62195 .25 L
.62196 .25 L
.62197 .25 L
.62197 .25 L
.62198 .25 L
.62198 .25 L
.62199 .25 L
.622 .25 L
.622 .25 L
.62201 .25 L
.62201 .25 L
.62202 .25 L
.62203 .25 L
.62203 .25 L
.62204 .25 L
.62204 .25 L
.62205 .25 L
.62205 .25 L
.62206 .25 L
.62207 .25 L
.62207 .25 L
.62208 .25 L
.62208 .25 L
.62209 .25 L
.6221 .25 L
.6221 .25 L
.62211 .25 L
.62212 .25 L
.62212 .25 L
.62213 .25 L
.62214 .25 L
.62214 .25 L
.62214 .25 L
.62215 .25 L
.62216 .25 L
.62216 .25 L
.62217 .25 L
.62218 .25 L
.62218 .25 L
.62219 .25 L
.62219 .25 L
.6222 .25 L
.6222 .25 L
.62221 .25 L
.62222 .25 L
.62222 .25 L
.62223 .25 L
.62223 .25 L
.62224 .25 L
.62224 .25 L
Mistroke
.62225 .25 L
.62225 .25 L
.62226 .25 L
.62227 .25 L
.62227 .25 L
.62227 .25 L
.62228 .25 L
.62229 .25 L
.62229 .25 L
.6223 .25 L
.62231 .25 L
.62231 .25 L
.62232 .25 L
.62232 .25 L
.62233 .25 L
.62233 .25 L
.62233 .25 L
.62234 .25 L
.62235 .25 L
.62235 .25 L
.62236 .25 L
.62237 .25 L
.62237 .25 L
.62238 .25 L
.62238 .25 L
.62239 .25 L
.6224 .25 L
.6224 .25 L
.62241 .25 L
.62241 .25 L
.62242 .25 L
.62243 .25 L
.62243 .25 L
.62244 .25 L
.62245 .25 L
.62245 .25 L
.62246 .25 L
.62246 .25 L
.62247 .25 L
.62247 .25 L
.62248 .25 L
.62248 .25 L
.62249 .25 L
.62249 .25 L
.6225 .25 L
.62251 .25 L
.62251 .25 L
.62252 .25 L
.62252 .25 L
.62253 .25 L
Mistroke
.62254 .25 L
.62254 .25 L
.62255 .25 L
.62256 .25 L
.62256 .25 L
.62257 .25 L
.62258 .25 L
.62258 .25 L
.62259 .25 L
.62259 .25 L
.6226 .25 L
.6226 .25 L
.62261 .25 L
.62261 .25 L
.62262 .25 L
.62262 .25 L
.62262 .25 L
.62263 .25 L
.62263 .25 L
.62264 .25 L
.62264 .25 L
.62265 .25 L
.62265 .25 L
.62265 .25 L
.62266 .25 L
.62266 .25 L
.62267 .25 L
.62267 .25 L
.62268 .25 L
.62269 .25 L
.62269 .25 L
.6227 .25 L
.62271 .25 L
.62271 .25 L
.62272 .25 L
.62272 .25 L
.62273 .25 L
.62274 .25 L
.62274 .25 L
.62275 .25 L
.62276 .25 L
.62276 .25 L
.62276 .25 L
.62277 .25 L
.62278 .25 L
.62278 .25 L
.62279 .25 L
.6228 .25 L
.6228 .25 L
.62281 .25 L
Mistroke
.62281 .25 L
.62282 .25 L
.62283 .25 L
.62283 .25 L
.62284 .25 L
.62284 .25 L
.62285 .25 L
.62286 .25 L
.62286 .25 L
.62286 .25 L
.62287 .25 L
.62288 .25 L
.62288 .25 L
.62289 .25 L
.6229 .25 L
.6229 .25 L
.62291 .25 L
.62291 .25 L
.62292 .25 L
.62293 .25 L
.62293 .25 L
.62294 .25 L
.62295 .25 L
.62295 .25 L
.62296 .25 L
.62296 .25 L
.62297 .25 L
.62297 .25 L
.62298 .25 L
.62299 .25 L
.62299 .25 L
.623 .25 L
.62301 .25 L
.62301 .25 L
.62302 .25 L
.62302 .25 L
.62303 .25 L
.62303 .25 L
.62304 .25 L
.62305 .25 L
.62305 .25 L
.62306 .25 L
.62306 .25 L
.62307 .25 L
.62307 .25 L
.62308 .25 L
.62309 .25 L
.62309 .25 L
.62309 .25 L
.6231 .25 L
Mistroke
.62311 .25 L
.62311 .25 L
.62312 .25 L
.62312 .25 L
.62313 .25 L
.62314 .25 L
.62314 .25 L
.62314 .25 L
.62315 .25 L
.62315 .25 L
.62316 .25 L
.62316 .25 L
.62317 .25 L
.62318 .25 L
.62318 .25 L
.62319 .25 L
.6232 .25 L
.6232 .25 L
.62321 .25 L
.62321 .25 L
.62322 .25 L
.62323 .25 L
.62323 .25 L
.62324 .25 L
.62324 .25 L
.62325 .25 L
.62326 .25 L
.62326 .25 L
.62327 .25 L
.62327 .25 L
.62328 .25 L
.62329 .25 L
.62329 .25 L
.6233 .25 L
.6233 .25 L
.62331 .25 L
.62331 .25 L
.62332 .25 L
.62332 .25 L
.62333 .25 L
.62334 .25 L
.62334 .25 L
.62335 .25 L
.62335 .25 L
.62336 .25 L
.62337 .25 L
.62337 .25 L
.62338 .25 L
.62339 .25 L
.62339 .25 L
Mistroke
.6234 .25 L
.62341 .25 L
.62341 .25 L
.62342 .25 L
.62342 .25 L
.62343 .25 L
.62343 .25 L
.62344 .25 L
.62344 .25 L
.62344 .25 L
.62345 .25 L
.62345 .25 L
.62346 .25 L
.62346 .25 L
.62347 .25 L
.62347 .25 L
.62347 .25 L
.62348 .25 L
.62348 .25 L
.62348 .25 L
.62349 .25 L
.6235 .25 L
.6235 .25 L
.62351 .25 L
.62352 .25 L
.62352 .25 L
.62353 .25 L
.62354 .25 L
.62354 .25 L
.62355 .25 L
.62355 .25 L
.62356 .25 L
.62357 .25 L
.62357 .25 L
.62358 .25 L
.62358 .25 L
.62359 .25 L
.6236 .25 L
.6236 .25 L
.62361 .25 L
.62361 .25 L
.62362 .25 L
.62363 .25 L
.62363 .25 L
.62364 .25 L
.62364 .25 L
.62365 .25 L
.62365 .25 L
.62366 .25 L
.62367 .25 L
Mistroke
.62367 .25 L
.62368 .25 L
.62368 .25 L
.62369 .25 L
.62369 .25 L
.6237 .25 L
.62371 .25 L
.62371 .25 L
.62372 .25 L
.62373 .25 L
.62373 .25 L
.62374 .25 L
.62374 .25 L
.62375 .25 L
.62376 .25 L
.62376 .25 L
.62377 .25 L
.62378 .25 L
.62378 .25 L
.62379 .25 L
.62379 .25 L
.6238 .25 L
.6238 .25 L
.62381 .25 L
.62382 .25 L
.62382 .25 L
.62383 .25 L
.62383 .25 L
.62384 .25 L
.62385 .25 L
.62385 .25 L
.62386 .25 L
.62386 .25 L
.62387 .25 L
.62388 .25 L
.62388 .25 L
.62389 .25 L
.62389 .25 L
.6239 .25 L
.6239 .25 L
.62391 .25 L
.62391 .25 L
.62392 .25 L
.62392 .25 L
.62393 .25 L
.62393 .25 L
.62394 .25 L
.62395 .25 L
.62395 .25 L
.62396 .25 L
Mistroke
.62396 .25 L
.62397 .25 L
.62397 .25 L
.62398 .25 L
.62398 .25 L
.62399 .25 L
.62399 .25 L
.624 .25 L
.62401 .25 L
.62401 .25 L
.62402 .25 L
.62402 .25 L
.62403 .25 L
.62404 .25 L
.62404 .25 L
.62405 .25 L
.62405 .25 L
.62406 .25 L
.62407 .25 L
.62407 .25 L
.62408 .25 L
.62409 .25 L
.62409 .25 L
.6241 .25 L
.6241 .25 L
.62411 .25 L
.62412 .25 L
.62412 .25 L
.62413 .25 L
.62413 .25 L
.62413 .25 L
.62414 .25 L
.62415 .25 L
.62415 .25 L
.62416 .25 L
.62417 .25 L
.62417 .25 L
.62418 .25 L
.62418 .25 L
.62419 .25 L
.6242 .25 L
.6242 .25 L
.62421 .25 L
.62422 .25 L
.62422 .25 L
.62423 .25 L
.62424 .25 L
.62424 .25 L
.62425 .25 L
.62425 .25 L
Mistroke
.62426 .25 L
.62426 .25 L
.62426 .25 L
.62427 .25 L
.62427 .25 L
.62428 .25 L
.62428 .25 L
.62429 .25 L
.62429 .25 L
.62429 .25 L
.6243 .25 L
.6243 .25 L
.6243 .25 L
.62431 .25 L
.62431 .25 L
.62432 .25 L
.62433 .25 L
.62433 .25 L
.62434 .25 L
.62435 .25 L
.62435 .25 L
.62436 .25 L
.62437 .25 L
.62437 .25 L
.62438 .25 L
.62438 .25 L
.62439 .25 L
.6244 .25 L
.6244 .25 L
.62441 .25 L
.62441 .25 L
.62442 .25 L
.62443 .25 L
.62443 .25 L
.62444 .25 L
.62444 .25 L
.62445 .25 L
.62446 .25 L
.62446 .25 L
.62447 .25 L
.62447 .25 L
.62448 .25 L
.62448 .25 L
.62449 .25 L
.6245 .25 L
.6245 .25 L
.62451 .25 L
.62451 .25 L
.62452 .25 L
.62452 .25 L
Mistroke
.62453 .25 L
.62454 .25 L
.62454 .25 L
.62455 .25 L
.62456 .25 L
.62456 .25 L
.62457 .25 L
.62457 .25 L
.62458 .25 L
.62459 .25 L
.62459 .25 L
.6246 .25 L
.62461 .25 L
.62461 .25 L
.62461 .25 L
.62462 .25 L
.62463 .25 L
.62463 .25 L
.62464 .25 L
.62465 .25 L
.62465 .25 L
.62466 .25 L
.62466 .25 L
.62467 .25 L
.62467 .25 L
.62468 .25 L
.62469 .25 L
.62469 .25 L
.6247 .25 L
.62471 .25 L
.62471 .25 L
.62471 .25 L
.62472 .25 L
.62473 .25 L
.62473 .25 L
.62474 .25 L
.62475 .25 L
.62475 .25 L
.62476 .25 L
.62476 .25 L
.62477 .25 L
.62478 .25 L
.62478 .25 L
.62479 .25 L
.6248 .25 L
.6248 .25 L
.62481 .25 L
.62481 .25 L
.62482 .25 L
.62482 .25 L
Mistroke
.62483 .25 L
.62484 .25 L
.62484 .25 L
.62485 .25 L
.62485 .25 L
.62486 .25 L
.62487 .25 L
.62487 .25 L
.62488 .25 L
.62488 .25 L
.62489 .25 L
.6249 .25 L
.6249 .25 L
.62491 .25 L
.62491 .25 L
.62492 .25 L
.62492 .25 L
.62493 .25 L
.62493 .25 L
.62494 .25 L
.62494 .25 L
.62495 .25 L
.62495 .25 L
.62496 .25 L
.62497 .25 L
.62497 .25 L
.62498 .25 L
.62499 .25 L
.62499 .25 L
.62499 .25 L
.625 .25 L
.625 .25 L
.62501 .25 L
.62501 .25 L
.62502 .25 L
.62503 .25 L
.62503 .25 L
.62504 .25 L
.62504 .25 L
.62505 .25 L
.62506 .25 L
.62506 .25 L
.62507 .25 L
.62507 .25 L
.62508 .25 L
.62509 .25 L
.62509 .25 L
.6251 .25 L
.62511 .25 L
.62511 .25 L
Mistroke
.62512 .25 L
.62512 .25 L
.62513 .25 L
.62514 .25 L
.62514 .25 L
.62515 .25 L
.62515 .25 L
.62516 .25 L
.62516 .25 L
.62517 .25 L
.62517 .25 L
.62518 .25 L
.62519 .25 L
.62519 .25 L
.6252 .25 L
.6252 .25 L
.62521 .25 L
.62522 .25 L
.62522 .25 L
.62523 .25 L
.62524 .25 L
.62524 .25 L
.62525 .25 L
.62526 .25 L
.62526 .25 L
.62527 .25 L
.62527 .25 L
.62528 .25 L
.62528 .25 L
.62529 .25 L
.62529 .25 L
.62529 .25 L
.6253 .25 L
.6253 .25 L
.62531 .25 L
.62531 .25 L
.62532 .25 L
.62532 .25 L
.62532 .25 L
.62533 .25 L
.62533 .25 L
.62533 .25 L
.62534 .25 L
.62535 .25 L
.62535 .25 L
.62536 .25 L
.62537 .25 L
.62537 .25 L
.62538 .25 L
.62539 .25 L
Mistroke
.62539 .25 L
.6254 .25 L
.6254 .25 L
.62541 .25 L
.62542 .25 L
.62542 .25 L
.62543 .25 L
.62543 .25 L
.62544 .25 L
.62545 .25 L
.62545 .25 L
.62546 .25 L
.62546 .25 L
.62547 .25 L
.62548 .25 L
.62548 .25 L
.62549 .25 L
.62549 .25 L
.6255 .25 L
.6255 .25 L
.62551 .25 L
.62552 .25 L
.62552 .25 L
.62553 .25 L
.62553 .25 L
.62554 .25 L
.62554 .25 L
.62555 .25 L
.62556 .25 L
.62556 .25 L
.62557 .25 L
.62558 .25 L
.62558 .25 L
.62559 .25 L
.62559 .25 L
.6256 .25 L
.62561 .25 L
.62561 .25 L
.62562 .25 L
.62563 .25 L
.62563 .25 L
.62564 .25 L
.62564 .25 L
.62565 .25 L
.62565 .25 L
.62566 .25 L
.62567 .25 L
.62567 .25 L
.62568 .25 L
.62568 .25 L
Mistroke
.62569 .25 L
.6257 .25 L
.6257 .25 L
.62571 .25 L
.62571 .25 L
.62572 .25 L
.62573 .25 L
.62573 .25 L
.62574 .25 L
.62574 .25 L
.62575 .25 L
.62575 .25 L
.62576 .25 L
.62576 .25 L
.62577 .25 L
.62577 .25 L
.62578 .25 L
.62578 .25 L
.62579 .25 L
.6258 .25 L
.6258 .25 L
.62581 .25 L
.62581 .25 L
.62582 .25 L
.62582 .25 L
.62583 .25 L
.62583 .25 L
.62584 .25 L
.62584 .25 L
.62585 .25 L
.62586 .25 L
.62586 .25 L
.62587 .25 L
.62587 .25 L
.62588 .25 L
.62589 .25 L
.62589 .25 L
.6259 .25 L
.6259 .25 L
.62591 .25 L
.62592 .25 L
.62592 .25 L
.62593 .25 L
.62594 .25 L
.62594 .25 L
.62595 .25 L
.62596 .25 L
.62596 .25 L
.62597 .25 L
.62597 .25 L
Mistroke
.62598 .25 L
.62598 .25 L
.62598 .25 L
.62599 .25 L
.626 .25 L
.626 .25 L
.62601 .25 L
.62602 .25 L
.62602 .25 L
.62603 .25 L
.62603 .25 L
.62604 .25 L
.62605 .25 L
.62605 .25 L
.62606 .25 L
.62607 .25 L
.62607 .25 L
.62608 .25 L
.62609 .25 L
.62609 .25 L
.6261 .25 L
.6261 .25 L
.62611 .25 L
.62611 .25 L
.62611 .25 L
.62612 .25 L
.62612 .25 L
.62613 .25 L
.62613 .25 L
.62614 .25 L
.62614 .25 L
.62614 .25 L
.62615 .25 L
.62615 .25 L
.62615 .25 L
.62616 .25 L
.62616 .25 L
.62617 .25 L
.62618 .25 L
.62618 .25 L
.62619 .25 L
.6262 .25 L
.6262 .25 L
.62621 .25 L
.62622 .25 L
.62622 .25 L
.62623 .25 L
.62624 .25 L
.62624 .25 L
.62625 .25 L
Mistroke
.62625 .25 L
.62626 .25 L
.62626 .25 L
.62627 .25 L
.62628 .25 L
.62628 .25 L
.62629 .25 L
.62629 .25 L
.6263 .25 L
.62631 .25 L
.62631 .25 L
.62632 .25 L
.62632 .25 L
.62633 .25 L
.62634 .25 L
.62634 .25 L
.62635 .25 L
.62635 .25 L
.62636 .25 L
.62636 .25 L
.62637 .25 L
.62637 .25 L
.62638 .25 L
.62639 .25 L
.62639 .25 L
.6264 .25 L
.62641 .25 L
.62641 .25 L
.62642 .25 L
.62642 .25 L
.62643 .25 L
.62644 .25 L
.62644 .25 L
.62645 .25 L
.62646 .25 L
.62646 .25 L
.62646 .25 L
.62647 .25 L
.62648 .25 L
.62648 .25 L
.62649 .25 L
.6265 .25 L
.6265 .25 L
.62651 .25 L
.62651 .25 L
.62652 .25 L
.62653 .25 L
.62653 .25 L
.62654 .25 L
.62654 .25 L
Mistroke
.62655 .25 L
.62656 .25 L
.62656 .25 L
.62656 .25 L
.62657 .25 L
.62658 .25 L
.62658 .25 L
.62659 .25 L
.62659 .25 L
.6266 .25 L
.6266 .25 L
.62661 .25 L
.62661 .25 L
.62662 .25 L
.62663 .25 L
.62663 .25 L
.62664 .25 L
.62664 .25 L
.62665 .25 L
.62665 .25 L
.62666 .25 L
.62666 .25 L
.62667 .25 L
.62667 .25 L
.62668 .25 L
.62669 .25 L
.62669 .25 L
.6267 .25 L
.6267 .25 L
.62671 .25 L
.62672 .25 L
.62672 .25 L
.62673 .25 L
.62674 .25 L
.62674 .25 L
.62675 .25 L
.62675 .25 L
.62676 .25 L
.62677 .25 L
.62677 .25 L
.62678 .25 L
.62679 .25 L
.62679 .25 L
.6268 .25 L
.6268 .25 L
.6268 .25 L
.62681 .25 L
.62681 .25 L
.62682 .25 L
.62683 .25 L
Mistroke
.62683 .25 L
.62684 .25 L
.62685 .25 L
.62685 .25 L
.62686 .25 L
.62686 .25 L
.62687 .25 L
.62688 .25 L
.62688 .25 L
.62689 .25 L
.6269 .25 L
.6269 .25 L
.62691 .25 L
.62692 .25 L
.62692 .25 L
.62692 .25 L
.62693 .25 L
.62693 .25 L
.62694 .25 L
.62694 .25 L
.62695 .25 L
.62695 .25 L
.62696 .25 L
.62696 .25 L
.62696 .25 L
.62697 .25 L
.62697 .25 L
.62697 .25 L
.62698 .25 L
.62698 .25 L
.62699 .25 L
.627 .25 L
.627 .25 L
.62701 .25 L
.62702 .25 L
.62702 .25 L
.62703 .25 L
.62703 .25 L
.62704 .25 L
.62705 .25 L
.62705 .25 L
.62706 .25 L
.62706 .25 L
.62707 .25 L
.62708 .25 L
.62708 .25 L
.62709 .25 L
.62709 .25 L
.6271 .25 L
.62711 .25 L
Mistroke
.62711 .25 L
.62712 .25 L
.62712 .25 L
.62713 .25 L
.62713 .25 L
.62714 .25 L
.62715 .25 L
.62715 .25 L
.62716 .25 L
.62717 .25 L
.62717 .25 L
.62718 .25 L
.62718 .25 L
.62718 .25 L
.62719 .25 L
.6272 .25 L
.6272 .25 L
.62721 .25 L
.62722 .25 L
.62722 .25 L
.62723 .25 L
.62724 .25 L
.62724 .25 L
.62725 .25 L
.62725 .25 L
.62726 .25 L
.62727 .25 L
.62727 .25 L
.62728 .25 L
.62728 .25 L
.62729 .25 L
.6273 .25 L
.6273 .25 L
.62731 .25 L
.62731 .25 L
.62732 .25 L
.62733 .25 L
.62733 .25 L
.62734 .25 L
.62734 .25 L
.62735 .25 L
.62735 .25 L
.62736 .25 L
.62737 .25 L
.62737 .25 L
.62738 .25 L
.62738 .25 L
.62739 .25 L
.62739 .25 L
.6274 .25 L
Mistroke
.62741 .25 L
.62741 .25 L
.62741 .25 L
.62742 .25 L
.62743 .25 L
.62743 .25 L
.62744 .25 L
.62744 .25 L
.62745 .25 L
.62746 .25 L
.62746 .25 L
.62746 .25 L
.62747 .25 L
.62747 .25 L
.62748 .25 L
.62748 .25 L
.62749 .25 L
.6275 .25 L
.6275 .25 L
.62751 .25 L
.62752 .25 L
.62752 .25 L
.62753 .25 L
.62753 .25 L
.62754 .25 L
.62755 .25 L
.62755 .25 L
.62756 .25 L
.62756 .25 L
.62757 .25 L
.62758 .25 L
.62758 .25 L
.62759 .25 L
.6276 .25 L
.6276 .25 L
.62761 .25 L
.62762 .25 L
.62762 .25 L
.62762 .25 L
.62763 .25 L
.62763 .25 L
.62764 .25 L
.62764 .25 L
.62765 .25 L
.62766 .25 L
.62766 .25 L
.62767 .25 L
.62768 .25 L
.62768 .25 L
.62769 .25 L
Mistroke
.62769 .25 L
.6277 .25 L
.62771 .25 L
.62771 .25 L
.62772 .25 L
.62773 .25 L
.62773 .25 L
.62774 .25 L
.62774 .25 L
.62775 .25 L
.62775 .25 L
.62776 .25 L
.62776 .25 L
.62776 .25 L
.62777 .25 L
.62778 .25 L
.62778 .25 L
.62778 .25 L
.62779 .25 L
.62779 .25 L
.62779 .25 L
.6278 .25 L
.6278 .25 L
.62781 .25 L
.62781 .25 L
.62782 .25 L
.62782 .25 L
.62783 .25 L
.62784 .25 L
.62784 .25 L
.62785 .25 L
.62786 .25 L
.62786 .25 L
.62787 .25 L
.62788 .25 L
.62788 .25 L
.62789 .25 L
.62789 .25 L
.6279 .25 L
.62791 .25 L
.62791 .25 L
.62792 .25 L
.62792 .25 L
.62793 .25 L
.62793 .25 L
.62794 .25 L
.62795 .25 L
.62795 .25 L
.62796 .25 L
.62796 .25 L
Mistroke
.62797 .25 L
.62798 .25 L
.62798 .25 L
.62799 .25 L
.62799 .25 L
.628 .25 L
.628 .25 L
.62801 .25 L
.62801 .25 L
.62802 .25 L
.62803 .25 L
.62803 .25 L
.62804 .25 L
.62805 .25 L
.62805 .25 L
.62806 .25 L
.62807 .25 L
.62807 .25 L
.62808 .25 L
.62808 .25 L
.62809 .25 L
.6281 .25 L
.6281 .25 L
.62811 .25 L
.62811 .25 L
.62812 .25 L
.62813 .25 L
.62813 .25 L
.62814 .25 L
.62814 .25 L
.62815 .25 L
.62816 .25 L
.62816 .25 L
.62817 .25 L
.62817 .25 L
.62818 .25 L
.62818 .25 L
.62819 .25 L
.6282 .25 L
.6282 .25 L
.62821 .25 L
.62821 .25 L
.62822 .25 L
.62822 .25 L
.62823 .25 L
.62824 .25 L
.62824 .25 L
.62825 .25 L
.62826 .25 L
.62826 .25 L
Mistroke
.62827 .25 L
.62827 .25 L
.62828 .25 L
.62829 .25 L
.62829 .25 L
.6283 .25 L
.62831 .25 L
.62831 .25 L
.62831 .25 L
.62832 .25 L
.62833 .25 L
.62833 .25 L
.62834 .25 L
.62835 .25 L
.62835 .25 L
.62836 .25 L
.62836 .25 L
.62837 .25 L
.62837 .25 L
.62838 .25 L
.62839 .25 L
.62839 .25 L
.6284 .25 L
.62841 .25 L
.62841 .25 L
.62841 .25 L
.62842 .25 L
.62843 .25 L
.62843 .25 L
.62844 .25 L
.62844 .25 L
.62845 .25 L
.62845 .25 L
.62846 .25 L
.62846 .25 L
.62847 .25 L
.62848 .25 L
.62848 .25 L
.62849 .25 L
.62849 .25 L
.6285 .25 L
.6285 .25 L
.6285 .25 L
.62851 .25 L
.62852 .25 L
.62852 .25 L
.62853 .25 L
.62854 .25 L
.62854 .25 L
.62855 .25 L
Mistroke
.62855 .25 L
.62856 .25 L
.62857 .25 L
.62857 .25 L
.62858 .25 L
.62858 .25 L
.62859 .25 L
.6286 .25 L
.6286 .25 L
.62861 .25 L
.62862 .25 L
.62862 .25 L
.62863 .25 L
.62864 .25 L
.62864 .25 L
.62865 .25 L
.62865 .25 L
.62865 .25 L
.62866 .25 L
.62866 .25 L
.62867 .25 L
.62868 .25 L
.62868 .25 L
.62869 .25 L
.6287 .25 L
.6287 .25 L
.62871 .25 L
.62871 .25 L
.62872 .25 L
.62873 .25 L
.62873 .25 L
.62874 .25 L
.62875 .25 L
.62875 .25 L
.62876 .25 L
.62877 .25 L
.62877 .25 L
.62877 .25 L
.62878 .25 L
.62878 .25 L
.62879 .25 L
.62879 .25 L
.62879 .25 L
.6288 .25 L
.62881 .25 L
.62881 .25 L
.62881 .25 L
.62882 .25 L
.62882 .25 L
.62882 .25 L
Mistroke
.62883 .25 L
.62883 .25 L
.62884 .25 L
.62884 .25 L
.62885 .25 L
.62886 .25 L
.62887 .25 L
.62887 .25 L
.62888 .25 L
.62888 .25 L
.62889 .25 L
.6289 .25 L
.6289 .25 L
.62891 .25 L
.62891 .25 L
.62892 .25 L
.62893 .25 L
.62893 .25 L
.62894 .25 L
.62894 .25 L
.62895 .25 L
.62896 .25 L
.62896 .25 L
.62897 .25 L
.62897 .25 L
.62898 .25 L
.62898 .25 L
.62899 .25 L
.629 .25 L
.629 .25 L
.62901 .25 L
.62902 .25 L
.62902 .25 L
.62903 .25 L
.62903 .25 L
.62903 .25 L
.62904 .25 L
.62905 .25 L
.62905 .25 L
.62906 .25 L
.62907 .25 L
.62907 .25 L
.62908 .25 L
.62909 .25 L
.62909 .25 L
.6291 .25 L
.6291 .25 L
.62911 .25 L
.62912 .25 L
.62912 .25 L
Mistroke
.62913 .25 L
.62913 .25 L
.62914 .25 L
.62915 .25 L
.62915 .25 L
.62916 .25 L
.62916 .25 L
.62917 .25 L
.62918 .25 L
.62918 .25 L
.62919 .25 L
.62919 .25 L
.6292 .25 L
.62921 .25 L
.62921 .25 L
.62922 .25 L
.62922 .25 L
.62923 .25 L
.62923 .25 L
.62924 .25 L
.62924 .25 L
.62925 .25 L
.62926 .25 L
.62926 .25 L
.62926 .25 L
.62927 .25 L
.62928 .25 L
.62928 .25 L
.62929 .25 L
.62929 .25 L
.6293 .25 L
.62931 .25 L
.62931 .25 L
.62931 .25 L
.62932 .25 L
.62933 .25 L
.62933 .25 L
.62934 .25 L
.62934 .25 L
.62935 .25 L
.62935 .25 L
.62936 .25 L
.62937 .25 L
.62937 .25 L
.62938 .25 L
.62938 .25 L
.62939 .25 L
.6294 .25 L
.6294 .25 L
.62941 .25 L
Mistroke
.62942 .25 L
.62942 .25 L
.62943 .25 L
.62943 .25 L
.62944 .25 L
.62945 .25 L
.62945 .25 L
.62946 .25 L
.62947 .25 L
.62947 .25 L
.62947 .25 L
.62948 .25 L
.62948 .25 L
.62949 .25 L
.62949 .25 L
.6295 .25 L
.62951 .25 L
.62951 .25 L
.62952 .25 L
.62953 .25 L
.62953 .25 L
.62954 .25 L
.62954 .25 L
.62955 .25 L
.62956 .25 L
.62956 .25 L
.62957 .25 L
.62958 .25 L
.62958 .25 L
.62959 .25 L
.62959 .25 L
.6296 .25 L
.6296 .25 L
.62961 .25 L
.62961 .25 L
.62962 .25 L
.62962 .25 L
.62963 .25 L
.62963 .25 L
.62963 .25 L
.62964 .25 L
.62964 .25 L
.62964 .25 L
.62965 .25 L
.62965 .25 L
.62966 .25 L
.62966 .25 L
.62967 .25 L
.62968 .25 L
.62968 .25 L
Mistroke
.62969 .25 L
.6297 .25 L
.6297 .25 L
.62971 .25 L
.62971 .25 L
.62972 .25 L
.62973 .25 L
.62973 .25 L
.62974 .25 L
.62975 .25 L
.62975 .25 L
.62976 .25 L
.62976 .25 L
.62977 .25 L
.62977 .25 L
.62978 .25 L
.62979 .25 L
.62979 .25 L
.6298 .25 L
.6298 .25 L
.62981 .25 L
.62981 .25 L
.62982 .25 L
.62983 .25 L
.62983 .25 L
.62984 .25 L
.62984 .25 L
.62985 .25 L
.62985 .25 L
.62986 .25 L
.62986 .25 L
.62987 .25 L
.62988 .25 L
.62988 .25 L
.62989 .25 L
.6299 .25 L
.6299 .25 L
.62991 .25 L
.62992 .25 L
.62992 .25 L
.62993 .25 L
.62994 .25 L
.62994 .25 L
.62995 .25 L
.62995 .25 L
.62996 .25 L
.62996 .25 L
.62997 .25 L
.62998 .25 L
.62998 .25 L
Mistroke
.62999 .25 L
.62999 .25 L
.63 .25 L
.63001 .25 L
.63001 .25 L
.63002 .25 L
.63002 .25 L
.63003 .25 L
.63004 .25 L
.63004 .25 L
.63005 .25 L
.63005 .25 L
.63006 .25 L
.63006 .25 L
.63007 .25 L
.63007 .25 L
.63008 .25 L
.63008 .25 L
.63009 .25 L
.63009 .25 L
.6301 .25 L
.63011 .25 L
.63011 .25 L
.63012 .25 L
.63012 .25 L
.63013 .25 L
.63013 .25 L
.63014 .25 L
.63015 .25 L
.63015 .25 L
.63015 .25 L
.63016 .25 L
.63017 .25 L
.63017 .25 L
.63018 .25 L
.63018 .25 L
.63019 .25 L
.6302 .25 L
.6302 .25 L
.63021 .25 L
.63021 .25 L
.63022 .25 L
.63023 .25 L
.63023 .25 L
.63024 .25 L
.63024 .25 L
.63025 .25 L
.63026 .25 L
.63026 .25 L
.63027 .25 L
Mistroke
.63028 .25 L
.63028 .25 L
.63029 .25 L
.63029 .25 L
.6303 .25 L
.6303 .25 L
.6303 .25 L
.63031 .25 L
.63032 .25 L
.63032 .25 L
.63033 .25 L
.63034 .25 L
.63034 .25 L
.63035 .25 L
.63036 .25 L
.63036 .25 L
.63037 .25 L
.63037 .25 L
.63038 .25 L
.63039 .25 L
.63039 .25 L
.6304 .25 L
.63041 .25 L
.63041 .25 L
.63042 .25 L
.63042 .25 L
.63043 .25 L
.63043 .25 L
.63044 .25 L
.63044 .25 L
.63044 .25 L
.63045 .25 L
.63045 .25 L
.63046 .25 L
.63046 .25 L
.63047 .25 L
.63047 .25 L
.63047 .25 L
.63048 .25 L
.63048 .25 L
.63049 .25 L
.63049 .25 L
.6305 .25 L
.63051 .25 L
.63051 .25 L
.63052 .25 L
.63053 .25 L
.63053 .25 L
.63054 .25 L
.63054 .25 L
Mistroke
.63055 .25 L
.63056 .25 L
.63056 .25 L
.63057 .25 L
.63058 .25 L
.63058 .25 L
.63058 .25 L
.63059 .25 L
.6306 .25 L
.6306 .25 L
.63061 .25 L
.63062 .25 L
.63062 .25 L
.63063 .25 L
.63063 .25 L
.63064 .25 L
.63064 .25 L
.63065 .25 L
.63066 .25 L
.63066 .25 L
.63067 .25 L
.63067 .25 L
.63068 .25 L
.63068 .25 L
.63069 .25 L
.6307 .25 L
.6307 .25 L
.63071 .25 L
.63072 .25 L
.63072 .25 L
.63073 .25 L
.63073 .25 L
.63074 .25 L
.63075 .25 L
.63075 .25 L
.63076 .25 L
.63076 .25 L
.63077 .25 L
.63078 .25 L
.63078 .25 L
.63079 .25 L
.63079 .25 L
.6308 .25 L
.63081 .25 L
.63081 .25 L
.63082 .25 L
.63082 .25 L
.63083 .25 L
.63083 .25 L
.63084 .25 L
Mistroke
.63085 .25 L
.63085 .25 L
.63086 .25 L
.63087 .25 L
.63087 .25 L
.63088 .25 L
.63088 .25 L
.63088 .25 L
.63089 .25 L
.6309 .25 L
.6309 .25 L
.63091 .25 L
.63091 .25 L
.63092 .25 L
.63092 .25 L
.63093 .25 L
.63094 .25 L
.63094 .25 L
.63095 .25 L
.63095 .25 L
.63096 .25 L
.63096 .25 L
.63097 .25 L
.63097 .25 L
.63098 .25 L
.63098 .25 L
.63099 .25 L
.631 .25 L
.631 .25 L
.63101 .25 L
.63101 .25 L
.63102 .25 L
.63102 .25 L
.63103 .25 L
.63104 .25 L
.63104 .25 L
.63105 .25 L
.63106 .25 L
.63106 .25 L
.63107 .25 L
.63107 .25 L
.63108 .25 L
.63109 .25 L
.63109 .25 L
.6311 .25 L
.63111 .25 L
.63111 .25 L
.63112 .25 L
.63112 .25 L
.63112 .25 L
Mistroke
.63113 .25 L
.63113 .25 L
.63114 .25 L
.63115 .25 L
.63115 .25 L
.63116 .25 L
.63117 .25 L
.63117 .25 L
.63118 .25 L
.63119 .25 L
.63119 .25 L
.6312 .25 L
.6312 .25 L
.63121 .25 L
.63122 .25 L
.63122 .25 L
.63123 .25 L
.63124 .25 L
.63124 .25 L
.63125 .25 L
.63125 .25 L
.63126 .25 L
.63126 .25 L
.63126 .25 L
.63127 .25 L
.63127 .25 L
.63128 .25 L
.63128 .25 L
.63128 .25 L
.63129 .25 L
.63129 .25 L
.6313 .25 L
.6313 .25 L
.6313 .25 L
.63131 .25 L
.63132 .25 L
.63132 .25 L
.63133 .25 L
.63134 .25 L
.63134 .25 L
.63135 .25 L
.63135 .25 L
.63136 .25 L
.63137 .25 L
.63137 .25 L
.63138 .25 L
.63139 .25 L
.63139 .25 L
.6314 .25 L
.6314 .25 L
Mistroke
.63141 .25 L
.63141 .25 L
.63142 .25 L
.63143 .25 L
.63143 .25 L
.63144 .25 L
.63145 .25 L
.63145 .25 L
.63146 .25 L
.63146 .25 L
.63147 .25 L
.63147 .25 L
.63148 .25 L
.63149 .25 L
.63149 .25 L
.6315 .25 L
.6315 .25 L
.63151 .25 L
.63151 .25 L
.63152 .25 L
.63152 .25 L
.63153 .25 L
.63154 .25 L
.63154 .25 L
.63155 .25 L
.63156 .25 L
.63156 .25 L
.63157 .25 L
.63158 .25 L
.63158 .25 L
.63159 .25 L
.63159 .25 L
.6316 .25 L
.63161 .25 L
.63161 .25 L
.63162 .25 L
.63162 .25 L
.63163 .25 L
.63163 .25 L
.63164 .25 L
.63165 .25 L
.63165 .25 L
.63166 .25 L
.63166 .25 L
.63167 .25 L
.63168 .25 L
.63168 .25 L
.63169 .25 L
.63169 .25 L
.6317 .25 L
Mistroke
.6317 .25 L
.63171 .25 L
.63171 .25 L
.63172 .25 L
.63173 .25 L
.63173 .25 L
.63174 .25 L
.63175 .25 L
.63175 .25 L
.63176 .25 L
.63177 .25 L
.63177 .25 L
.63178 .25 L
.63179 .25 L
.63179 .25 L
.6318 .25 L
.6318 .25 L
.63181 .25 L
.63181 .25 L
.63182 .25 L
.63183 .25 L
.63183 .25 L
.63184 .25 L
.63184 .25 L
.63185 .25 L
.63186 .25 L
.63186 .25 L
.63187 .25 L
.63187 .25 L
.63188 .25 L
.63189 .25 L
.63189 .25 L
.6319 .25 L
.6319 .25 L
.63191 .25 L
.63191 .25 L
.63192 .25 L
.63192 .25 L
.63193 .25 L
.63193 .25 L
.63194 .25 L
.63194 .25 L
.63195 .25 L
.63196 .25 L
.63196 .25 L
.63197 .25 L
.63197 .25 L
.63198 .25 L
.63198 .25 L
.63199 .25 L
Mistroke
.632 .25 L
.632 .25 L
.632 .25 L
.63201 .25 L
.63202 .25 L
.63202 .25 L
.63203 .25 L
.63203 .25 L
.63204 .25 L
.63205 .25 L
.63205 .25 L
.63206 .25 L
.63206 .25 L
.63207 .25 L
.63208 .25 L
.63208 .25 L
.63209 .25 L
.63209 .25 L
.6321 .25 L
.63211 .25 L
.63211 .25 L
.63212 .25 L
.63213 .25 L
.63213 .25 L
.63214 .25 L
.63214 .25 L
.63215 .25 L
.63215 .25 L
.63215 .25 L
.63216 .25 L
.63217 .25 L
.63217 .25 L
.63218 .25 L
.63219 .25 L
.63219 .25 L
.6322 .25 L
.63221 .25 L
.63221 .25 L
.63222 .25 L
.63222 .25 L
.63223 .25 L
.63224 .25 L
.63224 .25 L
.63225 .25 L
.63226 .25 L
.63226 .25 L
.63227 .25 L
.63227 .25 L
.63228 .25 L
.63228 .25 L
Mistroke
.63229 .25 L
.63229 .25 L
.63229 .25 L
.6323 .25 L
.6323 .25 L
.63231 .25 L
.63231 .25 L
.63232 .25 L
.63232 .25 L
.63232 .25 L
.63233 .25 L
.63233 .25 L
.63234 .25 L
.63234 .25 L
.63235 .25 L
.63236 .25 L
.63236 .25 L
.63237 .25 L
.63238 .25 L
.63238 .25 L
.63239 .25 L
.63239 .25 L
.6324 .25 L
.63241 .25 L
.63241 .25 L
.63242 .25 L
.63243 .25 L
.63243 .25 L
.63243 .25 L
.63244 .25 L
.63245 .25 L
.63245 .25 L
.63246 .25 L
.63247 .25 L
.63247 .25 L
.63248 .25 L
.63248 .25 L
.63249 .25 L
.63249 .25 L
.6325 .25 L
.63251 .25 L
.63251 .25 L
.63252 .25 L
.63253 .25 L
.63253 .25 L
.63253 .25 L
.63254 .25 L
.63255 .25 L
.63255 .25 L
.63256 .25 L
Mistroke
.63257 .25 L
.63257 .25 L
.63258 .25 L
.63258 .25 L
.63259 .25 L
.6326 .25 L
.6326 .25 L
.63261 .25 L
.63262 .25 L
.63262 .25 L
.63263 .25 L
.63263 .25 L
.63264 .25 L
.63264 .25 L
.63265 .25 L
.63266 .25 L
.63266 .25 L
.63267 .25 L
.63267 .25 L
.63268 .25 L
.63269 .25 L
.63269 .25 L
.6327 .25 L
.6327 .25 L
.63271 .25 L
.63272 .25 L
.63272 .25 L
.63273 .25 L
.63273 .25 L
.63273 .25 L
.63274 .25 L
.63275 .25 L
.63275 .25 L
.63276 .25 L
.63276 .25 L
.63277 .25 L
.63277 .25 L
.63278 .25 L
.63279 .25 L
.63279 .25 L
.6328 .25 L
.63281 .25 L
.63281 .25 L
.63281 .25 L
.63282 .25 L
.63282 .25 L
.63283 .25 L
.63283 .25 L
.63284 .25 L
.63285 .25 L
Mistroke
.63285 .25 L
.63286 .25 L
.63286 .25 L
.63287 .25 L
.63288 .25 L
.63288 .25 L
.63289 .25 L
.63289 .25 L
.6329 .25 L
.63291 .25 L
.63291 .25 L
.63292 .25 L
.63292 .25 L
.63293 .25 L
.63294 .25 L
.63294 .25 L
.63295 .25 L
.63296 .25 L
.63296 .25 L
.63297 .25 L
.63297 .25 L
.63298 .25 L
.63298 .25 L
.63299 .25 L
.63299 .25 L
.633 .25 L
.63301 .25 L
.63301 .25 L
.63302 .25 L
.63302 .25 L
.63303 .25 L
.63304 .25 L
.63304 .25 L
.63305 .25 L
.63306 .25 L
.63306 .25 L
.63307 .25 L
.63308 .25 L
.63308 .25 L
.63309 .25 L
.63309 .25 L
.6331 .25 L
.6331 .25 L
.63311 .25 L
.63311 .25 L
.63311 .25 L
.63312 .25 L
.63312 .25 L
.63313 .25 L
.63313 .25 L
Mistroke
.63314 .25 L
.63314 .25 L
.63314 .25 L
.63315 .25 L
.63315 .25 L
.63315 .25 L
.63316 .25 L
.63317 .25 L
.63317 .25 L
.63318 .25 L
.63319 .25 L
.63319 .25 L
.6332 .25 L
.6332 .25 L
.63321 .25 L
.63322 .25 L
.63322 .25 L
.63323 .25 L
.63324 .25 L
.63324 .25 L
.63325 .25 L
.63325 .25 L
.63326 .25 L
.63326 .25 L
.63327 .25 L
.63328 .25 L
.63328 .25 L
.63329 .25 L
.6333 .25 L
.6333 .25 L
.63331 .25 L
.63331 .25 L
.63332 .25 L
.63332 .25 L
.63333 .25 L
.63334 .25 L
.63334 .25 L
.63335 .25 L
.63335 .25 L
.63336 .25 L
.63336 .25 L
.63337 .25 L
.63338 .25 L
.63338 .25 L
.63339 .25 L
.6334 .25 L
.6334 .25 L
.63341 .25 L
.63341 .25 L
.63342 .25 L
Mistroke
.63343 .25 L
.63343 .25 L
.63344 .25 L
.63345 .25 L
.63345 .25 L
.63346 .25 L
.63346 .25 L
.63347 .25 L
.63347 .25 L
.63348 .25 L
.63349 .25 L
.63349 .25 L
.6335 .25 L
.6335 .25 L
.63351 .25 L
.63352 .25 L
.63352 .25 L
.63353 .25 L
.63353 .25 L
.63354 .25 L
.63355 .25 L
.63355 .25 L
.63356 .25 L
.63356 .25 L
.63357 .25 L
.63357 .25 L
.63358 .25 L
.63358 .25 L
.63359 .25 L
.63359 .25 L
.6336 .25 L
.6336 .25 L
.63361 .25 L
.63362 .25 L
.63362 .25 L
.63363 .25 L
.63363 .25 L
.63364 .25 L
.63364 .25 L
.63365 .25 L
.63365 .25 L
.63366 .25 L
.63366 .25 L
.63367 .25 L
.63368 .25 L
.63368 .25 L
.63369 .25 L
.63369 .25 L
.6337 .25 L
.63371 .25 L
Mistroke
.63371 .25 L
.63372 .25 L
.63372 .25 L
.63373 .25 L
.63374 .25 L
.63374 .25 L
.63375 .25 L
.63376 .25 L
.63376 .25 L
.63377 .25 L
.63377 .25 L
.63378 .25 L
.63379 .25 L
.63379 .25 L
.6338 .25 L
.6338 .25 L
.6338 .25 L
.63381 .25 L
.63382 .25 L
.63382 .25 L
.63383 .25 L
.63384 .25 L
.63384 .25 L
.63385 .25 L
.63385 .25 L
.63386 .25 L
.63387 .25 L
.63387 .25 L
.63388 .25 L
.63389 .25 L
.63389 .25 L
.6339 .25 L
.6339 .25 L
.63391 .25 L
.63392 .25 L
.63392 .25 L
.63393 .25 L
.63393 .25 L
.63393 .25 L
.63394 .25 L
.63394 .25 L
.63395 .25 L
.63395 .25 L
.63395 .25 L
.63396 .25 L
.63396 .25 L
.63397 .25 L
.63397 .25 L
.63397 .25 L
.63398 .25 L
Mistroke
.63398 .25 L
.63399 .25 L
.634 .25 L
.634 .25 L
.63401 .25 L
.63402 .25 L
.63402 .25 L
.63403 .25 L
.63404 .25 L
.63404 .25 L
.63405 .25 L
.63405 .25 L
.63406 .25 L
.63407 .25 L
.63407 .25 L
.63408 .25 L
.63408 .25 L
.63409 .25 L
.6341 .25 L
.6341 .25 L
.63411 .25 L
.63411 .25 L
.63412 .25 L
.63413 .25 L
.63413 .25 L
.63414 .25 L
.63414 .25 L
.63415 .25 L
.63415 .25 L
.63416 .25 L
.63417 .25 L
.63417 .25 L
.63418 .25 L
.63418 .25 L
.63419 .25 L
.63419 .25 L
.6342 .25 L
.63421 .25 L
.63421 .25 L
.63422 .25 L
.63423 .25 L
.63423 .25 L
.63424 .25 L
.63424 .25 L
.63425 .25 L
.63426 .25 L
.63426 .25 L
.63427 .25 L
.63428 .25 L
.63428 .25 L
Mistroke
.63428 .25 L
.63429 .25 L
.6343 .25 L
.6343 .25 L
.63431 .25 L
.63432 .25 L
.63432 .25 L
.63433 .25 L
.63433 .25 L
.63434 .25 L
.63434 .25 L
.63435 .25 L
.63436 .25 L
.63436 .25 L
.63437 .25 L
.63438 .25 L
.63438 .25 L
.63438 .25 L
.63439 .25 L
.6344 .25 L
.6344 .25 L
.63441 .25 L
.63441 .25 L
.63442 .25 L
.63442 .25 L
.63443 .25 L
.63443 .25 L
.63444 .25 L
.63445 .25 L
.63445 .25 L
.63446 .25 L
.63446 .25 L
.63447 .25 L
.63447 .25 L
.63447 .25 L
.63448 .25 L
.63449 .25 L
.63449 .25 L
.6345 .25 L
.63451 .25 L
.63451 .25 L
.63452 .25 L
.63452 .25 L
.63453 .25 L
.63454 .25 L
.63454 .25 L
.63455 .25 L
.63455 .25 L
.63456 .25 L
.63457 .25 L
Mistroke
.63457 .25 L
.63458 .25 L
.63459 .25 L
.63459 .25 L
.6346 .25 L
.63461 .25 L
.63461 .25 L
.63462 .25 L
.63462 .25 L
.63462 .25 L
.63463 .25 L
.63463 .25 L
.63464 .25 L
.63465 .25 L
.63465 .25 L
.63466 .25 L
.63467 .25 L
.63467 .25 L
.63468 .25 L
.63468 .25 L
.63469 .25 L
.6347 .25 L
.6347 .25 L
.63471 .25 L
.63472 .25 L
.63472 .25 L
.63473 .25 L
.63474 .25 L
.63474 .25 L
.63474 .25 L
.63475 .25 L
.63475 .25 L
.63476 .25 L
.63476 .25 L
.63476 .25 L
.63477 .25 L
.63478 .25 L
.63478 .25 L
.63478 .25 L
.63479 .25 L
.63479 .25 L
.63479 .25 L
.6348 .25 L
.6348 .25 L
.63481 .25 L
.63481 .25 L
.63482 .25 L
.63483 .25 L
.63483 .25 L
.63484 .25 L
Mistroke
.63485 .25 L
.63485 .25 L
.63486 .25 L
.63486 .25 L
.63487 .25 L
.63488 .25 L
.63488 .25 L
.63489 .25 L
.6349 .25 L
.6349 .25 L
.63491 .25 L
.63491 .25 L
.63492 .25 L
.63492 .25 L
.63493 .25 L
.63494 .25 L
.63494 .25 L
.63495 .25 L
.63495 .25 L
.63496 .25 L
.63497 .25 L
.63497 .25 L
.63498 .25 L
.63498 .25 L
.63499 .25 L
.635 .25 L
.635 .25 L
.635 .25 L
.63501 .25 L
.63502 .25 L
.63502 .25 L
.63503 .25 L
.63504 .25 L
.63504 .25 L
.63505 .25 L
.63505 .25 L
.63506 .25 L
.63507 .25 L
.63507 .25 L
.63508 .25 L
.63509 .25 L
.63509 .25 L
.6351 .25 L
.6351 .25 L
.63511 .25 L
.63511 .25 L
.63512 .25 L
.63513 .25 L
.63513 .25 L
.63514 .25 L
Mistroke
.63515 .25 L
.63515 .25 L
.63516 .25 L
.63516 .25 L
.63517 .25 L
.63517 .25 L
.63518 .25 L
.63519 .25 L
.63519 .25 L
.6352 .25 L
.6352 .25 L
.63521 .25 L
.63521 .25 L
.63522 .25 L
.63523 .25 L
.63523 .25 L
.63523 .25 L
.63524 .25 L
.63525 .25 L
.63525 .25 L
.63526 .25 L
.63526 .25 L
.63527 .25 L
.63528 .25 L
.63528 .25 L
.63528 .25 L
.63529 .25 L
.63529 .25 L
.6353 .25 L
.6353 .25 L
.63531 .25 L
.63532 .25 L
.63532 .25 L
.63533 .25 L
.63534 .25 L
.63534 .25 L
.63535 .25 L
.63535 .25 L
.63536 .25 L
.63537 .25 L
.63537 .25 L
.63538 .25 L
.63538 .25 L
.63539 .25 L
.6354 .25 L
.6354 .25 L
.63541 .25 L
.63542 .25 L
.63542 .25 L
.63543 .25 L
Mistroke
.63544 .25 L
.63544 .25 L
.63544 .25 L
.63545 .25 L
.63545 .25 L
.63546 .25 L
.63546 .25 L
.63547 .25 L
.63548 .25 L
.63548 .25 L
.63549 .25 L
.63549 .25 L
.6355 .25 L
.63551 .25 L
.63551 .25 L
.63552 .25 L
.63553 .25 L
.63553 .25 L
.63554 .25 L
.63555 .25 L
.63555 .25 L
.63556 .25 L
.63556 .25 L
.63557 .25 L
.63557 .25 L
.63558 .25 L
.63558 .25 L
.63558 .25 L
.63559 .25 L
.63559 .25 L
.6356 .25 L
.6356 .25 L
.63561 .25 L
.63561 .25 L
.63561 .25 L
.63562 .25 L
.63562 .25 L
.63562 .25 L
.63563 .25 L
.63564 .25 L
.63564 .25 L
.63565 .25 L
.63566 .25 L
.63566 .25 L
.63567 .25 L
.63568 .25 L
.63568 .25 L
.63569 .25 L
.63569 .25 L
.6357 .25 L
Mistroke
.63571 .25 L
.63571 .25 L
.63572 .25 L
.63572 .25 L
.63573 .25 L
.63574 .25 L
.63574 .25 L
.63575 .25 L
.63575 .25 L
.63576 .25 L
.63577 .25 L
.63577 .25 L
.63578 .25 L
.63578 .25 L
.63579 .25 L
.6358 .25 L
.6358 .25 L
.63581 .25 L
.63581 .25 L
.63582 .25 L
.63582 .25 L
.63583 .25 L
.63583 .25 L
.63584 .25 L
.63585 .25 L
.63585 .25 L
.63586 .25 L
.63587 .25 L
.63587 .25 L
.63588 .25 L
.63588 .25 L
.63589 .25 L
.6359 .25 L
.6359 .25 L
.63591 .25 L
.63592 .25 L
.63592 .25 L
.63593 .25 L
.63593 .25 L
.63594 .25 L
.63594 .25 L
.63595 .25 L
.63596 .25 L
.63596 .25 L
.63597 .25 L
.63597 .25 L
.63598 .25 L
.63599 .25 L
.63599 .25 L
.636 .25 L
Mistroke
.636 .25 L
.63601 .25 L
.63602 .25 L
.63602 .25 L
.63603 .25 L
.63603 .25 L
.63604 .25 L
.63604 .25 L
.63605 .25 L
.63606 .25 L
.63606 .25 L
.63607 .25 L
.63607 .25 L
.63608 .25 L
.63609 .25 L
.63609 .25 L
.6361 .25 L
.63611 .25 L
.63611 .25 L
.63612 .25 L
.63613 .25 L
.63613 .25 L
.63613 .25 L
.63614 .25 L
.63615 .25 L
.63615 .25 L
.63616 .25 L
.63617 .25 L
.63617 .25 L
.63618 .25 L
.63618 .25 L
.63619 .25 L
.63619 .25 L
.6362 .25 L
.63621 .25 L
.63621 .25 L
.63622 .25 L
.63622 .25 L
.63623 .25 L
.63623 .25 L
.63624 .25 L
.63624 .25 L
.63625 .25 L
.63626 .25 L
.63626 .25 L
.63626 .25 L
.63627 .25 L
.63628 .25 L
.63628 .25 L
.63629 .25 L
Mistroke
.6363 .25 L
.6363 .25 L
.63631 .25 L
.63631 .25 L
.63632 .25 L
.63632 .25 L
.63632 .25 L
.63633 .25 L
.63634 .25 L
.63634 .25 L
.63635 .25 L
.63636 .25 L
.63636 .25 L
.63637 .25 L
.63637 .25 L
.63638 .25 L
.63639 .25 L
.63639 .25 L
.6364 .25 L
.6364 .25 L
.63641 .25 L
.63642 .25 L
.63642 .25 L
.63643 .25 L
.63644 .25 L
.63644 .25 L
.63645 .25 L
.63645 .25 L
.63646 .25 L
.63646 .25 L
.63647 .25 L
.63647 .25 L
.63648 .25 L
.63648 .25 L
.63649 .25 L
.6365 .25 L
.6365 .25 L
.63651 .25 L
.63651 .25 L
.63652 .25 L
.63653 .25 L
.63653 .25 L
.63654 .25 L
.63655 .25 L
.63655 .25 L
.63656 .25 L
.63657 .25 L
.63657 .25 L
.63658 .25 L
.63659 .25 L
Mistroke
.63659 .25 L
.63659 .25 L
.6366 .25 L
.6366 .25 L
.63661 .25 L
.63661 .25 L
.63661 .25 L
.63662 .25 L
.63662 .25 L
.63663 .25 L
.63663 .25 L
.63664 .25 L
.63664 .25 L
.63664 .25 L
.63665 .25 L
.63665 .25 L
.63666 .25 L
.63666 .25 L
.63667 .25 L
.63668 .25 L
.63668 .25 L
.63669 .25 L
.6367 .25 L
.6367 .25 L
.63671 .25 L
.63671 .25 L
.63672 .25 L
.63673 .25 L
.63673 .25 L
.63674 .25 L
.63675 .25 L
.63675 .25 L
.63675 .25 L
.63676 .25 L
.63677 .25 L
.63677 .25 L
.63678 .25 L
.63679 .25 L
.63679 .25 L
.6368 .25 L
.6368 .25 L
.63681 .25 L
.63682 .25 L
.63682 .25 L
.63683 .25 L
.63683 .25 L
.63684 .25 L
.63685 .25 L
.63685 .25 L
.63685 .25 L
Mistroke
.63686 .25 L
.63687 .25 L
.63687 .25 L
.63688 .25 L
.63689 .25 L
.63689 .25 L
.6369 .25 L
.6369 .25 L
.63691 .25 L
.63692 .25 L
.63692 .25 L
.63693 .25 L
.63694 .25 L
.63694 .25 L
.63695 .25 L
.63695 .25 L
.63696 .25 L
.63696 .25 L
.63697 .25 L
.63698 .25 L
.63698 .25 L
.63699 .25 L
.637 .25 L
.637 .25 L
.63701 .25 L
.63701 .25 L
.63702 .25 L
.63702 .25 L
.63703 .25 L
.63704 .25 L
.63704 .25 L
.63705 .25 L
.63705 .25 L
.63706 .25 L
.63706 .25 L
.63707 .25 L
.63708 .25 L
.63708 .25 L
.63708 .25 L
.63709 .25 L
.6371 .25 L
.6371 .25 L
.63711 .25 L
.63711 .25 L
.63712 .25 L
.63713 .25 L
.63713 .25 L
.63713 .25 L
.63714 .25 L
.63714 .25 L
Mistroke
.63715 .25 L
.63715 .25 L
.63716 .25 L
.63717 .25 L
.63717 .25 L
.63718 .25 L
.63719 .25 L
.63719 .25 L
.6372 .25 L
.6372 .25 L
.63721 .25 L
.63722 .25 L
.63722 .25 L
.63723 .25 L
.63723 .25 L
.63724 .25 L
.63725 .25 L
.63725 .25 L
.63726 .25 L
.63727 .25 L
.63727 .25 L
.63728 .25 L
.63729 .25 L
.63729 .25 L
.63729 .25 L
.6373 .25 L
.6373 .25 L
.63731 .25 L
.63731 .25 L
.63732 .25 L
.63733 .25 L
.63733 .25 L
.63734 .25 L
.63734 .25 L
.63735 .25 L
.63736 .25 L
.63736 .25 L
.63737 .25 L
.63738 .25 L
.63738 .25 L
.63739 .25 L
.6374 .25 L
.6374 .25 L
.63741 .25 L
.63741 .25 L
.63742 .25 L
.63742 .25 L
.63743 .25 L
.63743 .25 L
.63743 .25 L
Mistroke
.63744 .25 L
.63744 .25 L
.63745 .25 L
.63745 .25 L
.63746 .25 L
.63746 .25 L
.63746 .25 L
.63747 .25 L
.63747 .25 L
.63747 .25 L
.63748 .25 L
.63749 .25 L
.63749 .25 L
.6375 .25 L
.63751 .25 L
.63751 .25 L
.63752 .25 L
.63753 .25 L
.63753 .25 L
.63754 .25 L
.63754 .25 L
.63755 .25 L
.63756 .25 L
.63756 .25 L
.63757 .25 L
.63758 .25 L
.63758 .25 L
.63759 .25 L
.63759 .25 L
.6376 .25 L
.6376 .25 L
.63761 .25 L
.63762 .25 L
.63762 .25 L
.63763 .25 L
.63763 .25 L
.63764 .25 L
.63765 .25 L
.63765 .25 L
.63766 .25 L
.63766 .25 L
.63767 .25 L
.63767 .25 L
.63768 .25 L
.63768 .25 L
.63769 .25 L
.6377 .25 L
.6377 .25 L
.63771 .25 L
.63772 .25 L
Mistroke
.63772 .25 L
.63773 .25 L
.63773 .25 L
.63774 .25 L
.63775 .25 L
.63775 .25 L
.63776 .25 L
.63777 .25 L
.63777 .25 L
.63778 .25 L
.63778 .25 L
.63779 .25 L
.63779 .25 L
.6378 .25 L
.63781 .25 L
.63781 .25 L
.63782 .25 L
.63782 .25 L
.63783 .25 L
.63784 .25 L
.63784 .25 L
.63785 .25 L
.63785 .25 L
.63786 .25 L
.63787 .25 L
.63787 .25 L
.63788 .25 L
.63788 .25 L
.63789 .25 L
.63789 .25 L
.6379 .25 L
.6379 .25 L
.63791 .25 L
.63791 .25 L
.63792 .25 L
.63793 .25 L
.63793 .25 L
.63794 .25 L
.63794 .25 L
.63795 .25 L
.63795 .25 L
.63796 .25 L
.63796 .25 L
.63797 .25 L
.63797 .25 L
.63798 .25 L
.63798 .25 L
.63799 .25 L
.638 .25 L
.638 .25 L
Mistroke
.63801 .25 L
.63801 .25 L
.63802 .25 L
.63803 .25 L
.63803 .25 L
.63804 .25 L
.63805 .25 L
.63805 .25 L
.63806 .25 L
.63806 .25 L
.63807 .25 L
.63808 .25 L
.63808 .25 L
.63809 .25 L
.6381 .25 L
.6381 .25 L
.63811 .25 L
.63811 .25 L
.63812 .25 L
.63812 .25 L
.63812 .25 L
.63813 .25 L
.63814 .25 L
.63814 .25 L
.63815 .25 L
.63816 .25 L
.63816 .25 L
.63817 .25 L
.63817 .25 L
.63818 .25 L
.63819 .25 L
.63819 .25 L
.6382 .25 L
.63821 .25 L
.63821 .25 L
.63822 .25 L
.63823 .25 L
.63823 .25 L
.63824 .25 L
.63824 .25 L
.63825 .25 L
.63825 .25 L
.63825 .25 L
.63826 .25 L
.63826 .25 L
.63827 .25 L
.63827 .25 L
.63828 .25 L
.63828 .25 L
.63828 .25 L
Mistroke
.63829 .25 L
.63829 .25 L
.63829 .25 L
.6383 .25 L
.6383 .25 L
.63831 .25 L
.63832 .25 L
.63833 .25 L
.63833 .25 L
.63834 .25 L
.63834 .25 L
.63835 .25 L
.63836 .25 L
.63836 .25 L
.63837 .25 L
.63838 .25 L
.63838 .25 L
.63839 .25 L
.63839 .25 L
.6384 .25 L
.6384 .25 L
.63841 .25 L
.63842 .25 L
.63842 .25 L
.63843 .25 L
.63843 .25 L
.63844 .25 L
.63845 .25 L
.63845 .25 L
.63846 .25 L
.63846 .25 L
.63847 .25 L
.63848 .25 L
.63848 .25 L
.63849 .25 L
.63849 .25 L
.6385 .25 L
.6385 .25 L
.63851 .25 L
.63851 .25 L
.63852 .25 L
.63853 .25 L
.63853 .25 L
.63854 .25 L
.63855 .25 L
.63855 .25 L
.63856 .25 L
.63856 .25 L
.63857 .25 L
.63858 .25 L
Mistroke
.63858 .25 L
.63859 .25 L
.6386 .25 L
.6386 .25 L
.6386 .25 L
.63861 .25 L
.63862 .25 L
.63862 .25 L
.63863 .25 L
.63864 .25 L
.63864 .25 L
.63865 .25 L
.63865 .25 L
.63866 .25 L
.63867 .25 L
.63867 .25 L
.63868 .25 L
.63868 .25 L
.63869 .25 L
.6387 .25 L
.6387 .25 L
.6387 .25 L
.63871 .25 L
.63872 .25 L
.63872 .25 L
.63873 .25 L
.63873 .25 L
.63874 .25 L
.63874 .25 L
.63875 .25 L
.63875 .25 L
.63876 .25 L
.63877 .25 L
.63877 .25 L
.63878 .25 L
.63878 .25 L
.63879 .25 L
.63879 .25 L
.6388 .25 L
.6388 .25 L
.63881 .25 L
.63881 .25 L
.63882 .25 L
.63883 .25 L
.63883 .25 L
.63884 .25 L
.63884 .25 L
.63885 .25 L
.63886 .25 L
.63886 .25 L
Mistroke
.63887 .25 L
.63888 .25 L
.63888 .25 L
.63889 .25 L
.63889 .25 L
.6389 .25 L
.63891 .25 L
.63891 .25 L
.63892 .25 L
.63893 .25 L
.63893 .25 L
.63894 .25 L
.63894 .25 L
.63894 .25 L
.63895 .25 L
.63895 .25 L
.63896 .25 L
.63897 .25 L
.63897 .25 L
.63898 .25 L
.63899 .25 L
.63899 .25 L
.639 .25 L
.639 .25 L
.63901 .25 L
.63902 .25 L
.63902 .25 L
.63903 .25 L
.63904 .25 L
.63904 .25 L
.63905 .25 L
.63906 .25 L
.63906 .25 L
.63906 .25 L
.63907 .25 L
.63907 .25 L
.63908 .25 L
.63908 .25 L
.63908 .25 L
.63909 .25 L
.6391 .25 L
.6391 .25 L
.6391 .25 L
.63911 .25 L
.63911 .25 L
.63911 .25 L
.63912 .25 L
.63912 .25 L
.63913 .25 L
.63914 .25 L
Mistroke
.63914 .25 L
.63915 .25 L
.63916 .25 L
.63916 .25 L
.63917 .25 L
.63917 .25 L
.63918 .25 L
.63919 .25 L
.63919 .25 L
.6392 .25 L
.6392 .25 L
.63921 .25 L
.63922 .25 L
.63922 .25 L
.63923 .25 L
.63923 .25 L
.63924 .25 L
.63924 .25 L
.63925 .25 L
.63926 .25 L
.63926 .25 L
.63927 .25 L
.63927 .25 L
.63928 .25 L
.63929 .25 L
.63929 .25 L
.6393 .25 L
.6393 .25 L
.63931 .25 L
.63932 .25 L
.63932 .25 L
.63932 .25 L
.63933 .25 L
.63934 .25 L
.63934 .25 L
.63935 .25 L
.63936 .25 L
.63936 .25 L
.63937 .25 L
.63938 .25 L
.63938 .25 L
.63939 .25 L
.63939 .25 L
.6394 .25 L
.63941 .25 L
.63941 .25 L
.63942 .25 L
.63942 .25 L
.63943 .25 L
.63944 .25 L
Mistroke
.63944 .25 L
.63945 .25 L
.63945 .25 L
.63946 .25 L
.63947 .25 L
.63947 .25 L
.63948 .25 L
.63948 .25 L
.63949 .25 L
.63949 .25 L
.6395 .25 L
.63951 .25 L
.63951 .25 L
.63952 .25 L
.63952 .25 L
.63953 .25 L
.63953 .25 L
.63954 .25 L
.63955 .25 L
.63955 .25 L
.63956 .25 L
.63957 .25 L
.63957 .25 L
.63958 .25 L
.63958 .25 L
.63959 .25 L
.6396 .25 L
.6396 .25 L
.63961 .25 L
.63962 .25 L
.63962 .25 L
.63963 .25 L
.63963 .25 L
.63964 .25 L
.63964 .25 L
.63965 .25 L
.63966 .25 L
.63966 .25 L
.63967 .25 L
.63967 .25 L
.63968 .25 L
.63969 .25 L
.63969 .25 L
.6397 .25 L
.6397 .25 L
.63971 .25 L
.63972 .25 L
.63972 .25 L
.63973 .25 L
.63973 .25 L
Mistroke
.63974 .25 L
.63974 .25 L
.63975 .25 L
.63975 .25 L
.63976 .25 L
.63976 .25 L
.63977 .25 L
.63977 .25 L
.63978 .25 L
.63979 .25 L
.63979 .25 L
.6398 .25 L
.6398 .25 L
.63981 .25 L
.63981 .25 L
.63982 .25 L
.63982 .25 L
.63983 .25 L
.63983 .25 L
.63984 .25 L
.63985 .25 L
.63985 .25 L
.63986 .25 L
.63986 .25 L
.63987 .25 L
.63988 .25 L
.63988 .25 L
.63989 .25 L
.63989 .25 L
.6399 .25 L
.63991 .25 L
.63991 .25 L
.63992 .25 L
.63993 .25 L
.63993 .25 L
.63994 .25 L
.63995 .25 L
.63995 .25 L
.63996 .25 L
.63996 .25 L
.63997 .25 L
.63997 .25 L
.63997 .25 L
.63998 .25 L
.63999 .25 L
.63999 .25 L
.64 .25 L
.64001 .25 L
.64001 .25 L
.64002 .25 L
Mistroke
.64002 .25 L
.64003 .25 L
.64004 .25 L
.64004 .25 L
.64005 .25 L
.64006 .25 L
.64006 .25 L
.64007 .25 L
.64008 .25 L
.64008 .25 L
.64009 .25 L
.64009 .25 L
.6401 .25 L
.6401 .25 L
.6401 .25 L
.64011 .25 L
.64011 .25 L
.64012 .25 L
.64012 .25 L
.64013 .25 L
.64013 .25 L
.64013 .25 L
.64014 .25 L
.64014 .25 L
.64014 .25 L
.64015 .25 L
.64015 .25 L
.64016 .25 L
.64017 .25 L
.64017 .25 L
.64018 .25 L
.64019 .25 L
.64019 .25 L
.6402 .25 L
.64021 .25 L
.64021 .25 L
.64022 .25 L
.64023 .25 L
.64023 .25 L
.64024 .25 L
.64024 .25 L
.64025 .25 L
.64025 .25 L
.64026 .25 L
.64027 .25 L
.64027 .25 L
.64028 .25 L
.64028 .25 L
.64029 .25 L
.6403 .25 L
Mistroke
.6403 .25 L
.64031 .25 L
.64031 .25 L
.64032 .25 L
.64033 .25 L
.64033 .25 L
.64034 .25 L
.64034 .25 L
.64035 .25 L
.64035 .25 L
.64036 .25 L
.64036 .25 L
.64037 .25 L
.64038 .25 L
.64038 .25 L
.64039 .25 L
.6404 .25 L
.6404 .25 L
.64041 .25 L
.64041 .25 L
.64042 .25 L
.64043 .25 L
.64043 .25 L
.64044 .25 L
.64045 .25 L
.64045 .25 L
.64045 .25 L
.64046 .25 L
.64047 .25 L
.64047 .25 L
.64048 .25 L
.64049 .25 L
.64049 .25 L
.6405 .25 L
.6405 .25 L
.64051 .25 L
.64052 .25 L
.64052 .25 L
.64053 .25 L
.64053 .25 L
.64054 .25 L
.64055 .25 L
.64055 .25 L
.64055 .25 L
.64056 .25 L
.64057 .25 L
.64057 .25 L
.64058 .25 L
.64058 .25 L
.64059 .25 L
Mistroke
.64059 .25 L
.6406 .25 L
.6406 .25 L
.64061 .25 L
.64062 .25 L
.64062 .25 L
.64063 .25 L
.64063 .25 L
.64064 .25 L
.64064 .25 L
.64065 .25 L
.64065 .25 L
.64066 .25 L
.64067 .25 L
.64067 .25 L
.64068 .25 L
.64068 .25 L
.64069 .25 L
.64069 .25 L
.6407 .25 L
.64071 .25 L
.64071 .25 L
.64072 .25 L
.64073 .25 L
.64073 .25 L
.64074 .25 L
.64074 .25 L
.64075 .25 L
.64076 .25 L
.64076 .25 L
.64077 .25 L
.64078 .25 L
.64078 .25 L
.64079 .25 L
.64079 .25 L
.64079 .25 L
.6408 .25 L
.6408 .25 L
.64081 .25 L
.64082 .25 L
.64082 .25 L
.64083 .25 L
.64084 .25 L
.64084 .25 L
.64085 .25 L
.64085 .25 L
.64086 .25 L
.64087 .25 L
.64087 .25 L
.64088 .25 L
Mistroke
.64089 .25 L
.64089 .25 L
.6409 .25 L
.64091 .25 L
.64091 .25 L
.64091 .25 L
.64092 .25 L
.64092 .25 L
.64093 .25 L
.64093 .25 L
.64094 .25 L
.64094 .25 L
.64095 .25 L
.64095 .25 L
.64095 .25 L
.64096 .25 L
.64096 .25 L
.64097 .25 L
.64097 .25 L
.64097 .25 L
.64098 .25 L
.64099 .25 L
.64099 .25 L
.641 .25 L
.64101 .25 L
.64101 .25 L
.64102 .25 L
.64102 .25 L
.64103 .25 L
.64104 .25 L
.64104 .25 L
.64105 .25 L
.64106 .25 L
.64106 .25 L
.64107 .25 L
.64107 .25 L
.64108 .25 L
.64108 .25 L
.64109 .25 L
.6411 .25 L
.6411 .25 L
.64111 .25 L
.64111 .25 L
.64112 .25 L
.64112 .25 L
.64113 .25 L
.64114 .25 L
.64114 .25 L
.64115 .25 L
.64116 .25 L
Mistroke
.64116 .25 L
.64117 .25 L
.64117 .25 L
.64117 .25 L
.64118 .25 L
.64119 .25 L
.64119 .25 L
.6412 .25 L
.64121 .25 L
.64121 .25 L
.64122 .25 L
.64123 .25 L
.64123 .25 L
.64124 .25 L
.64124 .25 L
.64125 .25 L
.64126 .25 L
.64126 .25 L
.64127 .25 L
.64128 .25 L
.64128 .25 L
.64129 .25 L
.64129 .25 L
.6413 .25 L
.6413 .25 L
.64131 .25 L
.64132 .25 L
.64132 .25 L
.64133 .25 L
.64133 .25 L
.64134 .25 L
.64135 .25 L
.64135 .25 L
.64136 .25 L
.64136 .25 L
.64137 .25 L
.64137 .25 L
.64138 .25 L
.64138 .25 L
.64139 .25 L
.6414 .25 L
.6414 .25 L
.6414 .25 L
.64141 .25 L
.64142 .25 L
.64142 .25 L
.64143 .25 L
.64143 .25 L
.64144 .25 L
.64145 .25 L
Mistroke
.64145 .25 L
.64145 .25 L
.64146 .25 L
.64147 .25 L
.64147 .25 L
.64148 .25 L
.64148 .25 L
.64149 .25 L
.64149 .25 L
.6415 .25 L
.64151 .25 L
.64151 .25 L
.64152 .25 L
.64152 .25 L
.64153 .25 L
.64154 .25 L
.64154 .25 L
.64155 .25 L
.64156 .25 L
.64156 .25 L
.64157 .25 L
.64157 .25 L
.64158 .25 L
.64159 .25 L
.64159 .25 L
.6416 .25 L
.64161 .25 L
.64161 .25 L
.64161 .25 L
.64162 .25 L
.64162 .25 L
.64163 .25 L
.64163 .25 L
.64164 .25 L
.64165 .25 L
.64165 .25 L
.64166 .25 L
.64167 .25 L
.64167 .25 L
.64168 .25 L
.64168 .25 L
.64169 .25 L
.6417 .25 L
.6417 .25 L
.64171 .25 L
.64172 .25 L
.64172 .25 L
.64173 .25 L
.64173 .25 L
.64174 .25 L
Mistroke
.64174 .25 L
.64175 .25 L
.64175 .25 L
.64176 .25 L
.64176 .25 L
.64177 .25 L
.64177 .25 L
.64177 .25 L
.64178 .25 L
.64178 .25 L
.64178 .25 L
.64179 .25 L
.64179 .25 L
.6418 .25 L
.6418 .25 L
.64181 .25 L
.64182 .25 L
.64182 .25 L
.64183 .25 L
.64184 .25 L
.64184 .25 L
.64185 .25 L
.64185 .25 L
.64186 .25 L
.64187 .25 L
.64187 .25 L
.64188 .25 L
.64189 .25 L
.64189 .25 L
.6419 .25 L
.6419 .25 L
.64191 .25 L
.64191 .25 L
.64192 .25 L
.64193 .25 L
.64193 .25 L
.64194 .25 L
.64194 .25 L
.64195 .25 L
.64195 .25 L
.64196 .25 L
.64197 .25 L
.64197 .25 L
.64198 .25 L
.64198 .25 L
.64199 .25 L
.64199 .25 L
.642 .25 L
.642 .25 L
.64201 .25 L
Mistroke
.64202 .25 L
.64202 .25 L
.64203 .25 L
.64204 .25 L
.64204 .25 L
.64205 .25 L
.64206 .25 L
.64206 .25 L
.64207 .25 L
.64208 .25 L
.64208 .25 L
.64209 .25 L
.64209 .25 L
.6421 .25 L
.6421 .25 L
.64211 .25 L
.64212 .25 L
.64212 .25 L
.64213 .25 L
.64213 .25 L
.64214 .25 L
.64215 .25 L
.64215 .25 L
.64216 .25 L
.64216 .25 L
.64217 .25 L
.64218 .25 L
.64218 .25 L
.64219 .25 L
.64219 .25 L
.6422 .25 L
.6422 .25 L
.64221 .25 L
.64221 .25 L
.64222 .25 L
.64222 .25 L
.64223 .25 L
.64223 .25 L
.64224 .25 L
.64225 .25 L
.64225 .25 L
.64226 .25 L
.64226 .25 L
.64227 .25 L
.64227 .25 L
.64228 .25 L
.64229 .25 L
.64229 .25 L
.64229 .25 L
.6423 .25 L
Mistroke
.64231 .25 L
.64231 .25 L
.64232 .25 L
.64232 .25 L
.64233 .25 L
.64234 .25 L
.64234 .25 L
.64235 .25 L
.64235 .25 L
.64236 .25 L
.64237 .25 L
.64237 .25 L
.64238 .25 L
.64238 .25 L
.64239 .25 L
.6424 .25 L
.6424 .25 L
.64241 .25 L
.64242 .25 L
.64242 .25 L
.64243 .25 L
.64243 .25 L
.64244 .25 L
.64244 .25 L
.64244 .25 L
.64245 .25 L
.64246 .25 L
.64246 .25 L
.64247 .25 L
.64248 .25 L
.64248 .25 L
.64249 .25 L
.64249 .25 L
.6425 .25 L
.64251 .25 L
.64251 .25 L
.64252 .25 L
.64253 .25 L
.64253 .25 L
.64254 .25 L
.64255 .25 L
.64255 .25 L
.64256 .25 L
.64256 .25 L
.64257 .25 L
.64257 .25 L
.64258 .25 L
.64258 .25 L
.64258 .25 L
.64259 .25 L
Mistroke
.64259 .25 L
.6426 .25 L
.6426 .25 L
.6426 .25 L
.64261 .25 L
.64261 .25 L
.64262 .25 L
.64262 .25 L
.64263 .25 L
.64263 .25 L
.64264 .25 L
.64265 .25 L
.64265 .25 L
.64266 .25 L
.64266 .25 L
.64267 .25 L
.64268 .25 L
.64268 .25 L
.64269 .25 L
.6427 .25 L
.6427 .25 L
.64271 .25 L
.64272 .25 L
.64272 .25 L
.64272 .25 L
.64273 .25 L
.64274 .25 L
.64274 .25 L
.64275 .25 L
.64276 .25 L
.64276 .25 L
.64277 .25 L
.64277 .25 L
.64278 .25 L
.64278 .25 L
.64279 .25 L
.6428 .25 L
.6428 .25 L
.64281 .25 L
.64281 .25 L
.64282 .25 L
.64282 .25 L
.64283 .25 L
.64283 .25 L
.64284 .25 L
.64285 .25 L
.64285 .25 L
.64286 .25 L
.64287 .25 L
.64287 .25 L
Mistroke
.64288 .25 L
.64289 .25 L
.64289 .25 L
.6429 .25 L
.6429 .25 L
.64291 .25 L
.64292 .25 L
.64292 .25 L
.64293 .25 L
.64293 .25 L
.64294 .25 L
.64294 .25 L
.64295 .25 L
.64296 .25 L
.64296 .25 L
.64297 .25 L
.64297 .25 L
.64298 .25 L
.64299 .25 L
.64299 .25 L
.643 .25 L
.643 .25 L
.64301 .25 L
.64302 .25 L
.64302 .25 L
.64302 .25 L
.64303 .25 L
.64304 .25 L
.64304 .25 L
.64305 .25 L
.64306 .25 L
.64306 .25 L
.64307 .25 L
.64308 .25 L
.64308 .25 L
.64309 .25 L
.64309 .25 L
.6431 .25 L
.64311 .25 L
.64311 .25 L
.64312 .25 L
.64312 .25 L
.64313 .25 L
.64314 .25 L
.64314 .25 L
.64315 .25 L
.64315 .25 L
.64316 .25 L
.64317 .25 L
.64317 .25 L
Mistroke
.64318 .25 L
.64318 .25 L
.64319 .25 L
.64319 .25 L
.6432 .25 L
.64321 .25 L
.64321 .25 L
.64322 .25 L
.64322 .25 L
.64323 .25 L
.64323 .25 L
.64324 .25 L
.64325 .25 L
.64325 .25 L
.64325 .25 L
.64326 .25 L
.64327 .25 L
.64327 .25 L
.64328 .25 L
.64328 .25 L
.64329 .25 L
.6433 .25 L
.6433 .25 L
.6433 .25 L
.64331 .25 L
.64332 .25 L
.64332 .25 L
.64333 .25 L
.64333 .25 L
.64334 .25 L
.64334 .25 L
.64335 .25 L
.64336 .25 L
.64336 .25 L
.64337 .25 L
.64337 .25 L
.64338 .25 L
.64339 .25 L
.64339 .25 L
.6434 .25 L
.64341 .25 L
.64341 .25 L
.64342 .25 L
.64342 .25 L
.64343 .25 L
.64344 .25 L
.64344 .25 L
.64345 .25 L
.64346 .25 L
.64346 .25 L
Mistroke
.64346 .25 L
.64347 .25 L
.64347 .25 L
.64348 .25 L
.64348 .25 L
.64349 .25 L
.6435 .25 L
.6435 .25 L
.64351 .25 L
.64352 .25 L
.64352 .25 L
.64353 .25 L
.64353 .25 L
.64354 .25 L
.64355 .25 L
.64355 .25 L
.64356 .25 L
.64357 .25 L
.64357 .25 L
.64358 .25 L
.64358 .25 L
.64359 .25 L
.64359 .25 L
.6436 .25 L
.6436 .25 L
.64361 .25 L
.64361 .25 L
.64362 .25 L
.64362 .25 L
.64362 .25 L
.64363 .25 L
.64363 .25 L
.64363 .25 L
.64364 .25 L
.64364 .25 L
.64365 .25 L
.64365 .25 L
.64366 .25 L
.64367 .25 L
.64367 .25 L
.64368 .25 L
.64369 .25 L
.64369 .25 L
.6437 .25 L
.6437 .25 L
.64371 .25 L
.64372 .25 L
.64372 .25 L
.64373 .25 L
.64374 .25 L
Mistroke
.64374 .25 L
.64375 .25 L
.64375 .25 L
.64376 .25 L
.64376 .25 L
.64377 .25 L
.64378 .25 L
.64378 .25 L
.64379 .25 L
.64379 .25 L
.6438 .25 L
.6438 .25 L
.64381 .25 L
.64382 .25 L
.64382 .25 L
.64383 .25 L
.64383 .25 L
.64384 .25 L
.64384 .25 L
.64385 .25 L
.64385 .25 L
.64386 .25 L
.64387 .25 L
.64387 .25 L
.64388 .25 L
.64389 .25 L
.64389 .25 L
.6439 .25 L
.64391 .25 L
.64391 .25 L
.64392 .25 L
.64393 .25 L
.64393 .25 L
.64394 .25 L
.64394 .25 L
.64395 .25 L
.64395 .25 L
.64396 .25 L
.64397 .25 L
.64397 .25 L
.64398 .25 L
.64398 .25 L
.64399 .25 L
.644 .25 L
.644 .25 L
.64401 .25 L
.64401 .25 L
.64402 .25 L
.64403 .25 L
.64403 .25 L
Mistroke
.64404 .25 L
.64404 .25 L
.64405 .25 L
.64405 .25 L
.64406 .25 L
.64406 .25 L
.64407 .25 L
.64407 .25 L
.64408 .25 L
.64408 .25 L
.64409 .25 L
.6441 .25 L
.6441 .25 L
.64411 .25 L
.64411 .25 L
.64412 .25 L
.64412 .25 L
.64413 .25 L
.64414 .25 L
.64414 .25 L
.64414 .25 L
.64415 .25 L
.64416 .25 L
.64416 .25 L
.64417 .25 L
.64417 .25 L
.64418 .25 L
.64419 .25 L
.64419 .25 L
.6442 .25 L
.6442 .25 L
.64421 .25 L
.64422 .25 L
.64422 .25 L
.64423 .25 L
.64423 .25 L
.64424 .25 L
.64425 .25 L
.64425 .25 L
.64426 .25 L
.64427 .25 L
.64427 .25 L
.64428 .25 L
.64428 .25 L
.64429 .25 L
.64429 .25 L
.64429 .25 L
.6443 .25 L
.64431 .25 L
.64431 .25 L
Mistroke
.64432 .25 L
.64433 .25 L
.64433 .25 L
.64434 .25 L
.64435 .25 L
.64435 .25 L
.64436 .25 L
.64437 .25 L
.64437 .25 L
.64438 .25 L
.64438 .25 L
.64439 .25 L
.6444 .25 L
.6444 .25 L
.64441 .25 L
.64441 .25 L
.64442 .25 L
.64442 .25 L
.64443 .25 L
.64443 .25 L
.64443 .25 L
.64444 .25 L
.64444 .25 L
.64445 .25 L
.64445 .25 L
.64446 .25 L
.64446 .25 L
.64446 .25 L
.64447 .25 L
.64447 .25 L
.64448 .25 L
.64448 .25 L
.64449 .25 L
.6445 .25 L
.6445 .25 L
.64451 .25 L
.64452 .25 L
.64452 .25 L
.64453 .25 L
.64453 .25 L
.64454 .25 L
.64455 .25 L
.64455 .25 L
.64456 .25 L
.64457 .25 L
.64457 .25 L
.64457 .25 L
.64458 .25 L
.64459 .25 L
.64459 .25 L
Mistroke
.6446 .25 L
.64461 .25 L
.64461 .25 L
.64462 .25 L
.64462 .25 L
.64463 .25 L
.64463 .25 L
.64464 .25 L
.64465 .25 L
.64465 .25 L
.64466 .25 L
.64467 .25 L
.64467 .25 L
.64467 .25 L
.64468 .25 L
.64469 .25 L
.64469 .25 L
.6447 .25 L
.64471 .25 L
.64471 .25 L
.64472 .25 L
.64472 .25 L
.64473 .25 L
.64474 .25 L
.64474 .25 L
.64475 .25 L
.64476 .25 L
.64476 .25 L
.64477 .25 L
.64477 .25 L
.64478 .25 L
.64478 .25 L
.64479 .25 L
.6448 .25 L
.6448 .25 L
.64481 .25 L
.64481 .25 L
.64482 .25 L
.64483 .25 L
.64483 .25 L
.64484 .25 L
.64484 .25 L
.64485 .25 L
.64486 .25 L
.64486 .25 L
.64487 .25 L
.64487 .25 L
.64487 .25 L
.64488 .25 L
.64489 .25 L
Mistroke
.64489 .25 L
.6449 .25 L
.6449 .25 L
.64491 .25 L
.64491 .25 L
.64492 .25 L
.64493 .25 L
.64493 .25 L
.64494 .25 L
.64494 .25 L
.64495 .25 L
.64495 .25 L
.64496 .25 L
.64496 .25 L
.64497 .25 L
.64497 .25 L
.64498 .25 L
.64499 .25 L
.64499 .25 L
.645 .25 L
.645 .25 L
.64501 .25 L
.64502 .25 L
.64502 .25 L
.64503 .25 L
.64503 .25 L
.64504 .25 L
.64505 .25 L
.64505 .25 L
.64506 .25 L
.64506 .25 L
.64507 .25 L
.64508 .25 L
.64508 .25 L
.64509 .25 L
.6451 .25 L
.6451 .25 L
.64511 .25 L
.64511 .25 L
.64511 .25 L
.64512 .25 L
.64513 .25 L
.64513 .25 L
.64514 .25 L
.64515 .25 L
.64515 .25 L
.64516 .25 L
.64516 .25 L
.64517 .25 L
.64518 .25 L
Mistroke
.64518 .25 L
.64519 .25 L
.64519 .25 L
.6452 .25 L
.64521 .25 L
.64521 .25 L
.64522 .25 L
.64523 .25 L
.64523 .25 L
.64524 .25 L
.64524 .25 L
.64525 .25 L
.64525 .25 L
.64525 .25 L
.64526 .25 L
.64526 .25 L
.64527 .25 L
.64527 .25 L
.64527 .25 L
.64528 .25 L
.64528 .25 L
.64529 .25 L
.64529 .25 L
.64529 .25 L
.6453 .25 L
.64531 .25 L
.64531 .25 L
.64532 .25 L
.64533 .25 L
.64533 .25 L
.64534 .25 L
.64534 .25 L
.64535 .25 L
.64536 .25 L
.64536 .25 L
.64537 .25 L
.64538 .25 L
.64538 .25 L
.64539 .25 L
.64539 .25 L
.6454 .25 L
.6454 .25 L
.64541 .25 L
.64542 .25 L
.64542 .25 L
.64543 .25 L
.64544 .25 L
.64544 .25 L
.64545 .25 L
.64545 .25 L
Mistroke
.64546 .25 L
.64546 .25 L
.64547 .25 L
.64548 .25 L
.64548 .25 L
.64549 .25 L
.64549 .25 L
.6455 .25 L
.6455 .25 L
.64551 .25 L
.64552 .25 L
.64552 .25 L
.64553 .25 L
.64554 .25 L
.64554 .25 L
.64555 .25 L
.64555 .25 L
.64556 .25 L
.64557 .25 L
.64557 .25 L
.64558 .25 L
.64559 .25 L
.64559 .25 L
.6456 .25 L
.6456 .25 L
.64561 .25 L
.64561 .25 L
.64562 .25 L
.64563 .25 L
.64563 .25 L
.64564 .25 L
.64564 .25 L
.64565 .25 L
.64565 .25 L
.64566 .25 L
.64567 .25 L
.64567 .25 L
.64568 .25 L
.64568 .25 L
.64569 .25 L
.6457 .25 L
.6457 .25 L
.6457 .25 L
.64571 .25 L
.64572 .25 L
.64572 .25 L
.64572 .25 L
.64573 .25 L
.64574 .25 L
.64574 .25 L
Mistroke
.64575 .25 L
.64576 .25 L
.64576 .25 L
.64577 .25 L
.64577 .25 L
.64578 .25 L
.64578 .25 L
.64579 .25 L
.64579 .25 L
.6458 .25 L
.6458 .25 L
.64581 .25 L
.64582 .25 L
.64582 .25 L
.64583 .25 L
.64583 .25 L
.64584 .25 L
.64584 .25 L
.64585 .25 L
.64586 .25 L
.64586 .25 L
.64587 .25 L
.64588 .25 L
.64588 .25 L
.64589 .25 L
.64589 .25 L
.6459 .25 L
.64591 .25 L
.64591 .25 L
.64592 .25 L
.64593 .25 L
.64593 .25 L
.64593 .25 L
.64594 .25 L
.64594 .25 L
.64595 .25 L
.64595 .25 L
.64596 .25 L
.64597 .25 L
.64597 .25 L
.64598 .25 L
.64599 .25 L
.64599 .25 L
.646 .25 L
.64601 .25 L
.64601 .25 L
.64602 .25 L
.64602 .25 L
.64603 .25 L
.64604 .25 L
Mistroke
.64604 .25 L
.64605 .25 L
.64606 .25 L
.64606 .25 L
.64607 .25 L
.64607 .25 L
.64607 .25 L
.64608 .25 L
.64608 .25 L
.64609 .25 L
.64609 .25 L
.64609 .25 L
.6461 .25 L
.6461 .25 L
.64611 .25 L
.64611 .25 L
.64611 .25 L
.64612 .25 L
.64612 .25 L
.64613 .25 L
.64614 .25 L
.64614 .25 L
.64615 .25 L
.64616 .25 L
.64616 .25 L
.64617 .25 L
.64617 .25 L
.64618 .25 L
.64619 .25 L
.64619 .25 L
.6462 .25 L
.64621 .25 L
.64621 .25 L
.64622 .25 L
.64622 .25 L
.64623 .25 L
.64623 .25 L
.64624 .25 L
.64625 .25 L
.64625 .25 L
.64626 .25 L
.64626 .25 L
.64627 .25 L
.64628 .25 L
.64628 .25 L
.64629 .25 L
.64629 .25 L
.6463 .25 L
.64631 .25 L
.64631 .25 L
Mistroke
.64632 .25 L
.64632 .25 L
.64633 .25 L
.64633 .25 L
.64634 .25 L
.64635 .25 L
.64635 .25 L
.64636 .25 L
.64636 .25 L
.64637 .25 L
.64638 .25 L
.64638 .25 L
.64639 .25 L
.6464 .25 L
.6464 .25 L
.64641 .25 L
.64642 .25 L
.64642 .25 L
.64642 .25 L
.64643 .25 L
.64644 .25 L
.64644 .25 L
.64645 .25 L
.64646 .25 L
.64646 .25 L
.64647 .25 L
.64647 .25 L
.64648 .25 L
.64648 .25 L
.64649 .25 L
.6465 .25 L
.6465 .25 L
.64651 .25 L
.64651 .25 L
.64652 .25 L
.64652 .25 L
.64653 .25 L
.64653 .25 L
.64654 .25 L
.64655 .25 L
.64656 .25 L
.64656 .25 L
.64657 .25 L
.64657 .25 L
.64658 .25 L
.64659 .25 L
.64659 .25 L
.6466 .25 L
.6466 .25 L
.64661 .25 L
Mistroke
.64662 .25 L
.64662 .25 L
.64663 .25 L
.64663 .25 L
.64664 .25 L
.64665 .25 L
.64665 .25 L
.64666 .25 L
.64666 .25 L
.64667 .25 L
.64667 .25 L
.64668 .25 L
.64669 .25 L
.64669 .25 L
.6467 .25 L
.64671 .25 L
.64671 .25 L
.64672 .25 L
.64672 .25 L
.64672 .25 L
.64673 .25 L
.64674 .25 L
.64674 .25 L
.64675 .25 L
.64675 .25 L
.64676 .25 L
.64676 .25 L
.64677 .25 L
.64678 .25 L
.64678 .25 L
.64679 .25 L
.64679 .25 L
.6468 .25 L
.6468 .25 L
.64681 .25 L
.64681 .25 L
.64682 .25 L
.64682 .25 L
.64683 .25 L
.64684 .25 L
.64684 .25 L
.64685 .25 L
.64685 .25 L
.64686 .25 L
.64687 .25 L
.64687 .25 L
.64688 .25 L
.64688 .25 L
.64689 .25 L
.6469 .25 L
Mistroke
.6469 .25 L
.64691 .25 L
.64691 .25 L
.64692 .25 L
.64693 .25 L
.64693 .25 L
.64694 .25 L
.64695 .25 L
.64695 .25 L
.64696 .25 L
.64696 .25 L
.64696 .25 L
.64697 .25 L
.64698 .25 L
.64698 .25 L
.64699 .25 L
.647 .25 L
.647 .25 L
.64701 .25 L
.64701 .25 L
.64702 .25 L
.64703 .25 L
.64703 .25 L
.64704 .25 L
.64704 .25 L
.64705 .25 L
.64706 .25 L
.64706 .25 L
.64707 .25 L
.64708 .25 L
.64708 .25 L
.64709 .25 L
.64709 .25 L
.6471 .25 L
.6471 .25 L
.6471 .25 L
.64711 .25 L
.64711 .25 L
.64712 .25 L
.64712 .25 L
.64712 .25 L
.64713 .25 L
.64713 .25 L
.64714 .25 L
.64714 .25 L
.64714 .25 L
.64715 .25 L
.64716 .25 L
.64716 .25 L
.64717 .25 L
Mistroke
.64718 .25 L
.64718 .25 L
.64719 .25 L
.64719 .25 L
.6472 .25 L
.64721 .25 L
.64721 .25 L
.64722 .25 L
.64723 .25 L
.64723 .25 L
.64724 .25 L
.64724 .25 L
.64725 .25 L
.64725 .25 L
.64726 .25 L
.64727 .25 L
.64727 .25 L
.64728 .25 L
.64729 .25 L
.64729 .25 L
.6473 .25 L
.6473 .25 L
.64731 .25 L
.64731 .25 L
.64732 .25 L
.64733 .25 L
.64733 .25 L
.64734 .25 L
.64734 .25 L
.64735 .25 L
.64735 .25 L
.64736 .25 L
.64737 .25 L
.64737 .25 L
.64738 .25 L
.64739 .25 L
.64739 .25 L
.6474 .25 L
.6474 .25 L
.64741 .25 L
.64742 .25 L
.64742 .25 L
.64743 .25 L
.64744 .25 L
.64744 .25 L
.64745 .25 L
.64745 .25 L
.64746 .25 L
.64746 .25 L
.64747 .25 L
Mistroke
.64748 .25 L
.64748 .25 L
.64749 .25 L
.64749 .25 L
.6475 .25 L
.64751 .25 L
.64751 .25 L
.64752 .25 L
.64752 .25 L
.64753 .25 L
.64754 .25 L
.64754 .25 L
.64755 .25 L
.64755 .25 L
.64756 .25 L
.64756 .25 L
.64757 .25 L
.64757 .25 L
.64758 .25 L
.64758 .25 L
.64759 .25 L
.64759 .25 L
.6476 .25 L
.64761 .25 L
.64761 .25 L
.64762 .25 L
.64762 .25 L
.64763 .25 L
.64763 .25 L
.64764 .25 L
.64764 .25 L
.64765 .25 L
.64765 .25 L
.64766 .25 L
.64767 .25 L
.64767 .25 L
.64768 .25 L
.64768 .25 L
.64769 .25 L
.6477 .25 L
.6477 .25 L
.64771 .25 L
.64771 .25 L
.64772 .25 L
.64773 .25 L
.64773 .25 L
.64774 .25 L
.64775 .25 L
.64775 .25 L
.64776 .25 L
Mistroke
.64776 .25 L
.64777 .25 L
.64778 .25 L
.64778 .25 L
.64779 .25 L
.64779 .25 L
.64779 .25 L
.6478 .25 L
.64781 .25 L
.64781 .25 L
.64782 .25 L
.64783 .25 L
.64783 .25 L
.64784 .25 L
.64784 .25 L
.64785 .25 L
.64786 .25 L
.64786 .25 L
.64787 .25 L
.64788 .25 L
.64788 .25 L
.64789 .25 L
.64789 .25 L
.6479 .25 L
.64791 .25 L
.64791 .25 L
.64792 .25 L
.64792 .25 L
.64792 .25 L
.64793 .25 L
.64793 .25 L
.64794 .25 L
.64794 .25 L
.64795 .25 L
.64795 .25 L
.64795 .25 L
.64796 .25 L
.64796 .25 L
.64796 .25 L
.64797 .25 L
.64797 .25 L
.64798 .25 L
.64799 .25 L
.64799 .25 L
.648 .25 L
.64801 .25 L
.64801 .25 L
.64802 .25 L
.64803 .25 L
.64803 .25 L
Mistroke
.64804 .25 L
.64804 .25 L
.64805 .25 L
.64806 .25 L
.64806 .25 L
.64807 .25 L
.64807 .25 L
.64808 .25 L
.64809 .25 L
.64809 .25 L
.6481 .25 L
.6481 .25 L
.64811 .25 L
.64812 .25 L
.64812 .25 L
.64813 .25 L
.64813 .25 L
.64814 .25 L
.64814 .25 L
.64815 .25 L
.64816 .25 L
.64816 .25 L
.64817 .25 L
.64817 .25 L
.64818 .25 L
.64818 .25 L
.64819 .25 L
.6482 .25 L
.6482 .25 L
.64821 .25 L
.64822 .25 L
.64822 .25 L
.64823 .25 L
.64823 .25 L
.64824 .25 L
.64825 .25 L
.64825 .25 L
.64826 .25 L
.64827 .25 L
.64827 .25 L
.64827 .25 L
.64828 .25 L
.64829 .25 L
.64829 .25 L
.6483 .25 L
.64831 .25 L
.64831 .25 L
.64832 .25 L
.64832 .25 L
.64833 .25 L
Mistroke
.64833 .25 L
.64834 .25 L
.64835 .25 L
.64835 .25 L
.64836 .25 L
.64837 .25 L
.64837 .25 L
.64837 .25 L
.64838 .25 L
.64839 .25 L
.64839 .25 L
.6484 .25 L
.6484 .25 L
.64841 .25 L
.64841 .25 L
.64842 .25 L
.64842 .25 L
.64843 .25 L
.64844 .25 L
.64844 .25 L
.64845 .25 L
.64845 .25 L
.64846 .25 L
.64846 .25 L
.64846 .25 L
.64847 .25 L
.64848 .25 L
.64848 .25 L
.64849 .25 L
.6485 .25 L
.6485 .25 L
.64851 .25 L
.64851 .25 L
.64852 .25 L
.64853 .25 L
.64853 .25 L
.64854 .25 L
.64854 .25 L
.64855 .25 L
.64856 .25 L
.64856 .25 L
.64857 .25 L
.64858 .25 L
.64858 .25 L
.64859 .25 L
.6486 .25 L
.6486 .25 L
.64861 .25 L
.64861 .25 L
.64861 .25 L
Mistroke
.64862 .25 L
.64862 .25 L
.64863 .25 L
.64864 .25 L
.64864 .25 L
.64865 .25 L
.64866 .25 L
.64866 .25 L
.64867 .25 L
.64867 .25 L
.64868 .25 L
.64869 .25 L
.64869 .25 L
.6487 .25 L
.64871 .25 L
.64871 .25 L
.64872 .25 L
.64873 .25 L
.64873 .25 L
.64873 .25 L
.64874 .25 L
.64874 .25 L
.64875 .25 L
.64875 .25 L
.64875 .25 L
.64876 .25 L
.64877 .25 L
.64877 .25 L
.64877 .25 L
.64878 .25 L
.64878 .25 L
.64878 .25 L
.64879 .25 L
.64879 .25 L
.6488 .25 L
.6488 .25 L
.64881 .25 L
.64882 .25 L
.64882 .25 L
.64883 .25 L
.64884 .25 L
.64884 .25 L
.64885 .25 L
.64886 .25 L
.64886 .25 L
.64887 .25 L
.64887 .25 L
.64888 .25 L
.64889 .25 L
.64889 .25 L
Mistroke
.6489 .25 L
.6489 .25 L
.64891 .25 L
.64891 .25 L
.64892 .25 L
.64893 .25 L
.64893 .25 L
.64894 .25 L
.64894 .25 L
.64895 .25 L
.64896 .25 L
.64896 .25 L
.64897 .25 L
.64897 .25 L
.64898 .25 L
.64899 .25 L
.64899 .25 L
.64899 .25 L
.649 .25 L
.64901 .25 L
.64901 .25 L
.64902 .25 L
.64903 .25 L
.64903 .25 L
.64904 .25 L
.64904 .25 L
.64905 .25 L
.64906 .25 L
.64906 .25 L
.64907 .25 L
.64908 .25 L
.64908 .25 L
.64909 .25 L
.64909 .25 L
.6491 .25 L
.6491 .25 L
.64911 .25 L
.64912 .25 L
.64912 .25 L
.64913 .25 L
.64914 .25 L
.64914 .25 L
.64915 .25 L
.64915 .25 L
.64916 .25 L
.64916 .25 L
.64917 .25 L
.64918 .25 L
.64918 .25 L
.64919 .25 L
Mistroke
.64919 .25 L
.6492 .25 L
.6492 .25 L
.64921 .25 L
.64922 .25 L
.64922 .25 L
.64922 .25 L
.64923 .25 L
.64924 .25 L
.64924 .25 L
.64925 .25 L
.64925 .25 L
.64926 .25 L
.64927 .25 L
.64927 .25 L
.64927 .25 L
.64928 .25 L
.64928 .25 L
.64929 .25 L
.64929 .25 L
.6493 .25 L
.64931 .25 L
.64931 .25 L
.64932 .25 L
.64933 .25 L
.64933 .25 L
.64934 .25 L
.64934 .25 L
.64935 .25 L
.64936 .25 L
.64936 .25 L
.64937 .25 L
.64937 .25 L
.64938 .25 L
.64939 .25 L
.64939 .25 L
.6494 .25 L
.64941 .25 L
.64941 .25 L
.64942 .25 L
.64943 .25 L
.64943 .25 L
.64943 .25 L
.64944 .25 L
.64944 .25 L
.64945 .25 L
.64945 .25 L
.64946 .25 L
.64947 .25 L
.64947 .25 L
Mistroke
.64948 .25 L
.64949 .25 L
.64949 .25 L
.6495 .25 L
.6495 .25 L
.64951 .25 L
.64952 .25 L
.64952 .25 L
.64953 .25 L
.64954 .25 L
.64954 .25 L
.64955 .25 L
.64955 .25 L
.64956 .25 L
.64956 .25 L
.64957 .25 L
.64957 .25 L
.64957 .25 L
.64958 .25 L
.64959 .25 L
.64959 .25 L
.64959 .25 L
.6496 .25 L
.6496 .25 L
.6496 .25 L
.64961 .25 L
.64961 .25 L
.64962 .25 L
.64962 .25 L
.64963 .25 L
.64963 .25 L
.64964 .25 L
.64965 .25 L
.64965 .25 L
.64966 .25 L
.64967 .25 L
.64967 .25 L
.64968 .25 L
.64969 .25 L
.64969 .25 L
.6497 .25 L
.6497 .25 L
.64971 .25 L
.64972 .25 L
.64972 .25 L
.64973 .25 L
.64973 .25 L
.64974 .25 L
.64974 .25 L
.64975 .25 L
Mistroke
.64976 .25 L
.64976 .25 L
.64977 .25 L
.64977 .25 L
.64978 .25 L
.64979 .25 L
.64979 .25 L
.6498 .25 L
.6498 .25 L
.64981 .25 L
.64981 .25 L
.64982 .25 L
.64982 .25 L
.64983 .25 L
.64984 .25 L
.64984 .25 L
.64985 .25 L
.64986 .25 L
.64986 .25 L
.64987 .25 L
.64987 .25 L
.64988 .25 L
.64989 .25 L
.64989 .25 L
.6499 .25 L
.64991 .25 L
.64991 .25 L
.64992 .25 L
.64992 .25 L
.64993 .25 L
.64994 .25 L
.64994 .25 L
.64995 .25 L
.64995 .25 L
.64996 .25 L
.64997 .25 L
.64997 .25 L
.64998 .25 L
.64998 .25 L
.64999 .25 L
.64999 .25 L
.65 .25 L
.65001 .25 L
.65001 .25 L
.65002 .25 L
.65002 .25 L
.65003 .25 L
.65003 .25 L
.65004 .25 L
.65004 .25 L
Mistroke
.65005 .25 L
.65005 .25 L
.65006 .25 L
.65007 .25 L
.65007 .25 L
.65008 .25 L
.65008 .25 L
.65009 .25 L
.65009 .25 L
.6501 .25 L
.6501 .25 L
.65011 .25 L
.65011 .25 L
.65012 .25 L
.65013 .25 L
.65013 .25 L
.65014 .25 L
.65014 .25 L
.65015 .25 L
.65016 .25 L
.65016 .25 L
.65017 .25 L
.65017 .25 L
.65018 .25 L
.65019 .25 L
.65019 .25 L
.6502 .25 L
.6502 .25 L
.65021 .25 L
.65022 .25 L
.65022 .25 L
.65023 .25 L
.65024 .25 L
.65024 .25 L
.65025 .25 L
.65025 .25 L
.65026 .25 L
.65026 .25 L
.65026 .25 L
.65027 .25 L
.65028 .25 L
.65028 .25 L
.65029 .25 L
.6503 .25 L
.6503 .25 L
.65031 .25 L
.65031 .25 L
.65032 .25 L
.65033 .25 L
.65033 .25 L
Mistroke
.65034 .25 L
.65035 .25 L
.65035 .25 L
.65036 .25 L
.65037 .25 L
.65037 .25 L
.65038 .25 L
.65038 .25 L
.65039 .25 L
.65039 .25 L
.65039 .25 L
.6504 .25 L
.6504 .25 L
.65041 .25 L
.65041 .25 L
.65042 .25 L
.65042 .25 L
.65042 .25 L
.65043 .25 L
.65043 .25 L
.65043 .25 L
.65044 .25 L
.65044 .25 L
.65045 .25 L
.65046 .25 L
.65047 .25 L
.65047 .25 L
.65048 .25 L
.65048 .25 L
.65049 .25 L
.6505 .25 L
.6505 .25 L
.65051 .25 L
.65052 .25 L
.65052 .25 L
.65053 .25 L
.65053 .25 L
.65054 .25 L
.65054 .25 L
.65055 .25 L
.65056 .25 L
.65056 .25 L
.65057 .25 L
.65057 .25 L
.65058 .25 L
.65059 .25 L
.65059 .25 L
.6506 .25 L
.6506 .25 L
.65061 .25 L
Mistroke
.65062 .25 L
.65062 .25 L
.65063 .25 L
.65063 .25 L
.65064 .25 L
.65064 .25 L
.65065 .25 L
.65065 .25 L
.65066 .25 L
.65067 .25 L
.65067 .25 L
.65068 .25 L
.65069 .25 L
.65069 .25 L
.6507 .25 L
.6507 .25 L
.65071 .25 L
.65072 .25 L
.65072 .25 L
.65073 .25 L
.65074 .25 L
.65074 .25 L
.65074 .25 L
.65075 .25 L
.65076 .25 L
.65076 .25 L
.65077 .25 L
.65078 .25 L
.65078 .25 L
.65079 .25 L
.65079 .25 L
.6508 .25 L
.65081 .25 L
.65081 .25 L
.65082 .25 L
.65082 .25 L
.65083 .25 L
.65084 .25 L
.65084 .25 L
.65084 .25 L
.65085 .25 L
.65086 .25 L
.65086 .25 L
.65087 .25 L
.65088 .25 L
.65088 .25 L
.65089 .25 L
.65089 .25 L
.6509 .25 L
.65091 .25 L
Mistroke
.65091 .25 L
.65092 .25 L
.65093 .25 L
.65093 .25 L
.65094 .25 L
.65094 .25 L
.65095 .25 L
.65095 .25 L
.65096 .25 L
.65097 .25 L
.65097 .25 L
.65098 .25 L
.65099 .25 L
.65099 .25 L
.651 .25 L
.651 .25 L
.65101 .25 L
.65101 .25 L
.65102 .25 L
.65103 .25 L
.65103 .25 L
.65104 .25 L
.65104 .25 L
.65105 .25 L
.65105 .25 L
.65106 .25 L
.65107 .25 L
.65107 .25 L
.65107 .25 L
.65108 .25 L
.65109 .25 L
.65109 .25 L
.6511 .25 L
.6511 .25 L
.65111 .25 L
.65112 .25 L
.65112 .25 L
.65112 .25 L
.65113 .25 L
.65113 .25 L
.65114 .25 L
.65114 .25 L
.65115 .25 L
.65116 .25 L
.65116 .25 L
.65117 .25 L
.65118 .25 L
.65118 .25 L
.65119 .25 L
.65119 .25 L
Mistroke
.6512 .25 L
.65121 .25 L
.65121 .25 L
.65122 .25 L
.65122 .25 L
.65123 .25 L
.65124 .25 L
.65124 .25 L
.65125 .25 L
.65126 .25 L
.65126 .25 L
.65127 .25 L
.65128 .25 L
.65128 .25 L
.65128 .25 L
.65129 .25 L
.65129 .25 L
.6513 .25 L
.6513 .25 L
.65131 .25 L
.65132 .25 L
.65132 .25 L
.65133 .25 L
.65133 .25 L
.65134 .25 L
.65135 .25 L
.65135 .25 L
.65136 .25 L
.65137 .25 L
.65137 .25 L
.65138 .25 L
.65139 .25 L
.65139 .25 L
.6514 .25 L
.6514 .25 L
.65141 .25 L
.65141 .25 L
.65142 .25 L
.65142 .25 L
.65142 .25 L
.65143 .25 L
.65143 .25 L
.65144 .25 L
.65144 .25 L
.65145 .25 L
.65145 .25 L
.65145 .25 L
.65146 .25 L
.65146 .25 L
.65146 .25 L
Mistroke
.65147 .25 L
.65148 .25 L
.65148 .25 L
.65149 .25 L
.6515 .25 L
.6515 .25 L
.65151 .25 L
.65152 .25 L
.65152 .25 L
.65153 .25 L
.65153 .25 L
.65154 .25 L
.65155 .25 L
.65155 .25 L
.65156 .25 L
.65157 .25 L
.65157 .25 L
.65158 .25 L
.65158 .25 L
.65159 .25 L
.65159 .25 L
.6516 .25 L
.65161 .25 L
.65161 .25 L
.65162 .25 L
.65162 .25 L
.65163 .25 L
.65164 .25 L
.65164 .25 L
.65165 .25 L
.65165 .25 L
.65166 .25 L
.65166 .25 L
.65167 .25 L
.65167 .25 L
.65168 .25 L
.65169 .25 L
.65169 .25 L
.6517 .25 L
.65171 .25 L
.65171 .25 L
.65172 .25 L
.65172 .25 L
.65173 .25 L
.65174 .25 L
.65174 .25 L
.65175 .25 L
.65176 .25 L
.65176 .25 L
.65177 .25 L
Mistroke
.65177 .25 L
.65178 .25 L
.65178 .25 L
.65179 .25 L
.6518 .25 L
.6518 .25 L
.65181 .25 L
.65181 .25 L
.65182 .25 L
.65183 .25 L
.65183 .25 L
.65184 .25 L
.65184 .25 L
.65185 .25 L
.65186 .25 L
.65186 .25 L
.65187 .25 L
.65187 .25 L
.65188 .25 L
.65188 .25 L
.65189 .25 L
.65189 .25 L
.6519 .25 L
.6519 .25 L
.65191 .25 L
.65192 .25 L
.65192 .25 L
.65193 .25 L
.65193 .25 L
.65194 .25 L
.65194 .25 L
.65195 .25 L
.65195 .25 L
.65196 .25 L
.65196 .25 L
.65197 .25 L
.65197 .25 L
.65198 .25 L
.65199 .25 L
.65199 .25 L
.652 .25 L
.65201 .25 L
.65201 .25 L
.65202 .25 L
.65202 .25 L
.65203 .25 L
.65204 .25 L
.65204 .25 L
.65205 .25 L
.65205 .25 L
Mistroke
.65206 .25 L
.65207 .25 L
.65207 .25 L
.65208 .25 L
.65209 .25 L
.65209 .25 L
.6521 .25 L
.6521 .25 L
.65211 .25 L
.65211 .25 L
.65211 .25 L
.65212 .25 L
.65213 .25 L
.65213 .25 L
.65214 .25 L
.65215 .25 L
.65215 .25 L
.65216 .25 L
.65216 .25 L
.65217 .25 L
.65218 .25 L
.65218 .25 L
.65219 .25 L
.6522 .25 L
.6522 .25 L
.65221 .25 L
.65222 .25 L
.65222 .25 L
.65223 .25 L
.65223 .25 L
.65224 .25 L
.65224 .25 L
.65224 .25 L
.65225 .25 L
.65225 .25 L
.65226 .25 L
.65226 .25 L
.65227 .25 L
.65227 .25 L
.65227 .25 L
.65228 .25 L
.65228 .25 L
.65229 .25 L
.65229 .25 L
.65229 .25 L
.6523 .25 L
.65231 .25 L
.65232 .25 L
.65232 .25 L
.65233 .25 L
Mistroke
.65233 .25 L
.65234 .25 L
.65235 .25 L
.65235 .25 L
.65236 .25 L
.65237 .25 L
.65237 .25 L
.65238 .25 L
.65239 .25 L
.65239 .25 L
.65239 .25 L
.6524 .25 L
.65241 .25 L
.65241 .25 L
.65242 .25 L
.65242 .25 L
.65243 .25 L
.65244 .25 L
.65244 .25 L
.65245 .25 L
.65245 .25 L
.65246 .25 L
.65247 .25 L
.65247 .25 L
.65248 .25 L
.65248 .25 L
.65249 .25 L
.65249 .25 L
.6525 .25 L
.6525 .25 L
.65251 .25 L
.65252 .25 L
.65252 .25 L
.65253 .25 L
.65254 .25 L
.65254 .25 L
.65255 .25 L
.65255 .25 L
.65256 .25 L
.65257 .25 L
.65257 .25 L
.65258 .25 L
.65259 .25 L
.65259 .25 L
.6526 .25 L
.6526 .25 L
.65261 .25 L
.65261 .25 L
.65262 .25 L
.65263 .25 L
Mistroke
.65263 .25 L
.65264 .25 L
.65264 .25 L
.65265 .25 L
.65266 .25 L
.65266 .25 L
.65267 .25 L
.65267 .25 L
.65268 .25 L
.65269 .25 L
.65269 .25 L
.65269 .25 L
.6527 .25 L
.65271 .25 L
.65271 .25 L
.65272 .25 L
.65272 .25 L
.65273 .25 L
.65273 .25 L
.65274 .25 L
.65274 .25 L
.65275 .25 L
.65276 .25 L
.65276 .25 L
.65277 .25 L
.65277 .25 L
.65278 .25 L
.65278 .25 L
.65279 .25 L
.65279 .25 L
.6528 .25 L
.65281 .25 L
.65281 .25 L
.65282 .25 L
.65282 .25 L
.65283 .25 L
.65283 .25 L
.65284 .25 L
.65285 .25 L
.65285 .25 L
.65286 .25 L
.65287 .25 L
.65287 .25 L
.65288 .25 L
.65288 .25 L
.65289 .25 L
.6529 .25 L
.6529 .25 L
.65291 .25 L
.65292 .25 L
Mistroke
.65292 .25 L
.65293 .25 L
.65293 .25 L
.65293 .25 L
.65294 .25 L
.65294 .25 L
.65295 .25 L
.65296 .25 L
.65296 .25 L
.65297 .25 L
.65298 .25 L
.65298 .25 L
.65299 .25 L
.65299 .25 L
.653 .25 L
.65301 .25 L
.65301 .25 L
.65302 .25 L
.65303 .25 L
.65303 .25 L
.65304 .25 L
.65305 .25 L
.65305 .25 L
.65305 .25 L
.65306 .25 L
.65306 .25 L
.65307 .25 L
.65307 .25 L
.65308 .25 L
.65308 .25 L
.65309 .25 L
.65309 .25 L
.65309 .25 L
.6531 .25 L
.6531 .25 L
.65311 .25 L
.65311 .25 L
.65311 .25 L
.65312 .25 L
.65313 .25 L
.65313 .25 L
.65314 .25 L
.65315 .25 L
.65315 .25 L
.65316 .25 L
.65316 .25 L
.65317 .25 L
.65318 .25 L
.65318 .25 L
.65319 .25 L
Mistroke
.6532 .25 L
.6532 .25 L
.65321 .25 L
.65321 .25 L
.65322 .25 L
.65322 .25 L
.65323 .25 L
.65324 .25 L
.65324 .25 L
.65325 .25 L
.65325 .25 L
.65326 .25 L
.65326 .25 L
.65327 .25 L
.65328 .25 L
.65328 .25 L
.65329 .25 L
.6533 .25 L
.6533 .25 L
.65331 .25 L
.65331 .25 L
.65331 .25 L
.65332 .25 L
.65333 .25 L
.65333 .25 L
.65334 .25 L
.65335 .25 L
.65335 .25 L
.65336 .25 L
.65337 .25 L
.65337 .25 L
.65338 .25 L
.65338 .25 L
.65339 .25 L
.6534 .25 L
.6534 .25 L
.65341 .25 L
.65341 .25 L
.65342 .25 L
.65343 .25 L
.65343 .25 L
.65344 .25 L
.65344 .25 L
.65345 .25 L
.65346 .25 L
.65346 .25 L
.65347 .25 L
.65347 .25 L
.65348 .25 L
.65349 .25 L
Mistroke
.65349 .25 L
.6535 .25 L
.6535 .25 L
.65351 .25 L
.65351 .25 L
.65352 .25 L
.65352 .25 L
.65353 .25 L
.65354 .25 L
.65354 .25 L
.65354 .25 L
.65355 .25 L
.65356 .25 L
.65356 .25 L
.65357 .25 L
.65357 .25 L
.65358 .25 L
.65359 .25 L
.65359 .25 L
.65359 .25 L
.6536 .25 L
.65361 .25 L
.65361 .25 L
.65362 .25 L
.65362 .25 L
.65363 .25 L
.65363 .25 L
.65364 .25 L
.65365 .25 L
.65365 .25 L
.65366 .25 L
.65366 .25 L
.65367 .25 L
.65368 .25 L
.65368 .25 L
.65369 .25 L
.6537 .25 L
.6537 .25 L
.65371 .25 L
.65371 .25 L
.65372 .25 L
.65373 .25 L
.65373 .25 L
.65374 .25 L
.65375 .25 L
.65375 .25 L
.65375 .25 L
.65376 .25 L
.65376 .25 L
.65377 .25 L
Mistroke
.65377 .25 L
.65378 .25 L
.65379 .25 L
.65379 .25 L
.6538 .25 L
.65381 .25 L
.65381 .25 L
.65382 .25 L
.65382 .25 L
.65383 .25 L
.65384 .25 L
.65384 .25 L
.65385 .25 L
.65386 .25 L
.65386 .25 L
.65387 .25 L
.65387 .25 L
.65388 .25 L
.65388 .25 L
.65389 .25 L
.65389 .25 L
.65389 .25 L
.6539 .25 L
.65391 .25 L
.65391 .25 L
.65391 .25 L
.65392 .25 L
.65392 .25 L
.65392 .25 L
.65393 .25 L
.65393 .25 L
.65394 .25 L
.65394 .25 L
.65395 .25 L
.65396 .25 L
.65396 .25 L
.65397 .25 L
.65398 .25 L
.65398 .25 L
.65399 .25 L
.65399 .25 L
.654 .25 L
.65401 .25 L
.65401 .25 L
.65402 .25 L
.65403 .25 L
.65403 .25 L
.65404 .25 L
.65404 .25 L
.65405 .25 L
Mistroke
.65405 .25 L
.65406 .25 L
.65406 .25 L
.65407 .25 L
.65408 .25 L
.65408 .25 L
.65409 .25 L
.65409 .25 L
.6541 .25 L
.65411 .25 L
.65411 .25 L
.65412 .25 L
.65412 .25 L
.65413 .25 L
.65413 .25 L
.65414 .25 L
.65414 .25 L
.65415 .25 L
.65416 .25 L
.65416 .25 L
.65417 .25 L
.65418 .25 L
.65418 .25 L
.65419 .25 L
.6542 .25 L
.6542 .25 L
.65421 .25 L
.65421 .25 L
.65422 .25 L
.65423 .25 L
.65423 .25 L
.65424 .25 L
.65424 .25 L
.65425 .25 L
.65426 .25 L
.65426 .25 L
.65427 .25 L
.65427 .25 L
.65428 .25 L
.65429 .25 L
.65429 .25 L
.6543 .25 L
.6543 .25 L
.65431 .25 L
.65431 .25 L
.65432 .25 L
.65433 .25 L
.65433 .25 L
.65434 .25 L
.65434 .25 L
Mistroke
.65435 .25 L
.65435 .25 L
.65436 .25 L
.65437 .25 L
.65437 .25 L
.65438 .25 L
.65439 .25 L
.65439 .25 L
.6544 .25 L
.6544 .25 L
.65441 .25 L
.65442 .25 L
.65442 .25 L
.65443 .25 L
.65444 .25 L
.65444 .25 L
.65444 .25 L
.65445 .25 L
.65446 .25 L
.65446 .25 L
.65447 .25 L
.65448 .25 L
.65448 .25 L
.65449 .25 L
.65449 .25 L
.6545 .25 L
.6545 .25 L
.65451 .25 L
.65452 .25 L
.65452 .25 L
.65453 .25 L
.65454 .25 L
.65454 .25 L
.65454 .25 L
.65455 .25 L
.65456 .25 L
.65456 .25 L
.65457 .25 L
.65457 .25 L
.65458 .25 L
.65458 .25 L
.65459 .25 L
.65459 .25 L
.6546 .25 L
.65461 .25 L
.65461 .25 L
.65462 .25 L
.65462 .25 L
.65463 .25 L
.65463 .25 L
Mistroke
.65463 .25 L
.65464 .25 L
.65465 .25 L
.65465 .25 L
.65466 .25 L
.65467 .25 L
.65467 .25 L
.65468 .25 L
.65468 .25 L
.65469 .25 L
.6547 .25 L
.6547 .25 L
.65471 .25 L
.65472 .25 L
.65472 .25 L
.65473 .25 L
.65473 .25 L
.65474 .25 L
.65475 .25 L
.65475 .25 L
.65476 .25 L
.65477 .25 L
.65477 .25 L
.65478 .25 L
.65478 .25 L
.65478 .25 L
.65479 .25 L
.65479 .25 L
.6548 .25 L
.65481 .25 L
.65481 .25 L
.65482 .25 L
.65483 .25 L
.65483 .25 L
.65484 .25 L
.65484 .25 L
.65485 .25 L
.65486 .25 L
.65486 .25 L
.65487 .25 L
.65488 .25 L
.65488 .25 L
.65489 .25 L
.6549 .25 L
.6549 .25 L
.6549 .25 L
.65491 .25 L
.65491 .25 L
.65492 .25 L
.65492 .25 L
Mistroke
.65493 .25 L
.65493 .25 L
.65494 .25 L
.65494 .25 L
.65494 .25 L
.65495 .25 L
.65495 .25 L
.65495 .25 L
.65496 .25 L
.65496 .25 L
.65497 .25 L
.65498 .25 L
.65498 .25 L
.65499 .25 L
.655 .25 L
.655 .25 L
.65501 .25 L
.65501 .25 L
.65502 .25 L
.65503 .25 L
.65503 .25 L
.65504 .25 L
.65504 .25 L
.65505 .25 L
.65506 .25 L
.65506 .25 L
.65507 .25 L
.65507 .25 L
.65508 .25 L
.65509 .25 L
.65509 .25 L
.6551 .25 L
.6551 .25 L
.65511 .25 L
.65511 .25 L
.65512 .25 L
.65513 .25 L
.65513 .25 L
.65514 .25 L
.65515 .25 L
.65515 .25 L
.65516 .25 L
.65516 .25 L
.65516 .25 L
.65517 .25 L
.65518 .25 L
.65518 .25 L
.65519 .25 L
.6552 .25 L
.6552 .25 L
Mistroke
.65521 .25 L
.65522 .25 L
.65522 .25 L
.65523 .25 L
.65523 .25 L
.65524 .25 L
.65525 .25 L
.65525 .25 L
.65526 .25 L
.65526 .25 L
.65527 .25 L
.65528 .25 L
.65528 .25 L
.65529 .25 L
.65529 .25 L
.6553 .25 L
.65531 .25 L
.65531 .25 L
.65532 .25 L
.65532 .25 L
.65533 .25 L
.65534 .25 L
.65534 .25 L
.65535 .25 L
.65535 .25 L
.65536 .25 L
.65536 .25 L
.65537 .25 L
.65537 .25 L
.65538 .25 L
.65539 .25 L
.65539 .25 L
.65539 .25 L
.6554 .25 L
.65541 .25 L
.65541 .25 L
.65542 .25 L
.65542 .25 L
.65543 .25 L
.65544 .25 L
.65544 .25 L
.65544 .25 L
.65545 .25 L
.65546 .25 L
.65546 .25 L
.65547 .25 L
.65547 .25 L
.65548 .25 L
.65548 .25 L
.65549 .25 L
Mistroke
.6555 .25 L
.6555 .25 L
.65551 .25 L
.65551 .25 L
.65552 .25 L
.65553 .25 L
.65553 .25 L
.65554 .25 L
.65555 .25 L
.65555 .25 L
.65556 .25 L
.65556 .25 L
.65557 .25 L
.65558 .25 L
.65558 .25 L
.65559 .25 L
.6556 .25 L
.6556 .25 L
.6556 .25 L
.65561 .25 L
.65561 .25 L
.65562 .25 L
.65562 .25 L
.65563 .25 L
.65564 .25 L
.65564 .25 L
.65565 .25 L
.65566 .25 L
.65566 .25 L
.65567 .25 L
.65567 .25 L
.65568 .25 L
.65569 .25 L
.65569 .25 L
.6557 .25 L
.65571 .25 L
.65571 .25 L
.65572 .25 L
.65572 .25 L
.65573 .25 L
.65573 .25 L
.65574 .25 L
.65574 .25 L
.65575 .25 L
.65575 .25 L
.65576 .25 L
.65576 .25 L
.65576 .25 L
.65577 .25 L
.65577 .25 L
Mistroke
.65577 .25 L
.65578 .25 L
.65578 .25 L
.65579 .25 L
.65579 .25 L
.6558 .25 L
.65581 .25 L
.65581 .25 L
.65582 .25 L
.65583 .25 L
.65583 .25 L
.65584 .25 L
.65584 .25 L
.65585 .25 L
.65586 .25 L
.65586 .25 L
.65587 .25 L
.65588 .25 L
.65588 .25 L
.65589 .25 L
.65589 .25 L
.6559 .25 L
.6559 .25 L
.65591 .25 L
.65592 .25 L
.65592 .25 L
.65593 .25 L
.65593 .25 L
.65594 .25 L
.65594 .25 L
.65595 .25 L
.65596 .25 L
.65596 .25 L
.65597 .25 L
.65597 .25 L
.65598 .25 L
.65598 .25 L
.65599 .25 L
.65599 .25 L
.656 .25 L
.65601 .25 L
.65601 .25 L
.65602 .25 L
.65603 .25 L
.65603 .25 L
.65604 .25 L
.65605 .25 L
.65605 .25 L
.65606 .25 L
.65607 .25 L
Mistroke
.65607 .25 L
.65608 .25 L
.65608 .25 L
.65609 .25 L
.65609 .25 L
.6561 .25 L
.65611 .25 L
.65611 .25 L
.65612 .25 L
.65612 .25 L
.65613 .25 L
.65614 .25 L
.65614 .25 L
.65615 .25 L
.65615 .25 L
.65616 .25 L
.65617 .25 L
.65617 .25 L
.65618 .25 L
.65618 .25 L
.65619 .25 L
.65619 .25 L
.6562 .25 L
.6562 .25 L
.65621 .25 L
.65621 .25 L
.65622 .25 L
.65622 .25 L
.65623 .25 L
.65624 .25 L
.65624 .25 L
.65625 .25 L
.65625 .25 L
.65626 .25 L
.65626 .25 L
.65627 .25 L
.65628 .25 L
.65628 .25 L
.65628 .25 L
.65629 .25 L
.6563 .25 L
.6563 .25 L
.65631 .25 L
.65631 .25 L
.65632 .25 L
.65633 .25 L
.65633 .25 L
.65634 .25 L
.65634 .25 L
.65635 .25 L
Mistroke
.65636 .25 L
.65636 .25 L
.65637 .25 L
.65637 .25 L
.65638 .25 L
.65639 .25 L
.65639 .25 L
.6564 .25 L
.65641 .25 L
.65641 .25 L
.65642 .25 L
.65642 .25 L
.65643 .25 L
.65643 .25 L
.65643 .25 L
.65644 .25 L
.65645 .25 L
.65645 .25 L
.65646 .25 L
.65647 .25 L
.65647 .25 L
.65648 .25 L
.65648 .25 L
.65649 .25 L
.6565 .25 L
.6565 .25 L
.65651 .25 L
.65652 .25 L
.65652 .25 L
.65653 .25 L
.65654 .25 L
.65654 .25 L
.65655 .25 L
.65655 .25 L
.65656 .25 L
.65656 .25 L
.65657 .25 L
.65657 .25 L
.65657 .25 L
.65658 .25 L
.65658 .25 L
.65659 .25 L
.65659 .25 L
.65659 .25 L
.6566 .25 L
.6566 .25 L
.65661 .25 L
.65661 .25 L
.65662 .25 L
.65662 .25 L
Mistroke
.65663 .25 L
.65664 .25 L
.65664 .25 L
.65665 .25 L
.65666 .25 L
.65666 .25 L
.65667 .25 L
.65667 .25 L
.65668 .25 L
.65669 .25 L
.65669 .25 L
.6567 .25 L
.65671 .25 L
.65671 .25 L
.65671 .25 L
.65672 .25 L
.65673 .25 L
.65673 .25 L
.65674 .25 L
.65675 .25 L
.65675 .25 L
.65676 .25 L
.65676 .25 L
.65677 .25 L
.65677 .25 L
.65678 .25 L
.65679 .25 L
.65679 .25 L
.6568 .25 L
.6568 .25 L
.65681 .25 L
.65681 .25 L
.65682 .25 L
.65682 .25 L
.65683 .25 L
.65684 .25 L
.65685 .25 L
.65685 .25 L
.65686 .25 L
.65686 .25 L
.65687 .25 L
.65688 .25 L
.65688 .25 L
.65689 .25 L
.65689 .25 L
.6569 .25 L
.65691 .25 L
.65691 .25 L
.65692 .25 L
.65692 .25 L
Mistroke
.65693 .25 L
.65694 .25 L
.65694 .25 L
.65695 .25 L
.65695 .25 L
.65696 .25 L
.65696 .25 L
.65697 .25 L
.65698 .25 L
.65698 .25 L
.65699 .25 L
.657 .25 L
.657 .25 L
.65701 .25 L
.65701 .25 L
.65701 .25 L
.65702 .25 L
.65703 .25 L
.65703 .25 L
.65704 .25 L
.65704 .25 L
.65705 .25 L
.65705 .25 L
.65706 .25 L
.65707 .25 L
.65707 .25 L
.65708 .25 L
.65708 .25 L
.65709 .25 L
.65709 .25 L
.6571 .25 L
.6571 .25 L
.65711 .25 L
.65711 .25 L
.65712 .25 L
.65713 .25 L
.65713 .25 L
.65714 .25 L
.65714 .25 L
.65715 .25 L
.65715 .25 L
.65716 .25 L
.65717 .25 L
.65717 .25 L
.65718 .25 L
.65719 .25 L
.65719 .25 L
.6572 .25 L
.6572 .25 L
.65721 .25 L
Mistroke
.65722 .25 L
.65722 .25 L
.65723 .25 L
.65724 .25 L
.65724 .25 L
.65725 .25 L
.65725 .25 L
.65725 .25 L
.65726 .25 L
.65726 .25 L
.65727 .25 L
.65728 .25 L
.65728 .25 L
.65729 .25 L
.6573 .25 L
.6573 .25 L
.65731 .25 L
.65731 .25 L
.65732 .25 L
.65733 .25 L
.65733 .25 L
.65734 .25 L
.65735 .25 L
.65735 .25 L
.65736 .25 L
.65737 .25 L
.65737 .25 L
.65737 .25 L
.65738 .25 L
.65739 .25 L
.65739 .25 L
.65739 .25 L
.6574 .25 L
.6574 .25 L
.65741 .25 L
.65741 .25 L
.65741 .25 L
.65742 .25 L
.65742 .25 L
.65743 .25 L
.65743 .25 L
.65743 .25 L
.65744 .25 L
.65745 .25 L
.65745 .25 L
.65746 .25 L
.65747 .25 L
.65747 .25 L
.65748 .25 L
.65748 .25 L
Mistroke
.65749 .25 L
.6575 .25 L
.6575 .25 L
.65751 .25 L
.65752 .25 L
.65752 .25 L
.65753 .25 L
.65753 .25 L
.65754 .25 L
.65754 .25 L
.65755 .25 L
.65756 .25 L
.65756 .25 L
.65757 .25 L
.65757 .25 L
.65758 .25 L
.65759 .25 L
.65759 .25 L
.6576 .25 L
.6576 .25 L
.65761 .25 L
.65762 .25 L
.65762 .25 L
.65763 .25 L
.65763 .25 L
.65764 .25 L
.65764 .25 L
.65765 .25 L
.65765 .25 L
.65766 .25 L
.65767 .25 L
.65767 .25 L
.65768 .25 L
.65769 .25 L
.65769 .25 L
.6577 .25 L
.65771 .25 L
.65771 .25 L
.65772 .25 L
.65772 .25 L
.65773 .25 L
.65774 .25 L
.65774 .25 L
.65775 .25 L
.65775 .25 L
.65776 .25 L
.65776 .25 L
.65777 .25 L
.65778 .25 L
.65778 .25 L
Mistroke
.65779 .25 L
.65779 .25 L
.6578 .25 L
.65781 .25 L
.65781 .25 L
.65782 .25 L
.65782 .25 L
.65783 .25 L
.65783 .25 L
.65784 .25 L
.65784 .25 L
.65785 .25 L
.65786 .25 L
.65786 .25 L
.65787 .25 L
.65788 .25 L
.65788 .25 L
.65789 .25 L
.6579 .25 L
.6579 .25 L
.65791 .25 L
.65791 .25 L
.65792 .25 L
.65793 .25 L
.65793 .25 L
.65794 .25 L
.65794 .25 L
.65795 .25 L
.65796 .25 L
.65796 .25 L
.65797 .25 L
.65797 .25 L
.65798 .25 L
.65799 .25 L
.65799 .25 L
.658 .25 L
.658 .25 L
.65801 .25 L
.65802 .25 L
.65802 .25 L
.65803 .25 L
.65803 .25 L
.65804 .25 L
.65804 .25 L
.65805 .25 L
.65805 .25 L
.65806 .25 L
.65806 .25 L
.65807 .25 L
.65807 .25 L
Mistroke
.65808 .25 L
.65809 .25 L
.65809 .25 L
.6581 .25 L
.6581 .25 L
.65811 .25 L
.65811 .25 L
.65812 .25 L
.65812 .25 L
.65813 .25 L
.65813 .25 L
.65814 .25 L
.65815 .25 L
.65815 .25 L
.65816 .25 L
.65816 .25 L
.65817 .25 L
.65818 .25 L
.65818 .25 L
.65819 .25 L
.65819 .25 L
.6582 .25 L
.65821 .25 L
.65821 .25 L
.65822 .25 L
.65822 .25 L
.65823 .25 L
.65824 .25 L
.65824 .25 L
.65825 .25 L
.65826 .25 L
.65826 .25 L
.65827 .25 L
.65827 .25 L
.65828 .25 L
.65828 .25 L
.65828 .25 L
.65829 .25 L
.6583 .25 L
.6583 .25 L
.65831 .25 L
.65832 .25 L
.65832 .25 L
.65833 .25 L
.65833 .25 L
.65834 .25 L
.65835 .25 L
.65835 .25 L
.65836 .25 L
.65837 .25 L
Mistroke
.65837 .25 L
.65838 .25 L
.65839 .25 L
.65839 .25 L
.6584 .25 L
.6584 .25 L
.65841 .25 L
.65841 .25 L
.65842 .25 L
.65842 .25 L
.65842 .25 L
.65843 .25 L
.65843 .25 L
.65844 .25 L
.65844 .25 L
.65844 .25 L
.65845 .25 L
.65845 .25 L
.65846 .25 L
.65846 .25 L
.65847 .25 L
.65847 .25 L
.65848 .25 L
.65849 .25 L
.65849 .25 L
.6585 .25 L
.65851 .25 L
.65851 .25 L
.65852 .25 L
.65852 .25 L
.65853 .25 L
.65854 .25 L
.65854 .25 L
.65855 .25 L
.65856 .25 L
.65856 .25 L
.65856 .25 L
.65857 .25 L
.65858 .25 L
.65858 .25 L
.65859 .25 L
.6586 .25 L
.6586 .25 L
.65861 .25 L
.65861 .25 L
.65862 .25 L
.65862 .25 L
.65863 .25 L
.65864 .25 L
.65864 .25 L
Mistroke
.65865 .25 L
.65865 .25 L
.65866 .25 L
.65866 .25 L
.65867 .25 L
.65867 .25 L
.65868 .25 L
.65868 .25 L
.65869 .25 L
.6587 .25 L
.6587 .25 L
.6587 .25 L
.65871 .25 L
.65872 .25 L
.65872 .25 L
.65872 .25 L
.65873 .25 L
Mfstroke
.65873 .25 m
.65874 .25 L
.65874 .25 L
.65875 .25 L
.65876 .25 L
.65876 .25 L
.65877 .25 L
.65877 .25 L
.65878 .25 L
.65878 .25 L
.65879 .25 L
.6588 .25 L
.6588 .25 L
.65881 .25 L
.65881 .25 L
.65882 .25 L
.65882 .25 L
.65883 .25 L
.65883 .25 L
.65884 .25 L
.65884 .25 L
.65885 .25 L
.65885 .25 L
.65886 .25 L
.65886 .25 L
.65886 .25 L
.65887 .25 L
.65887 .25 L
.65888 .25 L
.65889 .25 L
.65889 .25 L
.6589 .25 L
.6589 .25 L
.65891 .25 L
.65892 .25 L
.65892 .25 L
.65893 .25 L
.65894 .25 L
.65894 .25 L
.65894 .25 L
.65895 .25 L
.65895 .25 L
.65896 .25 L
.65896 .25 L
.65897 .25 L
.65897 .25 L
.65898 .25 L
.65898 .25 L
.65899 .25 L
.65899 .25 L
Mistroke
.659 .25 L
.659 .25 L
.659 .25 L
.65901 .25 L
.65901 .25 L
.65902 .25 L
.65902 .25 L
.65902 .25 L
.65903 .25 L
.65903 .25 L
.65904 .25 L
.65904 .25 L
.65905 .25 L
.65905 .25 L
.65905 .25 L
.65906 .25 L
.65907 .25 L
.65907 .25 L
.65908 .25 L
.65908 .25 L
.65909 .25 L
.6591 .25 L
.6591 .25 L
.65911 .25 L
.65911 .25 L
.65911 .25 L
.65912 .25 L
.65912 .25 L
.65913 .25 L
.65913 .25 L
.65914 .25 L
.65914 .25 L
.65915 .25 L
.65916 .25 L
.65916 .25 L
.65917 .25 L
.65917 .25 L
.65918 .25 L
.65919 .25 L
.65919 .25 L
.6592 .25 L
.6592 .25 L
.65921 .25 L
.65921 .25 L
.65922 .25 L
.65922 .25 L
.65922 .25 L
.65923 .25 L
.65923 .25 L
.65924 .25 L
Mistroke
.65924 .25 L
.65925 .25 L
.65925 .25 L
.65926 .25 L
.65927 .25 L
.65927 .25 L
.65928 .25 L
.65929 .25 L
.65929 .25 L
.6593 .25 L
.6593 .25 L
.65931 .25 L
.65932 .25 L
.65932 .25 L
.65933 .25 L
.65933 .25 L
.65934 .25 L
.65935 .25 L
.65935 .25 L
.65935 .25 L
.65936 .25 L
.65937 .25 L
.65937 .25 L
.65938 .25 L
.65939 .25 L
.65939 .25 L
.6594 .25 L
.6594 .25 L
.65941 .25 L
.65942 .25 L
.65942 .25 L
.65943 .25 L
.65944 .25 L
.65944 .25 L
.65945 .25 L
.65945 .25 L
.65946 .25 L
.65946 .25 L
.65947 .25 L
.65948 .25 L
.65948 .25 L
.65949 .25 L
.6595 .25 L
.6595 .25 L
.65951 .25 L
.65951 .25 L
.65952 .25 L
.65952 .25 L
.65953 .25 L
.65954 .25 L
Mistroke
.65954 .25 L
.65955 .25 L
.65955 .25 L
.65956 .25 L
.65956 .25 L
.65957 .25 L
.65957 .25 L
.65958 .25 L
.65959 .25 L
.65959 .25 L
.6596 .25 L
.65961 .25 L
.65961 .25 L
.65962 .25 L
.65963 .25 L
.65963 .25 L
.65964 .25 L
.65964 .25 L
.65965 .25 L
.65966 .25 L
.65966 .25 L
.65967 .25 L
.65967 .25 L
.65968 .25 L
.65968 .25 L
.65969 .25 L
.6597 .25 L
.6597 .25 L
.65971 .25 L
.65971 .25 L
.65972 .25 L
.65973 .25 L
.65973 .25 L
.65974 .25 L
.65974 .25 L
.65975 .25 L
.65975 .25 L
.65976 .25 L
.65976 .25 L
.65977 .25 L
.65978 .25 L
.65978 .25 L
.65979 .25 L
.6598 .25 L
.6598 .25 L
.65981 .25 L
.65981 .25 L
.65982 .25 L
.65983 .25 L
.65983 .25 L
Mistroke
.65984 .25 L
.65985 .25 L
.65985 .25 L
.65986 .25 L
.65986 .25 L
.65987 .25 L
.65988 .25 L
.65988 .25 L
.65989 .25 L
.65989 .25 L
.6599 .25 L
.65991 .25 L
.65991 .25 L
.65992 .25 L
.65992 .25 L
.65993 .25 L
.65993 .25 L
.65994 .25 L
.65995 .25 L
.65995 .25 L
.65996 .25 L
.65996 .25 L
.65997 .25 L
.65997 .25 L
.65998 .25 L
.65999 .25 L
.65999 .25 L
.66 .25 L
.66 .25 L
.66001 .25 L
.66002 .25 L
.66002 .25 L
.66003 .25 L
.66004 .25 L
.66004 .25 L
.66005 .25 L
.66006 .25 L
.66006 .25 L
.66006 .25 L
.66007 .25 L
.66008 .25 L
.66008 .25 L
.66009 .25 L
.6601 .25 L
.6601 .25 L
.66011 .25 L
.66011 .25 L
.66012 .25 L
.66012 .25 L
.66013 .25 L
Mistroke
.66014 .25 L
.66014 .25 L
.66015 .25 L
.66016 .25 L
.66016 .25 L
.66016 .25 L
.66017 .25 L
.66018 .25 L
.66018 .25 L
.66019 .25 L
.66019 .25 L
.6602 .25 L
.6602 .25 L
.66021 .25 L
.66021 .25 L
.66022 .25 L
.66023 .25 L
.66023 .25 L
.66024 .25 L
.66024 .25 L
.66025 .25 L
.66025 .25 L
.66025 .25 L
.66026 .25 L
.66027 .25 L
.66027 .25 L
.66028 .25 L
.66029 .25 L
.66029 .25 L
.6603 .25 L
.6603 .25 L
.66031 .25 L
.66032 .25 L
.66032 .25 L
.66033 .25 L
.66033 .25 L
.66034 .25 L
.66035 .25 L
.66035 .25 L
.66036 .25 L
.66037 .25 L
.66037 .25 L
.66038 .25 L
.66039 .25 L
.66039 .25 L
.6604 .25 L
.6604 .25 L
.6604 .25 L
.66041 .25 L
.66041 .25 L
Mistroke
.66042 .25 L
.66043 .25 L
.66043 .25 L
.66044 .25 L
.66045 .25 L
.66045 .25 L
.66046 .25 L
.66046 .25 L
.66047 .25 L
.66048 .25 L
.66048 .25 L
.66049 .25 L
.6605 .25 L
.6605 .25 L
.66051 .25 L
.66052 .25 L
.66052 .25 L
.66052 .25 L
.66053 .25 L
.66053 .25 L
.66054 .25 L
.66054 .25 L
.66054 .25 L
.66055 .25 L
.66056 .25 L
.66056 .25 L
.66056 .25 L
.66057 .25 L
.66057 .25 L
.66057 .25 L
.66058 .25 L
.66058 .25 L
.66059 .25 L
.66059 .25 L
.6606 .25 L
.66061 .25 L
.66062 .25 L
.66062 .25 L
.66063 .25 L
.66063 .25 L
.66064 .25 L
.66065 .25 L
.66065 .25 L
.66066 .25 L
.66066 .25 L
.66067 .25 L
.66068 .25 L
.66068 .25 L
.66069 .25 L
.66069 .25 L
Mistroke
.6607 .25 L
.66071 .25 L
.66071 .25 L
.66072 .25 L
.66072 .25 L
.66073 .25 L
.66073 .25 L
.66074 .25 L
.66075 .25 L
.66075 .25 L
.66076 .25 L
.66077 .25 L
.66077 .25 L
.66078 .25 L
.66078 .25 L
.66078 .25 L
.66079 .25 L
.6608 .25 L
.6608 .25 L
.66081 .25 L
.66082 .25 L
.66082 .25 L
.66083 .25 L
.66084 .25 L
.66084 .25 L
.66085 .25 L
.66085 .25 L
.66086 .25 L
.66087 .25 L
.66087 .25 L
.66088 .25 L
.66088 .25 L
.66089 .25 L
.6609 .25 L
.6609 .25 L
.66091 .25 L
.66091 .25 L
.66092 .25 L
.66093 .25 L
.66093 .25 L
.66094 .25 L
.66094 .25 L
.66095 .25 L
.66096 .25 L
.66096 .25 L
.66097 .25 L
.66097 .25 L
.66098 .25 L
.66098 .25 L
.66099 .25 L
Mistroke
.66099 .25 L
.661 .25 L
.66101 .25 L
.66101 .25 L
.66101 .25 L
.66102 .25 L
.66103 .25 L
.66103 .25 L
.66104 .25 L
.66104 .25 L
.66105 .25 L
.66106 .25 L
.66106 .25 L
.66106 .25 L
.66107 .25 L
.66108 .25 L
.66108 .25 L
.66109 .25 L
.66109 .25 L
.6611 .25 L
.6611 .25 L
.66111 .25 L
.66112 .25 L
.66112 .25 L
.66113 .25 L
.66113 .25 L
.66114 .25 L
.66115 .25 L
.66115 .25 L
.66116 .25 L
.66117 .25 L
.66117 .25 L
.66118 .25 L
.66118 .25 L
.66119 .25 L
.6612 .25 L
.6612 .25 L
.66121 .25 L
.66122 .25 L
.66122 .25 L
.66122 .25 L
.66123 .25 L
.66123 .25 L
.66124 .25 L
.66124 .25 L
.66125 .25 L
.66126 .25 L
.66126 .25 L
.66127 .25 L
.66128 .25 L
Mistroke
.66128 .25 L
.66129 .25 L
.66129 .25 L
.6613 .25 L
.66131 .25 L
.66131 .25 L
.66132 .25 L
.66133 .25 L
.66133 .25 L
.66134 .25 L
.66134 .25 L
.66135 .25 L
.66135 .25 L
.66136 .25 L
.66136 .25 L
.66137 .25 L
.66137 .25 L
.66138 .25 L
.66138 .25 L
.66138 .25 L
.66139 .25 L
.66139 .25 L
.66139 .25 L
.6614 .25 L
.6614 .25 L
.66141 .25 L
.66141 .25 L
.66142 .25 L
.66143 .25 L
.66143 .25 L
.66144 .25 L
.66145 .25 L
.66145 .25 L
.66146 .25 L
.66146 .25 L
.66147 .25 L
.66148 .25 L
.66148 .25 L
.66149 .25 L
.6615 .25 L
.6615 .25 L
.66151 .25 L
.66151 .25 L
.66152 .25 L
.66152 .25 L
.66153 .25 L
.66154 .25 L
.66154 .25 L
.66155 .25 L
.66155 .25 L
Mistroke
.66156 .25 L
.66156 .25 L
.66157 .25 L
.66158 .25 L
.66158 .25 L
.66159 .25 L
.66159 .25 L
.6616 .25 L
.66161 .25 L
.66161 .25 L
.66161 .25 L
.66162 .25 L
.66163 .25 L
.66163 .25 L
.66164 .25 L
.66165 .25 L
.66165 .25 L
.66166 .25 L
.66167 .25 L
.66167 .25 L
.66168 .25 L
.66169 .25 L
.66169 .25 L
.6617 .25 L
.6617 .25 L
.66171 .25 L
.66171 .25 L
.66172 .25 L
.66173 .25 L
.66173 .25 L
.66174 .25 L
.66174 .25 L
.66175 .25 L
.66176 .25 L
.66176 .25 L
.66177 .25 L
.66177 .25 L
.66178 .25 L
.66179 .25 L
.66179 .25 L
.6618 .25 L
.6618 .25 L
.66181 .25 L
.66181 .25 L
.66182 .25 L
.66182 .25 L
.66183 .25 L
.66183 .25 L
.66184 .25 L
.66184 .25 L
Mistroke
.66185 .25 L
.66186 .25 L
.66186 .25 L
.66187 .25 L
.66187 .25 L
.66188 .25 L
.66188 .25 L
.66189 .25 L
.6619 .25 L
.6619 .25 L
.6619 .25 L
.66191 .25 L
.66192 .25 L
.66192 .25 L
.66193 .25 L
.66193 .25 L
.66194 .25 L
.66195 .25 L
.66195 .25 L
.66196 .25 L
.66196 .25 L
.66197 .25 L
.66198 .25 L
.66198 .25 L
.66199 .25 L
.66199 .25 L
.662 .25 L
.66201 .25 L
.66201 .25 L
.66202 .25 L
.66203 .25 L
.66203 .25 L
.66204 .25 L
.66204 .25 L
.66205 .25 L
.66205 .25 L
.66205 .25 L
.66206 .25 L
.66207 .25 L
.66207 .25 L
.66208 .25 L
.66209 .25 L
.66209 .25 L
.6621 .25 L
.66211 .25 L
.66211 .25 L
.66212 .25 L
.66213 .25 L
.66213 .25 L
.66214 .25 L
Mistroke
.66214 .25 L
.66215 .25 L
.66216 .25 L
.66216 .25 L
.66217 .25 L
.66217 .25 L
.66218 .25 L
.66218 .25 L
.66219 .25 L
.66219 .25 L
.66219 .25 L
.6622 .25 L
.6622 .25 L
.66221 .25 L
.66221 .25 L
.66222 .25 L
.66222 .25 L
.66222 .25 L
.66223 .25 L
.66223 .25 L
.66224 .25 L
.66224 .25 L
.66225 .25 L
.66226 .25 L
.66226 .25 L
.66227 .25 L
.66228 .25 L
.66228 .25 L
.66229 .25 L
.66229 .25 L
.6623 .25 L
.66231 .25 L
.66231 .25 L
.66232 .25 L
.66233 .25 L
.66233 .25 L
.66233 .25 L
.66234 .25 L
.66235 .25 L
.66235 .25 L
.66236 .25 L
.66237 .25 L
.66237 .25 L
.66238 .25 L
.66238 .25 L
.66239 .25 L
.66239 .25 L
.6624 .25 L
.66241 .25 L
.66241 .25 L
Mistroke
.66242 .25 L
.66243 .25 L
.66243 .25 L
.66243 .25 L
.66244 .25 L
.66245 .25 L
.66245 .25 L
.66246 .25 L
.66247 .25 L
.66247 .25 L
.66248 .25 L
.66248 .25 L
.66249 .25 L
.6625 .25 L
.6625 .25 L
.66251 .25 L
.66252 .25 L
.66252 .25 L
.66253 .25 L
.66253 .25 L
.66254 .25 L
.66254 .25 L
.66255 .25 L
.66256 .25 L
.66256 .25 L
.66257 .25 L
.66257 .25 L
.66258 .25 L
.66259 .25 L
.66259 .25 L
.6626 .25 L
.6626 .25 L
.66261 .25 L
.66262 .25 L
.66262 .25 L
.66263 .25 L
.66263 .25 L
.66263 .25 L
.66264 .25 L
.66265 .25 L
.66265 .25 L
.66266 .25 L
.66266 .25 L
.66267 .25 L
.66267 .25 L
.66268 .25 L
.66269 .25 L
.66269 .25 L
.6627 .25 L
.6627 .25 L
Mistroke
.66271 .25 L
.66271 .25 L
.66272 .25 L
.66272 .25 L
.66273 .25 L
.66273 .25 L
.66274 .25 L
.66275 .25 L
.66275 .25 L
.66276 .25 L
.66276 .25 L
.66277 .25 L
.66278 .25 L
.66278 .25 L
.66279 .25 L
.66279 .25 L
.6628 .25 L
.66281 .25 L
.66281 .25 L
.66282 .25 L
.66282 .25 L
.66283 .25 L
.66284 .25 L
.66284 .25 L
.66285 .25 L
.66286 .25 L
.66286 .25 L
.66287 .25 L
.66287 .25 L
.66287 .25 L
.66288 .25 L
.66289 .25 L
.66289 .25 L
.6629 .25 L
.66291 .25 L
.66291 .25 L
.66292 .25 L
.66292 .25 L
.66293 .25 L
.66294 .25 L
.66294 .25 L
.66295 .25 L
.66295 .25 L
.66296 .25 L
.66297 .25 L
.66297 .25 L
.66298 .25 L
.66299 .25 L
.66299 .25 L
.663 .25 L
Mistroke
.663 .25 L
.66301 .25 L
.66301 .25 L
.66301 .25 L
.66302 .25 L
.66302 .25 L
.66303 .25 L
.66303 .25 L
.66303 .25 L
.66304 .25 L
.66304 .25 L
.66305 .25 L
.66305 .25 L
.66305 .25 L
.66306 .25 L
.66307 .25 L
.66307 .25 L
.66308 .25 L
.66309 .25 L
.66309 .25 L
.6631 .25 L
.6631 .25 L
.66311 .25 L
.66312 .25 L
.66312 .25 L
.66313 .25 L
.66314 .25 L
.66314 .25 L
.66315 .25 L
.66315 .25 L
.66316 .25 L
.66316 .25 L
.66317 .25 L
.66318 .25 L
.66318 .25 L
.66319 .25 L
.6632 .25 L
.6632 .25 L
.66321 .25 L
.66321 .25 L
.66322 .25 L
.66322 .25 L
.66323 .25 L
.66324 .25 L
.66324 .25 L
.66325 .25 L
.66325 .25 L
.66326 .25 L
.66326 .25 L
.66327 .25 L
Mistroke
.66328 .25 L
.66328 .25 L
.66329 .25 L
.6633 .25 L
.6633 .25 L
.66331 .25 L
.66331 .25 L
.66332 .25 L
.66333 .25 L
.66333 .25 L
.66334 .25 L
.66335 .25 L
.66335 .25 L
.66336 .25 L
.66336 .25 L
.66337 .25 L
.66337 .25 L
.66338 .25 L
.66339 .25 L
.66339 .25 L
.6634 .25 L
.6634 .25 L
.66341 .25 L
.66341 .25 L
.66342 .25 L
.66343 .25 L
.66343 .25 L
.66344 .25 L
.66344 .25 L
.66345 .25 L
.66345 .25 L
.66346 .25 L
.66346 .25 L
.66347 .25 L
.66348 .25 L
.66348 .25 L
.66348 .25 L
.66349 .25 L
.6635 .25 L
.6635 .25 L
.66351 .25 L
.66352 .25 L
.66352 .25 L
.66353 .25 L
.66353 .25 L
.66354 .25 L
.66354 .25 L
.66355 .25 L
.66355 .25 L
.66356 .25 L
Mistroke
.66356 .25 L
.66357 .25 L
.66358 .25 L
.66358 .25 L
.66359 .25 L
.66359 .25 L
.6636 .25 L
.6636 .25 L
.66361 .25 L
.66362 .25 L
.66362 .25 L
.66363 .25 L
.66364 .25 L
.66364 .25 L
.66365 .25 L
.66365 .25 L
.66366 .25 L
.66367 .25 L
.66367 .25 L
.66368 .25 L
.66369 .25 L
.66369 .25 L
.66369 .25 L
.6637 .25 L
.6637 .25 L
.66371 .25 L
.66371 .25 L
.66372 .25 L
.66373 .25 L
.66373 .25 L
.66374 .25 L
.66375 .25 L
.66375 .25 L
.66376 .25 L
.66377 .25 L
.66377 .25 L
.66378 .25 L
.66378 .25 L
.66379 .25 L
.6638 .25 L
.6638 .25 L
.66381 .25 L
.66381 .25 L
.66382 .25 L
.66383 .25 L
.66383 .25 L
.66383 .25 L
.66384 .25 L
.66384 .25 L
.66385 .25 L
Mistroke
.66385 .25 L
.66385 .25 L
.66386 .25 L
.66386 .25 L
.66387 .25 L
.66387 .25 L
.66387 .25 L
.66388 .25 L
.66388 .25 L
.66389 .25 L
.6639 .25 L
.6639 .25 L
.66391 .25 L
.66392 .25 L
.66392 .25 L
.66393 .25 L
.66393 .25 L
.66394 .25 L
.66395 .25 L
.66395 .25 L
.66396 .25 L
.66397 .25 L
.66397 .25 L
.66398 .25 L
.66398 .25 L
.66399 .25 L
.66399 .25 L
.664 .25 L
.66401 .25 L
.66401 .25 L
.66402 .25 L
.66402 .25 L
.66403 .25 L
.66404 .25 L
.66404 .25 L
.66405 .25 L
.66405 .25 L
.66406 .25 L
.66407 .25 L
.66407 .25 L
.66408 .25 L
.66408 .25 L
.66409 .25 L
.66409 .25 L
.6641 .25 L
.66411 .25 L
.66411 .25 L
.66412 .25 L
.66412 .25 L
.66413 .25 L
Mistroke
.66414 .25 L
.66414 .25 L
.66415 .25 L
.66416 .25 L
.66416 .25 L
.66417 .25 L
.66418 .25 L
.66418 .25 L
.66418 .25 L
.66419 .25 L
.6642 .25 L
.6642 .25 L
.66421 .25 L
.66421 .25 L
.66422 .25 L
.66423 .25 L
.66423 .25 L
.66424 .25 L
.66424 .25 L
.66425 .25 L
.66426 .25 L
.66426 .25 L
.66427 .25 L
.66427 .25 L
.66428 .25 L
.66428 .25 L
.66429 .25 L
.66429 .25 L
.6643 .25 L
.66431 .25 L
.66431 .25 L
.66432 .25 L
.66433 .25 L
.66433 .25 L
.66434 .25 L
.66434 .25 L
.66435 .25 L
.66436 .25 L
.66436 .25 L
.66437 .25 L
.66438 .25 L
.66438 .25 L
.66439 .25 L
.66439 .25 L
.6644 .25 L
.6644 .25 L
.66441 .25 L
.66442 .25 L
.66442 .25 L
.66443 .25 L
Mistroke
.66443 .25 L
.66444 .25 L
.66445 .25 L
.66445 .25 L
.66446 .25 L
.66446 .25 L
.66447 .25 L
.66448 .25 L
.66448 .25 L
.66448 .25 L
.66449 .25 L
.6645 .25 L
.6645 .25 L
.66451 .25 L
.66451 .25 L
.66452 .25 L
.66452 .25 L
.66453 .25 L
.66453 .25 L
.66454 .25 L
.66455 .25 L
.66455 .25 L
.66456 .25 L
.66456 .25 L
.66457 .25 L
.66457 .25 L
.66458 .25 L
.66458 .25 L
.66459 .25 L
.6646 .25 L
.6646 .25 L
.66461 .25 L
.66461 .25 L
.66462 .25 L
.66462 .25 L
.66463 .25 L
.66464 .25 L
.66464 .25 L
.66465 .25 L
.66466 .25 L
.66466 .25 L
.66467 .25 L
.66467 .25 L
.66468 .25 L
.66469 .25 L
.66469 .25 L
.6647 .25 L
.66471 .25 L
.66471 .25 L
.66472 .25 L
Mistroke
.66472 .25 L
.66472 .25 L
.66473 .25 L
.66473 .25 L
.66474 .25 L
.66475 .25 L
.66475 .25 L
.66476 .25 L
.66477 .25 L
.66477 .25 L
.66478 .25 L
.66478 .25 L
.66479 .25 L
.6648 .25 L
.6648 .25 L
.66481 .25 L
.66482 .25 L
.66482 .25 L
.66483 .25 L
.66484 .25 L
.66484 .25 L
.66484 .25 L
.66485 .25 L
.66485 .25 L
.66486 .25 L
.66486 .25 L
.66487 .25 L
.66487 .25 L
.66488 .25 L
.66488 .25 L
.66488 .25 L
.66489 .25 L
.66489 .25 L
.6649 .25 L
.6649 .25 L
.6649 .25 L
.66491 .25 L
.66492 .25 L
.66492 .25 L
.66493 .25 L
.66494 .25 L
.66494 .25 L
.66495 .25 L
.66495 .25 L
.66496 .25 L
.66497 .25 L
.66497 .25 L
.66498 .25 L
.66499 .25 L
.66499 .25 L
Mistroke
.665 .25 L
.665 .25 L
.66501 .25 L
.66501 .25 L
.66502 .25 L
.66503 .25 L
.66503 .25 L
.66504 .25 L
.66505 .25 L
.66505 .25 L
.66506 .25 L
.66506 .25 L
.66507 .25 L
.66507 .25 L
.66508 .25 L
.66509 .25 L
.66509 .25 L
.6651 .25 L
.6651 .25 L
.66511 .25 L
.66511 .25 L
.66512 .25 L
.66512 .25 L
.66513 .25 L
.66514 .25 L
.66514 .25 L
.66515 .25 L
.66516 .25 L
.66516 .25 L
.66517 .25 L
.66518 .25 L
.66518 .25 L
.66519 .25 L
.6652 .25 L
.6652 .25 L
.66521 .25 L
.66521 .25 L
.66522 .25 L
.66522 .25 L
.66523 .25 L
.66523 .25 L
.66524 .25 L
.66525 .25 L
.66525 .25 L
.66526 .25 L
.66526 .25 L
.66527 .25 L
.66528 .25 L
.66528 .25 L
.66529 .25 L
Mistroke
.66529 .25 L
.6653 .25 L
.6653 .25 L
.66531 .25 L
.66531 .25 L
.66532 .25 L
.66533 .25 L
.66533 .25 L
.66533 .25 L
.66534 .25 L
.66535 .25 L
.66535 .25 L
.66536 .25 L
.66537 .25 L
.66537 .25 L
.66538 .25 L
.66538 .25 L
.66539 .25 L
.66539 .25 L
.6654 .25 L
.6654 .25 L
.66541 .25 L
.66541 .25 L
.66542 .25 L
.66543 .25 L
.66543 .25 L
.66544 .25 L
.66544 .25 L
.66545 .25 L
.66545 .25 L
.66546 .25 L
.66547 .25 L
.66547 .25 L
.66548 .25 L
.66549 .25 L
.66549 .25 L
.6655 .25 L
.6655 .25 L
.66551 .25 L
.66552 .25 L
.66552 .25 L
.66553 .25 L
.66554 .25 L
.66554 .25 L
.66554 .25 L
.66555 .25 L
.66555 .25 L
.66556 .25 L
.66556 .25 L
.66557 .25 L
Mistroke
.66558 .25 L
.66558 .25 L
.66559 .25 L
.6656 .25 L
.6656 .25 L
.66561 .25 L
.66562 .25 L
.66562 .25 L
.66563 .25 L
.66563 .25 L
.66564 .25 L
.66565 .25 L
.66565 .25 L
.66566 .25 L
.66567 .25 L
.66567 .25 L
.66568 .25 L
.66568 .25 L
.66568 .25 L
.66569 .25 L
.66569 .25 L
.6657 .25 L
.6657 .25 L
.6657 .25 L
.66571 .25 L
.66571 .25 L
.66572 .25 L
.66572 .25 L
.66572 .25 L
.66573 .25 L
.66573 .25 L
.66574 .25 L
.66575 .25 L
.66575 .25 L
.66576 .25 L
.66577 .25 L
.66577 .25 L
.66578 .25 L
.66578 .25 L
.66579 .25 L
.6658 .25 L
.6658 .25 L
.66581 .25 L
.66582 .25 L
.66582 .25 L
.66583 .25 L
.66583 .25 L
.66584 .25 L
.66584 .25 L
.66585 .25 L
Mistroke
.66586 .25 L
.66586 .25 L
.66587 .25 L
.66587 .25 L
.66588 .25 L
.66589 .25 L
.66589 .25 L
.6659 .25 L
.6659 .25 L
.66591 .25 L
.66592 .25 L
.66592 .25 L
.66593 .25 L
.66593 .25 L
.66594 .25 L
.66594 .25 L
.66595 .25 L
.66596 .25 L
.66596 .25 L
.66597 .25 L
.66597 .25 L
.66598 .25 L
.66599 .25 L
.66599 .25 L
.666 .25 L
.66601 .25 L
.66601 .25 L
.66602 .25 L
.66603 .25 L
.66603 .25 L
.66603 .25 L
.66604 .25 L
.66605 .25 L
.66605 .25 L
.66606 .25 L
.66607 .25 L
.66607 .25 L
.66608 .25 L
.66608 .25 L
.66609 .25 L
.66609 .25 L
.6661 .25 L
.66611 .25 L
.66611 .25 L
.66612 .25 L
.66612 .25 L
.66613 .25 L
.66613 .25 L
.66614 .25 L
.66614 .25 L
Mistroke
.66615 .25 L
.66616 .25 L
.66616 .25 L
.66616 .25 L
.66617 .25 L
.66618 .25 L
.66618 .25 L
.66619 .25 L
.6662 .25 L
.6662 .25 L
.66621 .25 L
.66621 .25 L
.66622 .25 L
.66622 .25 L
.66622 .25 L
.66623 .25 L
.66624 .25 L
.66624 .25 L
.66625 .25 L
.66626 .25 L
.66626 .25 L
.66627 .25 L
.66627 .25 L
.66628 .25 L
.66629 .25 L
.66629 .25 L
.6663 .25 L
.6663 .25 L
.66631 .25 L
.66632 .25 L
.66632 .25 L
.66633 .25 L
.66634 .25 L
.66634 .25 L
.66635 .25 L
.66635 .25 L
.66636 .25 L
.66636 .25 L
.66637 .25 L
.66637 .25 L
.66638 .25 L
.66638 .25 L
.66639 .25 L
.6664 .25 L
.6664 .25 L
.66641 .25 L
.66641 .25 L
.66642 .25 L
.66643 .25 L
.66643 .25 L
Mistroke
.66644 .25 L
.66645 .25 L
.66645 .25 L
.66646 .25 L
.66647 .25 L
.66647 .25 L
.66648 .25 L
.66648 .25 L
.66649 .25 L
.66649 .25 L
.6665 .25 L
.6665 .25 L
.66651 .25 L
.66651 .25 L
.66651 .25 L
.66652 .25 L
.66652 .25 L
.66653 .25 L
.66653 .25 L
.66654 .25 L
.66654 .25 L
.66654 .25 L
.66655 .25 L
.66655 .25 L
.66656 .25 L
.66656 .25 L
.66657 .25 L
.66658 .25 L
.66658 .25 L
.66659 .25 L
.6666 .25 L
.6666 .25 L
.66661 .25 L
.66661 .25 L
.66662 .25 L
.66663 .25 L
.66663 .25 L
.66664 .25 L
.66665 .25 L
.66665 .25 L
.66665 .25 L
.66666 .25 L
.66667 .25 L
.66667 .25 L
.66668 .25 L
.66669 .25 L
.66669 .25 L
.6667 .25 L
.6667 .25 L
.66671 .25 L
Mistroke
.66671 .25 L
.66672 .25 L
.66673 .25 L
.66673 .25 L
.66674 .25 L
.66675 .25 L
.66675 .25 L
.66675 .25 L
.66676 .25 L
.66677 .25 L
.66677 .25 L
.66678 .25 L
.66679 .25 L
.66679 .25 L
.6668 .25 L
.6668 .25 L
.66681 .25 L
.66682 .25 L
.66682 .25 L
.66683 .25 L
.66684 .25 L
.66684 .25 L
.66685 .25 L
.66685 .25 L
.66686 .25 L
.66686 .25 L
.66687 .25 L
.66688 .25 L
.66688 .25 L
.66689 .25 L
.66689 .25 L
.6669 .25 L
.66691 .25 L
.66691 .25 L
.66692 .25 L
.66692 .25 L
.66693 .25 L
.66694 .25 L
.66694 .25 L
.66695 .25 L
.66695 .25 L
.66696 .25 L
.66696 .25 L
.66697 .25 L
.66697 .25 L
.66698 .25 L
.66698 .25 L
.66699 .25 L
.66699 .25 L
.667 .25 L
Mistroke
.66701 .25 L
.66701 .25 L
.66702 .25 L
.66703 .25 L
.66703 .25 L
.66703 .25 L
.66704 .25 L
.66704 .25 L
.66705 .25 L
.66705 .25 L
.66706 .25 L
.66707 .25 L
.66707 .25 L
.66708 .25 L
.66708 .25 L
.66709 .25 L
.6671 .25 L
.6671 .25 L
.66711 .25 L
.66711 .25 L
.66712 .25 L
.66713 .25 L
.66713 .25 L
.66714 .25 L
.66715 .25 L
.66715 .25 L
.66716 .25 L
.66716 .25 L
.66717 .25 L
.66718 .25 L
.66718 .25 L
.66719 .25 L
.66719 .25 L
.6672 .25 L
.6672 .25 L
.66721 .25 L
.66721 .25 L
.66722 .25 L
.66723 .25 L
.66723 .25 L
.66724 .25 L
.66724 .25 L
.66725 .25 L
.66726 .25 L
.66726 .25 L
.66727 .25 L
.66728 .25 L
.66728 .25 L
.66729 .25 L
.6673 .25 L
Mistroke
.6673 .25 L
.66731 .25 L
.66731 .25 L
.66732 .25 L
.66732 .25 L
.66733 .25 L
.66733 .25 L
.66733 .25 L
.66734 .25 L
.66734 .25 L
.66735 .25 L
.66735 .25 L
.66736 .25 L
.66736 .25 L
.66736 .25 L
.66737 .25 L
.66737 .25 L
.66737 .25 L
.66738 .25 L
.66739 .25 L
.66739 .25 L
.6674 .25 L
.66741 .25 L
.66741 .25 L
.66742 .25 L
.66743 .25 L
.66743 .25 L
.66744 .25 L
.66744 .25 L
.66745 .25 L
.66746 .25 L
.66746 .25 L
.66747 .25 L
.66747 .25 L
.66748 .25 L
.66748 .25 L
.66749 .25 L
.6675 .25 L
.6675 .25 L
.66751 .25 L
.66752 .25 L
.66752 .25 L
.66753 .25 L
.66753 .25 L
.66754 .25 L
.66754 .25 L
.66755 .25 L
.66756 .25 L
.66756 .25 L
.66757 .25 L
Mistroke
.66757 .25 L
.66758 .25 L
.66758 .25 L
.66759 .25 L
.6676 .25 L
.6676 .25 L
.66761 .25 L
.66762 .25 L
.66762 .25 L
.66763 .25 L
.66763 .25 L
.66764 .25 L
.66765 .25 L
.66765 .25 L
.66766 .25 L
.66767 .25 L
.66767 .25 L
.66768 .25 L
.66768 .25 L
.66769 .25 L
.66769 .25 L
.6677 .25 L
.66771 .25 L
.66771 .25 L
.66772 .25 L
.66772 .25 L
.66773 .25 L
.66773 .25 L
.66774 .25 L
.66775 .25 L
.66775 .25 L
.66776 .25 L
.66777 .25 L
.66777 .25 L
.66778 .25 L
.66778 .25 L
.66779 .25 L
.66779 .25 L
.6678 .25 L
.66781 .25 L
.66781 .25 L
.66782 .25 L
.66782 .25 L
.66783 .25 L
.66784 .25 L
.66784 .25 L
.66785 .25 L
.66786 .25 L
.66786 .25 L
.66787 .25 L
Mistroke
.66788 .25 L
.66788 .25 L
.66788 .25 L
.66789 .25 L
.6679 .25 L
.6679 .25 L
.66791 .25 L
.66791 .25 L
.66792 .25 L
.66793 .25 L
.66793 .25 L
.66794 .25 L
.66794 .25 L
.66795 .25 L
.66796 .25 L
.66796 .25 L
.66797 .25 L
.66797 .25 L
.66798 .25 L
.66798 .25 L
.66799 .25 L
.66799 .25 L
.668 .25 L
.668 .25 L
.66801 .25 L
.66801 .25 L
.66802 .25 L
.66803 .25 L
.66803 .25 L
.66804 .25 L
.66804 .25 L
.66805 .25 L
.66806 .25 L
.66806 .25 L
.66807 .25 L
.66807 .25 L
.66807 .25 L
.66808 .25 L
.66809 .25 L
.66809 .25 L
.6681 .25 L
.6681 .25 L
.66811 .25 L
.66812 .25 L
.66812 .25 L
.66813 .25 L
.66813 .25 L
.66814 .25 L
.66815 .25 L
.66815 .25 L
Mistroke
.66816 .25 L
.66817 .25 L
.66817 .25 L
.66818 .25 L
.66818 .25 L
.66819 .25 L
.6682 .25 L
.6682 .25 L
.66821 .25 L
.66821 .25 L
.66822 .25 L
.66822 .25 L
.66823 .25 L
.66823 .25 L
.66824 .25 L
.66824 .25 L
.66825 .25 L
.66826 .25 L
.66826 .25 L
.66827 .25 L
.66828 .25 L
.66828 .25 L
.66829 .25 L
.6683 .25 L
.6683 .25 L
.66831 .25 L
.66832 .25 L
.66832 .25 L
.66833 .25 L
.66833 .25 L
.66834 .25 L
.66834 .25 L
.66835 .25 L
.66835 .25 L
.66836 .25 L
.66836 .25 L
.66836 .25 L
.66837 .25 L
.66837 .25 L
.66838 .25 L
.66838 .25 L
.66839 .25 L
.66839 .25 L
.66839 .25 L
.6684 .25 L
.6684 .25 L
.66841 .25 L
.66841 .25 L
.66842 .25 L
.66843 .25 L
Mistroke
.66843 .25 L
.66844 .25 L
.66845 .25 L
.66845 .25 L
.66846 .25 L
.66846 .25 L
.66847 .25 L
.66848 .25 L
.66848 .25 L
.66849 .25 L
.6685 .25 L
.6685 .25 L
.6685 .25 L
.66851 .25 L
.66852 .25 L
.66852 .25 L
.66853 .25 L
.66854 .25 L
.66854 .25 L
.66855 .25 L
.66855 .25 L
.66856 .25 L
.66856 .25 L
.66857 .25 L
.66858 .25 L
.66858 .25 L
.66859 .25 L
.6686 .25 L
.6686 .25 L
.6686 .25 L
.66861 .25 L
.66862 .25 L
.66862 .25 L
.66863 .25 L
.66864 .25 L
.66864 .25 L
.66865 .25 L
.66865 .25 L
.66866 .25 L
.66867 .25 L
.66867 .25 L
.66868 .25 L
.66869 .25 L
.66869 .25 L
.6687 .25 L
.6687 .25 L
.66871 .25 L
.66871 .25 L
.66872 .25 L
.66873 .25 L
Mistroke
.66873 .25 L
.66874 .25 L
.66874 .25 L
.66875 .25 L
.66876 .25 L
.66876 .25 L
.66877 .25 L
.66877 .25 L
.66878 .25 L
.66879 .25 L
.66879 .25 L
.6688 .25 L
.6688 .25 L
.66881 .25 L
.66881 .25 L
.66882 .25 L
.66882 .25 L
.66883 .25 L
.66883 .25 L
.66884 .25 L
.66884 .25 L
.66885 .25 L
.66886 .25 L
.66886 .25 L
.66887 .25 L
.66888 .25 L
.66888 .25 L
.66888 .25 L
.66889 .25 L
.66889 .25 L
.6689 .25 L
.6689 .25 L
.66891 .25 L
.66892 .25 L
.66892 .25 L
.66893 .25 L
.66894 .25 L
.66894 .25 L
.66895 .25 L
.66895 .25 L
.66896 .25 L
.66897 .25 L
.66897 .25 L
.66898 .25 L
.66898 .25 L
.66899 .25 L
.669 .25 L
.669 .25 L
.66901 .25 L
.66901 .25 L
Mistroke
.66902 .25 L
.66903 .25 L
.66903 .25 L
.66904 .25 L
.66904 .25 L
.66905 .25 L
.66905 .25 L
.66906 .25 L
.66906 .25 L
.66907 .25 L
.66908 .25 L
.66908 .25 L
.66909 .25 L
.66909 .25 L
.6691 .25 L
.66911 .25 L
.66911 .25 L
.66912 .25 L
.66913 .25 L
.66913 .25 L
.66914 .25 L
.66915 .25 L
.66915 .25 L
.66916 .25 L
.66916 .25 L
.66917 .25 L
.66917 .25 L
.66918 .25 L
.66918 .25 L
.66918 .25 L
.66919 .25 L
.66919 .25 L
.6692 .25 L
.6692 .25 L
.66921 .25 L
.66921 .25 L
.66921 .25 L
.66922 .25 L
.66922 .25 L
.66922 .25 L
.66923 .25 L
.66924 .25 L
.66924 .25 L
.66925 .25 L
.66926 .25 L
.66926 .25 L
.66927 .25 L
.66928 .25 L
.66928 .25 L
.66929 .25 L
Mistroke
.66929 .25 L
.6693 .25 L
.66931 .25 L
.66931 .25 L
.66932 .25 L
.66932 .25 L
.66933 .25 L
.66934 .25 L
.66934 .25 L
.66935 .25 L
.66935 .25 L
.66936 .25 L
.66937 .25 L
.66937 .25 L
.66938 .25 L
.66938 .25 L
.66939 .25 L
.66939 .25 L
.6694 .25 L
.66941 .25 L
.66941 .25 L
.66942 .25 L
.66942 .25 L
.66943 .25 L
.66943 .25 L
.66944 .25 L
.66945 .25 L
.66945 .25 L
.66946 .25 L
.66947 .25 L
.66947 .25 L
.66948 .25 L
.66948 .25 L
.66949 .25 L
.6695 .25 L
.6695 .25 L
.66951 .25 L
.66952 .25 L
.66952 .25 L
.66953 .25 L
.66953 .25 L
.66954 .25 L
.66954 .25 L
.66955 .25 L
.66956 .25 L
.66956 .25 L
.66957 .25 L
.66957 .25 L
.66958 .25 L
.66959 .25 L
Mistroke
.66959 .25 L
.6696 .25 L
.6696 .25 L
.66961 .25 L
.66962 .25 L
.66962 .25 L
.66963 .25 L
.66963 .25 L
.66964 .25 L
.66964 .25 L
.66965 .25 L
.66965 .25 L
.66966 .25 L
.66966 .25 L
.66967 .25 L
.66967 .25 L
.66968 .25 L
.66969 .25 L
.66969 .25 L
.6697 .25 L
.6697 .25 L
.66971 .25 L
.66971 .25 L
.66972 .25 L
.66972 .25 L
.66973 .25 L
.66973 .25 L
.66974 .25 L
.66975 .25 L
.66975 .25 L
.66976 .25 L
.66976 .25 L
.66977 .25 L
.66978 .25 L
.66978 .25 L
.66979 .25 L
.66979 .25 L
.6698 .25 L
.66981 .25 L
.66981 .25 L
.66982 .25 L
.66983 .25 L
.66983 .25 L
.66984 .25 L
.66985 .25 L
.66985 .25 L
.66986 .25 L
.66986 .25 L
.66987 .25 L
.66987 .25 L
Mistroke
.66987 .25 L
.66988 .25 L
.66989 .25 L
.66989 .25 L
.6699 .25 L
.66991 .25 L
.66991 .25 L
.66992 .25 L
.66992 .25 L
.66993 .25 L
.66994 .25 L
.66994 .25 L
.66995 .25 L
.66996 .25 L
.66996 .25 L
.66997 .25 L
.66998 .25 L
.66998 .25 L
.66999 .25 L
.66999 .25 L
.67 .25 L
.67 .25 L
.67 .25 L
.67001 .25 L
.67001 .25 L
.67002 .25 L
.67002 .25 L
.67003 .25 L
.67003 .25 L
.67003 .25 L
.67004 .25 L
.67004 .25 L
.67004 .25 L
.67005 .25 L
.67005 .25 L
.67006 .25 L
.67007 .25 L
.67007 .25 L
.67008 .25 L
.67009 .25 L
.67009 .25 L
.6701 .25 L
.67011 .25 L
.67011 .25 L
.67012 .25 L
.67013 .25 L
.67013 .25 L
.67014 .25 L
.67014 .25 L
.67015 .25 L
Mistroke
.67015 .25 L
.67016 .25 L
.67017 .25 L
.67017 .25 L
.67018 .25 L
.67018 .25 L
.67019 .25 L
.6702 .25 L
.6702 .25 L
.67021 .25 L
.67021 .25 L
.67022 .25 L
.67023 .25 L
.67023 .25 L
.67024 .25 L
.67024 .25 L
.67025 .25 L
.67025 .25 L
.67026 .25 L
.67026 .25 L
.67027 .25 L
.67028 .25 L
.67028 .25 L
.67029 .25 L
.6703 .25 L
.6703 .25 L
.67031 .25 L
.67031 .25 L
.67032 .25 L
.67033 .25 L
.67033 .25 L
.67034 .25 L
.67035 .25 L
.67035 .25 L
.67035 .25 L
.67036 .25 L
.67037 .25 L
.67037 .25 L
.67038 .25 L
.67039 .25 L
.67039 .25 L
.6704 .25 L
.6704 .25 L
.67041 .25 L
.67041 .25 L
.67042 .25 L
.67043 .25 L
.67043 .25 L
.67044 .25 L
.67045 .25 L
Mistroke
.67045 .25 L
.67045 .25 L
.67046 .25 L
.67047 .25 L
.67047 .25 L
.67048 .25 L
.67048 .25 L
.67049 .25 L
.67049 .25 L
.6705 .25 L
.6705 .25 L
.67051 .25 L
.67052 .25 L
.67052 .25 L
.67053 .25 L
.67053 .25 L
.67054 .25 L
.67054 .25 L
.67054 .25 L
.67055 .25 L
.67056 .25 L
.67056 .25 L
.67057 .25 L
.67058 .25 L
.67058 .25 L
.67059 .25 L
.67059 .25 L
.6706 .25 L
.67061 .25 L
.67061 .25 L
.67062 .25 L
.67062 .25 L
.67063 .25 L
.67064 .25 L
.67064 .25 L
.67065 .25 L
.67066 .25 L
.67066 .25 L
.67067 .25 L
.67068 .25 L
.67068 .25 L
.67069 .25 L
.67069 .25 L
.67069 .25 L
.6707 .25 L
.6707 .25 L
.67071 .25 L
.67072 .25 L
.67072 .25 L
.67073 .25 L
Mistroke
.67074 .25 L
.67074 .25 L
.67075 .25 L
.67075 .25 L
.67076 .25 L
.67077 .25 L
.67077 .25 L
.67078 .25 L
.67079 .25 L
.67079 .25 L
.6708 .25 L
.67081 .25 L
.67081 .25 L
.67081 .25 L
.67082 .25 L
.67082 .25 L
.67083 .25 L
.67083 .25 L
.67083 .25 L
.67084 .25 L
.67085 .25 L
.67085 .25 L
.67085 .25 L
.67086 .25 L
.67086 .25 L
.67086 .25 L
.67087 .25 L
.67087 .25 L
.67088 .25 L
.67088 .25 L
.67089 .25 L
.6709 .25 L
.6709 .25 L
.67091 .25 L
.67092 .25 L
.67092 .25 L
.67093 .25 L
.67093 .25 L
.67094 .25 L
.67095 .25 L
.67095 .25 L
.67096 .25 L
.67097 .25 L
.67097 .25 L
.67098 .25 L
.67098 .25 L
.67099 .25 L
.67099 .25 L
.671 .25 L
.67101 .25 L
Mistroke
.67101 .25 L
.67102 .25 L
.67102 .25 L
.67103 .25 L
.67104 .25 L
.67104 .25 L
.67105 .25 L
.67105 .25 L
.67106 .25 L
.67107 .25 L
.67107 .25 L
.67107 .25 L
.67108 .25 L
.67109 .25 L
.67109 .25 L
.6711 .25 L
.67111 .25 L
.67111 .25 L
.67112 .25 L
.67112 .25 L
.67113 .25 L
.67114 .25 L
.67114 .25 L
.67115 .25 L
.67116 .25 L
.67116 .25 L
.67117 .25 L
.67117 .25 L
.67118 .25 L
.67118 .25 L
.67119 .25 L
.6712 .25 L
.6712 .25 L
.67121 .25 L
.67122 .25 L
.67122 .25 L
.67123 .25 L
.67123 .25 L
.67124 .25 L
.67124 .25 L
.67125 .25 L
.67126 .25 L
.67126 .25 L
.67127 .25 L
.67127 .25 L
.67128 .25 L
.67128 .25 L
.67129 .25 L
.6713 .25 L
.6713 .25 L
Mistroke
.67131 .25 L
.67132 .25 L
.67132 .25 L
.67133 .25 L
.67133 .25 L
.67134 .25 L
.67135 .25 L
.67135 .25 L
.67136 .25 L
.67137 .25 L
.67137 .25 L
.67138 .25 L
.67138 .25 L
.67139 .25 L
.67139 .25 L
.6714 .25 L
.67141 .25 L
.67141 .25 L
.67142 .25 L
.67142 .25 L
.67143 .25 L
.67144 .25 L
.67144 .25 L
.67145 .25 L
.67145 .25 L
.67146 .25 L
.67147 .25 L
.67147 .25 L
.67148 .25 L
.67148 .25 L
.67149 .25 L
.67149 .25 L
.6715 .25 L
.6715 .25 L
.67151 .25 L
.67151 .25 L
.67152 .25 L
.67152 .25 L
.67153 .25 L
.67154 .25 L
.67154 .25 L
.67155 .25 L
.67155 .25 L
.67156 .25 L
.67156 .25 L
.67157 .25 L
.67157 .25 L
.67158 .25 L
.67158 .25 L
.67159 .25 L
Mistroke
.6716 .25 L
.6716 .25 L
.67161 .25 L
.67161 .25 L
.67162 .25 L
.67163 .25 L
.67163 .25 L
.67164 .25 L
.67164 .25 L
.67165 .25 L
.67166 .25 L
.67166 .25 L
.67167 .25 L
.67168 .25 L
.67168 .25 L
.67169 .25 L
.67169 .25 L
.6717 .25 L
.67171 .25 L
.67171 .25 L
.67172 .25 L
.67172 .25 L
.67172 .25 L
.67173 .25 L
.67174 .25 L
.67174 .25 L
.67175 .25 L
.67176 .25 L
.67176 .25 L
.67177 .25 L
.67177 .25 L
.67178 .25 L
.67179 .25 L
.67179 .25 L
.6718 .25 L
.67181 .25 L
.67181 .25 L
.67182 .25 L
.67183 .25 L
.67183 .25 L
.67184 .25 L
.67184 .25 L
.67185 .25 L
.67185 .25 L
.67185 .25 L
.67186 .25 L
.67186 .25 L
.67187 .25 L
.67187 .25 L
.67188 .25 L
Mistroke
.67188 .25 L
.67188 .25 L
.67189 .25 L
.67189 .25 L
.67189 .25 L
.6719 .25 L
.6719 .25 L
.67191 .25 L
.67192 .25 L
.67192 .25 L
.67193 .25 L
.67194 .25 L
.67194 .25 L
.67195 .25 L
.67196 .25 L
.67196 .25 L
.67197 .25 L
.67198 .25 L
.67198 .25 L
.67199 .25 L
.67199 .25 L
.672 .25 L
.672 .25 L
.67201 .25 L
.67202 .25 L
.67202 .25 L
.67203 .25 L
.67203 .25 L
.67204 .25 L
.67205 .25 L
.67205 .25 L
.67206 .25 L
.67206 .25 L
.67207 .25 L
.67208 .25 L
.67208 .25 L
.67209 .25 L
.67209 .25 L
.6721 .25 L
.6721 .25 L
.67211 .25 L
.67211 .25 L
.67212 .25 L
.67213 .25 L
.67213 .25 L
.67214 .25 L
.67215 .25 L
.67215 .25 L
.67216 .25 L
.67216 .25 L
Mistroke
.67217 .25 L
.67218 .25 L
.67218 .25 L
.67219 .25 L
.6722 .25 L
.6722 .25 L
.6722 .25 L
.67221 .25 L
.67222 .25 L
.67222 .25 L
.67223 .25 L
.67224 .25 L
.67224 .25 L
.67225 .25 L
.67225 .25 L
.67226 .25 L
.67227 .25 L
.67227 .25 L
.67228 .25 L
.67228 .25 L
.67229 .25 L
.6723 .25 L
.6723 .25 L
.6723 .25 L
.67231 .25 L
.67232 .25 L
.67232 .25 L
.67233 .25 L
.67233 .25 L
.67234 .25 L
.67234 .25 L
.67235 .25 L
.67235 .25 L
.67236 .25 L
.67237 .25 L
.67237 .25 L
.67238 .25 L
.67238 .25 L
.67239 .25 L
.67239 .25 L
.6724 .25 L
.6724 .25 L
.67241 .25 L
.67241 .25 L
.67242 .25 L
.67243 .25 L
.67243 .25 L
.67244 .25 L
.67244 .25 L
.67245 .25 L
Mistroke
.67246 .25 L
.67246 .25 L
.67247 .25 L
.67248 .25 L
.67248 .25 L
.67249 .25 L
.67249 .25 L
.6725 .25 L
.67251 .25 L
.67251 .25 L
.67252 .25 L
.67253 .25 L
.67253 .25 L
.67254 .25 L
.67254 .25 L
.67254 .25 L
.67255 .25 L
.67255 .25 L
.67256 .25 L
.67257 .25 L
.67257 .25 L
.67258 .25 L
.67259 .25 L
.67259 .25 L
.6726 .25 L
.6726 .25 L
.67261 .25 L
.67262 .25 L
.67262 .25 L
.67263 .25 L
.67264 .25 L
.67264 .25 L
.67265 .25 L
.67266 .25 L
.67266 .25 L
.67266 .25 L
.67267 .25 L
.67267 .25 L
.67268 .25 L
.67268 .25 L
.67269 .25 L
.67269 .25 L
.6727 .25 L
.6727 .25 L
.6727 .25 L
.67271 .25 L
.67271 .25 L
.67271 .25 L
.67272 .25 L
.67272 .25 L
Mistroke
.67273 .25 L
.67274 .25 L
.67274 .25 L
.67275 .25 L
.67276 .25 L
.67276 .25 L
.67277 .25 L
.67277 .25 L
.67278 .25 L
.67279 .25 L
.67279 .25 L
.6728 .25 L
.67281 .25 L
.67281 .25 L
.67282 .25 L
.67282 .25 L
.67283 .25 L
.67283 .25 L
.67284 .25 L
.67285 .25 L
.67285 .25 L
.67286 .25 L
.67286 .25 L
.67287 .25 L
.67287 .25 L
.67288 .25 L
.67289 .25 L
.67289 .25 L
.6729 .25 L
.67291 .25 L
.67291 .25 L
.67292 .25 L
.67292 .25 L
.67292 .25 L
.67293 .25 L
.67294 .25 L
.67294 .25 L
.67295 .25 L
.67296 .25 L
.67296 .25 L
.67297 .25 L
.67298 .25 L
.67298 .25 L
.67299 .25 L
.67299 .25 L
.673 .25 L
.67301 .25 L
.67301 .25 L
.67302 .25 L
.67302 .25 L
Mistroke
.67303 .25 L
.67304 .25 L
.67304 .25 L
.67305 .25 L
.67305 .25 L
.67306 .25 L
.67307 .25 L
.67307 .25 L
.67308 .25 L
.67308 .25 L
.67309 .25 L
.6731 .25 L
.6731 .25 L
.67311 .25 L
.67311 .25 L
.67312 .25 L
.67312 .25 L
.67313 .25 L
.67313 .25 L
.67314 .25 L
.67315 .25 L
.67315 .25 L
.67315 .25 L
.67316 .25 L
.67317 .25 L
.67317 .25 L
.67318 .25 L
.67318 .25 L
.67319 .25 L
.6732 .25 L
.6732 .25 L
.6732 .25 L
.67321 .25 L
.67322 .25 L
.67322 .25 L
.67323 .25 L
.67323 .25 L
.67324 .25 L
.67324 .25 L
.67325 .25 L
.67326 .25 L
.67326 .25 L
.67327 .25 L
.67327 .25 L
.67328 .25 L
.67329 .25 L
.67329 .25 L
.6733 .25 L
.67331 .25 L
.67331 .25 L
Mistroke
.67332 .25 L
.67332 .25 L
.67333 .25 L
.67334 .25 L
.67334 .25 L
.67335 .25 L
.67336 .25 L
.67336 .25 L
.67336 .25 L
.67337 .25 L
.67337 .25 L
.67338 .25 L
.67338 .25 L
.67339 .25 L
.6734 .25 L
.6734 .25 L
.67341 .25 L
.67342 .25 L
.67342 .25 L
.67343 .25 L
.67343 .25 L
.67344 .25 L
.67345 .25 L
.67345 .25 L
.67346 .25 L
.67347 .25 L
.67347 .25 L
.67348 .25 L
.67348 .25 L
.67349 .25 L
.67349 .25 L
.6735 .25 L
.6735 .25 L
.67351 .25 L
.67351 .25 L
.67352 .25 L
.67352 .25 L
.67352 .25 L
.67353 .25 L
.67353 .25 L
.67353 .25 L
.67354 .25 L
.67354 .25 L
.67355 .25 L
.67355 .25 L
.67356 .25 L
.67357 .25 L
.67357 .25 L
.67358 .25 L
.67359 .25 L
Mistroke
.67359 .25 L
.6736 .25 L
.6736 .25 L
.67361 .25 L
.67362 .25 L
.67362 .25 L
.67363 .25 L
.67364 .25 L
.67364 .25 L
.67365 .25 L
.67365 .25 L
.67366 .25 L
.67366 .25 L
.67367 .25 L
.67368 .25 L
.67368 .25 L
.67369 .25 L
.67369 .25 L
.6737 .25 L
.6737 .25 L
.67371 .25 L
.67372 .25 L
.67372 .25 L
.67373 .25 L
.67373 .25 L
.67374 .25 L
.67374 .25 L
.67375 .25 L
.67375 .25 L
.67376 .25 L
.67377 .25 L
.67377 .25 L
.67378 .25 L
.67379 .25 L
.67379 .25 L
.6738 .25 L
.67381 .25 L
.67381 .25 L
.67382 .25 L
.67383 .25 L
.67383 .25 L
.67384 .25 L
.67384 .25 L
.67385 .25 L
.67385 .25 L
.67386 .25 L
.67387 .25 L
.67387 .25 L
.67388 .25 L
.67388 .25 L
Mistroke
.67389 .25 L
.6739 .25 L
.6739 .25 L
.67391 .25 L
.67391 .25 L
.67392 .25 L
.67393 .25 L
.67393 .25 L
.67394 .25 L
.67394 .25 L
.67395 .25 L
.67395 .25 L
.67396 .25 L
.67396 .25 L
.67397 .25 L
.67397 .25 L
.67398 .25 L
.67398 .25 L
.67399 .25 L
.674 .25 L
.674 .25 L
.67401 .25 L
.67401 .25 L
.67402 .25 L
.67402 .25 L
.67403 .25 L
.67404 .25 L
.67404 .25 L
.67404 .25 L
.67405 .25 L
.67406 .25 L
.67406 .25 L
.67407 .25 L
.67407 .25 L
.67408 .25 L
.67409 .25 L
.67409 .25 L
.6741 .25 L
.6741 .25 L
.67411 .25 L
.67412 .25 L
.67412 .25 L
.67413 .25 L
.67413 .25 L
.67414 .25 L
.67415 .25 L
.67415 .25 L
.67416 .25 L
.67417 .25 L
.67417 .25 L
Mistroke
.67418 .25 L
.67418 .25 L
.67419 .25 L
.67419 .25 L
.67419 .25 L
.6742 .25 L
.67421 .25 L
.67421 .25 L
.67422 .25 L
.67423 .25 L
.67423 .25 L
.67424 .25 L
.67424 .25 L
.67425 .25 L
.67426 .25 L
.67426 .25 L
.67427 .25 L
.67428 .25 L
.67428 .25 L
.67429 .25 L
.6743 .25 L
.6743 .25 L
.67431 .25 L
.67431 .25 L
.67432 .25 L
.67432 .25 L
.67433 .25 L
.67433 .25 L
.67433 .25 L
.67434 .25 L
.67434 .25 L
.67435 .25 L
.67435 .25 L
.67435 .25 L
.67436 .25 L
.67436 .25 L
.67437 .25 L
.67437 .25 L
.67438 .25 L
.67438 .25 L
.67439 .25 L
.6744 .25 L
.6744 .25 L
.67441 .25 L
.67441 .25 L
.67442 .25 L
.67443 .25 L
.67443 .25 L
.67444 .25 L
.67445 .25 L
Mistroke
.67445 .25 L
.67446 .25 L
.67447 .25 L
.67447 .25 L
.67447 .25 L
.67448 .25 L
.67449 .25 L
.67449 .25 L
.6745 .25 L
.67451 .25 L
.67451 .25 L
.67452 .25 L
.67452 .25 L
.67453 .25 L
.67453 .25 L
.67454 .25 L
.67455 .25 L
.67455 .25 L
.67456 .25 L
.67456 .25 L
.67457 .25 L
.67457 .25 L
.67458 .25 L
.67458 .25 L
.67459 .25 L
.6746 .25 L
.6746 .25 L
.67461 .25 L
.67462 .25 L
.67462 .25 L
.67463 .25 L
.67464 .25 L
.67464 .25 L
.67465 .25 L
.67465 .25 L
.67466 .25 L
.67467 .25 L
.67467 .25 L
.67468 .25 L
.67468 .25 L
.67469 .25 L
.67469 .25 L
.6747 .25 L
.67471 .25 L
.67471 .25 L
.67472 .25 L
.67472 .25 L
.67473 .25 L
.67474 .25 L
.67474 .25 L
Mistroke
.67475 .25 L
.67475 .25 L
.67476 .25 L
.67477 .25 L
.67477 .25 L
.67477 .25 L
.67478 .25 L
.67479 .25 L
.67479 .25 L
.6748 .25 L
.67481 .25 L
.67481 .25 L
.67482 .25 L
.67483 .25 L
.67483 .25 L
.67484 .25 L
.67484 .25 L
.67485 .25 L
.67486 .25 L
.67486 .25 L
.67487 .25 L
.67487 .25 L
.67488 .25 L
.67489 .25 L
.67489 .25 L
.6749 .25 L
.6749 .25 L
.67491 .25 L
.67492 .25 L
.67492 .25 L
.67493 .25 L
.67493 .25 L
.67494 .25 L
.67494 .25 L
.67495 .25 L
.67496 .25 L
.67496 .25 L
.67497 .25 L
.67497 .25 L
.67498 .25 L
.67498 .25 L
.67499 .25 L
.675 .25 L
.675 .25 L
.675 .25 L
.67501 .25 L
.67502 .25 L
.67502 .25 L
.67503 .25 L
.67503 .25 L
Mistroke
.67504 .25 L
.67505 .25 L
.67505 .25 L
.67505 .25 L
.67506 .25 L
.67507 .25 L
.67507 .25 L
.67508 .25 L
.67508 .25 L
.67509 .25 L
.67509 .25 L
.6751 .25 L
.67511 .25 L
.67511 .25 L
.67512 .25 L
.67512 .25 L
.67513 .25 L
.67514 .25 L
.67514 .25 L
.67515 .25 L
.67516 .25 L
.67516 .25 L
.67517 .25 L
.67517 .25 L
.67518 .25 L
.67519 .25 L
.67519 .25 L
.6752 .25 L
.67521 .25 L
.67521 .25 L
.67521 .25 L
.67522 .25 L
.67522 .25 L
.67523 .25 L
.67523 .25 L
.67524 .25 L
.67525 .25 L
.67525 .25 L
.67526 .25 L
.67527 .25 L
.67527 .25 L
.67528 .25 L
.67528 .25 L
.67529 .25 L
.6753 .25 L
.6753 .25 L
.67531 .25 L
.67532 .25 L
.67532 .25 L
.67533 .25 L
Mistroke
.67533 .25 L
.67534 .25 L
.67534 .25 L
.67535 .25 L
.67535 .25 L
.67536 .25 L
.67536 .25 L
.67537 .25 L
.67537 .25 L
.67537 .25 L
.67538 .25 L
.67538 .25 L
.67538 .25 L
.67539 .25 L
.67539 .25 L
.6754 .25 L
.6754 .25 L
.67541 .25 L
.67542 .25 L
.67542 .25 L
.67543 .25 L
.67544 .25 L
.67544 .25 L
.67545 .25 L
.67545 .25 L
.67546 .25 L
.67547 .25 L
.67547 .25 L
.67548 .25 L
.67549 .25 L
.67549 .25 L
.6755 .25 L
.6755 .25 L
.67551 .25 L
.67551 .25 L
.67552 .25 L
.67553 .25 L
.67553 .25 L
.67554 .25 L
.67554 .25 L
.67555 .25 L
.67555 .25 L
.67556 .25 L
.67557 .25 L
.67557 .25 L
.67558 .25 L
.67558 .25 L
.67559 .25 L
.6756 .25 L
.6756 .25 L
Mistroke
.6756 .25 L
.67561 .25 L
.67562 .25 L
.67562 .25 L
.67563 .25 L
.67564 .25 L
.67564 .25 L
.67565 .25 L
.67566 .25 L
.67566 .25 L
.67567 .25 L
.67568 .25 L
.67568 .25 L
.67569 .25 L
.67569 .25 L
.6757 .25 L
.6757 .25 L
.67571 .25 L
.67572 .25 L
.67572 .25 L
.67573 .25 L
.67573 .25 L
.67574 .25 L
.67575 .25 L
.67575 .25 L
.67576 .25 L
.67576 .25 L
.67577 .25 L
.67578 .25 L
.67578 .25 L
.67579 .25 L
.67579 .25 L
.6758 .25 L
.6758 .25 L
.67581 .25 L
.67581 .25 L
.67582 .25 L
.67582 .25 L
.67583 .25 L
.67583 .25 L
.67584 .25 L
.67585 .25 L
.67585 .25 L
.67586 .25 L
.67586 .25 L
.67587 .25 L
.67587 .25 L
.67588 .25 L
.67589 .25 L
.67589 .25 L
Mistroke
.67589 .25 L
.6759 .25 L
.67591 .25 L
.67591 .25 L
.67592 .25 L
.67592 .25 L
.67593 .25 L
.67594 .25 L
.67594 .25 L
.67595 .25 L
.67595 .25 L
.67596 .25 L
.67597 .25 L
.67597 .25 L
.67598 .25 L
.67598 .25 L
.67599 .25 L
.676 .25 L
.676 .25 L
.67601 .25 L
.67602 .25 L
.67602 .25 L
.67603 .25 L
.67603 .25 L
.67604 .25 L
.67604 .25 L
.67604 .25 L
.67605 .25 L
.67606 .25 L
.67606 .25 L
.67607 .25 L
.67608 .25 L
.67608 .25 L
.67609 .25 L
.6761 .25 L
.6761 .25 L
.67611 .25 L
.67612 .25 L
.67612 .25 L
.67613 .25 L
.67613 .25 L
.67614 .25 L
.67615 .25 L
.67615 .25 L
.67616 .25 L
.67616 .25 L
.67617 .25 L
.67617 .25 L
.67618 .25 L
.67618 .25 L
Mistroke
.67618 .25 L
.67619 .25 L
.67619 .25 L
.6762 .25 L
.6762 .25 L
.67621 .25 L
.67621 .25 L
.67621 .25 L
.67622 .25 L
.67622 .25 L
.67623 .25 L
.67623 .25 L
.67624 .25 L
.67625 .25 L
.67625 .25 L
.67626 .25 L
.67627 .25 L
.67627 .25 L
.67628 .25 L
.67628 .25 L
.67629 .25 L
.6763 .25 L
.6763 .25 L
.67631 .25 L
.67632 .25 L
.67632 .25 L
.67632 .25 L
.67633 .25 L
.67634 .25 L
.67634 .25 L
.67635 .25 L
.67636 .25 L
.67636 .25 L
.67637 .25 L
.67637 .25 L
.67638 .25 L
.67638 .25 L
.67639 .25 L
.6764 .25 L
.6764 .25 L
.67641 .25 L
.67642 .25 L
.67642 .25 L
.67642 .25 L
.67643 .25 L
.67644 .25 L
.67644 .25 L
.67645 .25 L
.67646 .25 L
.67646 .25 L
Mistroke
.67647 .25 L
.67647 .25 L
.67648 .25 L
.67649 .25 L
.67649 .25 L
.6765 .25 L
.67651 .25 L
.67651 .25 L
.67652 .25 L
.67652 .25 L
.67653 .25 L
.67653 .25 L
.67654 .25 L
.67655 .25 L
.67655 .25 L
.67656 .25 L
.67656 .25 L
.67657 .25 L
.67658 .25 L
.67658 .25 L
.67659 .25 L
.67659 .25 L
.6766 .25 L
.67661 .25 L
.67661 .25 L
.67662 .25 L
.67662 .25 L
.67663 .25 L
.67663 .25 L
.67664 .25 L
.67664 .25 L
.67665 .25 L
.67665 .25 L
.67666 .25 L
.67666 .25 L
.67667 .25 L
.67668 .25 L
.67668 .25 L
.67669 .25 L
.6767 .25 L
.6767 .25 L
.6767 .25 L
.67671 .25 L
.67671 .25 L
.67672 .25 L
.67672 .25 L
.67673 .25 L
.67674 .25 L
.67674 .25 L
.67675 .25 L
Mistroke
.67675 .25 L
.67676 .25 L
.67677 .25 L
.67677 .25 L
.67678 .25 L
.67678 .25 L
.67679 .25 L
.6768 .25 L
.6768 .25 L
.67681 .25 L
.67681 .25 L
.67682 .25 L
.67683 .25 L
.67683 .25 L
.67684 .25 L
.67685 .25 L
.67685 .25 L
.67686 .25 L
.67686 .25 L
.67687 .25 L
.67687 .25 L
.67688 .25 L
.67688 .25 L
.67689 .25 L
.6769 .25 L
.6769 .25 L
.67691 .25 L
.67691 .25 L
.67692 .25 L
.67693 .25 L
.67693 .25 L
.67694 .25 L
.67695 .25 L
.67695 .25 L
.67696 .25 L
.67697 .25 L
.67697 .25 L
.67698 .25 L
.67698 .25 L
.67699 .25 L
.67699 .25 L
.677 .25 L
.677 .25 L
.677 .25 L
.67701 .25 L
.67701 .25 L
.67702 .25 L
.67702 .25 L
.67703 .25 L
.67703 .25 L
Mistroke
.67703 .25 L
.67704 .25 L
.67704 .25 L
.67704 .25 L
.67705 .25 L
.67706 .25 L
.67706 .25 L
.67707 .25 L
.67708 .25 L
.67708 .25 L
.67709 .25 L
.67709 .25 L
.6771 .25 L
.67711 .25 L
.67711 .25 L
.67712 .25 L
.67713 .25 L
.67713 .25 L
.67714 .25 L
.67714 .25 L
.67715 .25 L
.67715 .25 L
.67716 .25 L
.67717 .25 L
.67717 .25 L
.67718 .25 L
.67719 .25 L
.67719 .25 L
.6772 .25 L
.6772 .25 L
.67721 .25 L
.67721 .25 L
.67722 .25 L
.67723 .25 L
.67723 .25 L
.67724 .25 L
.67724 .25 L
.67725 .25 L
.67725 .25 L
.67726 .25 L
.67727 .25 L
.67727 .25 L
.67728 .25 L
.67729 .25 L
.67729 .25 L
.6773 .25 L
.6773 .25 L
.67731 .25 L
.67732 .25 L
.67732 .25 L
Mistroke
.67733 .25 L
.67734 .25 L
.67734 .25 L
.67735 .25 L
.67735 .25 L
.67736 .25 L
.67736 .25 L
.67737 .25 L
.67738 .25 L
.67738 .25 L
.67739 .25 L
.67739 .25 L
.6774 .25 L
.6774 .25 L
.67741 .25 L
.67742 .25 L
.67742 .25 L
.67743 .25 L
.67744 .25 L
.67744 .25 L
.67745 .25 L
.67745 .25 L
.67746 .25 L
.67746 .25 L
.67747 .25 L
.67747 .25 L
.67748 .25 L
.67748 .25 L
.67749 .25 L
.67749 .25 L
.6775 .25 L
.67751 .25 L
.67751 .25 L
.67752 .25 L
.67752 .25 L
.67753 .25 L
.67753 .25 L
.67754 .25 L
.67754 .25 L
.67755 .25 L
.67755 .25 L
.67756 .25 L
.67757 .25 L
.67757 .25 L
.67758 .25 L
.67758 .25 L
.67759 .25 L
.6776 .25 L
.6776 .25 L
.67761 .25 L
Mistroke
.67761 .25 L
.67762 .25 L
.67763 .25 L
.67763 .25 L
.67764 .25 L
.67765 .25 L
.67765 .25 L
.67766 .25 L
.67766 .25 L
.67767 .25 L
.67768 .25 L
.67768 .25 L
.67768 .25 L
.67769 .25 L
.67769 .25 L
.6777 .25 L
.67771 .25 L
.67771 .25 L
.67772 .25 L
.67773 .25 L
.67773 .25 L
.67774 .25 L
.67774 .25 L
.67775 .25 L
.67776 .25 L
.67776 .25 L
.67777 .25 L
.67778 .25 L
.67778 .25 L
.67779 .25 L
.67779 .25 L
.6778 .25 L
.67781 .25 L
.67781 .25 L
.67782 .25 L
.67782 .25 L
.67782 .25 L
.67783 .25 L
.67783 .25 L
.67784 .25 L
.67784 .25 L
.67784 .25 L
.67785 .25 L
.67785 .25 L
.67786 .25 L
.67786 .25 L
.67786 .25 L
.67787 .25 L
.67787 .25 L
.67788 .25 L
Mistroke
.67789 .25 L
.67789 .25 L
.6779 .25 L
.67791 .25 L
.67791 .25 L
.67792 .25 L
.67792 .25 L
.67793 .25 L
.67794 .25 L
.67794 .25 L
.67795 .25 L
.67796 .25 L
.67796 .25 L
.67797 .25 L
.67797 .25 L
.67798 .25 L
.67798 .25 L
.67799 .25 L
.678 .25 L
.678 .25 L
.67801 .25 L
.67801 .25 L
.67802 .25 L
.67803 .25 L
.67803 .25 L
.67804 .25 L
.67804 .25 L
.67805 .25 L
.67806 .25 L
.67806 .25 L
.67807 .25 L
.67807 .25 L
.67808 .25 L
.67808 .25 L
.67809 .25 L
.6781 .25 L
.6781 .25 L
.67811 .25 L
.67812 .25 L
.67812 .25 L
.67813 .25 L
.67813 .25 L
.67814 .25 L
.67815 .25 L
.67815 .25 L
.67816 .25 L
.67817 .25 L
.67817 .25 L
.67817 .25 L
.67818 .25 L
Mistroke
.67819 .25 L
.67819 .25 L
.6782 .25 L
.67821 .25 L
.67821 .25 L
.67822 .25 L
.67822 .25 L
.67823 .25 L
.67823 .25 L
.67824 .25 L
.67825 .25 L
.67825 .25 L
.67826 .25 L
.67827 .25 L
.67827 .25 L
.67827 .25 L
.67828 .25 L
.67829 .25 L
.67829 .25 L
.6783 .25 L
.6783 .25 L
.6783 .25 L
.67831 .25 L
.67832 .25 L
.67832 .25 L
.67833 .25 L
.67834 .25 L
.67834 .25 L
.67835 .25 L
.67835 .25 L
.67836 .25 L
.67836 .25 L
.67836 .25 L
.67837 .25 L
.67838 .25 L
.67838 .25 L
.67839 .25 L
.6784 .25 L
.6784 .25 L
.67841 .25 L
.67841 .25 L
.67842 .25 L
.67843 .25 L
.67843 .25 L
.67844 .25 L
.67844 .25 L
.67845 .25 L
.67846 .25 L
.67846 .25 L
.67847 .25 L
Mistroke
.67848 .25 L
.67848 .25 L
.67849 .25 L
.67849 .25 L
.6785 .25 L
.6785 .25 L
.67851 .25 L
.67851 .25 L
.67852 .25 L
.67852 .25 L
.67853 .25 L
.67854 .25 L
.67854 .25 L
.67855 .25 L
.67855 .25 L
.67856 .25 L
.67857 .25 L
.67857 .25 L
.67858 .25 L
.67859 .25 L
.67859 .25 L
.6786 .25 L
.67861 .25 L
.67861 .25 L
.67862 .25 L
.67863 .25 L
.67863 .25 L
.67863 .25 L
.67864 .25 L
.67864 .25 L
.67865 .25 L
.67865 .25 L
.67865 .25 L
.67866 .25 L
.67866 .25 L
.67867 .25 L
.67867 .25 L
.67868 .25 L
.67868 .25 L
.67868 .25 L
.67869 .25 L
.67869 .25 L
.6787 .25 L
.6787 .25 L
.67871 .25 L
.67872 .25 L
.67872 .25 L
.67873 .25 L
.67874 .25 L
.67874 .25 L
Mistroke
.67875 .25 L
.67875 .25 L
.67876 .25 L
.67877 .25 L
.67877 .25 L
.67878 .25 L
.67879 .25 L
.67879 .25 L
.67879 .25 L
.6788 .25 L
.67881 .25 L
.67881 .25 L
.67882 .25 L
.67883 .25 L
.67883 .25 L
.67884 .25 L
.67884 .25 L
.67885 .25 L
.67886 .25 L
.67886 .25 L
.67887 .25 L
.67887 .25 L
.67888 .25 L
.67889 .25 L
.67889 .25 L
.67889 .25 L
.6789 .25 L
.67891 .25 L
.67891 .25 L
.67892 .25 L
.67893 .25 L
.67893 .25 L
.67894 .25 L
.67894 .25 L
.67895 .25 L
.67896 .25 L
.67896 .25 L
.67897 .25 L
.67898 .25 L
.67898 .25 L
.67899 .25 L
.67899 .25 L
.679 .25 L
.679 .25 L
.67901 .25 L
.67902 .25 L
.67902 .25 L
.67903 .25 L
.67903 .25 L
.67904 .25 L
Mistroke
.67905 .25 L
.67905 .25 L
.67906 .25 L
.67906 .25 L
.67907 .25 L
.67908 .25 L
.67908 .25 L
.67909 .25 L
.67909 .25 L
.6791 .25 L
.6791 .25 L
.67911 .25 L
.67911 .25 L
.67912 .25 L
.67913 .25 L
.67913 .25 L
.67914 .25 L
.67915 .25 L
.67915 .25 L
.67916 .25 L
.67917 .25 L
.67917 .25 L
.67918 .25 L
.67918 .25 L
.67919 .25 L
.6792 .25 L
.6792 .25 L
.67921 .25 L
.67921 .25 L
.67922 .25 L
.67922 .25 L
.67923 .25 L
.67924 .25 L
.67924 .25 L
.67925 .25 L
.67925 .25 L
.67926 .25 L
.67927 .25 L
.67927 .25 L
.67928 .25 L
.67928 .25 L
.67929 .25 L
.67929 .25 L
.6793 .25 L
.6793 .25 L
.67931 .25 L
.67932 .25 L
.67932 .25 L
.67932 .25 L
.67933 .25 L
Mistroke
.67934 .25 L
.67934 .25 L
.67935 .25 L
.67936 .25 L
.67936 .25 L
.67937 .25 L
.67937 .25 L
.67938 .25 L
.67938 .25 L
.67939 .25 L
.67939 .25 L
.6794 .25 L
.6794 .25 L
.67941 .25 L
.67942 .25 L
.67942 .25 L
.67943 .25 L
.67943 .25 L
.67944 .25 L
.67944 .25 L
.67945 .25 L
.67946 .25 L
.67946 .25 L
.67947 .25 L
.67948 .25 L
.67948 .25 L
.67949 .25 L
.67949 .25 L
.6795 .25 L
.67951 .25 L
.67951 .25 L
.67952 .25 L
.67953 .25 L
.67953 .25 L
.67953 .25 L
.67954 .25 L
.67954 .25 L
.67955 .25 L
.67955 .25 L
.67956 .25 L
.67957 .25 L
.67957 .25 L
.67958 .25 L
.67959 .25 L
.67959 .25 L
.6796 .25 L
.67961 .25 L
.67961 .25 L
.67962 .25 L
.67962 .25 L
Mistroke
.67963 .25 L
.67964 .25 L
.67964 .25 L
.67965 .25 L
.67966 .25 L
.67966 .25 L
.67967 .25 L
.67967 .25 L
.67967 .25 L
.67968 .25 L
.67968 .25 L
.67969 .25 L
.67969 .25 L
.67969 .25 L
.6797 .25 L
.6797 .25 L
.67971 .25 L
.67971 .25 L
.67971 .25 L
.67972 .25 L
.67972 .25 L
.67973 .25 L
.67974 .25 L
.67974 .25 L
.67975 .25 L
.67976 .25 L
.67976 .25 L
.67977 .25 L
.67977 .25 L
.67978 .25 L
.67979 .25 L
.67979 .25 L
.6798 .25 L
.67981 .25 L
.67981 .25 L
.67982 .25 L
.67982 .25 L
.67983 .25 L
.67983 .25 L
.67984 .25 L
.67985 .25 L
.67985 .25 L
.67986 .25 L
.67986 .25 L
.67987 .25 L
.67988 .25 L
.67988 .25 L
.67989 .25 L
.67989 .25 L
.6799 .25 L
Mistroke
.67991 .25 L
.67991 .25 L
.67992 .25 L
.67992 .25 L
.67993 .25 L
.67993 .25 L
.67994 .25 L
.67995 .25 L
.67995 .25 L
.67996 .25 L
.67996 .25 L
.67997 .25 L
.67998 .25 L
.67998 .25 L
.67999 .25 L
.68 .25 L
.68 .25 L
.68001 .25 L
.68002 .25 L
.68002 .25 L
.68002 .25 L
.68003 .25 L
.68004 .25 L
.68004 .25 L
.68005 .25 L
.68006 .25 L
.68006 .25 L
.68007 .25 L
.68007 .25 L
.68008 .25 L
.68008 .25 L
.68009 .25 L
.6801 .25 L
.6801 .25 L
.68011 .25 L
.68012 .25 L
.68012 .25 L
.68012 .25 L
.68013 .25 L
.68014 .25 L
.68014 .25 L
.68015 .25 L
.68015 .25 L
.68015 .25 L
.68016 .25 L
.68017 .25 L
.68017 .25 L
.68018 .25 L
.68019 .25 L
.68019 .25 L
Mistroke
.6802 .25 L
.6802 .25 L
.68021 .25 L
.68021 .25 L
.68021 .25 L
.68022 .25 L
.68023 .25 L
.68023 .25 L
.68024 .25 L
.68025 .25 L
.68025 .25 L
.68026 .25 L
.68026 .25 L
.68027 .25 L
.68028 .25 L
.68028 .25 L
.68029 .25 L
.68029 .25 L
.6803 .25 L
.68031 .25 L
.68031 .25 L
.68032 .25 L
.68033 .25 L
.68033 .25 L
.68034 .25 L
.68034 .25 L
.68035 .25 L
.68035 .25 L
.68036 .25 L
.68036 .25 L
.68037 .25 L
.68037 .25 L
.68038 .25 L
.68039 .25 L
.68039 .25 L
.6804 .25 L
.6804 .25 L
.68041 .25 L
.68042 .25 L
.68042 .25 L
.68043 .25 L
.68044 .25 L
.68044 .25 L
.68045 .25 L
.68046 .25 L
.68046 .25 L
.68047 .25 L
.68048 .25 L
.68048 .25 L
.68048 .25 L
Mistroke
.68049 .25 L
.68049 .25 L
.6805 .25 L
.6805 .25 L
.6805 .25 L
.68051 .25 L
.68051 .25 L
.68052 .25 L
.68052 .25 L
.68053 .25 L
.68053 .25 L
.68053 .25 L
.68054 .25 L
.68054 .25 L
.68055 .25 L
.68055 .25 L
.68056 .25 L
.68057 .25 L
.68057 .25 L
.68058 .25 L
.68059 .25 L
.68059 .25 L
.6806 .25 L
.6806 .25 L
.68061 .25 L
.68062 .25 L
.68062 .25 L
.68063 .25 L
.68064 .25 L
.68064 .25 L
.68064 .25 L
.68065 .25 L
.68066 .25 L
.68066 .25 L
.68067 .25 L
.68068 .25 L
.68068 .25 L
.68069 .25 L
.68069 .25 L
.6807 .25 L
.68071 .25 L
.68071 .25 L
.68072 .25 L
.68072 .25 L
.68073 .25 L
.68074 .25 L
.68074 .25 L
.68074 .25 L
.68075 .25 L
.68076 .25 L
Mistroke
.68076 .25 L
.68077 .25 L
.68078 .25 L
.68078 .25 L
.68079 .25 L
.68079 .25 L
.6808 .25 L
.68081 .25 L
.68081 .25 L
.68082 .25 L
.68083 .25 L
.68083 .25 L
.68084 .25 L
.68084 .25 L
.68085 .25 L
.68085 .25 L
.68086 .25 L
.68087 .25 L
.68087 .25 L
.68088 .25 L
.68089 .25 L
.68089 .25 L
.6809 .25 L
.6809 .25 L
.68091 .25 L
.68091 .25 L
.68092 .25 L
.68093 .25 L
.68093 .25 L
.68094 .25 L
.68094 .25 L
.68095 .25 L
.68095 .25 L
.68096 .25 L
.68097 .25 L
.68097 .25 L
.68097 .25 L
.68098 .25 L
.68099 .25 L
.68099 .25 L
.681 .25 L
.681 .25 L
.68101 .25 L
.68102 .25 L
.68102 .25 L
.68102 .25 L
.68103 .25 L
.68103 .25 L
.68104 .25 L
.68104 .25 L
Mistroke
.68105 .25 L
.68106 .25 L
.68106 .25 L
.68107 .25 L
.68108 .25 L
.68108 .25 L
.68109 .25 L
.68109 .25 L
.6811 .25 L
.68111 .25 L
.68111 .25 L
.68112 .25 L
.68112 .25 L
.68113 .25 L
.68114 .25 L
.68114 .25 L
.68115 .25 L
.68116 .25 L
.68116 .25 L
.68117 .25 L
.68118 .25 L
.68118 .25 L
.68118 .25 L
.68119 .25 L
.68119 .25 L
.6812 .25 L
.6812 .25 L
.68121 .25 L
.68122 .25 L
.68122 .25 L
.68123 .25 L
.68123 .25 L
.68124 .25 L
.68125 .25 L
.68125 .25 L
.68126 .25 L
.68127 .25 L
.68127 .25 L
.68128 .25 L
.68129 .25 L
.68129 .25 L
.6813 .25 L
.6813 .25 L
.68131 .25 L
.68131 .25 L
.68132 .25 L
.68132 .25 L
.68132 .25 L
.68133 .25 L
.68133 .25 L
Mistroke
.68134 .25 L
.68134 .25 L
.68135 .25 L
.68135 .25 L
.68135 .25 L
.68136 .25 L
.68136 .25 L
.68136 .25 L
.68137 .25 L
.68138 .25 L
.68138 .25 L
.68139 .25 L
.6814 .25 L
.6814 .25 L
.68141 .25 L
.68142 .25 L
.68142 .25 L
.68143 .25 L
.68143 .25 L
.68144 .25 L
.68145 .25 L
.68145 .25 L
.68146 .25 L
.68146 .25 L
.68147 .25 L
.68148 .25 L
.68148 .25 L
.68149 .25 L
.68149 .25 L
.6815 .25 L
.68151 .25 L
.68151 .25 L
.68152 .25 L
.68152 .25 L
.68153 .25 L
.68154 .25 L
.68154 .25 L
.68155 .25 L
.68155 .25 L
.68156 .25 L
.68156 .25 L
.68157 .25 L
.68157 .25 L
.68158 .25 L
.68159 .25 L
.68159 .25 L
.6816 .25 L
.68161 .25 L
.68161 .25 L
.68162 .25 L
Mistroke
.68162 .25 L
.68163 .25 L
.68164 .25 L
.68164 .25 L
.68165 .25 L
.68166 .25 L
.68166 .25 L
.68167 .25 L
.68167 .25 L
.68168 .25 L
.68168 .25 L
.68169 .25 L
.6817 .25 L
.6817 .25 L
.68171 .25 L
.68171 .25 L
.68172 .25 L
.68173 .25 L
.68173 .25 L
.68174 .25 L
.68174 .25 L
.68175 .25 L
.68176 .25 L
.68176 .25 L
.68177 .25 L
.68177 .25 L
.68178 .25 L
.68178 .25 L
.68179 .25 L
.68179 .25 L
.6818 .25 L
.6818 .25 L
.68181 .25 L
.68181 .25 L
.68182 .25 L
.68183 .25 L
.68183 .25 L
.68184 .25 L
.68184 .25 L
.68185 .25 L
.68185 .25 L
.68186 .25 L
.68186 .25 L
.68187 .25 L
.68187 .25 L
.68188 .25 L
.68189 .25 L
.68189 .25 L
.6819 .25 L
.6819 .25 L
Mistroke
.68191 .25 L
.68192 .25 L
.68192 .25 L
.68193 .25 L
.68193 .25 L
.68194 .25 L
.68195 .25 L
.68195 .25 L
.68196 .25 L
.68197 .25 L
.68197 .25 L
.68198 .25 L
.68199 .25 L
.68199 .25 L
.682 .25 L
.682 .25 L
.68201 .25 L
.68201 .25 L
.68201 .25 L
.68202 .25 L
.68203 .25 L
.68203 .25 L
.68204 .25 L
.68205 .25 L
.68205 .25 L
.68206 .25 L
.68206 .25 L
.68207 .25 L
.68208 .25 L
.68208 .25 L
.68209 .25 L
.6821 .25 L
.6821 .25 L
.68211 .25 L
.68212 .25 L
.68212 .25 L
.68213 .25 L
.68213 .25 L
.68214 .25 L
.68214 .25 L
.68214 .25 L
.68215 .25 L
.68215 .25 L
.68216 .25 L
.68216 .25 L
.68217 .25 L
.68217 .25 L
.68217 .25 L
.68218 .25 L
.68218 .25 L
Mistroke
.68218 .25 L
.68219 .25 L
.68219 .25 L
.6822 .25 L
.68221 .25 L
.68221 .25 L
.68222 .25 L
.68223 .25 L
.68223 .25 L
.68224 .25 L
.68225 .25 L
.68225 .25 L
.68226 .25 L
.68226 .25 L
.68227 .25 L
.68228 .25 L
.68228 .25 L
.68229 .25 L
.68229 .25 L
.6823 .25 L
.68231 .25 L
.68231 .25 L
.68232 .25 L
.68232 .25 L
.68233 .25 L
.68234 .25 L
.68234 .25 L
.68235 .25 L
.68235 .25 L
.68236 .25 L
.68236 .25 L
.68237 .25 L
.68238 .25 L
.68238 .25 L
.68239 .25 L
.68239 .25 L
.6824 .25 L
.6824 .25 L
.68241 .25 L
.68242 .25 L
.68242 .25 L
.68243 .25 L
.68244 .25 L
.68244 .25 L
.68245 .25 L
.68245 .25 L
.68246 .25 L
.68247 .25 L
.68247 .25 L
.68248 .25 L
Mistroke
.68249 .25 L
.68249 .25 L
.68249 .25 L
.6825 .25 L
.68251 .25 L
.68251 .25 L
.68252 .25 L
.68253 .25 L
.68253 .25 L
.68254 .25 L
.68254 .25 L
.68255 .25 L
.68255 .25 L
.68256 .25 L
.68257 .25 L
.68257 .25 L
.68258 .25 L
.68259 .25 L
.68259 .25 L
.68259 .25 L
.6826 .25 L
.68261 .25 L
.68261 .25 L
.68262 .25 L
.68263 .25 L
.68263 .25 L
.68264 .25 L
.68264 .25 L
.68265 .25 L
.68266 .25 L
.68266 .25 L
.68267 .25 L
.68268 .25 L
.68268 .25 L
.68269 .25 L
.68269 .25 L
.6827 .25 L
.6827 .25 L
.68271 .25 L
.68272 .25 L
.68272 .25 L
.68273 .25 L
.68273 .25 L
.68274 .25 L
.68275 .25 L
.68275 .25 L
.68276 .25 L
.68276 .25 L
.68277 .25 L
.68278 .25 L
Mistroke
.68278 .25 L
.68279 .25 L
.68279 .25 L
.6828 .25 L
.6828 .25 L
.68281 .25 L
.68281 .25 L
.68282 .25 L
.68282 .25 L
.68283 .25 L
.68283 .25 L
.68284 .25 L
.68285 .25 L
.68285 .25 L
.68286 .25 L
.68287 .25 L
.68287 .25 L
.68287 .25 L
.68288 .25 L
.68288 .25 L
.68289 .25 L
.68289 .25 L
.6829 .25 L
.68291 .25 L
.68291 .25 L
.68292 .25 L
.68292 .25 L
.68293 .25 L
.68294 .25 L
.68294 .25 L
.68295 .25 L
.68295 .25 L
.68296 .25 L
.68297 .25 L
.68297 .25 L
.68298 .25 L
.68299 .25 L
.68299 .25 L
.683 .25 L
.683 .25 L
.68301 .25 L
.68302 .25 L
.68302 .25 L
.68303 .25 L
.68303 .25 L
.68304 .25 L
.68304 .25 L
.68305 .25 L
.68305 .25 L
.68306 .25 L
Mistroke
.68307 .25 L
.68307 .25 L
.68308 .25 L
.68308 .25 L
.68309 .25 L
.6831 .25 L
.6831 .25 L
.68311 .25 L
.68312 .25 L
.68312 .25 L
.68313 .25 L
.68314 .25 L
.68314 .25 L
.68315 .25 L
.68315 .25 L
.68316 .25 L
.68316 .25 L
.68317 .25 L
.68317 .25 L
.68317 .25 L
.68318 .25 L
.68318 .25 L
.68319 .25 L
.68319 .25 L
.6832 .25 L
.6832 .25 L
.6832 .25 L
.68321 .25 L
.68321 .25 L
.68321 .25 L
.68322 .25 L
.68323 .25 L
.68323 .25 L
.68324 .25 L
.68325 .25 L
.68325 .25 L
.68326 .25 L
.68327 .25 L
.68327 .25 L
.68328 .25 L
.68328 .25 L
.68329 .25 L
.6833 .25 L
.6833 .25 L
.68331 .25 L
.68331 .25 L
.68332 .25 L
.68333 .25 L
.68333 .25 L
.68334 .25 L
Mistroke
.68334 .25 L
.68335 .25 L
.68336 .25 L
.68336 .25 L
.68337 .25 L
.68337 .25 L
.68338 .25 L
.68338 .25 L
.68339 .25 L
.6834 .25 L
.6834 .25 L
.68341 .25 L
.68341 .25 L
.68342 .25 L
.68342 .25 L
.68343 .25 L
.68344 .25 L
.68344 .25 L
.68345 .25 L
.68346 .25 L
.68346 .25 L
.68347 .25 L
.68347 .25 L
.68348 .25 L
.68349 .25 L
.68349 .25 L
.6835 .25 L
.68351 .25 L
.68351 .25 L
.68352 .25 L
.68352 .25 L
.68353 .25 L
.68353 .25 L
.68354 .25 L
.68355 .25 L
.68355 .25 L
.68356 .25 L
.68356 .25 L
.68357 .25 L
.68358 .25 L
.68358 .25 L
.68359 .25 L
.68359 .25 L
.6836 .25 L
.68361 .25 L
.68361 .25 L
.68362 .25 L
.68362 .25 L
.68363 .25 L
.68363 .25 L
Mistroke
.68364 .25 L
.68364 .25 L
.68365 .25 L
.68365 .25 L
.68366 .25 L
.68366 .25 L
.68367 .25 L
.68368 .25 L
.68368 .25 L
.68369 .25 L
.68369 .25 L
.6837 .25 L
.6837 .25 L
.68371 .25 L
.68371 .25 L
.68372 .25 L
.68372 .25 L
.68373 .25 L
.68374 .25 L
.68374 .25 L
.68375 .25 L
.68375 .25 L
.68376 .25 L
.68377 .25 L
.68377 .25 L
.68378 .25 L
.68378 .25 L
.68379 .25 L
.6838 .25 L
.6838 .25 L
.68381 .25 L
.68382 .25 L
.68382 .25 L
.68383 .25 L
.68384 .25 L
.68384 .25 L
.68385 .25 L
.68385 .25 L
.68386 .25 L
.68386 .25 L
.68386 .25 L
.68387 .25 L
.68388 .25 L
.68388 .25 L
.68389 .25 L
.6839 .25 L
.6839 .25 L
.68391 .25 L
.68391 .25 L
.68392 .25 L
Mistroke
.68393 .25 L
.68393 .25 L
.68394 .25 L
.68395 .25 L
.68395 .25 L
.68396 .25 L
.68397 .25 L
.68397 .25 L
.68398 .25 L
.68398 .25 L
.68399 .25 L
.68399 .25 L
.68399 .25 L
.684 .25 L
.684 .25 L
.68401 .25 L
.68401 .25 L
.68402 .25 L
.68402 .25 L
.68402 .25 L
.68403 .25 L
.68403 .25 L
.68403 .25 L
.68404 .25 L
.68404 .25 L
.68405 .25 L
.68406 .25 L
.68406 .25 L
.68407 .25 L
.68408 .25 L
.68408 .25 L
.68409 .25 L
.6841 .25 L
.6841 .25 L
.68411 .25 L
.68412 .25 L
.68412 .25 L
.68413 .25 L
.68413 .25 L
.68414 .25 L
.68414 .25 L
.68415 .25 L
.68416 .25 L
.68416 .25 L
.68417 .25 L
.68417 .25 L
.68418 .25 L
.68419 .25 L
.68419 .25 L
.6842 .25 L
Mistroke
.6842 .25 L
.68421 .25 L
.68422 .25 L
.68422 .25 L
.68423 .25 L
.68423 .25 L
.68424 .25 L
.68424 .25 L
.68425 .25 L
.68425 .25 L
.68426 .25 L
.68427 .25 L
.68427 .25 L
.68428 .25 L
.68429 .25 L
.68429 .25 L
.6843 .25 L
.6843 .25 L
.68431 .25 L
.68432 .25 L
.68432 .25 L
.68433 .25 L
.68434 .25 L
.68434 .25 L
.68434 .25 L
.68435 .25 L
.68436 .25 L
.68436 .25 L
.68437 .25 L
.68438 .25 L
.68438 .25 L
.68439 .25 L
.68439 .25 L
.6844 .25 L
.68441 .25 L
.68441 .25 L
.68442 .25 L
.68442 .25 L
.68443 .25 L
.68444 .25 L
.68444 .25 L
.68444 .25 L
.68445 .25 L
.68446 .25 L
.68446 .25 L
.68447 .25 L
.68447 .25 L
.68448 .25 L
.68448 .25 L
.68449 .25 L
Mistroke
.68449 .25 L
.6845 .25 L
.68451 .25 L
.68451 .25 L
.68452 .25 L
.68452 .25 L
.68453 .25 L
.68453 .25 L
.68454 .25 L
.68454 .25 L
.68455 .25 L
.68456 .25 L
.68456 .25 L
.68457 .25 L
.68457 .25 L
.68458 .25 L
.68458 .25 L
.68459 .25 L
.6846 .25 L
.6846 .25 L
.68461 .25 L
.68462 .25 L
.68462 .25 L
.68463 .25 L
.68463 .25 L
.68464 .25 L
.68465 .25 L
.68465 .25 L
.68466 .25 L
.68467 .25 L
.68467 .25 L
.68468 .25 L
.68468 .25 L
.68468 .25 L
.68469 .25 L
.68469 .25 L
.6847 .25 L
.68471 .25 L
.68471 .25 L
.68472 .25 L
.68473 .25 L
.68473 .25 L
.68474 .25 L
.68474 .25 L
.68475 .25 L
.68476 .25 L
.68476 .25 L
.68477 .25 L
.68478 .25 L
.68478 .25 L
Mistroke
.68479 .25 L
.6848 .25 L
.6848 .25 L
.6848 .25 L
.68481 .25 L
.68481 .25 L
.68482 .25 L
.68482 .25 L
.68483 .25 L
.68483 .25 L
.68484 .25 L
.68484 .25 L
.68484 .25 L
.68485 .25 L
.68485 .25 L
.68485 .25 L
.68486 .25 L
.68486 .25 L
.68487 .25 L
.68488 .25 L
.68488 .25 L
.68489 .25 L
.6849 .25 L
.6849 .25 L
.68491 .25 L
.68491 .25 L
.68492 .25 L
.68493 .25 L
.68493 .25 L
.68494 .25 L
.68494 .25 L
.68495 .25 L
.68496 .25 L
.68496 .25 L
.68497 .25 L
.68497 .25 L
.68498 .25 L
.68499 .25 L
.68499 .25 L
.685 .25 L
.685 .25 L
.68501 .25 L
.68501 .25 L
.68502 .25 L
.68503 .25 L
.68503 .25 L
.68504 .25 L
.68505 .25 L
.68505 .25 L
.68506 .25 L
Mistroke
.68506 .25 L
.68506 .25 L
.68507 .25 L
.68508 .25 L
.68508 .25 L
.68509 .25 L
.6851 .25 L
.6851 .25 L
.68511 .25 L
.68512 .25 L
.68512 .25 L
.68513 .25 L
.68513 .25 L
.68514 .25 L
.68515 .25 L
.68515 .25 L
.68516 .25 L
.68516 .25 L
.68517 .25 L
.68518 .25 L
.68518 .25 L
.68519 .25 L
.68519 .25 L
.6852 .25 L
.68521 .25 L
.68521 .25 L
.68522 .25 L
.68522 .25 L
.68523 .25 L
.68523 .25 L
.68524 .25 L
.68525 .25 L
.68525 .25 L
.68526 .25 L
.68526 .25 L
.68527 .25 L
.68527 .25 L
.68528 .25 L
.68529 .25 L
.68529 .25 L
.68529 .25 L
.6853 .25 L
.68531 .25 L
.68531 .25 L
.68532 .25 L
.68532 .25 L
.68533 .25 L
.68534 .25 L
.68534 .25 L
.68534 .25 L
Mistroke
.68535 .25 L
.68536 .25 L
.68536 .25 L
.68537 .25 L
.68537 .25 L
.68538 .25 L
.68538 .25 L
.68539 .25 L
.6854 .25 L
.6854 .25 L
.68541 .25 L
.68541 .25 L
.68542 .25 L
.68543 .25 L
.68543 .25 L
.68544 .25 L
.68544 .25 L
.68545 .25 L
.68546 .25 L
.68546 .25 L
.68547 .25 L
.68548 .25 L
.68548 .25 L
.68549 .25 L
.6855 .25 L
.6855 .25 L
.6855 .25 L
.68551 .25 L
.68551 .25 L
.68552 .25 L
.68552 .25 L
.68553 .25 L
.68554 .25 L
.68554 .25 L
.68555 .25 L
.68556 .25 L
.68556 .25 L
.68557 .25 L
.68557 .25 L
.68558 .25 L
.68559 .25 L
.68559 .25 L
.6856 .25 L
.68561 .25 L
.68561 .25 L
.68562 .25 L
.68562 .25 L
.68563 .25 L
.68563 .25 L
.68564 .25 L
Mistroke
.68564 .25 L
.68564 .25 L
.68565 .25 L
.68566 .25 L
.68566 .25 L
.68566 .25 L
.68567 .25 L
.68567 .25 L
.68567 .25 L
.68568 .25 L
.68568 .25 L
.68569 .25 L
.68569 .25 L
.6857 .25 L
.68571 .25 L
.68571 .25 L
.68572 .25 L
.68572 .25 L
.68573 .25 L
.68574 .25 L
.68574 .25 L
.68575 .25 L
.68576 .25 L
.68576 .25 L
.68577 .25 L
.68577 .25 L
.68578 .25 L
.68579 .25 L
.68579 .25 L
.6858 .25 L
.6858 .25 L
.68581 .25 L
.68581 .25 L
.68582 .25 L
.68583 .25 L
.68583 .25 L
.68584 .25 L
.68584 .25 L
.68585 .25 L
.68586 .25 L
.68586 .25 L
.68587 .25 L
.68587 .25 L
.68588 .25 L
.68588 .25 L
.68589 .25 L
.68589 .25 L
.6859 .25 L
.68591 .25 L
.68591 .25 L
Mistroke
.68592 .25 L
.68593 .25 L
.68593 .25 L
.68594 .25 L
.68595 .25 L
.68595 .25 L
.68596 .25 L
.68596 .25 L
.68597 .25 L
.68598 .25 L
.68598 .25 L
.68599 .25 L
.68599 .25 L
.686 .25 L
.68601 .25 L
.68601 .25 L
.68602 .25 L
.68602 .25 L
.68603 .25 L
.68604 .25 L
.68604 .25 L
.68605 .25 L
.68605 .25 L
.68606 .25 L
.68606 .25 L
.68607 .25 L
.68608 .25 L
.68608 .25 L
.68609 .25 L
.68609 .25 L
.6861 .25 L
.6861 .25 L
.68611 .25 L
.68612 .25 L
.68612 .25 L
.68613 .25 L
.68614 .25 L
.68614 .25 L
.68615 .25 L
.68615 .25 L
.68616 .25 L
.68617 .25 L
.68617 .25 L
.68618 .25 L
.68619 .25 L
.68619 .25 L
.68619 .25 L
.6862 .25 L
.68621 .25 L
.68621 .25 L
Mistroke
.68622 .25 L
.68623 .25 L
.68623 .25 L
.68624 .25 L
.68624 .25 L
.68625 .25 L
.68625 .25 L
.68626 .25 L
.68627 .25 L
.68627 .25 L
.68628 .25 L
.68629 .25 L
.68629 .25 L
.68629 .25 L
.6863 .25 L
.68631 .25 L
.68631 .25 L
.68632 .25 L
.68632 .25 L
.68633 .25 L
.68633 .25 L
.68634 .25 L
.68634 .25 L
.68635 .25 L
.68636 .25 L
.68636 .25 L
.68637 .25 L
.68637 .25 L
.68638 .25 L
.68638 .25 L
.68638 .25 L
.68639 .25 L
.6864 .25 L
.6864 .25 L
.68641 .25 L
.68642 .25 L
.68642 .25 L
.68643 .25 L
.68643 .25 L
.68644 .25 L
.68645 .25 L
.68645 .25 L
.68646 .25 L
.68646 .25 L
.68647 .25 L
.68648 .25 L
.68648 .25 L
.68649 .25 L
.6865 .25 L
.6865 .25 L
Mistroke
.68651 .25 L
.68652 .25 L
.68652 .25 L
.68653 .25 L
.68653 .25 L
.68653 .25 L
.68654 .25 L
.68654 .25 L
.68655 .25 L
.68656 .25 L
.68656 .25 L
.68657 .25 L
.68658 .25 L
.68658 .25 L
.68659 .25 L
.68659 .25 L
.6866 .25 L
.68661 .25 L
.68661 .25 L
.68662 .25 L
.68663 .25 L
.68663 .25 L
.68664 .25 L
.68665 .25 L
.68665 .25 L
.68665 .25 L
.68666 .25 L
.68666 .25 L
.68667 .25 L
.68667 .25 L
.68668 .25 L
.68668 .25 L
.68669 .25 L
.68669 .25 L
.68669 .25 L
.6867 .25 L
.6867 .25 L
.6867 .25 L
.68671 .25 L
.68671 .25 L
.68672 .25 L
.68673 .25 L
.68673 .25 L
.68674 .25 L
.68675 .25 L
.68675 .25 L
.68676 .25 L
.68676 .25 L
.68677 .25 L
.68678 .25 L
Mistroke
.68678 .25 L
.68679 .25 L
.68679 .25 L
.6868 .25 L
.68681 .25 L
.68681 .25 L
.68682 .25 L
.68682 .25 L
.68683 .25 L
.68684 .25 L
.68684 .25 L
.68685 .25 L
.68685 .25 L
.68686 .25 L
.68686 .25 L
.68687 .25 L
.68688 .25 L
.68688 .25 L
.68689 .25 L
.6869 .25 L
.6869 .25 L
.68691 .25 L
.68691 .25 L
.68691 .25 L
.68692 .25 L
.68693 .25 L
.68693 .25 L
.68694 .25 L
.68695 .25 L
.68695 .25 L
.68696 .25 L
.68697 .25 L
.68697 .25 L
.68698 .25 L
.68698 .25 L
.68699 .25 L
.687 .25 L
.687 .25 L
.68701 .25 L
.68701 .25 L
.68702 .25 L
.68703 .25 L
.68703 .25 L
.68704 .25 L
.68704 .25 L
.68705 .25 L
.68706 .25 L
.68706 .25 L
.68707 .25 L
.68707 .25 L
Mistroke
.68708 .25 L
.68709 .25 L
.68709 .25 L
.6871 .25 L
.6871 .25 L
.68711 .25 L
.68711 .25 L
.68712 .25 L
.68712 .25 L
.68713 .25 L
.68714 .25 L
.68714 .25 L
.68714 .25 L
.68715 .25 L
.68716 .25 L
.68716 .25 L
.68717 .25 L
.68717 .25 L
.68718 .25 L
.68719 .25 L
.68719 .25 L
.68719 .25 L
.6872 .25 L
.68721 .25 L
.68721 .25 L
.68722 .25 L
.68722 .25 L
.68723 .25 L
.68723 .25 L
.68724 .25 L
.68725 .25 L
.68725 .25 L
.68726 .25 L
.68726 .25 L
.68727 .25 L
.68728 .25 L
.68728 .25 L
.68729 .25 L
.6873 .25 L
.6873 .25 L
.68731 .25 L
.68731 .25 L
.68732 .25 L
.68733 .25 L
.68733 .25 L
.68734 .25 L
.68735 .25 L
.68735 .25 L
.68735 .25 L
.68736 .25 L
Mistroke
.68736 .25 L
.68737 .25 L
.68737 .25 L
.68738 .25 L
.68739 .25 L
.68739 .25 L
.6874 .25 L
.68741 .25 L
.68741 .25 L
.68742 .25 L
.68742 .25 L
.68743 .25 L
.68744 .25 L
.68744 .25 L
.68745 .25 L
.68746 .25 L
.68746 .25 L
.68747 .25 L
.68747 .25 L
.68748 .25 L
.68748 .25 L
.68749 .25 L
.68749 .25 L
.6875 .25 L
.6875 .25 L
.68751 .25 L
.68751 .25 L
.68751 .25 L
.68752 .25 L
.68752 .25 L
.68752 .25 L
.68753 .25 L
.68753 .25 L
.68754 .25 L
.68754 .25 L
.68755 .25 L
.68756 .25 L
.68756 .25 L
.68757 .25 L
.68758 .25 L
.68758 .25 L
.68759 .25 L
.68759 .25 L
.6876 .25 L
.68761 .25 L
.68761 .25 L
.68762 .25 L
.68763 .25 L
.68763 .25 L
.68764 .25 L
Mistroke
.68764 .25 L
.68765 .25 L
.68765 .25 L
.68766 .25 L
.68767 .25 L
.68767 .25 L
.68768 .25 L
.68768 .25 L
.68769 .25 L
.68769 .25 L
.6877 .25 L
.68771 .25 L
.68771 .25 L
.68772 .25 L
.68772 .25 L
.68773 .25 L
.68774 .25 L
.68774 .25 L
.68774 .25 L
.68775 .25 L
.68776 .25 L
.68776 .25 L
.68777 .25 L
.68778 .25 L
.68778 .25 L
.68779 .25 L
.6878 .25 L
.6878 .25 L
.68781 .25 L
.68782 .25 L
.68782 .25 L
.68783 .25 L
.68783 .25 L
.68784 .25 L
.68784 .25 L
.68785 .25 L
.68786 .25 L
.68786 .25 L
.68787 .25 L
.68787 .25 L
.68788 .25 L
.68789 .25 L
.68789 .25 L
.6879 .25 L
.6879 .25 L
.68791 .25 L
.68792 .25 L
.68792 .25 L
.68793 .25 L
.68793 .25 L
Mistroke
.68794 .25 L
.68794 .25 L
.68795 .25 L
.68795 .25 L
.68796 .25 L
.68796 .25 L
.68797 .25 L
.68797 .25 L
.68798 .25 L
.68799 .25 L
.68799 .25 L
.688 .25 L
.688 .25 L
.68801 .25 L
.68801 .25 L
.68802 .25 L
.68803 .25 L
.68803 .25 L
.68803 .25 L
.68804 .25 L
.68805 .25 L
.68805 .25 L
.68806 .25 L
.68806 .25 L
.68807 .25 L
.68808 .25 L
.68808 .25 L
.68809 .25 L
.68809 .25 L
.6881 .25 L
.68811 .25 L
.68811 .25 L
.68812 .25 L
.68812 .25 L
.68813 .25 L
.68814 .25 L
.68814 .25 L
.68815 .25 L
.68816 .25 L
.68816 .25 L
.68817 .25 L
.68817 .25 L
.68818 .25 L
.68818 .25 L
.68818 .25 L
.68819 .25 L
.6882 .25 L
.6882 .25 L
.68821 .25 L
.68822 .25 L
Mistroke
.68822 .25 L
.68823 .25 L
.68824 .25 L
.68824 .25 L
.68825 .25 L
.68826 .25 L
.68826 .25 L
.68827 .25 L
.68827 .25 L
.68828 .25 L
.68829 .25 L
.68829 .25 L
.6883 .25 L
.6883 .25 L
.68831 .25 L
.68831 .25 L
.68832 .25 L
.68832 .25 L
.68832 .25 L
.68833 .25 L
.68833 .25 L
.68834 .25 L
.68834 .25 L
.68835 .25 L
.68835 .25 L
.68835 .25 L
.68836 .25 L
.68836 .25 L
.68837 .25 L
.68837 .25 L
.68838 .25 L
.68839 .25 L
.68839 .25 L
.6884 .25 L
.68841 .25 L
.68841 .25 L
.68842 .25 L
.68842 .25 L
.68843 .25 L
.68844 .25 L
.68844 .25 L
.68845 .25 L
.68846 .25 L
.68846 .25 L
.68846 .25 L
.68847 .25 L
.68848 .25 L
.68848 .25 L
.68849 .25 L
.6885 .25 L
Mistroke
.6885 .25 L
.68851 .25 L
.68851 .25 L
.68852 .25 L
.68852 .25 L
.68853 .25 L
.68854 .25 L
.68854 .25 L
.68855 .25 L
.68856 .25 L
.68856 .25 L
.68856 .25 L
.68857 .25 L
.68858 .25 L
.68858 .25 L
.68859 .25 L
.6886 .25 L
.6886 .25 L
.68861 .25 L
.68861 .25 L
.68862 .25 L
.68863 .25 L
.68863 .25 L
.68864 .25 L
.68865 .25 L
.68865 .25 L
.68866 .25 L
.68866 .25 L
.68867 .25 L
.68867 .25 L
.68868 .25 L
.68869 .25 L
.68869 .25 L
.6887 .25 L
.6887 .25 L
.68871 .25 L
.68871 .25 L
.68872 .25 L
.68873 .25 L
.68873 .25 L
.68874 .25 L
.68875 .25 L
.68875 .25 L
.68876 .25 L
.68876 .25 L
.68876 .25 L
.68877 .25 L
.68878 .25 L
.68878 .25 L
.68879 .25 L
Mistroke
.68879 .25 L
.6888 .25 L
.6888 .25 L
.68881 .25 L
.68882 .25 L
.68882 .25 L
.68883 .25 L
.68883 .25 L
.68884 .25 L
.68884 .25 L
.68885 .25 L
.68885 .25 L
.68886 .25 L
.68886 .25 L
.68887 .25 L
.68888 .25 L
.68888 .25 L
.68889 .25 L
.68889 .25 L
.6889 .25 L
.6889 .25 L
.68891 .25 L
.68892 .25 L
.68892 .25 L
.68893 .25 L
.68894 .25 L
.68894 .25 L
.68895 .25 L
.68895 .25 L
.68896 .25 L
.68897 .25 L
.68897 .25 L
.68898 .25 L
.68899 .25 L
.68899 .25 L
.689 .25 L
.689 .25 L
.689 .25 L
.68901 .25 L
.68901 .25 L
.68902 .25 L
.68903 .25 L
.68903 .25 L
.68904 .25 L
.68905 .25 L
.68905 .25 L
.68906 .25 L
.68907 .25 L
.68907 .25 L
.68908 .25 L
Mistroke
.68908 .25 L
.68909 .25 L
.6891 .25 L
.6891 .25 L
.68911 .25 L
.68912 .25 L
.68912 .25 L
.68913 .25 L
.68913 .25 L
.68914 .25 L
.68914 .25 L
.68914 .25 L
.68915 .25 L
.68915 .25 L
.68916 .25 L
.68916 .25 L
.68916 .25 L
.68917 .25 L
.68917 .25 L
.68918 .25 L
.68918 .25 L
.68918 .25 L
.68919 .25 L
.6892 .25 L
.6892 .25 L
.68921 .25 L
.68922 .25 L
.68922 .25 L
.68923 .25 L
.68923 .25 L
.68924 .25 L
.68925 .25 L
.68925 .25 L
.68926 .25 L
.68927 .25 L
.68927 .25 L
.68928 .25 L
.68928 .25 L
.68929 .25 L
.68929 .25 L
.6893 .25 L
.68931 .25 L
.68931 .25 L
.68932 .25 L
.68933 .25 L
.68933 .25 L
.68934 .25 L
.68934 .25 L
.68935 .25 L
.68935 .25 L
Mistroke
.68936 .25 L
.68937 .25 L
.68937 .25 L
.68938 .25 L
.68938 .25 L
.68939 .25 L
.68939 .25 L
.6894 .25 L
.6894 .25 L
.68941 .25 L
.68942 .25 L
.68942 .25 L
.68943 .25 L
.68944 .25 L
.68944 .25 L
.68945 .25 L
.68946 .25 L
.68946 .25 L
.68947 .25 L
.68947 .25 L
.68948 .25 L
.68949 .25 L
.68949 .25 L
.6895 .25 L
.6895 .25 L
.68951 .25 L
.68951 .25 L
.68952 .25 L
.68953 .25 L
.68953 .25 L
.68954 .25 L
.68954 .25 L
.68955 .25 L
.68956 .25 L
.68956 .25 L
.68957 .25 L
.68957 .25 L
.68958 .25 L
.68958 .25 L
.68959 .25 L
.68959 .25 L
.6896 .25 L
.68961 .25 L
.68961 .25 L
.68962 .25 L
.68963 .25 L
.68963 .25 L
.68964 .25 L
.68965 .25 L
.68965 .25 L
Mistroke
.68966 .25 L
.68967 .25 L
.68967 .25 L
.68968 .25 L
.68968 .25 L
.68969 .25 L
.68969 .25 L
.6897 .25 L
.68971 .25 L
.68971 .25 L
.68972 .25 L
.68972 .25 L
.68973 .25 L
.68974 .25 L
.68974 .25 L
.68975 .25 L
.68975 .25 L
.68976 .25 L
.68977 .25 L
.68977 .25 L
.68978 .25 L
.68978 .25 L
.68979 .25 L
.68979 .25 L
.6898 .25 L
.6898 .25 L
.68981 .25 L
.68981 .25 L
.68982 .25 L
.68982 .25 L
.68983 .25 L
.68984 .25 L
.68984 .25 L
.68985 .25 L
.68985 .25 L
.68986 .25 L
.68986 .25 L
.68987 .25 L
.68988 .25 L
.68988 .25 L
.68988 .25 L
.68989 .25 L
.6899 .25 L
.6899 .25 L
.68991 .25 L
.68991 .25 L
.68992 .25 L
.68993 .25 L
.68993 .25 L
.68994 .25 L
Mistroke
.68994 .25 L
.68995 .25 L
.68996 .25 L
.68996 .25 L
.68997 .25 L
.68997 .25 L
.68998 .25 L
.68999 .25 L
.68999 .25 L
.69 .25 L
.69001 .25 L
.69001 .25 L
.69002 .25 L
.69002 .25 L
.69003 .25 L
.69003 .25 L
.69003 .25 L
.69004 .25 L
.69005 .25 L
.69005 .25 L
.69006 .25 L
.69007 .25 L
.69007 .25 L
.69008 .25 L
.69009 .25 L
.69009 .25 L
.6901 .25 L
.6901 .25 L
.69011 .25 L
.69012 .25 L
.69012 .25 L
.69013 .25 L
.69014 .25 L
.69014 .25 L
.69015 .25 L
.69015 .25 L
.69016 .25 L
.69016 .25 L
.69017 .25 L
.69017 .25 L
.69017 .25 L
.69018 .25 L
.69018 .25 L
.69019 .25 L
.69019 .25 L
.6902 .25 L
.6902 .25 L
.6902 .25 L
.69021 .25 L
.69021 .25 L
Mistroke
.69022 .25 L
.69022 .25 L
.69023 .25 L
.69024 .25 L
.69024 .25 L
.69025 .25 L
.69026 .25 L
.69026 .25 L
.69027 .25 L
.69027 .25 L
.69028 .25 L
.69029 .25 L
.69029 .25 L
.6903 .25 L
.69031 .25 L
.69031 .25 L
.69031 .25 L
.69032 .25 L
.69033 .25 L
.69033 .25 L
.69034 .25 L
.69035 .25 L
.69035 .25 L
.69036 .25 L
.69036 .25 L
.69037 .25 L
.69037 .25 L
.69038 .25 L
.69039 .25 L
.69039 .25 L
.6904 .25 L
.69041 .25 L
.69041 .25 L
.69041 .25 L
.69042 .25 L
.69043 .25 L
.69043 .25 L
.69044 .25 L
.69045 .25 L
.69045 .25 L
.69046 .25 L
.69046 .25 L
.69047 .25 L
.69048 .25 L
.69048 .25 L
.69049 .25 L
.6905 .25 L
.6905 .25 L
.69051 .25 L
.69051 .25 L
Mistroke
.69052 .25 L
.69052 .25 L
.69053 .25 L
.69054 .25 L
.69054 .25 L
.69055 .25 L
.69055 .25 L
.69056 .25 L
.69057 .25 L
.69057 .25 L
.69058 .25 L
.69058 .25 L
.69059 .25 L
.6906 .25 L
.6906 .25 L
.69061 .25 L
.69061 .25 L
.69061 .25 L
.69062 .25 L
.69063 .25 L
.69063 .25 L
.69064 .25 L
.69064 .25 L
.69065 .25 L
.69065 .25 L
.69066 .25 L
.69067 .25 L
.69067 .25 L
.69068 .25 L
.69069 .25 L
.69069 .25 L
.69069 .25 L
.6907 .25 L
.6907 .25 L
.69071 .25 L
.69071 .25 L
.69072 .25 L
.69073 .25 L
.69073 .25 L
.69074 .25 L
.69074 .25 L
.69075 .25 L
.69076 .25 L
.69076 .25 L
.69077 .25 L
.69077 .25 L
.69078 .25 L
.69079 .25 L
.69079 .25 L
.6908 .25 L
Mistroke
.6908 .25 L
.69081 .25 L
.69082 .25 L
.69082 .25 L
.69083 .25 L
.69084 .25 L
.69084 .25 L
.69085 .25 L
.69085 .25 L
.69086 .25 L
.69086 .25 L
.69087 .25 L
.69087 .25 L
.69088 .25 L
.69089 .25 L
.69089 .25 L
.6909 .25 L
.6909 .25 L
.69091 .25 L
.69092 .25 L
.69092 .25 L
.69093 .25 L
.69094 .25 L
.69094 .25 L
.69095 .25 L
.69096 .25 L
.69096 .25 L
.69097 .25 L
.69097 .25 L
.69098 .25 L
.69098 .25 L
.69099 .25 L
.69099 .25 L
.69099 .25 L
.691 .25 L
.691 .25 L
.69101 .25 L
.69101 .25 L
.69101 .25 L
.69102 .25 L
.69102 .25 L
.69103 .25 L
.69103 .25 L
.69103 .25 L
.69104 .25 L
.69105 .25 L
.69105 .25 L
.69106 .25 L
.69107 .25 L
.69107 .25 L
Mistroke
.69108 .25 L
.69108 .25 L
.69109 .25 L
.6911 .25 L
.6911 .25 L
.69111 .25 L
.69112 .25 L
.69112 .25 L
.69113 .25 L
.69113 .25 L
.69114 .25 L
.69114 .25 L
.69115 .25 L
.69116 .25 L
.69116 .25 L
.69117 .25 L
.69118 .25 L
.69118 .25 L
.69119 .25 L
.69119 .25 L
.6912 .25 L
.6912 .25 L
.69121 .25 L
.69122 .25 L
.69122 .25 L
.69123 .25 L
.69123 .25 L
.69124 .25 L
.69124 .25 L
.69125 .25 L
.69126 .25 L
.69126 .25 L
.69127 .25 L
.69128 .25 L
.69128 .25 L
.69129 .25 L
.69129 .25 L
.6913 .25 L
.69131 .25 L
.69131 .25 L
.69132 .25 L
.69133 .25 L
.69133 .25 L
.69134 .25 L
.69134 .25 L
.69135 .25 L
.69135 .25 L
.69136 .25 L
.69137 .25 L
.69137 .25 L
Mistroke
.69138 .25 L
.69138 .25 L
.69139 .25 L
.6914 .25 L
.6914 .25 L
.69141 .25 L
.69141 .25 L
.69142 .25 L
.69143 .25 L
.69143 .25 L
.69144 .25 L
.69144 .25 L
.69145 .25 L
.69145 .25 L
.69146 .25 L
.69146 .25 L
.69147 .25 L
.69147 .25 L
.69148 .25 L
.69148 .25 L
.69149 .25 L
.6915 .25 L
.6915 .25 L
.69151 .25 L
.69151 .25 L
.69152 .25 L
.69152 .25 L
.69153 .25 L
.69153 .25 L
.69154 .25 L
.69154 .25 L
.69155 .25 L
.69156 .25 L
.69156 .25 L
.69157 .25 L
.69157 .25 L
.69158 .25 L
.69159 .25 L
.69159 .25 L
.6916 .25 L
.6916 .25 L
.69161 .25 L
.69162 .25 L
.69162 .25 L
.69163 .25 L
.69164 .25 L
.69164 .25 L
.69165 .25 L
.69165 .25 L
.69166 .25 L
Mistroke
.69167 .25 L
.69167 .25 L
.69168 .25 L
.69168 .25 L
.69168 .25 L
.69169 .25 L
.6917 .25 L
.6917 .25 L
.69171 .25 L
.69172 .25 L
.69172 .25 L
.69173 .25 L
.69173 .25 L
.69174 .25 L
.69175 .25 L
.69175 .25 L
.69176 .25 L
.69177 .25 L
.69177 .25 L
.69178 .25 L
.69178 .25 L
.69179 .25 L
.6918 .25 L
.6918 .25 L
.69181 .25 L
.69181 .25 L
.69181 .25 L
.69182 .25 L
.69182 .25 L
.69183 .25 L
.69183 .25 L
.69183 .25 L
.69184 .25 L
.69184 .25 L
.69185 .25 L
.69185 .25 L
.69185 .25 L
.69186 .25 L
.69186 .25 L
.69187 .25 L
.69188 .25 L
.69188 .25 L
.69189 .25 L
.6919 .25 L
.6919 .25 L
.69191 .25 L
.69192 .25 L
.69192 .25 L
.69193 .25 L
.69193 .25 L
Mistroke
.69194 .25 L
.69195 .25 L
.69195 .25 L
.69196 .25 L
.69196 .25 L
.69197 .25 L
.69198 .25 L
.69198 .25 L
.69199 .25 L
.69199 .25 L
.692 .25 L
.69201 .25 L
.69201 .25 L
.69202 .25 L
.69202 .25 L
.69203 .25 L
.69203 .25 L
.69204 .25 L
.69205 .25 L
.69205 .25 L
.69206 .25 L
.69206 .25 L
.69207 .25 L
.69207 .25 L
.69208 .25 L
.69209 .25 L
.69209 .25 L
.6921 .25 L
.69211 .25 L
.69211 .25 L
.69212 .25 L
.69212 .25 L
.69213 .25 L
.69214 .25 L
.69214 .25 L
.69215 .25 L
.69216 .25 L
.69216 .25 L
.69216 .25 L
.69217 .25 L
.69218 .25 L
.69218 .25 L
.69219 .25 L
.6922 .25 L
.6922 .25 L
.69221 .25 L
.69221 .25 L
.69222 .25 L
.69222 .25 L
.69223 .25 L
Mistroke
.69224 .25 L
.69224 .25 L
.69225 .25 L
.69226 .25 L
.69226 .25 L
.69226 .25 L
.69227 .25 L
.69228 .25 L
.69228 .25 L
.69229 .25 L
.69229 .25 L
.6923 .25 L
.6923 .25 L
.69231 .25 L
.69231 .25 L
.69232 .25 L
.69233 .25 L
.69233 .25 L
.69234 .25 L
.69234 .25 L
.69235 .25 L
.69235 .25 L
.69235 .25 L
.69236 .25 L
.69237 .25 L
.69237 .25 L
.69238 .25 L
.69239 .25 L
.69239 .25 L
.6924 .25 L
.6924 .25 L
.69241 .25 L
.69242 .25 L
.69242 .25 L
.69243 .25 L
.69243 .25 L
.69244 .25 L
.69245 .25 L
.69245 .25 L
.69246 .25 L
.69247 .25 L
.69247 .25 L
.69248 .25 L
.69249 .25 L
.69249 .25 L
.6925 .25 L
.6925 .25 L
.6925 .25 L
.69251 .25 L
.69251 .25 L
Mistroke
.69252 .25 L
.69253 .25 L
.69253 .25 L
.69254 .25 L
.69255 .25 L
.69255 .25 L
.69256 .25 L
.69256 .25 L
.69257 .25 L
.69258 .25 L
.69258 .25 L
.69259 .25 L
.6926 .25 L
.6926 .25 L
.69261 .25 L
.69262 .25 L
.69262 .25 L
.69262 .25 L
.69263 .25 L
.69263 .25 L
.69264 .25 L
.69264 .25 L
.69264 .25 L
.69265 .25 L
.69265 .25 L
.69266 .25 L
.69266 .25 L
.69267 .25 L
.69267 .25 L
.69267 .25 L
.69268 .25 L
.69268 .25 L
.69269 .25 L
.69269 .25 L
.6927 .25 L
.69271 .25 L
.69271 .25 L
.69272 .25 L
.69273 .25 L
.69273 .25 L
.69274 .25 L
.69274 .25 L
.69275 .25 L
.69276 .25 L
.69276 .25 L
.69277 .25 L
.69278 .25 L
.69278 .25 L
.69279 .25 L
.69279 .25 L
Mistroke
.6928 .25 L
.6928 .25 L
.69281 .25 L
.69282 .25 L
.69282 .25 L
.69283 .25 L
.69283 .25 L
.69284 .25 L
.69285 .25 L
.69285 .25 L
.69286 .25 L
.69286 .25 L
.69287 .25 L
.69288 .25 L
.69288 .25 L
.69288 .25 L
.69289 .25 L
.6929 .25 L
.6929 .25 L
.69291 .25 L
.69292 .25 L
.69292 .25 L
.69293 .25 L
.69293 .25 L
.69294 .25 L
.69295 .25 L
.69295 .25 L
.69296 .25 L
.69297 .25 L
.69297 .25 L
.69298 .25 L
.69298 .25 L
.69299 .25 L
.69299 .25 L
.693 .25 L
.69301 .25 L
.69301 .25 L
.69302 .25 L
.69303 .25 L
.69303 .25 L
.69304 .25 L
.69304 .25 L
.69305 .25 L
.69305 .25 L
.69306 .25 L
.69307 .25 L
.69307 .25 L
.69308 .25 L
.69308 .25 L
.69309 .25 L
Mistroke
.69309 .25 L
.6931 .25 L
.69311 .25 L
.69311 .25 L
.69311 .25 L
.69312 .25 L
.69313 .25 L
.69313 .25 L
.69314 .25 L
.69314 .25 L
.69315 .25 L
.69316 .25 L
.69316 .25 L
.69316 .25 L
.69317 .25 L
.69317 .25 L
.69318 .25 L
.69318 .25 L
.69319 .25 L
.6932 .25 L
.6932 .25 L
.69321 .25 L
.69322 .25 L
.69322 .25 L
.69323 .25 L
.69323 .25 L
.69324 .25 L
.69325 .25 L
.69325 .25 L
.69326 .25 L
.69326 .25 L
.69327 .25 L
.69328 .25 L
.69328 .25 L
.69329 .25 L
.6933 .25 L
.6933 .25 L
.69331 .25 L
.69332 .25 L
.69332 .25 L
.69332 .25 L
.69333 .25 L
.69333 .25 L
.69334 .25 L
.69334 .25 L
.69335 .25 L
.69336 .25 L
.69336 .25 L
.69337 .25 L
.69337 .25 L
Mistroke
.69338 .25 L
.69339 .25 L
.69339 .25 L
.6934 .25 L
.69341 .25 L
.69341 .25 L
.69342 .25 L
.69343 .25 L
.69343 .25 L
.69344 .25 L
.69344 .25 L
.69345 .25 L
.69345 .25 L
.69346 .25 L
.69346 .25 L
.69346 .25 L
.69347 .25 L
.69347 .25 L
.69348 .25 L
.69348 .25 L
.69349 .25 L
.69349 .25 L
.69349 .25 L
.6935 .25 L
.6935 .25 L
.6935 .25 L
.69351 .25 L
.69352 .25 L
.69352 .25 L
.69353 .25 L
.69354 .25 L
.69354 .25 L
.69355 .25 L
.69356 .25 L
.69356 .25 L
.69357 .25 L
.69357 .25 L
.69358 .25 L
.69359 .25 L
.69359 .25 L
.6936 .25 L
.6936 .25 L
.69361 .25 L
.69362 .25 L
.69362 .25 L
.69363 .25 L
.69363 .25 L
.69364 .25 L
.69365 .25 L
.69365 .25 L
Mistroke
.69366 .25 L
.69366 .25 L
.69367 .25 L
.69367 .25 L
.69368 .25 L
.69369 .25 L
.69369 .25 L
.6937 .25 L
.6937 .25 L
.69371 .25 L
.69371 .25 L
.69372 .25 L
.69373 .25 L
.69373 .25 L
.69374 .25 L
.69375 .25 L
.69375 .25 L
.69376 .25 L
.69376 .25 L
.69377 .25 L
.69378 .25 L
.69378 .25 L
.69379 .25 L
.6938 .25 L
.6938 .25 L
.69381 .25 L
.69381 .25 L
.69382 .25 L
.69382 .25 L
.69383 .25 L
.69384 .25 L
.69384 .25 L
.69385 .25 L
.69385 .25 L
.69386 .25 L
.69387 .25 L
.69387 .25 L
.69388 .25 L
.69388 .25 L
.69389 .25 L
.6939 .25 L
.6939 .25 L
.69391 .25 L
.69391 .25 L
.69392 .25 L
.69392 .25 L
.69393 .25 L
.69394 .25 L
.69394 .25 L
.69395 .25 L
Mistroke
.69395 .25 L
.69396 .25 L
.69397 .25 L
.69397 .25 L
.69398 .25 L
.69399 .25 L
.69399 .25 L
.694 .25 L
.69401 .25 L
.69401 .25 L
.69401 .25 L
.69402 .25 L
.69403 .25 L
.69403 .25 L
.69404 .25 L
.69405 .25 L
.69405 .25 L
.69406 .25 L
.69406 .25 L
.69407 .25 L
.69407 .25 L
.69408 .25 L
.69409 .25 L
.69409 .25 L
.6941 .25 L
.6941 .25 L
.69411 .25 L
.69411 .25 L
.69412 .25 L
.69412 .25 L
.69413 .25 L
.69413 .25 L
.69414 .25 L
.69414 .25 L
.69415 .25 L
.69416 .25 L
.69416 .25 L
.69417 .25 L
.69418 .25 L
.69418 .25 L
.69419 .25 L
.69419 .25 L
.6942 .25 L
.6942 .25 L
.6942 .25 L
.69421 .25 L
.69422 .25 L
.69422 .25 L
.69423 .25 L
.69424 .25 L
Mistroke
.69424 .25 L
.69425 .25 L
.69425 .25 L
.69426 .25 L
.69427 .25 L
.69427 .25 L
.69428 .25 L
.69428 .25 L
.69429 .25 L
.6943 .25 L
.6943 .25 L
.69431 .25 L
.69432 .25 L
.69432 .25 L
.69433 .25 L
.69433 .25 L
.69434 .25 L
.69434 .25 L
.69435 .25 L
.69435 .25 L
.69436 .25 L
.69436 .25 L
.69437 .25 L
.69438 .25 L
.69438 .25 L
.69439 .25 L
.69439 .25 L
.6944 .25 L
.69441 .25 L
.69441 .25 L
.69442 .25 L
.69443 .25 L
.69443 .25 L
.69444 .25 L
.69445 .25 L
.69445 .25 L
.69446 .25 L
.69447 .25 L
.69447 .25 L
.69447 .25 L
.69448 .25 L
.69448 .25 L
.69449 .25 L
.69449 .25 L
.69449 .25 L
.6945 .25 L
.6945 .25 L
.69451 .25 L
.69451 .25 L
.69452 .25 L
Mistroke
.69452 .25 L
.69452 .25 L
.69453 .25 L
.69453 .25 L
.69454 .25 L
.69454 .25 L
.69455 .25 L
.69456 .25 L
.69456 .25 L
.69457 .25 L
.69458 .25 L
.69458 .25 L
.69459 .25 L
.69459 .25 L
.6946 .25 L
.69461 .25 L
.69461 .25 L
.69462 .25 L
.69463 .25 L
.69463 .25 L
.69463 .25 L
.69464 .25 L
.69465 .25 L
.69465 .25 L
.69466 .25 L
.69467 .25 L
.69467 .25 L
.69468 .25 L
.69468 .25 L
.69469 .25 L
.6947 .25 L
.6947 .25 L
.69471 .25 L
.69471 .25 L
.69472 .25 L
.69473 .25 L
.69473 .25 L
.69473 .25 L
.69474 .25 L
.69475 .25 L
.69475 .25 L
.69476 .25 L
.69477 .25 L
.69477 .25 L
.69478 .25 L
.69478 .25 L
.69479 .25 L
.6948 .25 L
.6948 .25 L
.69481 .25 L
Mistroke
.69482 .25 L
.69482 .25 L
.69483 .25 L
.69483 .25 L
.69484 .25 L
.69484 .25 L
.69485 .25 L
.69486 .25 L
.69486 .25 L
.69487 .25 L
.69488 .25 L
.69488 .25 L
.69489 .25 L
.69489 .25 L
.6949 .25 L
.6949 .25 L
.69491 .25 L
.69492 .25 L
.69492 .25 L
.69493 .25 L
.69493 .25 L
.69494 .25 L
.69494 .25 L
.69495 .25 L
.69496 .25 L
.69496 .25 L
.69496 .25 L
.69497 .25 L
.69498 .25 L
.69498 .25 L
.69499 .25 L
.69499 .25 L
.695 .25 L
.69501 .25 L
.69501 .25 L
.69501 .25 L
.69502 .25 L
.69502 .25 L
.69503 .25 L
.69503 .25 L
.69504 .25 L
.69505 .25 L
.69505 .25 L
.69506 .25 L
.69507 .25 L
.69507 .25 L
.69508 .25 L
.69508 .25 L
.69509 .25 L
.6951 .25 L
Mistroke
.6951 .25 L
.69511 .25 L
.69511 .25 L
.69512 .25 L
.69513 .25 L
.69513 .25 L
.69514 .25 L
.69515 .25 L
.69515 .25 L
.69516 .25 L
.69517 .25 L
.69517 .25 L
.69517 .25 L
.69518 .25 L
.69518 .25 L
.69519 .25 L
.69519 .25 L
.6952 .25 L
.69521 .25 L
.69521 .25 L
.69522 .25 L
.69522 .25 L
.69523 .25 L
.69524 .25 L
.69524 .25 L
.69525 .25 L
.69526 .25 L
.69526 .25 L
.69527 .25 L
.69528 .25 L
.69528 .25 L
.69529 .25 L
.69529 .25 L
.6953 .25 L
.6953 .25 L
.69531 .25 L
.69531 .25 L
.69531 .25 L
.69532 .25 L
.69532 .25 L
.69533 .25 L
.69533 .25 L
.69534 .25 L
.69534 .25 L
.69534 .25 L
.69535 .25 L
.69535 .25 L
.69535 .25 L
.69536 .25 L
.69537 .25 L
Mistroke
.69537 .25 L
.69538 .25 L
.69539 .25 L
.69539 .25 L
.6954 .25 L
.69541 .25 L
.69541 .25 L
.69542 .25 L
.69542 .25 L
.69543 .25 L
.69544 .25 L
.69544 .25 L
.69545 .25 L
.69546 .25 L
.69546 .25 L
.69547 .25 L
.69547 .25 L
.69548 .25 L
.69548 .25 L
.69549 .25 L
.6955 .25 L
.6955 .25 L
.69551 .25 L
.69551 .25 L
.69552 .25 L
.69553 .25 L
.69553 .25 L
.69554 .25 L
.69554 .25 L
.69555 .25 L
.69555 .25 L
.69556 .25 L
.69556 .25 L
.69557 .25 L
.69558 .25 L
.69558 .25 L
.69559 .25 L
.6956 .25 L
.6956 .25 L
.69561 .25 L
.69561 .25 L
.69562 .25 L
.69563 .25 L
.69563 .25 L
.69564 .25 L
.69565 .25 L
.69565 .25 L
.69566 .25 L
.69566 .25 L
.69567 .25 L
Mistroke
.69567 .25 L
.69568 .25 L
.69569 .25 L
.69569 .25 L
.6957 .25 L
.6957 .25 L
.69571 .25 L
.69572 .25 L
.69572 .25 L
.69573 .25 L
.69573 .25 L
.69574 .25 L
.69575 .25 L
.69575 .25 L
.69576 .25 L
.69576 .25 L
.69577 .25 L
.69577 .25 L
.69578 .25 L
.69578 .25 L
.69579 .25 L
.69579 .25 L
.6958 .25 L
.6958 .25 L
.69581 .25 L
.69582 .25 L
.69582 .25 L
.69583 .25 L
.69583 .25 L
.69584 .25 L
.69584 .25 L
.69585 .25 L
.69585 .25 L
.69586 .25 L
.69586 .25 L
.69587 .25 L
.69588 .25 L
.69588 .25 L
.69589 .25 L
.69589 .25 L
.6959 .25 L
.69591 .25 L
.69591 .25 L
.69592 .25 L
.69592 .25 L
.69593 .25 L
.69594 .25 L
.69594 .25 L
.69595 .25 L
.69596 .25 L
Mistroke
.69596 .25 L
.69597 .25 L
.69598 .25 L
.69598 .25 L
.69599 .25 L
.69599 .25 L
.696 .25 L
.696 .25 L
.696 .25 L
.69601 .25 L
.69602 .25 L
.69602 .25 L
.69603 .25 L
.69604 .25 L
.69604 .25 L
.69605 .25 L
.69605 .25 L
.69606 .25 L
.69607 .25 L
.69607 .25 L
.69608 .25 L
.69609 .25 L
.69609 .25 L
.6961 .25 L
.69611 .25 L
.69611 .25 L
.69612 .25 L
.69612 .25 L
.69613 .25 L
.69613 .25 L
.69613 .25 L
.69614 .25 L
.69614 .25 L
.69615 .25 L
.69615 .25 L
.69616 .25 L
.69616 .25 L
.69616 .25 L
.69617 .25 L
.69617 .25 L
.69617 .25 L
.69618 .25 L
.69618 .25 L
.69619 .25 L
.6962 .25 L
.6962 .25 L
.69621 .25 L
.69622 .25 L
.69622 .25 L
.69623 .25 L
Mistroke
.69624 .25 L
.69624 .25 L
.69625 .25 L
.69626 .25 L
.69626 .25 L
.69627 .25 L
.69627 .25 L
.69628 .25 L
.69628 .25 L
.69629 .25 L
.6963 .25 L
.6963 .25 L
.69631 .25 L
.69631 .25 L
.69632 .25 L
.69633 .25 L
.69633 .25 L
.69634 .25 L
.69634 .25 L
.69635 .25 L
.69636 .25 L
.69636 .25 L
.69637 .25 L
.69637 .25 L
.69638 .25 L
.69638 .25 L
.69639 .25 L
.69639 .25 L
.6964 .25 L
.69641 .25 L
.69641 .25 L
.69642 .25 L
.69643 .25 L
.69643 .25 L
.69644 .25 L
.69644 .25 L
.69645 .25 L
.69646 .25 L
.69646 .25 L
.69647 .25 L
.69648 .25 L
.69648 .25 L
.69648 .25 L
.69649 .25 L
.6965 .25 L
.6965 .25 L
.69651 .25 L
.69652 .25 L
.69652 .25 L
.69653 .25 L
Mistroke
.69653 .25 L
.69654 .25 L
.69655 .25 L
.69655 .25 L
.69656 .25 L
.69656 .25 L
.69657 .25 L
.69658 .25 L
.69658 .25 L
.69658 .25 L
.69659 .25 L
.6966 .25 L
.6966 .25 L
.69661 .25 L
.69661 .25 L
.69662 .25 L
.69662 .25 L
.69663 .25 L
.69663 .25 L
.69664 .25 L
.69665 .25 L
.69665 .25 L
.69666 .25 L
.69666 .25 L
.69667 .25 L
.69667 .25 L
.69667 .25 L
.69668 .25 L
.69669 .25 L
.69669 .25 L
.6967 .25 L
.69671 .25 L
.69671 .25 L
.69672 .25 L
.69672 .25 L
.69673 .25 L
.69674 .25 L
.69674 .25 L
.69675 .25 L
.69675 .25 L
.69676 .25 L
.69677 .25 L
.69677 .25 L
.69678 .25 L
.69679 .25 L
.69679 .25 L
.6968 .25 L
.69681 .25 L
.69681 .25 L
.69682 .25 L
Mistroke
.69682 .25 L
.69682 .25 L
.69683 .25 L
.69683 .25 L
.69684 .25 L
.69685 .25 L
.69685 .25 L
.69686 .25 L
.69687 .25 L
.69687 .25 L
.69688 .25 L
.69688 .25 L
.69689 .25 L
.6969 .25 L
.6969 .25 L
.69691 .25 L
.69692 .25 L
.69692 .25 L
.69693 .25 L
.69694 .25 L
.69694 .25 L
.69694 .25 L
.69695 .25 L
.69695 .25 L
.69696 .25 L
.69696 .25 L
.69696 .25 L
.69697 .25 L
.69698 .25 L
.69698 .25 L
.69698 .25 L
.69699 .25 L
.69699 .25 L
.69699 .25 L
.697 .25 L
.697 .25 L
.69701 .25 L
.69701 .25 L
.69702 .25 L
.69703 .25 L
.69703 .25 L
.69704 .25 L
.69705 .25 L
.69705 .25 L
.69706 .25 L
.69707 .25 L
.69707 .25 L
.69708 .25 L
.69708 .25 L
.69709 .25 L
Mistroke
.6971 .25 L
.6971 .25 L
.69711 .25 L
.69711 .25 L
.69712 .25 L
.69712 .25 L
.69713 .25 L
.69714 .25 L
.69714 .25 L
.69715 .25 L
.69715 .25 L
.69716 .25 L
.69717 .25 L
.69717 .25 L
.69718 .25 L
.69718 .25 L
.69719 .25 L
.6972 .25 L
.6972 .25 L
.6972 .25 L
.69721 .25 L
.69722 .25 L
.69722 .25 L
.69723 .25 L
.69724 .25 L
.69724 .25 L
.69725 .25 L
.69725 .25 L
.69726 .25 L
.69727 .25 L
.69727 .25 L
.69728 .25 L
.69729 .25 L
.69729 .25 L
.6973 .25 L
.6973 .25 L
.69731 .25 L
.69731 .25 L
.69732 .25 L
.69733 .25 L
.69733 .25 L
.69734 .25 L
.69735 .25 L
.69735 .25 L
.69736 .25 L
.69736 .25 L
.69737 .25 L
.69737 .25 L
.69738 .25 L
.69739 .25 L
Mistroke
.69739 .25 L
.6974 .25 L
.6974 .25 L
.69741 .25 L
.69741 .25 L
.69742 .25 L
.69743 .25 L
.69743 .25 L
.69744 .25 L
.69745 .25 L
.69745 .25 L
.69746 .25 L
.69746 .25 L
.69747 .25 L
.69748 .25 L
.69748 .25 L
.69749 .25 L
.6975 .25 L
.6975 .25 L
.69751 .25 L
.69751 .25 L
.69752 .25 L
.69752 .25 L
.69753 .25 L
.69754 .25 L
.69754 .25 L
.69755 .25 L
.69755 .25 L
.69756 .25 L
.69757 .25 L
.69757 .25 L
.69758 .25 L
.69758 .25 L
.69759 .25 L
.6976 .25 L
.6976 .25 L
.69761 .25 L
.69761 .25 L
.69762 .25 L
.69762 .25 L
.69763 .25 L
.69763 .25 L
.69764 .25 L
.69764 .25 L
.69765 .25 L
.69765 .25 L
.69766 .25 L
.69767 .25 L
.69767 .25 L
.69768 .25 L
Mistroke
.69768 .25 L
.69769 .25 L
.69769 .25 L
.6977 .25 L
.6977 .25 L
.69771 .25 L
.69771 .25 L
.69772 .25 L
.69773 .25 L
.69773 .25 L
.69774 .25 L
.69774 .25 L
.69775 .25 L
.69776 .25 L
.69776 .25 L
.69777 .25 L
.69777 .25 L
.69778 .25 L
.69779 .25 L
.69779 .25 L
.6978 .25 L
.69781 .25 L
.69781 .25 L
.69782 .25 L
.69782 .25 L
.69783 .25 L
.69784 .25 L
.69784 .25 L
.69785 .25 L
.69785 .25 L
.69785 .25 L
.69786 .25 L
.69787 .25 L
.69787 .25 L
.69788 .25 L
.69789 .25 L
.69789 .25 L
.6979 .25 L
.6979 .25 L
.69791 .25 L
.69792 .25 L
.69792 .25 L
.69793 .25 L
.69794 .25 L
.69794 .25 L
.69795 .25 L
.69796 .25 L
.69796 .25 L
.69797 .25 L
.69797 .25 L
Mistroke
.69798 .25 L
.69798 .25 L
.69798 .25 L
.69799 .25 L
.69799 .25 L
.698 .25 L
.698 .25 L
.69801 .25 L
.69801 .25 L
.69801 .25 L
.69802 .25 L
.69802 .25 L
.69802 .25 L
.69803 .25 L
.69803 .25 L
.69804 .25 L
.69805 .25 L
.69805 .25 L
.69806 .25 L
.69807 .25 L
.69807 .25 L
.69808 .25 L
.69809 .25 L
.69809 .25 L
.6981 .25 L
.69811 .25 L
.69811 .25 L
.69812 .25 L
.69812 .25 L
.69813 .25 L
.69813 .25 L
.69814 .25 L
.69815 .25 L
.69815 .25 L
.69816 .25 L
.69816 .25 L
.69817 .25 L
.69818 .25 L
.69818 .25 L
.69819 .25 L
.69819 .25 L
.6982 .25 L
.69821 .25 L
.69821 .25 L
.69822 .25 L
.69822 .25 L
.69823 .25 L
.69823 .25 L
.69824 .25 L
.69824 .25 L
Mistroke
.69825 .25 L
.69826 .25 L
.69826 .25 L
.69827 .25 L
.69828 .25 L
.69828 .25 L
.69829 .25 L
.69829 .25 L
.6983 .25 L
.69831 .25 L
.69831 .25 L
.69832 .25 L
.69833 .25 L
.69833 .25 L
.69833 .25 L
.69834 .25 L
.69835 .25 L
.69835 .25 L
.69836 .25 L
.69837 .25 L
.69837 .25 L
.69838 .25 L
.69838 .25 L
.69839 .25 L
.6984 .25 L
.6984 .25 L
.69841 .25 L
.69841 .25 L
.69842 .25 L
.69843 .25 L
.69843 .25 L
.69843 .25 L
.69844 .25 L
.69845 .25 L
.69845 .25 L
.69846 .25 L
.69846 .25 L
.69847 .25 L
.69847 .25 L
.69848 .25 L
.69848 .25 L
.69849 .25 L
.6985 .25 L
.6985 .25 L
.69851 .25 L
.69851 .25 L
.69852 .25 L
.69852 .25 L
.69852 .25 L
.69853 .25 L
Mistroke
.69854 .25 L
.69854 .25 L
.69855 .25 L
.69856 .25 L
.69856 .25 L
.69857 .25 L
.69857 .25 L
.69858 .25 L
.69859 .25 L
.69859 .25 L
.6986 .25 L
.69861 .25 L
.69861 .25 L
.69862 .25 L
.69862 .25 L
.69863 .25 L
.69864 .25 L
.69864 .25 L
.69865 .25 L
.69866 .25 L
.69866 .25 L
.69867 .25 L
.69867 .25 L
.69867 .25 L
.69868 .25 L
.69868 .25 L
.69869 .25 L
.6987 .25 L
.6987 .25 L
.69871 .25 L
.69872 .25 L
.69872 .25 L
.69873 .25 L
.69873 .25 L
.69874 .25 L
.69875 .25 L
.69875 .25 L
.69876 .25 L
.69877 .25 L
.69877 .25 L
.69878 .25 L
.69879 .25 L
.69879 .25 L
.69879 .25 L
.6988 .25 L
.6988 .25 L
.69881 .25 L
.69881 .25 L
.69882 .25 L
.69882 .25 L
Mistroke
.69883 .25 L
.69883 .25 L
.69883 .25 L
.69884 .25 L
.69884 .25 L
.69884 .25 L
.69885 .25 L
.69885 .25 L
.69886 .25 L
.69887 .25 L
.69887 .25 L
.69888 .25 L
.69889 .25 L
.69889 .25 L
.6989 .25 L
.6989 .25 L
.69891 .25 L
.69892 .25 L
.69892 .25 L
.69893 .25 L
.69893 .25 L
.69894 .25 L
.69895 .25 L
.69895 .25 L
.69896 .25 L
.69896 .25 L
.69897 .25 L
.69898 .25 L
.69898 .25 L
.69899 .25 L
.69899 .25 L
.699 .25 L
.699 .25 L
.69901 .25 L
.69902 .25 L
.69902 .25 L
.69903 .25 L
.69904 .25 L
.69904 .25 L
.69905 .25 L
.69905 .25 L
.69905 .25 L
.69906 .25 L
.69907 .25 L
.69907 .25 L
.69908 .25 L
.69909 .25 L
.69909 .25 L
.6991 .25 L
.69911 .25 L
Mistroke
.69911 .25 L
.69912 .25 L
.69912 .25 L
.69913 .25 L
.69914 .25 L
.69914 .25 L
.69915 .25 L
.69915 .25 L
.69916 .25 L
.69917 .25 L
.69917 .25 L
.69918 .25 L
.69918 .25 L
.69919 .25 L
.6992 .25 L
.6992 .25 L
.69921 .25 L
.69921 .25 L
.69922 .25 L
.69923 .25 L
.69923 .25 L
.69924 .25 L
.69924 .25 L
.69925 .25 L
.69925 .25 L
.69926 .25 L
.69926 .25 L
.69927 .25 L
.69928 .25 L
.69928 .25 L
.69928 .25 L
.69929 .25 L
.6993 .25 L
.6993 .25 L
.69931 .25 L
.69931 .25 L
.69932 .25 L
.69933 .25 L
.69933 .25 L
.69933 .25 L
.69934 .25 L
.69935 .25 L
.69935 .25 L
.69936 .25 L
.69936 .25 L
.69937 .25 L
.69937 .25 L
.69938 .25 L
.69939 .25 L
.69939 .25 L
Mistroke
.6994 .25 L
.6994 .25 L
.69941 .25 L
.69942 .25 L
.69942 .25 L
.69943 .25 L
.69944 .25 L
.69944 .25 L
.69945 .25 L
.69945 .25 L
.69946 .25 L
.69947 .25 L
.69947 .25 L
.69948 .25 L
.69949 .25 L
.69949 .25 L
.69949 .25 L
.6995 .25 L
.6995 .25 L
.69951 .25 L
.69951 .25 L
.69952 .25 L
.69953 .25 L
.69953 .25 L
.69954 .25 L
.69955 .25 L
.69955 .25 L
.69956 .25 L
.69956 .25 L
.69957 .25 L
.69958 .25 L
.69958 .25 L
.69959 .25 L
.6996 .25 L
.6996 .25 L
.69961 .25 L
.69961 .25 L
.69962 .25 L
.69962 .25 L
.69963 .25 L
.69963 .25 L
.69963 .25 L
.69964 .25 L
.69965 .25 L
.69965 .25 L
.69965 .25 L
.69966 .25 L
.69966 .25 L
.69966 .25 L
.69967 .25 L
Mistroke
.69967 .25 L
.69968 .25 L
.69968 .25 L
.69969 .25 L
.6997 .25 L
.6997 .25 L
.69971 .25 L
.69972 .25 L
.69972 .25 L
.69973 .25 L
.69973 .25 L
.69974 .25 L
.69975 .25 L
.69975 .25 L
.69976 .25 L
.69977 .25 L
.69977 .25 L
.69978 .25 L
.69978 .25 L
.69979 .25 L
.69979 .25 L
.6998 .25 L
.69981 .25 L
.69981 .25 L
.69982 .25 L
.69982 .25 L
.69983 .25 L
.69983 .25 L
.69984 .25 L
.69985 .25 L
.69985 .25 L
.69986 .25 L
.69986 .25 L
.69987 .25 L
.69987 .25 L
.69988 .25 L
.69988 .25 L
.69989 .25 L
.6999 .25 L
.6999 .25 L
.69991 .25 L
.69992 .25 L
.69992 .25 L
.69993 .25 L
.69994 .25 L
.69994 .25 L
.69995 .25 L
.69995 .25 L
.69996 .25 L
.69997 .25 L
Mistroke
.69997 .25 L
.69998 .25 L
.69998 .25 L
.69999 .25 L
.7 .25 L
.7 .25 L
.70001 .25 L
.70001 .25 L
.70002 .25 L
.70003 .25 L
.70003 .25 L
.70004 .25 L
.70004 .25 L
.70005 .25 L
.70006 .25 L
.70006 .25 L
.70007 .25 L
.70007 .25 L
.70008 .25 L
.70008 .25 L
.70009 .25 L
.70009 .25 L
.7001 .25 L
.7001 .25 L
.70011 .25 L
.70011 .25 L
.70012 .25 L
.70013 .25 L
.70013 .25 L
.70014 .25 L
.70014 .25 L
.70015 .25 L
.70015 .25 L
.70016 .25 L
.70016 .25 L
.70017 .25 L
.70017 .25 L
.70018 .25 L
.70019 .25 L
.70019 .25 L
.7002 .25 L
.7002 .25 L
.70021 .25 L
.70022 .25 L
.70022 .25 L
.70023 .25 L
.70023 .25 L
.70024 .25 L
.70025 .25 L
.70025 .25 L
Mistroke
.70026 .25 L
.70026 .25 L
.70027 .25 L
.70028 .25 L
.70028 .25 L
.70029 .25 L
.7003 .25 L
.7003 .25 L
.70031 .25 L
.70031 .25 L
.70032 .25 L
.70032 .25 L
.70032 .25 L
.70033 .25 L
.70034 .25 L
.70034 .25 L
.70035 .25 L
.70036 .25 L
.70036 .25 L
.70037 .25 L
.70037 .25 L
.70038 .25 L
.70039 .25 L
.70039 .25 L
.7004 .25 L
.70041 .25 L
.70041 .25 L
.70042 .25 L
.70043 .25 L
.70043 .25 L
.70044 .25 L
.70044 .25 L
.70045 .25 L
.70045 .25 L
.70045 .25 L
.70046 .25 L
.70046 .25 L
.70047 .25 L
.70047 .25 L
.70048 .25 L
.70048 .25 L
.70048 .25 L
.70049 .25 L
.70049 .25 L
.7005 .25 L
.7005 .25 L
.70051 .25 L
.70051 .25 L
.70052 .25 L
.70053 .25 L
Mistroke
.70053 .25 L
.70054 .25 L
.70054 .25 L
.70055 .25 L
.70056 .25 L
.70056 .25 L
.70057 .25 L
.70058 .25 L
.70058 .25 L
.70059 .25 L
.7006 .25 L
.7006 .25 L
.7006 .25 L
.70061 .25 L
.70062 .25 L
.70062 .25 L
.70063 .25 L
.70063 .25 L
.70064 .25 L
.70065 .25 L
.70065 .25 L
.70066 .25 L
.70066 .25 L
.70067 .25 L
.70068 .25 L
.70068 .25 L
.70069 .25 L
.70069 .25 L
.7007 .25 L
.7007 .25 L
.70071 .25 L
.70071 .25 L
.70072 .25 L
.70073 .25 L
.70073 .25 L
.70074 .25 L
.70075 .25 L
.70075 .25 L
.70076 .25 L
.70076 .25 L
.70077 .25 L
.70078 .25 L
.70078 .25 L
.70079 .25 L
.7008 .25 L
.7008 .25 L
.70081 .25 L
.70081 .25 L
.70082 .25 L
.70082 .25 L
Mistroke
.70083 .25 L
.70084 .25 L
.70084 .25 L
.70085 .25 L
.70085 .25 L
.70086 .25 L
.70087 .25 L
.70087 .25 L
.70088 .25 L
.70088 .25 L
.70089 .25 L
.7009 .25 L
.7009 .25 L
.7009 .25 L
.70091 .25 L
.70092 .25 L
.70092 .25 L
.70093 .25 L
.70094 .25 L
.70094 .25 L
.70095 .25 L
.70095 .25 L
.70096 .25 L
.70097 .25 L
.70097 .25 L
.70098 .25 L
.70099 .25 L
.70099 .25 L
.701 .25 L
.701 .25 L
.70101 .25 L
.70101 .25 L
.70102 .25 L
.70103 .25 L
.70103 .25 L
.70104 .25 L
.70105 .25 L
.70105 .25 L
.70106 .25 L
.70106 .25 L
.70107 .25 L
.70107 .25 L
.70108 .25 L
.70109 .25 L
.70109 .25 L
.7011 .25 L
.7011 .25 L
.70111 .25 L
.70111 .25 L
.70112 .25 L
Mistroke
.70113 .25 L
.70113 .25 L
.70113 .25 L
.70114 .25 L
.70115 .25 L
.70115 .25 L
.70116 .25 L
.70116 .25 L
.70117 .25 L
.70118 .25 L
.70118 .25 L
.70118 .25 L
.70119 .25 L
.70119 .25 L
.7012 .25 L
.7012 .25 L
.70121 .25 L
.70122 .25 L
.70122 .25 L
.70123 .25 L
.70124 .25 L
.70124 .25 L
.70125 .25 L
.70125 .25 L
.70126 .25 L
.70127 .25 L
.70127 .25 L
.70128 .25 L
.70128 .25 L
.70129 .25 L
.7013 .25 L
.7013 .25 L
.70131 .25 L
.70132 .25 L
.70132 .25 L
.70133 .25 L
.70134 .25 L
.70134 .25 L
.70134 .25 L
.70135 .25 L
.70135 .25 L
.70136 .25 L
.70136 .25 L
.70137 .25 L
.70138 .25 L
.70138 .25 L
.70139 .25 L
.7014 .25 L
.7014 .25 L
.70141 .25 L
Mistroke
.70141 .25 L
.70142 .25 L
.70143 .25 L
.70143 .25 L
.70144 .25 L
.70145 .25 L
.70145 .25 L
.70146 .25 L
.70146 .25 L
.70147 .25 L
.70147 .25 L
.70148 .25 L
.70148 .25 L
.70148 .25 L
.70149 .25 L
.7015 .25 L
.7015 .25 L
.7015 .25 L
.70151 .25 L
.70151 .25 L
.70151 .25 L
.70152 .25 L
.70152 .25 L
.70153 .25 L
.70153 .25 L
.70154 .25 L
.70155 .25 L
.70155 .25 L
.70156 .25 L
.70156 .25 L
.70157 .25 L
.70158 .25 L
.70158 .25 L
.70159 .25 L
.7016 .25 L
.7016 .25 L
.70161 .25 L
.70162 .25 L
.70162 .25 L
.70163 .25 L
.70163 .25 L
.70164 .25 L
.70164 .25 L
.70165 .25 L
.70165 .25 L
.70166 .25 L
.70167 .25 L
.70167 .25 L
.70168 .25 L
.70168 .25 L
Mistroke
.70169 .25 L
.7017 .25 L
.7017 .25 L
.70171 .25 L
.70171 .25 L
.70172 .25 L
.70172 .25 L
.70173 .25 L
.70173 .25 L
.70174 .25 L
.70175 .25 L
.70175 .25 L
.70176 .25 L
.70177 .25 L
.70177 .25 L
.70178 .25 L
.70179 .25 L
.70179 .25 L
.7018 .25 L
.70181 .25 L
.70181 .25 L
.70182 .25 L
.70182 .25 L
.70183 .25 L
.70183 .25 L
.70184 .25 L
.70185 .25 L
.70185 .25 L
.70186 .25 L
.70186 .25 L
.70187 .25 L
.70188 .25 L
.70188 .25 L
.70189 .25 L
.70189 .25 L
.7019 .25 L
.70191 .25 L
.70191 .25 L
.70192 .25 L
.70192 .25 L
.70193 .25 L
.70193 .25 L
.70194 .25 L
.70194 .25 L
.70195 .25 L
.70195 .25 L
.70196 .25 L
.70196 .25 L
.70197 .25 L
.70198 .25 L
Mistroke
.70198 .25 L
.70199 .25 L
.70199 .25 L
.702 .25 L
.702 .25 L
.70201 .25 L
.70202 .25 L
.70202 .25 L
.70202 .25 L
.70203 .25 L
.70204 .25 L
.70204 .25 L
.70205 .25 L
.70205 .25 L
.70206 .25 L
.70207 .25 L
.70207 .25 L
.70208 .25 L
.70208 .25 L
.70209 .25 L
.7021 .25 L
.7021 .25 L
.70211 .25 L
.70211 .25 L
.70212 .25 L
.70213 .25 L
.70213 .25 L
.70214 .25 L
.70215 .25 L
.70215 .25 L
.70216 .25 L
.70216 .25 L
.70217 .25 L
.70217 .25 L
.70217 .25 L
.70218 .25 L
.70219 .25 L
.70219 .25 L
.7022 .25 L
.70221 .25 L
.70221 .25 L
.70222 .25 L
.70222 .25 L
.70223 .25 L
.70224 .25 L
.70224 .25 L
.70225 .25 L
.70226 .25 L
.70226 .25 L
.70227 .25 L
Mistroke
.70228 .25 L
.70228 .25 L
.70229 .25 L
.70229 .25 L
.7023 .25 L
.7023 .25 L
.70231 .25 L
.70231 .25 L
.70231 .25 L
.70232 .25 L
.70232 .25 L
.70233 .25 L
.70233 .25 L
.70233 .25 L
.70234 .25 L
.70234 .25 L
.70235 .25 L
.70235 .25 L
.70236 .25 L
.70236 .25 L
.70237 .25 L
.70238 .25 L
.70238 .25 L
.70239 .25 L
.7024 .25 L
.7024 .25 L
.70241 .25 L
.70241 .25 L
.70242 .25 L
.70243 .25 L
.70243 .25 L
.70244 .25 L
.70245 .25 L
.70245 .25 L
.70245 .25 L
.70246 .25 L
.70247 .25 L
.70247 .25 L
.70248 .25 L
.70249 .25 L
.70249 .25 L
.7025 .25 L
.7025 .25 L
.70251 .25 L
.70251 .25 L
.70252 .25 L
.70253 .25 L
.70253 .25 L
.70254 .25 L
.70254 .25 L
Mistroke
.70255 .25 L
.70255 .25 L
.70256 .25 L
.70256 .25 L
.70257 .25 L
.70258 .25 L
.70259 .25 L
.70259 .25 L
.7026 .25 L
.7026 .25 L
.70261 .25 L
.70262 .25 L
.70262 .25 L
.70263 .25 L
.70263 .25 L
.70264 .25 L
.70265 .25 L
.70265 .25 L
.70266 .25 L
.70266 .25 L
.70267 .25 L
.70268 .25 L
.70268 .25 L
.70269 .25 L
.70269 .25 L
.7027 .25 L
.7027 .25 L
.70271 .25 L
.70272 .25 L
.70272 .25 L
.70273 .25 L
.70274 .25 L
.70274 .25 L
.70275 .25 L
.70275 .25 L
.70275 .25 L
.70276 .25 L
.70277 .25 L
.70277 .25 L
.70278 .25 L
.70278 .25 L
.70279 .25 L
.70279 .25 L
.7028 .25 L
.70281 .25 L
.70281 .25 L
.70282 .25 L
.70282 .25 L
.70283 .25 L
.70283 .25 L
Mistroke
.70284 .25 L
.70284 .25 L
.70285 .25 L
.70285 .25 L
.70286 .25 L
.70287 .25 L
.70287 .25 L
.70288 .25 L
.70288 .25 L
.70289 .25 L
.70289 .25 L
.7029 .25 L
.70291 .25 L
.70291 .25 L
.70292 .25 L
.70293 .25 L
.70293 .25 L
.70294 .25 L
.70294 .25 L
.70295 .25 L
.70296 .25 L
.70296 .25 L
.70297 .25 L
.70298 .25 L
.70298 .25 L
.70299 .25 L
.70299 .25 L
.70299 .25 L
.703 .25 L
.70301 .25 L
.70301 .25 L
.70302 .25 L
.70302 .25 L
.70303 .25 L
.70304 .25 L
.70304 .25 L
.70305 .25 L
.70306 .25 L
.70306 .25 L
.70307 .25 L
.70307 .25 L
.70308 .25 L
.70309 .25 L
.70309 .25 L
.7031 .25 L
.70311 .25 L
.70311 .25 L
.70312 .25 L
.70312 .25 L
.70313 .25 L
Mistroke
.70313 .25 L
.70313 .25 L
.70314 .25 L
.70314 .25 L
.70315 .25 L
.70315 .25 L
.70315 .25 L
.70316 .25 L
.70316 .25 L
.70317 .25 L
.70317 .25 L
.70317 .25 L
.70318 .25 L
.70319 .25 L
.70319 .25 L
.7032 .25 L
.70321 .25 L
.70321 .25 L
.70322 .25 L
.70322 .25 L
.70323 .25 L
.70324 .25 L
.70324 .25 L
.70325 .25 L
.70326 .25 L
.70326 .25 L
.70327 .25 L
.70327 .25 L
.70328 .25 L
.70328 .25 L
.70329 .25 L
.7033 .25 L
.7033 .25 L
.70331 .25 L
.70332 .25 L
.70332 .25 L
.70333 .25 L
.70333 .25 L
.70334 .25 L
.70334 .25 L
.70335 .25 L
.70336 .25 L
.70336 .25 L
.70337 .25 L
.70337 .25 L
.70338 .25 L
.70338 .25 L
.70339 .25 L
.7034 .25 L
.7034 .25 L
Mistroke
.70341 .25 L
.70341 .25 L
.70342 .25 L
.70343 .25 L
.70343 .25 L
.70344 .25 L
.70345 .25 L
.70345 .25 L
.70346 .25 L
.70347 .25 L
.70347 .25 L
.70348 .25 L
.70348 .25 L
.70349 .25 L
.70349 .25 L
.7035 .25 L
.70351 .25 L
.70351 .25 L
.70352 .25 L
.70352 .25 L
.70353 .25 L
.70353 .25 L
.70354 .25 L
.70355 .25 L
.70355 .25 L
.70356 .25 L
.70356 .25 L
.70357 .25 L
.70357 .25 L
.70358 .25 L
.70358 .25 L
.70359 .25 L
.7036 .25 L
.7036 .25 L
.7036 .25 L
.70361 .25 L
.70362 .25 L
.70362 .25 L
.70363 .25 L
.70364 .25 L
.70364 .25 L
.70365 .25 L
.70365 .25 L
.70366 .25 L
.70366 .25 L
.70367 .25 L
.70367 .25 L
.70368 .25 L
.70368 .25 L
.70369 .25 L
Mistroke
.7037 .25 L
.7037 .25 L
.70371 .25 L
.70371 .25 L
.70372 .25 L
.70372 .25 L
.70373 .25 L
.70374 .25 L
.70374 .25 L
.70375 .25 L
.70376 .25 L
.70376 .25 L
.70377 .25 L
.70377 .25 L
.70378 .25 L
.70379 .25 L
.70379 .25 L
.7038 .25 L
.70381 .25 L
.70381 .25 L
.70381 .25 L
.70382 .25 L
.70382 .25 L
.70383 .25 L
.70383 .25 L
.70384 .25 L
.70385 .25 L
.70385 .25 L
.70386 .25 L
.70387 .25 L
.70387 .25 L
.70388 .25 L
.70389 .25 L
.70389 .25 L
.7039 .25 L
.7039 .25 L
.70391 .25 L
.70392 .25 L
.70392 .25 L
.70393 .25 L
.70393 .25 L
.70394 .25 L
.70395 .25 L
.70395 .25 L
.70395 .25 L
.70396 .25 L
.70396 .25 L
.70397 .25 L
.70397 .25 L
.70397 .25 L
Mistroke
.70398 .25 L
.70398 .25 L
.70399 .25 L
.70399 .25 L
.70399 .25 L
.704 .25 L
.704 .25 L
.70401 .25 L
.70402 .25 L
.70402 .25 L
.70403 .25 L
.70404 .25 L
.70404 .25 L
.70405 .25 L
.70405 .25 L
.70406 .25 L
.70407 .25 L
.70407 .25 L
.70408 .25 L
.70409 .25 L
.70409 .25 L
.7041 .25 L
.7041 .25 L
.70411 .25 L
.70411 .25 L
.70412 .25 L
.70413 .25 L
.70413 .25 L
.70414 .25 L
.70414 .25 L
.70415 .25 L
.70416 .25 L
.70416 .25 L
.70417 .25 L
.70417 .25 L
.70418 .25 L
.70419 .25 L
.70419 .25 L
.7042 .25 L
.7042 .25 L
.70421 .25 L
.70421 .25 L
.70422 .25 L
.70423 .25 L
.70423 .25 L
.70424 .25 L
.70424 .25 L
.70425 .25 L
.70426 .25 L
.70426 .25 L
Mistroke
.70427 .25 L
.70428 .25 L
.70428 .25 L
.70429 .25 L
.7043 .25 L
.7043 .25 L
.7043 .25 L
.70431 .25 L
.70432 .25 L
.70432 .25 L
.70433 .25 L
.70433 .25 L
.70434 .25 L
.70435 .25 L
.70435 .25 L
.70436 .25 L
.70436 .25 L
.70437 .25 L
.70438 .25 L
.70438 .25 L
.70439 .25 L
.70439 .25 L
.7044 .25 L
.7044 .25 L
.70441 .25 L
.70441 .25 L
.70442 .25 L
.70443 .25 L
.70443 .25 L
.70444 .25 L
.70445 .25 L
.70445 .25 L
.70446 .25 L
.70447 .25 L
.70447 .25 L
.70448 .25 L
.70448 .25 L
.70449 .25 L
.7045 .25 L
.7045 .25 L
.70451 .25 L
.70451 .25 L
.70452 .25 L
.70452 .25 L
.70453 .25 L
.70454 .25 L
.70454 .25 L
.70455 .25 L
.70455 .25 L
.70456 .25 L
Mistroke
.70457 .25 L
.70457 .25 L
.70458 .25 L
.70458 .25 L
.70459 .25 L
.7046 .25 L
.7046 .25 L
.7046 .25 L
.70461 .25 L
.70462 .25 L
.70462 .25 L
.70463 .25 L
.70463 .25 L
.70464 .25 L
.70464 .25 L
.70465 .25 L
.70466 .25 L
.70466 .25 L
.70467 .25 L
.70467 .25 L
.70468 .25 L
.70468 .25 L
.70469 .25 L
.70469 .25 L
.7047 .25 L
.7047 .25 L
.70471 .25 L
.70472 .25 L
.70472 .25 L
.70473 .25 L
.70473 .25 L
.70474 .25 L
.70474 .25 L
.70475 .25 L
.70476 .25 L
.70476 .25 L
.70477 .25 L
.70478 .25 L
.70478 .25 L
.70479 .25 L
.70479 .25 L
.7048 .25 L
.70481 .25 L
.70481 .25 L
.70482 .25 L
.70483 .25 L
.70483 .25 L
.70484 .25 L
.70484 .25 L
.70484 .25 L
Mistroke
.70485 .25 L
.70485 .25 L
.70486 .25 L
.70487 .25 L
.70487 .25 L
.70488 .25 L
.70489 .25 L
.70489 .25 L
.7049 .25 L
.70491 .25 L
.70491 .25 L
.70492 .25 L
.70492 .25 L
.70493 .25 L
.70494 .25 L
.70494 .25 L
.70495 .25 L
.70496 .25 L
.70496 .25 L
.70497 .25 L
.70497 .25 L
.70498 .25 L
.70498 .25 L
.70498 .25 L
.70499 .25 L
.70499 .25 L
.705 .25 L
.705 .25 L
.705 .25 L
.70501 .25 L
.70501 .25 L
.70502 .25 L
.70502 .25 L
.70502 .25 L
.70503 .25 L
.70504 .25 L
.70504 .25 L
.70505 .25 L
.70506 .25 L
.70506 .25 L
.70507 .25 L
.70507 .25 L
.70508 .25 L
.70509 .25 L
.70509 .25 L
.7051 .25 L
.70511 .25 L
.70511 .25 L
.70512 .25 L
.70512 .25 L
Mistroke
.70513 .25 L
.70513 .25 L
.70514 .25 L
.70515 .25 L
.70515 .25 L
.70516 .25 L
.70517 .25 L
.70517 .25 L
.70518 .25 L
.70518 .25 L
.70519 .25 L
.70519 .25 L
.7052 .25 L
.70521 .25 L
.70521 .25 L
.70522 .25 L
.70522 .25 L
.70523 .25 L
.70523 .25 L
.70524 .25 L
.70525 .25 L
.70525 .25 L
.70526 .25 L
.70527 .25 L
.70527 .25 L
.70528 .25 L
.70528 .25 L
.70529 .25 L
.7053 .25 L
.7053 .25 L
.70531 .25 L
.70532 .25 L
.70532 .25 L
.70533 .25 L
.70533 .25 L
.70534 .25 L
.70534 .25 L
.70535 .25 L
.70536 .25 L
.70536 .25 L
.70537 .25 L
.70537 .25 L
.70538 .25 L
.70538 .25 L
.70539 .25 L
.7054 .25 L
.7054 .25 L
.70541 .25 L
.70541 .25 L
.70542 .25 L
Mistroke
.70543 .25 L
.70543 .25 L
.70543 .25 L
.70544 .25 L
.70545 .25 L
.70545 .25 L
.70545 .25 L
.70546 .25 L
.70547 .25 L
.70547 .25 L
.70548 .25 L
.70549 .25 L
.70549 .25 L
.7055 .25 L
.7055 .25 L
.70551 .25 L
.70551 .25 L
.70552 .25 L
.70552 .25 L
.70553 .25 L
.70553 .25 L
.70554 .25 L
.70555 .25 L
.70555 .25 L
.70556 .25 L
.70556 .25 L
.70557 .25 L
.70558 .25 L
.70558 .25 L
.70559 .25 L
.70559 .25 L
.7056 .25 L
.70561 .25 L
.70561 .25 L
.70562 .25 L
.70562 .25 L
.70563 .25 L
.70564 .25 L
.70564 .25 L
.70565 .25 L
.70566 .25 L
.70566 .25 L
.70566 .25 L
.70567 .25 L
.70567 .25 L
.70568 .25 L
.70569 .25 L
.70569 .25 L
.7057 .25 L
.7057 .25 L
Mistroke
.70571 .25 L
.70572 .25 L
.70572 .25 L
.70573 .25 L
.70574 .25 L
.70574 .25 L
.70575 .25 L
.70576 .25 L
.70576 .25 L
.70577 .25 L
.70577 .25 L
.70578 .25 L
.70579 .25 L
.70579 .25 L
.7058 .25 L
.7058 .25 L
.7058 .25 L
.70581 .25 L
.70581 .25 L
.70582 .25 L
.70582 .25 L
.70582 .25 L
.70583 .25 L
.70583 .25 L
.70584 .25 L
.70584 .25 L
.70584 .25 L
.70585 .25 L
.70585 .25 L
.70586 .25 L
.70587 .25 L
.70587 .25 L
.70588 .25 L
.70589 .25 L
.70589 .25 L
.7059 .25 L
.7059 .25 L
.70591 .25 L
.70592 .25 L
.70592 .25 L
.70593 .25 L
.70594 .25 L
.70594 .25 L
.70595 .25 L
.70595 .25 L
.70596 .25 L
.70596 .25 L
.70597 .25 L
.70598 .25 L
.70598 .25 L
Mistroke
.70599 .25 L
.70599 .25 L
.706 .25 L
.70601 .25 L
.70601 .25 L
.70602 .25 L
.70602 .25 L
.70603 .25 L
.70604 .25 L
.70604 .25 L
.70605 .25 L
.70605 .25 L
.70606 .25 L
.70606 .25 L
.70607 .25 L
.70608 .25 L
.70608 .25 L
.70609 .25 L
.7061 .25 L
.7061 .25 L
.70611 .25 L
.70611 .25 L
.70612 .25 L
.70613 .25 L
.70613 .25 L
.70614 .25 L
.70615 .25 L
.70615 .25 L
.70615 .25 L
.70616 .25 L
.70617 .25 L
.70617 .25 L
.70618 .25 L
.70619 .25 L
.70619 .25 L
.7062 .25 L
.7062 .25 L
.70621 .25 L
.70621 .25 L
.70622 .25 L
.70623 .25 L
.70623 .25 L
.70624 .25 L
.70625 .25 L
.70625 .25 L
.70625 .25 L
.70626 .25 L
.70627 .25 L
.70627 .25 L
.70628 .25 L
Mistroke
.70628 .25 L
.70629 .25 L
.70629 .25 L
.7063 .25 L
.7063 .25 L
.70631 .25 L
.70632 .25 L
.70632 .25 L
.70633 .25 L
.70633 .25 L
.70634 .25 L
.70634 .25 L
.70634 .25 L
.70635 .25 L
.70636 .25 L
.70636 .25 L
.70637 .25 L
.70638 .25 L
.70638 .25 L
.70639 .25 L
.70639 .25 L
.7064 .25 L
.70641 .25 L
.70641 .25 L
.70642 .25 L
.70642 .25 L
.70643 .25 L
.70644 .25 L
.70644 .25 L
.70645 .25 L
.70646 .25 L
.70646 .25 L
.70647 .25 L
.70648 .25 L
.70648 .25 L
.70648 .25 L
.70649 .25 L
.70649 .25 L
.7065 .25 L
.7065 .25 L
.70651 .25 L
.70652 .25 L
.70652 .25 L
.70653 .25 L
.70654 .25 L
.70654 .25 L
.70655 .25 L
.70655 .25 L
.70656 .25 L
.70657 .25 L
Mistroke
.70657 .25 L
.70658 .25 L
.70659 .25 L
.70659 .25 L
.7066 .25 L
.70661 .25 L
.70661 .25 L
.70661 .25 L
.70662 .25 L
.70662 .25 L
.70663 .25 L
.70663 .25 L
.70663 .25 L
.70664 .25 L
.70664 .25 L
.70665 .25 L
.70665 .25 L
.70666 .25 L
.70666 .25 L
.70666 .25 L
.70667 .25 L
.70667 .25 L
.70668 .25 L
.70668 .25 L
.70669 .25 L
.7067 .25 L
.7067 .25 L
.70671 .25 L
.70672 .25 L
.70672 .25 L
.70673 .25 L
.70673 .25 L
.70674 .25 L
.70675 .25 L
.70675 .25 L
.70676 .25 L
.70677 .25 L
.70677 .25 L
.70678 .25 L
.70678 .25 L
.70679 .25 L
.70679 .25 L
.7068 .25 L
.70681 .25 L
.70681 .25 L
.70682 .25 L
.70682 .25 L
.70683 .25 L
.70684 .25 L
.70684 .25 L
Mistroke
.70685 .25 L
.70685 .25 L
.70686 .25 L
.70687 .25 L
.70687 .25 L
.70687 .25 L
.70688 .25 L
.70689 .25 L
.70689 .25 L
.7069 .25 L
.70691 .25 L
.70691 .25 L
.70692 .25 L
.70692 .25 L
.70693 .25 L
.70694 .25 L
.70694 .25 L
.70695 .25 L
.70696 .25 L
.70696 .25 L
.70697 .25 L
.70697 .25 L
.70698 .25 L
.70698 .25 L
.70699 .25 L
.707 .25 L
.707 .25 L
.70701 .25 L
.70702 .25 L
.70702 .25 L
.70703 .25 L
.70703 .25 L
.70704 .25 L
.70704 .25 L
.70705 .25 L
.70706 .25 L
.70706 .25 L
.70707 .25 L
.70707 .25 L
.70708 .25 L
.70708 .25 L
.70709 .25 L
.7071 .25 L
.7071 .25 L
.7071 .25 L
.70711 .25 L
.70712 .25 L
.70712 .25 L
.70713 .25 L
.70713 .25 L
Mistroke
.70714 .25 L
.70715 .25 L
.70715 .25 L
.70715 .25 L
.70716 .25 L
.70716 .25 L
.70717 .25 L
.70717 .25 L
.70718 .25 L
.70719 .25 L
.70719 .25 L
.7072 .25 L
.70721 .25 L
.70721 .25 L
.70722 .25 L
.70722 .25 L
.70723 .25 L
.70724 .25 L
.70724 .25 L
.70725 .25 L
.70725 .25 L
.70726 .25 L
.70727 .25 L
.70727 .25 L
.70728 .25 L
.70729 .25 L
.70729 .25 L
.7073 .25 L
.70731 .25 L
.70731 .25 L
.70731 .25 L
.70732 .25 L
.70732 .25 L
.70733 .25 L
.70733 .25 L
.70734 .25 L
.70735 .25 L
.70735 .25 L
.70736 .25 L
.70736 .25 L
.70737 .25 L
.70738 .25 L
.70738 .25 L
.70739 .25 L
.7074 .25 L
.7074 .25 L
.70741 .25 L
.70742 .25 L
.70742 .25 L
.70743 .25 L
Mistroke
.70743 .25 L
.70744 .25 L
.70744 .25 L
.70745 .25 L
.70745 .25 L
.70745 .25 L
.70746 .25 L
.70746 .25 L
.70747 .25 L
.70747 .25 L
.70748 .25 L
.70748 .25 L
.70748 .25 L
.70749 .25 L
.70749 .25 L
.70749 .25 L
.7075 .25 L
.70751 .25 L
.70751 .25 L
.70752 .25 L
.70753 .25 L
.70753 .25 L
.70754 .25 L
.70755 .25 L
.70755 .25 L
.70756 .25 L
.70756 .25 L
.70757 .25 L
.70758 .25 L
.70758 .25 L
.70759 .25 L
.7076 .25 L
.7076 .25 L
.70761 .25 L
.70761 .25 L
.70762 .25 L
.70762 .25 L
.70763 .25 L
.70764 .25 L
.70764 .25 L
.70765 .25 L
.70765 .25 L
.70766 .25 L
.70767 .25 L
.70767 .25 L
.70768 .25 L
.70768 .25 L
.70769 .25 L
.70769 .25 L
.7077 .25 L
Mistroke
.7077 .25 L
.70771 .25 L
.70772 .25 L
.70772 .25 L
.70773 .25 L
.70774 .25 L
.70774 .25 L
.70775 .25 L
.70775 .25 L
.70776 .25 L
.70777 .25 L
.70777 .25 L
.70778 .25 L
.70779 .25 L
.70779 .25 L
.7078 .25 L
.7078 .25 L
.70781 .25 L
.70781 .25 L
.70782 .25 L
.70783 .25 L
.70783 .25 L
.70784 .25 L
.70784 .25 L
.70785 .25 L
.70786 .25 L
.70786 .25 L
.70787 .25 L
.70787 .25 L
.70788 .25 L
.70789 .25 L
.70789 .25 L
.7079 .25 L
.7079 .25 L
.70791 .25 L
.70791 .25 L
.70792 .25 L
.70793 .25 L
.70793 .25 L
.70794 .25 L
.70794 .25 L
.70795 .25 L
.70796 .25 L
.70796 .25 L
.70797 .25 L
.70798 .25 L
.70798 .25 L
.70799 .25 L
.708 .25 L
.708 .25 L
Mistroke
.708 .25 L
.70801 .25 L
.70802 .25 L
.70802 .25 L
.70803 .25 L
.70804 .25 L
.70804 .25 L
.70805 .25 L
.70805 .25 L
.70806 .25 L
.70806 .25 L
.70807 .25 L
.70808 .25 L
.70808 .25 L
.70809 .25 L
.7081 .25 L
.7081 .25 L
.7081 .25 L
.70811 .25 L
.70812 .25 L
.70812 .25 L
.70813 .25 L
.70813 .25 L
.70814 .25 L
.70814 .25 L
.70815 .25 L
.70815 .25 L
.70816 .25 L
.70817 .25 L
.70817 .25 L
.70818 .25 L
.70818 .25 L
.70819 .25 L
.70819 .25 L
.70819 .25 L
.7082 .25 L
.70821 .25 L
.70821 .25 L
.70822 .25 L
.70823 .25 L
.70823 .25 L
.70824 .25 L
.70824 .25 L
.70825 .25 L
.70826 .25 L
.70826 .25 L
.70827 .25 L
.70827 .25 L
.70828 .25 L
.70829 .25 L
Mistroke
.70829 .25 L
.7083 .25 L
.70831 .25 L
.70831 .25 L
.70832 .25 L
.70833 .25 L
.70833 .25 L
.70833 .25 L
.70834 .25 L
.70834 .25 L
.70835 .25 L
.70835 .25 L
.70836 .25 L
.70837 .25 L
.70837 .25 L
.70838 .25 L
.70839 .25 L
.70839 .25 L
.7084 .25 L
.7084 .25 L
.70841 .25 L
.70842 .25 L
.70842 .25 L
.70843 .25 L
.70844 .25 L
.70844 .25 L
.70845 .25 L
.70846 .25 L
.70846 .25 L
.70846 .25 L
.70847 .25 L
.70847 .25 L
.70848 .25 L
.70848 .25 L
.70848 .25 L
.70849 .25 L
.7085 .25 L
.7085 .25 L
.7085 .25 L
.70851 .25 L
.70851 .25 L
.70851 .25 L
.70852 .25 L
.70852 .25 L
.70853 .25 L
.70853 .25 L
.70854 .25 L
.70855 .25 L
.70855 .25 L
.70856 .25 L
Mistroke
.70857 .25 L
.70857 .25 L
.70858 .25 L
.70858 .25 L
.70859 .25 L
.7086 .25 L
.7086 .25 L
.70861 .25 L
.70862 .25 L
.70862 .25 L
.70863 .25 L
.70863 .25 L
.70864 .25 L
.70864 .25 L
.70865 .25 L
.70866 .25 L
.70866 .25 L
.70867 .25 L
.70867 .25 L
.70868 .25 L
.70869 .25 L
.70869 .25 L
.7087 .25 L
.7087 .25 L
.70871 .25 L
.70872 .25 L
.70872 .25 L
.70872 .25 L
.70873 .25 L
.70874 .25 L
.70874 .25 L
.70875 .25 L
.70876 .25 L
.70876 .25 L
.70877 .25 L
.70877 .25 L
.70878 .25 L
.70879 .25 L
.70879 .25 L
.7088 .25 L
.70881 .25 L
.70881 .25 L
.70882 .25 L
.70882 .25 L
.70883 .25 L
.70883 .25 L
.70884 .25 L
.70885 .25 L
.70885 .25 L
.70886 .25 L
Mistroke
.70887 .25 L
.70887 .25 L
.70888 .25 L
.70888 .25 L
.70889 .25 L
.70889 .25 L
.7089 .25 L
.70891 .25 L
.70891 .25 L
.70892 .25 L
.70892 .25 L
.70893 .25 L
.70893 .25 L
.70894 .25 L
.70895 .25 L
.70895 .25 L
.70895 .25 L
.70896 .25 L
.70897 .25 L
.70897 .25 L
.70898 .25 L
.70898 .25 L
.70899 .25 L
.709 .25 L
.709 .25 L
.709 .25 L
.70901 .25 L
.70901 .25 L
.70902 .25 L
.70902 .25 L
.70903 .25 L
.70904 .25 L
.70904 .25 L
.70905 .25 L
.70906 .25 L
.70906 .25 L
.70907 .25 L
.70907 .25 L
.70908 .25 L
.70909 .25 L
.70909 .25 L
.7091 .25 L
.7091 .25 L
.70911 .25 L
.70912 .25 L
.70912 .25 L
.70913 .25 L
.70914 .25 L
.70914 .25 L
.70915 .25 L
Mistroke
.70916 .25 L
.70916 .25 L
.70916 .25 L
.70917 .25 L
.70917 .25 L
.70918 .25 L
.70918 .25 L
.70919 .25 L
.7092 .25 L
.7092 .25 L
.70921 .25 L
.70922 .25 L
.70922 .25 L
.70923 .25 L
.70923 .25 L
.70924 .25 L
.70925 .25 L
.70925 .25 L
.70926 .25 L
.70927 .25 L
.70927 .25 L
.70928 .25 L
.70928 .25 L
.70929 .25 L
.70929 .25 L
.7093 .25 L
.7093 .25 L
.7093 .25 L
.70931 .25 L
.70932 .25 L
.70932 .25 L
.70932 .25 L
.70933 .25 L
.70933 .25 L
.70933 .25 L
.70934 .25 L
.70934 .25 L
.70935 .25 L
.70935 .25 L
.70936 .25 L
.70937 .25 L
.70937 .25 L
.70938 .25 L
.70938 .25 L
.70939 .25 L
.7094 .25 L
.7094 .25 L
.70941 .25 L
.70942 .25 L
.70942 .25 L
Mistroke
.70943 .25 L
.70943 .25 L
.70944 .25 L
.70945 .25 L
.70945 .25 L
.70946 .25 L
.70946 .25 L
.70947 .25 L
.70947 .25 L
.70948 .25 L
.70949 .25 L
.70949 .25 L
.7095 .25 L
.7095 .25 L
.70951 .25 L
.70952 .25 L
.70952 .25 L
.70953 .25 L
.70953 .25 L
.70954 .25 L
.70954 .25 L
.70955 .25 L
.70955 .25 L
.70956 .25 L
.70957 .25 L
.70957 .25 L
.70958 .25 L
.70959 .25 L
.70959 .25 L
.7096 .25 L
.70961 .25 L
.70961 .25 L
.70962 .25 L
.70962 .25 L
.70963 .25 L
.70964 .25 L
.70964 .25 L
.70965 .25 L
.70965 .25 L
.70966 .25 L
.70967 .25 L
.70967 .25 L
.70968 .25 L
.70968 .25 L
.70969 .25 L
.7097 .25 L
.7097 .25 L
.70971 .25 L
.70971 .25 L
.70972 .25 L
Mistroke
.70973 .25 L
.70973 .25 L
.70974 .25 L
.70974 .25 L
.70975 .25 L
.70975 .25 L
.70976 .25 L
.70976 .25 L
.70977 .25 L
.70977 .25 L
.70978 .25 L
.70978 .25 L
.70979 .25 L
.7098 .25 L
.7098 .25 L
.70981 .25 L
.70981 .25 L
.70982 .25 L
.70982 .25 L
.70983 .25 L
.70983 .25 L
.70984 .25 L
.70984 .25 L
.70985 .25 L
.70986 .25 L
.70986 .25 L
.70987 .25 L
.70987 .25 L
.70988 .25 L
.70989 .25 L
.70989 .25 L
.7099 .25 L
.7099 .25 L
.70991 .25 L
.70992 .25 L
.70992 .25 L
.70993 .25 L
.70993 .25 L
.70994 .25 L
.70995 .25 L
.70995 .25 L
.70996 .25 L
.70997 .25 L
.70997 .25 L
.70998 .25 L
.70998 .25 L
.70999 .25 L
.70999 .25 L
.70999 .25 L
.71 .25 L
Mistroke
.71001 .25 L
.71001 .25 L
.71002 .25 L
.71003 .25 L
.71003 .25 L
.71004 .25 L
.71004 .25 L
.71005 .25 L
.71006 .25 L
.71006 .25 L
.71007 .25 L
.71008 .25 L
.71008 .25 L
.71009 .25 L
.7101 .25 L
.7101 .25 L
.71011 .25 L
.71011 .25 L
.71012 .25 L
.71012 .25 L
.71013 .25 L
.71013 .25 L
.71013 .25 L
.71014 .25 L
.71014 .25 L
.71015 .25 L
.71015 .25 L
.71015 .25 L
.71016 .25 L
.71016 .25 L
.71017 .25 L
.71017 .25 L
.71018 .25 L
.71018 .25 L
.71019 .25 L
.7102 .25 L
.7102 .25 L
.71021 .25 L
.71021 .25 L
.71022 .25 L
.71023 .25 L
.71023 .25 L
.71024 .25 L
.71025 .25 L
.71025 .25 L
.71026 .25 L
.71027 .25 L
.71027 .25 L
.71027 .25 L
.71028 .25 L
Mistroke
.71029 .25 L
.71029 .25 L
.7103 .25 L
.71031 .25 L
.71031 .25 L
.71032 .25 L
.71032 .25 L
.71033 .25 L
.71033 .25 L
.71034 .25 L
.71035 .25 L
.71035 .25 L
.71036 .25 L
.71036 .25 L
.71037 .25 L
.71037 .25 L
.71038 .25 L
.71038 .25 L
.71039 .25 L
.7104 .25 L
.7104 .25 L
.71041 .25 L
.71042 .25 L
.71042 .25 L
.71043 .25 L
.71044 .25 L
.71044 .25 L
.71045 .25 L
.71045 .25 L
.71046 .25 L
.71047 .25 L
.71047 .25 L
.71048 .25 L
.71048 .25 L
.71049 .25 L
.71049 .25 L
.7105 .25 L
.71051 .25 L
.71051 .25 L
.71052 .25 L
.71052 .25 L
.71053 .25 L
.71054 .25 L
.71054 .25 L
.71055 .25 L
.71056 .25 L
.71056 .25 L
.71057 .25 L
.71057 .25 L
.71057 .25 L
Mistroke
.71058 .25 L
.71059 .25 L
.71059 .25 L
.7106 .25 L
.7106 .25 L
.71061 .25 L
.71061 .25 L
.71062 .25 L
.71063 .25 L
.71063 .25 L
.71064 .25 L
.71064 .25 L
.71065 .25 L
.71065 .25 L
.71066 .25 L
.71066 .25 L
.71067 .25 L
.71067 .25 L
.71068 .25 L
.71069 .25 L
.71069 .25 L
.7107 .25 L
.7107 .25 L
.71071 .25 L
.71071 .25 L
.71072 .25 L
.71073 .25 L
.71073 .25 L
.71074 .25 L
.71075 .25 L
.71075 .25 L
.71076 .25 L
.71076 .25 L
.71077 .25 L
.71078 .25 L
.71078 .25 L
.71079 .25 L
.7108 .25 L
.7108 .25 L
.71081 .25 L
.71081 .25 L
.71081 .25 L
.71082 .25 L
.71082 .25 L
.71083 .25 L
.71084 .25 L
.71084 .25 L
.71085 .25 L
.71086 .25 L
.71086 .25 L
Mistroke
.71087 .25 L
.71087 .25 L
.71088 .25 L
.71089 .25 L
.71089 .25 L
.7109 .25 L
.71091 .25 L
.71091 .25 L
.71092 .25 L
.71093 .25 L
.71093 .25 L
.71093 .25 L
.71094 .25 L
.71095 .25 L
.71095 .25 L
.71095 .25 L
.71096 .25 L
.71096 .25 L
.71097 .25 L
.71097 .25 L
.71097 .25 L
.71098 .25 L
.71098 .25 L
.71099 .25 L
.71099 .25 L
.71099 .25 L
.711 .25 L
.71101 .25 L
.71101 .25 L
.71102 .25 L
.71103 .25 L
.71103 .25 L
.71104 .25 L
.71104 .25 L
.71105 .25 L
.71106 .25 L
.71106 .25 L
.71107 .25 L
.71108 .25 L
.71108 .25 L
.71109 .25 L
.71109 .25 L
.7111 .25 L
.7111 .25 L
.71111 .25 L
.71112 .25 L
.71112 .25 L
.71113 .25 L
.71113 .25 L
.71114 .25 L
Mistroke
.71115 .25 L
.71115 .25 L
.71116 .25 L
.71116 .25 L
.71117 .25 L
.71118 .25 L
.71118 .25 L
.71119 .25 L
.71119 .25 L
.7112 .25 L
.7112 .25 L
.71121 .25 L
.71121 .25 L
.71122 .25 L
.71123 .25 L
.71123 .25 L
.71124 .25 L
.71125 .25 L
.71125 .25 L
.71126 .25 L
.71127 .25 L
.71127 .25 L
.71128 .25 L
.71128 .25 L
.71129 .25 L
.7113 .25 L
.7113 .25 L
.71131 .25 L
.71131 .25 L
.71132 .25 L
.71132 .25 L
.71133 .25 L
.71134 .25 L
.71134 .25 L
.71135 .25 L
.71135 .25 L
.71136 .25 L
.71137 .25 L
.71137 .25 L
.71138 .25 L
.71138 .25 L
.71139 .25 L
.71139 .25 L
.7114 .25 L
.7114 .25 L
.71141 .25 L
.71142 .25 L
.71142 .25 L
.71142 .25 L
.71143 .25 L
Mistroke
.71144 .25 L
.71144 .25 L
.71145 .25 L
.71145 .25 L
.71146 .25 L
.71147 .25 L
.71147 .25 L
.71148 .25 L
.71148 .25 L
.71149 .25 L
.71149 .25 L
.7115 .25 L
.7115 .25 L
.71151 .25 L
.71152 .25 L
.71152 .25 L
.71153 .25 L
.71153 .25 L
.71154 .25 L
.71154 .25 L
.71155 .25 L
.71156 .25 L
.71156 .25 L
.71157 .25 L
.71158 .25 L
.71158 .25 L
.71159 .25 L
.71159 .25 L
.7116 .25 L
.71161 .25 L
.71161 .25 L
.71162 .25 L
.71163 .25 L
.71163 .25 L
.71163 .25 L
.71164 .25 L
.71164 .25 L
.71165 .25 L
.71165 .25 L
.71166 .25 L
.71167 .25 L
.71167 .25 L
.71168 .25 L
.71169 .25 L
.71169 .25 L
.7117 .25 L
.71171 .25 L
.71171 .25 L
.71172 .25 L
.71172 .25 L
Mistroke
.71173 .25 L
.71174 .25 L
.71174 .25 L
.71175 .25 L
.71175 .25 L
.71176 .25 L
.71176 .25 L
.71177 .25 L
.71177 .25 L
.71178 .25 L
.71178 .25 L
.71179 .25 L
.71179 .25 L
.71179 .25 L
.7118 .25 L
.7118 .25 L
.71181 .25 L
.71181 .25 L
.71181 .25 L
.71182 .25 L
.71182 .25 L
.71183 .25 L
.71184 .25 L
.71184 .25 L
.71185 .25 L
.71186 .25 L
.71186 .25 L
.71187 .25 L
.71187 .25 L
.71188 .25 L
.71189 .25 L
.71189 .25 L
.7119 .25 L
.71191 .25 L
.71191 .25 L
.71192 .25 L
.71192 .25 L
.71193 .25 L
.71193 .25 L
.71194 .25 L
.71195 .25 L
.71195 .25 L
.71196 .25 L
.71196 .25 L
.71197 .25 L
.71197 .25 L
.71198 .25 L
.71199 .25 L
.71199 .25 L
.712 .25 L
Mistroke
.712 .25 L
.71201 .25 L
.71202 .25 L
.71202 .25 L
.71202 .25 L
.71203 .25 L
.71204 .25 L
.71205 .25 L
.71205 .25 L
.71206 .25 L
.71206 .25 L
.71207 .25 L
.71208 .25 L
.71208 .25 L
.71209 .25 L
.7121 .25 L
.7121 .25 L
.71211 .25 L
.71211 .25 L
.71212 .25 L
.71212 .25 L
.71213 .25 L
.71214 .25 L
.71214 .25 L
.71215 .25 L
.71215 .25 L
.71216 .25 L
.71217 .25 L
.71217 .25 L
.71218 .25 L
.71218 .25 L
.71219 .25 L
.7122 .25 L
.7122 .25 L
.71221 .25 L
.71221 .25 L
.71222 .25 L
.71222 .25 L
.71223 .25 L
.71223 .25 L
.71224 .25 L
.71225 .25 L
.71225 .25 L
.71226 .25 L
.71227 .25 L
.71227 .25 L
.71228 .25 L
.71228 .25 L
.71229 .25 L
.7123 .25 L
Mistroke
.7123 .25 L
.71231 .25 L
.71232 .25 L
.71232 .25 L
.71233 .25 L
.71233 .25 L
.71234 .25 L
.71234 .25 L
.71235 .25 L
.71236 .25 L
.71236 .25 L
.71237 .25 L
.71237 .25 L
.71238 .25 L
.71239 .25 L
.71239 .25 L
.7124 .25 L
.7124 .25 L
.71241 .25 L
.71242 .25 L
.71242 .25 L
.71242 .25 L
.71243 .25 L
.71244 .25 L
.71244 .25 L
.71245 .25 L
.71245 .25 L
.71246 .25 L
.71246 .25 L
.71247 .25 L
.71247 .25 L
.71248 .25 L
.71249 .25 L
.71249 .25 L
.7125 .25 L
.7125 .25 L
.71251 .25 L
.71251 .25 L
.71252 .25 L
.71252 .25 L
.71253 .25 L
.71254 .25 L
.71254 .25 L
.71255 .25 L
.71255 .25 L
.71256 .25 L
.71256 .25 L
.71257 .25 L
.71258 .25 L
.71258 .25 L
Mistroke
.71259 .25 L
.7126 .25 L
.7126 .25 L
.71261 .25 L
.71261 .25 L
.71262 .25 L
.71263 .25 L
.71263 .25 L
.71264 .25 L
.71265 .25 L
.71265 .25 L
.71266 .25 L
.71266 .25 L
.71266 .25 L
.71267 .25 L
.71267 .25 L
.71268 .25 L
.71269 .25 L
.71269 .25 L
.7127 .25 L
.71271 .25 L
.71271 .25 L
.71272 .25 L
.71272 .25 L
.71273 .25 L
.71274 .25 L
.71274 .25 L
.71275 .25 L
.71276 .25 L
.71276 .25 L
.71277 .25 L
.71278 .25 L
.71278 .25 L
.71278 .25 L
.71279 .25 L
.71279 .25 L
.7128 .25 L
.7128 .25 L
.71281 .25 L
.71281 .25 L
.71282 .25 L
.71282 .25 L
.71282 .25 L
.71283 .25 L
.71283 .25 L
.71284 .25 L
.71284 .25 L
.71284 .25 L
.71285 .25 L
.71286 .25 L
Mistroke
.71286 .25 L
.71287 .25 L
.71288 .25 L
.71288 .25 L
.71289 .25 L
.71289 .25 L
.7129 .25 L
.71291 .25 L
.71291 .25 L
.71292 .25 L
.71293 .25 L
.71293 .25 L
.71294 .25 L
.71294 .25 L
.71295 .25 L
.71295 .25 L
.71296 .25 L
.71297 .25 L
.71297 .25 L
.71298 .25 L
.71298 .25 L
.71299 .25 L
.713 .25 L
.713 .25 L
.71301 .25 L
.71301 .25 L
.71302 .25 L
.71303 .25 L
.71303 .25 L
.71304 .25 L
.71304 .25 L
.71305 .25 L
.71305 .25 L
.71306 .25 L
.71306 .25 L
.71307 .25 L
.71308 .25 L
.71308 .25 L
.71309 .25 L
.7131 .25 L
.7131 .25 L
.71311 .25 L
.71312 .25 L
.71312 .25 L
.71313 .25 L
.71313 .25 L
.71314 .25 L
.71315 .25 L
.71315 .25 L
.71316 .25 L
Mistroke
.71316 .25 L
.71317 .25 L
.71317 .25 L
.71318 .25 L
.71319 .25 L
.71319 .25 L
.7132 .25 L
.7132 .25 L
.71321 .25 L
.71322 .25 L
.71322 .25 L
.71323 .25 L
.71323 .25 L
.71324 .25 L
.71324 .25 L
.71325 .25 L
.71325 .25 L
.71326 .25 L
.71327 .25 L
.71327 .25 L
.71327 .25 L
.71328 .25 L
.71329 .25 L
.71329 .25 L
.7133 .25 L
.7133 .25 L
.71331 .25 L
.71332 .25 L
.71332 .25 L
.71333 .25 L
.71333 .25 L
.71334 .25 L
.71334 .25 L
.71335 .25 L
.71335 .25 L
.71336 .25 L
.71337 .25 L
.71337 .25 L
.71338 .25 L
.71338 .25 L
.71339 .25 L
.71339 .25 L
.7134 .25 L
.71341 .25 L
.71341 .25 L
.71342 .25 L
.71343 .25 L
.71343 .25 L
.71344 .25 L
.71344 .25 L
Mistroke
.71345 .25 L
.71346 .25 L
.71346 .25 L
.71347 .25 L
.71348 .25 L
.71348 .25 L
.71348 .25 L
.71349 .25 L
.71349 .25 L
.7135 .25 L
.7135 .25 L
.71351 .25 L
.71352 .25 L
.71352 .25 L
.71353 .25 L
.71354 .25 L
.71354 .25 L
.71355 .25 L
.71356 .25 L
.71356 .25 L
.71357 .25 L
.71357 .25 L
.71358 .25 L
.71359 .25 L
.71359 .25 L
.7136 .25 L
.7136 .25 L
.71361 .25 L
.71362 .25 L
.71362 .25 L
.71362 .25 L
.71363 .25 L
.71363 .25 L
.71364 .25 L
.71364 .25 L
.71364 .25 L
.71365 .25 L
.71365 .25 L
.71366 .25 L
.71366 .25 L
.71366 .25 L
.71367 .25 L
.71367 .25 L
.71368 .25 L
.71369 .25 L
.71369 .25 L
.7137 .25 L
.71371 .25 L
.71371 .25 L
.71372 .25 L
Mistroke
.71372 .25 L
.71373 .25 L
.71374 .25 L
.71374 .25 L
.71375 .25 L
.71376 .25 L
.71376 .25 L
.71377 .25 L
.71377 .25 L
.71378 .25 L
.71378 .25 L
.71379 .25 L
.7138 .25 L
.7138 .25 L
.71381 .25 L
.71381 .25 L
.71382 .25 L
.71383 .25 L
.71383 .25 L
.71384 .25 L
.71384 .25 L
.71385 .25 L
.71386 .25 L
.71386 .25 L
.71387 .25 L
.71387 .25 L
.71388 .25 L
.71388 .25 L
.71389 .25 L
.7139 .25 L
.7139 .25 L
.71391 .25 L
.71391 .25 L
.71392 .25 L
.71393 .25 L
.71393 .25 L
.71394 .25 L
.71395 .25 L
.71395 .25 L
.71396 .25 L
.71397 .25 L
.71397 .25 L
.71397 .25 L
.71398 .25 L
.71399 .25 L
.71399 .25 L
.714 .25 L
.714 .25 L
.71401 .25 L
.71402 .25 L
Mistroke
.71402 .25 L
.71403 .25 L
.71403 .25 L
.71404 .25 L
.71405 .25 L
.71405 .25 L
.71406 .25 L
.71406 .25 L
.71407 .25 L
.71407 .25 L
.71408 .25 L
.71408 .25 L
.71409 .25 L
.71409 .25 L
.7141 .25 L
.7141 .25 L
.71411 .25 L
.71412 .25 L
.71412 .25 L
.71413 .25 L
.71414 .25 L
.71414 .25 L
.71415 .25 L
.71415 .25 L
.71416 .25 L
.71416 .25 L
.71416 .25 L
.71417 .25 L
.71418 .25 L
.71418 .25 L
.71419 .25 L
.71419 .25 L
.7142 .25 L
.71421 .25 L
.71421 .25 L
.71422 .25 L
.71422 .25 L
.71423 .25 L
.71424 .25 L
.71424 .25 L
.71425 .25 L
.71426 .25 L
.71426 .25 L
.71427 .25 L
.71427 .25 L
.71428 .25 L
.71429 .25 L
.71429 .25 L
.7143 .25 L
.7143 .25 L
Mistroke
.71431 .25 L
.71431 .25 L
.71432 .25 L
.71432 .25 L
.71433 .25 L
.71433 .25 L
.71434 .25 L
.71435 .25 L
.71435 .25 L
.71436 .25 L
.71437 .25 L
.71437 .25 L
.71438 .25 L
.71439 .25 L
.71439 .25 L
.7144 .25 L
.7144 .25 L
.71441 .25 L
.71442 .25 L
.71442 .25 L
.71443 .25 L
.71443 .25 L
.71444 .25 L
.71444 .25 L
.71445 .25 L
.71445 .25 L
.71445 .25 L
.71446 .25 L
.71446 .25 L
.71447 .25 L
.71447 .25 L
.71448 .25 L
.71448 .25 L
.71448 .25 L
.71449 .25 L
.71449 .25 L
.7145 .25 L
.7145 .25 L
.71451 .25 L
.71452 .25 L
.71452 .25 L
.71453 .25 L
.71454 .25 L
.71454 .25 L
.71455 .25 L
.71455 .25 L
.71456 .25 L
.71457 .25 L
.71457 .25 L
.71458 .25 L
Mistroke
.71459 .25 L
.71459 .25 L
.71459 .25 L
.7146 .25 L
.71461 .25 L
.71461 .25 L
.71462 .25 L
.71463 .25 L
.71463 .25 L
.71464 .25 L
.71464 .25 L
.71465 .25 L
.71465 .25 L
.71466 .25 L
.71467 .25 L
.71467 .25 L
.71468 .25 L
.71469 .25 L
.71469 .25 L
.71469 .25 L
.7147 .25 L
.71471 .25 L
.71471 .25 L
.71472 .25 L
.71473 .25 L
.71473 .25 L
.71474 .25 L
.71474 .25 L
.71475 .25 L
.71476 .25 L
.71476 .25 L
.71477 .25 L
.71478 .25 L
.71478 .25 L
.71479 .25 L
.71479 .25 L
.7148 .25 L
.7148 .25 L
.71481 .25 L
.71482 .25 L
.71482 .25 L
.71483 .25 L
.71483 .25 L
.71484 .25 L
.71485 .25 L
.71485 .25 L
.71486 .25 L
.71486 .25 L
.71487 .25 L
.71488 .25 L
Mistroke
.71488 .25 L
.71489 .25 L
.71489 .25 L
.7149 .25 L
.7149 .25 L
.71491 .25 L
.71491 .25 L
.71492 .25 L
.71492 .25 L
.71493 .25 L
.71493 .25 L
.71494 .25 L
.71495 .25 L
.71495 .25 L
.71496 .25 L
.71497 .25 L
.71497 .25 L
.71497 .25 L
.71498 .25 L
.71498 .25 L
.71499 .25 L
.71499 .25 L
.715 .25 L
.71501 .25 L
.71501 .25 L
.71502 .25 L
.71502 .25 L
.71503 .25 L
.71504 .25 L
.71504 .25 L
.71505 .25 L
.71505 .25 L
.71506 .25 L
.71507 .25 L
.71507 .25 L
.71508 .25 L
.71508 .25 L
.71509 .25 L
.7151 .25 L
.7151 .25 L
.71511 .25 L
.71512 .25 L
.71512 .25 L
.71513 .25 L
.71513 .25 L
.71514 .25 L
.71514 .25 L
.71515 .25 L
.71515 .25 L
.71516 .25 L
Mistroke
.71517 .25 L
.71517 .25 L
.71518 .25 L
.71518 .25 L
.71519 .25 L
.7152 .25 L
.7152 .25 L
.71521 .25 L
.71522 .25 L
.71522 .25 L
.71523 .25 L
.71523 .25 L
.71524 .25 L
.71525 .25 L
.71525 .25 L
.71526 .25 L
.71526 .25 L
.71527 .25 L
.71527 .25 L
.71527 .25 L
.71528 .25 L
.71528 .25 L
.71529 .25 L
.71529 .25 L
.71529 .25 L
.7153 .25 L
.7153 .25 L
.71531 .25 L
.71531 .25 L
.71531 .25 L
.71532 .25 L
.71533 .25 L
.71533 .25 L
.71534 .25 L
.71535 .25 L
.71535 .25 L
.71536 .25 L
.71536 .25 L
.71537 .25 L
.71538 .25 L
.71538 .25 L
.71539 .25 L
.7154 .25 L
.7154 .25 L
.71541 .25 L
.71541 .25 L
.71542 .25 L
.71542 .25 L
.71543 .25 L
.71544 .25 L
Mistroke
.71544 .25 L
.71545 .25 L
.71546 .25 L
.71546 .25 L
.71547 .25 L
.71547 .25 L
.71548 .25 L
.71548 .25 L
.71549 .25 L
.7155 .25 L
.7155 .25 L
.71551 .25 L
.71551 .25 L
.71552 .25 L
.71552 .25 L
.71553 .25 L
.71554 .25 L
.71554 .25 L
.71555 .25 L
.71556 .25 L
.71556 .25 L
.71557 .25 L
.71557 .25 L
.71558 .25 L
.71559 .25 L
.71559 .25 L
.7156 .25 L
.71561 .25 L
.71561 .25 L
.71562 .25 L
.71562 .25 L
.71563 .25 L
.71563 .25 L
.71564 .25 L
.71565 .25 L
.71565 .25 L
.71566 .25 L
.71566 .25 L
.71567 .25 L
.71567 .25 L
.71568 .25 L
.71569 .25 L
.71569 .25 L
.7157 .25 L
.7157 .25 L
.71571 .25 L
.71571 .25 L
.71572 .25 L
.71572 .25 L
.71573 .25 L
Mistroke
.71574 .25 L
.71574 .25 L
.71575 .25 L
.71576 .25 L
.71576 .25 L
.71577 .25 L
.71578 .25 L
.71578 .25 L
.71579 .25 L
.7158 .25 L
.7158 .25 L
.71581 .25 L
.71581 .25 L
.71582 .25 L
.71582 .25 L
.71583 .25 L
.71584 .25 L
.71584 .25 L
.71585 .25 L
.71585 .25 L
.71586 .25 L
.71587 .25 L
.71587 .25 L
.71588 .25 L
.71588 .25 L
.71589 .25 L
.7159 .25 L
.7159 .25 L
.71591 .25 L
.71591 .25 L
.71592 .25 L
.71592 .25 L
.71593 .25 L
.71593 .25 L
.71594 .25 L
.71594 .25 L
.71595 .25 L
.71595 .25 L
.71596 .25 L
.71597 .25 L
.71597 .25 L
.71598 .25 L
.71598 .25 L
.71599 .25 L
.71599 .25 L
.716 .25 L
.71601 .25 L
.71601 .25 L
.71601 .25 L
.71602 .25 L
Mistroke
.71603 .25 L
.71603 .25 L
.71604 .25 L
.71604 .25 L
.71605 .25 L
.71606 .25 L
.71606 .25 L
.71607 .25 L
.71607 .25 L
.71608 .25 L
.71609 .25 L
.71609 .25 L
.7161 .25 L
.7161 .25 L
.71611 .25 L
.71612 .25 L
.71612 .25 L
.71613 .25 L
.71614 .25 L
.71614 .25 L
.71615 .25 L
.71615 .25 L
.71616 .25 L
.71616 .25 L
.71616 .25 L
.71617 .25 L
.71618 .25 L
.71618 .25 L
.71619 .25 L
.7162 .25 L
.7162 .25 L
.71621 .25 L
.71622 .25 L
.71622 .25 L
.71623 .25 L
.71624 .25 L
.71624 .25 L
.71625 .25 L
.71625 .25 L
.71626 .25 L
.71627 .25 L
.71627 .25 L
.71628 .25 L
.71628 .25 L
.71629 .25 L
.71629 .25 L
.7163 .25 L
.7163 .25 L
.7163 .25 L
.71631 .25 L
Mistroke
.71631 .25 L
.71632 .25 L
.71632 .25 L
.71633 .25 L
.71633 .25 L
.71633 .25 L
.71634 .25 L
.71634 .25 L
.71635 .25 L
.71635 .25 L
.71636 .25 L
.71637 .25 L
.71637 .25 L
.71638 .25 L
.71639 .25 L
.71639 .25 L
.7164 .25 L
.7164 .25 L
.71641 .25 L
.71642 .25 L
.71642 .25 L
.71643 .25 L
.71644 .25 L
.71644 .25 L
.71644 .25 L
.71645 .25 L
.71646 .25 L
.71646 .25 L
.71647 .25 L
.71648 .25 L
.71648 .25 L
.71649 .25 L
.71649 .25 L
.7165 .25 L
.7165 .25 L
.71651 .25 L
.71652 .25 L
.71652 .25 L
.71653 .25 L
.71654 .25 L
.71654 .25 L
.71654 .25 L
.71655 .25 L
.71656 .25 L
.71656 .25 L
.71657 .25 L
.71658 .25 L
.71658 .25 L
.71659 .25 L
.71659 .25 L
Mistroke
.7166 .25 L
.71661 .25 L
.71661 .25 L
.71662 .25 L
.71663 .25 L
.71663 .25 L
.71664 .25 L
.71664 .25 L
.71665 .25 L
.71665 .25 L
.71666 .25 L
.71667 .25 L
.71667 .25 L
.71668 .25 L
.71668 .25 L
.71669 .25 L
.7167 .25 L
.7167 .25 L
.71671 .25 L
.71671 .25 L
.71672 .25 L
.71673 .25 L
.71673 .25 L
.71674 .25 L
.71674 .25 L
.71675 .25 L
.71675 .25 L
.71676 .25 L
.71676 .25 L
.71677 .25 L
.71677 .25 L
.71678 .25 L
.71678 .25 L
.71679 .25 L
.7168 .25 L
.7168 .25 L
.71681 .25 L
.71682 .25 L
.71682 .25 L
.71682 .25 L
.71683 .25 L
.71683 .25 L
.71684 .25 L
.71684 .25 L
.71685 .25 L
.71686 .25 L
.71686 .25 L
.71687 .25 L
.71687 .25 L
.71688 .25 L
Mistroke
.71689 .25 L
.71689 .25 L
.7169 .25 L
.7169 .25 L
.71691 .25 L
.71692 .25 L
.71692 .25 L
.71693 .25 L
.71693 .25 L
.71694 .25 L
.71695 .25 L
.71695 .25 L
.71696 .25 L
.71697 .25 L
.71697 .25 L
.71698 .25 L
.71698 .25 L
.71699 .25 L
.71699 .25 L
.717 .25 L
.717 .25 L
.71701 .25 L
.71702 .25 L
.71702 .25 L
.71703 .25 L
.71703 .25 L
.71704 .25 L
.71705 .25 L
.71705 .25 L
.71706 .25 L
.71707 .25 L
.71707 .25 L
.71708 .25 L
.71709 .25 L
.71709 .25 L
.7171 .25 L
.7171 .25 L
.71711 .25 L
.71711 .25 L
.71712 .25 L
.71712 .25 L
.71712 .25 L
.71713 .25 L
.71713 .25 L
.71714 .25 L
.71714 .25 L
.71715 .25 L
.71715 .25 L
.71715 .25 L
.71716 .25 L
Mistroke
.71716 .25 L
.71716 .25 L
.71717 .25 L
.71718 .25 L
.71718 .25 L
.71719 .25 L
.7172 .25 L
.7172 .25 L
.71721 .25 L
.71722 .25 L
.71722 .25 L
.71723 .25 L
.71723 .25 L
.71724 .25 L
.71725 .25 L
.71725 .25 L
.71726 .25 L
.71726 .25 L
.71727 .25 L
.71728 .25 L
.71728 .25 L
.71729 .25 L
.71729 .25 L
.7173 .25 L
.71731 .25 L
.71731 .25 L
.71732 .25 L
.71732 .25 L
.71733 .25 L
.71733 .25 L
.71734 .25 L
.71735 .25 L
.71735 .25 L
.71736 .25 L
.71736 .25 L
.71737 .25 L
.71737 .25 L
.71738 .25 L
.71739 .25 L
.71739 .25 L
.7174 .25 L
.71741 .25 L
.71741 .25 L
.71742 .25 L
.71742 .25 L
.71743 .25 L
.71744 .25 L
.71744 .25 L
.71745 .25 L
.71746 .25 L
Mistroke
.71746 .25 L
.71747 .25 L
.71747 .25 L
.71748 .25 L
.71748 .25 L
.71749 .25 L
.7175 .25 L
.7175 .25 L
.71751 .25 L
.71751 .25 L
.71752 .25 L
.71753 .25 L
.71753 .25 L
.71754 .25 L
.71754 .25 L
.71755 .25 L
.71756 .25 L
.71756 .25 L
.71757 .25 L
.71757 .25 L
.71758 .25 L
.71758 .25 L
.71759 .25 L
.71759 .25 L
.7176 .25 L
.7176 .25 L
.71761 .25 L
.71761 .25 L
.71762 .25 L
.71763 .25 L
.71763 .25 L
.71764 .25 L
.71764 .25 L
.71765 .25 L
.71765 .25 L
.71766 .25 L
.71766 .25 L
.71767 .25 L
.71767 .25 L
.71768 .25 L
.71769 .25 L
.71769 .25 L
.7177 .25 L
.7177 .25 L
.71771 .25 L
.71772 .25 L
.71772 .25 L
.71773 .25 L
.71773 .25 L
.71774 .25 L
Mistroke
.71775 .25 L
.71775 .25 L
.71776 .25 L
.71777 .25 L
.71777 .25 L
.71778 .25 L
.71778 .25 L
.71779 .25 L
.7178 .25 L
.7178 .25 L
.71781 .25 L
.71781 .25 L
.71781 .25 L
.71782 .25 L
.71783 .25 L
.71783 .25 L
.71784 .25 L
.71785 .25 L
.71785 .25 L
.71786 .25 L
.71786 .25 L
.71787 .25 L
.71788 .25 L
.71788 .25 L
.71789 .25 L
.7179 .25 L
.7179 .25 L
.71791 .25 L
.71792 .25 L
.71792 .25 L
.71793 .25 L
.71793 .25 L
.71794 .25 L
.71794 .25 L
.71794 .25 L
.71795 .25 L
.71795 .25 L
.71796 .25 L
.71796 .25 L
.71797 .25 L
.71797 .25 L
.71797 .25 L
.71798 .25 L
.71798 .25 L
.71798 .25 L
.71799 .25 L
.71799 .25 L
.718 .25 L
.71801 .25 L
.71801 .25 L
Mistroke
.71802 .25 L
.71803 .25 L
.71803 .25 L
.71804 .25 L
.71805 .25 L
.71805 .25 L
.71806 .25 L
.71806 .25 L
.71807 .25 L
.71808 .25 L
.71808 .25 L
.71809 .25 L
.71809 .25 L
.7181 .25 L
.71811 .25 L
.71811 .25 L
.71812 .25 L
.71812 .25 L
.71813 .25 L
.71814 .25 L
.71814 .25 L
.71815 .25 L
.71815 .25 L
.71816 .25 L
.71816 .25 L
.71817 .25 L
.71818 .25 L
.71818 .25 L
.71819 .25 L
.71819 .25 L
.7182 .25 L
.7182 .25 L
.71821 .25 L
.71822 .25 L
.71822 .25 L
.71823 .25 L
.71824 .25 L
.71824 .25 L
.71825 .25 L
.71825 .25 L
.71826 .25 L
.71827 .25 L
.71827 .25 L
.71828 .25 L
.71829 .25 L
.71829 .25 L
.71829 .25 L
.7183 .25 L
.71831 .25 L
.71831 .25 L
Mistroke
.71832 .25 L
.71833 .25 L
.71833 .25 L
.71834 .25 L
.71834 .25 L
.71835 .25 L
.71835 .25 L
.71836 .25 L
.71837 .25 L
.71837 .25 L
.71838 .25 L
.71839 .25 L
.71839 .25 L
.71839 .25 L
.7184 .25 L
.71841 .25 L
.71841 .25 L
.71842 .25 L
.71842 .25 L
.71843 .25 L
.71843 .25 L
.71844 .25 L
.71844 .25 L
.71845 .25 L
.71846 .25 L
.71846 .25 L
.71847 .25 L
.71847 .25 L
.71848 .25 L
.71848 .25 L
.71848 .25 L
.71849 .25 L
.7185 .25 L
.7185 .25 L
.71851 .25 L
.71852 .25 L
.71852 .25 L
.71853 .25 L
.71853 .25 L
.71854 .25 L
.71855 .25 L
.71855 .25 L
.71856 .25 L
.71856 .25 L
.71857 .25 L
.71858 .25 L
.71858 .25 L
.71859 .25 L
.7186 .25 L
.7186 .25 L
Mistroke
.71861 .25 L
.71862 .25 L
.71862 .25 L
.71863 .25 L
.71863 .25 L
.71863 .25 L
.71864 .25 L
.71864 .25 L
.71865 .25 L
.71866 .25 L
.71866 .25 L
.71867 .25 L
.71868 .25 L
.71868 .25 L
.71869 .25 L
.71869 .25 L
.7187 .25 L
.71871 .25 L
.71871 .25 L
.71872 .25 L
.71873 .25 L
.71873 .25 L
.71874 .25 L
.71875 .25 L
.71875 .25 L
.71875 .25 L
.71876 .25 L
.71876 .25 L
.71877 .25 L
.71877 .25 L
.71877 .25 L
.71878 .25 L
.71879 .25 L
.71879 .25 L
.71879 .25 L
.7188 .25 L
.7188 .25 L
.7188 .25 L
.71881 .25 L
.71881 .25 L
.71882 .25 L
.71882 .25 L
.71883 .25 L
.71884 .25 L
.71884 .25 L
.71885 .25 L
.71886 .25 L
.71886 .25 L
.71887 .25 L
.71887 .25 L
Mistroke
.71888 .25 L
.71889 .25 L
.71889 .25 L
.7189 .25 L
.71891 .25 L
.71891 .25 L
.71892 .25 L
.71892 .25 L
.71893 .25 L
.71893 .25 L
.71894 .25 L
.71895 .25 L
.71895 .25 L
.71896 .25 L
.71896 .25 L
.71897 .25 L
.71898 .25 L
.71898 .25 L
.71899 .25 L
.71899 .25 L
.719 .25 L
.71901 .25 L
.71901 .25 L
.71901 .25 L
.71902 .25 L
.71903 .25 L
.71903 .25 L
.71904 .25 L
.71905 .25 L
.71905 .25 L
.71906 .25 L
.71906 .25 L
.71907 .25 L
.71908 .25 L
.71908 .25 L
.71909 .25 L
.7191 .25 L
.7191 .25 L
.71911 .25 L
.71911 .25 L
.71912 .25 L
.71912 .25 L
.71913 .25 L
.71914 .25 L
.71914 .25 L
.71915 .25 L
.71916 .25 L
.71916 .25 L
.71917 .25 L
.71917 .25 L
Mistroke
.71918 .25 L
.71918 .25 L
.71919 .25 L
.7192 .25 L
.7192 .25 L
.71921 .25 L
.71921 .25 L
.71922 .25 L
.71922 .25 L
.71923 .25 L
.71924 .25 L
.71924 .25 L
.71925 .25 L
.71926 .25 L
.71926 .25 L
.71927 .25 L
.71927 .25 L
.71928 .25 L
.71929 .25 L
.71929 .25 L
.7193 .25 L
.71931 .25 L
.71931 .25 L
.71932 .25 L
.71932 .25 L
.71933 .25 L
.71933 .25 L
.71934 .25 L
.71935 .25 L
.71935 .25 L
.71936 .25 L
.71936 .25 L
.71937 .25 L
.71937 .25 L
.71938 .25 L
.71939 .25 L
.71939 .25 L
.7194 .25 L
.71941 .25 L
.71941 .25 L
.71942 .25 L
.71942 .25 L
.71943 .25 L
.71943 .25 L
.71944 .25 L
.71944 .25 L
.71945 .25 L
.71945 .25 L
.71946 .25 L
.71946 .25 L
Mistroke
.71947 .25 L
.71948 .25 L
.71948 .25 L
.71949 .25 L
.71949 .25 L
.7195 .25 L
.7195 .25 L
.71951 .25 L
.71951 .25 L
.71952 .25 L
.71952 .25 L
.71953 .25 L
.71954 .25 L
.71954 .25 L
.71955 .25 L
.71955 .25 L
.71956 .25 L
.71957 .25 L
.71957 .25 L
.71958 .25 L
.71958 .25 L
.71959 .25 L
.7196 .25 L
.7196 .25 L
.71961 .25 L
.71962 .25 L
.71962 .25 L
.71963 .25 L
.71963 .25 L
.71964 .25 L
.71965 .25 L
.71965 .25 L
.71966 .25 L
.71966 .25 L
.71966 .25 L
.71967 .25 L
.71968 .25 L
.71968 .25 L
.71969 .25 L
.7197 .25 L
.7197 .25 L
.71971 .25 L
.71971 .25 L
.71972 .25 L
.71973 .25 L
.71973 .25 L
.71974 .25 L
.71975 .25 L
.71975 .25 L
.71976 .25 L
Mistroke
.71976 .25 L
.71977 .25 L
.71978 .25 L
.71978 .25 L
.71979 .25 L
.71979 .25 L
.71979 .25 L
.7198 .25 L
.7198 .25 L
.71981 .25 L
.71981 .25 L
.71982 .25 L
.71982 .25 L
.71982 .25 L
.71983 .25 L
.71983 .25 L
.71983 .25 L
.71984 .25 L
.71984 .25 L
.71985 .25 L
.71986 .25 L
.71986 .25 L
.71987 .25 L
.71988 .25 L
.71988 .25 L
.71989 .25 L
.7199 .25 L
.7199 .25 L
.71991 .25 L
.71991 .25 L
.71992 .25 L
.71993 .25 L
.71993 .25 L
.71994 .25 L
.71994 .25 L
.71995 .25 L
.71996 .25 L
.71996 .25 L
.71997 .25 L
.71997 .25 L
.71998 .25 L
.71999 .25 L
.71999 .25 L
.72 .25 L
.72 .25 L
.72001 .25 L
.72001 .25 L
.72002 .25 L
.72003 .25 L
.72003 .25 L
Mistroke
.72004 .25 L
.72004 .25 L
.72005 .25 L
.72005 .25 L
.72006 .25 L
.72007 .25 L
.72007 .25 L
.72008 .25 L
.72009 .25 L
.72009 .25 L
.7201 .25 L
.7201 .25 L
.72011 .25 L
.72012 .25 L
.72012 .25 L
.72013 .25 L
.72014 .25 L
.72014 .25 L
.72014 .25 L
.72015 .25 L
.72016 .25 L
.72016 .25 L
.72017 .25 L
.72018 .25 L
.72018 .25 L
.72019 .25 L
.72019 .25 L
.7202 .25 L
.7202 .25 L
.72021 .25 L
.72022 .25 L
.72022 .25 L
.72023 .25 L
.72024 .25 L
.72024 .25 L
.72024 .25 L
.72025 .25 L
.72026 .25 L
.72026 .25 L
.72027 .25 L
.72027 .25 L
.72028 .25 L
.72028 .25 L
.72029 .25 L
.72029 .25 L
.7203 .25 L
.72031 .25 L
.72031 .25 L
.72032 .25 L
.72032 .25 L
Mistroke
.72033 .25 L
.72033 .25 L
.72033 .25 L
.72034 .25 L
.72035 .25 L
.72035 .25 L
.72036 .25 L
.72037 .25 L
.72037 .25 L
.72038 .25 L
.72038 .25 L
.72039 .25 L
.7204 .25 L
.7204 .25 L
.72041 .25 L
.72041 .25 L
.72042 .25 L
.72043 .25 L
.72043 .25 L
.72044 .25 L
.72045 .25 L
.72045 .25 L
.72046 .25 L
.72047 .25 L
.72047 .25 L
.72048 .25 L
.72048 .25 L
.72048 .25 L
.72049 .25 L
.72049 .25 L
.7205 .25 L
.72051 .25 L
.72051 .25 L
.72052 .25 L
.72053 .25 L
.72053 .25 L
.72054 .25 L
.72054 .25 L
.72055 .25 L
.72056 .25 L
.72056 .25 L
.72057 .25 L
.72058 .25 L
.72058 .25 L
.72059 .25 L
.7206 .25 L
.7206 .25 L
.7206 .25 L
.72061 .25 L
.72061 .25 L
Mistroke
.72062 .25 L
.72062 .25 L
.72062 .25 L
.72063 .25 L
.72064 .25 L
.72064 .25 L
.72064 .25 L
.72065 .25 L
.72065 .25 L
.72065 .25 L
.72066 .25 L
.72066 .25 L
.72067 .25 L
.72067 .25 L
.72068 .25 L
.72069 .25 L
.7207 .25 L
.7207 .25 L
.72071 .25 L
.72071 .25 L
.72072 .25 L
.72073 .25 L
.72073 .25 L
.72074 .25 L
.72074 .25 L
.72075 .25 L
.72076 .25 L
.72076 .25 L
.72077 .25 L
.72077 .25 L
.72078 .25 L
.72079 .25 L
.72079 .25 L
.7208 .25 L
.7208 .25 L
.72081 .25 L
.72081 .25 L
.72082 .25 L
.72083 .25 L
.72083 .25 L
.72084 .25 L
.72085 .25 L
.72085 .25 L
.72086 .25 L
.72086 .25 L
.72086 .25 L
.72087 .25 L
.72088 .25 L
.72088 .25 L
.72089 .25 L
Mistroke
.7209 .25 L
.7209 .25 L
.72091 .25 L
.72092 .25 L
.72092 .25 L
.72093 .25 L
.72093 .25 L
.72094 .25 L
.72095 .25 L
.72095 .25 L
.72096 .25 L
.72096 .25 L
.72097 .25 L
.72098 .25 L
.72098 .25 L
.72099 .25 L
.72099 .25 L
.721 .25 L
.72101 .25 L
.72101 .25 L
.72102 .25 L
.72102 .25 L
.72103 .25 L
.72103 .25 L
.72104 .25 L
.72105 .25 L
.72105 .25 L
.72106 .25 L
.72106 .25 L
.72107 .25 L
.72107 .25 L
.72108 .25 L
.72109 .25 L
.72109 .25 L
.72109 .25 L
.7211 .25 L
.72111 .25 L
.72111 .25 L
.72112 .25 L
.72112 .25 L
.72113 .25 L
.72114 .25 L
.72114 .25 L
.72114 .25 L
.72115 .25 L
.72116 .25 L
.72116 .25 L
.72117 .25 L
.72117 .25 L
.72118 .25 L
Mistroke
.72118 .25 L
.72119 .25 L
.7212 .25 L
.7212 .25 L
.72121 .25 L
.72121 .25 L
.72122 .25 L
.72123 .25 L
.72123 .25 L
.72124 .25 L
.72125 .25 L
.72125 .25 L
.72126 .25 L
.72126 .25 L
.72127 .25 L
.72128 .25 L
.72128 .25 L
.72129 .25 L
.7213 .25 L
.7213 .25 L
.7213 .25 L
.72131 .25 L
.72131 .25 L
.72132 .25 L
.72132 .25 L
.72133 .25 L
.72134 .25 L
.72134 .25 L
.72135 .25 L
.72136 .25 L
.72136 .25 L
.72137 .25 L
.72137 .25 L
.72138 .25 L
.72139 .25 L
.72139 .25 L
.7214 .25 L
.72141 .25 L
.72141 .25 L
.72142 .25 L
.72142 .25 L
.72143 .25 L
.72143 .25 L
.72144 .25 L
.72144 .25 L
.72144 .25 L
.72145 .25 L
.72146 .25 L
.72146 .25 L
.72146 .25 L
Mistroke
.72147 .25 L
.72147 .25 L
.72147 .25 L
.72148 .25 L
.72148 .25 L
.72149 .25 L
.72149 .25 L
.7215 .25 L
.72151 .25 L
.72151 .25 L
.72152 .25 L
.72153 .25 L
.72153 .25 L
.72154 .25 L
.72154 .25 L
.72155 .25 L
.72156 .25 L
.72156 .25 L
.72157 .25 L
.72158 .25 L
.72158 .25 L
.72159 .25 L
.72159 .25 L
.7216 .25 L
.7216 .25 L
.72161 .25 L
.72161 .25 L
.72162 .25 L
.72163 .25 L
.72163 .25 L
.72164 .25 L
.72164 .25 L
.72165 .25 L
.72166 .25 L
.72166 .25 L
.72167 .25 L
.72167 .25 L
.72168 .25 L
.72168 .25 L
.72169 .25 L
.72169 .25 L
.7217 .25 L
.72171 .25 L
.72171 .25 L
.72172 .25 L
.72173 .25 L
.72173 .25 L
.72174 .25 L
.72175 .25 L
.72175 .25 L
Mistroke
.72176 .25 L
.72176 .25 L
.72177 .25 L
.72178 .25 L
.72178 .25 L
.72179 .25 L
.72179 .25 L
.7218 .25 L
.72181 .25 L
.72181 .25 L
.72182 .25 L
.72182 .25 L
.72183 .25 L
.72184 .25 L
.72184 .25 L
.72185 .25 L
.72185 .25 L
.72186 .25 L
.72187 .25 L
.72187 .25 L
.72188 .25 L
.72188 .25 L
.72189 .25 L
.72189 .25 L
.7219 .25 L
.7219 .25 L
.72191 .25 L
.72191 .25 L
.72192 .25 L
.72192 .25 L
.72193 .25 L
.72194 .25 L
.72194 .25 L
.72195 .25 L
.72195 .25 L
.72196 .25 L
.72196 .25 L
.72197 .25 L
.72197 .25 L
.72198 .25 L
.72198 .25 L
.72199 .25 L
.722 .25 L
.722 .25 L
.72201 .25 L
.72201 .25 L
.72202 .25 L
.72203 .25 L
.72203 .25 L
.72204 .25 L
Mistroke
.72204 .25 L
.72205 .25 L
.72206 .25 L
.72206 .25 L
.72207 .25 L
.72207 .25 L
.72208 .25 L
.72209 .25 L
.72209 .25 L
.7221 .25 L
.72211 .25 L
.72211 .25 L
.72212 .25 L
.72212 .25 L
.72213 .25 L
.72213 .25 L
.72213 .25 L
.72214 .25 L
.72215 .25 L
.72215 .25 L
.72216 .25 L
.72217 .25 L
.72217 .25 L
.72218 .25 L
.72218 .25 L
.72219 .25 L
.7222 .25 L
.7222 .25 L
.72221 .25 L
.72222 .25 L
.72222 .25 L
.72223 .25 L
.72224 .25 L
.72224 .25 L
.72225 .25 L
.72225 .25 L
.72226 .25 L
.72226 .25 L
.72226 .25 L
.72227 .25 L
.72227 .25 L
.72228 .25 L
.72228 .25 L
.72229 .25 L
.72229 .25 L
.72229 .25 L
.7223 .25 L
.7223 .25 L
.72231 .25 L
.72231 .25 L
Mistroke
.72232 .25 L
.72232 .25 L
.72233 .25 L
.72234 .25 L
.72234 .25 L
.72235 .25 L
.72235 .25 L
.72236 .25 L
.72237 .25 L
.72237 .25 L
.72238 .25 L
.72239 .25 L
.72239 .25 L
.7224 .25 L
.72241 .25 L
.72241 .25 L
.72241 .25 L
.72242 .25 L
.72243 .25 L
.72243 .25 L
.72244 .25 L
.72244 .25 L
.72245 .25 L
.72246 .25 L
.72246 .25 L
.72247 .25 L
.72247 .25 L
.72248 .25 L
.72249 .25 L
.72249 .25 L
.7225 .25 L
.7225 .25 L
.72251 .25 L
.72251 .25 L
.72252 .25 L
.72252 .25 L
.72253 .25 L
.72254 .25 L
.72254 .25 L
.72255 .25 L
.72256 .25 L
.72256 .25 L
.72257 .25 L
.72257 .25 L
.72258 .25 L
.72259 .25 L
.72259 .25 L
.7226 .25 L
.72261 .25 L
.72261 .25 L
Mistroke
.72262 .25 L
.72262 .25 L
.72263 .25 L
.72263 .25 L
.72264 .25 L
.72265 .25 L
.72265 .25 L
.72266 .25 L
.72266 .25 L
.72267 .25 L
.72268 .25 L
.72268 .25 L
.72269 .25 L
.72269 .25 L
.7227 .25 L
.72271 .25 L
.72271 .25 L
.72271 .25 L
.72272 .25 L
.72273 .25 L
.72273 .25 L
.72274 .25 L
.72275 .25 L
.72275 .25 L
.72276 .25 L
.72276 .25 L
.72277 .25 L
.72278 .25 L
.72278 .25 L
.72279 .25 L
.7228 .25 L
.7228 .25 L
.72281 .25 L
.72281 .25 L
.72282 .25 L
.72283 .25 L
.72283 .25 L
.72284 .25 L
.72284 .25 L
.72285 .25 L
.72286 .25 L
.72286 .25 L
.72287 .25 L
.72287 .25 L
.72288 .25 L
.72288 .25 L
.72289 .25 L
.7229 .25 L
.7229 .25 L
.72291 .25 L
Mistroke
.72291 .25 L
.72292 .25 L
.72292 .25 L
.72293 .25 L
.72294 .25 L
.72294 .25 L
.72294 .25 L
.72295 .25 L
.72296 .25 L
.72296 .25 L
.72297 .25 L
.72297 .25 L
.72298 .25 L
.72299 .25 L
.72299 .25 L
.72299 .25 L
.723 .25 L
.723 .25 L
.72301 .25 L
.72301 .25 L
.72302 .25 L
.72303 .25 L
.72303 .25 L
.72304 .25 L
.72305 .25 L
.72305 .25 L
.72306 .25 L
.72306 .25 L
.72307 .25 L
.72308 .25 L
.72308 .25 L
.72309 .25 L
.72309 .25 L
.7231 .25 L
.72311 .25 L
.72311 .25 L
.72312 .25 L
.72313 .25 L
.72313 .25 L
.72314 .25 L
.72315 .25 L
.72315 .25 L
.72315 .25 L
.72316 .25 L
.72316 .25 L
.72317 .25 L
.72317 .25 L
.72318 .25 L
.72319 .25 L
.72319 .25 L
Mistroke
.7232 .25 L
.72321 .25 L
.72321 .25 L
.72322 .25 L
.72322 .25 L
.72323 .25 L
.72324 .25 L
.72324 .25 L
.72325 .25 L
.72326 .25 L
.72326 .25 L
.72327 .25 L
.72327 .25 L
.72328 .25 L
.72328 .25 L
.72329 .25 L
.72329 .25 L
.7233 .25 L
.7233 .25 L
.72331 .25 L
.72331 .25 L
.72331 .25 L
.72332 .25 L
.72332 .25 L
.72332 .25 L
.72333 .25 L
.72333 .25 L
.72334 .25 L
.72334 .25 L
.72335 .25 L
.72336 .25 L
.72336 .25 L
.72337 .25 L
.72338 .25 L
.72338 .25 L
.72339 .25 L
.72339 .25 L
.7234 .25 L
.72341 .25 L
.72341 .25 L
.72342 .25 L
.72343 .25 L
.72343 .25 L
.72344 .25 L
.72344 .25 L
.72345 .25 L
.72345 .25 L
.72346 .25 L
.72347 .25 L
.72347 .25 L
Mistroke
.72348 .25 L
.72348 .25 L
.72349 .25 L
.72349 .25 L
.7235 .25 L
.72351 .25 L
.72351 .25 L
.72352 .25 L
.72352 .25 L
.72353 .25 L
.72353 .25 L
.72354 .25 L
.72354 .25 L
.72355 .25 L
.72356 .25 L
.72356 .25 L
.72357 .25 L
.72358 .25 L
.72358 .25 L
.72359 .25 L
.7236 .25 L
.7236 .25 L
.72361 .25 L
.72362 .25 L
.72362 .25 L
.72363 .25 L
.72363 .25 L
.72364 .25 L
.72364 .25 L
.72365 .25 L
.72366 .25 L
.72366 .25 L
.72367 .25 L
.72367 .25 L
.72368 .25 L
.72369 .25 L
.72369 .25 L
.7237 .25 L
.7237 .25 L
.72371 .25 L
.72372 .25 L
.72372 .25 L
.72373 .25 L
.72373 .25 L
.72374 .25 L
.72374 .25 L
.72375 .25 L
.72375 .25 L
.72376 .25 L
.72376 .25 L
Mistroke
.72377 .25 L
.72377 .25 L
.72378 .25 L
.72379 .25 L
.72379 .25 L
.7238 .25 L
.7238 .25 L
.72381 .25 L
.72381 .25 L
.72382 .25 L
.72383 .25 L
.72383 .25 L
.72383 .25 L
.72384 .25 L
.72385 .25 L
.72385 .25 L
.72386 .25 L
.72386 .25 L
.72387 .25 L
.72388 .25 L
.72388 .25 L
.72389 .25 L
.72389 .25 L
.7239 .25 L
.72391 .25 L
.72391 .25 L
.72392 .25 L
.72392 .25 L
.72393 .25 L
.72394 .25 L
.72394 .25 L
.72395 .25 L
.72396 .25 L
.72396 .25 L
.72397 .25 L
.72397 .25 L
.72398 .25 L
.72398 .25 L
.72398 .25 L
.72399 .25 L
.724 .25 L
.724 .25 L
.72401 .25 L
.72402 .25 L
.72402 .25 L
.72403 .25 L
.72404 .25 L
.72404 .25 L
.72405 .25 L
.72406 .25 L
Mistroke
.72406 .25 L
.72407 .25 L
.72407 .25 L
.72408 .25 L
.72409 .25 L
.72409 .25 L
.7241 .25 L
.7241 .25 L
.72411 .25 L
.72411 .25 L
.72412 .25 L
.72412 .25 L
.72412 .25 L
.72413 .25 L
.72413 .25 L
.72414 .25 L
.72414 .25 L
.72415 .25 L
.72415 .25 L
.72415 .25 L
.72416 .25 L
.72416 .25 L
.72417 .25 L
.72417 .25 L
.72418 .25 L
.72419 .25 L
.72419 .25 L
.7242 .25 L
.72421 .25 L
.72421 .25 L
.72422 .25 L
.72422 .25 L
.72423 .25 L
.72424 .25 L
.72424 .25 L
.72425 .25 L
.72426 .25 L
.72426 .25 L
.72426 .25 L
.72427 .25 L
.72428 .25 L
.72428 .25 L
.72429 .25 L
.7243 .25 L
.7243 .25 L
.72431 .25 L
.72431 .25 L
.72432 .25 L
.72432 .25 L
.72433 .25 L
Mistroke
.72434 .25 L
.72434 .25 L
.72435 .25 L
.72436 .25 L
.72436 .25 L
.72436 .25 L
.72437 .25 L
.72438 .25 L
.72438 .25 L
.72439 .25 L
.7244 .25 L
.7244 .25 L
.72441 .25 L
.72441 .25 L
.72442 .25 L
.72443 .25 L
.72443 .25 L
.72444 .25 L
.72445 .25 L
.72445 .25 L
.72446 .25 L
.72446 .25 L
.72447 .25 L
.72447 .25 L
.72448 .25 L
.72449 .25 L
.72449 .25 L
.7245 .25 L
.7245 .25 L
.72451 .25 L
.72452 .25 L
.72452 .25 L
.72453 .25 L
.72453 .25 L
.72454 .25 L
.72455 .25 L
.72455 .25 L
.72456 .25 L
.72456 .25 L
.72456 .25 L
.72457 .25 L
.72458 .25 L
.72458 .25 L
.72459 .25 L
.72459 .25 L
.7246 .25 L
.7246 .25 L
.72461 .25 L
.72462 .25 L
.72462 .25 L
Mistroke
.72463 .25 L
.72464 .25 L
.72464 .25 L
.72464 .25 L
.72465 .25 L
.72465 .25 L
.72466 .25 L
.72466 .25 L
.72467 .25 L
.72468 .25 L
.72468 .25 L
.72469 .25 L
.72469 .25 L
.7247 .25 L
.72471 .25 L
.72471 .25 L
.72472 .25 L
.72472 .25 L
.72473 .25 L
.72474 .25 L
.72474 .25 L
.72475 .25 L
.72475 .25 L
.72476 .25 L
.72477 .25 L
.72477 .25 L
.72478 .25 L
.72479 .25 L
.72479 .25 L
.7248 .25 L
.7248 .25 L
.72481 .25 L
.72481 .25 L
.72482 .25 L
.72482 .25 L
.72483 .25 L
.72484 .25 L
.72484 .25 L
.72485 .25 L
.72485 .25 L
.72486 .25 L
.72487 .25 L
.72487 .25 L
.72488 .25 L
.72489 .25 L
.72489 .25 L
.7249 .25 L
.7249 .25 L
.72491 .25 L
.72492 .25 L
Mistroke
.72492 .25 L
.72493 .25 L
.72493 .25 L
.72494 .25 L
.72494 .25 L
.72494 .25 L
.72495 .25 L
.72495 .25 L
.72496 .25 L
.72496 .25 L
.72496 .25 L
.72497 .25 L
.72497 .25 L
.72498 .25 L
.72498 .25 L
.72498 .25 L
.72499 .25 L
.725 .25 L
.725 .25 L
.72501 .25 L
.72502 .25 L
.72502 .25 L
.72503 .25 L
.72503 .25 L
.72504 .25 L
.72505 .25 L
.72505 .25 L
.72506 .25 L
.72507 .25 L
.72507 .25 L
.72508 .25 L
.72508 .25 L
.72509 .25 L
.72509 .25 L
.7251 .25 L
.72511 .25 L
.72511 .25 L
.72512 .25 L
.72513 .25 L
.72513 .25 L
.72514 .25 L
.72514 .25 L
.72515 .25 L
.72515 .25 L
.72516 .25 L
.72517 .25 L
.72517 .25 L
.72518 .25 L
.72518 .25 L
.72519 .25 L
Mistroke
.72519 .25 L
.7252 .25 L
.72521 .25 L
.72521 .25 L
.72522 .25 L
.72523 .25 L
.72523 .25 L
.72524 .25 L
.72524 .25 L
.72525 .25 L
.72526 .25 L
.72526 .25 L
.72527 .25 L
.72528 .25 L
.72528 .25 L
.72529 .25 L
.72529 .25 L
.7253 .25 L
.7253 .25 L
.72531 .25 L
.72532 .25 L
.72532 .25 L
.72533 .25 L
.72533 .25 L
.72534 .25 L
.72534 .25 L
.72535 .25 L
.72536 .25 L
.72536 .25 L
.72537 .25 L
.72537 .25 L
.72538 .25 L
.72539 .25 L
.72539 .25 L
.72539 .25 L
.7254 .25 L
.72541 .25 L
.72541 .25 L
.72542 .25 L
.72542 .25 L
.72543 .25 L
.72543 .25 L
.72544 .25 L
.72545 .25 L
.72545 .25 L
.72546 .25 L
.72546 .25 L
.72547 .25 L
.72547 .25 L
.72548 .25 L
Mistroke
.72548 .25 L
.72549 .25 L
.72549 .25 L
.7255 .25 L
.72551 .25 L
.72551 .25 L
.72552 .25 L
.72552 .25 L
.72553 .25 L
.72554 .25 L
.72554 .25 L
.72555 .25 L
.72555 .25 L
.72556 .25 L
.72557 .25 L
.72557 .25 L
.72558 .25 L
.72558 .25 L
.72559 .25 L
.7256 .25 L
.7256 .25 L
.72561 .25 L
.72562 .25 L
.72562 .25 L
.72562 .25 L
.72563 .25 L
.72563 .25 L
.72564 .25 L
.72565 .25 L
.72565 .25 L
.72566 .25 L
.72566 .25 L
.72567 .25 L
.72568 .25 L
.72568 .25 L
.72569 .25 L
.7257 .25 L
.7257 .25 L
.72571 .25 L
.72572 .25 L
.72572 .25 L
.72573 .25 L
.72573 .25 L
.72574 .25 L
.72575 .25 L
.72575 .25 L
.72576 .25 L
.72576 .25 L
.72576 .25 L
.72577 .25 L
Mistroke
.72577 .25 L
.72578 .25 L
.72578 .25 L
.72578 .25 L
.72579 .25 L
.72579 .25 L
.7258 .25 L
.7258 .25 L
.7258 .25 L
.72581 .25 L
.72581 .25 L
.72582 .25 L
.72583 .25 L
.72583 .25 L
.72584 .25 L
.72585 .25 L
.72585 .25 L
.72586 .25 L
.72586 .25 L
.72587 .25 L
.72588 .25 L
.72588 .25 L
.72589 .25 L
.7259 .25 L
.7259 .25 L
.72591 .25 L
.72591 .25 L
.72592 .25 L
.72592 .25 L
.72593 .25 L
.72594 .25 L
.72594 .25 L
.72595 .25 L
.72595 .25 L
.72596 .25 L
.72597 .25 L
.72597 .25 L
.72598 .25 L
.72598 .25 L
.72599 .25 L
.726 .25 L
.726 .25 L
.72601 .25 L
.72601 .25 L
.72602 .25 L
.72602 .25 L
.72603 .25 L
.72604 .25 L
.72604 .25 L
.72605 .25 L
Mistroke
.72606 .25 L
.72606 .25 L
.72607 .25 L
.72607 .25 L
.72608 .25 L
.72609 .25 L
.72609 .25 L
.7261 .25 L
.72611 .25 L
.72611 .25 L
.72611 .25 L
.72612 .25 L
.72613 .25 L
.72613 .25 L
.72614 .25 L
.72615 .25 L
.72615 .25 L
.72616 .25 L
.72616 .25 L
.72617 .25 L
.72617 .25 L
.72618 .25 L
.72619 .25 L
.72619 .25 L
.7262 .25 L
.72621 .25 L
.72621 .25 L
.72621 .25 L
.72622 .25 L
.72623 .25 L
.72623 .25 L
.72624 .25 L
.72624 .25 L
.72624 .25 L
.72625 .25 L
.72626 .25 L
.72626 .25 L
.72627 .25 L
.72628 .25 L
.72628 .25 L
.72629 .25 L
.72629 .25 L
.7263 .25 L
.7263 .25 L
.7263 .25 L
.72631 .25 L
.72632 .25 L
.72632 .25 L
.72633 .25 L
.72634 .25 L
Mistroke
.72634 .25 L
.72635 .25 L
.72635 .25 L
.72636 .25 L
.72637 .25 L
.72637 .25 L
.72638 .25 L
.72638 .25 L
.72639 .25 L
.7264 .25 L
.7264 .25 L
.72641 .25 L
.72642 .25 L
.72642 .25 L
.72643 .25 L
.72643 .25 L
.72644 .25 L
.72644 .25 L
.72645 .25 L
.72645 .25 L
.72646 .25 L
.72646 .25 L
.72647 .25 L
.72648 .25 L
.72648 .25 L
.72649 .25 L
.72649 .25 L
.7265 .25 L
.72651 .25 L
.72651 .25 L
.72652 .25 L
.72653 .25 L
.72653 .25 L
.72654 .25 L
.72655 .25 L
.72655 .25 L
.72656 .25 L
.72656 .25 L
.72657 .25 L
.72657 .25 L
.72658 .25 L
.72658 .25 L
.72659 .25 L
.72659 .25 L
.72659 .25 L
.7266 .25 L
.7266 .25 L
.72661 .25 L
.72661 .25 L
.72662 .25 L
Mistroke
.72662 .25 L
.72662 .25 L
.72663 .25 L
.72663 .25 L
.72664 .25 L
.72664 .25 L
.72665 .25 L
.72666 .25 L
.72666 .25 L
.72667 .25 L
.72668 .25 L
.72668 .25 L
.72669 .25 L
.72669 .25 L
.7267 .25 L
.72671 .25 L
.72671 .25 L
.72672 .25 L
.72673 .25 L
.72673 .25 L
.72673 .25 L
.72674 .25 L
.72675 .25 L
.72675 .25 L
.72676 .25 L
.72677 .25 L
.72677 .25 L
.72678 .25 L
.72678 .25 L
.72679 .25 L
.72679 .25 L
.7268 .25 L
.72681 .25 L
.72681 .25 L
.72682 .25 L
.72683 .25 L
.72683 .25 L
.72683 .25 L
.72684 .25 L
.72685 .25 L
.72685 .25 L
.72686 .25 L
.72687 .25 L
.72687 .25 L
.72688 .25 L
.72688 .25 L
.72689 .25 L
.7269 .25 L
.7269 .25 L
.72691 .25 L
Mistroke
.72692 .25 L
.72692 .25 L
.72693 .25 L
.72693 .25 L
.72694 .25 L
.72694 .25 L
.72695 .25 L
.72696 .25 L
.72696 .25 L
.72697 .25 L
.72697 .25 L
.72698 .25 L
.72699 .25 L
.72699 .25 L
.727 .25 L
.727 .25 L
.72701 .25 L
.72702 .25 L
.72702 .25 L
.72703 .25 L
.72703 .25 L
.72704 .25 L
.72704 .25 L
.72705 .25 L
.72705 .25 L
.72706 .25 L
.72707 .25 L
.72707 .25 L
.72708 .25 L
.72709 .25 L
.72709 .25 L
.7271 .25 L
.72711 .25 L
.72711 .25 L
.72712 .25 L
.72712 .25 L
.72713 .25 L
.72714 .25 L
.72714 .25 L
.72715 .25 L
.72715 .25 L
.72716 .25 L
.72716 .25 L
.72717 .25 L
.72718 .25 L
.72718 .25 L
.72719 .25 L
.72719 .25 L
.7272 .25 L
.72721 .25 L
Mistroke
.72721 .25 L
.72722 .25 L
.72722 .25 L
.72723 .25 L
.72723 .25 L
.72724 .25 L
.72724 .25 L
.72725 .25 L
.72726 .25 L
.72726 .25 L
.72726 .25 L
.72727 .25 L
.72728 .25 L
.72728 .25 L
.72729 .25 L
.72729 .25 L
.7273 .25 L
.72731 .25 L
.72731 .25 L
.72732 .25 L
.72732 .25 L
.72733 .25 L
.72733 .25 L
.72734 .25 L
.72734 .25 L
.72735 .25 L
.72736 .25 L
.72736 .25 L
.72737 .25 L
.72737 .25 L
.72738 .25 L
.72738 .25 L
.72739 .25 L
.7274 .25 L
.7274 .25 L
.72741 .25 L
.72742 .25 L
.72742 .25 L
.72743 .25 L
.72743 .25 L
.72744 .25 L
.72745 .25 L
.72745 .25 L
.72746 .25 L
.72747 .25 L
.72747 .25 L
.72747 .25 L
.72748 .25 L
.72748 .25 L
.72749 .25 L
Mistroke
.72749 .25 L
.7275 .25 L
.72751 .25 L
.72751 .25 L
.72752 .25 L
.72753 .25 L
.72753 .25 L
.72754 .25 L
.72755 .25 L
.72755 .25 L
.72756 .25 L
.72756 .25 L
.72757 .25 L
.72758 .25 L
.72758 .25 L
.72759 .25 L
.7276 .25 L
.7276 .25 L
.72761 .25 L
.72761 .25 L
.72761 .25 L
.72762 .25 L
.72762 .25 L
.72763 .25 L
.72763 .25 L
.72763 .25 L
.72764 .25 L
.72764 .25 L
.72765 .25 L
.72765 .25 L
.72765 .25 L
.72766 .25 L
.72766 .25 L
.72767 .25 L
.72768 .25 L
.72768 .25 L
.72769 .25 L
.7277 .25 L
.7277 .25 L
.72771 .25 L
.72771 .25 L
.72772 .25 L
.72773 .25 L
.72773 .25 L
.72774 .25 L
.72775 .25 L
.72775 .25 L
.72776 .25 L
.72776 .25 L
.72777 .25 L
Mistroke
.72777 .25 L
.72778 .25 L
.72779 .25 L
.72779 .25 L
.7278 .25 L
.7278 .25 L
.72781 .25 L
.72782 .25 L
.72782 .25 L
.72783 .25 L
.72783 .25 L
.72784 .25 L
.72785 .25 L
.72785 .25 L
.72786 .25 L
.72786 .25 L
.72787 .25 L
.72787 .25 L
.72788 .25 L
.72789 .25 L
.72789 .25 L
.7279 .25 L
.7279 .25 L
.72791 .25 L
.72792 .25 L
.72792 .25 L
.72793 .25 L
.72794 .25 L
.72794 .25 L
.72795 .25 L
.72796 .25 L
.72796 .25 L
.72796 .25 L
.72797 .25 L
.72798 .25 L
.72798 .25 L
.72799 .25 L
.728 .25 L
.728 .25 L
.72801 .25 L
.72801 .25 L
.72802 .25 L
.72802 .25 L
.72803 .25 L
.72804 .25 L
.72804 .25 L
.72805 .25 L
.72805 .25 L
.72806 .25 L
.72806 .25 L
Mistroke
.72807 .25 L
.72807 .25 L
.72808 .25 L
.72809 .25 L
.72809 .25 L
.72809 .25 L
.7281 .25 L
.72811 .25 L
.72811 .25 L
.72812 .25 L
.72813 .25 L
.72813 .25 L
.72814 .25 L
.72814 .25 L
.72815 .25 L
.72815 .25 L
.72815 .25 L
.72816 .25 L
.72817 .25 L
.72817 .25 L
.72818 .25 L
.72819 .25 L
.72819 .25 L
.7282 .25 L
.7282 .25 L
.72821 .25 L
.72822 .25 L
.72822 .25 L
.72823 .25 L
.72823 .25 L
.72824 .25 L
.72825 .25 L
.72825 .25 L
.72826 .25 L
.72827 .25 L
.72827 .25 L
.72828 .25 L
.72828 .25 L
.72829 .25 L
.72829 .25 L
.7283 .25 L
.7283 .25 L
.72831 .25 L
.72831 .25 L
.72832 .25 L
.72833 .25 L
.72833 .25 L
.72834 .25 L
.72834 .25 L
.72835 .25 L
Mistroke
.72836 .25 L
.72836 .25 L
.72837 .25 L
.72838 .25 L
.72838 .25 L
.72839 .25 L
.7284 .25 L
.7284 .25 L
.72841 .25 L
.72842 .25 L
.72842 .25 L
.72842 .25 L
.72843 .25 L
.72843 .25 L
.72844 .25 L
.72844 .25 L
.72844 .25 L
.72845 .25 L
.72845 .25 L
.72846 .25 L
.72846 .25 L
.72847 .25 L
.72847 .25 L
.72847 .25 L
.72848 .25 L
.72848 .25 L
.72849 .25 L
.72849 .25 L
.7285 .25 L
.72851 .25 L
.72851 .25 L
.72852 .25 L
.72853 .25 L
.72853 .25 L
.72854 .25 L
.72854 .25 L
.72855 .25 L
.72856 .25 L
.72856 .25 L
.72857 .25 L
.72858 .25 L
.72858 .25 L
.72858 .25 L
.72859 .25 L
.7286 .25 L
.7286 .25 L
.72861 .25 L
.72862 .25 L
.72862 .25 L
.72863 .25 L
Mistroke
.72863 .25 L
.72864 .25 L
.72865 .25 L
.72865 .25 L
.72866 .25 L
.72866 .25 L
.72867 .25 L
.72868 .25 L
.72868 .25 L
.72868 .25 L
.72869 .25 L
.7287 .25 L
.7287 .25 L
.72871 .25 L
.72872 .25 L
.72872 .25 L
.72873 .25 L
.72873 .25 L
.72874 .25 L
.72875 .25 L
.72875 .25 L
.72876 .25 L
.72877 .25 L
.72877 .25 L
.72878 .25 L
.72878 .25 L
.72879 .25 L
.72879 .25 L
.7288 .25 L
.72881 .25 L
.72881 .25 L
.72882 .25 L
.72883 .25 L
.72883 .25 L
.72884 .25 L
.72884 .25 L
.72885 .25 L
.72885 .25 L
.72886 .25 L
.72887 .25 L
.72887 .25 L
.72888 .25 L
.72888 .25 L
.72889 .25 L
.72889 .25 L
.7289 .25 L
.72891 .25 L
.72891 .25 L
.72891 .25 L
.72892 .25 L
Mistroke
.72893 .25 L
.72893 .25 L
.72894 .25 L
.72894 .25 L
.72895 .25 L
.72896 .25 L
.72896 .25 L
.72896 .25 L
.72897 .25 L
.72897 .25 L
.72898 .25 L
.72898 .25 L
.72899 .25 L
.729 .25 L
.729 .25 L
.72901 .25 L
.72902 .25 L
.72902 .25 L
.72903 .25 L
.72903 .25 L
.72904 .25 L
.72905 .25 L
.72905 .25 L
.72906 .25 L
.72906 .25 L
.72907 .25 L
.72908 .25 L
.72908 .25 L
.72909 .25 L
.7291 .25 L
.7291 .25 L
.72911 .25 L
.72912 .25 L
.72912 .25 L
.72912 .25 L
.72913 .25 L
.72913 .25 L
.72914 .25 L
.72914 .25 L
.72915 .25 L
.72916 .25 L
.72916 .25 L
.72917 .25 L
.72917 .25 L
.72918 .25 L
.72919 .25 L
.72919 .25 L
.7292 .25 L
.72921 .25 L
.72921 .25 L
Mistroke
.72922 .25 L
.72923 .25 L
.72923 .25 L
.72924 .25 L
.72924 .25 L
.72925 .25 L
.72925 .25 L
.72926 .25 L
.72926 .25 L
.72926 .25 L
.72927 .25 L
.72927 .25 L
.72928 .25 L
.72928 .25 L
.72929 .25 L
.72929 .25 L
.72929 .25 L
.7293 .25 L
.7293 .25 L
.7293 .25 L
.72931 .25 L
.72932 .25 L
.72932 .25 L
.72933 .25 L
.72934 .25 L
.72934 .25 L
.72935 .25 L
.72936 .25 L
.72936 .25 L
.72937 .25 L
.72937 .25 L
.72938 .25 L
.72939 .25 L
.72939 .25 L
.7294 .25 L
.7294 .25 L
.72941 .25 L
.72942 .25 L
.72942 .25 L
.72943 .25 L
.72943 .25 L
.72944 .25 L
.72945 .25 L
.72945 .25 L
.72946 .25 L
.72946 .25 L
.72947 .25 L
.72948 .25 L
.72948 .25 L
.72949 .25 L
Mistroke
.72949 .25 L
.7295 .25 L
.7295 .25 L
.72951 .25 L
.72951 .25 L
.72952 .25 L
.72953 .25 L
.72953 .25 L
.72954 .25 L
.72955 .25 L
.72955 .25 L
.72956 .25 L
.72956 .25 L
.72957 .25 L
.72958 .25 L
.72958 .25 L
.72959 .25 L
.7296 .25 L
.7296 .25 L
.72961 .25 L
.72961 .25 L
.72962 .25 L
.72962 .25 L
.72963 .25 L
.72964 .25 L
.72964 .25 L
.72965 .25 L
.72965 .25 L
.72966 .25 L
.72967 .25 L
.72967 .25 L
.72968 .25 L
.72968 .25 L
.72969 .25 L
.7297 .25 L
.7297 .25 L
.72971 .25 L
.72971 .25 L
.72972 .25 L
.72972 .25 L
.72973 .25 L
.72973 .25 L
.72974 .25 L
.72974 .25 L
.72975 .25 L
.72975 .25 L
.72976 .25 L
.72977 .25 L
.72977 .25 L
.72978 .25 L
Mistroke
.72978 .25 L
.72979 .25 L
.72979 .25 L
.7298 .25 L
.7298 .25 L
.72981 .25 L
.72981 .25 L
.72982 .25 L
.72983 .25 L
.72983 .25 L
.72984 .25 L
.72984 .25 L
.72985 .25 L
.72986 .25 L
.72986 .25 L
.72987 .25 L
.72987 .25 L
.72988 .25 L
.72989 .25 L
.72989 .25 L
.7299 .25 L
.72991 .25 L
.72991 .25 L
.72992 .25 L
.72993 .25 L
.72993 .25 L
.72994 .25 L
.72994 .25 L
.72995 .25 L
.72995 .25 L
.72995 .25 L
.72996 .25 L
.72997 .25 L
.72997 .25 L
.72998 .25 L
.72999 .25 L
.72999 .25 L
.73 .25 L
.73 .25 L
.73001 .25 L
.73002 .25 L
.73002 .25 L
.73003 .25 L
.73004 .25 L
.73004 .25 L
.73005 .25 L
.73006 .25 L
.73006 .25 L
.73007 .25 L
.73007 .25 L
Mistroke
.73008 .25 L
.73008 .25 L
.73008 .25 L
.73009 .25 L
.73009 .25 L
.7301 .25 L
.7301 .25 L
.73011 .25 L
.73011 .25 L
.73011 .25 L
.73012 .25 L
.73012 .25 L
.73012 .25 L
.73013 .25 L
.73013 .25 L
.73014 .25 L
.73015 .25 L
.73015 .25 L
.73016 .25 L
.73017 .25 L
.73017 .25 L
.73018 .25 L
.73019 .25 L
.73019 .25 L
.7302 .25 L
.7302 .25 L
.73021 .25 L
.73022 .25 L
.73022 .25 L
.73023 .25 L
.73023 .25 L
.73024 .25 L
.73025 .25 L
.73025 .25 L
.73026 .25 L
.73026 .25 L
.73027 .25 L
.73028 .25 L
.73028 .25 L
.73029 .25 L
.73029 .25 L
.7303 .25 L
.7303 .25 L
.73031 .25 L
.73032 .25 L
.73032 .25 L
.73033 .25 L
.73033 .25 L
.73034 .25 L
.73034 .25 L
Mistroke
.73035 .25 L
.73036 .25 L
.73036 .25 L
.73037 .25 L
.73038 .25 L
.73038 .25 L
.73039 .25 L
.73039 .25 L
.7304 .25 L
.73041 .25 L
.73041 .25 L
.73042 .25 L
.73043 .25 L
.73043 .25 L
.73043 .25 L
.73044 .25 L
.73045 .25 L
.73045 .25 L
.73046 .25 L
.73047 .25 L
.73047 .25 L
.73048 .25 L
.73048 .25 L
.73049 .25 L
.73049 .25 L
.7305 .25 L
.73051 .25 L
.73051 .25 L
.73052 .25 L
.73053 .25 L
.73053 .25 L
.73053 .25 L
.73054 .25 L
.73055 .25 L
.73055 .25 L
.73056 .25 L
.73057 .25 L
.73057 .25 L
.73058 .25 L
.73058 .25 L
.73059 .25 L
.7306 .25 L
.7306 .25 L
.73061 .25 L
.73062 .25 L
.73062 .25 L
.73063 .25 L
.73063 .25 L
.73064 .25 L
.73064 .25 L
Mistroke
.73065 .25 L
.73066 .25 L
.73066 .25 L
.73067 .25 L
.73067 .25 L
.73068 .25 L
.73069 .25 L
.73069 .25 L
.7307 .25 L
.7307 .25 L
.73071 .25 L
.73072 .25 L
.73072 .25 L
.73073 .25 L
.73073 .25 L
.73074 .25 L
.73074 .25 L
.73075 .25 L
.73075 .25 L
.73076 .25 L
.73076 .25 L
.73077 .25 L
.73077 .25 L
.73078 .25 L
.73079 .25 L
.73079 .25 L
.7308 .25 L
.73081 .25 L
.73081 .25 L
.73081 .25 L
.73082 .25 L
.73082 .25 L
.73083 .25 L
.73083 .25 L
.73084 .25 L
.73085 .25 L
.73085 .25 L
.73086 .25 L
.73086 .25 L
.73087 .25 L
.73088 .25 L
.73088 .25 L
.73089 .25 L
.73089 .25 L
.7309 .25 L
.73091 .25 L
.73091 .25 L
.73092 .25 L
.73093 .25 L
.73093 .25 L
Mistroke
.73094 .25 L
.73094 .25 L
.73095 .25 L
.73096 .25 L
.73096 .25 L
.73097 .25 L
.73097 .25 L
.73098 .25 L
.73098 .25 L
.73099 .25 L
.73099 .25 L
.731 .25 L
.73101 .25 L
.73101 .25 L
.73102 .25 L
.73102 .25 L
.73103 .25 L
.73104 .25 L
.73104 .25 L
.73105 .25 L
.73106 .25 L
.73106 .25 L
.73107 .25 L
.73108 .25 L
.73108 .25 L
.73109 .25 L
.73109 .25 L
.7311 .25 L
.7311 .25 L
.73111 .25 L
.73111 .25 L
.73111 .25 L
.73112 .25 L
.73112 .25 L
.73113 .25 L
.73113 .25 L
.73114 .25 L
.73114 .25 L
.73114 .25 L
.73115 .25 L
.73115 .25 L
.73115 .25 L
.73116 .25 L
.73117 .25 L
.73117 .25 L
.73118 .25 L
.73119 .25 L
.73119 .25 L
.7312 .25 L
.73121 .25 L
Mistroke
.73121 .25 L
.73122 .25 L
.73122 .25 L
.73123 .25 L
.73124 .25 L
.73124 .25 L
.73125 .25 L
.73125 .25 L
.73126 .25 L
.73127 .25 L
.73127 .25 L
.73128 .25 L
.73128 .25 L
.73129 .25 L
.7313 .25 L
.7313 .25 L
.73131 .25 L
.73131 .25 L
.73132 .25 L
.73132 .25 L
.73133 .25 L
.73134 .25 L
.73134 .25 L
.73135 .25 L
.73135 .25 L
.73136 .25 L
.73136 .25 L
.73137 .25 L
.73138 .25 L
.73138 .25 L
.73139 .25 L
.7314 .25 L
.7314 .25 L
.73141 .25 L
.73141 .25 L
.73142 .25 L
.73143 .25 L
.73143 .25 L
.73144 .25 L
.73145 .25 L
.73145 .25 L
.73146 .25 L
.73146 .25 L
.73147 .25 L
.73147 .25 L
.73148 .25 L
.73149 .25 L
.73149 .25 L
.7315 .25 L
.7315 .25 L
Mistroke
.73151 .25 L
.73152 .25 L
.73152 .25 L
.73153 .25 L
.73153 .25 L
.73154 .25 L
.73155 .25 L
.73155 .25 L
.73156 .25 L
.73156 .25 L
.73157 .25 L
.73157 .25 L
.73158 .25 L
.73158 .25 L
.73159 .25 L
.73159 .25 L
.7316 .25 L
.7316 .25 L
.73161 .25 L
.73162 .25 L
.73162 .25 L
.73163 .25 L
.73163 .25 L
.73164 .25 L
.73164 .25 L
.73165 .25 L
.73165 .25 L
.73166 .25 L
.73166 .25 L
.73167 .25 L
.73168 .25 L
.73168 .25 L
.73169 .25 L
.73169 .25 L
.7317 .25 L
.73171 .25 L
.73171 .25 L
.73172 .25 L
.73172 .25 L
.73173 .25 L
.73174 .25 L
.73174 .25 L
.73175 .25 L
.73176 .25 L
.73176 .25 L
.73177 .25 L
.73178 .25 L
.73178 .25 L
.73179 .25 L
.73179 .25 L
Mistroke
.7318 .25 L
.7318 .25 L
.7318 .25 L
.73181 .25 L
.73182 .25 L
.73182 .25 L
.73183 .25 L
.73184 .25 L
.73184 .25 L
.73185 .25 L
.73185 .25 L
.73186 .25 L
.73187 .25 L
.73187 .25 L
.73188 .25 L
.73189 .25 L
.73189 .25 L
.7319 .25 L
.73191 .25 L
.73191 .25 L
.73192 .25 L
.73192 .25 L
.73193 .25 L
.73193 .25 L
.73193 .25 L
.73194 .25 L
.73194 .25 L
.73195 .25 L
.73195 .25 L
.73196 .25 L
.73196 .25 L
.73196 .25 L
.73197 .25 L
.73197 .25 L
.73197 .25 L
.73198 .25 L
.73198 .25 L
.73199 .25 L
.732 .25 L
.732 .25 L
.73201 .25 L
.73202 .25 L
.73202 .25 L
.73203 .25 L
.73204 .25 L
.73204 .25 L
.73205 .25 L
.73206 .25 L
.73206 .25 L
.73207 .25 L
Mistroke
.73207 .25 L
.73208 .25 L
.73208 .25 L
.73209 .25 L
.7321 .25 L
.7321 .25 L
.73211 .25 L
.73211 .25 L
.73212 .25 L
.73213 .25 L
.73213 .25 L
.73214 .25 L
.73214 .25 L
.73215 .25 L
.73216 .25 L
.73216 .25 L
.73217 .25 L
.73217 .25 L
.73218 .25 L
.73218 .25 L
.73219 .25 L
.73219 .25 L
.7322 .25 L
.73221 .25 L
.73221 .25 L
.73222 .25 L
.73223 .25 L
.73223 .25 L
.73224 .25 L
.73224 .25 L
.73225 .25 L
.73226 .25 L
.73226 .25 L
.73227 .25 L
.73228 .25 L
.73228 .25 L
.73228 .25 L
.73229 .25 L
.7323 .25 L
.7323 .25 L
.73231 .25 L
.73232 .25 L
.73232 .25 L
.73233 .25 L
.73233 .25 L
.73234 .25 L
.73235 .25 L
.73235 .25 L
.73236 .25 L
.73236 .25 L
Mistroke
.73237 .25 L
.73238 .25 L
.73238 .25 L
.73238 .25 L
.73239 .25 L
.7324 .25 L
.7324 .25 L
.73241 .25 L
.73241 .25 L
.73242 .25 L
.73242 .25 L
.73243 .25 L
.73243 .25 L
.73244 .25 L
.73245 .25 L
.73245 .25 L
.73246 .25 L
.73246 .25 L
.73247 .25 L
.73247 .25 L
.73248 .25 L
.73248 .25 L
.73249 .25 L
.7325 .25 L
.7325 .25 L
.73251 .25 L
.73251 .25 L
.73252 .25 L
.73252 .25 L
.73253 .25 L
.73254 .25 L
.73254 .25 L
.73255 .25 L
.73256 .25 L
.73256 .25 L
.73257 .25 L
.73257 .25 L
.73258 .25 L
.73259 .25 L
.73259 .25 L
.7326 .25 L
.73261 .25 L
.73261 .25 L
.73262 .25 L
.73262 .25 L
.73262 .25 L
.73263 .25 L
.73263 .25 L
.73264 .25 L
.73265 .25 L
Mistroke
.73265 .25 L
.73266 .25 L
.73267 .25 L
.73267 .25 L
.73268 .25 L
.73268 .25 L
.73269 .25 L
.7327 .25 L
.7327 .25 L
.73271 .25 L
.73272 .25 L
.73272 .25 L
.73273 .25 L
.73274 .25 L
.73274 .25 L
.73274 .25 L
.73275 .25 L
.73275 .25 L
.73276 .25 L
.73276 .25 L
.73277 .25 L
.73277 .25 L
.73278 .25 L
.73278 .25 L
.73278 .25 L
.73279 .25 L
.73279 .25 L
.73279 .25 L
.7328 .25 L
.7328 .25 L
.73281 .25 L
.73282 .25 L
.73282 .25 L
.73283 .25 L
.73284 .25 L
.73284 .25 L
.73285 .25 L
.73285 .25 L
.73286 .25 L
.73287 .25 L
.73287 .25 L
.73288 .25 L
.73288 .25 L
.73289 .25 L
.7329 .25 L
.7329 .25 L
.73291 .25 L
.73291 .25 L
.73292 .25 L
.73293 .25 L
Mistroke
.73293 .25 L
.73294 .25 L
.73294 .25 L
.73295 .25 L
.73295 .25 L
.73296 .25 L
.73297 .25 L
.73297 .25 L
.73298 .25 L
.73299 .25 L
.73299 .25 L
.733 .25 L
.733 .25 L
.733 .25 L
.73301 .25 L
.73302 .25 L
.73302 .25 L
.73303 .25 L
.73304 .25 L
.73304 .25 L
.73305 .25 L
.73306 .25 L
.73306 .25 L
.73307 .25 L
.73307 .25 L
.73308 .25 L
.73309 .25 L
.73309 .25 L
.7331 .25 L
.7331 .25 L
.73311 .25 L
.73312 .25 L
.73312 .25 L
.73313 .25 L
.73313 .25 L
.73314 .25 L
.73315 .25 L
.73315 .25 L
.73316 .25 L
.73316 .25 L
.73317 .25 L
.73317 .25 L
.73318 .25 L
.73319 .25 L
.73319 .25 L
.7332 .25 L
.7332 .25 L
.73321 .25 L
.73321 .25 L
.73322 .25 L
Mistroke
.73323 .25 L
.73323 .25 L
.73323 .25 L
.73324 .25 L
.73325 .25 L
.73325 .25 L
.73326 .25 L
.73326 .25 L
.73327 .25 L
.73328 .25 L
.73328 .25 L
.73328 .25 L
.73329 .25 L
.7333 .25 L
.7333 .25 L
.73331 .25 L
.73331 .25 L
.73332 .25 L
.73332 .25 L
.73333 .25 L
.73334 .25 L
.73334 .25 L
.73335 .25 L
.73335 .25 L
.73336 .25 L
.73337 .25 L
.73337 .25 L
.73338 .25 L
.73338 .25 L
.73339 .25 L
.7334 .25 L
.7334 .25 L
.73341 .25 L
.73342 .25 L
.73342 .25 L
.73343 .25 L
.73344 .25 L
.73344 .25 L
.73344 .25 L
.73345 .25 L
.73345 .25 L
.73346 .25 L
.73346 .25 L
.73347 .25 L
.73348 .25 L
.73348 .25 L
.73349 .25 L
.7335 .25 L
.7335 .25 L
.73351 .25 L
Mistroke
.73351 .25 L
.73352 .25 L
.73353 .25 L
.73353 .25 L
.73354 .25 L
.73355 .25 L
.73355 .25 L
.73356 .25 L
.73356 .25 L
.73357 .25 L
.73357 .25 L
.73358 .25 L
.73358 .25 L
.73358 .25 L
.73359 .25 L
.7336 .25 L
.7336 .25 L
.7336 .25 L
.73361 .25 L
.73361 .25 L
.73361 .25 L
.73362 .25 L
.73362 .25 L
.73363 .25 L
.73363 .25 L
.73364 .25 L
.73365 .25 L
.73365 .25 L
.73366 .25 L
.73366 .25 L
.73367 .25 L
.73368 .25 L
.73368 .25 L
.73369 .25 L
.7337 .25 L
.7337 .25 L
.73371 .25 L
.73371 .25 L
.73372 .25 L
.73373 .25 L
.73373 .25 L
.73374 .25 L
.73374 .25 L
.73375 .25 L
.73375 .25 L
.73376 .25 L
.73377 .25 L
.73377 .25 L
.73378 .25 L
.73378 .25 L
Mistroke
.73379 .25 L
.7338 .25 L
.7338 .25 L
.73381 .25 L
.73381 .25 L
.73382 .25 L
.73382 .25 L
.73383 .25 L
.73383 .25 L
.73384 .25 L
.73385 .25 L
.73385 .25 L
.73386 .25 L
.73387 .25 L
.73387 .25 L
.73388 .25 L
.73389 .25 L
.73389 .25 L
.7339 .25 L
.7339 .25 L
.73391 .25 L
.73392 .25 L
.73392 .25 L
.73393 .25 L
.73393 .25 L
.73394 .25 L
.73395 .25 L
.73395 .25 L
.73396 .25 L
.73396 .25 L
.73397 .25 L
.73398 .25 L
.73398 .25 L
.73399 .25 L
.73399 .25 L
.734 .25 L
.734 .25 L
.73401 .25 L
.73402 .25 L
.73402 .25 L
.73403 .25 L
.73403 .25 L
.73404 .25 L
.73404 .25 L
.73405 .25 L
.73406 .25 L
.73406 .25 L
.73407 .25 L
.73408 .25 L
.73408 .25 L
Mistroke
.73409 .25 L
.73409 .25 L
.7341 .25 L
.73411 .25 L
.73411 .25 L
.73412 .25 L
.73413 .25 L
.73413 .25 L
.73413 .25 L
.73414 .25 L
.73415 .25 L
.73415 .25 L
.73416 .25 L
.73417 .25 L
.73417 .25 L
.73418 .25 L
.73418 .25 L
.73419 .25 L
.73419 .25 L
.7342 .25 L
.73421 .25 L
.73421 .25 L
.73422 .25 L
.73423 .25 L
.73423 .25 L
.73423 .25 L
.73424 .25 L
.73425 .25 L
.73425 .25 L
.73426 .25 L
.73426 .25 L
.73427 .25 L
.73427 .25 L
.73428 .25 L
.73428 .25 L
.73429 .25 L
.7343 .25 L
.7343 .25 L
.73431 .25 L
.73431 .25 L
.73432 .25 L
.73432 .25 L
.73432 .25 L
.73433 .25 L
.73434 .25 L
.73434 .25 L
.73435 .25 L
.73436 .25 L
.73436 .25 L
.73437 .25 L
Mistroke
.73437 .25 L
.73438 .25 L
.73439 .25 L
.73439 .25 L
.7344 .25 L
.73441 .25 L
.73441 .25 L
.73442 .25 L
.73442 .25 L
.73443 .25 L
.73444 .25 L
.73444 .25 L
.73445 .25 L
.73446 .25 L
.73446 .25 L
.73447 .25 L
.73447 .25 L
.73447 .25 L
.73448 .25 L
.73448 .25 L
.73449 .25 L
.7345 .25 L
.7345 .25 L
.73451 .25 L
.73452 .25 L
.73452 .25 L
.73453 .25 L
.73453 .25 L
.73454 .25 L
.73455 .25 L
.73455 .25 L
.73456 .25 L
.73457 .25 L
.73457 .25 L
.73458 .25 L
.73459 .25 L
.73459 .25 L
.73459 .25 L
.7346 .25 L
.7346 .25 L
.73461 .25 L
.73461 .25 L
.73462 .25 L
.73462 .25 L
.73463 .25 L
.73463 .25 L
.73463 .25 L
.73464 .25 L
.73464 .25 L
.73464 .25 L
Mistroke
.73465 .25 L
.73465 .25 L
.73466 .25 L
.73467 .25 L
.73467 .25 L
.73468 .25 L
.73469 .25 L
.73469 .25 L
.7347 .25 L
.7347 .25 L
.73471 .25 L
.73472 .25 L
.73472 .25 L
.73473 .25 L
.73473 .25 L
.73474 .25 L
.73475 .25 L
.73475 .25 L
.73476 .25 L
.73476 .25 L
.73477 .25 L
.73478 .25 L
.73478 .25 L
.73479 .25 L
.73479 .25 L
.7348 .25 L
.7348 .25 L
.73481 .25 L
.73482 .25 L
.73482 .25 L
.73483 .25 L
.73484 .25 L
.73484 .25 L
.73485 .25 L
.73485 .25 L
.73485 .25 L
.73486 .25 L
.73487 .25 L
.73487 .25 L
.73488 .25 L
.73489 .25 L
.73489 .25 L
.7349 .25 L
.73491 .25 L
.73491 .25 L
.73492 .25 L
.73492 .25 L
.73493 .25 L
.73494 .25 L
.73494 .25 L
Mistroke
.73495 .25 L
.73495 .25 L
.73496 .25 L
.73497 .25 L
.73497 .25 L
.73498 .25 L
.73498 .25 L
.73499 .25 L
.735 .25 L
.735 .25 L
.73501 .25 L
.73501 .25 L
.73502 .25 L
.73503 .25 L
.73503 .25 L
.73504 .25 L
.73504 .25 L
.73505 .25 L
.73505 .25 L
.73506 .25 L
.73506 .25 L
.73507 .25 L
.73508 .25 L
.73508 .25 L
.73508 .25 L
.73509 .25 L
.7351 .25 L
.7351 .25 L
.73511 .25 L
.73511 .25 L
.73512 .25 L
.73513 .25 L
.73513 .25 L
.73513 .25 L
.73514 .25 L
.73515 .25 L
.73515 .25 L
.73516 .25 L
.73516 .25 L
.73517 .25 L
.73517 .25 L
.73518 .25 L
.73519 .25 L
.73519 .25 L
.7352 .25 L
.7352 .25 L
.73521 .25 L
.73522 .25 L
.73522 .25 L
.73523 .25 L
Mistroke
.73524 .25 L
.73524 .25 L
.73525 .25 L
.73525 .25 L
.73526 .25 L
.73527 .25 L
.73527 .25 L
.73528 .25 L
.73529 .25 L
.73529 .25 L
.73529 .25 L
.7353 .25 L
.7353 .25 L
.73531 .25 L
.73531 .25 L
.73532 .25 L
.73533 .25 L
.73533 .25 L
.73534 .25 L
.73535 .25 L
.73535 .25 L
.73536 .25 L
.73536 .25 L
.73537 .25 L
.73538 .25 L
.73538 .25 L
.73539 .25 L
.7354 .25 L
.7354 .25 L
.73541 .25 L
.73541 .25 L
.73542 .25 L
.73542 .25 L
.73543 .25 L
.73543 .25 L
.73544 .25 L
.73544 .25 L
.73545 .25 L
.73545 .25 L
.73545 .25 L
.73546 .25 L
.73546 .25 L
.73546 .25 L
.73547 .25 L
.73547 .25 L
.73548 .25 L
.73548 .25 L
.73549 .25 L
.7355 .25 L
.7355 .25 L
Mistroke
.73551 .25 L
.73552 .25 L
.73552 .25 L
.73553 .25 L
.73553 .25 L
.73554 .25 L
.73555 .25 L
.73555 .25 L
.73556 .25 L
.73557 .25 L
.73557 .25 L
.73558 .25 L
.73558 .25 L
.73559 .25 L
.73559 .25 L
.7356 .25 L
.73561 .25 L
.73561 .25 L
.73562 .25 L
.73562 .25 L
.73563 .25 L
.73563 .25 L
.73564 .25 L
.73565 .25 L
.73565 .25 L
.73566 .25 L
.73566 .25 L
.73567 .25 L
.73568 .25 L
.73568 .25 L
.73568 .25 L
.73569 .25 L
.7357 .25 L
.7357 .25 L
.73571 .25 L
.73572 .25 L
.73572 .25 L
.73573 .25 L
.73574 .25 L
.73574 .25 L
.73575 .25 L
.73576 .25 L
.73576 .25 L
.73577 .25 L
.73577 .25 L
.73578 .25 L
.73578 .25 L
.73579 .25 L
.7358 .25 L
.7358 .25 L
Mistroke
.73581 .25 L
.73581 .25 L
.73582 .25 L
.73583 .25 L
.73583 .25 L
.73584 .25 L
.73584 .25 L
.73585 .25 L
.73586 .25 L
.73586 .25 L
.73587 .25 L
.73587 .25 L
.73588 .25 L
.73588 .25 L
.73589 .25 L
.73589 .25 L
.7359 .25 L
.7359 .25 L
.73591 .25 L
.73591 .25 L
.73592 .25 L
.73593 .25 L
.73593 .25 L
.73594 .25 L
.73594 .25 L
.73595 .25 L
.73595 .25 L
.73596 .25 L
.73597 .25 L
.73597 .25 L
.73597 .25 L
.73598 .25 L
.73599 .25 L
.73599 .25 L
.736 .25 L
.736 .25 L
.73601 .25 L
.73602 .25 L
.73602 .25 L
.73603 .25 L
.73603 .25 L
.73604 .25 L
.73605 .25 L
.73605 .25 L
.73606 .25 L
.73606 .25 L
.73607 .25 L
.73608 .25 L
.73608 .25 L
.73609 .25 L
Mistroke
.7361 .25 L
.7361 .25 L
.73611 .25 L
.73611 .25 L
.73612 .25 L
.73612 .25 L
.73612 .25 L
.73613 .25 L
.73614 .25 L
.73614 .25 L
.73615 .25 L
.73616 .25 L
.73616 .25 L
.73617 .25 L
.73618 .25 L
.73618 .25 L
.73619 .25 L
.7362 .25 L
.7362 .25 L
.73621 .25 L
.73621 .25 L
.73622 .25 L
.73623 .25 L
.73623 .25 L
.73624 .25 L
.73624 .25 L
.73625 .25 L
.73625 .25 L
.73626 .25 L
.73626 .25 L
.73626 .25 L
.73627 .25 L
.73627 .25 L
.73628 .25 L
.73628 .25 L
.73629 .25 L
.73629 .25 L
.73629 .25 L
.7363 .25 L
.7363 .25 L
.73631 .25 L
.73631 .25 L
.73632 .25 L
.73633 .25 L
.73633 .25 L
.73634 .25 L
.73635 .25 L
.73635 .25 L
.73636 .25 L
.73636 .25 L
Mistroke
.73637 .25 L
.73638 .25 L
.73638 .25 L
.73639 .25 L
.7364 .25 L
.7364 .25 L
.7364 .25 L
.73641 .25 L
.73642 .25 L
.73642 .25 L
.73643 .25 L
.73644 .25 L
.73644 .25 L
.73645 .25 L
.73645 .25 L
.73646 .25 L
.73646 .25 L
.73647 .25 L
.73648 .25 L
.73648 .25 L
.73649 .25 L
.7365 .25 L
.7365 .25 L
.7365 .25 L
.73651 .25 L
.73652 .25 L
.73652 .25 L
.73653 .25 L
.73654 .25 L
.73654 .25 L
.73655 .25 L
.73655 .25 L
.73656 .25 L
.73657 .25 L
.73657 .25 L
.73658 .25 L
.73659 .25 L
.73659 .25 L
.7366 .25 L
.7366 .25 L
.73661 .25 L
.73661 .25 L
.73662 .25 L
.73663 .25 L
.73663 .25 L
.73664 .25 L
.73664 .25 L
.73665 .25 L
.73666 .25 L
.73666 .25 L
Mistroke
.73667 .25 L
.73667 .25 L
.73668 .25 L
.73669 .25 L
.73669 .25 L
.7367 .25 L
.7367 .25 L
.7367 .25 L
.73671 .25 L
.73672 .25 L
.73672 .25 L
.73673 .25 L
.73673 .25 L
.73674 .25 L
.73674 .25 L
.73675 .25 L
.73676 .25 L
.73676 .25 L
.73677 .25 L
.73677 .25 L
.73678 .25 L
.73678 .25 L
.73679 .25 L
.73679 .25 L
.7368 .25 L
.7368 .25 L
.73681 .25 L
.73682 .25 L
.73682 .25 L
.73683 .25 L
.73683 .25 L
.73684 .25 L
.73685 .25 L
.73685 .25 L
.73686 .25 L
.73686 .25 L
.73687 .25 L
.73688 .25 L
.73688 .25 L
.73689 .25 L
.73689 .25 L
.7369 .25 L
.73691 .25 L
.73691 .25 L
.73692 .25 L
.73693 .25 L
.73693 .25 L
.73694 .25 L
.73694 .25 L
.73694 .25 L
Mistroke
.73695 .25 L
.73696 .25 L
.73696 .25 L
.73697 .25 L
.73697 .25 L
.73698 .25 L
.73699 .25 L
.73699 .25 L
.737 .25 L
.73701 .25 L
.73701 .25 L
.73702 .25 L
.73702 .25 L
.73703 .25 L
.73704 .25 L
.73704 .25 L
.73705 .25 L
.73706 .25 L
.73706 .25 L
.73707 .25 L
.73707 .25 L
.73708 .25 L
.73708 .25 L
.73708 .25 L
.73709 .25 L
.73709 .25 L
.7371 .25 L
.7371 .25 L
.7371 .25 L
.73711 .25 L
.73711 .25 L
.73712 .25 L
.73712 .25 L
.73712 .25 L
.73713 .25 L
.73714 .25 L
.73714 .25 L
.73715 .25 L
.73716 .25 L
.73716 .25 L
.73717 .25 L
.73717 .25 L
.73718 .25 L
.73719 .25 L
.73719 .25 L
.7372 .25 L
.73721 .25 L
.73721 .25 L
.73722 .25 L
.73722 .25 L
Mistroke
.73723 .25 L
.73723 .25 L
.73724 .25 L
.73725 .25 L
.73725 .25 L
.73726 .25 L
.73727 .25 L
.73727 .25 L
.73728 .25 L
.73728 .25 L
.73729 .25 L
.73729 .25 L
.7373 .25 L
.73731 .25 L
.73731 .25 L
.73732 .25 L
.73732 .25 L
.73733 .25 L
.73733 .25 L
.73734 .25 L
.73735 .25 L
.73735 .25 L
.73736 .25 L
.73736 .25 L
.73737 .25 L
.73738 .25 L
.73738 .25 L
.73739 .25 L
.7374 .25 L
.7374 .25 L
.73741 .25 L
.73742 .25 L
.73742 .25 L
.73743 .25 L
.73743 .25 L
.73744 .25 L
.73744 .25 L
.73745 .25 L
.73746 .25 L
.73746 .25 L
.73747 .25 L
.73747 .25 L
.73748 .25 L
.73748 .25 L
.73749 .25 L
.7375 .25 L
.7375 .25 L
.73751 .25 L
.73751 .25 L
.73752 .25 L
Mistroke
.73752 .25 L
.73753 .25 L
.73753 .25 L
.73754 .25 L
.73755 .25 L
.73755 .25 L
.73756 .25 L
.73757 .25 L
.73757 .25 L
.73758 .25 L
.73759 .25 L
.73759 .25 L
.7376 .25 L
.73761 .25 L
.73761 .25 L
.73762 .25 L
.73762 .25 L
.73763 .25 L
.73763 .25 L
.73764 .25 L
.73765 .25 L
.73765 .25 L
.73766 .25 L
.73766 .25 L
.73767 .25 L
.73768 .25 L
.73768 .25 L
.73769 .25 L
.73769 .25 L
.7377 .25 L
.73771 .25 L
.73771 .25 L
.73772 .25 L
.73772 .25 L
.73773 .25 L
.73773 .25 L
.73774 .25 L
.73774 .25 L
.73775 .25 L
.73775 .25 L
.73776 .25 L
.73776 .25 L
.73777 .25 L
.73778 .25 L
.73778 .25 L
.73779 .25 L
.73779 .25 L
.7378 .25 L
.7378 .25 L
.73781 .25 L
Mistroke
.73782 .25 L
.73782 .25 L
.73782 .25 L
.73783 .25 L
.73784 .25 L
.73784 .25 L
.73785 .25 L
.73785 .25 L
.73786 .25 L
.73787 .25 L
.73787 .25 L
.73788 .25 L
.73788 .25 L
.73789 .25 L
.7379 .25 L
.7379 .25 L
.73791 .25 L
.73791 .25 L
.73792 .25 L
.73793 .25 L
.73793 .25 L
.73794 .25 L
.73795 .25 L
.73795 .25 L
.73796 .25 L
.73796 .25 L
.73797 .25 L
.73797 .25 L
.73797 .25 L
.73798 .25 L
.73799 .25 L
.73799 .25 L
.738 .25 L
.73801 .25 L
.73801 .25 L
.73802 .25 L
.73803 .25 L
.73803 .25 L
.73804 .25 L
.73805 .25 L
.73805 .25 L
.73806 .25 L
.73806 .25 L
.73807 .25 L
.73808 .25 L
.73808 .25 L
.73809 .25 L
.73809 .25 L
.7381 .25 L
.7381 .25 L
Mistroke
.73811 .25 L
.73811 .25 L
.73811 .25 L
.73812 .25 L
.73812 .25 L
.73813 .25 L
.73813 .25 L
.73814 .25 L
.73814 .25 L
.73814 .25 L
.73815 .25 L
.73815 .25 L
.73816 .25 L
.73816 .25 L
.73817 .25 L
.73818 .25 L
.73818 .25 L
.73819 .25 L
.7382 .25 L
.7382 .25 L
.73821 .25 L
.73821 .25 L
.73822 .25 L
.73823 .25 L
.73823 .25 L
.73824 .25 L
.73825 .25 L
.73825 .25 L
.73825 .25 L
.73826 .25 L
.73827 .25 L
.73827 .25 L
.73828 .25 L
.73829 .25 L
.73829 .25 L
.7383 .25 L
.7383 .25 L
.73831 .25 L
.73831 .25 L
.73832 .25 L
.73833 .25 L
.73833 .25 L
.73834 .25 L
.73835 .25 L
.73835 .25 L
.73835 .25 L
.73836 .25 L
.73837 .25 L
.73837 .25 L
.73838 .25 L
Mistroke
.73839 .25 L
.73839 .25 L
.7384 .25 L
.7384 .25 L
.73841 .25 L
.73842 .25 L
.73842 .25 L
.73843 .25 L
.73844 .25 L
.73844 .25 L
.73845 .25 L
.73845 .25 L
.73846 .25 L
.73846 .25 L
.73847 .25 L
.73848 .25 L
.73848 .25 L
.73849 .25 L
.73849 .25 L
.7385 .25 L
.73851 .25 L
.73851 .25 L
.73852 .25 L
.73852 .25 L
.73853 .25 L
.73854 .25 L
.73854 .25 L
.73855 .25 L
.73855 .25 L
.73856 .25 L
.73856 .25 L
.73857 .25 L
.73857 .25 L
.73858 .25 L
.73858 .25 L
.73859 .25 L
.73859 .25 L
.7386 .25 L
.73861 .25 L
.73861 .25 L
.73862 .25 L
.73863 .25 L
.73863 .25 L
.73863 .25 L
.73864 .25 L
.73864 .25 L
.73865 .25 L
.73865 .25 L
.73866 .25 L
.73867 .25 L
Mistroke
.73867 .25 L
.73868 .25 L
.73868 .25 L
.73869 .25 L
.7387 .25 L
.7387 .25 L
.73871 .25 L
.73871 .25 L
.73872 .25 L
.73873 .25 L
.73873 .25 L
.73874 .25 L
.73874 .25 L
.73875 .25 L
.73876 .25 L
.73876 .25 L
.73877 .25 L
.73878 .25 L
.73878 .25 L
.73879 .25 L
.73879 .25 L
.7388 .25 L
.7388 .25 L
.73881 .25 L
.73881 .25 L
.73882 .25 L
.73883 .25 L
.73883 .25 L
.73884 .25 L
.73884 .25 L
.73885 .25 L
.73886 .25 L
.73886 .25 L
.73887 .25 L
.73888 .25 L
.73888 .25 L
.73889 .25 L
.7389 .25 L
.7389 .25 L
.73891 .25 L
.73891 .25 L
.73892 .25 L
.73892 .25 L
.73893 .25 L
.73893 .25 L
.73893 .25 L
.73894 .25 L
.73894 .25 L
.73895 .25 L
.73895 .25 L
Mistroke
.73896 .25 L
.73896 .25 L
.73896 .25 L
.73897 .25 L
.73897 .25 L
.73897 .25 L
.73898 .25 L
.73899 .25 L
.73899 .25 L
.739 .25 L
.73901 .25 L
.73901 .25 L
.73902 .25 L
.73903 .25 L
.73903 .25 L
.73904 .25 L
.73904 .25 L
.73905 .25 L
.73906 .25 L
.73906 .25 L
.73907 .25 L
.73907 .25 L
.73908 .25 L
.73908 .25 L
.73909 .25 L
.7391 .25 L
.7391 .25 L
.73911 .25 L
.73912 .25 L
.73912 .25 L
.73913 .25 L
.73913 .25 L
.73914 .25 L
.73914 .25 L
.73915 .25 L
.73916 .25 L
.73916 .25 L
.73917 .25 L
.73917 .25 L
.73918 .25 L
.73918 .25 L
.73919 .25 L
.7392 .25 L
.7392 .25 L
.73921 .25 L
.73922 .25 L
.73922 .25 L
.73923 .25 L
.73923 .25 L
.73924 .25 L
Mistroke
.73925 .25 L
.73925 .25 L
.73926 .25 L
.73927 .25 L
.73927 .25 L
.73928 .25 L
.73928 .25 L
.73929 .25 L
.73929 .25 L
.7393 .25 L
.73931 .25 L
.73931 .25 L
.73932 .25 L
.73932 .25 L
.73933 .25 L
.73934 .25 L
.73934 .25 L
.73935 .25 L
.73935 .25 L
.73936 .25 L
.73937 .25 L
.73937 .25 L
.73938 .25 L
.73938 .25 L
.73939 .25 L
.73939 .25 L
.7394 .25 L
.7394 .25 L
.73941 .25 L
.73941 .25 L
.73942 .25 L
.73942 .25 L
.73943 .25 L
.73944 .25 L
.73944 .25 L
.73945 .25 L
.73945 .25 L
.73946 .25 L
.73946 .25 L
.73947 .25 L
.73947 .25 L
.73948 .25 L
.73948 .25 L
.73949 .25 L
.7395 .25 L
.7395 .25 L
.73951 .25 L
.73951 .25 L
.73952 .25 L
.73953 .25 L
Mistroke
.73953 .25 L
.73954 .25 L
.73954 .25 L
.73955 .25 L
.73956 .25 L
.73956 .25 L
.73957 .25 L
.73958 .25 L
.73958 .25 L
.73959 .25 L
.73959 .25 L
.7396 .25 L
.73961 .25 L
.73961 .25 L
.73962 .25 L
.73962 .25 L
.73962 .25 L
.73963 .25 L
.73964 .25 L
.73964 .25 L
.73965 .25 L
.73966 .25 L
.73966 .25 L
.73967 .25 L
.73967 .25 L
.73968 .25 L
.73969 .25 L
.73969 .25 L
.7397 .25 L
.73971 .25 L
.73971 .25 L
.73972 .25 L
.73973 .25 L
.73973 .25 L
.73974 .25 L
.73974 .25 L
.73975 .25 L
.73975 .25 L
.73975 .25 L
.73976 .25 L
.73976 .25 L
.73977 .25 L
.73977 .25 L
.73978 .25 L
.73978 .25 L
.73978 .25 L
.73979 .25 L
.73979 .25 L
.73979 .25 L
.7398 .25 L
Mistroke
.7398 .25 L
.73981 .25 L
.73982 .25 L
.73982 .25 L
.73983 .25 L
.73984 .25 L
.73984 .25 L
.73985 .25 L
.73986 .25 L
.73986 .25 L
.73987 .25 L
.73987 .25 L
.73988 .25 L
.73989 .25 L
.73989 .25 L
.7399 .25 L
.7399 .25 L
.73991 .25 L
.73992 .25 L
.73992 .25 L
.73993 .25 L
.73993 .25 L
.73994 .25 L
.73995 .25 L
.73995 .25 L
.73996 .25 L
.73996 .25 L
.73997 .25 L
.73997 .25 L
.73998 .25 L
.73999 .25 L
.73999 .25 L
.74 .25 L
.74 .25 L
.74001 .25 L
.74001 .25 L
.74002 .25 L
.74003 .25 L
.74003 .25 L
.74004 .25 L
.74005 .25 L
.74005 .25 L
.74006 .25 L
.74006 .25 L
.74007 .25 L
.74008 .25 L
.74008 .25 L
.74009 .25 L
.7401 .25 L
.7401 .25 L
Mistroke
.7401 .25 L
.74011 .25 L
.74012 .25 L
.74012 .25 L
.74013 .25 L
.74014 .25 L
.74014 .25 L
.74015 .25 L
.74015 .25 L
.74016 .25 L
.74016 .25 L
.74017 .25 L
.74018 .25 L
.74018 .25 L
.74019 .25 L
.7402 .25 L
.7402 .25 L
.7402 .25 L
.74021 .25 L
.74022 .25 L
.74022 .25 L
.74023 .25 L
.74023 .25 L
.74024 .25 L
.74024 .25 L
.74025 .25 L
.74025 .25 L
.74026 .25 L
.74027 .25 L
.74027 .25 L
.74028 .25 L
.74028 .25 L
.74029 .25 L
.74029 .25 L
.74029 .25 L
.7403 .25 L
.74031 .25 L
.74031 .25 L
.74032 .25 L
.74033 .25 L
.74033 .25 L
.74034 .25 L
.74034 .25 L
.74035 .25 L
.74036 .25 L
.74036 .25 L
.74037 .25 L
.74037 .25 L
.74038 .25 L
.74039 .25 L
Mistroke
.74039 .25 L
.7404 .25 L
.74041 .25 L
.74041 .25 L
.74042 .25 L
.74043 .25 L
.74043 .25 L
.74044 .25 L
.74044 .25 L
.74044 .25 L
.74045 .25 L
.74045 .25 L
.74046 .25 L
.74047 .25 L
.74047 .25 L
.74048 .25 L
.74049 .25 L
.74049 .25 L
.7405 .25 L
.7405 .25 L
.74051 .25 L
.74052 .25 L
.74052 .25 L
.74053 .25 L
.74054 .25 L
.74054 .25 L
.74055 .25 L
.74056 .25 L
.74056 .25 L
.74056 .25 L
.74057 .25 L
.74057 .25 L
.74058 .25 L
.74058 .25 L
.74058 .25 L
.74059 .25 L
.7406 .25 L
.7406 .25 L
.7406 .25 L
.74061 .25 L
.74061 .25 L
.74061 .25 L
.74062 .25 L
.74062 .25 L
.74063 .25 L
.74063 .25 L
.74064 .25 L
.74065 .25 L
.74065 .25 L
.74066 .25 L
Mistroke
.74067 .25 L
.74067 .25 L
.74068 .25 L
.74068 .25 L
.74069 .25 L
.7407 .25 L
.7407 .25 L
.74071 .25 L
.74072 .25 L
.74072 .25 L
.74073 .25 L
.74073 .25 L
.74074 .25 L
.74074 .25 L
.74075 .25 L
.74076 .25 L
.74076 .25 L
.74077 .25 L
.74077 .25 L
.74078 .25 L
.74079 .25 L
.74079 .25 L
.7408 .25 L
.7408 .25 L
.74081 .25 L
.74082 .25 L
.74082 .25 L
.74082 .25 L
.74083 .25 L
.74084 .25 L
.74084 .25 L
.74085 .25 L
.74086 .25 L
.74086 .25 L
.74087 .25 L
.74087 .25 L
.74088 .25 L
.74089 .25 L
.74089 .25 L
.7409 .25 L
.74091 .25 L
.74091 .25 L
.74092 .25 L
.74092 .25 L
.74093 .25 L
.74093 .25 L
.74094 .25 L
.74095 .25 L
.74095 .25 L
.74096 .25 L
Mistroke
.74097 .25 L
.74097 .25 L
.74098 .25 L
.74098 .25 L
.74099 .25 L
.74099 .25 L
.741 .25 L
.74101 .25 L
.74101 .25 L
.74102 .25 L
.74102 .25 L
.74103 .25 L
.74103 .25 L
.74104 .25 L
.74105 .25 L
.74105 .25 L
.74105 .25 L
.74106 .25 L
.74107 .25 L
.74107 .25 L
.74108 .25 L
.74108 .25 L
.74109 .25 L
.7411 .25 L
.7411 .25 L
.7411 .25 L
.74111 .25 L
.74111 .25 L
.74112 .25 L
.74112 .25 L
.74113 .25 L
.74114 .25 L
.74114 .25 L
.74115 .25 L
.74116 .25 L
.74116 .25 L
.74117 .25 L
.74117 .25 L
.74118 .25 L
.74119 .25 L
.74119 .25 L
.7412 .25 L
.7412 .25 L
.74121 .25 L
.74122 .25 L
.74122 .25 L
.74123 .25 L
.74124 .25 L
.74124 .25 L
.74125 .25 L
Mistroke
.74126 .25 L
.74126 .25 L
.74126 .25 L
.74127 .25 L
.74127 .25 L
.74128 .25 L
.74128 .25 L
.74129 .25 L
.7413 .25 L
.7413 .25 L
.74131 .25 L
.74131 .25 L
.74132 .25 L
.74133 .25 L
.74133 .25 L
.74134 .25 L
.74135 .25 L
.74135 .25 L
.74136 .25 L
.74137 .25 L
.74137 .25 L
.74138 .25 L
.74138 .25 L
.74139 .25 L
.74139 .25 L
.7414 .25 L
.7414 .25 L
.7414 .25 L
.74141 .25 L
.74141 .25 L
.74142 .25 L
.74142 .25 L
.74143 .25 L
.74143 .25 L
.74143 .25 L
.74144 .25 L
.74144 .25 L
.74144 .25 L
.74145 .25 L
.74146 .25 L
.74146 .25 L
.74147 .25 L
.74148 .25 L
.74148 .25 L
.74149 .25 L
.7415 .25 L
.7415 .25 L
.74151 .25 L
.74151 .25 L
.74152 .25 L
Mistroke
.74153 .25 L
.74153 .25 L
.74154 .25 L
.74155 .25 L
.74155 .25 L
.74156 .25 L
.74156 .25 L
.74157 .25 L
.74157 .25 L
.74158 .25 L
.74159 .25 L
.74159 .25 L
.7416 .25 L
.7416 .25 L
.74161 .25 L
.74162 .25 L
.74162 .25 L
.74163 .25 L
.74163 .25 L
.74164 .25 L
.74164 .25 L
.74165 .25 L
.74165 .25 L
.74166 .25 L
.74167 .25 L
.74167 .25 L
.74168 .25 L
.74169 .25 L
.74169 .25 L
.7417 .25 L
.7417 .25 L
.74171 .25 L
.74172 .25 L
.74172 .25 L
.74173 .25 L
.74174 .25 L
.74174 .25 L
.74175 .25 L
.74175 .25 L
.74176 .25 L
.74176 .25 L
.74177 .25 L
.74178 .25 L
.74178 .25 L
.74179 .25 L
.74179 .25 L
.7418 .25 L
.74181 .25 L
.74181 .25 L
.74182 .25 L
Mistroke
.74182 .25 L
.74183 .25 L
.74184 .25 L
.74184 .25 L
.74185 .25 L
.74185 .25 L
.74186 .25 L
.74186 .25 L
.74187 .25 L
.74188 .25 L
.74188 .25 L
.74189 .25 L
.74189 .25 L
.7419 .25 L
.74191 .25 L
.74191 .25 L
.74192 .25 L
.74193 .25 L
.74193 .25 L
.74194 .25 L
.74195 .25 L
.74195 .25 L
.74195 .25 L
.74196 .25 L
.74197 .25 L
.74197 .25 L
.74198 .25 L
.74199 .25 L
.74199 .25 L
.742 .25 L
.742 .25 L
.74201 .25 L
.74201 .25 L
.74202 .25 L
.74203 .25 L
.74203 .25 L
.74204 .25 L
.74204 .25 L
.74205 .25 L
.74205 .25 L
.74206 .25 L
.74206 .25 L
.74207 .25 L
.74208 .25 L
.74208 .25 L
.74208 .25 L
.74209 .25 L
.7421 .25 L
.7421 .25 L
.74211 .25 L
Mistroke
.74212 .25 L
.74212 .25 L
.74213 .25 L
.74213 .25 L
.74214 .25 L
.74214 .25 L
.74214 .25 L
.74215 .25 L
.74216 .25 L
.74216 .25 L
.74217 .25 L
.74218 .25 L
.74218 .25 L
.74219 .25 L
.74219 .25 L
.7422 .25 L
.74221 .25 L
.74221 .25 L
.74222 .25 L
.74222 .25 L
.74223 .25 L
.74224 .25 L
.74224 .25 L
.74225 .25 L
.74226 .25 L
.74226 .25 L
.74227 .25 L
.74227 .25 L
.74228 .25 L
.74228 .25 L
.74229 .25 L
.74229 .25 L
.7423 .25 L
.7423 .25 L
.74231 .25 L
.74232 .25 L
.74232 .25 L
.74233 .25 L
.74233 .25 L
.74234 .25 L
.74235 .25 L
.74235 .25 L
.74236 .25 L
.74237 .25 L
.74237 .25 L
.74238 .25 L
.74239 .25 L
.74239 .25 L
.7424 .25 L
.74241 .25 L
Mistroke
.74241 .25 L
.74241 .25 L
.74242 .25 L
.74242 .25 L
.74243 .25 L
.74243 .25 L
.74243 .25 L
.74244 .25 L
.74244 .25 L
.74245 .25 L
.74245 .25 L
.74246 .25 L
.74246 .25 L
.74246 .25 L
.74247 .25 L
.74247 .25 L
.74248 .25 L
.74248 .25 L
.74249 .25 L
.7425 .25 L
.7425 .25 L
.74251 .25 L
.74252 .25 L
.74252 .25 L
.74253 .25 L
.74253 .25 L
.74254 .25 L
.74255 .25 L
.74255 .25 L
.74256 .25 L
.74257 .25 L
.74257 .25 L
.74258 .25 L
.74258 .25 L
.74259 .25 L
.74259 .25 L
.7426 .25 L
.74261 .25 L
.74261 .25 L
.74262 .25 L
.74262 .25 L
.74263 .25 L
.74264 .25 L
.74264 .25 L
.74265 .25 L
.74265 .25 L
.74266 .25 L
.74267 .25 L
.74267 .25 L
.74267 .25 L
Mistroke
.74268 .25 L
.74269 .25 L
.74269 .25 L
.7427 .25 L
.74271 .25 L
.74271 .25 L
.74272 .25 L
.74272 .25 L
.74273 .25 L
.74274 .25 L
.74274 .25 L
.74275 .25 L
.74276 .25 L
.74276 .25 L
.74277 .25 L
.74277 .25 L
.74278 .25 L
.74278 .25 L
.74279 .25 L
.7428 .25 L
.7428 .25 L
.74281 .25 L
.74282 .25 L
.74282 .25 L
.74283 .25 L
.74283 .25 L
.74284 .25 L
.74284 .25 L
.74285 .25 L
.74286 .25 L
.74286 .25 L
.74287 .25 L
.74287 .25 L
.74288 .25 L
.74288 .25 L
.74289 .25 L
.7429 .25 L
.7429 .25 L
.7429 .25 L
.74291 .25 L
.74292 .25 L
.74292 .25 L
.74293 .25 L
.74293 .25 L
.74294 .25 L
.74295 .25 L
.74295 .25 L
.74295 .25 L
.74296 .25 L
.74296 .25 L
Mistroke
.74297 .25 L
.74297 .25 L
.74298 .25 L
.74299 .25 L
.74299 .25 L
.743 .25 L
.74301 .25 L
.74301 .25 L
.74302 .25 L
.74302 .25 L
.74303 .25 L
.74304 .25 L
.74304 .25 L
.74305 .25 L
.74305 .25 L
.74306 .25 L
.74307 .25 L
.74307 .25 L
.74308 .25 L
.74309 .25 L
.74309 .25 L
.7431 .25 L
.74311 .25 L
.74311 .25 L
.74311 .25 L
.74312 .25 L
.74312 .25 L
.74313 .25 L
.74313 .25 L
.74314 .25 L
.74315 .25 L
.74315 .25 L
.74316 .25 L
.74316 .25 L
.74317 .25 L
.74318 .25 L
.74318 .25 L
.74319 .25 L
.7432 .25 L
.7432 .25 L
.74321 .25 L
.74322 .25 L
.74322 .25 L
.74323 .25 L
.74323 .25 L
.74324 .25 L
.74324 .25 L
.74325 .25 L
.74325 .25 L
.74325 .25 L
Mistroke
.74326 .25 L
.74326 .25 L
.74327 .25 L
.74327 .25 L
.74328 .25 L
.74328 .25 L
.74328 .25 L
.74329 .25 L
.74329 .25 L
.74329 .25 L
.7433 .25 L
.74331 .25 L
.74331 .25 L
.74332 .25 L
.74333 .25 L
.74333 .25 L
.74334 .25 L
.74335 .25 L
.74335 .25 L
.74336 .25 L
.74337 .25 L
.74337 .25 L
.74338 .25 L
.74338 .25 L
.74339 .25 L
.7434 .25 L
.7434 .25 L
.74341 .25 L
.74341 .25 L
.74342 .25 L
.74342 .25 L
.74343 .25 L
.74344 .25 L
.74344 .25 L
.74345 .25 L
.74345 .25 L
.74346 .25 L
.74347 .25 L
.74347 .25 L
.74348 .25 L
.74348 .25 L
.74349 .25 L
.74349 .25 L
.7435 .25 L
.7435 .25 L
.74351 .25 L
.74352 .25 L
.74352 .25 L
.74353 .25 L
.74354 .25 L
Mistroke
.74354 .25 L
.74355 .25 L
.74355 .25 L
.74356 .25 L
.74357 .25 L
.74357 .25 L
.74358 .25 L
.74359 .25 L
.74359 .25 L
.7436 .25 L
.7436 .25 L
.74361 .25 L
.74361 .25 L
.74362 .25 L
.74363 .25 L
.74363 .25 L
.74364 .25 L
.74365 .25 L
.74365 .25 L
.74366 .25 L
.74366 .25 L
.74367 .25 L
.74367 .25 L
.74368 .25 L
.74369 .25 L
.74369 .25 L
.7437 .25 L
.7437 .25 L
.74371 .25 L
.74371 .25 L
.74372 .25 L
.74372 .25 L
.74373 .25 L
.74373 .25 L
.74374 .25 L
.74375 .25 L
.74375 .25 L
.74376 .25 L
.74376 .25 L
.74377 .25 L
.74377 .25 L
.74378 .25 L
.74378 .25 L
.74379 .25 L
.74379 .25 L
.7438 .25 L
.74381 .25 L
.74381 .25 L
.74382 .25 L
.74382 .25 L
Mistroke
.74383 .25 L
.74384 .25 L
.74384 .25 L
.74385 .25 L
.74385 .25 L
.74386 .25 L
.74387 .25 L
.74387 .25 L
.74388 .25 L
.74388 .25 L
.74389 .25 L
.7439 .25 L
.7439 .25 L
.74391 .25 L
.74392 .25 L
.74392 .25 L
.74393 .25 L
.74393 .25 L
.74394 .25 L
.74394 .25 L
.74394 .25 L
.74395 .25 L
.74396 .25 L
.74396 .25 L
.74397 .25 L
.74398 .25 L
.74398 .25 L
.74399 .25 L
.74399 .25 L
.744 .25 L
.74401 .25 L
.74401 .25 L
.74402 .25 L
.74403 .25 L
.74403 .25 L
.74404 .25 L
.74405 .25 L
.74405 .25 L
.74406 .25 L
.74406 .25 L
.74407 .25 L
.74407 .25 L
.74407 .25 L
.74408 .25 L
.74408 .25 L
.74409 .25 L
.74409 .25 L
.7441 .25 L
.7441 .25 L
.7441 .25 L
Mistroke
.74411 .25 L
.74411 .25 L
.74412 .25 L
.74412 .25 L
.74412 .25 L
.74413 .25 L
.74414 .25 L
.74415 .25 L
.74415 .25 L
.74416 .25 L
.74416 .25 L
.74417 .25 L
.74418 .25 L
.74418 .25 L
.74419 .25 L
.7442 .25 L
.7442 .25 L
.74421 .25 L
.74422 .25 L
.74422 .25 L
.74422 .25 L
.74423 .25 L
.74424 .25 L
.74424 .25 L
.74425 .25 L
.74425 .25 L
.74426 .25 L
.74427 .25 L
.74427 .25 L
.74428 .25 L
.74428 .25 L
.74429 .25 L
.7443 .25 L
.7443 .25 L
.74431 .25 L
.74431 .25 L
.74432 .25 L
.74432 .25 L
.74433 .25 L
.74433 .25 L
.74434 .25 L
.74435 .25 L
.74435 .25 L
.74436 .25 L
.74437 .25 L
.74437 .25 L
.74438 .25 L
.74438 .25 L
.74439 .25 L
.7444 .25 L
Mistroke
.7444 .25 L
.74441 .25 L
.74442 .25 L
.74442 .25 L
.74442 .25 L
.74443 .25 L
.74444 .25 L
.74444 .25 L
.74445 .25 L
.74446 .25 L
.74446 .25 L
.74447 .25 L
.74447 .25 L
.74448 .25 L
.74449 .25 L
.74449 .25 L
.7445 .25 L
.7445 .25 L
.74451 .25 L
.74452 .25 L
.74452 .25 L
.74452 .25 L
.74453 .25 L
.74454 .25 L
.74454 .25 L
.74455 .25 L
.74455 .25 L
.74456 .25 L
.74456 .25 L
.74457 .25 L
.74457 .25 L
.74458 .25 L
.74459 .25 L
.74459 .25 L
.7446 .25 L
.7446 .25 L
.74461 .25 L
.74461 .25 L
.74462 .25 L
.74462 .25 L
.74463 .25 L
.74464 .25 L
.74464 .25 L
.74465 .25 L
.74465 .25 L
.74466 .25 L
.74466 .25 L
.74467 .25 L
.74468 .25 L
.74468 .25 L
Mistroke
.74469 .25 L
.7447 .25 L
.7447 .25 L
.74471 .25 L
.74471 .25 L
.74472 .25 L
.74473 .25 L
.74473 .25 L
.74474 .25 L
.74475 .25 L
.74475 .25 L
.74476 .25 L
.74476 .25 L
.74476 .25 L
.74477 .25 L
.74477 .25 L
.74478 .25 L
.74479 .25 L
.74479 .25 L
.7448 .25 L
.74481 .25 L
.74481 .25 L
.74482 .25 L
.74482 .25 L
.74483 .25 L
.74484 .25 L
.74484 .25 L
.74485 .25 L
.74486 .25 L
.74486 .25 L
.74487 .25 L
.74488 .25 L
.74488 .25 L
.74488 .25 L
.74489 .25 L
.74489 .25 L
.7449 .25 L
.7449 .25 L
.74491 .25 L
.74491 .25 L
.74492 .25 L
.74492 .25 L
.74492 .25 L
.74493 .25 L
.74493 .25 L
.74493 .25 L
.74494 .25 L
.74494 .25 L
.74495 .25 L
.74496 .25 L
Mistroke
.74496 .25 L
.74497 .25 L
.74498 .25 L
.74498 .25 L
.74499 .25 L
.74499 .25 L
.745 .25 L
.74501 .25 L
.74501 .25 L
.74502 .25 L
.74502 .25 L
.74503 .25 L
.74504 .25 L
.74504 .25 L
.74505 .25 L
.74505 .25 L
.74506 .25 L
.74507 .25 L
.74507 .25 L
.74508 .25 L
.74508 .25 L
.74509 .25 L
.74509 .25 L
.7451 .25 L
.74511 .25 L
.74511 .25 L
.74512 .25 L
.74513 .25 L
.74513 .25 L
.74514 .25 L
.74514 .25 L
.74514 .25 L
.74515 .25 L
.74516 .25 L
.74516 .25 L
.74517 .25 L
.74518 .25 L
.74518 .25 L
.74519 .25 L
.7452 .25 L
.7452 .25 L
.74521 .25 L
.74521 .25 L
.74522 .25 L
.74523 .25 L
.74523 .25 L
.74524 .25 L
.74524 .25 L
.74525 .25 L
.74526 .25 L
Mistroke
.74526 .25 L
.74527 .25 L
.74527 .25 L
.74528 .25 L
.74529 .25 L
.74529 .25 L
.7453 .25 L
.7453 .25 L
.74531 .25 L
.74531 .25 L
.74532 .25 L
.74533 .25 L
.74533 .25 L
.74534 .25 L
.74534 .25 L
.74535 .25 L
.74535 .25 L
.74536 .25 L
.74537 .25 L
.74537 .25 L
.74538 .25 L
.74539 .25 L
.74539 .25 L
.7454 .25 L
.7454 .25 L
.74541 .25 L
.74542 .25 L
.74542 .25 L
.74543 .25 L
.74544 .25 L
.74544 .25 L
.74545 .25 L
.74545 .25 L
.74546 .25 L
.74546 .25 L
.74547 .25 L
.74548 .25 L
.74548 .25 L
.74549 .25 L
.74549 .25 L
.7455 .25 L
.74551 .25 L
.74551 .25 L
.74552 .25 L
.74552 .25 L
.74553 .25 L
.74554 .25 L
.74554 .25 L
.74555 .25 L
.74555 .25 L
Mistroke
.74556 .25 L
.74556 .25 L
.74557 .25 L
.74557 .25 L
.74558 .25 L
.74558 .25 L
.74559 .25 L
.74559 .25 L
.7456 .25 L
.74561 .25 L
.74561 .25 L
.74562 .25 L
.74562 .25 L
.74563 .25 L
.74563 .25 L
.74564 .25 L
.74564 .25 L
.74565 .25 L
.74565 .25 L
.74566 .25 L
.74567 .25 L
.74567 .25 L
.74568 .25 L
.74568 .25 L
.74569 .25 L
.7457 .25 L
.7457 .25 L
.74571 .25 L
.74571 .25 L
.74572 .25 L
.74573 .25 L
.74573 .25 L
.74574 .25 L
.74575 .25 L
.74575 .25 L
.74576 .25 L
.74577 .25 L
.74577 .25 L
.74578 .25 L
.74578 .25 L
.74579 .25 L
.74579 .25 L
.74579 .25 L
.7458 .25 L
.74581 .25 L
.74581 .25 L
.74582 .25 L
.74583 .25 L
.74583 .25 L
.74584 .25 L
Mistroke
.74584 .25 L
.74585 .25 L
.74586 .25 L
.74586 .25 L
.74587 .25 L
.74588 .25 L
.74588 .25 L
.74589 .25 L
.7459 .25 L
.7459 .25 L
.74591 .25 L
.74591 .25 L
.74592 .25 L
.74592 .25 L
.74592 .25 L
.74593 .25 L
.74593 .25 L
.74594 .25 L
.74594 .25 L
.74595 .25 L
.74595 .25 L
.74595 .25 L
.74596 .25 L
.74596 .25 L
.74596 .25 L
.74597 .25 L
.74597 .25 L
.74598 .25 L
.74599 .25 L
.74599 .25 L
.746 .25 L
.74601 .25 L
.74601 .25 L
.74602 .25 L
.74603 .25 L
.74603 .25 L
.74604 .25 L
.74605 .25 L
.74605 .25 L
.74606 .25 L
.74606 .25 L
.74607 .25 L
.74607 .25 L
.74608 .25 L
.74609 .25 L
.74609 .25 L
.7461 .25 L
.7461 .25 L
.74611 .25 L
.74612 .25 L
Mistroke
.74612 .25 L
.74613 .25 L
.74613 .25 L
.74614 .25 L
.74615 .25 L
.74615 .25 L
.74616 .25 L
.74616 .25 L
.74617 .25 L
.74617 .25 L
.74618 .25 L
.74618 .25 L
.74619 .25 L
.7462 .25 L
.7462 .25 L
.74621 .25 L
.74622 .25 L
.74622 .25 L
.74623 .25 L
.74623 .25 L
.74624 .25 L
.74625 .25 L
.74625 .25 L
.74626 .25 L
.74627 .25 L
.74627 .25 L
.74627 .25 L
.74628 .25 L
.74629 .25 L
.74629 .25 L
.7463 .25 L
.74631 .25 L
.74631 .25 L
.74632 .25 L
.74632 .25 L
.74633 .25 L
.74634 .25 L
.74634 .25 L
.74635 .25 L
.74635 .25 L
.74636 .25 L
.74637 .25 L
.74637 .25 L
.74637 .25 L
.74638 .25 L
.74639 .25 L
.74639 .25 L
.7464 .25 L
.7464 .25 L
.74641 .25 L
Mistroke
.74641 .25 L
.74642 .25 L
.74642 .25 L
.74643 .25 L
.74644 .25 L
.74644 .25 L
.74645 .25 L
.74645 .25 L
.74646 .25 L
.74646 .25 L
.74647 .25 L
.74647 .25 L
.74648 .25 L
.74649 .25 L
.74649 .25 L
.7465 .25 L
.7465 .25 L
.74651 .25 L
.74651 .25 L
.74652 .25 L
.74653 .25 L
.74653 .25 L
.74654 .25 L
.74655 .25 L
.74655 .25 L
.74656 .25 L
.74656 .25 L
.74657 .25 L
.74658 .25 L
.74658 .25 L
.74659 .25 L
.7466 .25 L
.7466 .25 L
.74661 .25 L
.74661 .25 L
.74661 .25 L
.74662 .25 L
.74662 .25 L
.74663 .25 L
.74664 .25 L
.74664 .25 L
.74665 .25 L
.74666 .25 L
.74666 .25 L
.74667 .25 L
.74667 .25 L
.74668 .25 L
.74669 .25 L
.74669 .25 L
.7467 .25 L
Mistroke
.74671 .25 L
.74671 .25 L
.74672 .25 L
.74673 .25 L
.74673 .25 L
.74673 .25 L
.74674 .25 L
.74674 .25 L
.74675 .25 L
.74675 .25 L
.74676 .25 L
.74676 .25 L
.74677 .25 L
.74677 .25 L
.74677 .25 L
.74678 .25 L
.74678 .25 L
.74679 .25 L
.74679 .25 L
.74679 .25 L
.7468 .25 L
.74681 .25 L
.74681 .25 L
.74682 .25 L
.74683 .25 L
.74683 .25 L
.74684 .25 L
.74684 .25 L
.74685 .25 L
.74686 .25 L
.74686 .25 L
.74687 .25 L
.74688 .25 L
.74688 .25 L
.74689 .25 L
.74689 .25 L
.7469 .25 L
.7469 .25 L
.74691 .25 L
.74692 .25 L
.74692 .25 L
.74693 .25 L
.74693 .25 L
.74694 .25 L
.74695 .25 L
.74695 .25 L
.74696 .25 L
.74696 .25 L
.74697 .25 L
.74698 .25 L
Mistroke
.74698 .25 L
.74699 .25 L
.74699 .25 L
.74699 .25 L
.747 .25 L
.74701 .25 L
.74701 .25 L
.74702 .25 L
.74703 .25 L
.74703 .25 L
.74704 .25 L
.74705 .25 L
.74705 .25 L
.74706 .25 L
.74706 .25 L
.74707 .25 L
.74708 .25 L
.74708 .25 L
.74709 .25 L
.7471 .25 L
.7471 .25 L
.74711 .25 L
.74711 .25 L
.74712 .25 L
.74712 .25 L
.74713 .25 L
.74714 .25 L
.74714 .25 L
.74715 .25 L
.74715 .25 L
.74716 .25 L
.74717 .25 L
.74717 .25 L
.74718 .25 L
.74718 .25 L
.74719 .25 L
.74719 .25 L
.7472 .25 L
.7472 .25 L
.74721 .25 L
.74722 .25 L
.74722 .25 L
.74722 .25 L
.74723 .25 L
.74724 .25 L
.74724 .25 L
.74725 .25 L
.74725 .25 L
.74726 .25 L
.74727 .25 L
Mistroke
.74727 .25 L
.74727 .25 L
.74728 .25 L
.74729 .25 L
.74729 .25 L
.7473 .25 L
.7473 .25 L
.74731 .25 L
.74732 .25 L
.74732 .25 L
.74733 .25 L
.74733 .25 L
.74734 .25 L
.74734 .25 L
.74735 .25 L
.74736 .25 L
.74736 .25 L
.74737 .25 L
.74738 .25 L
.74738 .25 L
.74739 .25 L
.74739 .25 L
.7474 .25 L
.74741 .25 L
.74741 .25 L
.74742 .25 L
.74743 .25 L
.74743 .25 L
.74743 .25 L
.74744 .25 L
.74744 .25 L
.74745 .25 L
.74745 .25 L
.74746 .25 L
.74747 .25 L
.74747 .25 L
.74748 .25 L
.74749 .25 L
.74749 .25 L
.7475 .25 L
.7475 .25 L
.74751 .25 L
.74752 .25 L
.74752 .25 L
.74753 .25 L
.74754 .25 L
.74754 .25 L
.74755 .25 L
.74755 .25 L
.74756 .25 L
Mistroke
.74756 .25 L
.74757 .25 L
.74757 .25 L
.74758 .25 L
.74758 .25 L
.74759 .25 L
.74759 .25 L
.74759 .25 L
.7476 .25 L
.7476 .25 L
.7476 .25 L
.74761 .25 L
.74761 .25 L
.74762 .25 L
.74762 .25 L
.74763 .25 L
.74764 .25 L
.74764 .25 L
.74765 .25 L
.74766 .25 L
.74766 .25 L
.74767 .25 L
.74767 .25 L
.74768 .25 L
.74769 .25 L
.74769 .25 L
.7477 .25 L
.74771 .25 L
.74771 .25 L
.74772 .25 L
.74772 .25 L
.74773 .25 L
.74773 .25 L
.74774 .25 L
.74775 .25 L
.74775 .25 L
.74776 .25 L
.74776 .25 L
.74777 .25 L
.74777 .25 L
.74778 .25 L
.74779 .25 L
.74779 .25 L
.7478 .25 L
.7478 .25 L
.74781 .25 L
.74782 .25 L
.74782 .25 L
.74782 .25 L
.74783 .25 L
Mistroke
.74784 .25 L
.74784 .25 L
.74785 .25 L
.74786 .25 L
.74786 .25 L
.74787 .25 L
.74788 .25 L
.74788 .25 L
.74789 .25 L
.7479 .25 L
.7479 .25 L
.74791 .25 L
.74791 .25 L
.74792 .25 L
.74792 .25 L
.74793 .25 L
.74794 .25 L
.74794 .25 L
.74795 .25 L
.74795 .25 L
.74796 .25 L
.74797 .25 L
.74797 .25 L
.74798 .25 L
.74798 .25 L
.74799 .25 L
.748 .25 L
.748 .25 L
.74801 .25 L
.74801 .25 L
.74802 .25 L
.74802 .25 L
.74803 .25 L
.74803 .25 L
.74804 .25 L
.74804 .25 L
.74805 .25 L
.74805 .25 L
.74806 .25 L
.74807 .25 L
.74807 .25 L
.74808 .25 L
.74808 .25 L
.74809 .25 L
.74809 .25 L
.7481 .25 L
.74811 .25 L
.74811 .25 L
.74811 .25 L
.74812 .25 L
Mistroke
.74813 .25 L
.74813 .25 L
.74814 .25 L
.74814 .25 L
.74815 .25 L
.74816 .25 L
.74816 .25 L
.74817 .25 L
.74817 .25 L
.74818 .25 L
.74819 .25 L
.74819 .25 L
.7482 .25 L
.7482 .25 L
.74821 .25 L
.74822 .25 L
.74822 .25 L
.74823 .25 L
.74824 .25 L
.74824 .25 L
.74825 .25 L
.74825 .25 L
.74826 .25 L
.74826 .25 L
.74826 .25 L
.74827 .25 L
.74828 .25 L
.74828 .25 L
.74829 .25 L
.7483 .25 L
.7483 .25 L
.74831 .25 L
.74831 .25 L
.74832 .25 L
.74833 .25 L
.74833 .25 L
.74834 .25 L
.74835 .25 L
.74835 .25 L
.74836 .25 L
.74837 .25 L
.74837 .25 L
.74838 .25 L
.74838 .25 L
.74839 .25 L
.74839 .25 L
.7484 .25 L
.7484 .25 L
.7484 .25 L
.74841 .25 L
Mistroke
.74841 .25 L
.74842 .25 L
.74842 .25 L
.74842 .25 L
.74843 .25 L
.74843 .25 L
.74844 .25 L
.74844 .25 L
.74845 .25 L
.74845 .25 L
.74846 .25 L
.74847 .25 L
.74847 .25 L
.74848 .25 L
.74848 .25 L
.74849 .25 L
.7485 .25 L
.7485 .25 L
.74851 .25 L
.74852 .25 L
.74852 .25 L
.74853 .25 L
.74854 .25 L
.74854 .25 L
.74854 .25 L
.74855 .25 L
.74856 .25 L
.74856 .25 L
.74857 .25 L
.74858 .25 L
.74858 .25 L
.74859 .25 L
.74859 .25 L
.7486 .25 L
.7486 .25 L
.74861 .25 L
.74862 .25 L
.74862 .25 L
.74863 .25 L
.74863 .25 L
.74864 .25 L
.74864 .25 L
.74865 .25 L
.74865 .25 L
.74866 .25 L
.74867 .25 L
.74867 .25 L
.74868 .25 L
.74869 .25 L
.74869 .25 L
Mistroke
.7487 .25 L
.74871 .25 L
.74871 .25 L
.74872 .25 L
.74872 .25 L
.74873 .25 L
.74874 .25 L
.74874 .25 L
.74875 .25 L
.74875 .25 L
.74876 .25 L
.74876 .25 L
.74877 .25 L
.74878 .25 L
.74878 .25 L
.74879 .25 L
.74879 .25 L
.7488 .25 L
.74881 .25 L
.74881 .25 L
.74882 .25 L
.74882 .25 L
.74883 .25 L
.74884 .25 L
.74884 .25 L
.74884 .25 L
.74885 .25 L
.74886 .25 L
.74886 .25 L
.74887 .25 L
.74888 .25 L
.74888 .25 L
.74889 .25 L
.7489 .25 L
.7489 .25 L
.74891 .25 L
.74891 .25 L
.74892 .25 L
.74893 .25 L
.74893 .25 L
.74894 .25 L
.74894 .25 L
.74895 .25 L
.74896 .25 L
.74896 .25 L
.74897 .25 L
.74897 .25 L
.74898 .25 L
.74899 .25 L
.74899 .25 L
Mistroke
.749 .25 L
.749 .25 L
.74901 .25 L
.74901 .25 L
.74902 .25 L
.74903 .25 L
.74903 .25 L
.74904 .25 L
.74904 .25 L
.74905 .25 L
.74905 .25 L
.74906 .25 L
.74907 .25 L
.74907 .25 L
.74907 .25 L
.74908 .25 L
.74909 .25 L
.74909 .25 L
.7491 .25 L
.7491 .25 L
.74911 .25 L
.74912 .25 L
.74912 .25 L
.74912 .25 L
.74913 .25 L
.74914 .25 L
.74914 .25 L
.74915 .25 L
.74915 .25 L
.74916 .25 L
.74916 .25 L
.74917 .25 L
.74918 .25 L
.74918 .25 L
.74919 .25 L
.74919 .25 L
.7492 .25 L
.74921 .25 L
.74921 .25 L
.74922 .25 L
.74923 .25 L
.74923 .25 L
.74924 .25 L
.74924 .25 L
.74925 .25 L
.74926 .25 L
.74926 .25 L
.74927 .25 L
.74928 .25 L
.74928 .25 L
Mistroke
.74928 .25 L
.74929 .25 L
.74929 .25 L
.7493 .25 L
.7493 .25 L
.74931 .25 L
.74932 .25 L
.74932 .25 L
.74933 .25 L
.74934 .25 L
.74934 .25 L
.74935 .25 L
.74935 .25 L
.74936 .25 L
.74937 .25 L
.74937 .25 L
.74938 .25 L
.74939 .25 L
.74939 .25 L
.7494 .25 L
.7494 .25 L
.74941 .25 L
.74941 .25 L
.74942 .25 L
.74942 .25 L
.74943 .25 L
.74943 .25 L
.74944 .25 L
.74944 .25 L
.74944 .25 L
.74945 .25 L
.74945 .25 L
.74945 .25 L
.74946 .25 L
.74946 .25 L
.74947 .25 L
.74947 .25 L
.74948 .25 L
.74949 .25 L
.74949 .25 L
.7495 .25 L
.74951 .25 L
.74951 .25 L
.74952 .25 L
.74952 .25 L
.74953 .25 L
.74954 .25 L
.74954 .25 L
.74955 .25 L
.74956 .25 L
Mistroke
.74956 .25 L
.74957 .25 L
.74957 .25 L
.74958 .25 L
.74958 .25 L
.74959 .25 L
.7496 .25 L
.7496 .25 L
.74961 .25 L
.74961 .25 L
.74962 .25 L
.74962 .25 L
.74963 .25 L
.74964 .25 L
.74964 .25 L
.74965 .25 L
.74965 .25 L
.74966 .25 L
.74967 .25 L
.74967 .25 L
.74967 .25 L
.74968 .25 L
.74969 .25 L
.74969 .25 L
.7497 .25 L
.74971 .25 L
.74971 .25 L
.74972 .25 L
.74973 .25 L
.74973 .25 L
.74974 .25 L
.74975 .25 L
.74975 .25 L
.74976 .25 L
.74976 .25 L
.74977 .25 L
.74977 .25 L
.74978 .25 L
.74979 .25 L
.74979 .25 L
.7498 .25 L
.7498 .25 L
.74981 .25 L
.74982 .25 L
.74982 .25 L
.74983 .25 L
.74983 .25 L
.74984 .25 L
.74985 .25 L
.74985 .25 L
Mistroke
.74986 .25 L
.74986 .25 L
.74987 .25 L
.74987 .25 L
.74988 .25 L
.74988 .25 L
.74989 .25 L
.74989 .25 L
.7499 .25 L
.7499 .25 L
.74991 .25 L
.74992 .25 L
.74992 .25 L
.74993 .25 L
.74993 .25 L
.74994 .25 L
.74994 .25 L
.74995 .25 L
.74996 .25 L
.74996 .25 L
.74996 .25 L
.74997 .25 L
.74998 .25 L
.74998 .25 L
.74999 .25 L
.74999 .25 L
.75 .25 L
.75001 .25 L
.75001 .25 L
.75002 .25 L
.75002 .25 L
.75003 .25 L
.75004 .25 L
.75004 .25 L
.75005 .25 L
.75005 .25 L
.75006 .25 L
.75007 .25 L
.75007 .25 L
.75008 .25 L
.75009 .25 L
.75009 .25 L
.7501 .25 L
.7501 .25 L
.75011 .25 L
.75011 .25 L
.75011 .25 L
.75012 .25 L
.75013 .25 L
.75013 .25 L
Mistroke
.75014 .25 L
.75015 .25 L
.75015 .25 L
.75016 .25 L
.75017 .25 L
.75017 .25 L
.75018 .25 L
.75019 .25 L
.75019 .25 L
.7502 .25 L
.7502 .25 L
.75021 .25 L
.75022 .25 L
.75022 .25 L
.75023 .25 L
.75023 .25 L
.75024 .25 L
.75024 .25 L
.75025 .25 L
.75025 .25 L
.75025 .25 L
.75026 .25 L
.75026 .25 L
.75027 .25 L
.75027 .25 L
.75028 .25 L
.75028 .25 L
.75028 .25 L
.75029 .25 L
.75029 .25 L
.7503 .25 L
.7503 .25 L
.75031 .25 L
.75032 .25 L
.75032 .25 L
.75033 .25 L
.75034 .25 L
.75034 .25 L
.75035 .25 L
.75035 .25 L
.75036 .25 L
.75037 .25 L
.75037 .25 L
.75038 .25 L
.75039 .25 L
.75039 .25 L
.75039 .25 L
.7504 .25 L
.75041 .25 L
.75041 .25 L
Mistroke
.75042 .25 L
.75043 .25 L
.75043 .25 L
.75044 .25 L
.75044 .25 L
.75045 .25 L
.75045 .25 L
.75046 .25 L
.75047 .25 L
.75047 .25 L
.75048 .25 L
.75049 .25 L
.75049 .25 L
.75049 .25 L
.7505 .25 L
.75051 .25 L
.75051 .25 L
.75052 .25 L
.75053 .25 L
.75053 .25 L
.75054 .25 L
.75054 .25 L
.75055 .25 L
.75056 .25 L
.75056 .25 L
.75057 .25 L
.75058 .25 L
.75058 .25 L
.75059 .25 L
.75059 .25 L
.7506 .25 L
.7506 .25 L
.75061 .25 L
.75062 .25 L
.75062 .25 L
.75063 .25 L
.75063 .25 L
.75064 .25 L
.75065 .25 L
.75065 .25 L
.75066 .25 L
.75066 .25 L
.75067 .25 L
.75068 .25 L
.75068 .25 L
.75069 .25 L
.75069 .25 L
.75069 .25 L
.7507 .25 L
.75071 .25 L
Mistroke
.75071 .25 L
.75072 .25 L
.75072 .25 L
.75073 .25 L
.75073 .25 L
.75074 .25 L
.75075 .25 L
.75075 .25 L
.75076 .25 L
.75077 .25 L
.75077 .25 L
.75077 .25 L
.75078 .25 L
.75078 .25 L
.75079 .25 L
.75079 .25 L
.7508 .25 L
.75081 .25 L
.75081 .25 L
.75082 .25 L
.75082 .25 L
.75083 .25 L
.75084 .25 L
.75084 .25 L
.75085 .25 L
.75085 .25 L
.75086 .25 L
.75087 .25 L
.75087 .25 L
.75088 .25 L
.75088 .25 L
.75089 .25 L
.7509 .25 L
.7509 .25 L
.75091 .25 L
.75092 .25 L
.75092 .25 L
.75093 .25 L
.75093 .25 L
.75094 .25 L
.75094 .25 L
.75095 .25 L
.75095 .25 L
.75096 .25 L
.75097 .25 L
.75097 .25 L
.75098 .25 L
.75098 .25 L
.75099 .25 L
.751 .25 L
Mistroke
.751 .25 L
.75101 .25 L
.75102 .25 L
.75102 .25 L
.75103 .25 L
.75104 .25 L
.75104 .25 L
.75105 .25 L
.75105 .25 L
.75106 .25 L
.75106 .25 L
.75107 .25 L
.75107 .25 L
.75107 .25 L
.75108 .25 L
.75108 .25 L
.75109 .25 L
.75109 .25 L
.75109 .25 L
.7511 .25 L
.7511 .25 L
.75111 .25 L
.75111 .25 L
.75111 .25 L
.75112 .25 L
.75113 .25 L
.75113 .25 L
.75114 .25 L
.75115 .25 L
.75115 .25 L
.75116 .25 L
.75116 .25 L
.75117 .25 L
.75118 .25 L
.75118 .25 L
.75119 .25 L
.7512 .25 L
.7512 .25 L
.75121 .25 L
.75121 .25 L
.75122 .25 L
.75122 .25 L
.75123 .25 L
.75124 .25 L
.75124 .25 L
.75125 .25 L
.75126 .25 L
.75126 .25 L
.75127 .25 L
.75127 .25 L
Mistroke
.75128 .25 L
.75128 .25 L
.75129 .25 L
.7513 .25 L
.7513 .25 L
.75131 .25 L
.75131 .25 L
.75132 .25 L
.75132 .25 L
.75133 .25 L
.75134 .25 L
.75134 .25 L
.75135 .25 L
.75136 .25 L
.75136 .25 L
.75137 .25 L
.75137 .25 L
.75138 .25 L
.75139 .25 L
.75139 .25 L
.7514 .25 L
.75141 .25 L
.75141 .25 L
.75142 .25 L
.75142 .25 L
.75143 .25 L
.75143 .25 L
.75144 .25 L
.75145 .25 L
.75145 .25 L
.75146 .25 L
.75146 .25 L
.75147 .25 L
.75147 .25 L
.75148 .25 L
.75149 .25 L
.75149 .25 L
.7515 .25 L
.7515 .25 L
.75151 .25 L
.75152 .25 L
.75152 .25 L
.75152 .25 L
.75153 .25 L
.75154 .25 L
.75154 .25 L
.75155 .25 L
.75155 .25 L
.75156 .25 L
.75156 .25 L
Mistroke
.75157 .25 L
.75158 .25 L
.75158 .25 L
.75159 .25 L
.75159 .25 L
.7516 .25 L
.7516 .25 L
.75161 .25 L
.75161 .25 L
.75162 .25 L
.75162 .25 L
.75163 .25 L
.75164 .25 L
.75164 .25 L
.75165 .25 L
.75165 .25 L
.75166 .25 L
.75167 .25 L
.75167 .25 L
.75168 .25 L
.75168 .25 L
.75169 .25 L
.7517 .25 L
.7517 .25 L
.75171 .25 L
.75171 .25 L
.75172 .25 L
.75173 .25 L
.75173 .25 L
.75174 .25 L
.75175 .25 L
.75175 .25 L
.75175 .25 L
.75176 .25 L
.75176 .25 L
.75177 .25 L
.75178 .25 L
.75178 .25 L
.75179 .25 L
.75179 .25 L
.7518 .25 L
.75181 .25 L
.75181 .25 L
.75182 .25 L
.75183 .25 L
.75183 .25 L
.75184 .25 L
.75185 .25 L
.75185 .25 L
.75186 .25 L
Mistroke
.75186 .25 L
.75187 .25 L
.75188 .25 L
.75188 .25 L
.75189 .25 L
.75189 .25 L
.75189 .25 L
.7519 .25 L
.7519 .25 L
.75191 .25 L
.75191 .25 L
.75191 .25 L
.75192 .25 L
.75192 .25 L
.75193 .25 L
.75193 .25 L
.75193 .25 L
.75194 .25 L
.75194 .25 L
.75195 .25 L
.75196 .25 L
.75196 .25 L
.75197 .25 L
.75198 .25 L
.75198 .25 L
.75199 .25 L
.75199 .25 L
.752 .25 L
.75201 .25 L
.75201 .25 L
.75202 .25 L
.75203 .25 L
.75203 .25 L
.75204 .25 L
.75204 .25 L
.75205 .25 L
.75205 .25 L
.75206 .25 L
.75207 .25 L
.75207 .25 L
.75208 .25 L
.75208 .25 L
.75209 .25 L
.7521 .25 L
.7521 .25 L
.75211 .25 L
.75211 .25 L
.75212 .25 L
.75213 .25 L
.75213 .25 L
Mistroke
.75214 .25 L
.75214 .25 L
.75215 .25 L
.75215 .25 L
.75216 .25 L
.75217 .25 L
.75217 .25 L
.75218 .25 L
.75218 .25 L
.75219 .25 L
.7522 .25 L
.7522 .25 L
.75221 .25 L
.75222 .25 L
.75222 .25 L
.75223 .25 L
.75224 .25 L
.75224 .25 L
.75224 .25 L
.75225 .25 L
.75226 .25 L
.75226 .25 L
.75227 .25 L
.75228 .25 L
.75228 .25 L
.75229 .25 L
.75229 .25 L
.7523 .25 L
.7523 .25 L
.75231 .25 L
.75232 .25 L
.75232 .25 L
.75233 .25 L
.75233 .25 L
.75234 .25 L
.75234 .25 L
.75235 .25 L
.75235 .25 L
.75236 .25 L
.75237 .25 L
.75238 .25 L
.75238 .25 L
.75239 .25 L
.75239 .25 L
.7524 .25 L
.75241 .25 L
.75241 .25 L
.75242 .25 L
.75243 .25 L
.75243 .25 L
Mistroke
.75244 .25 L
.75244 .25 L
.75245 .25 L
.75245 .25 L
.75246 .25 L
.75247 .25 L
.75247 .25 L
.75248 .25 L
.75248 .25 L
.75249 .25 L
.75249 .25 L
.7525 .25 L
.75251 .25 L
.75251 .25 L
.75252 .25 L
.75253 .25 L
.75253 .25 L
.75254 .25 L
.75254 .25 L
.75254 .25 L
.75255 .25 L
.75256 .25 L
.75256 .25 L
.75257 .25 L
.75257 .25 L
.75258 .25 L
.75258 .25 L
.75259 .25 L
.7526 .25 L
.7526 .25 L
.75261 .25 L
.75261 .25 L
.75262 .25 L
.75262 .25 L
.75263 .25 L
.75263 .25 L
.75264 .25 L
.75264 .25 L
.75265 .25 L
.75266 .25 L
.75266 .25 L
.75267 .25 L
.75267 .25 L
.75268 .25 L
.75269 .25 L
.75269 .25 L
.7527 .25 L
.7527 .25 L
.75271 .25 L
.75272 .25 L
Mistroke
.75272 .25 L
.75273 .25 L
.75273 .25 L
.75274 .25 L
.75275 .25 L
.75275 .25 L
.75276 .25 L
.75277 .25 L
.75277 .25 L
.75278 .25 L
.75278 .25 L
.75279 .25 L
.75279 .25 L
.7528 .25 L
.7528 .25 L
.75281 .25 L
.75282 .25 L
.75282 .25 L
.75283 .25 L
.75283 .25 L
.75284 .25 L
.75285 .25 L
.75285 .25 L
.75286 .25 L
.75287 .25 L
.75287 .25 L
.75288 .25 L
.75289 .25 L
.75289 .25 L
.7529 .25 L
.7529 .25 L
.75291 .25 L
.75291 .25 L
.75292 .25 L
.75292 .25 L
.75292 .25 L
.75293 .25 L
.75293 .25 L
.75294 .25 L
.75294 .25 L
.75294 .25 L
.75295 .25 L
.75295 .25 L
.75296 .25 L
.75296 .25 L
.75296 .25 L
.75297 .25 L
.75298 .25 L
.75298 .25 L
.75299 .25 L
Mistroke
.753 .25 L
.753 .25 L
.75301 .25 L
.75301 .25 L
.75302 .25 L
.75303 .25 L
.75303 .25 L
.75304 .25 L
.75305 .25 L
.75305 .25 L
.75306 .25 L
.75306 .25 L
.75307 .25 L
.75307 .25 L
.75308 .25 L
.75309 .25 L
.75309 .25 L
.7531 .25 L
.75311 .25 L
.75311 .25 L
.75312 .25 L
.75312 .25 L
.75313 .25 L
.75313 .25 L
.75314 .25 L
.75315 .25 L
.75315 .25 L
.75316 .25 L
.75316 .25 L
.75317 .25 L
.75317 .25 L
.75318 .25 L
.75319 .25 L
.75319 .25 L
.7532 .25 L
.75321 .25 L
.75321 .25 L
.75322 .25 L
.75322 .25 L
.75323 .25 L
.75324 .25 L
.75324 .25 L
.75325 .25 L
.75326 .25 L
.75326 .25 L
.75327 .25 L
.75327 .25 L
.75328 .25 L
.75328 .25 L
.75329 .25 L
Mistroke
.7533 .25 L
.7533 .25 L
.75331 .25 L
.75331 .25 L
.75332 .25 L
.75333 .25 L
.75333 .25 L
.75334 .25 L
.75334 .25 L
.75335 .25 L
.75336 .25 L
.75336 .25 L
.75337 .25 L
.75337 .25 L
.75338 .25 L
.75338 .25 L
.75339 .25 L
.75339 .25 L
.7534 .25 L
.7534 .25 L
.75341 .25 L
.75341 .25 L
.75342 .25 L
.75343 .25 L
.75343 .25 L
.75344 .25 L
.75344 .25 L
.75345 .25 L
.75345 .25 L
.75346 .25 L
.75346 .25 L
.75347 .25 L
.75347 .25 L
.75348 .25 L
.75349 .25 L
.75349 .25 L
.7535 .25 L
.7535 .25 L
.75351 .25 L
.75352 .25 L
.75352 .25 L
.75353 .25 L
.75353 .25 L
.75354 .25 L
.75355 .25 L
.75355 .25 L
.75356 .25 L
.75357 .25 L
.75357 .25 L
.75358 .25 L
Mistroke
.75358 .25 L
.75359 .25 L
.7536 .25 L
.7536 .25 L
.75361 .25 L
.75361 .25 L
.75361 .25 L
.75362 .25 L
.75363 .25 L
.75363 .25 L
.75364 .25 L
.75365 .25 L
.75365 .25 L
.75366 .25 L
.75366 .25 L
.75367 .25 L
.75368 .25 L
.75368 .25 L
.75369 .25 L
.7537 .25 L
.7537 .25 L
.75371 .25 L
.75372 .25 L
.75372 .25 L
.75373 .25 L
.75373 .25 L
.75374 .25 L
.75374 .25 L
.75374 .25 L
.75375 .25 L
.75375 .25 L
.75376 .25 L
.75376 .25 L
.75377 .25 L
.75377 .25 L
.75377 .25 L
.75378 .25 L
.75378 .25 L
.75378 .25 L
.75379 .25 L
.75379 .25 L
.7538 .25 L
.75381 .25 L
.75381 .25 L
.75382 .25 L
.75383 .25 L
.75383 .25 L
.75384 .25 L
.75385 .25 L
.75385 .25 L
Mistroke
.75386 .25 L
.75386 .25 L
.75387 .25 L
.75388 .25 L
.75388 .25 L
.75389 .25 L
.75389 .25 L
.7539 .25 L
.75391 .25 L
.75391 .25 L
.75392 .25 L
.75392 .25 L
.75393 .25 L
.75394 .25 L
.75394 .25 L
.75395 .25 L
.75395 .25 L
.75396 .25 L
.75396 .25 L
.75397 .25 L
.75398 .25 L
.75398 .25 L
.75399 .25 L
.75399 .25 L
.754 .25 L
.754 .25 L
.75401 .25 L
.75402 .25 L
.75402 .25 L
.75403 .25 L
.75404 .25 L
.75404 .25 L
.75405 .25 L
.75405 .25 L
.75406 .25 L
.75407 .25 L
.75407 .25 L
.75408 .25 L
.75409 .25 L
.75409 .25 L
.75409 .25 L
.7541 .25 L
.75411 .25 L
.75411 .25 L
.75412 .25 L
.75413 .25 L
.75413 .25 L
.75414 .25 L
.75414 .25 L
.75415 .25 L
Mistroke
.75415 .25 L
.75416 .25 L
.75417 .25 L
.75417 .25 L
.75418 .25 L
.75419 .25 L
.75419 .25 L
.75419 .25 L
.7542 .25 L
.75421 .25 L
.75421 .25 L
.75422 .25 L
.75422 .25 L
.75423 .25 L
.75423 .25 L
.75424 .25 L
.75424 .25 L
.75425 .25 L
.75426 .25 L
.75426 .25 L
.75427 .25 L
.75427 .25 L
.75428 .25 L
.75428 .25 L
.75428 .25 L
.75429 .25 L
.7543 .25 L
.7543 .25 L
.75431 .25 L
.75432 .25 L
.75432 .25 L
.75433 .25 L
.75433 .25 L
.75434 .25 L
.75435 .25 L
.75435 .25 L
.75436 .25 L
.75436 .25 L
.75437 .25 L
.75438 .25 L
.75438 .25 L
.75439 .25 L
.7544 .25 L
.7544 .25 L
.75441 .25 L
.75442 .25 L
.75442 .25 L
.75443 .25 L
.75443 .25 L
.75443 .25 L
Mistroke
.75444 .25 L
.75444 .25 L
.75445 .25 L
.75446 .25 L
.75446 .25 L
.75447 .25 L
.75448 .25 L
.75448 .25 L
.75449 .25 L
.75449 .25 L
.7545 .25 L
.75451 .25 L
.75451 .25 L
.75452 .25 L
.75453 .25 L
.75453 .25 L
.75454 .25 L
.75455 .25 L
.75455 .25 L
.75455 .25 L
.75456 .25 L
.75456 .25 L
.75457 .25 L
.75457 .25 L
.75457 .25 L
.75458 .25 L
.75459 .25 L
.75459 .25 L
.75459 .25 L
.7546 .25 L
.7546 .25 L
.7546 .25 L
.75461 .25 L
.75461 .25 L
.75462 .25 L
.75462 .25 L
.75463 .25 L
.75464 .25 L
.75464 .25 L
.75465 .25 L
.75466 .25 L
.75466 .25 L
.75467 .25 L
.75468 .25 L
.75468 .25 L
.75469 .25 L
.75469 .25 L
.7547 .25 L
.75471 .25 L
.75471 .25 L
Mistroke
.75472 .25 L
.75472 .25 L
.75473 .25 L
.75473 .25 L
.75474 .25 L
.75475 .25 L
.75475 .25 L
.75476 .25 L
.75476 .25 L
.75477 .25 L
.75478 .25 L
.75478 .25 L
.75479 .25 L
.75479 .25 L
.7548 .25 L
.75481 .25 L
.75481 .25 L
.75481 .25 L
.75482 .25 L
.75483 .25 L
.75483 .25 L
.75484 .25 L
.75485 .25 L
.75485 .25 L
.75486 .25 L
.75487 .25 L
.75487 .25 L
.75488 .25 L
.75488 .25 L
.75489 .25 L
.7549 .25 L
.7549 .25 L
.75491 .25 L
.75491 .25 L
.75492 .25 L
.75493 .25 L
.75493 .25 L
.75494 .25 L
.75494 .25 L
.75495 .25 L
.75496 .25 L
.75496 .25 L
.75497 .25 L
.75497 .25 L
.75498 .25 L
.75498 .25 L
.75499 .25 L
.755 .25 L
.755 .25 L
.75501 .25 L
Mistroke
.75501 .25 L
.75502 .25 L
.75502 .25 L
.75503 .25 L
.75504 .25 L
.75504 .25 L
.75504 .25 L
.75505 .25 L
.75506 .25 L
.75506 .25 L
.75507 .25 L
.75507 .25 L
.75508 .25 L
.75509 .25 L
.75509 .25 L
.75509 .25 L
.7551 .25 L
.7551 .25 L
.75511 .25 L
.75511 .25 L
.75512 .25 L
.75513 .25 L
.75513 .25 L
.75514 .25 L
.75515 .25 L
.75515 .25 L
.75516 .25 L
.75516 .25 L
.75517 .25 L
.75518 .25 L
.75518 .25 L
.75519 .25 L
.75519 .25 L
.7552 .25 L
.75521 .25 L
.75521 .25 L
.75522 .25 L
.75523 .25 L
.75523 .25 L
.75524 .25 L
.75525 .25 L
.75525 .25 L
.75525 .25 L
.75526 .25 L
.75526 .25 L
.75527 .25 L
.75527 .25 L
.75528 .25 L
.75529 .25 L
.75529 .25 L
Mistroke
.7553 .25 L
.75531 .25 L
.75531 .25 L
.75532 .25 L
.75532 .25 L
.75533 .25 L
.75534 .25 L
.75534 .25 L
.75535 .25 L
.75536 .25 L
.75536 .25 L
.75537 .25 L
.75537 .25 L
.75538 .25 L
.75538 .25 L
.75539 .25 L
.75539 .25 L
.75539 .25 L
.7554 .25 L
.75541 .25 L
.75541 .25 L
.75541 .25 L
.75542 .25 L
.75542 .25 L
.75542 .25 L
.75543 .25 L
.75543 .25 L
.75544 .25 L
.75544 .25 L
.75545 .25 L
.75545 .25 L
.75546 .25 L
.75547 .25 L
.75547 .25 L
.75548 .25 L
.75549 .25 L
.75549 .25 L
.7555 .25 L
.75551 .25 L
.75551 .25 L
.75552 .25 L
.75552 .25 L
.75553 .25 L
.75554 .25 L
.75554 .25 L
.75555 .25 L
.75555 .25 L
.75556 .25 L
.75556 .25 L
.75557 .25 L
Mistroke
.75558 .25 L
.75558 .25 L
.75559 .25 L
.75559 .25 L
.7556 .25 L
.75561 .25 L
.75561 .25 L
.75562 .25 L
.75562 .25 L
.75563 .25 L
.75563 .25 L
.75564 .25 L
.75564 .25 L
.75565 .25 L
.75566 .25 L
.75566 .25 L
.75567 .25 L
.75568 .25 L
.75568 .25 L
.75569 .25 L
.75569 .25 L
.7557 .25 L
.75571 .25 L
.75571 .25 L
.75572 .25 L
.75573 .25 L
.75573 .25 L
.75574 .25 L
.75574 .25 L
.75575 .25 L
.75576 .25 L
.75576 .25 L
.75577 .25 L
.75577 .25 L
.75578 .25 L
.75579 .25 L
.75579 .25 L
.7558 .25 L
.7558 .25 L
.75581 .25 L
.75581 .25 L
.75582 .25 L
.75583 .25 L
.75583 .25 L
.75584 .25 L
.75584 .25 L
.75585 .25 L
.75585 .25 L
.75586 .25 L
.75586 .25 L
Mistroke
.75587 .25 L
.75587 .25 L
.75588 .25 L
.75589 .25 L
.75589 .25 L
.7559 .25 L
.7559 .25 L
.75591 .25 L
.75591 .25 L
.75592 .25 L
.75592 .25 L
.75593 .25 L
.75593 .25 L
.75594 .25 L
.75595 .25 L
.75595 .25 L
.75596 .25 L
.75596 .25 L
.75597 .25 L
.75598 .25 L
.75598 .25 L
.75599 .25 L
.75599 .25 L
.756 .25 L
.75601 .25 L
.75601 .25 L
.75602 .25 L
.75602 .25 L
.75603 .25 L
.75604 .25 L
.75604 .25 L
.75605 .25 L
.75606 .25 L
.75606 .25 L
.75607 .25 L
.75607 .25 L
.75608 .25 L
.75608 .25 L
.75608 .25 L
.75609 .25 L
.7561 .25 L
.7561 .25 L
.75611 .25 L
.75612 .25 L
.75612 .25 L
.75613 .25 L
.75613 .25 L
.75614 .25 L
.75615 .25 L
.75615 .25 L
Mistroke
.75616 .25 L
.75617 .25 L
.75617 .25 L
.75618 .25 L
.75619 .25 L
.75619 .25 L
.7562 .25 L
.7562 .25 L
.75621 .25 L
.75621 .25 L
.75621 .25 L
.75622 .25 L
.75622 .25 L
.75623 .25 L
.75623 .25 L
.75624 .25 L
.75624 .25 L
.75624 .25 L
.75625 .25 L
.75625 .25 L
.75626 .25 L
.75626 .25 L
.75626 .25 L
.75627 .25 L
.75628 .25 L
.75629 .25 L
.75629 .25 L
.7563 .25 L
.7563 .25 L
.75631 .25 L
.75632 .25 L
.75632 .25 L
.75633 .25 L
.75634 .25 L
.75634 .25 L
.75635 .25 L
.75635 .25 L
.75636 .25 L
.75636 .25 L
.75637 .25 L
.75638 .25 L
.75638 .25 L
.75639 .25 L
.75639 .25 L
.7564 .25 L
.75641 .25 L
.75641 .25 L
.75642 .25 L
.75642 .25 L
.75643 .25 L
Mistroke
.75644 .25 L
.75644 .25 L
.75645 .25 L
.75645 .25 L
.75646 .25 L
.75646 .25 L
.75647 .25 L
.75647 .25 L
.75648 .25 L
.75649 .25 L
.75649 .25 L
.7565 .25 L
.75651 .25 L
.75651 .25 L
.75652 .25 L
.75652 .25 L
.75653 .25 L
.75654 .25 L
.75654 .25 L
.75655 .25 L
.75656 .25 L
.75656 .25 L
.75656 .25 L
.75657 .25 L
.75658 .25 L
.75658 .25 L
.75659 .25 L
.7566 .25 L
.7566 .25 L
.75661 .25 L
.75661 .25 L
.75662 .25 L
.75663 .25 L
.75663 .25 L
.75664 .25 L
.75664 .25 L
.75665 .25 L
.75666 .25 L
.75666 .25 L
.75666 .25 L
.75667 .25 L
.75668 .25 L
.75668 .25 L
.75669 .25 L
.7567 .25 L
.7567 .25 L
.75671 .25 L
.75671 .25 L
.75672 .25 L
.75673 .25 L
Mistroke
.75673 .25 L
.75674 .25 L
.75675 .25 L
.75675 .25 L
.75676 .25 L
.75676 .25 L
.75677 .25 L
.75677 .25 L
.75678 .25 L
.75679 .25 L
.75679 .25 L
.7568 .25 L
.75681 .25 L
.75681 .25 L
.75682 .25 L
.75682 .25 L
.75683 .25 L
.75683 .25 L
.75684 .25 L
.75685 .25 L
.75685 .25 L
.75686 .25 L
.75686 .25 L
.75687 .25 L
.75687 .25 L
.75688 .25 L
.75689 .25 L
.75689 .25 L
.75689 .25 L
.7569 .25 L
.75691 .25 L
.75691 .25 L
.75692 .25 L
.75692 .25 L
.75693 .25 L
.75694 .25 L
.75694 .25 L
.75694 .25 L
.75695 .25 L
.75695 .25 L
.75696 .25 L
.75696 .25 L
.75697 .25 L
.75698 .25 L
.75698 .25 L
.75699 .25 L
.757 .25 L
.757 .25 L
.75701 .25 L
.75701 .25 L
Mistroke
.75702 .25 L
.75703 .25 L
.75703 .25 L
.75704 .25 L
.75704 .25 L
.75705 .25 L
.75706 .25 L
.75706 .25 L
.75707 .25 L
.75708 .25 L
.75708 .25 L
.75709 .25 L
.7571 .25 L
.7571 .25 L
.7571 .25 L
.75711 .25 L
.75711 .25 L
.75712 .25 L
.75712 .25 L
.75713 .25 L
.75714 .25 L
.75714 .25 L
.75715 .25 L
.75715 .25 L
.75716 .25 L
.75717 .25 L
.75717 .25 L
.75718 .25 L
.75719 .25 L
.75719 .25 L
.7572 .25 L
.75721 .25 L
.75721 .25 L
.75722 .25 L
.75722 .25 L
.75723 .25 L
.75723 .25 L
.75724 .25 L
.75724 .25 L
.75724 .25 L
.75725 .25 L
.75725 .25 L
.75726 .25 L
.75726 .25 L
.75727 .25 L
.75727 .25 L
.75727 .25 L
.75728 .25 L
.75728 .25 L
.75728 .25 L
Mistroke
.75729 .25 L
.7573 .25 L
.7573 .25 L
.75731 .25 L
.75732 .25 L
.75732 .25 L
.75733 .25 L
.75734 .25 L
.75734 .25 L
.75735 .25 L
.75735 .25 L
.75736 .25 L
.75737 .25 L
.75737 .25 L
.75738 .25 L
.75739 .25 L
.75739 .25 L
.7574 .25 L
.7574 .25 L
.75741 .25 L
.75741 .25 L
.75742 .25 L
.75743 .25 L
.75743 .25 L
.75744 .25 L
.75744 .25 L
.75745 .25 L
.75746 .25 L
.75746 .25 L
.75747 .25 L
.75747 .25 L
.75748 .25 L
.75748 .25 L
.75749 .25 L
.75749 .25 L
.7575 .25 L
.75751 .25 L
.75751 .25 L
.75752 .25 L
.75753 .25 L
.75753 .25 L
.75754 .25 L
.75754 .25 L
.75755 .25 L
.75756 .25 L
.75756 .25 L
.75757 .25 L
.75758 .25 L
.75758 .25 L
.75759 .25 L
Mistroke
.75759 .25 L
.7576 .25 L
.7576 .25 L
.75761 .25 L
.75762 .25 L
.75762 .25 L
.75763 .25 L
.75764 .25 L
.75764 .25 L
.75765 .25 L
.75765 .25 L
.75766 .25 L
.75766 .25 L
.75767 .25 L
.75768 .25 L
.75768 .25 L
.75769 .25 L
.75769 .25 L
.7577 .25 L
.7577 .25 L
.75771 .25 L
.75771 .25 L
.75772 .25 L
.75772 .25 L
.75773 .25 L
.75774 .25 L
.75774 .25 L
.75775 .25 L
.75775 .25 L
.75776 .25 L
.75776 .25 L
.75777 .25 L
.75777 .25 L
.75778 .25 L
.75778 .25 L
.75779 .25 L
.7578 .25 L
.7578 .25 L
.75781 .25 L
.75781 .25 L
.75782 .25 L
.75783 .25 L
.75783 .25 L
.75784 .25 L
.75784 .25 L
.75785 .25 L
.75786 .25 L
.75786 .25 L
.75787 .25 L
.75787 .25 L
Mistroke
.75788 .25 L
.75789 .25 L
.75789 .25 L
.7579 .25 L
.75791 .25 L
.75791 .25 L
.75792 .25 L
.75792 .25 L
.75793 .25 L
.75793 .25 L
.75793 .25 L
.75794 .25 L
.75795 .25 L
.75795 .25 L
.75796 .25 L
.75797 .25 L
.75797 .25 L
.75798 .25 L
.75798 .25 L
.75799 .25 L
.758 .25 L
.758 .25 L
.75801 .25 L
.75802 .25 L
.75802 .25 L
.75803 .25 L
.75804 .25 L
.75804 .25 L
.75805 .25 L
.75805 .25 L
.75806 .25 L
.75806 .25 L
.75806 .25 L
.75807 .25 L
.75807 .25 L
.75808 .25 L
.75808 .25 L
.75809 .25 L
.75809 .25 L
.75809 .25 L
.7581 .25 L
.7581 .25 L
.75811 .25 L
.75811 .25 L
.75812 .25 L
.75812 .25 L
.75813 .25 L
.75814 .25 L
.75814 .25 L
.75815 .25 L
Mistroke
.75815 .25 L
.75816 .25 L
.75817 .25 L
.75817 .25 L
.75818 .25 L
.75819 .25 L
.75819 .25 L
.7582 .25 L
.75821 .25 L
.75821 .25 L
.75821 .25 L
.75822 .25 L
.75823 .25 L
.75823 .25 L
.75824 .25 L
.75824 .25 L
.75825 .25 L
.75826 .25 L
.75826 .25 L
.75827 .25 L
.75827 .25 L
.75828 .25 L
.75829 .25 L
.75829 .25 L
.7583 .25 L
.7583 .25 L
.75831 .25 L
.75831 .25 L
.75832 .25 L
.75832 .25 L
.75833 .25 L
.75834 .25 L
.75834 .25 L
.75835 .25 L
.75836 .25 L
.75836 .25 L
.75837 .25 L
.75837 .25 L
.75838 .25 L
.75839 .25 L
.75839 .25 L
.7584 .25 L
.75841 .25 L
.75841 .25 L
.75842 .25 L
.75842 .25 L
.75843 .25 L
.75843 .25 L
.75844 .25 L
.75845 .25 L
Mistroke
.75845 .25 L
.75846 .25 L
.75846 .25 L
.75847 .25 L
.75848 .25 L
.75848 .25 L
.75849 .25 L
.75849 .25 L
.7585 .25 L
.75851 .25 L
.75851 .25 L
.75851 .25 L
.75852 .25 L
.75853 .25 L
.75853 .25 L
.75854 .25 L
.75854 .25 L
.75855 .25 L
.75855 .25 L
.75856 .25 L
.75856 .25 L
.75857 .25 L
.75858 .25 L
.75858 .25 L
.75859 .25 L
.75859 .25 L
.7586 .25 L
.7586 .25 L
.75861 .25 L
.75861 .25 L
.75862 .25 L
.75863 .25 L
.75863 .25 L
.75864 .25 L
.75864 .25 L
.75865 .25 L
.75865 .25 L
.75866 .25 L
.75867 .25 L
.75867 .25 L
.75868 .25 L
.75869 .25 L
.75869 .25 L
.7587 .25 L
.7587 .25 L
.75871 .25 L
.75872 .25 L
.75872 .25 L
.75873 .25 L
.75874 .25 L
Mistroke
.75874 .25 L
.75875 .25 L
.75875 .25 L
.75875 .25 L
.75876 .25 L
.75876 .25 L
.75877 .25 L
.75878 .25 L
.75878 .25 L
.75879 .25 L
.7588 .25 L
.7588 .25 L
.75881 .25 L
.75881 .25 L
.75882 .25 L
.75883 .25 L
.75883 .25 L
.75884 .25 L
.75885 .25 L
.75885 .25 L
.75886 .25 L
.75887 .25 L
.75887 .25 L
.75887 .25 L
.75888 .25 L
.75888 .25 L
.75889 .25 L
.75889 .25 L
.7589 .25 L
.7589 .25 L
.75891 .25 L
.75891 .25 L
.75891 .25 L
.75892 .25 L
.75892 .25 L
.75893 .25 L
.75893 .25 L
.75893 .25 L
.75894 .25 L
.75895 .25 L
.75895 .25 L
.75896 .25 L
.75897 .25 L
.75897 .25 L
.75898 .25 L
.75898 .25 L
.75899 .25 L
.759 .25 L
.759 .25 L
.75901 .25 L
Mistroke
.75902 .25 L
.75902 .25 L
.75903 .25 L
.75903 .25 L
.75904 .25 L
.75904 .25 L
.75905 .25 L
.75906 .25 L
.75906 .25 L
.75907 .25 L
.75907 .25 L
.75908 .25 L
.75909 .25 L
.75909 .25 L
.7591 .25 L
.7591 .25 L
.75911 .25 L
.75912 .25 L
.75912 .25 L
.75913 .25 L
.75913 .25 L
.75913 .25 L
.75914 .25 L
.75915 .25 L
.75915 .25 L
.75916 .25 L
.75917 .25 L
.75917 .25 L
.75918 .25 L
.75919 .25 L
.75919 .25 L
.7592 .25 L
.7592 .25 L
.75921 .25 L
.75922 .25 L
.75922 .25 L
.75923 .25 L
.75924 .25 L
.75924 .25 L
.75925 .25 L
.75925 .25 L
.75926 .25 L
.75926 .25 L
.75927 .25 L
.75928 .25 L
.75928 .25 L
.75929 .25 L
.75929 .25 L
.7593 .25 L
.75931 .25 L
Mistroke
.75931 .25 L
.75932 .25 L
.75932 .25 L
.75933 .25 L
.75933 .25 L
.75934 .25 L
.75934 .25 L
.75935 .25 L
.75936 .25 L
.75936 .25 L
.75936 .25 L
.75937 .25 L
.75938 .25 L
.75938 .25 L
.75939 .25 L
.75939 .25 L
.7594 .25 L
.75941 .25 L
.75941 .25 L
.75941 .25 L
.75942 .25 L
.75943 .25 L
.75943 .25 L
.75944 .25 L
.75944 .25 L
.75945 .25 L
.75945 .25 L
.75946 .25 L
.75947 .25 L
.75947 .25 L
.75948 .25 L
.75948 .25 L
.75949 .25 L
.7595 .25 L
.7595 .25 L
.75951 .25 L
.75952 .25 L
.75952 .25 L
.75953 .25 L
.75953 .25 L
.75954 .25 L
.75955 .25 L
.75955 .25 L
.75956 .25 L
.75957 .25 L
.75957 .25 L
.75957 .25 L
.75958 .25 L
.75958 .25 L
.75959 .25 L
Mistroke
.75959 .25 L
.7596 .25 L
.75961 .25 L
.75961 .25 L
.75962 .25 L
.75963 .25 L
.75963 .25 L
.75964 .25 L
.75964 .25 L
.75965 .25 L
.75966 .25 L
.75966 .25 L
.75967 .25 L
.75968 .25 L
.75968 .25 L
.75969 .25 L
.75969 .25 L
.7597 .25 L
.7597 .25 L
.75971 .25 L
.75971 .25 L
.75972 .25 L
.75972 .25 L
.75973 .25 L
.75973 .25 L
.75973 .25 L
.75974 .25 L
.75974 .25 L
.75974 .25 L
.75975 .25 L
.75975 .25 L
.75976 .25 L
.75976 .25 L
.75977 .25 L
.75978 .25 L
.75978 .25 L
.75979 .25 L
.7598 .25 L
.7598 .25 L
.75981 .25 L
.75981 .25 L
.75982 .25 L
.75983 .25 L
.75983 .25 L
.75984 .25 L
.75985 .25 L
.75985 .25 L
.75986 .25 L
.75986 .25 L
.75987 .25 L
Mistroke
.75987 .25 L
.75988 .25 L
.75989 .25 L
.75989 .25 L
.7599 .25 L
.7599 .25 L
.75991 .25 L
.75991 .25 L
.75992 .25 L
.75993 .25 L
.75993 .25 L
.75994 .25 L
.75994 .25 L
.75995 .25 L
.75995 .25 L
.75996 .25 L
.75996 .25 L
.75997 .25 L
.75998 .25 L
.75998 .25 L
.75999 .25 L
.76 .25 L
.76 .25 L
.76001 .25 L
.76002 .25 L
.76002 .25 L
.76003 .25 L
.76003 .25 L
.76004 .25 L
.76005 .25 L
.76005 .25 L
.76006 .25 L
.76006 .25 L
.76007 .25 L
.76008 .25 L
.76008 .25 L
.76009 .25 L
.76009 .25 L
.7601 .25 L
.76011 .25 L
.76011 .25 L
.76012 .25 L
.76012 .25 L
.76013 .25 L
.76014 .25 L
.76014 .25 L
.76015 .25 L
.76015 .25 L
.76016 .25 L
.76016 .25 L
Mistroke
.76017 .25 L
.76017 .25 L
.76018 .25 L
.76019 .25 L
.76019 .25 L
.7602 .25 L
.76021 .25 L
.76021 .25 L
.76022 .25 L
.76022 .25 L
.76023 .25 L
.76024 .25 L
.76024 .25 L
.76025 .25 L
.76026 .25 L
.76026 .25 L
.76026 .25 L
.76027 .25 L
.76028 .25 L
.76028 .25 L
.76029 .25 L
.7603 .25 L
.7603 .25 L
.76031 .25 L
.76031 .25 L
.76032 .25 L
.76033 .25 L
.76033 .25 L
.76034 .25 L
.76034 .25 L
.76035 .25 L
.76036 .25 L
.76036 .25 L
.76036 .25 L
.76037 .25 L
.76038 .25 L
.76038 .25 L
.76039 .25 L
.76039 .25 L
.7604 .25 L
.7604 .25 L
.76041 .25 L
.76041 .25 L
.76042 .25 L
.76043 .25 L
.76043 .25 L
.76044 .25 L
.76044 .25 L
.76045 .25 L
.76045 .25 L
Mistroke
.76045 .25 L
.76046 .25 L
.76047 .25 L
.76047 .25 L
.76048 .25 L
.76049 .25 L
.76049 .25 L
.7605 .25 L
.7605 .25 L
.76051 .25 L
.76052 .25 L
.76052 .25 L
.76053 .25 L
.76054 .25 L
.76054 .25 L
.76055 .25 L
.76055 .25 L
.76056 .25 L
.76057 .25 L
.76057 .25 L
.76058 .25 L
.76059 .25 L
.76059 .25 L
.7606 .25 L
.7606 .25 L
.7606 .25 L
.76061 .25 L
.76061 .25 L
.76062 .25 L
.76063 .25 L
.76063 .25 L
.76064 .25 L
.76065 .25 L
.76065 .25 L
.76066 .25 L
.76066 .25 L
.76067 .25 L
.76068 .25 L
.76068 .25 L
.76069 .25 L
.7607 .25 L
.7607 .25 L
.76071 .25 L
.76072 .25 L
.76072 .25 L
.76072 .25 L
.76073 .25 L
.76073 .25 L
.76074 .25 L
.76074 .25 L
Mistroke
.76075 .25 L
.76075 .25 L
.76076 .25 L
.76076 .25 L
.76076 .25 L
.76077 .25 L
.76077 .25 L
.76077 .25 L
.76078 .25 L
.76078 .25 L
.76079 .25 L
.7608 .25 L
.7608 .25 L
.76081 .25 L
.76082 .25 L
.76082 .25 L
.76083 .25 L
.76083 .25 L
.76084 .25 L
.76085 .25 L
.76085 .25 L
.76086 .25 L
.76087 .25 L
.76087 .25 L
.76088 .25 L
.76088 .25 L
.76089 .25 L
.76089 .25 L
.7609 .25 L
.76091 .25 L
.76091 .25 L
.76092 .25 L
.76092 .25 L
.76093 .25 L
.76093 .25 L
.76094 .25 L
.76095 .25 L
.76095 .25 L
.76096 .25 L
.76097 .25 L
.76097 .25 L
.76098 .25 L
.76098 .25 L
.76098 .25 L
.76099 .25 L
.761 .25 L
.761 .25 L
.76101 .25 L
.76102 .25 L
.76102 .25 L
Mistroke
.76103 .25 L
.76104 .25 L
.76104 .25 L
.76105 .25 L
.76105 .25 L
.76106 .25 L
.76107 .25 L
.76107 .25 L
.76108 .25 L
.76109 .25 L
.76109 .25 L
.7611 .25 L
.7611 .25 L
.76111 .25 L
.76111 .25 L
.76112 .25 L
.76113 .25 L
.76113 .25 L
.76114 .25 L
.76114 .25 L
.76115 .25 L
.76116 .25 L
.76116 .25 L
.76117 .25 L
.76117 .25 L
.76118 .25 L
.76118 .25 L
.76119 .25 L
.76119 .25 L
.7612 .25 L
.76121 .25 L
.76121 .25 L
.76121 .25 L
.76122 .25 L
.76123 .25 L
.76123 .25 L
.76124 .25 L
.76124 .25 L
.76125 .25 L
.76126 .25 L
.76126 .25 L
.76126 .25 L
.76127 .25 L
.76128 .25 L
.76128 .25 L
.76129 .25 L
.76129 .25 L
.7613 .25 L
.76131 .25 L
.76131 .25 L
Mistroke
.76132 .25 L
.76132 .25 L
.76133 .25 L
.76133 .25 L
.76134 .25 L
.76135 .25 L
.76135 .25 L
.76136 .25 L
.76137 .25 L
.76137 .25 L
.76138 .25 L
.76138 .25 L
.76139 .25 L
.7614 .25 L
.7614 .25 L
.76141 .25 L
.76142 .25 L
.76142 .25 L
.76142 .25 L
.76143 .25 L
.76143 .25 L
.76144 .25 L
.76144 .25 L
.76145 .25 L
.76146 .25 L
.76146 .25 L
.76147 .25 L
.76148 .25 L
.76148 .25 L
.76149 .25 L
.76149 .25 L
.7615 .25 L
.76151 .25 L
.76151 .25 L
.76152 .25 L
.76153 .25 L
.76153 .25 L
.76154 .25 L
.76154 .25 L
.76155 .25 L
.76155 .25 L
.76156 .25 L
.76156 .25 L
.76157 .25 L
.76157 .25 L
.76158 .25 L
.76158 .25 L
.76158 .25 L
.76159 .25 L
.76159 .25 L
Mistroke
.76159 .25 L
.7616 .25 L
.7616 .25 L
.76161 .25 L
.76161 .25 L
.76162 .25 L
.76163 .25 L
.76163 .25 L
.76164 .25 L
.76165 .25 L
.76165 .25 L
.76166 .25 L
.76166 .25 L
.76167 .25 L
.76168 .25 L
.76168 .25 L
.76169 .25 L
.7617 .25 L
.7617 .25 L
.76171 .25 L
.76171 .25 L
.76172 .25 L
.76172 .25 L
.76173 .25 L
.76174 .25 L
.76174 .25 L
.76175 .25 L
.76175 .25 L
.76176 .25 L
.76176 .25 L
.76177 .25 L
.76178 .25 L
.76178 .25 L
.76179 .25 L
.76179 .25 L
.7618 .25 L
.76181 .25 L
.76181 .25 L
.76181 .25 L
.76182 .25 L
.76183 .25 L
.76183 .25 L
.76184 .25 L
.76185 .25 L
.76185 .25 L
.76186 .25 L
.76187 .25 L
.76187 .25 L
.76188 .25 L
.76189 .25 L
Mistroke
.76189 .25 L
.7619 .25 L
.7619 .25 L
.76191 .25 L
.76191 .25 L
.76192 .25 L
.76193 .25 L
.76193 .25 L
.76194 .25 L
.76194 .25 L
.76195 .25 L
.76196 .25 L
.76196 .25 L
.76197 .25 L
.76197 .25 L
.76198 .25 L
.76199 .25 L
.76199 .25 L
.762 .25 L
.762 .25 L
.76201 .25 L
.76201 .25 L
.76202 .25 L
.76202 .25 L
.76203 .25 L
.76203 .25 L
.76204 .25 L
.76204 .25 L
.76205 .25 L
.76206 .25 L
.76206 .25 L
.76207 .25 L
.76207 .25 L
.76208 .25 L
.76208 .25 L
.76209 .25 L
.7621 .25 L
.7621 .25 L
.7621 .25 L
.76211 .25 L
.76212 .25 L
.76212 .25 L
.76213 .25 L
.76213 .25 L
.76214 .25 L
.76215 .25 L
.76215 .25 L
.76216 .25 L
.76216 .25 L
.76217 .25 L
Mistroke
.76218 .25 L
.76218 .25 L
.76219 .25 L
.76219 .25 L
.7622 .25 L
.76221 .25 L
.76221 .25 L
.76222 .25 L
.76223 .25 L
.76223 .25 L
.76224 .25 L
.76224 .25 L
.76225 .25 L
.76225 .25 L
.76225 .25 L
.76226 .25 L
.76227 .25 L
.76227 .25 L
.76228 .25 L
.76229 .25 L
.76229 .25 L
.7623 .25 L
.76231 .25 L
.76231 .25 L
.76232 .25 L
.76233 .25 L
.76233 .25 L
.76234 .25 L
.76234 .25 L
.76235 .25 L
.76236 .25 L
.76236 .25 L
.76237 .25 L
.76237 .25 L
.76238 .25 L
.76238 .25 L
.76239 .25 L
.76239 .25 L
.76239 .25 L
.7624 .25 L
.7624 .25 L
.76241 .25 L
.76241 .25 L
.76242 .25 L
.76242 .25 L
.76242 .25 L
.76243 .25 L
.76243 .25 L
.76244 .25 L
.76244 .25 L
Mistroke
.76245 .25 L
.76246 .25 L
.76246 .25 L
.76247 .25 L
.76248 .25 L
.76248 .25 L
.76249 .25 L
.76249 .25 L
.7625 .25 L
.76251 .25 L
.76251 .25 L
.76252 .25 L
.76253 .25 L
.76253 .25 L
.76253 .25 L
.76254 .25 L
.76255 .25 L
.76255 .25 L
.76256 .25 L
.76257 .25 L
.76257 .25 L
.76258 .25 L
.76258 .25 L
.76259 .25 L
.76259 .25 L
.7626 .25 L
.76261 .25 L
.76261 .25 L
.76262 .25 L
.76263 .25 L
.76263 .25 L
.76263 .25 L
.76264 .25 L
.76265 .25 L
.76265 .25 L
.76266 .25 L
.76267 .25 L
.76267 .25 L
.76268 .25 L
.76268 .25 L
.76269 .25 L
.7627 .25 L
.7627 .25 L
.76271 .25 L
.76272 .25 L
.76272 .25 L
.76273 .25 L
.76273 .25 L
.76274 .25 L
.76274 .25 L
Mistroke
.76275 .25 L
.76276 .25 L
.76276 .25 L
.76277 .25 L
.76277 .25 L
.76278 .25 L
.76278 .25 L
.76279 .25 L
.7628 .25 L
.7628 .25 L
.76281 .25 L
.76282 .25 L
.76282 .25 L
.76283 .25 L
.76283 .25 L
.76283 .25 L
.76284 .25 L
.76285 .25 L
.76285 .25 L
.76286 .25 L
.76286 .25 L
.76287 .25 L
.76287 .25 L
.76288 .25 L
.76289 .25 L
.76289 .25 L
.7629 .25 L
.7629 .25 L
.76291 .25 L
.76291 .25 L
.76292 .25 L
.76292 .25 L
.76293 .25 L
.76293 .25 L
.76294 .25 L
.76295 .25 L
.76295 .25 L
.76296 .25 L
.76296 .25 L
.76297 .25 L
.76297 .25 L
.76298 .25 L
.76299 .25 L
.76299 .25 L
.763 .25 L
.76301 .25 L
.76301 .25 L
.76302 .25 L
.76302 .25 L
.76303 .25 L
Mistroke
.76304 .25 L
.76304 .25 L
.76305 .25 L
.76306 .25 L
.76306 .25 L
.76307 .25 L
.76307 .25 L
.76307 .25 L
.76308 .25 L
.76308 .25 L
.76309 .25 L
.7631 .25 L
.7631 .25 L
.76311 .25 L
.76312 .25 L
.76312 .25 L
.76313 .25 L
.76314 .25 L
.76314 .25 L
.76315 .25 L
.76315 .25 L
.76316 .25 L
.76317 .25 L
.76317 .25 L
.76318 .25 L
.76319 .25 L
.76319 .25 L
.7632 .25 L
.7632 .25 L
.76321 .25 L
.76321 .25 L
.76321 .25 L
.76322 .25 L
.76322 .25 L
.76323 .25 L
.76323 .25 L
.76323 .25 L
.76324 .25 L
.76324 .25 L
.76325 .25 L
.76325 .25 L
.76325 .25 L
.76326 .25 L
.76327 .25 L
.76327 .25 L
.76328 .25 L
.76329 .25 L
.76329 .25 L
.7633 .25 L
.7633 .25 L
Mistroke
.76331 .25 L
.76332 .25 L
.76332 .25 L
.76333 .25 L
.76334 .25 L
.76334 .25 L
.76335 .25 L
.76335 .25 L
.76336 .25 L
.76336 .25 L
.76337 .25 L
.76338 .25 L
.76338 .25 L
.76339 .25 L
.7634 .25 L
.7634 .25 L
.76341 .25 L
.76341 .25 L
.76342 .25 L
.76342 .25 L
.76343 .25 L
.76344 .25 L
.76344 .25 L
.76345 .25 L
.76345 .25 L
.76346 .25 L
.76346 .25 L
.76347 .25 L
.76347 .25 L
.76348 .25 L
.76349 .25 L
.76349 .25 L
.7635 .25 L
.76351 .25 L
.76351 .25 L
.76352 .25 L
.76353 .25 L
.76353 .25 L
.76354 .25 L
.76354 .25 L
.76355 .25 L
.76356 .25 L
.76356 .25 L
.76357 .25 L
.76357 .25 L
.76358 .25 L
.76358 .25 L
.76359 .25 L
.7636 .25 L
.7636 .25 L
Mistroke
.76361 .25 L
.76361 .25 L
.76362 .25 L
.76363 .25 L
.76363 .25 L
.76364 .25 L
.76364 .25 L
.76365 .25 L
.76365 .25 L
.76366 .25 L
.76366 .25 L
.76367 .25 L
.76368 .25 L
.76368 .25 L
.76369 .25 L
.7637 .25 L
.7637 .25 L
.76371 .25 L
.76372 .25 L
.76372 .25 L
.76373 .25 L
.76373 .25 L
.76374 .25 L
.76375 .25 L
.76375 .25 L
.76376 .25 L
.76376 .25 L
.76377 .25 L
.76378 .25 L
.76378 .25 L
.76379 .25 L
.76379 .25 L
.7638 .25 L
.76381 .25 L
.76381 .25 L
.76382 .25 L
.76382 .25 L
.76383 .25 L
.76384 .25 L
.76384 .25 L
.76385 .25 L
.76385 .25 L
.76386 .25 L
.76386 .25 L
.76387 .25 L
.76387 .25 L
.76388 .25 L
.76388 .25 L
.76389 .25 L
.76389 .25 L
Mistroke
.7639 .25 L
.76391 .25 L
.76391 .25 L
.76392 .25 L
.76392 .25 L
.76393 .25 L
.76393 .25 L
.76394 .25 L
.76394 .25 L
.76395 .25 L
.76395 .25 L
.76396 .25 L
.76397 .25 L
.76397 .25 L
.76398 .25 L
.76398 .25 L
.76399 .25 L
.764 .25 L
.764 .25 L
.76401 .25 L
.76401 .25 L
.76402 .25 L
.76403 .25 L
.76403 .25 L
.76404 .25 L
.76404 .25 L
.76405 .25 L
.76406 .25 L
.76406 .25 L
.76407 .25 L
.76408 .25 L
.76408 .25 L
.76409 .25 L
.76409 .25 L
.7641 .25 L
.7641 .25 L
.7641 .25 L
.76411 .25 L
.76412 .25 L
.76412 .25 L
.76413 .25 L
.76414 .25 L
.76414 .25 L
.76415 .25 L
.76415 .25 L
.76416 .25 L
.76417 .25 L
.76417 .25 L
.76418 .25 L
.76419 .25 L
Mistroke
.76419 .25 L
.7642 .25 L
.76421 .25 L
.76421 .25 L
.76422 .25 L
.76422 .25 L
.76423 .25 L
.76423 .25 L
.76424 .25 L
.76424 .25 L
.76424 .25 L
.76425 .25 L
.76425 .25 L
.76426 .25 L
.76426 .25 L
.76426 .25 L
.76427 .25 L
.76427 .25 L
.76428 .25 L
.76428 .25 L
.76429 .25 L
.76429 .25 L
.7643 .25 L
.76431 .25 L
.76431 .25 L
.76432 .25 L
.76433 .25 L
.76433 .25 L
.76434 .25 L
.76434 .25 L
.76435 .25 L
.76436 .25 L
.76436 .25 L
.76437 .25 L
.76438 .25 L
.76438 .25 L
.76438 .25 L
.76439 .25 L
.7644 .25 L
.7644 .25 L
.76441 .25 L
.76442 .25 L
.76442 .25 L
.76443 .25 L
.76443 .25 L
.76444 .25 L
.76444 .25 L
.76445 .25 L
.76446 .25 L
.76446 .25 L
Mistroke
.76447 .25 L
.76448 .25 L
.76448 .25 L
.76448 .25 L
.76449 .25 L
.7645 .25 L
.7645 .25 L
.7645 .25 L
.76451 .25 L
.76452 .25 L
.76452 .25 L
.76452 .25 L
.76453 .25 L
.76454 .25 L
.76454 .25 L
.76454 .25 L
.76455 .25 L
Mfstroke
.76455 .25 m
.76456 .25 L
.76456 .25 L
.76457 .25 L
.76458 .25 L
.76458 .25 L
.76459 .25 L
.76459 .25 L
.7646 .25 L
.7646 .25 L
.76461 .25 L
.76462 .25 L
.76462 .25 L
.76463 .25 L
.76463 .25 L
.76464 .25 L
.76464 .25 L
.76465 .25 L
.76465 .25 L
.76466 .25 L
.76466 .25 L
.76467 .25 L
.76467 .25 L
.76468 .25 L
.76468 .25 L
.76468 .25 L
.76469 .25 L
.76469 .25 L
.7647 .25 L
.76471 .25 L
.76471 .25 L
.76472 .25 L
.76472 .25 L
.76473 .25 L
.76474 .25 L
.76474 .25 L
.76475 .25 L
.76476 .25 L
.76476 .25 L
.76476 .25 L
.76477 .25 L
.76477 .25 L
.76478 .25 L
.76478 .25 L
.76479 .25 L
.76479 .25 L
.7648 .25 L
.7648 .25 L
.76481 .25 L
.76481 .25 L
Mistroke
.76482 .25 L
.76482 .25 L
.76482 .25 L
.76483 .25 L
.76483 .25 L
.76484 .25 L
.76484 .25 L
.76484 .25 L
.76485 .25 L
.76485 .25 L
.76486 .25 L
.76486 .25 L
.76487 .25 L
.76487 .25 L
.76487 .25 L
.76488 .25 L
.76489 .25 L
.76489 .25 L
.7649 .25 L
.76491 .25 L
.76491 .25 L
.76492 .25 L
.76492 .25 L
.76493 .25 L
.76493 .25 L
.76493 .25 L
.76494 .25 L
.76494 .25 L
.76495 .25 L
.76495 .25 L
.76496 .25 L
.76496 .25 L
.76497 .25 L
.76498 .25 L
.76498 .25 L
.76499 .25 L
.76499 .25 L
.765 .25 L
.76501 .25 L
.76501 .25 L
.76502 .25 L
.76502 .25 L
.76503 .25 L
.76503 .25 L
.76504 .25 L
.76504 .25 L
.76504 .25 L
.76505 .25 L
.76505 .25 L
.76506 .25 L
Mistroke
.76506 .25 L
.76507 .25 L
.76507 .25 L
.76508 .25 L
.76509 .25 L
.76509 .25 L
.7651 .25 L
.76511 .25 L
.76511 .25 L
.76512 .25 L
.76512 .25 L
.76513 .25 L
.76514 .25 L
.76514 .25 L
.76515 .25 L
.76515 .25 L
.76516 .25 L
.76517 .25 L
.76517 .25 L
.76517 .25 L
.76518 .25 L
.76519 .25 L
.76519 .25 L
.7652 .25 L
.76521 .25 L
.76521 .25 L
.76522 .25 L
.76522 .25 L
.76523 .25 L
.76524 .25 L
.76524 .25 L
.76525 .25 L
.76526 .25 L
.76526 .25 L
.76527 .25 L
.76527 .25 L
.76528 .25 L
.76528 .25 L
.76529 .25 L
.7653 .25 L
.7653 .25 L
.76531 .25 L
.76532 .25 L
.76532 .25 L
.76533 .25 L
.76533 .25 L
.76534 .25 L
.76534 .25 L
.76535 .25 L
.76536 .25 L
Mistroke
.76536 .25 L
.76537 .25 L
.76537 .25 L
.76538 .25 L
.76538 .25 L
.76539 .25 L
.7654 .25 L
.7654 .25 L
.76541 .25 L
.76541 .25 L
.76542 .25 L
.76543 .25 L
.76543 .25 L
.76544 .25 L
.76545 .25 L
.76545 .25 L
.76546 .25 L
.76546 .25 L
.76547 .25 L
.76548 .25 L
.76548 .25 L
.76549 .25 L
.76549 .25 L
.7655 .25 L
.7655 .25 L
.76551 .25 L
.76552 .25 L
.76552 .25 L
.76553 .25 L
.76553 .25 L
.76554 .25 L
.76555 .25 L
.76555 .25 L
.76556 .25 L
.76556 .25 L
.76557 .25 L
.76557 .25 L
.76558 .25 L
.76558 .25 L
.76559 .25 L
.7656 .25 L
.7656 .25 L
.76561 .25 L
.76562 .25 L
.76562 .25 L
.76563 .25 L
.76564 .25 L
.76564 .25 L
.76565 .25 L
.76565 .25 L
Mistroke
.76566 .25 L
.76567 .25 L
.76567 .25 L
.76568 .25 L
.76568 .25 L
.76569 .25 L
.7657 .25 L
.7657 .25 L
.76571 .25 L
.76571 .25 L
.76572 .25 L
.76573 .25 L
.76573 .25 L
.76574 .25 L
.76574 .25 L
.76575 .25 L
.76575 .25 L
.76576 .25 L
.76577 .25 L
.76577 .25 L
.76578 .25 L
.76578 .25 L
.76579 .25 L
.76579 .25 L
.7658 .25 L
.76581 .25 L
.76581 .25 L
.76582 .25 L
.76583 .25 L
.76583 .25 L
.76584 .25 L
.76584 .25 L
.76585 .25 L
.76586 .25 L
.76586 .25 L
.76587 .25 L
.76588 .25 L
.76588 .25 L
.76588 .25 L
.76589 .25 L
.7659 .25 L
.7659 .25 L
.76591 .25 L
.76592 .25 L
.76592 .25 L
.76593 .25 L
.76593 .25 L
.76594 .25 L
.76594 .25 L
.76595 .25 L
Mistroke
.76596 .25 L
.76596 .25 L
.76597 .25 L
.76598 .25 L
.76598 .25 L
.76598 .25 L
.76599 .25 L
.766 .25 L
.766 .25 L
.76601 .25 L
.76601 .25 L
.76602 .25 L
.76602 .25 L
.76603 .25 L
.76603 .25 L
.76604 .25 L
.76605 .25 L
.76605 .25 L
.76606 .25 L
.76606 .25 L
.76607 .25 L
.76607 .25 L
.76607 .25 L
.76608 .25 L
.76609 .25 L
.76609 .25 L
.7661 .25 L
.76611 .25 L
.76611 .25 L
.76612 .25 L
.76612 .25 L
.76613 .25 L
.76614 .25 L
.76614 .25 L
.76615 .25 L
.76615 .25 L
.76616 .25 L
.76617 .25 L
.76617 .25 L
.76618 .25 L
.76619 .25 L
.76619 .25 L
.7662 .25 L
.76621 .25 L
.76621 .25 L
.76622 .25 L
.76622 .25 L
.76622 .25 L
.76623 .25 L
.76623 .25 L
Mistroke
.76624 .25 L
.76625 .25 L
.76625 .25 L
.76626 .25 L
.76627 .25 L
.76627 .25 L
.76628 .25 L
.76628 .25 L
.76629 .25 L
.7663 .25 L
.7663 .25 L
.76631 .25 L
.76632 .25 L
.76632 .25 L
.76633 .25 L
.76634 .25 L
.76634 .25 L
.76634 .25 L
.76635 .25 L
.76635 .25 L
.76636 .25 L
.76636 .25 L
.76637 .25 L
.76637 .25 L
.76638 .25 L
.76638 .25 L
.76638 .25 L
.76639 .25 L
.76639 .25 L
.76639 .25 L
.7664 .25 L
.7664 .25 L
.76641 .25 L
.76642 .25 L
.76642 .25 L
.76643 .25 L
.76644 .25 L
.76644 .25 L
.76645 .25 L
.76645 .25 L
.76646 .25 L
.76647 .25 L
.76647 .25 L
.76648 .25 L
.76648 .25 L
.76649 .25 L
.7665 .25 L
.7665 .25 L
.76651 .25 L
.76651 .25 L
Mistroke
.76652 .25 L
.76653 .25 L
.76653 .25 L
.76654 .25 L
.76654 .25 L
.76655 .25 L
.76655 .25 L
.76656 .25 L
.76657 .25 L
.76657 .25 L
.76658 .25 L
.76659 .25 L
.76659 .25 L
.7666 .25 L
.7666 .25 L
.7666 .25 L
.76661 .25 L
.76662 .25 L
.76662 .25 L
.76663 .25 L
.76664 .25 L
.76664 .25 L
.76665 .25 L
.76666 .25 L
.76666 .25 L
.76667 .25 L
.76667 .25 L
.76668 .25 L
.76669 .25 L
.76669 .25 L
.7667 .25 L
.7667 .25 L
.76671 .25 L
.76672 .25 L
.76672 .25 L
.76673 .25 L
.76673 .25 L
.76674 .25 L
.76675 .25 L
.76675 .25 L
.76676 .25 L
.76676 .25 L
.76677 .25 L
.76678 .25 L
.76678 .25 L
.76679 .25 L
.76679 .25 L
.7668 .25 L
.7668 .25 L
.76681 .25 L
Mistroke
.76681 .25 L
.76682 .25 L
.76683 .25 L
.76683 .25 L
.76683 .25 L
.76684 .25 L
.76685 .25 L
.76685 .25 L
.76686 .25 L
.76686 .25 L
.76687 .25 L
.76688 .25 L
.76688 .25 L
.76688 .25 L
.76689 .25 L
.7669 .25 L
.7669 .25 L
.76691 .25 L
.76691 .25 L
.76692 .25 L
.76692 .25 L
.76693 .25 L
.76694 .25 L
.76694 .25 L
.76695 .25 L
.76695 .25 L
.76696 .25 L
.76697 .25 L
.76697 .25 L
.76698 .25 L
.76699 .25 L
.76699 .25 L
.767 .25 L
.767 .25 L
.76701 .25 L
.76702 .25 L
.76702 .25 L
.76703 .25 L
.76704 .25 L
.76704 .25 L
.76704 .25 L
.76705 .25 L
.76705 .25 L
.76706 .25 L
.76706 .25 L
.76707 .25 L
.76708 .25 L
.76708 .25 L
.76709 .25 L
.7671 .25 L
Mistroke
.7671 .25 L
.76711 .25 L
.76711 .25 L
.76712 .25 L
.76713 .25 L
.76713 .25 L
.76714 .25 L
.76715 .25 L
.76715 .25 L
.76716 .25 L
.76716 .25 L
.76717 .25 L
.76717 .25 L
.76718 .25 L
.76718 .25 L
.76719 .25 L
.76719 .25 L
.7672 .25 L
.7672 .25 L
.7672 .25 L
.76721 .25 L
.76721 .25 L
.76721 .25 L
.76722 .25 L
.76722 .25 L
.76723 .25 L
.76723 .25 L
.76724 .25 L
.76725 .25 L
.76725 .25 L
.76726 .25 L
.76727 .25 L
.76727 .25 L
.76728 .25 L
.76728 .25 L
.76729 .25 L
.7673 .25 L
.7673 .25 L
.76731 .25 L
.76732 .25 L
.76732 .25 L
.76733 .25 L
.76733 .25 L
.76734 .25 L
.76734 .25 L
.76735 .25 L
.76736 .25 L
.76736 .25 L
.76737 .25 L
.76737 .25 L
Mistroke
.76738 .25 L
.76738 .25 L
.76739 .25 L
.7674 .25 L
.7674 .25 L
.76741 .25 L
.76741 .25 L
.76742 .25 L
.76743 .25 L
.76743 .25 L
.76743 .25 L
.76744 .25 L
.76745 .25 L
.76746 .25 L
.76746 .25 L
.76747 .25 L
.76747 .25 L
.76748 .25 L
.76749 .25 L
.76749 .25 L
.7675 .25 L
.76751 .25 L
.76751 .25 L
.76752 .25 L
.76753 .25 L
.76753 .25 L
.76753 .25 L
.76754 .25 L
.76755 .25 L
.76755 .25 L
.76756 .25 L
.76756 .25 L
.76757 .25 L
.76758 .25 L
.76758 .25 L
.76759 .25 L
.76759 .25 L
.7676 .25 L
.76761 .25 L
.76761 .25 L
.76762 .25 L
.76762 .25 L
.76763 .25 L
.76763 .25 L
.76764 .25 L
.76764 .25 L
.76765 .25 L
.76765 .25 L
.76766 .25 L
.76766 .25 L
Mistroke
.76767 .25 L
.76768 .25 L
.76768 .25 L
.76769 .25 L
.76769 .25 L
.7677 .25 L
.7677 .25 L
.76771 .25 L
.76772 .25 L
.76772 .25 L
.76772 .25 L
.76773 .25 L
.76774 .25 L
.76774 .25 L
.76775 .25 L
.76775 .25 L
.76776 .25 L
.76777 .25 L
.76777 .25 L
.76778 .25 L
.76778 .25 L
.76779 .25 L
.7678 .25 L
.7678 .25 L
.76781 .25 L
.76781 .25 L
.76782 .25 L
.76783 .25 L
.76783 .25 L
.76784 .25 L
.76785 .25 L
.76785 .25 L
.76786 .25 L
.76786 .25 L
.76787 .25 L
.76787 .25 L
.76787 .25 L
.76788 .25 L
.76789 .25 L
.76789 .25 L
.7679 .25 L
.76791 .25 L
.76791 .25 L
.76792 .25 L
.76793 .25 L
.76793 .25 L
.76794 .25 L
.76795 .25 L
.76795 .25 L
.76796 .25 L
Mistroke
.76796 .25 L
.76797 .25 L
.76798 .25 L
.76798 .25 L
.76799 .25 L
.76799 .25 L
.768 .25 L
.768 .25 L
.76801 .25 L
.76801 .25 L
.76801 .25 L
.76802 .25 L
.76802 .25 L
.76803 .25 L
.76803 .25 L
.76804 .25 L
.76804 .25 L
.76804 .25 L
.76805 .25 L
.76805 .25 L
.76806 .25 L
.76806 .25 L
.76807 .25 L
.76808 .25 L
.76808 .25 L
.76809 .25 L
.7681 .25 L
.7681 .25 L
.76811 .25 L
.76811 .25 L
.76812 .25 L
.76813 .25 L
.76813 .25 L
.76814 .25 L
.76815 .25 L
.76815 .25 L
.76815 .25 L
.76816 .25 L
.76817 .25 L
.76817 .25 L
.76818 .25 L
.76819 .25 L
.76819 .25 L
.7682 .25 L
.7682 .25 L
.76821 .25 L
.76821 .25 L
.76822 .25 L
.76823 .25 L
.76823 .25 L
Mistroke
.76824 .25 L
.76825 .25 L
.76825 .25 L
.76825 .25 L
.76826 .25 L
.76827 .25 L
.76827 .25 L
.76828 .25 L
.76829 .25 L
.76829 .25 L
.7683 .25 L
.7683 .25 L
.76831 .25 L
.76832 .25 L
.76832 .25 L
.76833 .25 L
.76834 .25 L
.76834 .25 L
.76835 .25 L
.76835 .25 L
.76836 .25 L
.76836 .25 L
.76837 .25 L
.76838 .25 L
.76838 .25 L
.76839 .25 L
.76839 .25 L
.7684 .25 L
.76841 .25 L
.76841 .25 L
.76842 .25 L
.76842 .25 L
.76843 .25 L
.76844 .25 L
.76844 .25 L
.76845 .25 L
.76845 .25 L
.76845 .25 L
.76846 .25 L
.76847 .25 L
.76847 .25 L
.76848 .25 L
.76848 .25 L
.76849 .25 L
.76849 .25 L
.7685 .25 L
.76851 .25 L
.76851 .25 L
.76852 .25 L
.76852 .25 L
Mistroke
.76853 .25 L
.76853 .25 L
.76854 .25 L
.76854 .25 L
.76855 .25 L
.76855 .25 L
.76856 .25 L
.76857 .25 L
.76857 .25 L
.76858 .25 L
.76858 .25 L
.76859 .25 L
.7686 .25 L
.7686 .25 L
.76861 .25 L
.76861 .25 L
.76862 .25 L
.76863 .25 L
.76863 .25 L
.76864 .25 L
.76864 .25 L
.76865 .25 L
.76866 .25 L
.76866 .25 L
.76867 .25 L
.76868 .25 L
.76868 .25 L
.76869 .25 L
.76869 .25 L
.76869 .25 L
.7687 .25 L
.76871 .25 L
.76871 .25 L
.76872 .25 L
.76873 .25 L
.76873 .25 L
.76874 .25 L
.76874 .25 L
.76875 .25 L
.76876 .25 L
.76876 .25 L
.76877 .25 L
.76877 .25 L
.76878 .25 L
.76879 .25 L
.76879 .25 L
.7688 .25 L
.76881 .25 L
.76881 .25 L
.76882 .25 L
Mistroke
.76882 .25 L
.76883 .25 L
.76883 .25 L
.76883 .25 L
.76884 .25 L
.76884 .25 L
.76885 .25 L
.76885 .25 L
.76885 .25 L
.76886 .25 L
.76886 .25 L
.76887 .25 L
.76887 .25 L
.76887 .25 L
.76888 .25 L
.76889 .25 L
.76889 .25 L
.7689 .25 L
.76891 .25 L
.76891 .25 L
.76892 .25 L
.76892 .25 L
.76893 .25 L
.76894 .25 L
.76894 .25 L
.76895 .25 L
.76896 .25 L
.76896 .25 L
.76897 .25 L
.76897 .25 L
.76898 .25 L
.76898 .25 L
.76899 .25 L
.769 .25 L
.769 .25 L
.76901 .25 L
.76902 .25 L
.76902 .25 L
.76903 .25 L
.76903 .25 L
.76904 .25 L
.76904 .25 L
.76905 .25 L
.76906 .25 L
.76906 .25 L
.76907 .25 L
.76907 .25 L
.76908 .25 L
.76908 .25 L
.76909 .25 L
Mistroke
.7691 .25 L
.7691 .25 L
.76911 .25 L
.76912 .25 L
.76912 .25 L
.76913 .25 L
.76913 .25 L
.76914 .25 L
.76915 .25 L
.76915 .25 L
.76916 .25 L
.76917 .25 L
.76917 .25 L
.76918 .25 L
.76918 .25 L
.76919 .25 L
.76919 .25 L
.7692 .25 L
.76921 .25 L
.76921 .25 L
.76922 .25 L
.76922 .25 L
.76923 .25 L
.76923 .25 L
.76924 .25 L
.76925 .25 L
.76925 .25 L
.76926 .25 L
.76926 .25 L
.76927 .25 L
.76927 .25 L
.76928 .25 L
.76928 .25 L
.76929 .25 L
.7693 .25 L
.7693 .25 L
.7693 .25 L
.76931 .25 L
.76932 .25 L
.76932 .25 L
.76933 .25 L
.76934 .25 L
.76934 .25 L
.76935 .25 L
.76935 .25 L
.76936 .25 L
.76936 .25 L
.76937 .25 L
.76937 .25 L
.76938 .25 L
Mistroke
.76938 .25 L
.76939 .25 L
.7694 .25 L
.7694 .25 L
.76941 .25 L
.76941 .25 L
.76942 .25 L
.76942 .25 L
.76943 .25 L
.76944 .25 L
.76944 .25 L
.76945 .25 L
.76946 .25 L
.76946 .25 L
.76947 .25 L
.76947 .25 L
.76948 .25 L
.76949 .25 L
.76949 .25 L
.7695 .25 L
.76951 .25 L
.76951 .25 L
.76951 .25 L
.76952 .25 L
.76952 .25 L
.76953 .25 L
.76953 .25 L
.76954 .25 L
.76955 .25 L
.76955 .25 L
.76956 .25 L
.76957 .25 L
.76957 .25 L
.76958 .25 L
.76959 .25 L
.76959 .25 L
.7696 .25 L
.7696 .25 L
.76961 .25 L
.76962 .25 L
.76962 .25 L
.76963 .25 L
.76964 .25 L
.76964 .25 L
.76965 .25 L
.76965 .25 L
.76965 .25 L
.76966 .25 L
.76966 .25 L
.76967 .25 L
Mistroke
.76967 .25 L
.76967 .25 L
.76968 .25 L
.76968 .25 L
.76969 .25 L
.76969 .25 L
.76969 .25 L
.7697 .25 L
.7697 .25 L
.76971 .25 L
.76972 .25 L
.76972 .25 L
.76973 .25 L
.76974 .25 L
.76974 .25 L
.76975 .25 L
.76975 .25 L
.76976 .25 L
.76977 .25 L
.76977 .25 L
.76978 .25 L
.76979 .25 L
.76979 .25 L
.7698 .25 L
.7698 .25 L
.76981 .25 L
.76981 .25 L
.76982 .25 L
.76983 .25 L
.76983 .25 L
.76984 .25 L
.76984 .25 L
.76985 .25 L
.76986 .25 L
.76986 .25 L
.76987 .25 L
.76987 .25 L
.76988 .25 L
.76989 .25 L
.76989 .25 L
.7699 .25 L
.7699 .25 L
.76991 .25 L
.76991 .25 L
.76992 .25 L
.76993 .25 L
.76993 .25 L
.76994 .25 L
.76994 .25 L
.76995 .25 L
Mistroke
.76996 .25 L
.76996 .25 L
.76997 .25 L
.76998 .25 L
.76998 .25 L
.76999 .25 L
.77 .25 L
.77 .25 L
.77 .25 L
.77001 .25 L
.77002 .25 L
.77002 .25 L
.77003 .25 L
.77003 .25 L
.77004 .25 L
.77005 .25 L
.77005 .25 L
.77006 .25 L
.77006 .25 L
.77007 .25 L
.77008 .25 L
.77008 .25 L
.77009 .25 L
.77009 .25 L
.7701 .25 L
.7701 .25 L
.77011 .25 L
.77011 .25 L
.77012 .25 L
.77013 .25 L
.77013 .25 L
.77014 .25 L
.77015 .25 L
.77015 .25 L
.77016 .25 L
.77016 .25 L
.77017 .25 L
.77018 .25 L
.77018 .25 L
.77019 .25 L
.7702 .25 L
.7702 .25 L
.77021 .25 L
.77021 .25 L
.77022 .25 L
.77022 .25 L
.77023 .25 L
.77024 .25 L
.77024 .25 L
.77025 .25 L
Mistroke
.77025 .25 L
.77026 .25 L
.77027 .25 L
.77027 .25 L
.77028 .25 L
.77028 .25 L
.77029 .25 L
.7703 .25 L
.7703 .25 L
.7703 .25 L
.77031 .25 L
.77032 .25 L
.77032 .25 L
.77033 .25 L
.77033 .25 L
.77034 .25 L
.77034 .25 L
.77035 .25 L
.77036 .25 L
.77036 .25 L
.77037 .25 L
.77037 .25 L
.77038 .25 L
.77038 .25 L
.77039 .25 L
.77039 .25 L
.7704 .25 L
.7704 .25 L
.77041 .25 L
.77042 .25 L
.77042 .25 L
.77043 .25 L
.77043 .25 L
.77044 .25 L
.77044 .25 L
.77045 .25 L
.77046 .25 L
.77046 .25 L
.77047 .25 L
.77048 .25 L
.77048 .25 L
.77049 .25 L
.77049 .25 L
.7705 .25 L
.77051 .25 L
.77051 .25 L
.77052 .25 L
.77053 .25 L
.77053 .25 L
.77054 .25 L
Mistroke
.77054 .25 L
.77054 .25 L
.77055 .25 L
.77055 .25 L
.77056 .25 L
.77057 .25 L
.77057 .25 L
.77058 .25 L
.77059 .25 L
.77059 .25 L
.7706 .25 L
.7706 .25 L
.77061 .25 L
.77062 .25 L
.77062 .25 L
.77063 .25 L
.77064 .25 L
.77064 .25 L
.77065 .25 L
.77066 .25 L
.77066 .25 L
.77066 .25 L
.77067 .25 L
.77068 .25 L
.77068 .25 L
.77068 .25 L
.77069 .25 L
.77069 .25 L
.7707 .25 L
.7707 .25 L
.7707 .25 L
.77071 .25 L
.77071 .25 L
.77072 .25 L
.77072 .25 L
.77072 .25 L
.77073 .25 L
.77074 .25 L
.77074 .25 L
.77075 .25 L
.77076 .25 L
.77076 .25 L
.77077 .25 L
.77077 .25 L
.77078 .25 L
.77079 .25 L
.77079 .25 L
.7708 .25 L
.77081 .25 L
.77081 .25 L
Mistroke
.77082 .25 L
.77082 .25 L
.77083 .25 L
.77083 .25 L
.77084 .25 L
.77085 .25 L
.77085 .25 L
.77086 .25 L
.77087 .25 L
.77087 .25 L
.77088 .25 L
.77088 .25 L
.77089 .25 L
.77089 .25 L
.7709 .25 L
.77091 .25 L
.77091 .25 L
.77092 .25 L
.77092 .25 L
.77093 .25 L
.77093 .25 L
.77094 .25 L
.77095 .25 L
.77095 .25 L
.77096 .25 L
.77096 .25 L
.77097 .25 L
.77098 .25 L
.77098 .25 L
.77099 .25 L
.771 .25 L
.771 .25 L
.77101 .25 L
.77102 .25 L
.77102 .25 L
.77103 .25 L
.77103 .25 L
.77104 .25 L
.77104 .25 L
.77105 .25 L
.77106 .25 L
.77106 .25 L
.77107 .25 L
.77107 .25 L
.77108 .25 L
.77108 .25 L
.77109 .25 L
.7711 .25 L
.7711 .25 L
.77111 .25 L
Mistroke
.77111 .25 L
.77112 .25 L
.77112 .25 L
.77113 .25 L
.77113 .25 L
.77114 .25 L
.77115 .25 L
.77115 .25 L
.77115 .25 L
.77116 .25 L
.77117 .25 L
.77117 .25 L
.77118 .25 L
.77119 .25 L
.77119 .25 L
.7712 .25 L
.7712 .25 L
.77121 .25 L
.77121 .25 L
.77122 .25 L
.77122 .25 L
.77123 .25 L
.77123 .25 L
.77124 .25 L
.77125 .25 L
.77125 .25 L
.77126 .25 L
.77126 .25 L
.77127 .25 L
.77127 .25 L
.77128 .25 L
.77129 .25 L
.77129 .25 L
.7713 .25 L
.77131 .25 L
.77131 .25 L
.77132 .25 L
.77132 .25 L
.77133 .25 L
.77134 .25 L
.77134 .25 L
.77135 .25 L
.77136 .25 L
.77136 .25 L
.77136 .25 L
.77137 .25 L
.77137 .25 L
.77138 .25 L
.77138 .25 L
.77139 .25 L
Mistroke
.7714 .25 L
.7714 .25 L
.77141 .25 L
.77142 .25 L
.77142 .25 L
.77143 .25 L
.77144 .25 L
.77144 .25 L
.77145 .25 L
.77145 .25 L
.77146 .25 L
.77147 .25 L
.77147 .25 L
.77148 .25 L
.77149 .25 L
.77149 .25 L
.7715 .25 L
.7715 .25 L
.7715 .25 L
.77151 .25 L
.77151 .25 L
.77152 .25 L
.77152 .25 L
.77152 .25 L
.77153 .25 L
.77153 .25 L
.77154 .25 L
.77154 .25 L
.77154 .25 L
.77155 .25 L
.77155 .25 L
.77156 .25 L
.77157 .25 L
.77157 .25 L
.77158 .25 L
.77159 .25 L
.77159 .25 L
.7716 .25 L
.7716 .25 L
.77161 .25 L
.77162 .25 L
.77162 .25 L
.77163 .25 L
.77164 .25 L
.77164 .25 L
.77165 .25 L
.77165 .25 L
.77166 .25 L
.77166 .25 L
.77167 .25 L
Mistroke
.77168 .25 L
.77168 .25 L
.77169 .25 L
.77169 .25 L
.7717 .25 L
.77171 .25 L
.77171 .25 L
.77172 .25 L
.77172 .25 L
.77173 .25 L
.77174 .25 L
.77174 .25 L
.77175 .25 L
.77175 .25 L
.77176 .25 L
.77176 .25 L
.77177 .25 L
.77178 .25 L
.77178 .25 L
.77179 .25 L
.77179 .25 L
.7718 .25 L
.77181 .25 L
.77181 .25 L
.77182 .25 L
.77183 .25 L
.77183 .25 L
.77184 .25 L
.77185 .25 L
.77185 .25 L
.77185 .25 L
.77186 .25 L
.77187 .25 L
.77187 .25 L
.77188 .25 L
.77189 .25 L
.77189 .25 L
.7719 .25 L
.7719 .25 L
.77191 .25 L
.77191 .25 L
.77192 .25 L
.77193 .25 L
.77193 .25 L
.77194 .25 L
.77194 .25 L
.77195 .25 L
.77195 .25 L
.77196 .25 L
.77196 .25 L
Mistroke
.77197 .25 L
.77198 .25 L
.77198 .25 L
.77198 .25 L
.77199 .25 L
.772 .25 L
.772 .25 L
.77201 .25 L
.77202 .25 L
.77202 .25 L
.77203 .25 L
.77203 .25 L
.77204 .25 L
.77204 .25 L
.77204 .25 L
.77205 .25 L
.77206 .25 L
.77206 .25 L
.77207 .25 L
.77208 .25 L
.77208 .25 L
.77209 .25 L
.77209 .25 L
.7721 .25 L
.77211 .25 L
.77211 .25 L
.77212 .25 L
.77212 .25 L
.77213 .25 L
.77214 .25 L
.77214 .25 L
.77215 .25 L
.77216 .25 L
.77216 .25 L
.77217 .25 L
.77217 .25 L
.77218 .25 L
.77218 .25 L
.77219 .25 L
.77219 .25 L
.7722 .25 L
.7722 .25 L
.77221 .25 L
.77222 .25 L
.77222 .25 L
.77223 .25 L
.77223 .25 L
.77224 .25 L
.77225 .25 L
.77225 .25 L
Mistroke
.77226 .25 L
.77227 .25 L
.77227 .25 L
.77228 .25 L
.77229 .25 L
.77229 .25 L
.7723 .25 L
.7723 .25 L
.77231 .25 L
.77231 .25 L
.77232 .25 L
.77232 .25 L
.77233 .25 L
.77233 .25 L
.77233 .25 L
.77234 .25 L
.77234 .25 L
.77235 .25 L
.77235 .25 L
.77236 .25 L
.77236 .25 L
.77236 .25 L
.77237 .25 L
.77237 .25 L
.77238 .25 L
.77238 .25 L
.77239 .25 L
.7724 .25 L
.7724 .25 L
.77241 .25 L
.77242 .25 L
.77242 .25 L
.77243 .25 L
.77243 .25 L
.77244 .25 L
.77245 .25 L
.77245 .25 L
.77246 .25 L
.77247 .25 L
.77247 .25 L
.77247 .25 L
.77248 .25 L
.77249 .25 L
.77249 .25 L
.7725 .25 L
.77251 .25 L
.77251 .25 L
.77252 .25 L
.77252 .25 L
.77253 .25 L
Mistroke
.77254 .25 L
.77254 .25 L
.77255 .25 L
.77255 .25 L
.77256 .25 L
.77257 .25 L
.77257 .25 L
.77257 .25 L
.77258 .25 L
.77259 .25 L
.77259 .25 L
.7726 .25 L
.77261 .25 L
.77261 .25 L
.77262 .25 L
.77262 .25 L
.77263 .25 L
.77264 .25 L
.77264 .25 L
.77265 .25 L
.77266 .25 L
.77266 .25 L
.77267 .25 L
.77267 .25 L
.77268 .25 L
.77268 .25 L
.77269 .25 L
.7727 .25 L
.7727 .25 L
.77271 .25 L
.77272 .25 L
.77272 .25 L
.77273 .25 L
.77273 .25 L
.77274 .25 L
.77274 .25 L
.77275 .25 L
.77276 .25 L
.77276 .25 L
.77277 .25 L
.77277 .25 L
.77278 .25 L
.77278 .25 L
.77279 .25 L
.7728 .25 L
.7728 .25 L
.7728 .25 L
.77281 .25 L
.77281 .25 L
.77282 .25 L
Mistroke
.77283 .25 L
.77283 .25 L
.77284 .25 L
.77285 .25 L
.77285 .25 L
.77285 .25 L
.77286 .25 L
.77286 .25 L
.77287 .25 L
.77287 .25 L
.77288 .25 L
.77289 .25 L
.77289 .25 L
.7729 .25 L
.7729 .25 L
.77291 .25 L
.77292 .25 L
.77292 .25 L
.77293 .25 L
.77294 .25 L
.77294 .25 L
.77295 .25 L
.77295 .25 L
.77296 .25 L
.77297 .25 L
.77297 .25 L
.77298 .25 L
.77298 .25 L
.77299 .25 L
.773 .25 L
.773 .25 L
.77301 .25 L
.77301 .25 L
.77302 .25 L
.77302 .25 L
.77303 .25 L
.77303 .25 L
.77304 .25 L
.77305 .25 L
.77305 .25 L
.77306 .25 L
.77306 .25 L
.77307 .25 L
.77308 .25 L
.77308 .25 L
.77309 .25 L
.7731 .25 L
.7731 .25 L
.77311 .25 L
.77312 .25 L
Mistroke
.77312 .25 L
.77313 .25 L
.77313 .25 L
.77314 .25 L
.77314 .25 L
.77315 .25 L
.77315 .25 L
.77315 .25 L
.77316 .25 L
.77316 .25 L
.77317 .25 L
.77317 .25 L
.77318 .25 L
.77318 .25 L
.77318 .25 L
.77319 .25 L
.77319 .25 L
.77319 .25 L
.7732 .25 L
.77321 .25 L
.77321 .25 L
.77322 .25 L
.77323 .25 L
.77323 .25 L
.77324 .25 L
.77325 .25 L
.77325 .25 L
.77326 .25 L
.77326 .25 L
.77327 .25 L
.77328 .25 L
.77328 .25 L
.77329 .25 L
.77329 .25 L
.7733 .25 L
.77331 .25 L
.77331 .25 L
.77332 .25 L
.77332 .25 L
.77333 .25 L
.77334 .25 L
.77334 .25 L
.77335 .25 L
.77335 .25 L
.77336 .25 L
.77336 .25 L
.77337 .25 L
.77338 .25 L
.77338 .25 L
.77339 .25 L
Mistroke
.77339 .25 L
.7734 .25 L
.7734 .25 L
.77341 .25 L
.77342 .25 L
.77342 .25 L
.77343 .25 L
.77344 .25 L
.77344 .25 L
.77345 .25 L
.77345 .25 L
.77346 .25 L
.77347 .25 L
.77347 .25 L
.77348 .25 L
.77349 .25 L
.77349 .25 L
.7735 .25 L
.7735 .25 L
.77351 .25 L
.77351 .25 L
.77352 .25 L
.77353 .25 L
.77353 .25 L
.77354 .25 L
.77354 .25 L
.77355 .25 L
.77355 .25 L
.77356 .25 L
.77357 .25 L
.77357 .25 L
.77358 .25 L
.77359 .25 L
.77359 .25 L
.7736 .25 L
.7736 .25 L
.77361 .25 L
.77361 .25 L
.77362 .25 L
.77363 .25 L
.77363 .25 L
.77364 .25 L
.77364 .25 L
.77365 .25 L
.77366 .25 L
.77366 .25 L
.77367 .25 L
.77368 .25 L
.77368 .25 L
.77369 .25 L
Mistroke
.7737 .25 L
.7737 .25 L
.7737 .25 L
.77371 .25 L
.77372 .25 L
.77372 .25 L
.77373 .25 L
.77373 .25 L
.77374 .25 L
.77375 .25 L
.77375 .25 L
.77376 .25 L
.77376 .25 L
.77377 .25 L
.77378 .25 L
.77378 .25 L
.77379 .25 L
.77379 .25 L
.7738 .25 L
.7738 .25 L
.77381 .25 L
.77381 .25 L
.77382 .25 L
.77382 .25 L
.77383 .25 L
.77383 .25 L
.77384 .25 L
.77385 .25 L
.77385 .25 L
.77386 .25 L
.77387 .25 L
.77387 .25 L
.77388 .25 L
.77388 .25 L
.77389 .25 L
.77389 .25 L
.77389 .25 L
.7739 .25 L
.77391 .25 L
.77391 .25 L
.77392 .25 L
.77393 .25 L
.77393 .25 L
.77394 .25 L
.77394 .25 L
.77395 .25 L
.77395 .25 L
.77396 .25 L
.77397 .25 L
.77397 .25 L
Mistroke
.77398 .25 L
.77399 .25 L
.77399 .25 L
.774 .25 L
.774 .25 L
.77401 .25 L
.77402 .25 L
.77402 .25 L
.77403 .25 L
.77403 .25 L
.77404 .25 L
.77404 .25 L
.77405 .25 L
.77405 .25 L
.77406 .25 L
.77406 .25 L
.77407 .25 L
.77408 .25 L
.77408 .25 L
.77409 .25 L
.7741 .25 L
.7741 .25 L
.77411 .25 L
.77412 .25 L
.77412 .25 L
.77413 .25 L
.77414 .25 L
.77414 .25 L
.77415 .25 L
.77415 .25 L
.77416 .25 L
.77416 .25 L
.77417 .25 L
.77417 .25 L
.77418 .25 L
.77418 .25 L
.77418 .25 L
.77419 .25 L
.77419 .25 L
.7742 .25 L
.7742 .25 L
.77421 .25 L
.77421 .25 L
.77421 .25 L
.77422 .25 L
.77422 .25 L
.77423 .25 L
.77423 .25 L
.77424 .25 L
.77425 .25 L
Mistroke
.77425 .25 L
.77426 .25 L
.77427 .25 L
.77427 .25 L
.77428 .25 L
.77428 .25 L
.77429 .25 L
.7743 .25 L
.7743 .25 L
.77431 .25 L
.77432 .25 L
.77432 .25 L
.77432 .25 L
.77433 .25 L
.77434 .25 L
.77434 .25 L
.77435 .25 L
.77436 .25 L
.77436 .25 L
.77437 .25 L
.77437 .25 L
.77438 .25 L
.77439 .25 L
.77439 .25 L
.7744 .25 L
.7744 .25 L
.77441 .25 L
.77442 .25 L
.77442 .25 L
.77442 .25 L
.77443 .25 L
.77444 .25 L
.77444 .25 L
.77445 .25 L
.77446 .25 L
.77446 .25 L
.77447 .25 L
.77447 .25 L
.77448 .25 L
.77449 .25 L
.77449 .25 L
.7745 .25 L
.77451 .25 L
.77451 .25 L
.77452 .25 L
.77452 .25 L
.77453 .25 L
.77453 .25 L
.77454 .25 L
.77455 .25 L
Mistroke
.77455 .25 L
.77456 .25 L
.77457 .25 L
.77457 .25 L
.77458 .25 L
.77458 .25 L
.77459 .25 L
.77459 .25 L
.7746 .25 L
.77461 .25 L
.77461 .25 L
.77462 .25 L
.77462 .25 L
.77463 .25 L
.77463 .25 L
.77464 .25 L
.77465 .25 L
.77465 .25 L
.77465 .25 L
.77466 .25 L
.77467 .25 L
.77467 .25 L
.77468 .25 L
.77468 .25 L
.77469 .25 L
.7747 .25 L
.7747 .25 L
.7747 .25 L
.77471 .25 L
.77471 .25 L
.77472 .25 L
.77472 .25 L
.77473 .25 L
.77474 .25 L
.77474 .25 L
.77475 .25 L
.77476 .25 L
.77476 .25 L
.77477 .25 L
.77477 .25 L
.77478 .25 L
.77479 .25 L
.77479 .25 L
.7748 .25 L
.7748 .25 L
.77481 .25 L
.77482 .25 L
.77482 .25 L
.77483 .25 L
.77483 .25 L
Mistroke
.77484 .25 L
.77485 .25 L
.77485 .25 L
.77486 .25 L
.77486 .25 L
.77487 .25 L
.77487 .25 L
.77488 .25 L
.77488 .25 L
.77489 .25 L
.7749 .25 L
.7749 .25 L
.77491 .25 L
.77491 .25 L
.77492 .25 L
.77493 .25 L
.77493 .25 L
.77494 .25 L
.77495 .25 L
.77495 .25 L
.77496 .25 L
.77497 .25 L
.77497 .25 L
.77498 .25 L
.77498 .25 L
.77499 .25 L
.77499 .25 L
.775 .25 L
.775 .25 L
.775 .25 L
.77501 .25 L
.77501 .25 L
.77502 .25 L
.77502 .25 L
.77503 .25 L
.77503 .25 L
.77503 .25 L
.77504 .25 L
.77504 .25 L
.77504 .25 L
.77505 .25 L
.77506 .25 L
.77506 .25 L
.77507 .25 L
.77508 .25 L
.77508 .25 L
.77509 .25 L
.7751 .25 L
.7751 .25 L
.77511 .25 L
Mistroke
.77511 .25 L
.77512 .25 L
.77513 .25 L
.77513 .25 L
.77514 .25 L
.77514 .25 L
.77515 .25 L
.77516 .25 L
.77516 .25 L
.77517 .25 L
.77517 .25 L
.77518 .25 L
.77519 .25 L
.77519 .25 L
.7752 .25 L
.7752 .25 L
.77521 .25 L
.77522 .25 L
.77522 .25 L
.77523 .25 L
.77523 .25 L
.77524 .25 L
.77524 .25 L
.77525 .25 L
.77525 .25 L
.77526 .25 L
.77527 .25 L
.77527 .25 L
.77528 .25 L
.77529 .25 L
.77529 .25 L
.7753 .25 L
.7753 .25 L
.77531 .25 L
.77532 .25 L
.77532 .25 L
.77533 .25 L
.77534 .25 L
.77534 .25 L
.77535 .25 L
.77535 .25 L
.77536 .25 L
.77536 .25 L
.77537 .25 L
.77538 .25 L
.77538 .25 L
.77539 .25 L
.77539 .25 L
.7754 .25 L
.77541 .25 L
Mistroke
.77541 .25 L
.77542 .25 L
.77542 .25 L
.77543 .25 L
.77544 .25 L
.77544 .25 L
.77545 .25 L
.77545 .25 L
.77546 .25 L
.77546 .25 L
.77547 .25 L
.77547 .25 L
.77548 .25 L
.77548 .25 L
.77549 .25 L
.77549 .25 L
.7755 .25 L
.77551 .25 L
.77551 .25 L
.77552 .25 L
.77552 .25 L
.77553 .25 L
.77553 .25 L
.77554 .25 L
.77554 .25 L
.77555 .25 L
.77555 .25 L
.77556 .25 L
.77557 .25 L
.77557 .25 L
.77558 .25 L
.77558 .25 L
.77559 .25 L
.7756 .25 L
.7756 .25 L
.77561 .25 L
.77561 .25 L
.77562 .25 L
.77563 .25 L
.77563 .25 L
.77564 .25 L
.77565 .25 L
.77565 .25 L
.77566 .25 L
.77567 .25 L
.77567 .25 L
.77568 .25 L
.77568 .25 L
.77569 .25 L
.77569 .25 L
Mistroke
.77569 .25 L
.7757 .25 L
.77571 .25 L
.77571 .25 L
.77572 .25 L
.77573 .25 L
.77573 .25 L
.77574 .25 L
.77574 .25 L
.77575 .25 L
.77576 .25 L
.77576 .25 L
.77577 .25 L
.77578 .25 L
.77578 .25 L
.77579 .25 L
.7758 .25 L
.7758 .25 L
.77581 .25 L
.77581 .25 L
.77582 .25 L
.77582 .25 L
.77582 .25 L
.77583 .25 L
.77583 .25 L
.77584 .25 L
.77584 .25 L
.77585 .25 L
.77585 .25 L
.77585 .25 L
.77586 .25 L
.77586 .25 L
.77586 .25 L
.77587 .25 L
.77587 .25 L
.77588 .25 L
.77589 .25 L
.77589 .25 L
.7759 .25 L
.77591 .25 L
.77591 .25 L
.77592 .25 L
.77593 .25 L
.77593 .25 L
.77594 .25 L
.77595 .25 L
.77595 .25 L
.77596 .25 L
.77596 .25 L
.77597 .25 L
Mistroke
.77597 .25 L
.77598 .25 L
.77599 .25 L
.77599 .25 L
.776 .25 L
.776 .25 L
.77601 .25 L
.77602 .25 L
.77602 .25 L
.77603 .25 L
.77603 .25 L
.77604 .25 L
.77605 .25 L
.77605 .25 L
.77606 .25 L
.77606 .25 L
.77607 .25 L
.77607 .25 L
.77608 .25 L
.77608 .25 L
.77609 .25 L
.7761 .25 L
.7761 .25 L
.77611 .25 L
.77612 .25 L
.77612 .25 L
.77613 .25 L
.77613 .25 L
.77614 .25 L
.77615 .25 L
.77615 .25 L
.77616 .25 L
.77617 .25 L
.77617 .25 L
.77617 .25 L
.77618 .25 L
.77619 .25 L
.77619 .25 L
.7762 .25 L
.77621 .25 L
.77621 .25 L
.77622 .25 L
.77622 .25 L
.77623 .25 L
.77624 .25 L
.77624 .25 L
.77625 .25 L
.77625 .25 L
.77626 .25 L
.77627 .25 L
Mistroke
.77627 .25 L
.77627 .25 L
.77628 .25 L
.77629 .25 L
.77629 .25 L
.7763 .25 L
.7763 .25 L
.77631 .25 L
.77631 .25 L
.77632 .25 L
.77632 .25 L
.77633 .25 L
.77634 .25 L
.77634 .25 L
.77635 .25 L
.77635 .25 L
.77636 .25 L
.77636 .25 L
.77636 .25 L
.77637 .25 L
.77638 .25 L
.77638 .25 L
.77639 .25 L
.7764 .25 L
.7764 .25 L
.77641 .25 L
.77641 .25 L
.77642 .25 L
.77643 .25 L
.77643 .25 L
.77644 .25 L
.77644 .25 L
.77645 .25 L
.77646 .25 L
.77646 .25 L
.77647 .25 L
.77648 .25 L
.77648 .25 L
.77649 .25 L
.7765 .25 L
.7765 .25 L
.77651 .25 L
.77651 .25 L
.77651 .25 L
.77652 .25 L
.77652 .25 L
.77653 .25 L
.77654 .25 L
.77654 .25 L
.77655 .25 L
Mistroke
.77656 .25 L
.77656 .25 L
.77657 .25 L
.77657 .25 L
.77658 .25 L
.77659 .25 L
.77659 .25 L
.7766 .25 L
.77661 .25 L
.77661 .25 L
.77662 .25 L
.77663 .25 L
.77663 .25 L
.77663 .25 L
.77664 .25 L
.77664 .25 L
.77665 .25 L
.77665 .25 L
.77665 .25 L
.77666 .25 L
.77667 .25 L
.77667 .25 L
.77667 .25 L
.77668 .25 L
.77668 .25 L
.77668 .25 L
.77669 .25 L
.77669 .25 L
.7767 .25 L
.7767 .25 L
.77671 .25 L
.77672 .25 L
.77672 .25 L
.77673 .25 L
.77674 .25 L
.77674 .25 L
.77675 .25 L
.77676 .25 L
.77676 .25 L
.77677 .25 L
.77677 .25 L
.77678 .25 L
.77679 .25 L
.77679 .25 L
.7768 .25 L
.7768 .25 L
.77681 .25 L
.77681 .25 L
.77682 .25 L
.77683 .25 L
Mistroke
.77683 .25 L
.77684 .25 L
.77684 .25 L
.77685 .25 L
.77686 .25 L
.77686 .25 L
.77687 .25 L
.77687 .25 L
.77688 .25 L
.77689 .25 L
.77689 .25 L
.77689 .25 L
.7769 .25 L
.77691 .25 L
.77691 .25 L
.77692 .25 L
.77693 .25 L
.77693 .25 L
.77694 .25 L
.77694 .25 L
.77695 .25 L
.77696 .25 L
.77696 .25 L
.77697 .25 L
.77698 .25 L
.77698 .25 L
.77699 .25 L
.77699 .25 L
.777 .25 L
.777 .25 L
.77701 .25 L
.77702 .25 L
.77702 .25 L
.77703 .25 L
.77704 .25 L
.77704 .25 L
.77705 .25 L
.77705 .25 L
.77706 .25 L
.77706 .25 L
.77707 .25 L
.77708 .25 L
.77708 .25 L
.77709 .25 L
.77709 .25 L
.7771 .25 L
.7771 .25 L
.77711 .25 L
.77712 .25 L
.77712 .25 L
Mistroke
.77713 .25 L
.77714 .25 L
.77714 .25 L
.77715 .25 L
.77715 .25 L
.77716 .25 L
.77717 .25 L
.77717 .25 L
.77718 .25 L
.77719 .25 L
.77719 .25 L
.7772 .25 L
.7772 .25 L
.77721 .25 L
.77721 .25 L
.77722 .25 L
.77723 .25 L
.77723 .25 L
.77724 .25 L
.77724 .25 L
.77725 .25 L
.77726 .25 L
.77726 .25 L
.77727 .25 L
.77727 .25 L
.77728 .25 L
.77729 .25 L
.77729 .25 L
.7773 .25 L
.7773 .25 L
.77731 .25 L
.77731 .25 L
.77732 .25 L
.77732 .25 L
.77733 .25 L
.77733 .25 L
.77734 .25 L
.77734 .25 L
.77735 .25 L
.77736 .25 L
.77736 .25 L
.77737 .25 L
.77737 .25 L
.77738 .25 L
.77738 .25 L
.77739 .25 L
.77739 .25 L
.7774 .25 L
.7774 .25 L
.77741 .25 L
Mistroke
.77742 .25 L
.77742 .25 L
.77743 .25 L
.77743 .25 L
.77744 .25 L
.77745 .25 L
.77745 .25 L
.77746 .25 L
.77746 .25 L
.77747 .25 L
.77748 .25 L
.77748 .25 L
.77749 .25 L
.7775 .25 L
.7775 .25 L
.77751 .25 L
.77751 .25 L
.77752 .25 L
.77753 .25 L
.77753 .25 L
.77754 .25 L
.77754 .25 L
.77754 .25 L
.77755 .25 L
.77756 .25 L
.77756 .25 L
.77757 .25 L
.77758 .25 L
.77758 .25 L
.77759 .25 L
.77759 .25 L
.7776 .25 L
.77761 .25 L
.77761 .25 L
.77762 .25 L
.77763 .25 L
.77763 .25 L
.77764 .25 L
.77765 .25 L
.77765 .25 L
.77766 .25 L
.77766 .25 L
.77767 .25 L
.77767 .25 L
.77767 .25 L
.77768 .25 L
.77768 .25 L
.77769 .25 L
.77769 .25 L
.7777 .25 L
Mistroke
.7777 .25 L
.7777 .25 L
.77771 .25 L
.77771 .25 L
.77771 .25 L
.77772 .25 L
.77772 .25 L
.77773 .25 L
.77774 .25 L
.77774 .25 L
.77775 .25 L
.77776 .25 L
.77776 .25 L
.77777 .25 L
.77778 .25 L
.77778 .25 L
.77779 .25 L
.7778 .25 L
.7778 .25 L
.77781 .25 L
.77781 .25 L
.77782 .25 L
.77782 .25 L
.77783 .25 L
.77784 .25 L
.77784 .25 L
.77785 .25 L
.77785 .25 L
.77786 .25 L
.77787 .25 L
.77787 .25 L
.77788 .25 L
.77788 .25 L
.77789 .25 L
.7779 .25 L
.7779 .25 L
.77791 .25 L
.77791 .25 L
.77792 .25 L
.77792 .25 L
.77793 .25 L
.77793 .25 L
.77794 .25 L
.77795 .25 L
.77795 .25 L
.77796 .25 L
.77797 .25 L
.77797 .25 L
.77798 .25 L
.77798 .25 L
Mistroke
.77799 .25 L
.778 .25 L
.778 .25 L
.77801 .25 L
.77802 .25 L
.77802 .25 L
.77802 .25 L
.77803 .25 L
.77804 .25 L
.77804 .25 L
.77805 .25 L
.77806 .25 L
.77806 .25 L
.77807 .25 L
.77807 .25 L
.77808 .25 L
.77809 .25 L
.77809 .25 L
.7781 .25 L
.7781 .25 L
.77811 .25 L
.77812 .25 L
.77812 .25 L
.77812 .25 L
.77813 .25 L
.77814 .25 L
.77814 .25 L
.77815 .25 L
.77815 .25 L
.77816 .25 L
.77816 .25 L
.77817 .25 L
.77817 .25 L
.77818 .25 L
.77819 .25 L
.77819 .25 L
.7782 .25 L
.7782 .25 L
.77821 .25 L
.77821 .25 L
.77822 .25 L
.77822 .25 L
.77823 .25 L
.77824 .25 L
.77824 .25 L
.77825 .25 L
.77825 .25 L
.77826 .25 L
.77826 .25 L
.77827 .25 L
Mistroke
.77828 .25 L
.77828 .25 L
.77829 .25 L
.7783 .25 L
.7783 .25 L
.77831 .25 L
.77831 .25 L
.77832 .25 L
.77833 .25 L
.77833 .25 L
.77834 .25 L
.77835 .25 L
.77835 .25 L
.77836 .25 L
.77836 .25 L
.77836 .25 L
.77837 .25 L
.77837 .25 L
.77838 .25 L
.77839 .25 L
.77839 .25 L
.7784 .25 L
.77841 .25 L
.77841 .25 L
.77842 .25 L
.77842 .25 L
.77843 .25 L
.77844 .25 L
.77844 .25 L
.77845 .25 L
.77846 .25 L
.77846 .25 L
.77847 .25 L
.77848 .25 L
.77848 .25 L
.77848 .25 L
.77849 .25 L
.77849 .25 L
.7785 .25 L
.7785 .25 L
.77851 .25 L
.77851 .25 L
.77852 .25 L
.77852 .25 L
.77852 .25 L
.77853 .25 L
.77853 .25 L
.77854 .25 L
.77854 .25 L
.77854 .25 L
Mistroke
.77855 .25 L
.77856 .25 L
.77856 .25 L
.77857 .25 L
.77858 .25 L
.77858 .25 L
.77859 .25 L
.77859 .25 L
.7786 .25 L
.77861 .25 L
.77861 .25 L
.77862 .25 L
.77863 .25 L
.77863 .25 L
.77864 .25 L
.77864 .25 L
.77865 .25 L
.77865 .25 L
.77866 .25 L
.77867 .25 L
.77867 .25 L
.77868 .25 L
.77868 .25 L
.77869 .25 L
.77869 .25 L
.7787 .25 L
.77871 .25 L
.77871 .25 L
.77872 .25 L
.77873 .25 L
.77873 .25 L
.77874 .25 L
.77874 .25 L
.77874 .25 L
.77875 .25 L
.77876 .25 L
.77876 .25 L
.77877 .25 L
.77878 .25 L
.77878 .25 L
.77879 .25 L
.7788 .25 L
.7788 .25 L
.77881 .25 L
.77881 .25 L
.77882 .25 L
.77883 .25 L
.77883 .25 L
.77884 .25 L
.77885 .25 L
Mistroke
.77885 .25 L
.77886 .25 L
.77886 .25 L
.77887 .25 L
.77887 .25 L
.77888 .25 L
.77889 .25 L
.77889 .25 L
.7789 .25 L
.7789 .25 L
.77891 .25 L
.77892 .25 L
.77892 .25 L
.77893 .25 L
.77893 .25 L
.77894 .25 L
.77894 .25 L
.77895 .25 L
.77895 .25 L
.77896 .25 L
.77897 .25 L
.77897 .25 L
.77897 .25 L
.77898 .25 L
.77899 .25 L
.77899 .25 L
.779 .25 L
.779 .25 L
.77901 .25 L
.77902 .25 L
.77902 .25 L
.77902 .25 L
.77903 .25 L
.77904 .25 L
.77904 .25 L
.77905 .25 L
.77905 .25 L
.77906 .25 L
.77907 .25 L
.77907 .25 L
.77908 .25 L
.77908 .25 L
.77909 .25 L
.77909 .25 L
.7791 .25 L
.77911 .25 L
.77911 .25 L
.77912 .25 L
.77913 .25 L
.77913 .25 L
Mistroke
.77914 .25 L
.77914 .25 L
.77915 .25 L
.77916 .25 L
.77916 .25 L
.77917 .25 L
.77918 .25 L
.77918 .25 L
.77918 .25 L
.77919 .25 L
.77919 .25 L
.7792 .25 L
.7792 .25 L
.77921 .25 L
.77922 .25 L
.77922 .25 L
.77923 .25 L
.77924 .25 L
.77924 .25 L
.77925 .25 L
.77925 .25 L
.77926 .25 L
.77927 .25 L
.77927 .25 L
.77928 .25 L
.77929 .25 L
.77929 .25 L
.7793 .25 L
.7793 .25 L
.77931 .25 L
.77931 .25 L
.77932 .25 L
.77932 .25 L
.77933 .25 L
.77933 .25 L
.77934 .25 L
.77934 .25 L
.77934 .25 L
.77935 .25 L
.77935 .25 L
.77935 .25 L
.77936 .25 L
.77936 .25 L
.77937 .25 L
.77937 .25 L
.77938 .25 L
.77939 .25 L
.77939 .25 L
.7794 .25 L
.77941 .25 L
Mistroke
.77941 .25 L
.77942 .25 L
.77942 .25 L
.77943 .25 L
.77944 .25 L
.77944 .25 L
.77945 .25 L
.77946 .25 L
.77946 .25 L
.77947 .25 L
.77947 .25 L
.77948 .25 L
.77948 .25 L
.77949 .25 L
.7795 .25 L
.7795 .25 L
.77951 .25 L
.77951 .25 L
.77952 .25 L
.77952 .25 L
.77953 .25 L
.77954 .25 L
.77954 .25 L
.77955 .25 L
.77955 .25 L
.77956 .25 L
.77956 .25 L
.77957 .25 L
.77957 .25 L
.77958 .25 L
.77959 .25 L
.77959 .25 L
.7796 .25 L
.77961 .25 L
.77961 .25 L
.77962 .25 L
.77963 .25 L
.77963 .25 L
.77964 .25 L
.77965 .25 L
.77965 .25 L
.77966 .25 L
.77966 .25 L
.77967 .25 L
.77967 .25 L
.77968 .25 L
.77969 .25 L
.77969 .25 L
.7797 .25 L
.7797 .25 L
Mistroke
.77971 .25 L
.77972 .25 L
.77972 .25 L
.77973 .25 L
.77973 .25 L
.77974 .25 L
.77975 .25 L
.77975 .25 L
.77976 .25 L
.77976 .25 L
.77977 .25 L
.77977 .25 L
.77978 .25 L
.77978 .25 L
.77979 .25 L
.77979 .25 L
.7798 .25 L
.7798 .25 L
.77981 .25 L
.77982 .25 L
.77982 .25 L
.77983 .25 L
.77983 .25 L
.77984 .25 L
.77984 .25 L
.77985 .25 L
.77986 .25 L
.77986 .25 L
.77986 .25 L
.77987 .25 L
.77988 .25 L
.77988 .25 L
.77989 .25 L
.77989 .25 L
.7799 .25 L
.77991 .25 L
.77991 .25 L
.77992 .25 L
.77992 .25 L
.77993 .25 L
.77994 .25 L
.77994 .25 L
.77995 .25 L
.77995 .25 L
.77996 .25 L
.77997 .25 L
.77997 .25 L
.77998 .25 L
.77999 .25 L
.77999 .25 L
Mistroke
.78 .25 L
.78 .25 L
.78001 .25 L
.78001 .25 L
.78001 .25 L
.78002 .25 L
.78003 .25 L
.78003 .25 L
.78004 .25 L
.78005 .25 L
.78005 .25 L
.78006 .25 L
.78006 .25 L
.78007 .25 L
.78008 .25 L
.78008 .25 L
.78009 .25 L
.7801 .25 L
.7801 .25 L
.78011 .25 L
.78012 .25 L
.78012 .25 L
.78013 .25 L
.78013 .25 L
.78014 .25 L
.78014 .25 L
.78015 .25 L
.78015 .25 L
.78015 .25 L
.78016 .25 L
.78016 .25 L
.78017 .25 L
.78017 .25 L
.78017 .25 L
.78018 .25 L
.78018 .25 L
.78019 .25 L
.78019 .25 L
.7802 .25 L
.7802 .25 L
.78021 .25 L
.78022 .25 L
.78022 .25 L
.78023 .25 L
.78024 .25 L
.78024 .25 L
.78025 .25 L
.78025 .25 L
.78026 .25 L
.78027 .25 L
Mistroke
.78027 .25 L
.78028 .25 L
.78029 .25 L
.78029 .25 L
.78029 .25 L
.7803 .25 L
.78031 .25 L
.78031 .25 L
.78032 .25 L
.78033 .25 L
.78033 .25 L
.78034 .25 L
.78034 .25 L
.78035 .25 L
.78035 .25 L
.78036 .25 L
.78037 .25 L
.78037 .25 L
.78038 .25 L
.78038 .25 L
.78039 .25 L
.78039 .25 L
.7804 .25 L
.7804 .25 L
.78041 .25 L
.78042 .25 L
.78042 .25 L
.78043 .25 L
.78044 .25 L
.78044 .25 L
.78045 .25 L
.78046 .25 L
.78046 .25 L
.78047 .25 L
.78047 .25 L
.78048 .25 L
.78049 .25 L
.78049 .25 L
.7805 .25 L
.7805 .25 L
.78051 .25 L
.78051 .25 L
.78052 .25 L
.78053 .25 L
.78053 .25 L
.78054 .25 L
.78054 .25 L
.78055 .25 L
.78056 .25 L
.78056 .25 L
Mistroke
.78057 .25 L
.78058 .25 L
.78058 .25 L
.78059 .25 L
.78059 .25 L
.78059 .25 L
.7806 .25 L
.78061 .25 L
.78061 .25 L
.78062 .25 L
.78063 .25 L
.78063 .25 L
.78064 .25 L
.78065 .25 L
.78065 .25 L
.78066 .25 L
.78066 .25 L
.78067 .25 L
.78068 .25 L
.78068 .25 L
.78069 .25 L
.78069 .25 L
.7807 .25 L
.78071 .25 L
.78071 .25 L
.78072 .25 L
.78072 .25 L
.78073 .25 L
.78074 .25 L
.78074 .25 L
.78075 .25 L
.78075 .25 L
.78076 .25 L
.78077 .25 L
.78077 .25 L
.78078 .25 L
.78078 .25 L
.78079 .25 L
.78079 .25 L
.7808 .25 L
.7808 .25 L
.78081 .25 L
.78082 .25 L
.78082 .25 L
.78082 .25 L
.78083 .25 L
.78084 .25 L
.78084 .25 L
.78085 .25 L
.78085 .25 L
Mistroke
.78086 .25 L
.78087 .25 L
.78087 .25 L
.78087 .25 L
.78088 .25 L
.78089 .25 L
.78089 .25 L
.7809 .25 L
.7809 .25 L
.78091 .25 L
.78091 .25 L
.78092 .25 L
.78093 .25 L
.78093 .25 L
.78094 .25 L
.78094 .25 L
.78095 .25 L
.78096 .25 L
.78096 .25 L
.78097 .25 L
.78098 .25 L
.78098 .25 L
.78099 .25 L
.78099 .25 L
.781 .25 L
.78101 .25 L
.78101 .25 L
.78102 .25 L
.78103 .25 L
.78103 .25 L
.78103 .25 L
.78104 .25 L
.78104 .25 L
.78105 .25 L
.78105 .25 L
.78106 .25 L
.78107 .25 L
.78107 .25 L
.78108 .25 L
.78109 .25 L
.78109 .25 L
.7811 .25 L
.7811 .25 L
.78111 .25 L
.78112 .25 L
.78112 .25 L
.78113 .25 L
.78114 .25 L
.78114 .25 L
.78115 .25 L
Mistroke
.78115 .25 L
.78116 .25 L
.78116 .25 L
.78117 .25 L
.78117 .25 L
.78118 .25 L
.78118 .25 L
.78119 .25 L
.78119 .25 L
.78119 .25 L
.7812 .25 L
.7812 .25 L
.7812 .25 L
.78121 .25 L
.78121 .25 L
.78122 .25 L
.78122 .25 L
.78123 .25 L
.78124 .25 L
.78124 .25 L
.78125 .25 L
.78126 .25 L
.78126 .25 L
.78127 .25 L
.78127 .25 L
.78128 .25 L
.78129 .25 L
.78129 .25 L
.7813 .25 L
.78131 .25 L
.78131 .25 L
.78132 .25 L
.78132 .25 L
.78133 .25 L
.78133 .25 L
.78134 .25 L
.78135 .25 L
.78135 .25 L
.78136 .25 L
.78136 .25 L
.78137 .25 L
.78137 .25 L
.78138 .25 L
.78139 .25 L
.78139 .25 L
.7814 .25 L
.7814 .25 L
.78141 .25 L
.78142 .25 L
.78142 .25 L
Mistroke
.78142 .25 L
.78143 .25 L
.78144 .25 L
.78145 .25 L
.78145 .25 L
.78146 .25 L
.78146 .25 L
.78147 .25 L
.78148 .25 L
.78148 .25 L
.78149 .25 L
.7815 .25 L
.7815 .25 L
.78151 .25 L
.78152 .25 L
.78152 .25 L
.78152 .25 L
.78153 .25 L
.78154 .25 L
.78154 .25 L
.78155 .25 L
.78155 .25 L
.78156 .25 L
.78157 .25 L
.78157 .25 L
.78158 .25 L
.78158 .25 L
.78159 .25 L
.7816 .25 L
.7816 .25 L
.78161 .25 L
.78161 .25 L
.78162 .25 L
.78162 .25 L
.78163 .25 L
.78163 .25 L
.78164 .25 L
.78164 .25 L
.78165 .25 L
.78165 .25 L
.78166 .25 L
.78167 .25 L
.78167 .25 L
.78168 .25 L
.78168 .25 L
.78169 .25 L
.7817 .25 L
.7817 .25 L
.78171 .25 L
.78171 .25 L
Mistroke
.78171 .25 L
.78172 .25 L
.78173 .25 L
.78173 .25 L
.78174 .25 L
.78174 .25 L
.78175 .25 L
.78176 .25 L
.78176 .25 L
.78177 .25 L
.78177 .25 L
.78178 .25 L
.78179 .25 L
.78179 .25 L
.7818 .25 L
.78181 .25 L
.78181 .25 L
.78182 .25 L
.78182 .25 L
.78183 .25 L
.78184 .25 L
.78184 .25 L
.78185 .25 L
.78185 .25 L
.78186 .25 L
.78186 .25 L
.78187 .25 L
.78187 .25 L
.78188 .25 L
.78188 .25 L
.78189 .25 L
.7819 .25 L
.7819 .25 L
.78191 .25 L
.78192 .25 L
.78192 .25 L
.78193 .25 L
.78194 .25 L
.78194 .25 L
.78195 .25 L
.78195 .25 L
.78196 .25 L
.78197 .25 L
.78197 .25 L
.78198 .25 L
.78198 .25 L
.78199 .25 L
.78199 .25 L
.782 .25 L
.782 .25 L
Mistroke
.782 .25 L
.78201 .25 L
.78201 .25 L
.78202 .25 L
.78202 .25 L
.78203 .25 L
.78203 .25 L
.78203 .25 L
.78204 .25 L
.78204 .25 L
.78205 .25 L
.78205 .25 L
.78206 .25 L
.78207 .25 L
.78207 .25 L
.78208 .25 L
.78209 .25 L
.78209 .25 L
.7821 .25 L
.7821 .25 L
.78211 .25 L
.78212 .25 L
.78212 .25 L
.78213 .25 L
.78214 .25 L
.78214 .25 L
.78214 .25 L
.78215 .25 L
.78216 .25 L
.78216 .25 L
.78217 .25 L
.78218 .25 L
.78218 .25 L
.78219 .25 L
.78219 .25 L
.7822 .25 L
.7822 .25 L
.78221 .25 L
.78222 .25 L
.78222 .25 L
.78223 .25 L
.78224 .25 L
.78224 .25 L
.78224 .25 L
.78225 .25 L
.78226 .25 L
.78226 .25 L
.78227 .25 L
.78228 .25 L
.78228 .25 L
Mistroke
.78229 .25 L
.78229 .25 L
.7823 .25 L
.78231 .25 L
.78231 .25 L
.78232 .25 L
.78233 .25 L
.78233 .25 L
.78234 .25 L
.78234 .25 L
.78235 .25 L
.78235 .25 L
.78236 .25 L
.78237 .25 L
.78237 .25 L
.78238 .25 L
.78238 .25 L
.78239 .25 L
.7824 .25 L
.7824 .25 L
.78241 .25 L
.78241 .25 L
.78242 .25 L
.78243 .25 L
.78243 .25 L
.78244 .25 L
.78244 .25 L
.78245 .25 L
.78245 .25 L
.78246 .25 L
.78246 .25 L
.78247 .25 L
.78247 .25 L
.78248 .25 L
.78248 .25 L
.78249 .25 L
.7825 .25 L
.7825 .25 L
.78251 .25 L
.78252 .25 L
.78252 .25 L
.78252 .25 L
.78253 .25 L
.78253 .25 L
.78254 .25 L
.78254 .25 L
.78255 .25 L
.78256 .25 L
.78256 .25 L
.78257 .25 L
Mistroke
.78257 .25 L
.78258 .25 L
.78259 .25 L
.78259 .25 L
.7826 .25 L
.7826 .25 L
.78261 .25 L
.78262 .25 L
.78262 .25 L
.78263 .25 L
.78263 .25 L
.78264 .25 L
.78265 .25 L
.78265 .25 L
.78266 .25 L
.78267 .25 L
.78267 .25 L
.78268 .25 L
.78268 .25 L
.78269 .25 L
.78269 .25 L
.7827 .25 L
.7827 .25 L
.78271 .25 L
.78272 .25 L
.78272 .25 L
.78273 .25 L
.78273 .25 L
.78274 .25 L
.78275 .25 L
.78275 .25 L
.78276 .25 L
.78277 .25 L
.78277 .25 L
.78278 .25 L
.78279 .25 L
.78279 .25 L
.7828 .25 L
.7828 .25 L
.78281 .25 L
.78281 .25 L
.78282 .25 L
.78282 .25 L
.78282 .25 L
.78283 .25 L
.78283 .25 L
.78284 .25 L
.78284 .25 L
.78285 .25 L
.78285 .25 L
Mistroke
.78285 .25 L
.78286 .25 L
.78286 .25 L
.78286 .25 L
.78287 .25 L
.78288 .25 L
.78288 .25 L
.78289 .25 L
.7829 .25 L
.7829 .25 L
.78291 .25 L
.78292 .25 L
.78292 .25 L
.78293 .25 L
.78293 .25 L
.78294 .25 L
.78295 .25 L
.78295 .25 L
.78296 .25 L
.78296 .25 L
.78297 .25 L
.78297 .25 L
.78298 .25 L
.78299 .25 L
.78299 .25 L
.783 .25 L
.78301 .25 L
.78301 .25 L
.78302 .25 L
.78302 .25 L
.78303 .25 L
.78303 .25 L
.78304 .25 L
.78305 .25 L
.78305 .25 L
.78306 .25 L
.78306 .25 L
.78307 .25 L
.78307 .25 L
.78308 .25 L
.78309 .25 L
.78309 .25 L
.7831 .25 L
.78311 .25 L
.78311 .25 L
.78312 .25 L
.78312 .25 L
.78313 .25 L
.78314 .25 L
.78314 .25 L
Mistroke
.78315 .25 L
.78316 .25 L
.78316 .25 L
.78317 .25 L
.78317 .25 L
.78318 .25 L
.78318 .25 L
.78319 .25 L
.7832 .25 L
.7832 .25 L
.78321 .25 L
.78321 .25 L
.78322 .25 L
.78322 .25 L
.78323 .25 L
.78324 .25 L
.78324 .25 L
.78325 .25 L
.78326 .25 L
.78326 .25 L
.78327 .25 L
.78327 .25 L
.78328 .25 L
.78328 .25 L
.78329 .25 L
.78329 .25 L
.7833 .25 L
.7833 .25 L
.78331 .25 L
.78331 .25 L
.78332 .25 L
.78333 .25 L
.78333 .25 L
.78334 .25 L
.78334 .25 L
.78335 .25 L
.78335 .25 L
.78336 .25 L
.78336 .25 L
.78337 .25 L
.78337 .25 L
.78338 .25 L
.78339 .25 L
.78339 .25 L
.7834 .25 L
.7834 .25 L
.78341 .25 L
.78342 .25 L
.78342 .25 L
.78343 .25 L
Mistroke
.78343 .25 L
.78344 .25 L
.78345 .25 L
.78345 .25 L
.78346 .25 L
.78347 .25 L
.78347 .25 L
.78348 .25 L
.78348 .25 L
.78349 .25 L
.7835 .25 L
.7835 .25 L
.78351 .25 L
.78351 .25 L
.78351 .25 L
.78352 .25 L
.78353 .25 L
.78353 .25 L
.78354 .25 L
.78355 .25 L
.78355 .25 L
.78356 .25 L
.78356 .25 L
.78357 .25 L
.78358 .25 L
.78358 .25 L
.78359 .25 L
.7836 .25 L
.7836 .25 L
.78361 .25 L
.78361 .25 L
.78362 .25 L
.78363 .25 L
.78363 .25 L
.78364 .25 L
.78364 .25 L
.78364 .25 L
.78365 .25 L
.78365 .25 L
.78366 .25 L
.78366 .25 L
.78366 .25 L
.78367 .25 L
.78367 .25 L
.78368 .25 L
.78368 .25 L
.78368 .25 L
.78369 .25 L
.78369 .25 L
.7837 .25 L
Mistroke
.78371 .25 L
.78371 .25 L
.78372 .25 L
.78373 .25 L
.78373 .25 L
.78374 .25 L
.78375 .25 L
.78375 .25 L
.78376 .25 L
.78376 .25 L
.78377 .25 L
.78378 .25 L
.78378 .25 L
.78379 .25 L
.78379 .25 L
.7838 .25 L
.78381 .25 L
.78381 .25 L
.78382 .25 L
.78382 .25 L
.78383 .25 L
.78384 .25 L
.78384 .25 L
.78385 .25 L
.78385 .25 L
.78386 .25 L
.78386 .25 L
.78387 .25 L
.78388 .25 L
.78388 .25 L
.78389 .25 L
.78389 .25 L
.7839 .25 L
.7839 .25 L
.78391 .25 L
.78392 .25 L
.78392 .25 L
.78393 .25 L
.78394 .25 L
.78394 .25 L
.78395 .25 L
.78395 .25 L
.78396 .25 L
.78397 .25 L
.78397 .25 L
.78398 .25 L
.78399 .25 L
.78399 .25 L
.78399 .25 L
.784 .25 L
Mistroke
.78401 .25 L
.78401 .25 L
.78402 .25 L
.78403 .25 L
.78403 .25 L
.78404 .25 L
.78404 .25 L
.78405 .25 L
.78405 .25 L
.78406 .25 L
.78407 .25 L
.78407 .25 L
.78408 .25 L
.78409 .25 L
.78409 .25 L
.78409 .25 L
.7841 .25 L
.78411 .25 L
.78411 .25 L
.78412 .25 L
.78412 .25 L
.78413 .25 L
.78413 .25 L
.78414 .25 L
.78414 .25 L
.78415 .25 L
.78416 .25 L
.78416 .25 L
.78417 .25 L
.78417 .25 L
.78418 .25 L
.78418 .25 L
.78418 .25 L
.78419 .25 L
.7842 .25 L
.7842 .25 L
.78421 .25 L
.78422 .25 L
.78422 .25 L
.78423 .25 L
.78423 .25 L
.78424 .25 L
.78425 .25 L
.78425 .25 L
.78426 .25 L
.78426 .25 L
.78427 .25 L
.78428 .25 L
.78428 .25 L
.78429 .25 L
Mistroke
.7843 .25 L
.7843 .25 L
.78431 .25 L
.78431 .25 L
.78432 .25 L
.78432 .25 L
.78433 .25 L
.78433 .25 L
.78434 .25 L
.78434 .25 L
.78435 .25 L
.78436 .25 L
.78436 .25 L
.78437 .25 L
.78437 .25 L
.78438 .25 L
.78439 .25 L
.78439 .25 L
.7844 .25 L
.78441 .25 L
.78441 .25 L
.78442 .25 L
.78443 .25 L
.78443 .25 L
.78444 .25 L
.78445 .25 L
.78445 .25 L
.78445 .25 L
.78446 .25 L
.78446 .25 L
.78447 .25 L
.78447 .25 L
.78447 .25 L
.78448 .25 L
.78448 .25 L
.78449 .25 L
.78449 .25 L
.7845 .25 L
.7845 .25 L
.7845 .25 L
.78451 .25 L
.78451 .25 L
.78452 .25 L
.78452 .25 L
.78453 .25 L
.78454 .25 L
.78454 .25 L
.78455 .25 L
.78456 .25 L
.78456 .25 L
Mistroke
.78457 .25 L
.78457 .25 L
.78458 .25 L
.78459 .25 L
.78459 .25 L
.7846 .25 L
.78461 .25 L
.78461 .25 L
.78461 .25 L
.78462 .25 L
.78463 .25 L
.78463 .25 L
.78464 .25 L
.78465 .25 L
.78465 .25 L
.78466 .25 L
.78466 .25 L
.78467 .25 L
.78468 .25 L
.78468 .25 L
.78469 .25 L
.78469 .25 L
.7847 .25 L
.78471 .25 L
.78471 .25 L
.78471 .25 L
.78472 .25 L
.78473 .25 L
.78473 .25 L
.78474 .25 L
.78475 .25 L
.78475 .25 L
.78476 .25 L
.78476 .25 L
.78477 .25 L
.78478 .25 L
.78478 .25 L
.78479 .25 L
.7848 .25 L
.7848 .25 L
.78481 .25 L
.78481 .25 L
.78482 .25 L
.78482 .25 L
.78483 .25 L
.78484 .25 L
.78484 .25 L
.78485 .25 L
.78486 .25 L
.78486 .25 L
Mistroke
.78487 .25 L
.78487 .25 L
.78488 .25 L
.78488 .25 L
.78489 .25 L
.7849 .25 L
.7849 .25 L
.78491 .25 L
.78491 .25 L
.78492 .25 L
.78492 .25 L
.78493 .25 L
.78493 .25 L
.78494 .25 L
.78495 .25 L
.78495 .25 L
.78496 .25 L
.78497 .25 L
.78497 .25 L
.78498 .25 L
.78499 .25 L
.78499 .25 L
.785 .25 L
.78501 .25 L
.78501 .25 L
.78502 .25 L
.78502 .25 L
.78503 .25 L
.78503 .25 L
.78504 .25 L
.78505 .25 L
.78505 .25 L
.78506 .25 L
.78506 .25 L
.78507 .25 L
.78507 .25 L
.78508 .25 L
.78509 .25 L
.78509 .25 L
.7851 .25 L
.7851 .25 L
.78511 .25 L
.78511 .25 L
.78512 .25 L
.78512 .25 L
.78513 .25 L
.78514 .25 L
.78514 .25 L
.78514 .25 L
.78515 .25 L
Mistroke
.78516 .25 L
.78516 .25 L
.78517 .25 L
.78518 .25 L
.78518 .25 L
.78519 .25 L
.78519 .25 L
.7852 .25 L
.7852 .25 L
.78521 .25 L
.78521 .25 L
.78522 .25 L
.78522 .25 L
.78523 .25 L
.78524 .25 L
.78524 .25 L
.78525 .25 L
.78525 .25 L
.78526 .25 L
.78526 .25 L
.78527 .25 L
.78528 .25 L
.78528 .25 L
.78529 .25 L
.7853 .25 L
.7853 .25 L
.78531 .25 L
.78531 .25 L
.78532 .25 L
.78533 .25 L
.78533 .25 L
.78534 .25 L
.78535 .25 L
.78535 .25 L
.78535 .25 L
.78536 .25 L
.78536 .25 L
.78537 .25 L
.78537 .25 L
.78538 .25 L
.78539 .25 L
.78539 .25 L
.7854 .25 L
.78541 .25 L
.78541 .25 L
.78542 .25 L
.78543 .25 L
.78543 .25 L
.78544 .25 L
.78544 .25 L
Mistroke
.78545 .25 L
.78546 .25 L
.78546 .25 L
.78547 .25 L
.78548 .25 L
.78548 .25 L
.78549 .25 L
.78549 .25 L
.78549 .25 L
.7855 .25 L
.7855 .25 L
.78551 .25 L
.78551 .25 L
.78551 .25 L
.78552 .25 L
.78552 .25 L
.78553 .25 L
.78553 .25 L
.78553 .25 L
.78554 .25 L
.78554 .25 L
.78555 .25 L
.78556 .25 L
.78556 .25 L
.78557 .25 L
.78558 .25 L
.78558 .25 L
.78559 .25 L
.78559 .25 L
.7856 .25 L
.78561 .25 L
.78561 .25 L
.78562 .25 L
.78563 .25 L
.78563 .25 L
.78564 .25 L
.78564 .25 L
.78565 .25 L
.78565 .25 L
.78566 .25 L
.78567 .25 L
.78567 .25 L
.78568 .25 L
.78568 .25 L
.78569 .25 L
.7857 .25 L
.7857 .25 L
.78571 .25 L
.78571 .25 L
.78572 .25 L
Mistroke
.78573 .25 L
.78573 .25 L
.78574 .25 L
.78574 .25 L
.78575 .25 L
.78575 .25 L
.78576 .25 L
.78577 .25 L
.78577 .25 L
.78578 .25 L
.78579 .25 L
.78579 .25 L
.7858 .25 L
.7858 .25 L
.78581 .25 L
.78582 .25 L
.78582 .25 L
.78583 .25 L
.78584 .25 L
.78584 .25 L
.78584 .25 L
.78585 .25 L
.78586 .25 L
.78586 .25 L
.78587 .25 L
.78588 .25 L
.78588 .25 L
.78589 .25 L
.78589 .25 L
.7859 .25 L
.7859 .25 L
.78591 .25 L
.78592 .25 L
.78592 .25 L
.78593 .25 L
.78594 .25 L
.78594 .25 L
.78594 .25 L
.78595 .25 L
.78596 .25 L
.78596 .25 L
.78597 .25 L
.78597 .25 L
.78598 .25 L
.78598 .25 L
.78599 .25 L
.78599 .25 L
.786 .25 L
.78601 .25 L
.78601 .25 L
Mistroke
.78602 .25 L
.78602 .25 L
.78603 .25 L
.78603 .25 L
.78603 .25 L
.78604 .25 L
.78605 .25 L
.78605 .25 L
.78606 .25 L
.78607 .25 L
.78607 .25 L
.78608 .25 L
.78608 .25 L
.78609 .25 L
.7861 .25 L
.7861 .25 L
.78611 .25 L
.78611 .25 L
.78612 .25 L
.78613 .25 L
.78613 .25 L
.78614 .25 L
.78615 .25 L
.78615 .25 L
.78616 .25 L
.78617 .25 L
.78617 .25 L
.78617 .25 L
.78618 .25 L
.78618 .25 L
.78619 .25 L
.78619 .25 L
.7862 .25 L
.78621 .25 L
.78621 .25 L
.78622 .25 L
.78622 .25 L
.78623 .25 L
.78624 .25 L
.78624 .25 L
.78625 .25 L
.78626 .25 L
.78626 .25 L
.78627 .25 L
.78628 .25 L
.78628 .25 L
.78629 .25 L
.7863 .25 L
.7863 .25 L
.7863 .25 L
Mistroke
.78631 .25 L
.78631 .25 L
.78632 .25 L
.78632 .25 L
.78632 .25 L
.78633 .25 L
.78633 .25 L
.78634 .25 L
.78634 .25 L
.78635 .25 L
.78635 .25 L
.78635 .25 L
.78636 .25 L
.78636 .25 L
.78637 .25 L
.78637 .25 L
.78638 .25 L
.78639 .25 L
.78639 .25 L
.7864 .25 L
.78641 .25 L
.78641 .25 L
.78642 .25 L
.78642 .25 L
.78643 .25 L
.78644 .25 L
.78644 .25 L
.78645 .25 L
.78646 .25 L
.78646 .25 L
.78647 .25 L
.78647 .25 L
.78648 .25 L
.78648 .25 L
.78649 .25 L
.7865 .25 L
.7865 .25 L
.78651 .25 L
.78651 .25 L
.78652 .25 L
.78653 .25 L
.78653 .25 L
.78654 .25 L
.78654 .25 L
.78655 .25 L
.78656 .25 L
.78656 .25 L
.78656 .25 L
.78657 .25 L
.78658 .25 L
Mistroke
.78658 .25 L
.78659 .25 L
.7866 .25 L
.7866 .25 L
.78661 .25 L
.78661 .25 L
.78662 .25 L
.78663 .25 L
.78663 .25 L
.78664 .25 L
.78665 .25 L
.78665 .25 L
.78666 .25 L
.78666 .25 L
.78667 .25 L
.78667 .25 L
.78668 .25 L
.78669 .25 L
.78669 .25 L
.7867 .25 L
.78671 .25 L
.78671 .25 L
.78672 .25 L
.78672 .25 L
.78673 .25 L
.78673 .25 L
.78674 .25 L
.78675 .25 L
.78675 .25 L
.78676 .25 L
.78676 .25 L
.78677 .25 L
.78677 .25 L
.78678 .25 L
.78679 .25 L
.78679 .25 L
.78679 .25 L
.7868 .25 L
.78681 .25 L
.78681 .25 L
.78682 .25 L
.78682 .25 L
.78683 .25 L
.78684 .25 L
.78684 .25 L
.78684 .25 L
.78685 .25 L
.78685 .25 L
.78686 .25 L
.78686 .25 L
Mistroke
.78687 .25 L
.78688 .25 L
.78688 .25 L
.78689 .25 L
.7869 .25 L
.7869 .25 L
.78691 .25 L
.78691 .25 L
.78692 .25 L
.78693 .25 L
.78693 .25 L
.78694 .25 L
.78694 .25 L
.78695 .25 L
.78696 .25 L
.78696 .25 L
.78697 .25 L
.78698 .25 L
.78698 .25 L
.78699 .25 L
.787 .25 L
.787 .25 L
.787 .25 L
.78701 .25 L
.78701 .25 L
.78702 .25 L
.78702 .25 L
.78703 .25 L
.78704 .25 L
.78704 .25 L
.78705 .25 L
.78705 .25 L
.78706 .25 L
.78707 .25 L
.78707 .25 L
.78708 .25 L
.78709 .25 L
.78709 .25 L
.7871 .25 L
.78711 .25 L
.78711 .25 L
.78712 .25 L
.78712 .25 L
.78713 .25 L
.78713 .25 L
.78714 .25 L
.78714 .25 L
.78714 .25 L
.78715 .25 L
.78715 .25 L
Mistroke
.78716 .25 L
.78716 .25 L
.78717 .25 L
.78717 .25 L
.78717 .25 L
.78718 .25 L
.78718 .25 L
.78718 .25 L
.78719 .25 L
.7872 .25 L
.7872 .25 L
.78721 .25 L
.78722 .25 L
.78722 .25 L
.78723 .25 L
.78724 .25 L
.78724 .25 L
.78725 .25 L
.78725 .25 L
.78726 .25 L
.78727 .25 L
.78727 .25 L
.78728 .25 L
.78729 .25 L
.78729 .25 L
.7873 .25 L
.7873 .25 L
.78731 .25 L
.78731 .25 L
.78732 .25 L
.78733 .25 L
.78733 .25 L
.78734 .25 L
.78734 .25 L
.78735 .25 L
.78736 .25 L
.78736 .25 L
.78737 .25 L
.78737 .25 L
.78738 .25 L
.78738 .25 L
.78739 .25 L
.78739 .25 L
.7874 .25 L
.78741 .25 L
.78741 .25 L
.78742 .25 L
.78743 .25 L
.78743 .25 L
.78744 .25 L
Mistroke
.78744 .25 L
.78745 .25 L
.78746 .25 L
.78746 .25 L
.78747 .25 L
.78748 .25 L
.78748 .25 L
.78749 .25 L
.78749 .25 L
.7875 .25 L
.7875 .25 L
.78751 .25 L
.78752 .25 L
.78752 .25 L
.78753 .25 L
.78753 .25 L
.78754 .25 L
.78755 .25 L
.78755 .25 L
.78756 .25 L
.78756 .25 L
.78757 .25 L
.78758 .25 L
.78758 .25 L
.78759 .25 L
.78759 .25 L
.7876 .25 L
.7876 .25 L
.78761 .25 L
.78761 .25 L
.78762 .25 L
.78762 .25 L
.78763 .25 L
.78763 .25 L
.78764 .25 L
.78765 .25 L
.78765 .25 L
.78766 .25 L
.78766 .25 L
.78767 .25 L
.78767 .25 L
.78768 .25 L
.78768 .25 L
.78769 .25 L
.78769 .25 L
.7877 .25 L
.78771 .25 L
.78771 .25 L
.78772 .25 L
.78772 .25 L
Mistroke
.78773 .25 L
.78774 .25 L
.78774 .25 L
.78775 .25 L
.78775 .25 L
.78776 .25 L
.78777 .25 L
.78777 .25 L
.78778 .25 L
.78779 .25 L
.78779 .25 L
.7878 .25 L
.78781 .25 L
.78781 .25 L
.78782 .25 L
.78782 .25 L
.78783 .25 L
.78783 .25 L
.78783 .25 L
.78784 .25 L
.78785 .25 L
.78785 .25 L
.78786 .25 L
.78787 .25 L
.78787 .25 L
.78788 .25 L
.78788 .25 L
.78789 .25 L
.7879 .25 L
.7879 .25 L
.78791 .25 L
.78792 .25 L
.78792 .25 L
.78793 .25 L
.78794 .25 L
.78794 .25 L
.78795 .25 L
.78795 .25 L
.78796 .25 L
.78796 .25 L
.78796 .25 L
.78797 .25 L
.78797 .25 L
.78798 .25 L
.78798 .25 L
.78799 .25 L
.78799 .25 L
.78799 .25 L
.788 .25 L
.788 .25 L
Mistroke
.788 .25 L
.78801 .25 L
.78801 .25 L
.78802 .25 L
.78803 .25 L
.78803 .25 L
.78804 .25 L
.78805 .25 L
.78805 .25 L
.78806 .25 L
.78807 .25 L
.78807 .25 L
.78808 .25 L
.78809 .25 L
.78809 .25 L
.7881 .25 L
.7881 .25 L
.78811 .25 L
.78811 .25 L
.78812 .25 L
.78813 .25 L
.78813 .25 L
.78814 .25 L
.78814 .25 L
.78815 .25 L
.78816 .25 L
.78816 .25 L
.78817 .25 L
.78817 .25 L
.78818 .25 L
.78819 .25 L
.78819 .25 L
.7882 .25 L
.7882 .25 L
.78821 .25 L
.78821 .25 L
.78822 .25 L
.78822 .25 L
.78823 .25 L
.78824 .25 L
.78824 .25 L
.78825 .25 L
.78826 .25 L
.78826 .25 L
.78827 .25 L
.78827 .25 L
.78828 .25 L
.78829 .25 L
.78829 .25 L
.7883 .25 L
Mistroke
.78831 .25 L
.78831 .25 L
.78831 .25 L
.78832 .25 L
.78833 .25 L
.78833 .25 L
.78834 .25 L
.78835 .25 L
.78835 .25 L
.78836 .25 L
.78836 .25 L
.78837 .25 L
.78837 .25 L
.78838 .25 L
.78839 .25 L
.78839 .25 L
.7884 .25 L
.78841 .25 L
.78841 .25 L
.78841 .25 L
.78842 .25 L
.78843 .25 L
.78843 .25 L
.78844 .25 L
.78845 .25 L
.78845 .25 L
.78846 .25 L
.78846 .25 L
.78847 .25 L
.78848 .25 L
.78848 .25 L
.78849 .25 L
.7885 .25 L
.7885 .25 L
.78851 .25 L
.78851 .25 L
.78852 .25 L
.78852 .25 L
.78853 .25 L
.78854 .25 L
.78854 .25 L
.78855 .25 L
.78855 .25 L
.78856 .25 L
.78857 .25 L
.78857 .25 L
.78858 .25 L
.78858 .25 L
.78859 .25 L
.7886 .25 L
Mistroke
.7886 .25 L
.78861 .25 L
.78861 .25 L
.78862 .25 L
.78862 .25 L
.78863 .25 L
.78863 .25 L
.78864 .25 L
.78864 .25 L
.78865 .25 L
.78865 .25 L
.78866 .25 L
.78867 .25 L
.78867 .25 L
.78868 .25 L
.78869 .25 L
.78869 .25 L
.78869 .25 L
.7887 .25 L
.7887 .25 L
.78871 .25 L
.78871 .25 L
.78872 .25 L
.78873 .25 L
.78873 .25 L
.78874 .25 L
.78875 .25 L
.78875 .25 L
.78876 .25 L
.78876 .25 L
.78877 .25 L
.78878 .25 L
.78878 .25 L
.78879 .25 L
.78879 .25 L
.7888 .25 L
.78881 .25 L
.78881 .25 L
.78882 .25 L
.78882 .25 L
.78883 .25 L
.78884 .25 L
.78884 .25 L
.78885 .25 L
.78885 .25 L
.78886 .25 L
.78886 .25 L
.78887 .25 L
.78887 .25 L
.78888 .25 L
Mistroke
.78889 .25 L
.78889 .25 L
.7889 .25 L
.7889 .25 L
.78891 .25 L
.78892 .25 L
.78892 .25 L
.78893 .25 L
.78894 .25 L
.78894 .25 L
.78895 .25 L
.78896 .25 L
.78896 .25 L
.78897 .25 L
.78897 .25 L
.78898 .25 L
.78898 .25 L
.78899 .25 L
.78899 .25 L
.78899 .25 L
.789 .25 L
.789 .25 L
.78901 .25 L
.78901 .25 L
.78902 .25 L
.78902 .25 L
.78902 .25 L
.78903 .25 L
.78903 .25 L
.78903 .25 L
.78904 .25 L
.78905 .25 L
.78905 .25 L
.78906 .25 L
.78907 .25 L
.78907 .25 L
.78908 .25 L
.78909 .25 L
.78909 .25 L
.7891 .25 L
.7891 .25 L
.78911 .25 L
.78912 .25 L
.78912 .25 L
.78913 .25 L
.78913 .25 L
.78914 .25 L
.78915 .25 L
.78915 .25 L
.78916 .25 L
Mistroke
.78916 .25 L
.78917 .25 L
.78918 .25 L
.78918 .25 L
.78919 .25 L
.78919 .25 L
.7892 .25 L
.78921 .25 L
.78921 .25 L
.78922 .25 L
.78922 .25 L
.78923 .25 L
.78923 .25 L
.78924 .25 L
.78924 .25 L
.78925 .25 L
.78926 .25 L
.78926 .25 L
.78927 .25 L
.78928 .25 L
.78928 .25 L
.78929 .25 L
.78929 .25 L
.7893 .25 L
.78931 .25 L
.78931 .25 L
.78932 .25 L
.78933 .25 L
.78933 .25 L
.78934 .25 L
.78934 .25 L
.78935 .25 L
.78935 .25 L
.78936 .25 L
.78937 .25 L
.78937 .25 L
.78938 .25 L
.78938 .25 L
.78939 .25 L
.7894 .25 L
.7894 .25 L
.78941 .25 L
.78941 .25 L
.78942 .25 L
.78943 .25 L
.78943 .25 L
.78944 .25 L
.78944 .25 L
.78945 .25 L
.78945 .25 L
Mistroke
.78946 .25 L
.78946 .25 L
.78947 .25 L
.78947 .25 L
.78948 .25 L
.78948 .25 L
.78949 .25 L
.7895 .25 L
.7895 .25 L
.78951 .25 L
.78951 .25 L
.78952 .25 L
.78952 .25 L
.78953 .25 L
.78953 .25 L
.78954 .25 L
.78954 .25 L
.78955 .25 L
.78956 .25 L
.78956 .25 L
.78957 .25 L
.78957 .25 L
.78958 .25 L
.78959 .25 L
.78959 .25 L
.7896 .25 L
.7896 .25 L
.78961 .25 L
.78962 .25 L
.78962 .25 L
.78963 .25 L
.78964 .25 L
.78964 .25 L
.78965 .25 L
.78966 .25 L
.78966 .25 L
.78967 .25 L
.78967 .25 L
.78968 .25 L
.78968 .25 L
.78968 .25 L
.78969 .25 L
.7897 .25 L
.7897 .25 L
.78971 .25 L
.78972 .25 L
.78972 .25 L
.78973 .25 L
.78973 .25 L
.78974 .25 L
Mistroke
.78975 .25 L
.78975 .25 L
.78976 .25 L
.78977 .25 L
.78977 .25 L
.78978 .25 L
.78979 .25 L
.78979 .25 L
.7898 .25 L
.7898 .25 L
.78981 .25 L
.78981 .25 L
.78981 .25 L
.78982 .25 L
.78982 .25 L
.78983 .25 L
.78983 .25 L
.78984 .25 L
.78984 .25 L
.78984 .25 L
.78985 .25 L
.78985 .25 L
.78985 .25 L
.78986 .25 L
.78986 .25 L
.78987 .25 L
.78988 .25 L
.78989 .25 L
.78989 .25 L
.7899 .25 L
.7899 .25 L
.78991 .25 L
.78992 .25 L
.78992 .25 L
.78993 .25 L
.78994 .25 L
.78994 .25 L
.78995 .25 L
.78995 .25 L
.78996 .25 L
.78996 .25 L
.78997 .25 L
.78998 .25 L
.78998 .25 L
.78999 .25 L
.78999 .25 L
.79 .25 L
.79001 .25 L
.79001 .25 L
.79002 .25 L
Mistroke
.79002 .25 L
.79003 .25 L
.79004 .25 L
.79004 .25 L
.79005 .25 L
.79005 .25 L
.79006 .25 L
.79006 .25 L
.79007 .25 L
.79007 .25 L
.79008 .25 L
.79009 .25 L
.79009 .25 L
.7901 .25 L
.79011 .25 L
.79011 .25 L
.79012 .25 L
.79012 .25 L
.79013 .25 L
.79014 .25 L
.79014 .25 L
.79015 .25 L
.79016 .25 L
.79016 .25 L
.79016 .25 L
.79017 .25 L
.79018 .25 L
.79018 .25 L
.79019 .25 L
.7902 .25 L
.7902 .25 L
.79021 .25 L
.79021 .25 L
.79022 .25 L
.79023 .25 L
.79023 .25 L
.79024 .25 L
.79024 .25 L
.79025 .25 L
.79026 .25 L
.79026 .25 L
.79026 .25 L
.79027 .25 L
.79028 .25 L
.79028 .25 L
.79029 .25 L
.79029 .25 L
.7903 .25 L
.7903 .25 L
.79031 .25 L
Mistroke
.79031 .25 L
.79032 .25 L
.79033 .25 L
.79033 .25 L
.79034 .25 L
.79034 .25 L
.79035 .25 L
.79035 .25 L
.79036 .25 L
.79036 .25 L
.79037 .25 L
.79038 .25 L
.79038 .25 L
.79039 .25 L
.79039 .25 L
.7904 .25 L
.7904 .25 L
.79041 .25 L
.79042 .25 L
.79042 .25 L
.79043 .25 L
.79044 .25 L
.79044 .25 L
.79045 .25 L
.79045 .25 L
.79046 .25 L
.79047 .25 L
.79047 .25 L
.79048 .25 L
.79049 .25 L
.79049 .25 L
.7905 .25 L
.7905 .25 L
.7905 .25 L
.79051 .25 L
.79051 .25 L
.79052 .25 L
.79053 .25 L
.79053 .25 L
.79054 .25 L
.79055 .25 L
.79055 .25 L
.79056 .25 L
.79056 .25 L
.79057 .25 L
.79058 .25 L
.79058 .25 L
.79059 .25 L
.7906 .25 L
.7906 .25 L
Mistroke
.79061 .25 L
.79062 .25 L
.79062 .25 L
.79062 .25 L
.79063 .25 L
.79063 .25 L
.79064 .25 L
.79064 .25 L
.79065 .25 L
.79065 .25 L
.79066 .25 L
.79066 .25 L
.79066 .25 L
.79067 .25 L
.79067 .25 L
.79067 .25 L
.79068 .25 L
.79068 .25 L
.79069 .25 L
.7907 .25 L
.7907 .25 L
.79071 .25 L
.79072 .25 L
.79072 .25 L
.79073 .25 L
.79073 .25 L
.79074 .25 L
.79075 .25 L
.79075 .25 L
.79076 .25 L
.79077 .25 L
.79077 .25 L
.79078 .25 L
.79078 .25 L
.79079 .25 L
.79079 .25 L
.7908 .25 L
.79081 .25 L
.79081 .25 L
.79082 .25 L
.79082 .25 L
.79083 .25 L
.79083 .25 L
.79084 .25 L
.79085 .25 L
.79085 .25 L
.79086 .25 L
.79087 .25 L
.79087 .25 L
.79088 .25 L
Mistroke
.79088 .25 L
.79088 .25 L
.79089 .25 L
.7909 .25 L
.7909 .25 L
.79091 .25 L
.79092 .25 L
.79092 .25 L
.79093 .25 L
.79094 .25 L
.79094 .25 L
.79095 .25 L
.79095 .25 L
.79096 .25 L
.79097 .25 L
.79097 .25 L
.79098 .25 L
.79098 .25 L
.79099 .25 L
.791 .25 L
.791 .25 L
.79101 .25 L
.79101 .25 L
.79102 .25 L
.79103 .25 L
.79103 .25 L
.79104 .25 L
.79104 .25 L
.79105 .25 L
.79106 .25 L
.79106 .25 L
.79107 .25 L
.79107 .25 L
.79108 .25 L
.79108 .25 L
.79109 .25 L
.79109 .25 L
.7911 .25 L
.79111 .25 L
.79111 .25 L
.79111 .25 L
.79112 .25 L
.79113 .25 L
.79113 .25 L
.79114 .25 L
.79114 .25 L
.79115 .25 L
.79116 .25 L
.79116 .25 L
.79116 .25 L
Mistroke
.79117 .25 L
.79118 .25 L
.79118 .25 L
.79119 .25 L
.79119 .25 L
.7912 .25 L
.7912 .25 L
.79121 .25 L
.79122 .25 L
.79122 .25 L
.79123 .25 L
.79123 .25 L
.79124 .25 L
.79125 .25 L
.79125 .25 L
.79126 .25 L
.79127 .25 L
.79127 .25 L
.79128 .25 L
.79128 .25 L
.79129 .25 L
.7913 .25 L
.7913 .25 L
.79131 .25 L
.79132 .25 L
.79132 .25 L
.79132 .25 L
.79133 .25 L
.79133 .25 L
.79134 .25 L
.79134 .25 L
.79135 .25 L
.79136 .25 L
.79136 .25 L
.79137 .25 L
.79138 .25 L
.79138 .25 L
.79139 .25 L
.79139 .25 L
.7914 .25 L
.79141 .25 L
.79141 .25 L
.79142 .25 L
.79143 .25 L
.79143 .25 L
.79144 .25 L
.79144 .25 L
.79145 .25 L
.79145 .25 L
.79146 .25 L
Mistroke
.79146 .25 L
.79146 .25 L
.79147 .25 L
.79148 .25 L
.79148 .25 L
.79148 .25 L
.79149 .25 L
.79149 .25 L
.79149 .25 L
.7915 .25 L
.7915 .25 L
.79151 .25 L
.79151 .25 L
.79152 .25 L
.79153 .25 L
.79153 .25 L
.79154 .25 L
.79155 .25 L
.79155 .25 L
.79156 .25 L
.79156 .25 L
.79157 .25 L
.79158 .25 L
.79158 .25 L
.79159 .25 L
.79159 .25 L
.7916 .25 L
.79161 .25 L
.79161 .25 L
.79162 .25 L
.79162 .25 L
.79163 .25 L
.79163 .25 L
.79164 .25 L
.79165 .25 L
.79165 .25 L
.79166 .25 L
.79166 .25 L
.79167 .25 L
.79168 .25 L
.79168 .25 L
.79169 .25 L
.79169 .25 L
.7917 .25 L
.7917 .25 L
.79171 .25 L
.79171 .25 L
.79172 .25 L
.79173 .25 L
.79173 .25 L
Mistroke
.79174 .25 L
.79175 .25 L
.79175 .25 L
.79176 .25 L
.79177 .25 L
.79177 .25 L
.79178 .25 L
.79178 .25 L
.79179 .25 L
.7918 .25 L
.7918 .25 L
.79181 .25 L
.79181 .25 L
.79182 .25 L
.79183 .25 L
.79183 .25 L
.79184 .25 L
.79184 .25 L
.79185 .25 L
.79186 .25 L
.79186 .25 L
.79187 .25 L
.79187 .25 L
.79188 .25 L
.79188 .25 L
.79189 .25 L
.7919 .25 L
.7919 .25 L
.79191 .25 L
.79191 .25 L
.79192 .25 L
.79192 .25 L
.79193 .25 L
.79194 .25 L
.79194 .25 L
.79195 .25 L
.79196 .25 L
.79196 .25 L
.79197 .25 L
.79197 .25 L
.79198 .25 L
.79199 .25 L
.79199 .25 L
.792 .25 L
.79201 .25 L
.79201 .25 L
.79201 .25 L
.79202 .25 L
.79203 .25 L
.79203 .25 L
Mistroke
.79204 .25 L
.79205 .25 L
.79205 .25 L
.79206 .25 L
.79206 .25 L
.79207 .25 L
.79207 .25 L
.79208 .25 L
.79209 .25 L
.79209 .25 L
.7921 .25 L
.79211 .25 L
.79211 .25 L
.79211 .25 L
.79212 .25 L
.79213 .25 L
.79213 .25 L
.79214 .25 L
.79214 .25 L
.79215 .25 L
.79215 .25 L
.79216 .25 L
.79216 .25 L
.79217 .25 L
.79218 .25 L
.79218 .25 L
.79219 .25 L
.79219 .25 L
.7922 .25 L
.7922 .25 L
.7922 .25 L
.79221 .25 L
.79222 .25 L
.79222 .25 L
.79223 .25 L
.79224 .25 L
.79224 .25 L
.79225 .25 L
.79225 .25 L
.79226 .25 L
.79227 .25 L
.79227 .25 L
.79228 .25 L
.79229 .25 L
.79229 .25 L
.7923 .25 L
.7923 .25 L
.79231 .25 L
.79232 .25 L
.79232 .25 L
Mistroke
.79233 .25 L
.79234 .25 L
.79234 .25 L
.79235 .25 L
.79235 .25 L
.79235 .25 L
.79236 .25 L
.79236 .25 L
.79237 .25 L
.79238 .25 L
.79238 .25 L
.79239 .25 L
.7924 .25 L
.7924 .25 L
.79241 .25 L
.79241 .25 L
.79242 .25 L
.79243 .25 L
.79243 .25 L
.79244 .25 L
.79245 .25 L
.79245 .25 L
.79246 .25 L
.79247 .25 L
.79247 .25 L
.79247 .25 L
.79248 .25 L
.79248 .25 L
.79249 .25 L
.79249 .25 L
.7925 .25 L
.7925 .25 L
.79251 .25 L
.79251 .25 L
.79251 .25 L
.79252 .25 L
.79252 .25 L
.79252 .25 L
.79253 .25 L
.79253 .25 L
.79254 .25 L
.79255 .25 L
.79255 .25 L
.79256 .25 L
.79257 .25 L
.79257 .25 L
.79258 .25 L
.79258 .25 L
.79259 .25 L
.7926 .25 L
Mistroke
.7926 .25 L
.79261 .25 L
.79262 .25 L
.79262 .25 L
.79263 .25 L
.79263 .25 L
.79264 .25 L
.79264 .25 L
.79265 .25 L
.79266 .25 L
.79266 .25 L
.79267 .25 L
.79267 .25 L
.79268 .25 L
.79268 .25 L
.79269 .25 L
.7927 .25 L
.7927 .25 L
.79271 .25 L
.79272 .25 L
.79272 .25 L
.79273 .25 L
.79273 .25 L
.79273 .25 L
.79274 .25 L
.79275 .25 L
.79275 .25 L
.79276 .25 L
.79277 .25 L
.79277 .25 L
.79278 .25 L
.79279 .25 L
.79279 .25 L
.7928 .25 L
.7928 .25 L
.79281 .25 L
.79282 .25 L
.79282 .25 L
.79283 .25 L
.79284 .25 L
.79284 .25 L
.79285 .25 L
.79285 .25 L
.79286 .25 L
.79286 .25 L
.79287 .25 L
.79288 .25 L
.79288 .25 L
.79289 .25 L
.79289 .25 L
Mistroke
.7929 .25 L
.79291 .25 L
.79291 .25 L
.79292 .25 L
.79292 .25 L
.79293 .25 L
.79293 .25 L
.79294 .25 L
.79294 .25 L
.79295 .25 L
.79296 .25 L
.79296 .25 L
.79296 .25 L
.79297 .25 L
.79298 .25 L
.79298 .25 L
.79299 .25 L
.79299 .25 L
.793 .25 L
.79301 .25 L
.79301 .25 L
.79301 .25 L
.79302 .25 L
.79303 .25 L
.79303 .25 L
.79304 .25 L
.79304 .25 L
.79305 .25 L
.79306 .25 L
.79306 .25 L
.79307 .25 L
.79307 .25 L
.79308 .25 L
.79308 .25 L
.79309 .25 L
.7931 .25 L
.7931 .25 L
.79311 .25 L
.79312 .25 L
.79312 .25 L
.79313 .25 L
.79313 .25 L
.79314 .25 L
.79315 .25 L
.79315 .25 L
.79316 .25 L
.79317 .25 L
.79317 .25 L
.79317 .25 L
.79318 .25 L
Mistroke
.79318 .25 L
.79319 .25 L
.79319 .25 L
.7932 .25 L
.79321 .25 L
.79321 .25 L
.79322 .25 L
.79323 .25 L
.79323 .25 L
.79324 .25 L
.79324 .25 L
.79325 .25 L
.79326 .25 L
.79326 .25 L
.79327 .25 L
.79328 .25 L
.79328 .25 L
.79329 .25 L
.79329 .25 L
.7933 .25 L
.7933 .25 L
.79331 .25 L
.79331 .25 L
.79332 .25 L
.79332 .25 L
.79333 .25 L
.79333 .25 L
.79333 .25 L
.79334 .25 L
.79334 .25 L
.79334 .25 L
.79335 .25 L
.79335 .25 L
.79336 .25 L
.79336 .25 L
.79337 .25 L
.79338 .25 L
.79338 .25 L
.79339 .25 L
.7934 .25 L
.7934 .25 L
.79341 .25 L
.79341 .25 L
.79342 .25 L
.79343 .25 L
.79343 .25 L
.79344 .25 L
.79345 .25 L
.79345 .25 L
.79346 .25 L
Mistroke
.79346 .25 L
.79347 .25 L
.79347 .25 L
.79348 .25 L
.79349 .25 L
.79349 .25 L
.7935 .25 L
.7935 .25 L
.79351 .25 L
.79351 .25 L
.79352 .25 L
.79353 .25 L
.79353 .25 L
.79354 .25 L
.79354 .25 L
.79355 .25 L
.79356 .25 L
.79356 .25 L
.79356 .25 L
.79357 .25 L
.79358 .25 L
.79359 .25 L
.79359 .25 L
.7936 .25 L
.7936 .25 L
.79361 .25 L
.79362 .25 L
.79362 .25 L
.79363 .25 L
.79364 .25 L
.79364 .25 L
.79365 .25 L
.79366 .25 L
.79366 .25 L
.79366 .25 L
.79367 .25 L
.79368 .25 L
.79368 .25 L
.79369 .25 L
.79369 .25 L
.7937 .25 L
.79371 .25 L
.79371 .25 L
.79372 .25 L
.79372 .25 L
.79373 .25 L
.79374 .25 L
.79374 .25 L
.79375 .25 L
.79375 .25 L
Mistroke
.79376 .25 L
.79376 .25 L
.79377 .25 L
.79377 .25 L
.79378 .25 L
.79378 .25 L
.79379 .25 L
.79379 .25 L
.7938 .25 L
.79381 .25 L
.79381 .25 L
.79382 .25 L
.79382 .25 L
.79383 .25 L
.79383 .25 L
.79384 .25 L
.79385 .25 L
.79385 .25 L
.79385 .25 L
.79386 .25 L
.79387 .25 L
.79387 .25 L
.79388 .25 L
.79388 .25 L
.79389 .25 L
.7939 .25 L
.7939 .25 L
.79391 .25 L
.79391 .25 L
.79392 .25 L
.79393 .25 L
.79393 .25 L
.79394 .25 L
.79394 .25 L
.79395 .25 L
.79396 .25 L
.79396 .25 L
.79397 .25 L
.79398 .25 L
.79398 .25 L
.79399 .25 L
.79399 .25 L
.794 .25 L
.794 .25 L
.794 .25 L
.79401 .25 L
.79402 .25 L
.79402 .25 L
.79403 .25 L
.79404 .25 L
Mistroke
.79404 .25 L
.79405 .25 L
.79406 .25 L
.79406 .25 L
.79407 .25 L
.79408 .25 L
.79408 .25 L
.79409 .25 L
.79409 .25 L
.7941 .25 L
.79411 .25 L
.79411 .25 L
.79412 .25 L
.79412 .25 L
.79413 .25 L
.79413 .25 L
.79414 .25 L
.79414 .25 L
.79414 .25 L
.79415 .25 L
.79415 .25 L
.79416 .25 L
.79416 .25 L
.79417 .25 L
.79417 .25 L
.79417 .25 L
.79418 .25 L
.79418 .25 L
.79419 .25 L
.79419 .25 L
.7942 .25 L
.79421 .25 L
.79421 .25 L
.79422 .25 L
.79423 .25 L
.79423 .25 L
.79424 .25 L
.79424 .25 L
.79425 .25 L
.79426 .25 L
.79426 .25 L
.79427 .25 L
.79428 .25 L
.79428 .25 L
.79428 .25 L
.79429 .25 L
.7943 .25 L
.7943 .25 L
.79431 .25 L
.79432 .25 L
Mistroke
.79432 .25 L
.79433 .25 L
.79433 .25 L
.79434 .25 L
.79434 .25 L
.79435 .25 L
.79436 .25 L
.79436 .25 L
.79437 .25 L
.79438 .25 L
.79438 .25 L
.79438 .25 L
.79439 .25 L
.7944 .25 L
.7944 .25 L
.79441 .25 L
.79442 .25 L
.79442 .25 L
.79443 .25 L
.79443 .25 L
.79444 .25 L
.79445 .25 L
.79445 .25 L
.79446 .25 L
.79447 .25 L
.79447 .25 L
.79448 .25 L
.79448 .25 L
.79449 .25 L
.79449 .25 L
.7945 .25 L
.79451 .25 L
.79451 .25 L
.79452 .25 L
.79452 .25 L
.79453 .25 L
.79454 .25 L
.79454 .25 L
.79455 .25 L
.79455 .25 L
.79456 .25 L
.79457 .25 L
.79457 .25 L
.79458 .25 L
.79458 .25 L
.79458 .25 L
.79459 .25 L
.7946 .25 L
.7946 .25 L
.79461 .25 L
Mistroke
.79461 .25 L
.79462 .25 L
.79462 .25 L
.79463 .25 L
.79464 .25 L
.79464 .25 L
.79465 .25 L
.79465 .25 L
.79466 .25 L
.79466 .25 L
.79467 .25 L
.79467 .25 L
.79468 .25 L
.79468 .25 L
.79469 .25 L
.7947 .25 L
.7947 .25 L
.79471 .25 L
.79471 .25 L
.79472 .25 L
.79473 .25 L
.79473 .25 L
.79474 .25 L
.79474 .25 L
.79475 .25 L
.79476 .25 L
.79476 .25 L
.79477 .25 L
.79477 .25 L
.79478 .25 L
.79479 .25 L
.79479 .25 L
.7948 .25 L
.79481 .25 L
.79481 .25 L
.79482 .25 L
.79482 .25 L
.79482 .25 L
.79483 .25 L
.79484 .25 L
.79484 .25 L
.79485 .25 L
.79485 .25 L
.79486 .25 L
.79487 .25 L
.79487 .25 L
.79488 .25 L
.79489 .25 L
.79489 .25 L
.7949 .25 L
Mistroke
.7949 .25 L
.79491 .25 L
.79492 .25 L
.79492 .25 L
.79493 .25 L
.79494 .25 L
.79494 .25 L
.79495 .25 L
.79495 .25 L
.79496 .25 L
.79496 .25 L
.79496 .25 L
.79497 .25 L
.79497 .25 L
.79498 .25 L
.79498 .25 L
.79498 .25 L
.79499 .25 L
.79499 .25 L
.795 .25 L
.795 .25 L
.795 .25 L
.79501 .25 L
.79502 .25 L
.79502 .25 L
.79503 .25 L
.79504 .25 L
.79504 .25 L
.79505 .25 L
.79505 .25 L
.79506 .25 L
.79507 .25 L
.79507 .25 L
.79508 .25 L
.79509 .25 L
.79509 .25 L
.7951 .25 L
.7951 .25 L
.79511 .25 L
.79511 .25 L
.79512 .25 L
.79513 .25 L
.79513 .25 L
.79514 .25 L
.79515 .25 L
.79515 .25 L
.79516 .25 L
.79516 .25 L
.79517 .25 L
.79517 .25 L
Mistroke
.79518 .25 L
.79519 .25 L
.79519 .25 L
.7952 .25 L
.7952 .25 L
.79521 .25 L
.79521 .25 L
.79522 .25 L
.79523 .25 L
.79523 .25 L
.79524 .25 L
.79524 .25 L
.79525 .25 L
.79526 .25 L
.79526 .25 L
.79527 .25 L
.79528 .25 L
.79528 .25 L
.79529 .25 L
.7953 .25 L
.7953 .25 L
.79531 .25 L
.79531 .25 L
.79532 .25 L
.79532 .25 L
.79533 .25 L
.79534 .25 L
.79534 .25 L
.79535 .25 L
.79535 .25 L
.79536 .25 L
.79536 .25 L
.79537 .25 L
.79538 .25 L
.79538 .25 L
.79539 .25 L
.79539 .25 L
.7954 .25 L
.7954 .25 L
.79541 .25 L
.79541 .25 L
.79542 .25 L
.79543 .25 L
.79543 .25 L
.79544 .25 L
.79545 .25 L
.79545 .25 L
.79546 .25 L
.79547 .25 L
.79547 .25 L
Mistroke
.79548 .25 L
.79549 .25 L
.79549 .25 L
.7955 .25 L
.7955 .25 L
.79551 .25 L
.79551 .25 L
.79552 .25 L
.79553 .25 L
.79553 .25 L
.79554 .25 L
.79554 .25 L
.79555 .25 L
.79556 .25 L
.79556 .25 L
.79557 .25 L
.79557 .25 L
.79558 .25 L
.79559 .25 L
.79559 .25 L
.7956 .25 L
.7956 .25 L
.79561 .25 L
.79561 .25 L
.79562 .25 L
.79562 .25 L
.79563 .25 L
.79563 .25 L
.79564 .25 L
.79564 .25 L
.79565 .25 L
.79566 .25 L
.79566 .25 L
.79567 .25 L
.79567 .25 L
.79568 .25 L
.79568 .25 L
.79569 .25 L
.7957 .25 L
.7957 .25 L
.7957 .25 L
.79571 .25 L
.79572 .25 L
.79572 .25 L
.79573 .25 L
.79573 .25 L
.79574 .25 L
.79575 .25 L
.79575 .25 L
.79576 .25 L
Mistroke
.79576 .25 L
.79577 .25 L
.79578 .25 L
.79578 .25 L
.79579 .25 L
.79579 .25 L
.7958 .25 L
.79581 .25 L
.79581 .25 L
.79582 .25 L
.79583 .25 L
.79583 .25 L
.79584 .25 L
.79584 .25 L
.79585 .25 L
.79585 .25 L
.79585 .25 L
.79586 .25 L
.79587 .25 L
.79587 .25 L
.79588 .25 L
.79589 .25 L
.79589 .25 L
.7959 .25 L
.79591 .25 L
.79591 .25 L
.79592 .25 L
.79593 .25 L
.79593 .25 L
.79594 .25 L
.79594 .25 L
.79595 .25 L
.79596 .25 L
.79596 .25 L
.79597 .25 L
.79597 .25 L
.79598 .25 L
.79598 .25 L
.79599 .25 L
.79599 .25 L
.79599 .25 L
.796 .25 L
.796 .25 L
.79601 .25 L
.79601 .25 L
.79602 .25 L
.79602 .25 L
.79602 .25 L
.79603 .25 L
.79603 .25 L
Mistroke
.79604 .25 L
.79604 .25 L
.79605 .25 L
.79606 .25 L
.79606 .25 L
.79607 .25 L
.79608 .25 L
.79608 .25 L
.79609 .25 L
.79609 .25 L
.7961 .25 L
.79611 .25 L
.79611 .25 L
.79612 .25 L
.79613 .25 L
.79613 .25 L
.79613 .25 L
.79614 .25 L
.79615 .25 L
.79615 .25 L
.79616 .25 L
.79617 .25 L
.79617 .25 L
.79618 .25 L
.79618 .25 L
.79619 .25 L
.79619 .25 L
.7962 .25 L
.79621 .25 L
.79621 .25 L
.79622 .25 L
.79623 .25 L
.79623 .25 L
.79623 .25 L
.79624 .25 L
.79625 .25 L
.79625 .25 L
.79626 .25 L
.79627 .25 L
.79627 .25 L
.79628 .25 L
.79628 .25 L
.79629 .25 L
.7963 .25 L
.7963 .25 L
.79631 .25 L
.79632 .25 L
.79632 .25 L
.79633 .25 L
.79633 .25 L
Mistroke
.79634 .25 L
.79634 .25 L
.79635 .25 L
.79636 .25 L
.79636 .25 L
.79637 .25 L
.79637 .25 L
.79638 .25 L
.79639 .25 L
.79639 .25 L
.7964 .25 L
.7964 .25 L
.79641 .25 L
.79642 .25 L
.79642 .25 L
.79643 .25 L
.79643 .25 L
.79644 .25 L
.79644 .25 L
.79645 .25 L
.79645 .25 L
.79646 .25 L
.79646 .25 L
.79647 .25 L
.79647 .25 L
.79648 .25 L
.79649 .25 L
.79649 .25 L
.7965 .25 L
.79651 .25 L
.79651 .25 L
.79651 .25 L
.79652 .25 L
.79652 .25 L
.79653 .25 L
.79653 .25 L
.79654 .25 L
.79655 .25 L
.79655 .25 L
.79656 .25 L
.79656 .25 L
.79657 .25 L
.79658 .25 L
.79658 .25 L
.79659 .25 L
.79659 .25 L
.7966 .25 L
.79661 .25 L
.79661 .25 L
.79662 .25 L
Mistroke
.79662 .25 L
.79663 .25 L
.79664 .25 L
.79664 .25 L
.79665 .25 L
.79666 .25 L
.79666 .25 L
.79667 .25 L
.79667 .25 L
.79668 .25 L
.79668 .25 L
.79669 .25 L
.79669 .25 L
.7967 .25 L
.79671 .25 L
.79671 .25 L
.79672 .25 L
.79672 .25 L
.79673 .25 L
.79674 .25 L
.79674 .25 L
.79675 .25 L
.79676 .25 L
.79676 .25 L
.79677 .25 L
.79678 .25 L
.79678 .25 L
.79679 .25 L
.79679 .25 L
.7968 .25 L
.7968 .25 L
.79681 .25 L
.79681 .25 L
.79681 .25 L
.79682 .25 L
.79682 .25 L
.79683 .25 L
.79683 .25 L
.79684 .25 L
.79684 .25 L
.79684 .25 L
.79685 .25 L
.79685 .25 L
.79685 .25 L
.79686 .25 L
.79687 .25 L
.79687 .25 L
.79688 .25 L
.79689 .25 L
.79689 .25 L
Mistroke
.7969 .25 L
.79691 .25 L
.79691 .25 L
.79692 .25 L
.79692 .25 L
.79693 .25 L
.79694 .25 L
.79694 .25 L
.79695 .25 L
.79695 .25 L
.79696 .25 L
.79696 .25 L
.79697 .25 L
.79698 .25 L
.79698 .25 L
.79699 .25 L
.797 .25 L
.797 .25 L
.79701 .25 L
.79701 .25 L
.79702 .25 L
.79702 .25 L
.79703 .25 L
.79704 .25 L
.79704 .25 L
.79705 .25 L
.79705 .25 L
.79706 .25 L
.79706 .25 L
.79707 .25 L
.79708 .25 L
.79708 .25 L
.79709 .25 L
.7971 .25 L
.7971 .25 L
.79711 .25 L
.79711 .25 L
.79712 .25 L
.79713 .25 L
.79713 .25 L
.79714 .25 L
.79715 .25 L
.79715 .25 L
.79716 .25 L
.79716 .25 L
.79717 .25 L
.79717 .25 L
.79718 .25 L
.79719 .25 L
.79719 .25 L
Mistroke
.7972 .25 L
.7972 .25 L
.79721 .25 L
.79722 .25 L
.79722 .25 L
.79723 .25 L
.79723 .25 L
.79724 .25 L
.79725 .25 L
.79725 .25 L
.79726 .25 L
.79726 .25 L
.79727 .25 L
.79727 .25 L
.79728 .25 L
.79728 .25 L
.79729 .25 L
.79729 .25 L
.7973 .25 L
.7973 .25 L
.79731 .25 L
.79732 .25 L
.79732 .25 L
.79733 .25 L
.79733 .25 L
.79734 .25 L
.79734 .25 L
.79735 .25 L
.79735 .25 L
.79736 .25 L
.79736 .25 L
.79737 .25 L
.79738 .25 L
.79738 .25 L
.79739 .25 L
.79739 .25 L
.7974 .25 L
.79741 .25 L
.79741 .25 L
.79742 .25 L
.79742 .25 L
.79743 .25 L
.79744 .25 L
.79744 .25 L
.79745 .25 L
.79746 .25 L
.79746 .25 L
.79747 .25 L
.79747 .25 L
.79748 .25 L
Mistroke
.79749 .25 L
.79749 .25 L
.7975 .25 L
.7975 .25 L
.7975 .25 L
.79751 .25 L
.79752 .25 L
.79752 .25 L
.79753 .25 L
.79754 .25 L
.79754 .25 L
.79755 .25 L
.79755 .25 L
.79756 .25 L
.79757 .25 L
.79757 .25 L
.79758 .25 L
.79759 .25 L
.79759 .25 L
.7976 .25 L
.79761 .25 L
.79761 .25 L
.79762 .25 L
.79762 .25 L
.79763 .25 L
.79763 .25 L
.79763 .25 L
.79764 .25 L
.79764 .25 L
.79765 .25 L
.79765 .25 L
.79766 .25 L
.79766 .25 L
.79766 .25 L
.79767 .25 L
.79767 .25 L
.79767 .25 L
.79768 .25 L
.79768 .25 L
.79769 .25 L
.7977 .25 L
.7977 .25 L
.79771 .25 L
.79772 .25 L
.79772 .25 L
.79773 .25 L
.79774 .25 L
.79774 .25 L
.79775 .25 L
.79775 .25 L
Mistroke
.79776 .25 L
.79777 .25 L
.79777 .25 L
.79778 .25 L
.79778 .25 L
.79779 .25 L
.7978 .25 L
.7978 .25 L
.79781 .25 L
.79781 .25 L
.79782 .25 L
.79783 .25 L
.79783 .25 L
.79784 .25 L
.79784 .25 L
.79785 .25 L
.79785 .25 L
.79786 .25 L
.79787 .25 L
.79787 .25 L
.79788 .25 L
.79788 .25 L
.79789 .25 L
.79789 .25 L
.7979 .25 L
.79791 .25 L
.79791 .25 L
.79792 .25 L
.79793 .25 L
.79793 .25 L
.79794 .25 L
.79794 .25 L
.79795 .25 L
.79796 .25 L
.79796 .25 L
.79797 .25 L
.79798 .25 L
.79798 .25 L
.79798 .25 L
.79799 .25 L
.798 .25 L
.798 .25 L
.79801 .25 L
.79802 .25 L
.79802 .25 L
.79803 .25 L
.79803 .25 L
.79804 .25 L
.79804 .25 L
.79805 .25 L
Mistroke
.79806 .25 L
.79806 .25 L
.79807 .25 L
.79808 .25 L
.79808 .25 L
.79808 .25 L
.79809 .25 L
.7981 .25 L
.7981 .25 L
.79811 .25 L
.79811 .25 L
.79812 .25 L
.79812 .25 L
.79813 .25 L
.79813 .25 L
.79814 .25 L
.79815 .25 L
.79815 .25 L
.79816 .25 L
.79816 .25 L
.79817 .25 L
.79817 .25 L
.79817 .25 L
.79818 .25 L
.79819 .25 L
.79819 .25 L
.7982 .25 L
.79821 .25 L
.79821 .25 L
.79822 .25 L
.79822 .25 L
.79823 .25 L
.79824 .25 L
.79824 .25 L
.79825 .25 L
.79825 .25 L
.79826 .25 L
.79827 .25 L
.79827 .25 L
.79828 .25 L
.79829 .25 L
.79829 .25 L
.7983 .25 L
.79831 .25 L
.79831 .25 L
.79832 .25 L
.79832 .25 L
.79832 .25 L
.79833 .25 L
.79833 .25 L
Mistroke
.79834 .25 L
.79835 .25 L
.79835 .25 L
.79836 .25 L
.79837 .25 L
.79837 .25 L
.79838 .25 L
.79838 .25 L
.79839 .25 L
.7984 .25 L
.7984 .25 L
.79841 .25 L
.79842 .25 L
.79842 .25 L
.79843 .25 L
.79844 .25 L
.79844 .25 L
.79844 .25 L
.79845 .25 L
.79845 .25 L
.79846 .25 L
.79846 .25 L
.79846 .25 L
.79847 .25 L
.79848 .25 L
.79848 .25 L
.79848 .25 L
.79849 .25 L
.79849 .25 L
.79849 .25 L
.7985 .25 L
.7985 .25 L
.79851 .25 L
.79851 .25 L
.79852 .25 L
.79853 .25 L
.79853 .25 L
.79854 .25 L
.79855 .25 L
.79855 .25 L
.79856 .25 L
.79856 .25 L
.79857 .25 L
.79858 .25 L
.79858 .25 L
.79859 .25 L
.7986 .25 L
.7986 .25 L
.79861 .25 L
.79861 .25 L
Mistroke
.79862 .25 L
.79862 .25 L
.79863 .25 L
.79864 .25 L
.79864 .25 L
.79865 .25 L
.79865 .25 L
.79866 .25 L
.79867 .25 L
.79867 .25 L
.79868 .25 L
.79868 .25 L
.79869 .25 L
.7987 .25 L
.7987 .25 L
.7987 .25 L
.79871 .25 L
.79872 .25 L
.79872 .25 L
.79873 .25 L
.79874 .25 L
.79874 .25 L
.79875 .25 L
.79875 .25 L
.79876 .25 L
.79877 .25 L
.79877 .25 L
.79878 .25 L
.79879 .25 L
.79879 .25 L
.7988 .25 L
.7988 .25 L
.79881 .25 L
.79881 .25 L
.79882 .25 L
.79883 .25 L
.79883 .25 L
.79884 .25 L
.79885 .25 L
.79885 .25 L
.79886 .25 L
.79886 .25 L
.79887 .25 L
.79887 .25 L
.79888 .25 L
.79889 .25 L
.79889 .25 L
.7989 .25 L
.7989 .25 L
.79891 .25 L
Mistroke
.79891 .25 L
.79892 .25 L
.79893 .25 L
.79893 .25 L
.79893 .25 L
.79894 .25 L
.79895 .25 L
.79895 .25 L
.79896 .25 L
.79896 .25 L
.79897 .25 L
.79898 .25 L
.79898 .25 L
.79898 .25 L
.79899 .25 L
.79899 .25 L
.799 .25 L
.799 .25 L
.79901 .25 L
.79902 .25 L
.79902 .25 L
.79903 .25 L
.79904 .25 L
.79904 .25 L
.79905 .25 L
.79905 .25 L
.79906 .25 L
.79907 .25 L
.79907 .25 L
.79908 .25 L
.79908 .25 L
.79909 .25 L
.7991 .25 L
.7991 .25 L
.79911 .25 L
.79912 .25 L
.79912 .25 L
.79913 .25 L
.79914 .25 L
.79914 .25 L
.79914 .25 L
.79915 .25 L
.79915 .25 L
.79916 .25 L
.79916 .25 L
.79917 .25 L
.79918 .25 L
.79918 .25 L
.79919 .25 L
.79919 .25 L
Mistroke
.7992 .25 L
.79921 .25 L
.79921 .25 L
.79922 .25 L
.79923 .25 L
.79923 .25 L
.79924 .25 L
.79925 .25 L
.79925 .25 L
.79926 .25 L
.79926 .25 L
.79927 .25 L
.79927 .25 L
.79928 .25 L
.79928 .25 L
.79928 .25 L
.79929 .25 L
.79929 .25 L
.7993 .25 L
.7993 .25 L
.79931 .25 L
.79931 .25 L
.79931 .25 L
.79932 .25 L
.79932 .25 L
.79932 .25 L
.79933 .25 L
.79934 .25 L
.79934 .25 L
.79935 .25 L
.79936 .25 L
.79936 .25 L
.79937 .25 L
.79938 .25 L
.79938 .25 L
.79939 .25 L
.79939 .25 L
.7994 .25 L
.79941 .25 L
.79941 .25 L
.79942 .25 L
.79942 .25 L
.79943 .25 L
.79944 .25 L
.79944 .25 L
.79945 .25 L
.79945 .25 L
.79946 .25 L
.79947 .25 L
.79947 .25 L
Mistroke
.79948 .25 L
.79948 .25 L
.79949 .25 L
.7995 .25 L
.7995 .25 L
.79951 .25 L
.79951 .25 L
.79952 .25 L
.79952 .25 L
.79953 .25 L
.79953 .25 L
.79954 .25 L
.79955 .25 L
.79955 .25 L
.79956 .25 L
.79957 .25 L
.79957 .25 L
.79958 .25 L
.79958 .25 L
.79959 .25 L
.7996 .25 L
.7996 .25 L
.79961 .25 L
.79962 .25 L
.79962 .25 L
.79963 .25 L
.79963 .25 L
.79964 .25 L
.79964 .25 L
.79965 .25 L
.79966 .25 L
.79966 .25 L
.79967 .25 L
.79967 .25 L
.79968 .25 L
.79969 .25 L
.79969 .25 L
.7997 .25 L
.7997 .25 L
.79971 .25 L
.79972 .25 L
.79972 .25 L
.79973 .25 L
.79973 .25 L
.79974 .25 L
.79974 .25 L
.79975 .25 L
.79976 .25 L
.79976 .25 L
.79977 .25 L
Mistroke
.79977 .25 L
.79978 .25 L
.79979 .25 L
.79979 .25 L
.7998 .25 L
.79981 .25 L
.79981 .25 L
.79982 .25 L
.79983 .25 L
.79983 .25 L
.79983 .25 L
.79984 .25 L
.79985 .25 L
.79985 .25 L
.79986 .25 L
.79987 .25 L
.79987 .25 L
.79988 .25 L
.79988 .25 L
.79989 .25 L
.79989 .25 L
.7999 .25 L
.79991 .25 L
.79991 .25 L
.79992 .25 L
.79992 .25 L
.79993 .25 L
.79993 .25 L
.79994 .25 L
.79994 .25 L
.79995 .25 L
.79996 .25 L
.79996 .25 L
.79996 .25 L
.79997 .25 L
.79998 .25 L
.79998 .25 L
.79999 .25 L
.8 .25 L
.8 .25 L
.80001 .25 L
.80001 .25 L
.80002 .25 L
.80002 .25 L
.80002 .25 L
.80003 .25 L
.80004 .25 L
.80004 .25 L
.80005 .25 L
.80006 .25 L
Mistroke
.80006 .25 L
.80007 .25 L
.80007 .25 L
.80008 .25 L
.80009 .25 L
.80009 .25 L
.8001 .25 L
.8001 .25 L
.80011 .25 L
.80012 .25 L
.80012 .25 L
.80013 .25 L
.80014 .25 L
.80014 .25 L
.80015 .25 L
.80015 .25 L
.80016 .25 L
.80016 .25 L
.80017 .25 L
.80017 .25 L
.80018 .25 L
.80018 .25 L
.80019 .25 L
.8002 .25 L
.8002 .25 L
.80021 .25 L
.80021 .25 L
.80022 .25 L
.80023 .25 L
.80023 .25 L
.80024 .25 L
.80025 .25 L
.80025 .25 L
.80026 .25 L
.80027 .25 L
.80027 .25 L
.80028 .25 L
.80029 .25 L
.80029 .25 L
.80029 .25 L
.8003 .25 L
.8003 .25 L
.80031 .25 L
.80031 .25 L
.80031 .25 L
.80032 .25 L
.80032 .25 L
.80033 .25 L
.80033 .25 L
.80034 .25 L
Mistroke
.80034 .25 L
.80034 .25 L
.80035 .25 L
.80035 .25 L
.80036 .25 L
.80036 .25 L
.80037 .25 L
.80038 .25 L
.80038 .25 L
.80039 .25 L
.8004 .25 L
.8004 .25 L
.80041 .25 L
.80041 .25 L
.80042 .25 L
.80043 .25 L
.80043 .25 L
.80044 .25 L
.80045 .25 L
.80045 .25 L
.80045 .25 L
.80046 .25 L
.80047 .25 L
.80047 .25 L
.80048 .25 L
.80049 .25 L
.80049 .25 L
.8005 .25 L
.8005 .25 L
.80051 .25 L
.80052 .25 L
.80052 .25 L
.80053 .25 L
.80053 .25 L
.80054 .25 L
.80055 .25 L
.80055 .25 L
.80055 .25 L
.80056 .25 L
.80057 .25 L
.80057 .25 L
.80058 .25 L
.80059 .25 L
.80059 .25 L
.8006 .25 L
.8006 .25 L
.80061 .25 L
.80062 .25 L
.80062 .25 L
.80063 .25 L
Mistroke
.80064 .25 L
.80064 .25 L
.80065 .25 L
.80065 .25 L
.80066 .25 L
.80066 .25 L
.80067 .25 L
.80068 .25 L
.80068 .25 L
.80069 .25 L
.8007 .25 L
.8007 .25 L
.80071 .25 L
.80071 .25 L
.80072 .25 L
.80072 .25 L
.80073 .25 L
.80074 .25 L
.80074 .25 L
.80075 .25 L
.80075 .25 L
.80076 .25 L
.80076 .25 L
.80077 .25 L
.80078 .25 L
.80078 .25 L
.80078 .25 L
.80079 .25 L
.8008 .25 L
.8008 .25 L
.80081 .25 L
.80081 .25 L
.80082 .25 L
.80083 .25 L
.80083 .25 L
.80083 .25 L
.80084 .25 L
.80084 .25 L
.80085 .25 L
.80085 .25 L
.80086 .25 L
.80087 .25 L
.80087 .25 L
.80088 .25 L
.80089 .25 L
.80089 .25 L
.8009 .25 L
.8009 .25 L
.80091 .25 L
.80092 .25 L
Mistroke
.80092 .25 L
.80093 .25 L
.80093 .25 L
.80094 .25 L
.80095 .25 L
.80095 .25 L
.80096 .25 L
.80097 .25 L
.80097 .25 L
.80098 .25 L
.80099 .25 L
.80099 .25 L
.80099 .25 L
.801 .25 L
.801 .25 L
.80101 .25 L
.80101 .25 L
.80102 .25 L
.80103 .25 L
.80103 .25 L
.80104 .25 L
.80104 .25 L
.80105 .25 L
.80106 .25 L
.80106 .25 L
.80107 .25 L
.80108 .25 L
.80108 .25 L
.80109 .25 L
.8011 .25 L
.8011 .25 L
.80111 .25 L
.80111 .25 L
.80112 .25 L
.80112 .25 L
.80113 .25 L
.80113 .25 L
.80113 .25 L
.80114 .25 L
.80114 .25 L
.80115 .25 L
.80115 .25 L
.80116 .25 L
.80116 .25 L
.80116 .25 L
.80117 .25 L
.80117 .25 L
.80117 .25 L
.80118 .25 L
.80119 .25 L
Mistroke
.80119 .25 L
.8012 .25 L
.80121 .25 L
.80121 .25 L
.80122 .25 L
.80123 .25 L
.80123 .25 L
.80124 .25 L
.80124 .25 L
.80125 .25 L
.80126 .25 L
.80126 .25 L
.80127 .25 L
.80128 .25 L
.80128 .25 L
.80129 .25 L
.80129 .25 L
.8013 .25 L
.8013 .25 L
.80131 .25 L
.80132 .25 L
.80132 .25 L
.80133 .25 L
.80133 .25 L
.80134 .25 L
.80135 .25 L
.80135 .25 L
.80136 .25 L
.80136 .25 L
.80137 .25 L
.80137 .25 L
.80138 .25 L
.80138 .25 L
.80139 .25 L
.8014 .25 L
.8014 .25 L
.80141 .25 L
.80142 .25 L
.80142 .25 L
.80143 .25 L
.80143 .25 L
.80144 .25 L
.80145 .25 L
.80145 .25 L
.80146 .25 L
.80147 .25 L
.80147 .25 L
.80148 .25 L
.80148 .25 L
.80149 .25 L
Mistroke
.80149 .25 L
.8015 .25 L
.80151 .25 L
.80151 .25 L
.80152 .25 L
.80152 .25 L
.80153 .25 L
.80154 .25 L
.80154 .25 L
.80155 .25 L
.80155 .25 L
.80156 .25 L
.80157 .25 L
.80157 .25 L
.80158 .25 L
.80158 .25 L
.80159 .25 L
.80159 .25 L
.8016 .25 L
.8016 .25 L
.80161 .25 L
.80161 .25 L
.80162 .25 L
.80163 .25 L
.80163 .25 L
.80164 .25 L
.80164 .25 L
.80165 .25 L
.80165 .25 L
.80166 .25 L
.80166 .25 L
.80167 .25 L
.80167 .25 L
.80168 .25 L
.80168 .25 L
.80169 .25 L
.8017 .25 L
.8017 .25 L
.80171 .25 L
.80171 .25 L
.80172 .25 L
.80173 .25 L
.80173 .25 L
.80174 .25 L
.80175 .25 L
.80175 .25 L
.80176 .25 L
.80176 .25 L
.80177 .25 L
.80178 .25 L
Mistroke
.80178 .25 L
.80179 .25 L
.8018 .25 L
.8018 .25 L
.80181 .25 L
.80181 .25 L
.80182 .25 L
.80182 .25 L
.80182 .25 L
.80183 .25 L
.80184 .25 L
.80184 .25 L
.80185 .25 L
.80186 .25 L
.80186 .25 L
.80187 .25 L
.80187 .25 L
.80188 .25 L
.80189 .25 L
.80189 .25 L
.8019 .25 L
.80191 .25 L
.80191 .25 L
.80192 .25 L
.80193 .25 L
.80193 .25 L
.80194 .25 L
.80194 .25 L
.80195 .25 L
.80195 .25 L
.80195 .25 L
.80196 .25 L
.80196 .25 L
.80197 .25 L
.80197 .25 L
.80198 .25 L
.80198 .25 L
.80198 .25 L
.80199 .25 L
.80199 .25 L
.80199 .25 L
.802 .25 L
.802 .25 L
.80201 .25 L
.80202 .25 L
.80203 .25 L
.80203 .25 L
.80204 .25 L
.80204 .25 L
.80205 .25 L
Mistroke
.80206 .25 L
.80206 .25 L
.80207 .25 L
.80208 .25 L
.80208 .25 L
.80209 .25 L
.80209 .25 L
.8021 .25 L
.8021 .25 L
.80211 .25 L
.80212 .25 L
.80212 .25 L
.80213 .25 L
.80213 .25 L
.80214 .25 L
.80215 .25 L
.80215 .25 L
.80216 .25 L
.80216 .25 L
.80217 .25 L
.80218 .25 L
.80218 .25 L
.80219 .25 L
.80219 .25 L
.8022 .25 L
.8022 .25 L
.80221 .25 L
.80221 .25 L
.80222 .25 L
.80223 .25 L
.80223 .25 L
.80224 .25 L
.80225 .25 L
.80225 .25 L
.80226 .25 L
.80226 .25 L
.80227 .25 L
.80228 .25 L
.80228 .25 L
.80229 .25 L
.8023 .25 L
.8023 .25 L
.8023 .25 L
.80231 .25 L
.80232 .25 L
.80232 .25 L
.80233 .25 L
.80234 .25 L
.80234 .25 L
.80235 .25 L
Mistroke
.80235 .25 L
.80236 .25 L
.80237 .25 L
.80237 .25 L
.80238 .25 L
.80238 .25 L
.80239 .25 L
.8024 .25 L
.8024 .25 L
.8024 .25 L
.80241 .25 L
.80242 .25 L
.80242 .25 L
.80243 .25 L
.80243 .25 L
.80244 .25 L
.80244 .25 L
.80245 .25 L
.80245 .25 L
.80246 .25 L
.80247 .25 L
.80247 .25 L
.80248 .25 L
.80248 .25 L
.80249 .25 L
.80249 .25 L
.8025 .25 L
.8025 .25 L
.80251 .25 L
.80251 .25 L
.80252 .25 L
.80253 .25 L
.80253 .25 L
.80254 .25 L
.80254 .25 L
.80255 .25 L
.80256 .25 L
.80256 .25 L
.80257 .25 L
.80258 .25 L
.80258 .25 L
.80259 .25 L
.80259 .25 L
.8026 .25 L
.80261 .25 L
.80261 .25 L
.80262 .25 L
.80263 .25 L
.80263 .25 L
.80264 .25 L
Mistroke
.80264 .25 L
.80264 .25 L
.80265 .25 L
.80265 .25 L
.80266 .25 L
.80267 .25 L
.80267 .25 L
.80268 .25 L
.80269 .25 L
.80269 .25 L
.8027 .25 L
.8027 .25 L
.80271 .25 L
.80272 .25 L
.80272 .25 L
.80273 .25 L
.80274 .25 L
.80274 .25 L
.80275 .25 L
.80276 .25 L
.80276 .25 L
.80276 .25 L
.80277 .25 L
.80277 .25 L
.80278 .25 L
.80278 .25 L
.80278 .25 L
.80279 .25 L
.8028 .25 L
.8028 .25 L
.8028 .25 L
.80281 .25 L
.80281 .25 L
.80281 .25 L
.80282 .25 L
.80282 .25 L
.80283 .25 L
.80283 .25 L
.80284 .25 L
.80285 .25 L
.80286 .25 L
.80286 .25 L
.80287 .25 L
.80287 .25 L
.80288 .25 L
.80289 .25 L
.80289 .25 L
.8029 .25 L
.8029 .25 L
.80291 .25 L
Mistroke
.80292 .25 L
.80292 .25 L
.80293 .25 L
.80293 .25 L
.80294 .25 L
.80294 .25 L
.80295 .25 L
.80296 .25 L
.80296 .25 L
.80297 .25 L
.80297 .25 L
.80298 .25 L
.80299 .25 L
.80299 .25 L
.803 .25 L
.803 .25 L
.80301 .25 L
.80302 .25 L
.80302 .25 L
.80302 .25 L
.80303 .25 L
.80304 .25 L
.80304 .25 L
.80305 .25 L
.80306 .25 L
.80306 .25 L
.80307 .25 L
.80308 .25 L
.80308 .25 L
.80309 .25 L
.80309 .25 L
.8031 .25 L
.80311 .25 L
.80311 .25 L
.80312 .25 L
.80312 .25 L
.80313 .25 L
.80314 .25 L
.80314 .25 L
.80315 .25 L
.80315 .25 L
.80316 .25 L
.80317 .25 L
.80317 .25 L
.80318 .25 L
.80318 .25 L
.80319 .25 L
.80319 .25 L
.8032 .25 L
.80321 .25 L
Mistroke
.80321 .25 L
.80322 .25 L
.80322 .25 L
.80323 .25 L
.80323 .25 L
.80324 .25 L
.80325 .25 L
.80325 .25 L
.80326 .25 L
.80327 .25 L
.80327 .25 L
.80328 .25 L
.80328 .25 L
.80329 .25 L
.8033 .25 L
.8033 .25 L
.80331 .25 L
.80332 .25 L
.80332 .25 L
.80333 .25 L
.80333 .25 L
.80334 .25 L
.80334 .25 L
.80335 .25 L
.80336 .25 L
.80336 .25 L
.80337 .25 L
.80337 .25 L
.80338 .25 L
.80339 .25 L
.80339 .25 L
.8034 .25 L
.8034 .25 L
.80341 .25 L
.80342 .25 L
.80342 .25 L
.80343 .25 L
.80343 .25 L
.80344 .25 L
.80344 .25 L
.80345 .25 L
.80345 .25 L
.80346 .25 L
.80346 .25 L
.80347 .25 L
.80347 .25 L
.80348 .25 L
.80349 .25 L
.80349 .25 L
.8035 .25 L
Mistroke
.8035 .25 L
.80351 .25 L
.80351 .25 L
.80352 .25 L
.80352 .25 L
.80353 .25 L
.80353 .25 L
.80354 .25 L
.80355 .25 L
.80355 .25 L
.80356 .25 L
.80356 .25 L
.80357 .25 L
.80358 .25 L
.80358 .25 L
.80359 .25 L
.80359 .25 L
.8036 .25 L
.80361 .25 L
.80361 .25 L
.80362 .25 L
.80363 .25 L
.80363 .25 L
.80364 .25 L
.80365 .25 L
.80365 .25 L
.80366 .25 L
.80366 .25 L
.80367 .25 L
.80367 .25 L
.80367 .25 L
.80368 .25 L
.80369 .25 L
.80369 .25 L
.8037 .25 L
.80371 .25 L
.80371 .25 L
.80372 .25 L
.80372 .25 L
.80373 .25 L
.80374 .25 L
.80374 .25 L
.80375 .25 L
.80376 .25 L
.80376 .25 L
.80377 .25 L
.80378 .25 L
.80378 .25 L
.80379 .25 L
.80379 .25 L
Mistroke
.8038 .25 L
.8038 .25 L
.8038 .25 L
.80381 .25 L
.80381 .25 L
.80382 .25 L
.80382 .25 L
.80383 .25 L
.80383 .25 L
.80383 .25 L
.80384 .25 L
.80384 .25 L
.80384 .25 L
.80385 .25 L
.80385 .25 L
.80386 .25 L
.80387 .25 L
.80387 .25 L
.80388 .25 L
.80389 .25 L
.80389 .25 L
.8039 .25 L
.80391 .25 L
.80391 .25 L
.80392 .25 L
.80393 .25 L
.80393 .25 L
.80394 .25 L
.80394 .25 L
.80395 .25 L
.80395 .25 L
.80396 .25 L
.80397 .25 L
.80397 .25 L
.80398 .25 L
.80398 .25 L
.80399 .25 L
.804 .25 L
.804 .25 L
.80401 .25 L
.80401 .25 L
.80402 .25 L
.80403 .25 L
.80403 .25 L
.80404 .25 L
.80404 .25 L
.80405 .25 L
.80405 .25 L
.80406 .25 L
.80406 .25 L
Mistroke
.80407 .25 L
.80408 .25 L
.80408 .25 L
.80409 .25 L
.8041 .25 L
.8041 .25 L
.80411 .25 L
.80411 .25 L
.80412 .25 L
.80413 .25 L
.80413 .25 L
.80414 .25 L
.80415 .25 L
.80415 .25 L
.80415 .25 L
.80416 .25 L
.80417 .25 L
.80417 .25 L
.80418 .25 L
.80419 .25 L
.80419 .25 L
.8042 .25 L
.8042 .25 L
.80421 .25 L
.80422 .25 L
.80422 .25 L
.80423 .25 L
.80423 .25 L
.80424 .25 L
.80425 .25 L
.80425 .25 L
.80425 .25 L
.80426 .25 L
.80427 .25 L
.80427 .25 L
.80428 .25 L
.80428 .25 L
.80429 .25 L
.80429 .25 L
.8043 .25 L
.8043 .25 L
.80431 .25 L
.80432 .25 L
.80432 .25 L
.80433 .25 L
.80433 .25 L
.80434 .25 L
.80434 .25 L
.80435 .25 L
.80435 .25 L
Mistroke
.80436 .25 L
.80437 .25 L
.80437 .25 L
.80438 .25 L
.80438 .25 L
.80439 .25 L
.80439 .25 L
.8044 .25 L
.80441 .25 L
.80441 .25 L
.80442 .25 L
.80443 .25 L
.80443 .25 L
.80444 .25 L
.80444 .25 L
.80445 .25 L
.80446 .25 L
.80446 .25 L
.80447 .25 L
.80448 .25 L
.80448 .25 L
.80449 .25 L
.80449 .25 L
.80449 .25 L
.8045 .25 L
.8045 .25 L
.80451 .25 L
.80452 .25 L
.80452 .25 L
.80453 .25 L
.80454 .25 L
.80454 .25 L
.80455 .25 L
.80455 .25 L
.80456 .25 L
.80457 .25 L
.80457 .25 L
.80458 .25 L
.80459 .25 L
.80459 .25 L
.8046 .25 L
.80461 .25 L
.80461 .25 L
.80461 .25 L
.80462 .25 L
.80462 .25 L
.80463 .25 L
.80463 .25 L
.80464 .25 L
.80464 .25 L
Mistroke
.80465 .25 L
.80465 .25 L
.80465 .25 L
.80466 .25 L
.80466 .25 L
.80466 .25 L
.80467 .25 L
.80467 .25 L
.80468 .25 L
.80469 .25 L
.80469 .25 L
.8047 .25 L
.80471 .25 L
.80471 .25 L
.80472 .25 L
.80472 .25 L
.80473 .25 L
.80474 .25 L
.80474 .25 L
.80475 .25 L
.80476 .25 L
.80476 .25 L
.80477 .25 L
.80477 .25 L
.80478 .25 L
.80478 .25 L
.80479 .25 L
.8048 .25 L
.8048 .25 L
.80481 .25 L
.80481 .25 L
.80482 .25 L
.80482 .25 L
.80483 .25 L
.80484 .25 L
.80484 .25 L
.80485 .25 L
.80486 .25 L
.80486 .25 L
.80487 .25 L
.80487 .25 L
.80487 .25 L
.80488 .25 L
.80489 .25 L
.80489 .25 L
.8049 .25 L
.80491 .25 L
.80491 .25 L
.80492 .25 L
.80493 .25 L
Mistroke
.80493 .25 L
.80494 .25 L
.80494 .25 L
.80495 .25 L
.80496 .25 L
.80496 .25 L
.80497 .25 L
.80497 .25 L
.80498 .25 L
.80499 .25 L
.80499 .25 L
.805 .25 L
.805 .25 L
.80501 .25 L
.80502 .25 L
.80502 .25 L
.80503 .25 L
.80503 .25 L
.80504 .25 L
.80505 .25 L
.80505 .25 L
.80506 .25 L
.80506 .25 L
.80507 .25 L
.80507 .25 L
.80508 .25 L
.80508 .25 L
.80509 .25 L
.8051 .25 L
.8051 .25 L
.8051 .25 L
.80511 .25 L
.80512 .25 L
.80512 .25 L
.80513 .25 L
.80513 .25 L
.80514 .25 L
.80515 .25 L
.80515 .25 L
.80515 .25 L
.80516 .25 L
.80517 .25 L
.80517 .25 L
.80518 .25 L
.80518 .25 L
.80519 .25 L
.80519 .25 L
.8052 .25 L
.80521 .25 L
.80521 .25 L
Mistroke
.80522 .25 L
.80522 .25 L
.80523 .25 L
.80524 .25 L
.80524 .25 L
.80525 .25 L
.80526 .25 L
.80526 .25 L
.80527 .25 L
.80527 .25 L
.80528 .25 L
.80529 .25 L
.80529 .25 L
.8053 .25 L
.80531 .25 L
.80531 .25 L
.80531 .25 L
.80532 .25 L
.80532 .25 L
.80533 .25 L
.80533 .25 L
.80534 .25 L
.80535 .25 L
.80535 .25 L
.80536 .25 L
.80537 .25 L
.80537 .25 L
.80538 .25 L
.80538 .25 L
.80539 .25 L
.8054 .25 L
.8054 .25 L
.80541 .25 L
.80542 .25 L
.80542 .25 L
.80543 .25 L
.80543 .25 L
.80544 .25 L
.80544 .25 L
.80545 .25 L
.80545 .25 L
.80546 .25 L
.80546 .25 L
.80547 .25 L
.80547 .25 L
.80547 .25 L
.80548 .25 L
.80548 .25 L
.80548 .25 L
.80549 .25 L
Mistroke
.80549 .25 L
.8055 .25 L
.8055 .25 L
.80551 .25 L
.80552 .25 L
.80552 .25 L
.80553 .25 L
.80554 .25 L
.80554 .25 L
.80555 .25 L
.80555 .25 L
.80556 .25 L
.80557 .25 L
.80557 .25 L
.80558 .25 L
.80559 .25 L
.80559 .25 L
.8056 .25 L
.8056 .25 L
.80561 .25 L
.80561 .25 L
.80562 .25 L
.80563 .25 L
.80563 .25 L
.80564 .25 L
.80564 .25 L
.80565 .25 L
.80565 .25 L
.80566 .25 L
.80567 .25 L
.80567 .25 L
.80568 .25 L
.80568 .25 L
.80569 .25 L
.80569 .25 L
.8057 .25 L
.8057 .25 L
.80571 .25 L
.80572 .25 L
.80572 .25 L
.80573 .25 L
.80574 .25 L
.80574 .25 L
.80575 .25 L
.80576 .25 L
.80576 .25 L
.80577 .25 L
.80578 .25 L
.80578 .25 L
.80579 .25 L
Mistroke
.80579 .25 L
.8058 .25 L
.8058 .25 L
.80581 .25 L
.80582 .25 L
.80582 .25 L
.80583 .25 L
.80583 .25 L
.80584 .25 L
.80585 .25 L
.80585 .25 L
.80586 .25 L
.80586 .25 L
.80587 .25 L
.80588 .25 L
.80588 .25 L
.80589 .25 L
.80589 .25 L
.8059 .25 L
.8059 .25 L
.80591 .25 L
.80591 .25 L
.80592 .25 L
.80592 .25 L
.80593 .25 L
.80593 .25 L
.80594 .25 L
.80595 .25 L
.80595 .25 L
.80596 .25 L
.80596 .25 L
.80597 .25 L
.80597 .25 L
.80598 .25 L
.80598 .25 L
.80599 .25 L
.80599 .25 L
.806 .25 L
.80601 .25 L
.80601 .25 L
.80602 .25 L
.80602 .25 L
.80603 .25 L
.80604 .25 L
.80604 .25 L
.80605 .25 L
.80605 .25 L
.80606 .25 L
.80607 .25 L
.80607 .25 L
Mistroke
.80608 .25 L
.80608 .25 L
.80609 .25 L
.8061 .25 L
.8061 .25 L
.80611 .25 L
.80612 .25 L
.80612 .25 L
.80613 .25 L
.80613 .25 L
.80614 .25 L
.80614 .25 L
.80614 .25 L
.80615 .25 L
.80616 .25 L
.80616 .25 L
.80617 .25 L
.80618 .25 L
.80618 .25 L
.80619 .25 L
.80619 .25 L
.8062 .25 L
.80621 .25 L
.80621 .25 L
.80622 .25 L
.80623 .25 L
.80623 .25 L
.80624 .25 L
.80625 .25 L
.80625 .25 L
.80626 .25 L
.80626 .25 L
.80627 .25 L
.80627 .25 L
.80627 .25 L
.80628 .25 L
.80628 .25 L
.80629 .25 L
.80629 .25 L
.8063 .25 L
.8063 .25 L
.8063 .25 L
.80631 .25 L
.80631 .25 L
.80632 .25 L
.80632 .25 L
.80633 .25 L
.80633 .25 L
.80634 .25 L
.80635 .25 L
Mistroke
.80635 .25 L
.80636 .25 L
.80636 .25 L
.80637 .25 L
.80638 .25 L
.80638 .25 L
.80639 .25 L
.8064 .25 L
.8064 .25 L
.80641 .25 L
.80642 .25 L
.80642 .25 L
.80642 .25 L
.80643 .25 L
.80644 .25 L
.80644 .25 L
.80645 .25 L
.80645 .25 L
.80646 .25 L
.80647 .25 L
.80647 .25 L
.80648 .25 L
.80648 .25 L
.80649 .25 L
.8065 .25 L
.8065 .25 L
.80651 .25 L
.80651 .25 L
.80652 .25 L
.80652 .25 L
.80653 .25 L
.80653 .25 L
.80654 .25 L
.80655 .25 L
.80655 .25 L
.80656 .25 L
.80657 .25 L
.80657 .25 L
.80658 .25 L
.80658 .25 L
.80659 .25 L
.8066 .25 L
.8066 .25 L
.80661 .25 L
.80662 .25 L
.80662 .25 L
.80663 .25 L
.80663 .25 L
.80664 .25 L
.80664 .25 L
Mistroke
.80665 .25 L
.80666 .25 L
.80666 .25 L
.80667 .25 L
.80667 .25 L
.80668 .25 L
.80669 .25 L
.80669 .25 L
.8067 .25 L
.8067 .25 L
.80671 .25 L
.80672 .25 L
.80672 .25 L
.80672 .25 L
.80673 .25 L
.80674 .25 L
.80674 .25 L
.80675 .25 L
.80676 .25 L
.80676 .25 L
.80677 .25 L
.80677 .25 L
.80678 .25 L
.80679 .25 L
.80679 .25 L
.8068 .25 L
.80681 .25 L
.80681 .25 L
.80682 .25 L
.80682 .25 L
.80683 .25 L
.80684 .25 L
.80684 .25 L
.80685 .25 L
.80685 .25 L
.80686 .25 L
.80687 .25 L
.80687 .25 L
.80688 .25 L
.80688 .25 L
.80689 .25 L
.80689 .25 L
.8069 .25 L
.80691 .25 L
.80691 .25 L
.80692 .25 L
.80692 .25 L
.80693 .25 L
.80693 .25 L
.80694 .25 L
Mistroke
.80695 .25 L
.80695 .25 L
.80695 .25 L
.80696 .25 L
.80697 .25 L
.80697 .25 L
.80698 .25 L
.80698 .25 L
.80699 .25 L
.807 .25 L
.807 .25 L
.807 .25 L
.80701 .25 L
.80701 .25 L
.80702 .25 L
.80702 .25 L
.80703 .25 L
.80704 .25 L
.80704 .25 L
.80705 .25 L
.80706 .25 L
.80706 .25 L
.80707 .25 L
.80707 .25 L
.80708 .25 L
.80709 .25 L
.80709 .25 L
.8071 .25 L
.8071 .25 L
.80711 .25 L
.80712 .25 L
.80712 .25 L
.80713 .25 L
.80714 .25 L
.80714 .25 L
.80715 .25 L
.80716 .25 L
.80716 .25 L
.80716 .25 L
.80717 .25 L
.80717 .25 L
.80718 .25 L
.80718 .25 L
.80719 .25 L
.8072 .25 L
.8072 .25 L
.80721 .25 L
.80722 .25 L
.80722 .25 L
.80723 .25 L
Mistroke
.80723 .25 L
.80724 .25 L
.80725 .25 L
.80725 .25 L
.80726 .25 L
.80727 .25 L
.80727 .25 L
.80728 .25 L
.80728 .25 L
.80729 .25 L
.80729 .25 L
.8073 .25 L
.8073 .25 L
.8073 .25 L
.80731 .25 L
.80732 .25 L
.80732 .25 L
.80732 .25 L
.80733 .25 L
.80733 .25 L
.80733 .25 L
.80734 .25 L
.80734 .25 L
.80735 .25 L
.80735 .25 L
.80736 .25 L
.80737 .25 L
.80737 .25 L
.80738 .25 L
.80739 .25 L
.80739 .25 L
.8074 .25 L
.8074 .25 L
.80741 .25 L
.80742 .25 L
.80742 .25 L
.80743 .25 L
.80744 .25 L
.80744 .25 L
.80745 .25 L
.80745 .25 L
.80746 .25 L
.80746 .25 L
.80747 .25 L
.80748 .25 L
.80748 .25 L
.80749 .25 L
.80749 .25 L
.8075 .25 L
.8075 .25 L
Mistroke
.80751 .25 L
.80752 .25 L
.80752 .25 L
.80753 .25 L
.80753 .25 L
.80754 .25 L
.80754 .25 L
.80755 .25 L
.80755 .25 L
.80756 .25 L
.80757 .25 L
.80757 .25 L
.80758 .25 L
.80759 .25 L
.80759 .25 L
.8076 .25 L
.80761 .25 L
.80761 .25 L
.80762 .25 L
.80763 .25 L
.80763 .25 L
.80764 .25 L
.80764 .25 L
.80765 .25 L
.80765 .25 L
.80766 .25 L
.80767 .25 L
.80767 .25 L
.80768 .25 L
.80768 .25 L
.80769 .25 L
.8077 .25 L
.8077 .25 L
.80771 .25 L
.80771 .25 L
.80772 .25 L
.80773 .25 L
.80773 .25 L
.80774 .25 L
.80774 .25 L
.80775 .25 L
.80775 .25 L
.80776 .25 L
.80776 .25 L
.80777 .25 L
.80777 .25 L
.80778 .25 L
.80778 .25 L
.80779 .25 L
.8078 .25 L
Mistroke
.8078 .25 L
.80781 .25 L
.80781 .25 L
.80782 .25 L
.80782 .25 L
.80783 .25 L
.80784 .25 L
.80784 .25 L
.80784 .25 L
.80785 .25 L
.80786 .25 L
.80786 .25 L
.80787 .25 L
.80787 .25 L
.80788 .25 L
.80789 .25 L
.80789 .25 L
.8079 .25 L
.8079 .25 L
.80791 .25 L
.80792 .25 L
.80792 .25 L
.80793 .25 L
.80793 .25 L
.80794 .25 L
.80795 .25 L
.80795 .25 L
.80796 .25 L
.80797 .25 L
.80797 .25 L
.80798 .25 L
.80798 .25 L
.80799 .25 L
.80799 .25 L
.80799 .25 L
.808 .25 L
.80801 .25 L
.80801 .25 L
.80802 .25 L
.80803 .25 L
.80803 .25 L
.80804 .25 L
.80805 .25 L
.80805 .25 L
.80806 .25 L
.80806 .25 L
.80807 .25 L
.80808 .25 L
.80808 .25 L
.80809 .25 L
Mistroke
.8081 .25 L
.8081 .25 L
.80811 .25 L
.80811 .25 L
.80812 .25 L
.80812 .25 L
.80813 .25 L
.80813 .25 L
.80813 .25 L
.80814 .25 L
.80814 .25 L
.80815 .25 L
.80815 .25 L
.80815 .25 L
.80816 .25 L
.80816 .25 L
.80817 .25 L
.80817 .25 L
.80818 .25 L
.80818 .25 L
.80819 .25 L
.8082 .25 L
.8082 .25 L
.80821 .25 L
.80822 .25 L
.80822 .25 L
.80823 .25 L
.80823 .25 L
.80824 .25 L
.80825 .25 L
.80825 .25 L
.80826 .25 L
.80827 .25 L
.80827 .25 L
.80827 .25 L
.80828 .25 L
.80829 .25 L
.80829 .25 L
.8083 .25 L
.80831 .25 L
.80831 .25 L
.80832 .25 L
.80832 .25 L
.80833 .25 L
.80833 .25 L
.80834 .25 L
.80835 .25 L
.80835 .25 L
.80836 .25 L
.80837 .25 L
Mistroke
.80837 .25 L
.80837 .25 L
.80838 .25 L
.80839 .25 L
.80839 .25 L
.8084 .25 L
.80841 .25 L
.80841 .25 L
.80842 .25 L
.80842 .25 L
.80843 .25 L
.80844 .25 L
.80844 .25 L
.80845 .25 L
.80846 .25 L
.80846 .25 L
.80847 .25 L
.80847 .25 L
.80848 .25 L
.80848 .25 L
.80849 .25 L
.8085 .25 L
.8085 .25 L
.80851 .25 L
.80851 .25 L
.80852 .25 L
.80852 .25 L
.80853 .25 L
.80854 .25 L
.80854 .25 L
.80855 .25 L
.80856 .25 L
.80856 .25 L
.80857 .25 L
.80857 .25 L
.80857 .25 L
.80858 .25 L
.80859 .25 L
.80859 .25 L
.8086 .25 L
.8086 .25 L
.80861 .25 L
.80861 .25 L
.80862 .25 L
.80863 .25 L
.80863 .25 L
.80864 .25 L
.80864 .25 L
.80865 .25 L
.80865 .25 L
Mistroke
.80866 .25 L
.80866 .25 L
.80867 .25 L
.80867 .25 L
.80868 .25 L
.80869 .25 L
.80869 .25 L
.8087 .25 L
.8087 .25 L
.80871 .25 L
.80872 .25 L
.80872 .25 L
.80873 .25 L
.80873 .25 L
.80874 .25 L
.80875 .25 L
.80875 .25 L
.80876 .25 L
.80876 .25 L
.80877 .25 L
.80878 .25 L
.80878 .25 L
.80879 .25 L
.8088 .25 L
.8088 .25 L
.80881 .25 L
.80881 .25 L
.80881 .25 L
.80882 .25 L
.80883 .25 L
.80883 .25 L
.80884 .25 L
.80885 .25 L
.80885 .25 L
.80886 .25 L
.80886 .25 L
.80887 .25 L
.80888 .25 L
.80888 .25 L
.80889 .25 L
.80889 .25 L
.8089 .25 L
.80891 .25 L
.80891 .25 L
.80892 .25 L
.80893 .25 L
.80893 .25 L
.80894 .25 L
.80894 .25 L
.80895 .25 L
Mistroke
.80895 .25 L
.80895 .25 L
.80896 .25 L
.80896 .25 L
.80897 .25 L
.80897 .25 L
.80897 .25 L
.80898 .25 L
.80898 .25 L
.80899 .25 L
.80899 .25 L
.80899 .25 L
.809 .25 L
.80901 .25 L
.80901 .25 L
.80902 .25 L
.80903 .25 L
.80903 .25 L
.80904 .25 L
.80904 .25 L
.80905 .25 L
.80906 .25 L
.80906 .25 L
.80907 .25 L
.80908 .25 L
.80908 .25 L
.80909 .25 L
.80909 .25 L
.8091 .25 L
.8091 .25 L
.80911 .25 L
.80912 .25 L
.80912 .25 L
.80913 .25 L
.80914 .25 L
.80914 .25 L
.80915 .25 L
.80915 .25 L
.80916 .25 L
.80916 .25 L
.80917 .25 L
.80918 .25 L
.80918 .25 L
.80919 .25 L
.80919 .25 L
.8092 .25 L
.8092 .25 L
.80921 .25 L
.80922 .25 L
.80922 .25 L
Mistroke
.80923 .25 L
.80924 .25 L
.80924 .25 L
.80925 .25 L
.80925 .25 L
.80926 .25 L
.80927 .25 L
.80927 .25 L
.80928 .25 L
.80929 .25 L
.80929 .25 L
.8093 .25 L
.8093 .25 L
.80931 .25 L
.80931 .25 L
.80932 .25 L
.80933 .25 L
.80933 .25 L
.80934 .25 L
.80934 .25 L
.80935 .25 L
.80935 .25 L
.80936 .25 L
.80937 .25 L
.80937 .25 L
.80938 .25 L
.80938 .25 L
.80939 .25 L
.80939 .25 L
.8094 .25 L
.8094 .25 L
.80941 .25 L
.80942 .25 L
.80942 .25 L
.80942 .25 L
.80943 .25 L
.80944 .25 L
.80944 .25 L
.80945 .25 L
.80946 .25 L
.80946 .25 L
.80947 .25 L
.80947 .25 L
.80948 .25 L
.80948 .25 L
.80949 .25 L
.80949 .25 L
.8095 .25 L
.8095 .25 L
.80951 .25 L
Mistroke
.80952 .25 L
.80952 .25 L
.80953 .25 L
.80953 .25 L
.80954 .25 L
.80954 .25 L
.80955 .25 L
.80956 .25 L
.80956 .25 L
.80957 .25 L
.80958 .25 L
.80958 .25 L
.80959 .25 L
.80959 .25 L
.8096 .25 L
.80961 .25 L
.80961 .25 L
.80962 .25 L
.80963 .25 L
.80963 .25 L
.80963 .25 L
.80964 .25 L
.80964 .25 L
.80965 .25 L
.80965 .25 L
.80966 .25 L
.80967 .25 L
.80967 .25 L
.80968 .25 L
.80969 .25 L
.80969 .25 L
.8097 .25 L
.80971 .25 L
.80971 .25 L
.80972 .25 L
.80972 .25 L
.80973 .25 L
.80974 .25 L
.80974 .25 L
.80975 .25 L
.80976 .25 L
.80976 .25 L
.80977 .25 L
.80977 .25 L
.80977 .25 L
.80978 .25 L
.80978 .25 L
.80979 .25 L
.80979 .25 L
.80979 .25 L
Mistroke
.8098 .25 L
.8098 .25 L
.80981 .25 L
.80981 .25 L
.80981 .25 L
.80982 .25 L
.80982 .25 L
.80983 .25 L
.80984 .25 L
.80984 .25 L
.80985 .25 L
.80986 .25 L
.80986 .25 L
.80987 .25 L
.80987 .25 L
.80988 .25 L
.80989 .25 L
.80989 .25 L
.8099 .25 L
.80991 .25 L
.80991 .25 L
.80992 .25 L
.80992 .25 L
.80993 .25 L
.80993 .25 L
.80994 .25 L
.80995 .25 L
.80995 .25 L
.80996 .25 L
.80996 .25 L
.80997 .25 L
.80998 .25 L
.80998 .25 L
.80999 .25 L
.80999 .25 L
.81 .25 L
.81001 .25 L
.81001 .25 L
.81002 .25 L
.81002 .25 L
.81003 .25 L
.81003 .25 L
.81004 .25 L
.81005 .25 L
.81005 .25 L
.81006 .25 L
.81006 .25 L
.81007 .25 L
.81008 .25 L
.81008 .25 L
Mistroke
.81009 .25 L
.8101 .25 L
.8101 .25 L
.81011 .25 L
.81012 .25 L
.81012 .25 L
.81012 .25 L
.81013 .25 L
.81014 .25 L
.81014 .25 L
.81015 .25 L
.81016 .25 L
.81016 .25 L
.81017 .25 L
.81017 .25 L
.81018 .25 L
.81018 .25 L
.81019 .25 L
.8102 .25 L
.8102 .25 L
.81021 .25 L
.81021 .25 L
.81022 .25 L
.81022 .25 L
.81023 .25 L
.81023 .25 L
.81024 .25 L
.81025 .25 L
.81025 .25 L
.81026 .25 L
.81027 .25 L
.81027 .25 L
.81028 .25 L
.81029 .25 L
.81029 .25 L
.8103 .25 L
.8103 .25 L
.81031 .25 L
.81032 .25 L
.81032 .25 L
.81033 .25 L
.81033 .25 L
.81034 .25 L
.81035 .25 L
.81035 .25 L
.81036 .25 L
.81036 .25 L
.81037 .25 L
.81037 .25 L
.81038 .25 L
Mistroke
.81039 .25 L
.81039 .25 L
.8104 .25 L
.81041 .25 L
.81041 .25 L
.81042 .25 L
.81042 .25 L
.81042 .25 L
.81043 .25 L
.81044 .25 L
.81044 .25 L
.81045 .25 L
.81045 .25 L
.81046 .25 L
.81046 .25 L
.81047 .25 L
.81048 .25 L
.81048 .25 L
.81049 .25 L
.81049 .25 L
.8105 .25 L
.8105 .25 L
.81051 .25 L
.81051 .25 L
.81052 .25 L
.81052 .25 L
.81053 .25 L
.81054 .25 L
.81054 .25 L
.81055 .25 L
.81055 .25 L
.81056 .25 L
.81056 .25 L
.81057 .25 L
.81058 .25 L
.81058 .25 L
.81059 .25 L
.8106 .25 L
.8106 .25 L
.81061 .25 L
.81061 .25 L
.81062 .25 L
.81063 .25 L
.81063 .25 L
.81064 .25 L
.81065 .25 L
.81065 .25 L
.81066 .25 L
.81066 .25 L
.81066 .25 L
Mistroke
.81067 .25 L
.81068 .25 L
.81068 .25 L
.81069 .25 L
.81069 .25 L
.8107 .25 L
.81071 .25 L
.81071 .25 L
.81072 .25 L
.81073 .25 L
.81073 .25 L
.81074 .25 L
.81074 .25 L
.81075 .25 L
.81076 .25 L
.81076 .25 L
.81077 .25 L
.81078 .25 L
.81078 .25 L
.81079 .25 L
.81079 .25 L
.8108 .25 L
.8108 .25 L
.8108 .25 L
.81081 .25 L
.81081 .25 L
.81082 .25 L
.81082 .25 L
.81082 .25 L
.81083 .25 L
.81083 .25 L
.81084 .25 L
.81084 .25 L
.81084 .25 L
.81085 .25 L
.81086 .25 L
.81086 .25 L
.81087 .25 L
.81088 .25 L
.81088 .25 L
.81089 .25 L
.81089 .25 L
.8109 .25 L
.81091 .25 L
.81091 .25 L
.81092 .25 L
.81093 .25 L
.81093 .25 L
.81094 .25 L
.81094 .25 L
Mistroke
.81095 .25 L
.81095 .25 L
.81096 .25 L
.81097 .25 L
.81097 .25 L
.81098 .25 L
.81099 .25 L
.81099 .25 L
.811 .25 L
.811 .25 L
.81101 .25 L
.81101 .25 L
.81102 .25 L
.81103 .25 L
.81103 .25 L
.81104 .25 L
.81104 .25 L
.81105 .25 L
.81105 .25 L
.81106 .25 L
.81107 .25 L
.81107 .25 L
.81108 .25 L
.81109 .25 L
.81109 .25 L
.8111 .25 L
.8111 .25 L
.81111 .25 L
.81112 .25 L
.81112 .25 L
.81113 .25 L
.81114 .25 L
.81114 .25 L
.81115 .25 L
.81115 .25 L
.81116 .25 L
.81116 .25 L
.81117 .25 L
.81118 .25 L
.81118 .25 L
.81119 .25 L
.81119 .25 L
.8112 .25 L
.8112 .25 L
.81121 .25 L
.81122 .25 L
.81122 .25 L
.81123 .25 L
.81123 .25 L
.81124 .25 L
Mistroke
.81125 .25 L
.81125 .25 L
.81125 .25 L
.81126 .25 L
.81127 .25 L
.81127 .25 L
.81128 .25 L
.81128 .25 L
.81129 .25 L
.81129 .25 L
.8113 .25 L
.81131 .25 L
.81131 .25 L
.81132 .25 L
.81132 .25 L
.81133 .25 L
.81133 .25 L
.81134 .25 L
.81134 .25 L
.81135 .25 L
.81135 .25 L
.81136 .25 L
.81137 .25 L
.81137 .25 L
.81138 .25 L
.81138 .25 L
.81139 .25 L
.8114 .25 L
.8114 .25 L
.81141 .25 L
.81141 .25 L
.81142 .25 L
.81143 .25 L
.81143 .25 L
.81144 .25 L
.81144 .25 L
.81145 .25 L
.81146 .25 L
.81146 .25 L
.81147 .25 L
.81148 .25 L
.81148 .25 L
.81148 .25 L
.81149 .25 L
.81149 .25 L
.8115 .25 L
.81151 .25 L
.81151 .25 L
.81152 .25 L
.81153 .25 L
Mistroke
.81153 .25 L
.81154 .25 L
.81154 .25 L
.81155 .25 L
.81156 .25 L
.81156 .25 L
.81157 .25 L
.81158 .25 L
.81158 .25 L
.81159 .25 L
.81159 .25 L
.8116 .25 L
.81161 .25 L
.81161 .25 L
.81162 .25 L
.81162 .25 L
.81162 .25 L
.81163 .25 L
.81163 .25 L
.81164 .25 L
.81164 .25 L
.81164 .25 L
.81165 .25 L
.81165 .25 L
.81166 .25 L
.81166 .25 L
.81166 .25 L
.81167 .25 L
.81167 .25 L
.81168 .25 L
.81169 .25 L
.81169 .25 L
.8117 .25 L
.81171 .25 L
.81171 .25 L
.81172 .25 L
.81172 .25 L
.81173 .25 L
.81174 .25 L
.81174 .25 L
.81175 .25 L
.81176 .25 L
.81176 .25 L
.81177 .25 L
.81177 .25 L
.81178 .25 L
.81179 .25 L
.81179 .25 L
.8118 .25 L
.8118 .25 L
Mistroke
.81181 .25 L
.81182 .25 L
.81182 .25 L
.81183 .25 L
.81183 .25 L
.81184 .25 L
.81184 .25 L
.81185 .25 L
.81186 .25 L
.81186 .25 L
.81187 .25 L
.81187 .25 L
.81188 .25 L
.81188 .25 L
.81189 .25 L
.8119 .25 L
.8119 .25 L
.81191 .25 L
.81192 .25 L
.81192 .25 L
.81193 .25 L
.81193 .25 L
.81194 .25 L
.81195 .25 L
.81195 .25 L
.81196 .25 L
.81197 .25 L
.81197 .25 L
.81197 .25 L
.81198 .25 L
.81199 .25 L
.81199 .25 L
.812 .25 L
.81201 .25 L
.81201 .25 L
.81202 .25 L
.81202 .25 L
.81203 .25 L
.81203 .25 L
.81204 .25 L
.81205 .25 L
.81205 .25 L
.81206 .25 L
.81207 .25 L
.81207 .25 L
.81207 .25 L
.81208 .25 L
.81209 .25 L
.81209 .25 L
.8121 .25 L
Mistroke
.8121 .25 L
.81211 .25 L
.81211 .25 L
.81212 .25 L
.81212 .25 L
.81213 .25 L
.81214 .25 L
.81214 .25 L
.81215 .25 L
.81215 .25 L
.81216 .25 L
.81216 .25 L
.81216 .25 L
.81217 .25 L
.81218 .25 L
.81218 .25 L
.81219 .25 L
.8122 .25 L
.8122 .25 L
.81221 .25 L
.81221 .25 L
.81222 .25 L
.81223 .25 L
.81223 .25 L
.81224 .25 L
.81224 .25 L
.81225 .25 L
.81226 .25 L
.81226 .25 L
.81227 .25 L
.81228 .25 L
.81228 .25 L
.81229 .25 L
.8123 .25 L
.8123 .25 L
.81231 .25 L
.81231 .25 L
.81231 .25 L
.81232 .25 L
.81232 .25 L
.81233 .25 L
.81234 .25 L
.81234 .25 L
.81235 .25 L
.81236 .25 L
.81236 .25 L
.81237 .25 L
.81237 .25 L
.81238 .25 L
.81239 .25 L
Mistroke
.81239 .25 L
.8124 .25 L
.81241 .25 L
.81241 .25 L
.81242 .25 L
.81243 .25 L
.81243 .25 L
.81243 .25 L
.81244 .25 L
.81244 .25 L
.81245 .25 L
.81245 .25 L
.81245 .25 L
.81246 .25 L
.81247 .25 L
.81247 .25 L
.81247 .25 L
.81248 .25 L
.81248 .25 L
.81248 .25 L
.81249 .25 L
.81249 .25 L
.8125 .25 L
.8125 .25 L
.81251 .25 L
.81252 .25 L
.81252 .25 L
.81253 .25 L
.81254 .25 L
.81254 .25 L
.81255 .25 L
.81255 .25 L
.81256 .25 L
.81257 .25 L
.81257 .25 L
.81258 .25 L
.81259 .25 L
.81259 .25 L
.8126 .25 L
.8126 .25 L
.81261 .25 L
.81261 .25 L
.81262 .25 L
.81263 .25 L
.81263 .25 L
.81264 .25 L
.81264 .25 L
.81265 .25 L
.81266 .25 L
.81266 .25 L
Mistroke
.81267 .25 L
.81267 .25 L
.81268 .25 L
.81269 .25 L
.81269 .25 L
.81269 .25 L
.8127 .25 L
.81271 .25 L
.81271 .25 L
.81272 .25 L
.81273 .25 L
.81273 .25 L
.81274 .25 L
.81274 .25 L
.81275 .25 L
.81276 .25 L
.81276 .25 L
.81277 .25 L
.81278 .25 L
.81278 .25 L
.81279 .25 L
.81279 .25 L
.8128 .25 L
.8128 .25 L
.81281 .25 L
.81282 .25 L
.81282 .25 L
.81283 .25 L
.81284 .25 L
.81284 .25 L
.81285 .25 L
.81285 .25 L
.81286 .25 L
.81286 .25 L
.81287 .25 L
.81288 .25 L
.81288 .25 L
.81289 .25 L
.81289 .25 L
.8129 .25 L
.8129 .25 L
.81291 .25 L
.81292 .25 L
.81292 .25 L
.81292 .25 L
.81293 .25 L
.81294 .25 L
.81294 .25 L
.81295 .25 L
.81295 .25 L
Mistroke
.81296 .25 L
.81297 .25 L
.81297 .25 L
.81297 .25 L
.81298 .25 L
.81298 .25 L
.81299 .25 L
.81299 .25 L
.813 .25 L
.81301 .25 L
.81301 .25 L
.81302 .25 L
.81303 .25 L
.81303 .25 L
.81304 .25 L
.81304 .25 L
.81305 .25 L
.81306 .25 L
.81306 .25 L
.81307 .25 L
.81307 .25 L
.81308 .25 L
.81309 .25 L
.81309 .25 L
.8131 .25 L
.81311 .25 L
.81311 .25 L
.81312 .25 L
.81313 .25 L
.81313 .25 L
.81313 .25 L
.81314 .25 L
.81314 .25 L
.81315 .25 L
.81315 .25 L
.81316 .25 L
.81317 .25 L
.81317 .25 L
.81318 .25 L
.81318 .25 L
.81319 .25 L
.8132 .25 L
.8132 .25 L
.81321 .25 L
.81322 .25 L
.81322 .25 L
.81323 .25 L
.81324 .25 L
.81324 .25 L
.81325 .25 L
Mistroke
.81325 .25 L
.81326 .25 L
.81326 .25 L
.81327 .25 L
.81327 .25 L
.81327 .25 L
.81328 .25 L
.81328 .25 L
.81329 .25 L
.81329 .25 L
.8133 .25 L
.8133 .25 L
.8133 .25 L
.81331 .25 L
.81331 .25 L
.81331 .25 L
.81332 .25 L
.81333 .25 L
.81333 .25 L
.81334 .25 L
.81335 .25 L
.81335 .25 L
.81336 .25 L
.81337 .25 L
.81337 .25 L
.81338 .25 L
.81338 .25 L
.81339 .25 L
.8134 .25 L
.8134 .25 L
.81341 .25 L
.81342 .25 L
.81342 .25 L
.81343 .25 L
.81343 .25 L
.81344 .25 L
.81344 .25 L
.81345 .25 L
.81346 .25 L
.81346 .25 L
.81347 .25 L
.81347 .25 L
.81348 .25 L
.81349 .25 L
.81349 .25 L
.8135 .25 L
.8135 .25 L
.81351 .25 L
.81351 .25 L
.81352 .25 L
Mistroke
.81352 .25 L
.81353 .25 L
.81354 .25 L
.81354 .25 L
.81355 .25 L
.81356 .25 L
.81356 .25 L
.81357 .25 L
.81357 .25 L
.81358 .25 L
.81359 .25 L
.81359 .25 L
.8136 .25 L
.81361 .25 L
.81361 .25 L
.81362 .25 L
.81362 .25 L
.81363 .25 L
.81363 .25 L
.81364 .25 L
.81365 .25 L
.81365 .25 L
.81366 .25 L
.81366 .25 L
.81367 .25 L
.81368 .25 L
.81368 .25 L
.81369 .25 L
.81369 .25 L
.8137 .25 L
.81371 .25 L
.81371 .25 L
.81372 .25 L
.81372 .25 L
.81373 .25 L
.81373 .25 L
.81374 .25 L
.81375 .25 L
.81375 .25 L
.81376 .25 L
.81376 .25 L
.81377 .25 L
.81378 .25 L
.81378 .25 L
.81379 .25 L
.8138 .25 L
.8138 .25 L
.81381 .25 L
.81382 .25 L
.81382 .25 L
Mistroke
.81382 .25 L
.81383 .25 L
.81384 .25 L
.81384 .25 L
.81385 .25 L
.81386 .25 L
.81386 .25 L
.81387 .25 L
.81387 .25 L
.81388 .25 L
.81388 .25 L
.81389 .25 L
.8139 .25 L
.8139 .25 L
.81391 .25 L
.81392 .25 L
.81392 .25 L
.81392 .25 L
.81393 .25 L
.81394 .25 L
.81394 .25 L
.81395 .25 L
.81395 .25 L
.81396 .25 L
.81396 .25 L
.81397 .25 L
.81397 .25 L
.81398 .25 L
.81399 .25 L
.81399 .25 L
.814 .25 L
.814 .25 L
.81401 .25 L
.81401 .25 L
.81401 .25 L
.81402 .25 L
.81403 .25 L
.81403 .25 L
.81404 .25 L
.81405 .25 L
.81405 .25 L
.81406 .25 L
.81406 .25 L
.81407 .25 L
.81408 .25 L
.81408 .25 L
.81409 .25 L
.81409 .25 L
.8141 .25 L
.81411 .25 L
Mistroke
.81411 .25 L
.81412 .25 L
.81413 .25 L
.81413 .25 L
.81414 .25 L
.81415 .25 L
.81415 .25 L
.81416 .25 L
.81416 .25 L
.81416 .25 L
.81417 .25 L
.81417 .25 L
.81418 .25 L
.81419 .25 L
.81419 .25 L
.8142 .25 L
.81421 .25 L
.81421 .25 L
.81422 .25 L
.81422 .25 L
.81423 .25 L
.81424 .25 L
.81424 .25 L
.81425 .25 L
.81426 .25 L
.81426 .25 L
.81427 .25 L
.81428 .25 L
.81428 .25 L
.81428 .25 L
.81429 .25 L
.81429 .25 L
.8143 .25 L
.8143 .25 L
.8143 .25 L
.81431 .25 L
.81432 .25 L
.81432 .25 L
.81432 .25 L
.81433 .25 L
.81433 .25 L
.81433 .25 L
.81434 .25 L
.81434 .25 L
.81435 .25 L
.81435 .25 L
.81436 .25 L
.81437 .25 L
.81437 .25 L
.81438 .25 L
Mistroke
.81439 .25 L
.81439 .25 L
.8144 .25 L
.8144 .25 L
.81441 .25 L
.81442 .25 L
.81442 .25 L
.81443 .25 L
.81444 .25 L
.81444 .25 L
.81445 .25 L
.81445 .25 L
.81446 .25 L
.81446 .25 L
.81447 .25 L
.81448 .25 L
.81448 .25 L
.81449 .25 L
.81449 .25 L
.8145 .25 L
.81451 .25 L
.81451 .25 L
.81452 .25 L
.81452 .25 L
.81453 .25 L
.81454 .25 L
.81454 .25 L
.81454 .25 L
.81455 .25 L
.81456 .25 L
.81456 .25 L
.81457 .25 L
.81458 .25 L
.81458 .25 L
.81459 .25 L
.8146 .25 L
.8146 .25 L
.81461 .25 L
.81461 .25 L
.81462 .25 L
.81463 .25 L
.81463 .25 L
.81464 .25 L
.81464 .25 L
.81465 .25 L
.81466 .25 L
.81466 .25 L
.81467 .25 L
.81467 .25 L
.81468 .25 L
Mistroke
.81469 .25 L
.81469 .25 L
.8147 .25 L
.8147 .25 L
.81471 .25 L
.81471 .25 L
.81472 .25 L
.81473 .25 L
.81473 .25 L
.81474 .25 L
.81474 .25 L
.81475 .25 L
.81475 .25 L
.81476 .25 L
.81477 .25 L
.81477 .25 L
.81477 .25 L
.81478 .25 L
.81479 .25 L
.81479 .25 L
.8148 .25 L
.8148 .25 L
.81481 .25 L
.81482 .25 L
.81482 .25 L
.81482 .25 L
.81483 .25 L
.81483 .25 L
.81484 .25 L
.81484 .25 L
.81485 .25 L
.81486 .25 L
.81486 .25 L
.81487 .25 L
.81488 .25 L
.81488 .25 L
.81489 .25 L
.81489 .25 L
.8149 .25 L
.81491 .25 L
.81491 .25 L
.81492 .25 L
.81492 .25 L
.81493 .25 L
.81494 .25 L
.81494 .25 L
.81495 .25 L
.81496 .25 L
.81496 .25 L
.81497 .25 L
Mistroke
.81498 .25 L
.81498 .25 L
.81498 .25 L
.81499 .25 L
.81499 .25 L
.815 .25 L
.815 .25 L
.81501 .25 L
.81502 .25 L
.81502 .25 L
.81503 .25 L
.81504 .25 L
.81504 .25 L
.81505 .25 L
.81505 .25 L
.81506 .25 L
.81507 .25 L
.81507 .25 L
.81508 .25 L
.81509 .25 L
.81509 .25 L
.8151 .25 L
.8151 .25 L
.81511 .25 L
.81511 .25 L
.81512 .25 L
.81512 .25 L
.81512 .25 L
.81513 .25 L
.81514 .25 L
.81514 .25 L
.81514 .25 L
.81515 .25 L
.81515 .25 L
.81515 .25 L
.81516 .25 L
.81516 .25 L
.81517 .25 L
.81517 .25 L
.81518 .25 L
.81519 .25 L
.81519 .25 L
.8152 .25 L
.81521 .25 L
.81521 .25 L
.81522 .25 L
.81522 .25 L
.81523 .25 L
.81524 .25 L
.81524 .25 L
Mistroke
.81525 .25 L
.81526 .25 L
.81526 .25 L
.81527 .25 L
.81527 .25 L
.81528 .25 L
.81528 .25 L
.81529 .25 L
.8153 .25 L
.8153 .25 L
.81531 .25 L
.81531 .25 L
.81532 .25 L
.81532 .25 L
.81533 .25 L
.81534 .25 L
.81534 .25 L
.81535 .25 L
.81535 .25 L
.81536 .25 L
.81536 .25 L
.81537 .25 L
.81537 .25 L
.81538 .25 L
.81539 .25 L
.81539 .25 L
.8154 .25 L
.81541 .25 L
.81541 .25 L
.81542 .25 L
.81543 .25 L
.81543 .25 L
.81544 .25 L
.81545 .25 L
.81545 .25 L
.81546 .25 L
.81546 .25 L
.81547 .25 L
.81547 .25 L
.81548 .25 L
.81549 .25 L
.81549 .25 L
.8155 .25 L
.8155 .25 L
.81551 .25 L
.81552 .25 L
.81552 .25 L
.81553 .25 L
.81553 .25 L
.81554 .25 L
Mistroke
.81555 .25 L
.81555 .25 L
.81556 .25 L
.81556 .25 L
.81557 .25 L
.81557 .25 L
.81558 .25 L
.81558 .25 L
.81559 .25 L
.81559 .25 L
.8156 .25 L
.8156 .25 L
.81561 .25 L
.81562 .25 L
.81562 .25 L
.81563 .25 L
.81563 .25 L
.81564 .25 L
.81564 .25 L
.81565 .25 L
.81565 .25 L
.81566 .25 L
.81566 .25 L
.81567 .25 L
.81568 .25 L
.81568 .25 L
.81569 .25 L
.81569 .25 L
.8157 .25 L
.81571 .25 L
.81571 .25 L
.81572 .25 L
.81572 .25 L
.81573 .25 L
.81574 .25 L
.81574 .25 L
.81575 .25 L
.81575 .25 L
.81576 .25 L
.81577 .25 L
.81577 .25 L
.81578 .25 L
.81579 .25 L
.81579 .25 L
.8158 .25 L
.8158 .25 L
.81581 .25 L
.81581 .25 L
.81581 .25 L
.81582 .25 L
Mistroke
.81583 .25 L
.81583 .25 L
.81584 .25 L
.81585 .25 L
.81585 .25 L
.81586 .25 L
.81586 .25 L
.81587 .25 L
.81588 .25 L
.81588 .25 L
.81589 .25 L
.8159 .25 L
.8159 .25 L
.81591 .25 L
.81592 .25 L
.81592 .25 L
.81593 .25 L
.81593 .25 L
.81594 .25 L
.81594 .25 L
.81595 .25 L
.81595 .25 L
.81595 .25 L
.81596 .25 L
.81596 .25 L
.81597 .25 L
.81597 .25 L
.81597 .25 L
.81598 .25 L
.81598 .25 L
.81599 .25 L
.81599 .25 L
.816 .25 L
.816 .25 L
.81601 .25 L
.81602 .25 L
.81602 .25 L
.81603 .25 L
.81604 .25 L
.81604 .25 L
.81605 .25 L
.81605 .25 L
.81606 .25 L
.81607 .25 L
.81607 .25 L
.81608 .25 L
.81609 .25 L
.81609 .25 L
.81609 .25 L
.8161 .25 L
Mistroke
.81611 .25 L
.81611 .25 L
.81612 .25 L
.81613 .25 L
.81613 .25 L
.81614 .25 L
.81614 .25 L
.81615 .25 L
.81615 .25 L
.81616 .25 L
.81617 .25 L
.81617 .25 L
.81618 .25 L
.81618 .25 L
.81619 .25 L
.81619 .25 L
.8162 .25 L
.8162 .25 L
.81621 .25 L
.81622 .25 L
.81623 .25 L
.81623 .25 L
.81624 .25 L
.81624 .25 L
.81625 .25 L
.81626 .25 L
.81626 .25 L
.81627 .25 L
.81627 .25 L
.81628 .25 L
.81629 .25 L
.81629 .25 L
.8163 .25 L
.8163 .25 L
.81631 .25 L
.81632 .25 L
.81632 .25 L
.81633 .25 L
.81633 .25 L
.81634 .25 L
.81634 .25 L
.81635 .25 L
.81636 .25 L
.81636 .25 L
.81637 .25 L
.81638 .25 L
.81638 .25 L
.81639 .25 L
.81639 .25 L
.81639 .25 L
Mistroke
.8164 .25 L
.81641 .25 L
.81641 .25 L
.81642 .25 L
.81642 .25 L
.81643 .25 L
.81643 .25 L
.81644 .25 L
.81645 .25 L
.81645 .25 L
.81646 .25 L
.81646 .25 L
.81647 .25 L
.81647 .25 L
.81648 .25 L
.81648 .25 L
.81649 .25 L
.81649 .25 L
.8165 .25 L
.81651 .25 L
.81651 .25 L
.81652 .25 L
.81652 .25 L
.81653 .25 L
.81653 .25 L
.81654 .25 L
.81655 .25 L
.81655 .25 L
.81656 .25 L
.81657 .25 L
.81657 .25 L
.81658 .25 L
.81658 .25 L
.81659 .25 L
.8166 .25 L
.8166 .25 L
.81661 .25 L
.81662 .25 L
.81662 .25 L
.81663 .25 L
.81663 .25 L
.81663 .25 L
.81664 .25 L
.81664 .25 L
.81665 .25 L
.81666 .25 L
.81666 .25 L
.81667 .25 L
.81668 .25 L
.81668 .25 L
Mistroke
.81669 .25 L
.81669 .25 L
.8167 .25 L
.81671 .25 L
.81671 .25 L
.81672 .25 L
.81673 .25 L
.81673 .25 L
.81674 .25 L
.81675 .25 L
.81675 .25 L
.81675 .25 L
.81676 .25 L
.81677 .25 L
.81677 .25 L
.81677 .25 L
.81678 .25 L
.81678 .25 L
.81679 .25 L
.81679 .25 L
.81679 .25 L
.8168 .25 L
.8168 .25 L
.81681 .25 L
.81681 .25 L
.81681 .25 L
.81682 .25 L
.81683 .25 L
.81683 .25 L
.81684 .25 L
.81685 .25 L
.81685 .25 L
.81686 .25 L
.81686 .25 L
.81687 .25 L
.81688 .25 L
.81688 .25 L
.81689 .25 L
.8169 .25 L
.8169 .25 L
.81691 .25 L
.81691 .25 L
.81692 .25 L
.81692 .25 L
.81693 .25 L
.81694 .25 L
.81694 .25 L
.81695 .25 L
.81695 .25 L
.81696 .25 L
Mistroke
.81697 .25 L
.81697 .25 L
.81698 .25 L
.81698 .25 L
.81699 .25 L
.817 .25 L
.817 .25 L
.81701 .25 L
.81701 .25 L
.81702 .25 L
.81702 .25 L
.81703 .25 L
.81703 .25 L
.81704 .25 L
.81705 .25 L
.81705 .25 L
.81706 .25 L
.81707 .25 L
.81707 .25 L
.81708 .25 L
.81709 .25 L
.81709 .25 L
.8171 .25 L
.8171 .25 L
.81711 .25 L
.81712 .25 L
.81712 .25 L
.81713 .25 L
.81713 .25 L
.81714 .25 L
.81714 .25 L
.81715 .25 L
.81716 .25 L
.81716 .25 L
.81717 .25 L
.81717 .25 L
.81718 .25 L
.81719 .25 L
.81719 .25 L
.8172 .25 L
.8172 .25 L
.81721 .25 L
.81721 .25 L
.81722 .25 L
.81722 .25 L
.81723 .25 L
.81724 .25 L
.81724 .25 L
.81724 .25 L
.81725 .25 L
Mistroke
.81726 .25 L
.81726 .25 L
.81727 .25 L
.81727 .25 L
.81728 .25 L
.81729 .25 L
.81729 .25 L
.8173 .25 L
.8173 .25 L
.81731 .25 L
.81731 .25 L
.81732 .25 L
.81732 .25 L
.81733 .25 L
.81734 .25 L
.81734 .25 L
.81735 .25 L
.81735 .25 L
.81736 .25 L
.81736 .25 L
.81737 .25 L
.81738 .25 L
.81738 .25 L
.81739 .25 L
.8174 .25 L
.8174 .25 L
.81741 .25 L
.81741 .25 L
.81742 .25 L
.81743 .25 L
.81743 .25 L
.81744 .25 L
.81745 .25 L
.81745 .25 L
.81745 .25 L
.81746 .25 L
.81746 .25 L
.81747 .25 L
.81747 .25 L
.81748 .25 L
.81749 .25 L
.81749 .25 L
.8175 .25 L
.81751 .25 L
.81751 .25 L
.81752 .25 L
.81753 .25 L
.81753 .25 L
.81754 .25 L
.81754 .25 L
Mistroke
.81755 .25 L
.81756 .25 L
.81756 .25 L
.81757 .25 L
.81757 .25 L
.81758 .25 L
.81758 .25 L
.81759 .25 L
.81759 .25 L
.8176 .25 L
.8176 .25 L
.81761 .25 L
.81761 .25 L
.81761 .25 L
.81762 .25 L
.81762 .25 L
.81763 .25 L
.81763 .25 L
.81763 .25 L
.81764 .25 L
.81764 .25 L
.81765 .25 L
.81766 .25 L
.81766 .25 L
.81767 .25 L
.81768 .25 L
.81768 .25 L
.81769 .25 L
.81769 .25 L
.8177 .25 L
.81771 .25 L
.81771 .25 L
.81772 .25 L
.81773 .25 L
.81773 .25 L
.81774 .25 L
.81774 .25 L
.81775 .25 L
.81775 .25 L
.81776 .25 L
.81777 .25 L
.81777 .25 L
.81778 .25 L
.81778 .25 L
.81779 .25 L
.81779 .25 L
.8178 .25 L
.81781 .25 L
.81781 .25 L
.81782 .25 L
Mistroke
.81783 .25 L
.81783 .25 L
.81784 .25 L
.81784 .25 L
.81785 .25 L
.81785 .25 L
.81786 .25 L
.81787 .25 L
.81787 .25 L
.81788 .25 L
.81788 .25 L
.81789 .25 L
.8179 .25 L
.8179 .25 L
.81791 .25 L
.81792 .25 L
.81792 .25 L
.81793 .25 L
.81794 .25 L
.81794 .25 L
.81794 .25 L
.81795 .25 L
.81796 .25 L
.81796 .25 L
.81797 .25 L
.81797 .25 L
.81798 .25 L
.81799 .25 L
.81799 .25 L
.818 .25 L
.818 .25 L
.81801 .25 L
.81802 .25 L
.81802 .25 L
.81803 .25 L
.81803 .25 L
.81804 .25 L
.81804 .25 L
.81805 .25 L
.81805 .25 L
.81806 .25 L
.81807 .25 L
.81807 .25 L
.81808 .25 L
.81809 .25 L
.81809 .25 L
.8181 .25 L
.8181 .25 L
.81811 .25 L
.81812 .25 L
Mistroke
.81812 .25 L
.81813 .25 L
.81814 .25 L
.81814 .25 L
.81815 .25 L
.81815 .25 L
.81816 .25 L
.81816 .25 L
.81817 .25 L
.81818 .25 L
.81818 .25 L
.81819 .25 L
.81819 .25 L
.8182 .25 L
.81821 .25 L
.81821 .25 L
.81822 .25 L
.81822 .25 L
.81823 .25 L
.81824 .25 L
.81824 .25 L
.81824 .25 L
.81825 .25 L
.81826 .25 L
.81826 .25 L
.81827 .25 L
.81827 .25 L
.81828 .25 L
.81828 .25 L
.81829 .25 L
.81829 .25 L
.8183 .25 L
.81831 .25 L
.81831 .25 L
.81832 .25 L
.81832 .25 L
.81833 .25 L
.81833 .25 L
.81834 .25 L
.81834 .25 L
.81835 .25 L
.81836 .25 L
.81836 .25 L
.81837 .25 L
.81837 .25 L
.81838 .25 L
.81838 .25 L
.81839 .25 L
.8184 .25 L
.8184 .25 L
Mistroke
.81841 .25 L
.81842 .25 L
.81842 .25 L
.81843 .25 L
.81843 .25 L
.81844 .25 L
.81845 .25 L
.81845 .25 L
.81846 .25 L
.81847 .25 L
.81847 .25 L
.81848 .25 L
.81848 .25 L
.81848 .25 L
.81849 .25 L
.81849 .25 L
.8185 .25 L
.81851 .25 L
.81851 .25 L
.81852 .25 L
.81853 .25 L
.81853 .25 L
.81854 .25 L
.81854 .25 L
.81855 .25 L
.81856 .25 L
.81856 .25 L
.81857 .25 L
.81858 .25 L
.81858 .25 L
.81859 .25 L
.8186 .25 L
.8186 .25 L
.8186 .25 L
.81861 .25 L
.81861 .25 L
.81862 .25 L
.81862 .25 L
.81863 .25 L
.81863 .25 L
.81864 .25 L
.81864 .25 L
.81864 .25 L
.81865 .25 L
.81865 .25 L
.81866 .25 L
.81866 .25 L
.81866 .25 L
.81867 .25 L
.81868 .25 L
Mistroke
.81868 .25 L
.81869 .25 L
.8187 .25 L
.8187 .25 L
.81871 .25 L
.81871 .25 L
.81872 .25 L
.81873 .25 L
.81873 .25 L
.81874 .25 L
.81875 .25 L
.81875 .25 L
.81876 .25 L
.81876 .25 L
.81877 .25 L
.81877 .25 L
.81878 .25 L
.81879 .25 L
.81879 .25 L
.8188 .25 L
.8188 .25 L
.81881 .25 L
.81882 .25 L
.81882 .25 L
.81883 .25 L
.81883 .25 L
.81884 .25 L
.81885 .25 L
.81885 .25 L
.81886 .25 L
.81886 .25 L
.81887 .25 L
.81887 .25 L
.81888 .25 L
.81888 .25 L
.81889 .25 L
.8189 .25 L
.8189 .25 L
.81891 .25 L
.81892 .25 L
.81892 .25 L
.81893 .25 L
.81894 .25 L
.81894 .25 L
.81895 .25 L
.81895 .25 L
.81896 .25 L
.81897 .25 L
.81897 .25 L
.81898 .25 L
Mistroke
.81898 .25 L
.81899 .25 L
.81899 .25 L
.819 .25 L
.81901 .25 L
.81901 .25 L
.81902 .25 L
.81902 .25 L
.81903 .25 L
.81904 .25 L
.81904 .25 L
.81905 .25 L
.81905 .25 L
.81906 .25 L
.81906 .25 L
.81907 .25 L
.81907 .25 L
.81908 .25 L
.81909 .25 L
.81909 .25 L
.81909 .25 L
.8191 .25 L
.81911 .25 L
.81911 .25 L
.81912 .25 L
.81912 .25 L
.81913 .25 L
.81914 .25 L
.81914 .25 L
.81915 .25 L
.81915 .25 L
.81916 .25 L
.81916 .25 L
.81917 .25 L
.81917 .25 L
.81918 .25 L
.81919 .25 L
.81919 .25 L
.8192 .25 L
.8192 .25 L
.81921 .25 L
.81921 .25 L
.81922 .25 L
.81923 .25 L
.81923 .25 L
.81924 .25 L
.81925 .25 L
.81925 .25 L
.81926 .25 L
.81926 .25 L
Mistroke
.81927 .25 L
.81928 .25 L
.81928 .25 L
.81929 .25 L
.8193 .25 L
.8193 .25 L
.8193 .25 L
.81931 .25 L
.81931 .25 L
.81932 .25 L
.81932 .25 L
.81933 .25 L
.81934 .25 L
.81934 .25 L
.81935 .25 L
.81936 .25 L
.81936 .25 L
.81937 .25 L
.81938 .25 L
.81938 .25 L
.81939 .25 L
.81939 .25 L
.8194 .25 L
.81941 .25 L
.81941 .25 L
.81942 .25 L
.81942 .25 L
.81943 .25 L
.81944 .25 L
.81944 .25 L
.81944 .25 L
.81945 .25 L
.81945 .25 L
.81946 .25 L
.81946 .25 L
.81946 .25 L
.81947 .25 L
.81947 .25 L
.81948 .25 L
.81948 .25 L
.81948 .25 L
.81949 .25 L
.81949 .25 L
.8195 .25 L
.81951 .25 L
.81951 .25 L
.81952 .25 L
.81953 .25 L
.81953 .25 L
.81954 .25 L
Mistroke
.81954 .25 L
.81955 .25 L
.81956 .25 L
.81956 .25 L
.81957 .25 L
.81958 .25 L
.81958 .25 L
.81959 .25 L
.81959 .25 L
.8196 .25 L
.8196 .25 L
.81961 .25 L
.81962 .25 L
.81962 .25 L
.81963 .25 L
.81963 .25 L
.81964 .25 L
.81965 .25 L
.81965 .25 L
.81966 .25 L
.81966 .25 L
.81967 .25 L
.81968 .25 L
.81968 .25 L
.81969 .25 L
.81969 .25 L
.8197 .25 L
.8197 .25 L
.81971 .25 L
.81972 .25 L
.81972 .25 L
.81973 .25 L
.81973 .25 L
.81974 .25 L
.81975 .25 L
.81975 .25 L
.81976 .25 L
.81977 .25 L
.81977 .25 L
.81978 .25 L
.81979 .25 L
.81979 .25 L
.81979 .25 L
.8198 .25 L
.81981 .25 L
.81981 .25 L
.81982 .25 L
.81983 .25 L
.81983 .25 L
.81984 .25 L
Mistroke
.81984 .25 L
.81985 .25 L
.81985 .25 L
.81986 .25 L
.81987 .25 L
.81987 .25 L
.81988 .25 L
.81988 .25 L
.81989 .25 L
.81989 .25 L
.8199 .25 L
.8199 .25 L
.81991 .25 L
.81991 .25 L
.81992 .25 L
.81992 .25 L
.81993 .25 L
.81994 .25 L
.81994 .25 L
.81995 .25 L
.81996 .25 L
.81996 .25 L
.81997 .25 L
.81997 .25 L
.81998 .25 L
.81998 .25 L
.81998 .25 L
.81999 .25 L
.82 .25 L
.82 .25 L
.82001 .25 L
.82002 .25 L
.82002 .25 L
.82003 .25 L
.82003 .25 L
.82004 .25 L
.82004 .25 L
.82005 .25 L
.82006 .25 L
.82006 .25 L
.82007 .25 L
.82008 .25 L
.82008 .25 L
.82009 .25 L
.82009 .25 L
.8201 .25 L
.82011 .25 L
.82011 .25 L
.82012 .25 L
.82012 .25 L
Mistroke
.82013 .25 L
.82013 .25 L
.82014 .25 L
.82014 .25 L
.82015 .25 L
.82015 .25 L
.82016 .25 L
.82017 .25 L
.82017 .25 L
.82018 .25 L
.82019 .25 L
.82019 .25 L
.8202 .25 L
.82021 .25 L
.82021 .25 L
.82022 .25 L
.82023 .25 L
.82023 .25 L
.82024 .25 L
.82024 .25 L
.82025 .25 L
.82025 .25 L
.82026 .25 L
.82026 .25 L
.82027 .25 L
.82027 .25 L
.82027 .25 L
.82028 .25 L
.82028 .25 L
.82029 .25 L
.82029 .25 L
.8203 .25 L
.8203 .25 L
.8203 .25 L
.82031 .25 L
.82031 .25 L
.82032 .25 L
.82032 .25 L
.82033 .25 L
.82034 .25 L
.82034 .25 L
.82035 .25 L
.82036 .25 L
.82036 .25 L
.82037 .25 L
.82037 .25 L
.82038 .25 L
.82039 .25 L
.82039 .25 L
.8204 .25 L
Mistroke
.82041 .25 L
.82041 .25 L
.82041 .25 L
.82042 .25 L
.82043 .25 L
.82043 .25 L
.82044 .25 L
.82045 .25 L
.82045 .25 L
.82046 .25 L
.82046 .25 L
.82047 .25 L
.82047 .25 L
.82048 .25 L
.82049 .25 L
.82049 .25 L
.8205 .25 L
.82051 .25 L
.82051 .25 L
.82051 .25 L
.82052 .25 L
.82053 .25 L
.82053 .25 L
.82054 .25 L
.82055 .25 L
.82055 .25 L
.82056 .25 L
.82056 .25 L
.82057 .25 L
.82058 .25 L
.82058 .25 L
.82059 .25 L
.8206 .25 L
.8206 .25 L
.82061 .25 L
.82061 .25 L
.82062 .25 L
.82062 .25 L
.82063 .25 L
.82064 .25 L
.82064 .25 L
.82065 .25 L
.82065 .25 L
.82066 .25 L
.82067 .25 L
.82067 .25 L
.82068 .25 L
.82068 .25 L
.82069 .25 L
.8207 .25 L
Mistroke
.8207 .25 L
.82071 .25 L
.82071 .25 L
.82072 .25 L
.82072 .25 L
.82073 .25 L
.82073 .25 L
.82074 .25 L
.82074 .25 L
.82075 .25 L
.82075 .25 L
.82076 .25 L
.82077 .25 L
.82077 .25 L
.82078 .25 L
.82079 .25 L
.82079 .25 L
.82079 .25 L
.8208 .25 L
.8208 .25 L
.82081 .25 L
.82081 .25 L
.82082 .25 L
.82083 .25 L
.82083 .25 L
.82084 .25 L
.82084 .25 L
.82085 .25 L
.82086 .25 L
.82086 .25 L
.82087 .25 L
.82087 .25 L
.82088 .25 L
.82089 .25 L
.82089 .25 L
.8209 .25 L
.8209 .25 L
.82091 .25 L
.82092 .25 L
.82092 .25 L
.82093 .25 L
.82094 .25 L
.82094 .25 L
.82095 .25 L
.82095 .25 L
.82096 .25 L
.82096 .25 L
.82097 .25 L
.82097 .25 L
.82098 .25 L
Mistroke
.82099 .25 L
.82099 .25 L
.821 .25 L
.821 .25 L
.82101 .25 L
.82102 .25 L
.82102 .25 L
.82103 .25 L
.82104 .25 L
.82104 .25 L
.82105 .25 L
.82106 .25 L
.82106 .25 L
.82107 .25 L
.82107 .25 L
.82108 .25 L
.82108 .25 L
.82109 .25 L
.82109 .25 L
.82109 .25 L
.8211 .25 L
.8211 .25 L
.82111 .25 L
.82111 .25 L
.82111 .25 L
.82112 .25 L
.82112 .25 L
.82113 .25 L
.82113 .25 L
.82113 .25 L
.82114 .25 L
.82115 .25 L
.82115 .25 L
.82116 .25 L
.82117 .25 L
.82117 .25 L
.82118 .25 L
.82118 .25 L
.82119 .25 L
.8212 .25 L
.8212 .25 L
.82121 .25 L
.82122 .25 L
.82122 .25 L
.82123 .25 L
.82123 .25 L
.82124 .25 L
.82124 .25 L
.82125 .25 L
.82126 .25 L
Mistroke
.82126 .25 L
.82127 .25 L
.82128 .25 L
.82128 .25 L
.82129 .25 L
.82129 .25 L
.8213 .25 L
.8213 .25 L
.82131 .25 L
.82132 .25 L
.82132 .25 L
.82133 .25 L
.82133 .25 L
.82134 .25 L
.82134 .25 L
.82135 .25 L
.82136 .25 L
.82136 .25 L
.82137 .25 L
.82138 .25 L
.82138 .25 L
.82139 .25 L
.82139 .25 L
.8214 .25 L
.82141 .25 L
.82141 .25 L
.82142 .25 L
.82143 .25 L
.82143 .25 L
.82144 .25 L
.82144 .25 L
.82145 .25 L
.82145 .25 L
.82146 .25 L
.82147 .25 L
.82147 .25 L
.82148 .25 L
.82148 .25 L
.82149 .25 L
.82149 .25 L
.8215 .25 L
.82151 .25 L
.82151 .25 L
.82152 .25 L
.82152 .25 L
.82153 .25 L
.82154 .25 L
.82154 .25 L
.82154 .25 L
.82155 .25 L
Mistroke
.82156 .25 L
.82156 .25 L
.82157 .25 L
.82158 .25 L
.82158 .25 L
.82159 .25 L
.8216 .25 L
.8216 .25 L
.82161 .25 L
.82162 .25 L
.82162 .25 L
.82163 .25 L
.82164 .25 L
.82164 .25 L
.82164 .25 L
.82165 .25 L
.82166 .25 L
.82166 .25 L
.82167 .25 L
.82167 .25 L
.82168 .25 L
.82169 .25 L
.82169 .25 L
.8217 .25 L
.8217 .25 L
.82171 .25 L
.82172 .25 L
.82172 .25 L
.82173 .25 L
.82173 .25 L
.82174 .25 L
.82174 .25 L
.82175 .25 L
.82175 .25 L
.82176 .25 L
.82176 .25 L
.82177 .25 L
.82177 .25 L
.82178 .25 L
.82179 .25 L
.82179 .25 L
.8218 .25 L
.8218 .25 L
.82181 .25 L
.82182 .25 L
.82182 .25 L
.82183 .25 L
.82183 .25 L
.82183 .25 L
.82184 .25 L
Mistroke
.82185 .25 L
.82185 .25 L
.82186 .25 L
.82186 .25 L
.82187 .25 L
.82188 .25 L
.82188 .25 L
.82189 .25 L
.82189 .25 L
.8219 .25 L
.82191 .25 L
.82191 .25 L
.82192 .25 L
.82193 .25 L
.82193 .25 L
.82194 .25 L
.82194 .25 L
.82195 .25 L
.82196 .25 L
.82196 .25 L
.82197 .25 L
.82197 .25 L
.82198 .25 L
.82198 .25 L
.82199 .25 L
.82199 .25 L
.822 .25 L
.822 .25 L
.82201 .25 L
.82202 .25 L
.82202 .25 L
.82203 .25 L
.82204 .25 L
.82204 .25 L
.82205 .25 L
.82206 .25 L
.82206 .25 L
.82207 .25 L
.82207 .25 L
.82208 .25 L
.82209 .25 L
.82209 .25 L
.8221 .25 L
.8221 .25 L
.82211 .25 L
.82211 .25 L
.82212 .25 L
.82212 .25 L
.82212 .25 L
.82213 .25 L
Mistroke
.82213 .25 L
.82214 .25 L
.82214 .25 L
.82215 .25 L
.82215 .25 L
.82215 .25 L
.82216 .25 L
.82216 .25 L
.82217 .25 L
.82217 .25 L
.82218 .25 L
.82219 .25 L
.82219 .25 L
.8222 .25 L
.82221 .25 L
.82221 .25 L
.82222 .25 L
.82222 .25 L
.82223 .25 L
.82224 .25 L
.82224 .25 L
.82225 .25 L
.82226 .25 L
.82226 .25 L
.82226 .25 L
.82227 .25 L
.82228 .25 L
.82228 .25 L
.82229 .25 L
.8223 .25 L
.8223 .25 L
.82231 .25 L
.82231 .25 L
.82232 .25 L
.82232 .25 L
.82233 .25 L
.82234 .25 L
.82234 .25 L
.82235 .25 L
.82236 .25 L
.82236 .25 L
.82236 .25 L
.82237 .25 L
.82238 .25 L
.82238 .25 L
.82239 .25 L
.8224 .25 L
.8224 .25 L
.82241 .25 L
.82241 .25 L
Mistroke
.82242 .25 L
.82243 .25 L
.82243 .25 L
.82244 .25 L
.82245 .25 L
.82245 .25 L
.82246 .25 L
.82246 .25 L
.82247 .25 L
.82247 .25 L
.82248 .25 L
.82249 .25 L
.82249 .25 L
.8225 .25 L
.8225 .25 L
.82251 .25 L
.82252 .25 L
.82252 .25 L
.82253 .25 L
.82253 .25 L
.82254 .25 L
.82255 .25 L
.82255 .25 L
.82256 .25 L
.82256 .25 L
.82257 .25 L
.82257 .25 L
.82258 .25 L
.82258 .25 L
.82259 .25 L
.82259 .25 L
.8226 .25 L
.8226 .25 L
.82261 .25 L
.82262 .25 L
.82262 .25 L
.82263 .25 L
.82264 .25 L
.82264 .25 L
.82264 .25 L
.82265 .25 L
.82265 .25 L
.82266 .25 L
.82266 .25 L
.82267 .25 L
.82268 .25 L
.82268 .25 L
.82269 .25 L
.82269 .25 L
.8227 .25 L
Mistroke
.82271 .25 L
.82271 .25 L
.82272 .25 L
.82272 .25 L
.82273 .25 L
.82274 .25 L
.82274 .25 L
.82275 .25 L
.82276 .25 L
.82276 .25 L
.82277 .25 L
.82277 .25 L
.82278 .25 L
.82279 .25 L
.82279 .25 L
.8228 .25 L
.8228 .25 L
.82281 .25 L
.82281 .25 L
.82282 .25 L
.82282 .25 L
.82283 .25 L
.82284 .25 L
.82284 .25 L
.82285 .25 L
.82285 .25 L
.82286 .25 L
.82287 .25 L
.82287 .25 L
.82288 .25 L
.82289 .25 L
.82289 .25 L
.8229 .25 L
.82291 .25 L
.82291 .25 L
.82292 .25 L
.82292 .25 L
.82293 .25 L
.82293 .25 L
.82294 .25 L
.82294 .25 L
.82294 .25 L
.82295 .25 L
.82295 .25 L
.82296 .25 L
.82296 .25 L
.82297 .25 L
.82297 .25 L
.82297 .25 L
.82298 .25 L
Mistroke
.82298 .25 L
.82298 .25 L
.82299 .25 L
.823 .25 L
.823 .25 L
.82301 .25 L
.82302 .25 L
.82302 .25 L
.82303 .25 L
.82304 .25 L
.82304 .25 L
.82305 .25 L
.82305 .25 L
.82306 .25 L
.82307 .25 L
.82307 .25 L
.82308 .25 L
.82308 .25 L
.82309 .25 L
.8231 .25 L
.8231 .25 L
.82311 .25 L
.82311 .25 L
.82312 .25 L
.82313 .25 L
.82313 .25 L
.82314 .25 L
.82314 .25 L
.82315 .25 L
.82315 .25 L
.82316 .25 L
.82317 .25 L
.82317 .25 L
.82318 .25 L
.82318 .25 L
.82319 .25 L
.82319 .25 L
.8232 .25 L
.82321 .25 L
.82321 .25 L
.82322 .25 L
.82323 .25 L
.82323 .25 L
.82324 .25 L
.82324 .25 L
.82325 .25 L
.82326 .25 L
.82326 .25 L
.82327 .25 L
.82328 .25 L
Mistroke
.82328 .25 L
.82329 .25 L
.82329 .25 L
.8233 .25 L
.8233 .25 L
.82331 .25 L
.82332 .25 L
.82332 .25 L
.82333 .25 L
.82333 .25 L
.82334 .25 L
.82335 .25 L
.82335 .25 L
.82336 .25 L
.82336 .25 L
.82337 .25 L
.82338 .25 L
.82338 .25 L
.82339 .25 L
.82339 .25 L
.8234 .25 L
.8234 .25 L
.82341 .25 L
.82341 .25 L
.82342 .25 L
.82342 .25 L
.82343 .25 L
.82343 .25 L
.82344 .25 L
.82345 .25 L
.82345 .25 L
.82346 .25 L
.82346 .25 L
.82347 .25 L
.82347 .25 L
.82348 .25 L
.82348 .25 L
.82349 .25 L
.82349 .25 L
.8235 .25 L
.82351 .25 L
.82351 .25 L
.82352 .25 L
.82352 .25 L
.82353 .25 L
.82354 .25 L
.82354 .25 L
.82355 .25 L
.82355 .25 L
.82356 .25 L
Mistroke
.82357 .25 L
.82357 .25 L
.82358 .25 L
.82359 .25 L
.82359 .25 L
.8236 .25 L
.8236 .25 L
.82361 .25 L
.82362 .25 L
.82362 .25 L
.82363 .25 L
.82363 .25 L
.82363 .25 L
.82364 .25 L
.82365 .25 L
.82365 .25 L
.82366 .25 L
.82367 .25 L
.82367 .25 L
.82368 .25 L
.82368 .25 L
.82369 .25 L
.8237 .25 L
.8237 .25 L
.82371 .25 L
.82372 .25 L
.82372 .25 L
.82373 .25 L
.82374 .25 L
.82374 .25 L
.82375 .25 L
.82375 .25 L
.82376 .25 L
.82376 .25 L
.82376 .25 L
.82377 .25 L
.82377 .25 L
.82378 .25 L
.82378 .25 L
.82379 .25 L
.82379 .25 L
.82379 .25 L
.8238 .25 L
.8238 .25 L
.8238 .25 L
.82381 .25 L
.82381 .25 L
.82382 .25 L
.82383 .25 L
.82383 .25 L
Mistroke
.82384 .25 L
.82385 .25 L
.82385 .25 L
.82386 .25 L
.82387 .25 L
.82387 .25 L
.82388 .25 L
.82388 .25 L
.82389 .25 L
.8239 .25 L
.8239 .25 L
.82391 .25 L
.82391 .25 L
.82392 .25 L
.82393 .25 L
.82393 .25 L
.82394 .25 L
.82394 .25 L
.82395 .25 L
.82396 .25 L
.82396 .25 L
.82397 .25 L
.82397 .25 L
.82398 .25 L
.82398 .25 L
.82399 .25 L
.824 .25 L
.824 .25 L
.82401 .25 L
.82401 .25 L
.82402 .25 L
.82402 .25 L
.82403 .25 L
.82404 .25 L
.82404 .25 L
.82405 .25 L
.82406 .25 L
.82406 .25 L
.82407 .25 L
.82407 .25 L
.82408 .25 L
.82409 .25 L
.82409 .25 L
.8241 .25 L
.82411 .25 L
.82411 .25 L
.82411 .25 L
.82412 .25 L
.82413 .25 L
.82413 .25 L
Mistroke
.82414 .25 L
.82415 .25 L
.82415 .25 L
.82416 .25 L
.82416 .25 L
.82417 .25 L
.82417 .25 L
.82418 .25 L
.82419 .25 L
.82419 .25 L
.8242 .25 L
.82421 .25 L
.82421 .25 L
.82421 .25 L
.82422 .25 L
.82423 .25 L
.82423 .25 L
.82424 .25 L
.82424 .25 L
.82425 .25 L
.82425 .25 L
.82426 .25 L
.82426 .25 L
.82427 .25 L
.82428 .25 L
.82428 .25 L
.82429 .25 L
.82429 .25 L
.8243 .25 L
.8243 .25 L
.8243 .25 L
.82431 .25 L
.82432 .25 L
.82432 .25 L
.82433 .25 L
.82434 .25 L
.82434 .25 L
.82435 .25 L
.82435 .25 L
.82436 .25 L
.82437 .25 L
.82437 .25 L
.82438 .25 L
.82438 .25 L
.82439 .25 L
.8244 .25 L
.8244 .25 L
.82441 .25 L
.82442 .25 L
.82442 .25 L
Mistroke
.82443 .25 L
.82444 .25 L
.82444 .25 L
.82445 .25 L
.82445 .25 L
.82445 .25 L
.82446 .25 L
.82446 .25 L
.82447 .25 L
.82448 .25 L
.82448 .25 L
.82449 .25 L
.8245 .25 L
.8245 .25 L
.82451 .25 L
.82451 .25 L
.82452 .25 L
.82453 .25 L
.82453 .25 L
.82454 .25 L
.82455 .25 L
.82455 .25 L
.82456 .25 L
.82457 .25 L
.82457 .25 L
.82457 .25 L
.82458 .25 L
.82458 .25 L
.82459 .25 L
.82459 .25 L
.82459 .25 L
.8246 .25 L
.82461 .25 L
.82461 .25 L
.82461 .25 L
.82462 .25 L
.82462 .25 L
.82462 .25 L
.82463 .25 L
.82463 .25 L
.82464 .25 L
.82464 .25 L
.82465 .25 L
.82466 .25 L
.82466 .25 L
.82467 .25 L
.82468 .25 L
.82468 .25 L
.82469 .25 L
.82469 .25 L
Mistroke
.8247 .25 L
.82471 .25 L
.82471 .25 L
.82472 .25 L
.82473 .25 L
.82473 .25 L
.82474 .25 L
.82474 .25 L
.82475 .25 L
.82475 .25 L
.82476 .25 L
.82477 .25 L
.82477 .25 L
.82478 .25 L
.82478 .25 L
.82479 .25 L
.8248 .25 L
.8248 .25 L
.82481 .25 L
.82481 .25 L
.82482 .25 L
.82483 .25 L
.82483 .25 L
.82483 .25 L
.82484 .25 L
.82485 .25 L
.82485 .25 L
.82486 .25 L
.82487 .25 L
.82487 .25 L
.82488 .25 L
.82488 .25 L
.82489 .25 L
.8249 .25 L
.8249 .25 L
.82491 .25 L
.82492 .25 L
.82492 .25 L
.82493 .25 L
.82493 .25 L
.82494 .25 L
.82494 .25 L
.82495 .25 L
.82496 .25 L
.82496 .25 L
.82497 .25 L
.82498 .25 L
.82498 .25 L
.82499 .25 L
.82499 .25 L
Mistroke
.825 .25 L
.825 .25 L
.82501 .25 L
.82502 .25 L
.82502 .25 L
.82503 .25 L
.82503 .25 L
.82504 .25 L
.82504 .25 L
.82505 .25 L
.82506 .25 L
.82506 .25 L
.82507 .25 L
.82508 .25 L
.82508 .25 L
.82509 .25 L
.82509 .25 L
.8251 .25 L
.82511 .25 L
.82511 .25 L
.82512 .25 L
.82513 .25 L
.82513 .25 L
.82514 .25 L
.82514 .25 L
.82515 .25 L
.82515 .25 L
.82516 .25 L
.82517 .25 L
.82517 .25 L
.82518 .25 L
.82518 .25 L
.82519 .25 L
.8252 .25 L
.8252 .25 L
.82521 .25 L
.82521 .25 L
.82522 .25 L
.82523 .25 L
.82523 .25 L
.82524 .25 L
.82524 .25 L
.82525 .25 L
.82525 .25 L
.82526 .25 L
.82526 .25 L
.82527 .25 L
.82527 .25 L
.82528 .25 L
.82528 .25 L
Mistroke
.82529 .25 L
.8253 .25 L
.8253 .25 L
.82531 .25 L
.82531 .25 L
.82532 .25 L
.82532 .25 L
.82533 .25 L
.82533 .25 L
.82534 .25 L
.82534 .25 L
.82535 .25 L
.82536 .25 L
.82536 .25 L
.82537 .25 L
.82537 .25 L
.82538 .25 L
.82539 .25 L
.82539 .25 L
.8254 .25 L
.8254 .25 L
.82541 .25 L
.82542 .25 L
.82542 .25 L
.82543 .25 L
.82544 .25 L
.82544 .25 L
.82545 .25 L
.82545 .25 L
.82546 .25 L
.82547 .25 L
.82547 .25 L
.82548 .25 L
.82548 .25 L
.82548 .25 L
.82549 .25 L
.8255 .25 L
.8255 .25 L
.82551 .25 L
.82552 .25 L
.82552 .25 L
.82553 .25 L
.82553 .25 L
.82554 .25 L
.82555 .25 L
.82555 .25 L
.82556 .25 L
.82557 .25 L
.82557 .25 L
.82558 .25 L
Mistroke
.82559 .25 L
.82559 .25 L
.8256 .25 L
.8256 .25 L
.82561 .25 L
.82561 .25 L
.82561 .25 L
.82562 .25 L
.82562 .25 L
.82563 .25 L
.82563 .25 L
.82564 .25 L
.82564 .25 L
.82564 .25 L
.82565 .25 L
.82565 .25 L
.82565 .25 L
.82566 .25 L
.82566 .25 L
.82567 .25 L
.82568 .25 L
.82568 .25 L
.82569 .25 L
.8257 .25 L
.8257 .25 L
.82571 .25 L
.82572 .25 L
.82572 .25 L
.82573 .25 L
.82573 .25 L
.82574 .25 L
.82575 .25 L
.82575 .25 L
.82576 .25 L
.82576 .25 L
.82577 .25 L
.82578 .25 L
.82578 .25 L
.82579 .25 L
.82579 .25 L
.8258 .25 L
.82581 .25 L
.82581 .25 L
.82582 .25 L
.82582 .25 L
.82583 .25 L
.82584 .25 L
.82584 .25 L
.82585 .25 L
.82585 .25 L
Mistroke
.82586 .25 L
.82586 .25 L
.82587 .25 L
.82587 .25 L
.82588 .25 L
.82589 .25 L
.82589 .25 L
.8259 .25 L
.82591 .25 L
.82591 .25 L
.82592 .25 L
.82592 .25 L
.82593 .25 L
.82594 .25 L
.82594 .25 L
.82595 .25 L
.82596 .25 L
.82596 .25 L
.82596 .25 L
.82597 .25 L
.82598 .25 L
.82598 .25 L
.82599 .25 L
.826 .25 L
.826 .25 L
.82601 .25 L
.82601 .25 L
.82602 .25 L
.82603 .25 L
.82603 .25 L
.82604 .25 L
.82604 .25 L
.82605 .25 L
.82606 .25 L
.82606 .25 L
.82606 .25 L
.82607 .25 L
.82608 .25 L
.82608 .25 L
.82609 .25 L
.82609 .25 L
.8261 .25 L
.8261 .25 L
.82611 .25 L
.82611 .25 L
.82612 .25 L
.82613 .25 L
.82613 .25 L
.82614 .25 L
.82614 .25 L
Mistroke
.82615 .25 L
.82615 .25 L
.82615 .25 L
.82616 .25 L
.82617 .25 L
.82617 .25 L
.82618 .25 L
.82619 .25 L
.82619 .25 L
.8262 .25 L
.8262 .25 L
.82621 .25 L
.82622 .25 L
.82622 .25 L
.82623 .25 L
.82624 .25 L
.82624 .25 L
.82625 .25 L
.82625 .25 L
.82626 .25 L
.82627 .25 L
.82627 .25 L
.82628 .25 L
.82629 .25 L
.82629 .25 L
.8263 .25 L
.8263 .25 L
.8263 .25 L
.82631 .25 L
.82631 .25 L
.82632 .25 L
.82633 .25 L
.82633 .25 L
.82634 .25 L
.82635 .25 L
.82635 .25 L
.82636 .25 L
.82636 .25 L
.82637 .25 L
.82638 .25 L
.82638 .25 L
.82639 .25 L
.8264 .25 L
.8264 .25 L
.82641 .25 L
.82642 .25 L
.82642 .25 L
.82642 .25 L
.82643 .25 L
.82643 .25 L
Mistroke
.82644 .25 L
.82644 .25 L
.82645 .25 L
.82645 .25 L
.82646 .25 L
.82646 .25 L
.82646 .25 L
.82647 .25 L
.82647 .25 L
.82647 .25 L
.82648 .25 L
.82648 .25 L
.82649 .25 L
.8265 .25 L
.8265 .25 L
.82651 .25 L
.82652 .25 L
.82652 .25 L
.82653 .25 L
.82653 .25 L
.82654 .25 L
.82655 .25 L
.82655 .25 L
.82656 .25 L
.82656 .25 L
.82657 .25 L
.82658 .25 L
.82658 .25 L
.82659 .25 L
.82659 .25 L
.8266 .25 L
.82661 .25 L
.82661 .25 L
.82662 .25 L
.82662 .25 L
.82663 .25 L
.82663 .25 L
.82664 .25 L
.82665 .25 L
.82665 .25 L
.82666 .25 L
.82667 .25 L
.82667 .25 L
.82668 .25 L
.82668 .25 L
.82668 .25 L
.82669 .25 L
.8267 .25 L
.8267 .25 L
.82671 .25 L
Mistroke
.82672 .25 L
.82672 .25 L
.82673 .25 L
.82674 .25 L
.82674 .25 L
.82675 .25 L
.82675 .25 L
.82676 .25 L
.82677 .25 L
.82677 .25 L
.82678 .25 L
.82678 .25 L
.82679 .25 L
.8268 .25 L
.8268 .25 L
.82681 .25 L
.82681 .25 L
.82682 .25 L
.82683 .25 L
.82683 .25 L
.82684 .25 L
.82684 .25 L
.82685 .25 L
.82686 .25 L
.82686 .25 L
.82687 .25 L
.82687 .25 L
.82688 .25 L
.82688 .25 L
.82689 .25 L
.82689 .25 L
.8269 .25 L
.82691 .25 L
.82691 .25 L
.82691 .25 L
.82692 .25 L
.82693 .25 L
.82693 .25 L
.82694 .25 L
.82694 .25 L
.82695 .25 L
.82696 .25 L
.82696 .25 L
.82696 .25 L
.82697 .25 L
.82698 .25 L
.82698 .25 L
.82699 .25 L
.82699 .25 L
.827 .25 L
Mistroke
.827 .25 L
.82701 .25 L
.82702 .25 L
.82702 .25 L
.82703 .25 L
.82703 .25 L
.82704 .25 L
.82705 .25 L
.82705 .25 L
.82706 .25 L
.82707 .25 L
.82707 .25 L
.82708 .25 L
.82708 .25 L
.82709 .25 L
.8271 .25 L
.8271 .25 L
.82711 .25 L
.82712 .25 L
.82712 .25 L
.82712 .25 L
.82713 .25 L
.82713 .25 L
.82714 .25 L
.82714 .25 L
.82715 .25 L
.82716 .25 L
.82716 .25 L
.82717 .25 L
.82718 .25 L
.82718 .25 L
.82719 .25 L
.82719 .25 L
.8272 .25 L
.82721 .25 L
.82721 .25 L
.82722 .25 L
.82723 .25 L
.82723 .25 L
.82724 .25 L
.82724 .25 L
.82725 .25 L
.82725 .25 L
.82726 .25 L
.82726 .25 L
.82727 .25 L
.82727 .25 L
.82728 .25 L
.82728 .25 L
.82728 .25 L
Mistroke
.82729 .25 L
.82729 .25 L
.82729 .25 L
.8273 .25 L
.8273 .25 L
.82731 .25 L
.82731 .25 L
.82732 .25 L
.82733 .25 L
.82733 .25 L
.82734 .25 L
.82735 .25 L
.82735 .25 L
.82736 .25 L
.82736 .25 L
.82737 .25 L
.82738 .25 L
.82738 .25 L
.82739 .25 L
.8274 .25 L
.8274 .25 L
.82741 .25 L
.82741 .25 L
.82742 .25 L
.82742 .25 L
.82743 .25 L
.82744 .25 L
.82744 .25 L
.82745 .25 L
.82745 .25 L
.82746 .25 L
.82746 .25 L
.82747 .25 L
.82748 .25 L
.82748 .25 L
.82749 .25 L
.82749 .25 L
.8275 .25 L
.8275 .25 L
.82751 .25 L
.82751 .25 L
.82752 .25 L
.82753 .25 L
.82753 .25 L
.82754 .25 L
.82755 .25 L
.82755 .25 L
.82756 .25 L
.82757 .25 L
.82757 .25 L
Mistroke
.82758 .25 L
.82759 .25 L
.82759 .25 L
.8276 .25 L
.8276 .25 L
.82761 .25 L
.82761 .25 L
.82762 .25 L
.82763 .25 L
.82763 .25 L
.82764 .25 L
.82764 .25 L
.82765 .25 L
.82766 .25 L
.82766 .25 L
.82767 .25 L
.82767 .25 L
.82768 .25 L
.82769 .25 L
.82769 .25 L
.8277 .25 L
.8277 .25 L
.82771 .25 L
.82771 .25 L
.82772 .25 L
.82772 .25 L
.82773 .25 L
.82773 .25 L
.82774 .25 L
.82774 .25 L
.82775 .25 L
.82776 .25 L
.82776 .25 L
.82777 .25 L
.82777 .25 L
.82778 .25 L
.82778 .25 L
.82779 .25 L
.82779 .25 L
.8278 .25 L
.8278 .25 L
.82781 .25 L
.82782 .25 L
.82782 .25 L
.82783 .25 L
.82783 .25 L
.82784 .25 L
.82785 .25 L
.82785 .25 L
.82786 .25 L
Mistroke
.82786 .25 L
.82787 .25 L
.82788 .25 L
.82788 .25 L
.82789 .25 L
.82789 .25 L
.8279 .25 L
.82791 .25 L
.82791 .25 L
.82792 .25 L
.82793 .25 L
.82793 .25 L
.82794 .25 L
.82794 .25 L
.82795 .25 L
.82795 .25 L
.82795 .25 L
.82796 .25 L
.82797 .25 L
.82797 .25 L
.82798 .25 L
.82799 .25 L
.82799 .25 L
.828 .25 L
.828 .25 L
.82801 .25 L
.82802 .25 L
.82802 .25 L
.82803 .25 L
.82804 .25 L
.82804 .25 L
.82805 .25 L
.82806 .25 L
.82806 .25 L
.82807 .25 L
.82807 .25 L
.82808 .25 L
.82808 .25 L
.82808 .25 L
.82809 .25 L
.82809 .25 L
.8281 .25 L
.8281 .25 L
.82811 .25 L
.82811 .25 L
.82811 .25 L
.82812 .25 L
.82812 .25 L
.82813 .25 L
.82813 .25 L
Mistroke
.82814 .25 L
.82814 .25 L
.82815 .25 L
.82816 .25 L
.82816 .25 L
.82817 .25 L
.82817 .25 L
.82818 .25 L
.82819 .25 L
.82819 .25 L
.8282 .25 L
.82821 .25 L
.82821 .25 L
.82822 .25 L
.82823 .25 L
.82823 .25 L
.82823 .25 L
.82824 .25 L
.82825 .25 L
.82825 .25 L
.82826 .25 L
.82827 .25 L
.82827 .25 L
.82828 .25 L
.82828 .25 L
.82829 .25 L
.82829 .25 L
.8283 .25 L
.82831 .25 L
.82831 .25 L
.82832 .25 L
.82832 .25 L
.82833 .25 L
.82833 .25 L
.82834 .25 L
.82834 .25 L
.82835 .25 L
.82836 .25 L
.82836 .25 L
.82837 .25 L
.82838 .25 L
.82838 .25 L
.82839 .25 L
.8284 .25 L
.8284 .25 L
.82841 .25 L
.82841 .25 L
.82842 .25 L
.82843 .25 L
.82843 .25 L
Mistroke
.82844 .25 L
.82844 .25 L
.82845 .25 L
.82845 .25 L
.82846 .25 L
.82847 .25 L
.82847 .25 L
.82848 .25 L
.82848 .25 L
.82849 .25 L
.8285 .25 L
.8285 .25 L
.82851 .25 L
.82851 .25 L
.82852 .25 L
.82853 .25 L
.82853 .25 L
.82853 .25 L
.82854 .25 L
.82855 .25 L
.82855 .25 L
.82856 .25 L
.82857 .25 L
.82857 .25 L
.82858 .25 L
.82859 .25 L
.82859 .25 L
.8286 .25 L
.8286 .25 L
.82861 .25 L
.82862 .25 L
.82862 .25 L
.82863 .25 L
.82863 .25 L
.82864 .25 L
.82865 .25 L
.82865 .25 L
.82866 .25 L
.82866 .25 L
.82867 .25 L
.82868 .25 L
.82868 .25 L
.82869 .25 L
.82869 .25 L
.8287 .25 L
.8287 .25 L
.82871 .25 L
.82872 .25 L
.82872 .25 L
.82873 .25 L
Mistroke
.82873 .25 L
.82874 .25 L
.82874 .25 L
.82875 .25 L
.82876 .25 L
.82876 .25 L
.82876 .25 L
.82877 .25 L
.82878 .25 L
.82878 .25 L
.82879 .25 L
.82879 .25 L
.8288 .25 L
.82881 .25 L
.82881 .25 L
.82881 .25 L
.82882 .25 L
.82883 .25 L
.82883 .25 L
.82884 .25 L
.82884 .25 L
.82885 .25 L
.82885 .25 L
.82886 .25 L
.82887 .25 L
.82887 .25 L
.82888 .25 L
.82888 .25 L
.82889 .25 L
.8289 .25 L
.8289 .25 L
.82891 .25 L
.82892 .25 L
.82892 .25 L
.82893 .25 L
.82893 .25 L
.82894 .25 L
.82895 .25 L
.82895 .25 L
.82896 .25 L
.82897 .25 L
.82897 .25 L
.82897 .25 L
.82898 .25 L
.82898 .25 L
.82899 .25 L
.82899 .25 L
.829 .25 L
.82901 .25 L
.82901 .25 L
Mistroke
.82902 .25 L
.82903 .25 L
.82903 .25 L
.82904 .25 L
.82904 .25 L
.82905 .25 L
.82906 .25 L
.82906 .25 L
.82907 .25 L
.82908 .25 L
.82908 .25 L
.82909 .25 L
.82909 .25 L
.8291 .25 L
.8291 .25 L
.82911 .25 L
.82911 .25 L
.82912 .25 L
.82912 .25 L
.82913 .25 L
.82913 .25 L
.82913 .25 L
.82914 .25 L
.82914 .25 L
.82914 .25 L
.82915 .25 L
.82915 .25 L
.82916 .25 L
.82916 .25 L
.82917 .25 L
.82918 .25 L
.82918 .25 L
.82919 .25 L
.8292 .25 L
.8292 .25 L
.82921 .25 L
.82921 .25 L
.82922 .25 L
.82923 .25 L
.82923 .25 L
.82924 .25 L
.82925 .25 L
.82925 .25 L
.82926 .25 L
.82926 .25 L
.82927 .25 L
.82927 .25 L
.82928 .25 L
.82929 .25 L
.82929 .25 L
Mistroke
.8293 .25 L
.8293 .25 L
.82931 .25 L
.82931 .25 L
.82932 .25 L
.82933 .25 L
.82933 .25 L
.82934 .25 L
.82934 .25 L
.82935 .25 L
.82936 .25 L
.82936 .25 L
.82936 .25 L
.82937 .25 L
.82938 .25 L
.82938 .25 L
.82939 .25 L
.8294 .25 L
.8294 .25 L
.82941 .25 L
.82942 .25 L
.82942 .25 L
.82943 .25 L
.82944 .25 L
.82944 .25 L
.82945 .25 L
.82945 .25 L
.82946 .25 L
.82946 .25 L
.82947 .25 L
.82948 .25 L
.82948 .25 L
.82949 .25 L
.82949 .25 L
.8295 .25 L
.82951 .25 L
.82951 .25 L
.82952 .25 L
.82952 .25 L
.82953 .25 L
.82954 .25 L
.82954 .25 L
.82955 .25 L
.82955 .25 L
.82956 .25 L
.82956 .25 L
.82957 .25 L
.82957 .25 L
.82958 .25 L
.82958 .25 L
Mistroke
.82959 .25 L
.82959 .25 L
.8296 .25 L
.82961 .25 L
.82961 .25 L
.82962 .25 L
.82962 .25 L
.82963 .25 L
.82963 .25 L
.82964 .25 L
.82965 .25 L
.82965 .25 L
.82965 .25 L
.82966 .25 L
.82967 .25 L
.82967 .25 L
.82968 .25 L
.82968 .25 L
.82969 .25 L
.8297 .25 L
.8297 .25 L
.82971 .25 L
.82971 .25 L
.82972 .25 L
.82973 .25 L
.82973 .25 L
.82974 .25 L
.82974 .25 L
.82975 .25 L
.82976 .25 L
.82976 .25 L
.82977 .25 L
.82978 .25 L
.82978 .25 L
.82979 .25 L
.82979 .25 L
.8298 .25 L
.8298 .25 L
.8298 .25 L
.82981 .25 L
.82982 .25 L
.82982 .25 L
.82983 .25 L
.82984 .25 L
.82984 .25 L
.82985 .25 L
.82986 .25 L
.82986 .25 L
.82987 .25 L
.82988 .25 L
Mistroke
.82988 .25 L
.82989 .25 L
.82989 .25 L
.8299 .25 L
.82991 .25 L
.82991 .25 L
.82992 .25 L
.82992 .25 L
.82993 .25 L
.82993 .25 L
.82994 .25 L
.82994 .25 L
.82994 .25 L
.82995 .25 L
.82995 .25 L
.82996 .25 L
.82996 .25 L
.82997 .25 L
.82997 .25 L
.82997 .25 L
.82998 .25 L
.82998 .25 L
.82999 .25 L
.82999 .25 L
.83 .25 L
.83001 .25 L
.83001 .25 L
.83002 .25 L
.83003 .25 L
.83003 .25 L
.83004 .25 L
.83004 .25 L
.83005 .25 L
.83006 .25 L
.83006 .25 L
.83007 .25 L
.83008 .25 L
.83008 .25 L
.83008 .25 L
.83009 .25 L
.8301 .25 L
.8301 .25 L
.83011 .25 L
.83012 .25 L
.83012 .25 L
.83013 .25 L
.83013 .25 L
.83014 .25 L
.83014 .25 L
.83015 .25 L
Mistroke
.83016 .25 L
.83016 .25 L
.83017 .25 L
.83018 .25 L
.83018 .25 L
.83018 .25 L
.83019 .25 L
.8302 .25 L
.8302 .25 L
.83021 .25 L
.83022 .25 L
.83022 .25 L
.83023 .25 L
.83023 .25 L
.83024 .25 L
.83025 .25 L
.83025 .25 L
.83026 .25 L
.83027 .25 L
.83027 .25 L
.83028 .25 L
.83028 .25 L
.83029 .25 L
.83029 .25 L
.8303 .25 L
.83031 .25 L
.83031 .25 L
.83032 .25 L
.83032 .25 L
.83033 .25 L
.83034 .25 L
.83034 .25 L
.83035 .25 L
.83035 .25 L
.83036 .25 L
.83037 .25 L
.83037 .25 L
.83038 .25 L
.83038 .25 L
.83039 .25 L
.83039 .25 L
.8304 .25 L
.8304 .25 L
.83041 .25 L
.83041 .25 L
.83042 .25 L
.83042 .25 L
.83043 .25 L
.83044 .25 L
.83044 .25 L
Mistroke
.83045 .25 L
.83046 .25 L
.83046 .25 L
.83046 .25 L
.83047 .25 L
.83047 .25 L
.83048 .25 L
.83048 .25 L
.83049 .25 L
.8305 .25 L
.8305 .25 L
.83051 .25 L
.83051 .25 L
.83052 .25 L
.83053 .25 L
.83053 .25 L
.83054 .25 L
.83054 .25 L
.83055 .25 L
.83056 .25 L
.83056 .25 L
.83057 .25 L
.83057 .25 L
.83058 .25 L
.83059 .25 L
.83059 .25 L
.8306 .25 L
.83061 .25 L
.83061 .25 L
.83062 .25 L
.83062 .25 L
.83063 .25 L
.83063 .25 L
.83064 .25 L
.83064 .25 L
.83065 .25 L
.83066 .25 L
.83066 .25 L
.83067 .25 L
.83067 .25 L
.83068 .25 L
.83069 .25 L
.83069 .25 L
.8307 .25 L
.83071 .25 L
.83071 .25 L
.83072 .25 L
.83073 .25 L
.83073 .25 L
.83074 .25 L
Mistroke
.83074 .25 L
.83075 .25 L
.83075 .25 L
.83076 .25 L
.83076 .25 L
.83076 .25 L
.83077 .25 L
.83077 .25 L
.83078 .25 L
.83078 .25 L
.83079 .25 L
.83079 .25 L
.83079 .25 L
.8308 .25 L
.8308 .25 L
.8308 .25 L
.83081 .25 L
.83082 .25 L
.83082 .25 L
.83083 .25 L
.83084 .25 L
.83084 .25 L
.83085 .25 L
.83085 .25 L
.83086 .25 L
.83087 .25 L
.83087 .25 L
.83088 .25 L
.83089 .25 L
.83089 .25 L
.8309 .25 L
.8309 .25 L
.83091 .25 L
.83091 .25 L
.83092 .25 L
.83093 .25 L
.83093 .25 L
.83094 .25 L
.83095 .25 L
.83095 .25 L
.83096 .25 L
.83096 .25 L
.83097 .25 L
.83097 .25 L
.83098 .25 L
.83099 .25 L
.83099 .25 L
.831 .25 L
.831 .25 L
.83101 .25 L
Mistroke
.83101 .25 L
.83102 .25 L
.83103 .25 L
.83103 .25 L
.83104 .25 L
.83105 .25 L
.83105 .25 L
.83106 .25 L
.83106 .25 L
.83107 .25 L
.83108 .25 L
.83108 .25 L
.83109 .25 L
.8311 .25 L
.8311 .25 L
.83111 .25 L
.83111 .25 L
.83112 .25 L
.83112 .25 L
.83113 .25 L
.83114 .25 L
.83114 .25 L
.83115 .25 L
.83115 .25 L
.83116 .25 L
.83116 .25 L
.83117 .25 L
.83118 .25 L
.83118 .25 L
.83119 .25 L
.8312 .25 L
.8312 .25 L
.83121 .25 L
.83121 .25 L
.83122 .25 L
.83122 .25 L
.83123 .25 L
.83123 .25 L
.83124 .25 L
.83124 .25 L
.83125 .25 L
.83125 .25 L
.83126 .25 L
.83127 .25 L
.83127 .25 L
.83128 .25 L
.83128 .25 L
.83129 .25 L
.83129 .25 L
.8313 .25 L
Mistroke
.8313 .25 L
.83131 .25 L
.83131 .25 L
.83132 .25 L
.83133 .25 L
.83133 .25 L
.83134 .25 L
.83134 .25 L
.83135 .25 L
.83136 .25 L
.83136 .25 L
.83137 .25 L
.83137 .25 L
.83138 .25 L
.83139 .25 L
.83139 .25 L
.8314 .25 L
.83141 .25 L
.83141 .25 L
.83142 .25 L
.83142 .25 L
.83143 .25 L
.83144 .25 L
.83144 .25 L
.83144 .25 L
.83145 .25 L
.83145 .25 L
.83146 .25 L
.83147 .25 L
.83147 .25 L
.83148 .25 L
.83149 .25 L
.83149 .25 L
.8315 .25 L
.8315 .25 L
.83151 .25 L
.83152 .25 L
.83152 .25 L
.83153 .25 L
.83154 .25 L
.83154 .25 L
.83155 .25 L
.83155 .25 L
.83156 .25 L
.83157 .25 L
.83157 .25 L
.83158 .25 L
.83158 .25 L
.83158 .25 L
.83159 .25 L
Mistroke
.83159 .25 L
.8316 .25 L
.8316 .25 L
.8316 .25 L
.83161 .25 L
.83161 .25 L
.83162 .25 L
.83162 .25 L
.83162 .25 L
.83163 .25 L
.83163 .25 L
.83164 .25 L
.83165 .25 L
.83165 .25 L
.83166 .25 L
.83167 .25 L
.83167 .25 L
.83168 .25 L
.83168 .25 L
.83169 .25 L
.8317 .25 L
.8317 .25 L
.83171 .25 L
.83172 .25 L
.83172 .25 L
.83173 .25 L
.83173 .25 L
.83174 .25 L
.83174 .25 L
.83175 .25 L
.83176 .25 L
.83176 .25 L
.83177 .25 L
.83177 .25 L
.83178 .25 L
.83179 .25 L
.83179 .25 L
.8318 .25 L
.8318 .25 L
.83181 .25 L
.83182 .25 L
.83182 .25 L
.83183 .25 L
.83183 .25 L
.83184 .25 L
.83184 .25 L
.83185 .25 L
.83186 .25 L
.83186 .25 L
.83187 .25 L
Mistroke
.83188 .25 L
.83188 .25 L
.83189 .25 L
.83189 .25 L
.8319 .25 L
.83191 .25 L
.83191 .25 L
.83192 .25 L
.83193 .25 L
.83193 .25 L
.83193 .25 L
.83194 .25 L
.83195 .25 L
.83195 .25 L
.83196 .25 L
.83197 .25 L
.83197 .25 L
.83198 .25 L
.83198 .25 L
.83199 .25 L
.83199 .25 L
.832 .25 L
.83201 .25 L
.83201 .25 L
.83202 .25 L
.83203 .25 L
.83203 .25 L
.83203 .25 L
.83204 .25 L
.83205 .25 L
.83205 .25 L
.83206 .25 L
.83206 .25 L
.83206 .25 L
.83207 .25 L
.83208 .25 L
.83208 .25 L
.83209 .25 L
.8321 .25 L
.8321 .25 L
.83211 .25 L
.83211 .25 L
.83212 .25 L
.83212 .25 L
.83212 .25 L
.83213 .25 L
.83214 .25 L
.83214 .25 L
.83215 .25 L
.83216 .25 L
Mistroke
.83216 .25 L
.83217 .25 L
.83217 .25 L
.83218 .25 L
.83219 .25 L
.83219 .25 L
.8322 .25 L
.8322 .25 L
.83221 .25 L
.83222 .25 L
.83222 .25 L
.83223 .25 L
.83224 .25 L
.83224 .25 L
.83225 .25 L
.83225 .25 L
.83226 .25 L
.83226 .25 L
.83227 .25 L
.83227 .25 L
.83228 .25 L
.83228 .25 L
.83229 .25 L
.8323 .25 L
.8323 .25 L
.83231 .25 L
.83231 .25 L
.83232 .25 L
.83233 .25 L
.83233 .25 L
.83234 .25 L
.83235 .25 L
.83235 .25 L
.83236 .25 L
.83237 .25 L
.83237 .25 L
.83238 .25 L
.83239 .25 L
.83239 .25 L
.83239 .25 L
.8324 .25 L
.8324 .25 L
.83241 .25 L
.83241 .25 L
.83241 .25 L
.83242 .25 L
.83242 .25 L
.83243 .25 L
.83243 .25 L
.83244 .25 L
Mistroke
.83244 .25 L
.83244 .25 L
.83245 .25 L
.83245 .25 L
.83246 .25 L
.83246 .25 L
.83247 .25 L
.83248 .25 L
.83248 .25 L
.83249 .25 L
.8325 .25 L
.8325 .25 L
.83251 .25 L
.83251 .25 L
.83252 .25 L
.83253 .25 L
.83253 .25 L
.83254 .25 L
.83255 .25 L
.83255 .25 L
.83255 .25 L
.83256 .25 L
.83257 .25 L
.83257 .25 L
.83258 .25 L
.83259 .25 L
.83259 .25 L
.8326 .25 L
.8326 .25 L
.83261 .25 L
.83262 .25 L
.83262 .25 L
.83263 .25 L
.83263 .25 L
.83264 .25 L
.83265 .25 L
.83265 .25 L
.83265 .25 L
.83266 .25 L
.83267 .25 L
.83267 .25 L
.83268 .25 L
.83269 .25 L
.83269 .25 L
.8327 .25 L
.8327 .25 L
.83271 .25 L
.83272 .25 L
.83272 .25 L
.83273 .25 L
Mistroke
.83274 .25 L
.83274 .25 L
.83275 .25 L
.83275 .25 L
.83276 .25 L
.83276 .25 L
.83277 .25 L
.83278 .25 L
.83278 .25 L
.83279 .25 L
.83279 .25 L
.8328 .25 L
.83281 .25 L
.83281 .25 L
.83282 .25 L
.83282 .25 L
.83283 .25 L
.83284 .25 L
.83284 .25 L
.83285 .25 L
.83285 .25 L
.83286 .25 L
.83286 .25 L
.83287 .25 L
.83287 .25 L
.83288 .25 L
.83289 .25 L
.83289 .25 L
.8329 .25 L
.83291 .25 L
.83291 .25 L
.83292 .25 L
.83293 .25 L
.83293 .25 L
.83294 .25 L
.83294 .25 L
.83295 .25 L
.83296 .25 L
.83296 .25 L
.83297 .25 L
.83297 .25 L
.83298 .25 L
.83298 .25 L
.83299 .25 L
.833 .25 L
.833 .25 L
.83301 .25 L
.83301 .25 L
.83302 .25 L
.83303 .25 L
Mistroke
.83303 .25 L
.83304 .25 L
.83304 .25 L
.83305 .25 L
.83305 .25 L
.83306 .25 L
.83306 .25 L
.83307 .25 L
.83308 .25 L
.83308 .25 L
.83308 .25 L
.83309 .25 L
.8331 .25 L
.8331 .25 L
.83311 .25 L
.83312 .25 L
.83312 .25 L
.83313 .25 L
.83313 .25 L
.83314 .25 L
.83314 .25 L
.83315 .25 L
.83315 .25 L
.83316 .25 L
.83316 .25 L
.83317 .25 L
.83318 .25 L
.83318 .25 L
.83319 .25 L
.83319 .25 L
.8332 .25 L
.8332 .25 L
.83321 .25 L
.83322 .25 L
.83322 .25 L
.83323 .25 L
.83324 .25 L
.83324 .25 L
.83325 .25 L
.83325 .25 L
.83326 .25 L
.83327 .25 L
.83327 .25 L
.83328 .25 L
.83329 .25 L
.83329 .25 L
.83329 .25 L
.8333 .25 L
.8333 .25 L
.83331 .25 L
Mistroke
.83331 .25 L
.83332 .25 L
.83333 .25 L
.83333 .25 L
.83334 .25 L
.83335 .25 L
.83335 .25 L
.83336 .25 L
.83337 .25 L
.83337 .25 L
.83338 .25 L
.83338 .25 L
.83339 .25 L
.8334 .25 L
.8334 .25 L
.83341 .25 L
.83342 .25 L
.83342 .25 L
.83343 .25 L
.83343 .25 L
.83343 .25 L
.83344 .25 L
.83344 .25 L
.83345 .25 L
.83345 .25 L
.83345 .25 L
.83346 .25 L
.83346 .25 L
.83347 .25 L
.83347 .25 L
.83347 .25 L
.83348 .25 L
.83348 .25 L
.83349 .25 L
.8335 .25 L
.8335 .25 L
.83351 .25 L
.83352 .25 L
.83352 .25 L
.83353 .25 L
.83353 .25 L
.83354 .25 L
.83355 .25 L
.83355 .25 L
.83356 .25 L
.83357 .25 L
.83357 .25 L
.83358 .25 L
.83358 .25 L
.83359 .25 L
Mistroke
.83359 .25 L
.8336 .25 L
.83361 .25 L
.83361 .25 L
.83362 .25 L
.83362 .25 L
.83363 .25 L
.83364 .25 L
.83364 .25 L
.83365 .25 L
.83365 .25 L
.83366 .25 L
.83367 .25 L
.83367 .25 L
.83368 .25 L
.83368 .25 L
.83369 .25 L
.83369 .25 L
.8337 .25 L
.83371 .25 L
.83371 .25 L
.83372 .25 L
.83373 .25 L
.83373 .25 L
.83374 .25 L
.83374 .25 L
.83375 .25 L
.83376 .25 L
.83376 .25 L
.83377 .25 L
.83378 .25 L
.83378 .25 L
.83378 .25 L
.83379 .25 L
.8338 .25 L
.8338 .25 L
.83381 .25 L
.83382 .25 L
.83382 .25 L
.83383 .25 L
.83383 .25 L
.83384 .25 L
.83384 .25 L
.83385 .25 L
.83386 .25 L
.83386 .25 L
.83387 .25 L
.83388 .25 L
.83388 .25 L
.83388 .25 L
Mistroke
.83389 .25 L
.8339 .25 L
.8339 .25 L
.83391 .25 L
.83391 .25 L
.83391 .25 L
.83392 .25 L
.83393 .25 L
.83393 .25 L
.83394 .25 L
.83395 .25 L
.83395 .25 L
.83396 .25 L
.83396 .25 L
.83397 .25 L
.83397 .25 L
.83397 .25 L
.83398 .25 L
.83399 .25 L
.83399 .25 L
.834 .25 L
.83401 .25 L
.83401 .25 L
.83402 .25 L
.83402 .25 L
.83403 .25 L
.83404 .25 L
.83404 .25 L
.83405 .25 L
.83405 .25 L
.83406 .25 L
.83407 .25 L
.83407 .25 L
.83408 .25 L
.83409 .25 L
.83409 .25 L
.8341 .25 L
.8341 .25 L
.83411 .25 L
.83411 .25 L
.83412 .25 L
.83412 .25 L
.83413 .25 L
.83413 .25 L
.83414 .25 L
.83415 .25 L
.83415 .25 L
.83416 .25 L
.83416 .25 L
.83417 .25 L
Mistroke
.83418 .25 L
.83418 .25 L
.83419 .25 L
.8342 .25 L
.8342 .25 L
.83421 .25 L
.83422 .25 L
.83422 .25 L
.83423 .25 L
.83424 .25 L
.83424 .25 L
.83424 .25 L
.83425 .25 L
.83425 .25 L
.83426 .25 L
.83426 .25 L
.83426 .25 L
.83427 .25 L
.83427 .25 L
.83428 .25 L
.83428 .25 L
.83429 .25 L
.83429 .25 L
.83429 .25 L
.8343 .25 L
.8343 .25 L
.83431 .25 L
.83431 .25 L
.83432 .25 L
.83433 .25 L
.83433 .25 L
.83434 .25 L
.83435 .25 L
.83435 .25 L
.83436 .25 L
.83436 .25 L
.83437 .25 L
.83438 .25 L
.83438 .25 L
.83439 .25 L
.8344 .25 L
.8344 .25 L
.83441 .25 L
.83441 .25 L
.83442 .25 L
.83442 .25 L
.83443 .25 L
.83444 .25 L
.83444 .25 L
.83445 .25 L
Mistroke
.83445 .25 L
.83446 .25 L
.83447 .25 L
.83447 .25 L
.83448 .25 L
.83448 .25 L
.83449 .25 L
.8345 .25 L
.8345 .25 L
.8345 .25 L
.83451 .25 L
.83452 .25 L
.83452 .25 L
.83453 .25 L
.83454 .25 L
.83454 .25 L
.83455 .25 L
.83455 .25 L
.83456 .25 L
.83457 .25 L
.83457 .25 L
.83458 .25 L
.83459 .25 L
.83459 .25 L
.8346 .25 L
.8346 .25 L
.83461 .25 L
.83461 .25 L
.83462 .25 L
.83463 .25 L
.83463 .25 L
.83464 .25 L
.83465 .25 L
.83465 .25 L
.83466 .25 L
.83466 .25 L
.83467 .25 L
.83467 .25 L
.83468 .25 L
.83469 .25 L
.83469 .25 L
.8347 .25 L
.8347 .25 L
.83471 .25 L
.83471 .25 L
.83472 .25 L
.83473 .25 L
.83473 .25 L
.83473 .25 L
.83474 .25 L
Mistroke
.83475 .25 L
.83475 .25 L
.83476 .25 L
.83476 .25 L
.83477 .25 L
.83478 .25 L
.83478 .25 L
.83478 .25 L
.83479 .25 L
.83479 .25 L
.8348 .25 L
.8348 .25 L
.83481 .25 L
.83482 .25 L
.83482 .25 L
.83483 .25 L
.83484 .25 L
.83484 .25 L
.83485 .25 L
.83485 .25 L
.83486 .25 L
.83487 .25 L
.83487 .25 L
.83488 .25 L
.83488 .25 L
.83489 .25 L
.8349 .25 L
.8349 .25 L
.83491 .25 L
.83492 .25 L
.83492 .25 L
.83493 .25 L
.83494 .25 L
.83494 .25 L
.83494 .25 L
.83495 .25 L
.83495 .25 L
.83496 .25 L
.83496 .25 L
.83497 .25 L
.83498 .25 L
.83498 .25 L
.83499 .25 L
.83499 .25 L
.835 .25 L
.83501 .25 L
.83501 .25 L
.83502 .25 L
.83503 .25 L
.83503 .25 L
Mistroke
.83504 .25 L
.83505 .25 L
.83505 .25 L
.83506 .25 L
.83506 .25 L
.83507 .25 L
.83507 .25 L
.83508 .25 L
.83508 .25 L
.83508 .25 L
.83509 .25 L
.83509 .25 L
.8351 .25 L
.8351 .25 L
.83511 .25 L
.83511 .25 L
.83511 .25 L
.83512 .25 L
.83512 .25 L
.83512 .25 L
.83513 .25 L
.83514 .25 L
.83514 .25 L
.83515 .25 L
.83516 .25 L
.83516 .25 L
.83517 .25 L
.83518 .25 L
.83518 .25 L
.83519 .25 L
.83519 .25 L
.8352 .25 L
.83521 .25 L
.83521 .25 L
.83522 .25 L
.83523 .25 L
.83523 .25 L
.83524 .25 L
.83524 .25 L
.83525 .25 L
.83525 .25 L
.83526 .25 L
.83527 .25 L
.83527 .25 L
.83528 .25 L
.83528 .25 L
.83529 .25 L
.8353 .25 L
.8353 .25 L
.83531 .25 L
Mistroke
.83531 .25 L
.83532 .25 L
.83532 .25 L
.83533 .25 L
.83533 .25 L
.83534 .25 L
.83535 .25 L
.83535 .25 L
.83536 .25 L
.83537 .25 L
.83537 .25 L
.83538 .25 L
.83538 .25 L
.83539 .25 L
.8354 .25 L
.8354 .25 L
.83541 .25 L
.83542 .25 L
.83542 .25 L
.83543 .25 L
.83543 .25 L
.83544 .25 L
.83544 .25 L
.83545 .25 L
.83546 .25 L
.83546 .25 L
.83547 .25 L
.83547 .25 L
.83548 .25 L
.83549 .25 L
.83549 .25 L
.8355 .25 L
.8355 .25 L
.83551 .25 L
.83552 .25 L
.83552 .25 L
.83553 .25 L
.83553 .25 L
.83554 .25 L
.83554 .25 L
.83555 .25 L
.83555 .25 L
.83556 .25 L
.83556 .25 L
.83557 .25 L
.83557 .25 L
.83558 .25 L
.83559 .25 L
.83559 .25 L
.8356 .25 L
Mistroke
.8356 .25 L
.83561 .25 L
.83561 .25 L
.83562 .25 L
.83562 .25 L
.83563 .25 L
.83563 .25 L
.83564 .25 L
.83565 .25 L
.83565 .25 L
.83566 .25 L
.83566 .25 L
.83567 .25 L
.83568 .25 L
.83568 .25 L
.83569 .25 L
.83569 .25 L
.8357 .25 L
.83571 .25 L
.83571 .25 L
.83572 .25 L
.83573 .25 L
.83573 .25 L
.83574 .25 L
.83575 .25 L
.83575 .25 L
.83576 .25 L
.83576 .25 L
.83577 .25 L
.83577 .25 L
.83577 .25 L
.83578 .25 L
.83579 .25 L
.83579 .25 L
.8358 .25 L
.83581 .25 L
.83581 .25 L
.83582 .25 L
.83582 .25 L
.83583 .25 L
.83584 .25 L
.83584 .25 L
.83585 .25 L
.83586 .25 L
.83586 .25 L
.83587 .25 L
.83588 .25 L
.83588 .25 L
.83589 .25 L
.83589 .25 L
Mistroke
.8359 .25 L
.8359 .25 L
.8359 .25 L
.83591 .25 L
.83591 .25 L
.83592 .25 L
.83592 .25 L
.83593 .25 L
.83593 .25 L
.83593 .25 L
.83594 .25 L
.83594 .25 L
.83594 .25 L
.83595 .25 L
.83595 .25 L
.83596 .25 L
.83597 .25 L
.83597 .25 L
.83598 .25 L
.83599 .25 L
.83599 .25 L
.836 .25 L
.83601 .25 L
.83601 .25 L
.83602 .25 L
.83603 .25 L
.83603 .25 L
.83604 .25 L
.83604 .25 L
.83605 .25 L
.83605 .25 L
.83606 .25 L
.83607 .25 L
.83607 .25 L
.83608 .25 L
.83608 .25 L
.83609 .25 L
.8361 .25 L
.8361 .25 L
.83611 .25 L
.83611 .25 L
.83612 .25 L
.83613 .25 L
.83613 .25 L
.83614 .25 L
.83614 .25 L
.83615 .25 L
.83615 .25 L
.83616 .25 L
.83616 .25 L
Mistroke
.83617 .25 L
.83618 .25 L
.83618 .25 L
.83619 .25 L
.8362 .25 L
.8362 .25 L
.83621 .25 L
.83621 .25 L
.83622 .25 L
.83623 .25 L
.83623 .25 L
.83624 .25 L
.83625 .25 L
.83625 .25 L
.83625 .25 L
.83626 .25 L
.83627 .25 L
.83627 .25 L
.83628 .25 L
.83629 .25 L
.83629 .25 L
.8363 .25 L
.8363 .25 L
.83631 .25 L
.83631 .25 L
.83632 .25 L
.83633 .25 L
.83633 .25 L
.83634 .25 L
.83635 .25 L
.83635 .25 L
.83635 .25 L
.83636 .25 L
.83637 .25 L
.83637 .25 L
.83638 .25 L
.83639 .25 L
.83639 .25 L
.8364 .25 L
.8364 .25 L
.83641 .25 L
.83642 .25 L
.83642 .25 L
.83643 .25 L
.83644 .25 L
.83644 .25 L
.83645 .25 L
.83645 .25 L
.83646 .25 L
.83646 .25 L
Mistroke
.83647 .25 L
.83648 .25 L
.83648 .25 L
.83649 .25 L
.83649 .25 L
.8365 .25 L
.83651 .25 L
.83651 .25 L
.83652 .25 L
.83652 .25 L
.83653 .25 L
.83654 .25 L
.83654 .25 L
.83655 .25 L
.83655 .25 L
.83656 .25 L
.83656 .25 L
.83657 .25 L
.83657 .25 L
.83658 .25 L
.83658 .25 L
.83659 .25 L
.83659 .25 L
.8366 .25 L
.83661 .25 L
.83661 .25 L
.83662 .25 L
.83663 .25 L
.83663 .25 L
.83663 .25 L
.83664 .25 L
.83664 .25 L
.83665 .25 L
.83665 .25 L
.83666 .25 L
.83667 .25 L
.83667 .25 L
.83668 .25 L
.83669 .25 L
.83669 .25 L
.8367 .25 L
.8367 .25 L
.83671 .25 L
.83672 .25 L
.83672 .25 L
.83673 .25 L
.83673 .25 L
.83674 .25 L
.83675 .25 L
.83675 .25 L
Mistroke
.83676 .25 L
.83676 .25 L
.83677 .25 L
.83678 .25 L
.83678 .25 L
.83679 .25 L
.83679 .25 L
.8368 .25 L
.8368 .25 L
.83681 .25 L
.83681 .25 L
.83682 .25 L
.83683 .25 L
.83683 .25 L
.83684 .25 L
.83684 .25 L
.83685 .25 L
.83686 .25 L
.83686 .25 L
.83687 .25 L
.83688 .25 L
.83688 .25 L
.83689 .25 L
.8369 .25 L
.8369 .25 L
.83691 .25 L
.83691 .25 L
.83692 .25 L
.83692 .25 L
.83693 .25 L
.83693 .25 L
.83693 .25 L
.83694 .25 L
.83694 .25 L
.83695 .25 L
.83695 .25 L
.83696 .25 L
.83696 .25 L
.83696 .25 L
.83697 .25 L
.83697 .25 L
.83697 .25 L
.83698 .25 L
.83699 .25 L
.83699 .25 L
.837 .25 L
.83701 .25 L
.83701 .25 L
.83702 .25 L
.83703 .25 L
Mistroke
.83703 .25 L
.83704 .25 L
.83704 .25 L
.83705 .25 L
.83706 .25 L
.83706 .25 L
.83707 .25 L
.83707 .25 L
.83708 .25 L
.83709 .25 L
.83709 .25 L
.8371 .25 L
.8371 .25 L
.83711 .25 L
.83712 .25 L
.83712 .25 L
.83713 .25 L
.83713 .25 L
.83714 .25 L
.83715 .25 L
.83715 .25 L
.83716 .25 L
.83716 .25 L
.83717 .25 L
.83717 .25 L
.83718 .25 L
.83718 .25 L
.83719 .25 L
.8372 .25 L
.8372 .25 L
.83721 .25 L
.83722 .25 L
.83722 .25 L
.83723 .25 L
.83723 .25 L
.83724 .25 L
.83725 .25 L
.83725 .25 L
.83726 .25 L
.83727 .25 L
.83727 .25 L
.83728 .25 L
.83728 .25 L
.83729 .25 L
.83729 .25 L
.8373 .25 L
.83731 .25 L
.83731 .25 L
.83732 .25 L
.83732 .25 L
Mistroke
.83733 .25 L
.83734 .25 L
.83734 .25 L
.83735 .25 L
.83735 .25 L
.83736 .25 L
.83737 .25 L
.83737 .25 L
.83738 .25 L
.83738 .25 L
.83739 .25 L
.83739 .25 L
.8374 .25 L
.8374 .25 L
.83741 .25 L
.83741 .25 L
.83742 .25 L
.83742 .25 L
.83743 .25 L
.83744 .25 L
.83744 .25 L
.83745 .25 L
.83745 .25 L
.83746 .25 L
.83746 .25 L
.83747 .25 L
.83747 .25 L
.83748 .25 L
.83748 .25 L
.83749 .25 L
.8375 .25 L
.8375 .25 L
.83751 .25 L
.83751 .25 L
.83752 .25 L
.83753 .25 L
.83753 .25 L
.83754 .25 L
.83754 .25 L
.83755 .25 L
.83756 .25 L
.83756 .25 L
.83757 .25 L
.83758 .25 L
.83758 .25 L
.83759 .25 L
.8376 .25 L
.8376 .25 L
.83761 .25 L
.83761 .25 L
Mistroke
.83762 .25 L
.83762 .25 L
.83762 .25 L
.83763 .25 L
.83764 .25 L
.83764 .25 L
.83765 .25 L
.83766 .25 L
.83766 .25 L
.83767 .25 L
.83767 .25 L
.83768 .25 L
.83769 .25 L
.83769 .25 L
.8377 .25 L
.83771 .25 L
.83771 .25 L
.83772 .25 L
.83773 .25 L
.83773 .25 L
.83774 .25 L
.83774 .25 L
.83775 .25 L
.83775 .25 L
.83775 .25 L
.83776 .25 L
.83776 .25 L
.83777 .25 L
.83777 .25 L
.83778 .25 L
.83778 .25 L
.83778 .25 L
.83779 .25 L
.83779 .25 L
.83779 .25 L
.8378 .25 L
.8378 .25 L
.83781 .25 L
.83782 .25 L
.83783 .25 L
.83783 .25 L
.83784 .25 L
.83784 .25 L
.83785 .25 L
.83786 .25 L
.83786 .25 L
.83787 .25 L
.83788 .25 L
.83788 .25 L
.83789 .25 L
Mistroke
.83789 .25 L
.8379 .25 L
.8379 .25 L
.83791 .25 L
.83792 .25 L
.83792 .25 L
.83793 .25 L
.83793 .25 L
.83794 .25 L
.83795 .25 L
.83795 .25 L
.83796 .25 L
.83796 .25 L
.83797 .25 L
.83798 .25 L
.83798 .25 L
.83799 .25 L
.83799 .25 L
.838 .25 L
.838 .25 L
.83801 .25 L
.83801 .25 L
.83802 .25 L
.83803 .25 L
.83803 .25 L
.83804 .25 L
.83805 .25 L
.83805 .25 L
.83806 .25 L
.83806 .25 L
.83807 .25 L
.83808 .25 L
.83808 .25 L
.83809 .25 L
.8381 .25 L
.8381 .25 L
.8381 .25 L
.83811 .25 L
.83812 .25 L
.83812 .25 L
.83813 .25 L
.83814 .25 L
.83814 .25 L
.83815 .25 L
.83815 .25 L
.83816 .25 L
.83817 .25 L
.83817 .25 L
.83818 .25 L
.83818 .25 L
Mistroke
.83819 .25 L
.8382 .25 L
.8382 .25 L
.8382 .25 L
.83821 .25 L
.83822 .25 L
.83822 .25 L
.83823 .25 L
.83823 .25 L
.83824 .25 L
.83824 .25 L
.83825 .25 L
.83825 .25 L
.83826 .25 L
.83827 .25 L
.83827 .25 L
.83828 .25 L
.83828 .25 L
.83829 .25 L
.83829 .25 L
.8383 .25 L
.8383 .25 L
.83831 .25 L
.83832 .25 L
.83832 .25 L
.83833 .25 L
.83833 .25 L
.83834 .25 L
.83834 .25 L
.83835 .25 L
.83836 .25 L
.83836 .25 L
.83837 .25 L
.83838 .25 L
.83838 .25 L
.83839 .25 L
.83839 .25 L
.8384 .25 L
.83841 .25 L
.83841 .25 L
.83842 .25 L
.83843 .25 L
.83843 .25 L
.83844 .25 L
.83844 .25 L
.83844 .25 L
.83845 .25 L
.83845 .25 L
.83846 .25 L
.83847 .25 L
Mistroke
.83847 .25 L
.83848 .25 L
.83849 .25 L
.83849 .25 L
.8385 .25 L
.8385 .25 L
.83851 .25 L
.83852 .25 L
.83852 .25 L
.83853 .25 L
.83854 .25 L
.83854 .25 L
.83855 .25 L
.83856 .25 L
.83856 .25 L
.83856 .25 L
.83857 .25 L
.83857 .25 L
.83858 .25 L
.83858 .25 L
.83859 .25 L
.83859 .25 L
.8386 .25 L
.8386 .25 L
.8386 .25 L
.83861 .25 L
.83861 .25 L
.83861 .25 L
.83862 .25 L
.83862 .25 L
.83863 .25 L
.83864 .25 L
.83864 .25 L
.83865 .25 L
.83866 .25 L
.83866 .25 L
.83867 .25 L
.83867 .25 L
.83868 .25 L
.83869 .25 L
.83869 .25 L
.8387 .25 L
.83871 .25 L
.83871 .25 L
.83872 .25 L
.83872 .25 L
.83873 .25 L
.83873 .25 L
.83874 .25 L
.83875 .25 L
Mistroke
.83875 .25 L
.83876 .25 L
.83876 .25 L
.83877 .25 L
.83877 .25 L
.83878 .25 L
.83879 .25 L
.83879 .25 L
.8388 .25 L
.83881 .25 L
.83881 .25 L
.83882 .25 L
.83882 .25 L
.83882 .25 L
.83883 .25 L
.83884 .25 L
.83884 .25 L
.83885 .25 L
.83886 .25 L
.83886 .25 L
.83887 .25 L
.83888 .25 L
.83888 .25 L
.83889 .25 L
.83889 .25 L
.8389 .25 L
.83891 .25 L
.83891 .25 L
.83892 .25 L
.83892 .25 L
.83893 .25 L
.83894 .25 L
.83894 .25 L
.83895 .25 L
.83895 .25 L
.83896 .25 L
.83897 .25 L
.83897 .25 L
.83898 .25 L
.83898 .25 L
.83899 .25 L
.839 .25 L
.839 .25 L
.83901 .25 L
.83901 .25 L
.83902 .25 L
.83902 .25 L
.83903 .25 L
.83903 .25 L
.83904 .25 L
Mistroke
.83905 .25 L
.83905 .25 L
.83905 .25 L
.83906 .25 L
.83907 .25 L
.83907 .25 L
.83908 .25 L
.83908 .25 L
.83909 .25 L
.8391 .25 L
.8391 .25 L
.8391 .25 L
.83911 .25 L
.83912 .25 L
.83912 .25 L
.83913 .25 L
.83913 .25 L
.83914 .25 L
.83914 .25 L
.83915 .25 L
.83916 .25 L
.83916 .25 L
.83917 .25 L
.83917 .25 L
.83918 .25 L
.83919 .25 L
.83919 .25 L
.8392 .25 L
.83921 .25 L
.83921 .25 L
.83922 .25 L
.83922 .25 L
.83923 .25 L
.83924 .25 L
.83924 .25 L
.83925 .25 L
.83926 .25 L
.83926 .25 L
.83926 .25 L
.83927 .25 L
.83927 .25 L
.83928 .25 L
.83928 .25 L
.83929 .25 L
.8393 .25 L
.8393 .25 L
.83931 .25 L
.83932 .25 L
.83932 .25 L
.83933 .25 L
Mistroke
.83933 .25 L
.83934 .25 L
.83935 .25 L
.83935 .25 L
.83936 .25 L
.83937 .25 L
.83937 .25 L
.83938 .25 L
.83938 .25 L
.83939 .25 L
.83939 .25 L
.8394 .25 L
.8394 .25 L
.8394 .25 L
.83941 .25 L
.83942 .25 L
.83942 .25 L
.83942 .25 L
.83943 .25 L
.83943 .25 L
.83943 .25 L
.83944 .25 L
.83944 .25 L
.83945 .25 L
.83945 .25 L
.83946 .25 L
.83947 .25 L
.83947 .25 L
.83948 .25 L
.83949 .25 L
.83949 .25 L
.8395 .25 L
.8395 .25 L
.83951 .25 L
.83952 .25 L
.83952 .25 L
.83953 .25 L
.83954 .25 L
.83954 .25 L
.83955 .25 L
.83955 .25 L
.83956 .25 L
.83956 .25 L
.83957 .25 L
.83957 .25 L
.83958 .25 L
.83959 .25 L
.83959 .25 L
.8396 .25 L
.8396 .25 L
Mistroke
.83961 .25 L
.83962 .25 L
.83962 .25 L
.83963 .25 L
.83963 .25 L
.83964 .25 L
.83964 .25 L
.83965 .25 L
.83965 .25 L
.83966 .25 L
.83967 .25 L
.83967 .25 L
.83968 .25 L
.83969 .25 L
.83969 .25 L
.8397 .25 L
.83971 .25 L
.83971 .25 L
.83972 .25 L
.83972 .25 L
.83973 .25 L
.83974 .25 L
.83974 .25 L
.83975 .25 L
.83975 .25 L
.83976 .25 L
.83977 .25 L
.83977 .25 L
.83978 .25 L
.83978 .25 L
.83979 .25 L
.8398 .25 L
.8398 .25 L
.83981 .25 L
.83981 .25 L
.83982 .25 L
.83982 .25 L
.83983 .25 L
.83984 .25 L
.83984 .25 L
.83985 .25 L
.83985 .25 L
.83986 .25 L
.83986 .25 L
.83987 .25 L
.83988 .25 L
.83988 .25 L
.83989 .25 L
.8399 .25 L
.8399 .25 L
Mistroke
.83991 .25 L
.83991 .25 L
.83992 .25 L
.83993 .25 L
.83993 .25 L
.83994 .25 L
.83995 .25 L
.83995 .25 L
.83995 .25 L
.83996 .25 L
.83997 .25 L
.83997 .25 L
.83998 .25 L
.83999 .25 L
.83999 .25 L
.84 .25 L
.84 .25 L
.84001 .25 L
.84002 .25 L
.84002 .25 L
.84003 .25 L
.84003 .25 L
.84004 .25 L
.84005 .25 L
.84005 .25 L
.84005 .25 L
.84006 .25 L
.84007 .25 L
.84007 .25 L
.84008 .25 L
.84008 .25 L
.84009 .25 L
.84009 .25 L
.8401 .25 L
.8401 .25 L
.84011 .25 L
.84012 .25 L
.84012 .25 L
.84013 .25 L
.84013 .25 L
.84014 .25 L
.84014 .25 L
.84014 .25 L
.84015 .25 L
.84016 .25 L
.84016 .25 L
.84017 .25 L
.84018 .25 L
.84018 .25 L
.84019 .25 L
Mistroke
.84019 .25 L
.8402 .25 L
.84021 .25 L
.84021 .25 L
.84022 .25 L
.84023 .25 L
.84023 .25 L
.84024 .25 L
.84024 .25 L
.84025 .25 L
.84026 .25 L
.84026 .25 L
.84027 .25 L
.84028 .25 L
.84028 .25 L
.84029 .25 L
.84029 .25 L
.84029 .25 L
.8403 .25 L
.8403 .25 L
.84031 .25 L
.84032 .25 L
.84032 .25 L
.84033 .25 L
.84034 .25 L
.84034 .25 L
.84035 .25 L
.84035 .25 L
.84036 .25 L
.84037 .25 L
.84037 .25 L
.84038 .25 L
.84039 .25 L
.84039 .25 L
.8404 .25 L
.84041 .25 L
.84041 .25 L
.84041 .25 L
.84042 .25 L
.84042 .25 L
.84043 .25 L
.84043 .25 L
.84044 .25 L
.84044 .25 L
.84045 .25 L
.84045 .25 L
.84045 .25 L
.84046 .25 L
.84046 .25 L
.84046 .25 L
Mistroke
.84047 .25 L
.84047 .25 L
.84048 .25 L
.84049 .25 L
.84049 .25 L
.8405 .25 L
.84051 .25 L
.84051 .25 L
.84052 .25 L
.84052 .25 L
.84053 .25 L
.84054 .25 L
.84054 .25 L
.84055 .25 L
.84056 .25 L
.84056 .25 L
.84057 .25 L
.84057 .25 L
.84058 .25 L
.84058 .25 L
.84059 .25 L
.8406 .25 L
.8406 .25 L
.84061 .25 L
.84061 .25 L
.84062 .25 L
.84062 .25 L
.84063 .25 L
.84064 .25 L
.84064 .25 L
.84065 .25 L
.84066 .25 L
.84066 .25 L
.84067 .25 L
.84067 .25 L
.84067 .25 L
.84068 .25 L
.84069 .25 L
.84069 .25 L
.8407 .25 L
.84071 .25 L
.84071 .25 L
.84072 .25 L
.84073 .25 L
.84073 .25 L
.84074 .25 L
.84074 .25 L
.84075 .25 L
.84076 .25 L
.84076 .25 L
Mistroke
.84077 .25 L
.84078 .25 L
.84078 .25 L
.84079 .25 L
.84079 .25 L
.8408 .25 L
.8408 .25 L
.84081 .25 L
.84082 .25 L
.84082 .25 L
.84083 .25 L
.84083 .25 L
.84084 .25 L
.84085 .25 L
.84085 .25 L
.84086 .25 L
.84086 .25 L
.84087 .25 L
.84087 .25 L
.84088 .25 L
.84088 .25 L
.84089 .25 L
.8409 .25 L
.8409 .25 L
.8409 .25 L
.84091 .25 L
.84092 .25 L
.84092 .25 L
.84093 .25 L
.84093 .25 L
.84094 .25 L
.84095 .25 L
.84095 .25 L
.84095 .25 L
.84096 .25 L
.84097 .25 L
.84097 .25 L
.84098 .25 L
.84098 .25 L
.84099 .25 L
.841 .25 L
.841 .25 L
.84101 .25 L
.84101 .25 L
.84102 .25 L
.84102 .25 L
.84103 .25 L
.84104 .25 L
.84104 .25 L
.84105 .25 L
Mistroke
.84106 .25 L
.84106 .25 L
.84107 .25 L
.84107 .25 L
.84108 .25 L
.84109 .25 L
.84109 .25 L
.8411 .25 L
.84111 .25 L
.84111 .25 L
.84111 .25 L
.84112 .25 L
.84112 .25 L
.84113 .25 L
.84113 .25 L
.84114 .25 L
.84115 .25 L
.84115 .25 L
.84116 .25 L
.84117 .25 L
.84117 .25 L
.84118 .25 L
.84118 .25 L
.84119 .25 L
.8412 .25 L
.8412 .25 L
.84121 .25 L
.84122 .25 L
.84122 .25 L
.84123 .25 L
.84123 .25 L
.84124 .25 L
.84124 .25 L
.84125 .25 L
.84125 .25 L
.84126 .25 L
.84126 .25 L
.84127 .25 L
.84127 .25 L
.84127 .25 L
.84128 .25 L
.84128 .25 L
.84129 .25 L
.84129 .25 L
.84129 .25 L
.8413 .25 L
.8413 .25 L
.84131 .25 L
.84132 .25 L
.84132 .25 L
Mistroke
.84133 .25 L
.84134 .25 L
.84134 .25 L
.84135 .25 L
.84135 .25 L
.84136 .25 L
.84137 .25 L
.84137 .25 L
.84138 .25 L
.84139 .25 L
.84139 .25 L
.8414 .25 L
.8414 .25 L
.84141 .25 L
.84141 .25 L
.84142 .25 L
.84143 .25 L
.84143 .25 L
.84144 .25 L
.84144 .25 L
.84145 .25 L
.84145 .25 L
.84146 .25 L
.84147 .25 L
.84147 .25 L
.84148 .25 L
.84148 .25 L
.84149 .25 L
.8415 .25 L
.8415 .25 L
.8415 .25 L
.84151 .25 L
.84152 .25 L
.84153 .25 L
.84153 .25 L
.84154 .25 L
.84154 .25 L
.84155 .25 L
.84156 .25 L
.84156 .25 L
.84157 .25 L
.84158 .25 L
.84158 .25 L
.84159 .25 L
.8416 .25 L
.8416 .25 L
.8416 .25 L
.84161 .25 L
.84162 .25 L
.84162 .25 L
Mistroke
.84163 .25 L
.84163 .25 L
.84164 .25 L
.84165 .25 L
.84165 .25 L
.84166 .25 L
.84166 .25 L
.84167 .25 L
.84168 .25 L
.84168 .25 L
.84169 .25 L
.84169 .25 L
.8417 .25 L
.8417 .25 L
.84171 .25 L
.84171 .25 L
.84172 .25 L
.84172 .25 L
.84173 .25 L
.84173 .25 L
.84174 .25 L
.84175 .25 L
.84175 .25 L
.84176 .25 L
.84176 .25 L
.84177 .25 L
.84178 .25 L
.84178 .25 L
.84179 .25 L
.84179 .25 L
.84179 .25 L
.8418 .25 L
.84181 .25 L
.84181 .25 L
.84182 .25 L
.84182 .25 L
.84183 .25 L
.84184 .25 L
.84184 .25 L
.84185 .25 L
.84185 .25 L
.84186 .25 L
.84187 .25 L
.84187 .25 L
.84188 .25 L
.84188 .25 L
.84189 .25 L
.8419 .25 L
.8419 .25 L
.84191 .25 L
Mistroke
.84192 .25 L
.84192 .25 L
.84193 .25 L
.84193 .25 L
.84194 .25 L
.84194 .25 L
.84194 .25 L
.84195 .25 L
.84196 .25 L
.84196 .25 L
.84197 .25 L
.84198 .25 L
.84198 .25 L
.84199 .25 L
.842 .25 L
.842 .25 L
.84201 .25 L
.84202 .25 L
.84202 .25 L
.84203 .25 L
.84203 .25 L
.84204 .25 L
.84205 .25 L
.84205 .25 L
.84206 .25 L
.84206 .25 L
.84207 .25 L
.84207 .25 L
.84208 .25 L
.84208 .25 L
.84208 .25 L
.84209 .25 L
.84209 .25 L
.8421 .25 L
.8421 .25 L
.84211 .25 L
.84211 .25 L
.84211 .25 L
.84212 .25 L
.84212 .25 L
.84213 .25 L
.84213 .25 L
.84214 .25 L
.84215 .25 L
.84215 .25 L
.84216 .25 L
.84217 .25 L
.84217 .25 L
.84218 .25 L
.84218 .25 L
Mistroke
.84219 .25 L
.8422 .25 L
.8422 .25 L
.84221 .25 L
.84222 .25 L
.84222 .25 L
.84222 .25 L
.84223 .25 L
.84224 .25 L
.84224 .25 L
.84225 .25 L
.84226 .25 L
.84226 .25 L
.84227 .25 L
.84227 .25 L
.84228 .25 L
.84228 .25 L
.84229 .25 L
.8423 .25 L
.8423 .25 L
.84231 .25 L
.84232 .25 L
.84232 .25 L
.84232 .25 L
.84233 .25 L
.84234 .25 L
.84234 .25 L
.84235 .25 L
.84236 .25 L
.84236 .25 L
.84237 .25 L
.84237 .25 L
.84238 .25 L
.84239 .25 L
.84239 .25 L
.8424 .25 L
.84241 .25 L
.84241 .25 L
.84242 .25 L
.84242 .25 L
.84243 .25 L
.84243 .25 L
.84244 .25 L
.84245 .25 L
.84245 .25 L
.84246 .25 L
.84246 .25 L
.84247 .25 L
.84248 .25 L
.84248 .25 L
Mistroke
.84249 .25 L
.84249 .25 L
.8425 .25 L
.84251 .25 L
.84251 .25 L
.84252 .25 L
.84252 .25 L
.84252 .25 L
.84253 .25 L
.84254 .25 L
.84254 .25 L
.84255 .25 L
.84255 .25 L
.84256 .25 L
.84256 .25 L
.84257 .25 L
.84258 .25 L
.84258 .25 L
.84259 .25 L
.84259 .25 L
.8426 .25 L
.8426 .25 L
.84261 .25 L
.84261 .25 L
.84262 .25 L
.84262 .25 L
.84263 .25 L
.84264 .25 L
.84264 .25 L
.84265 .25 L
.84265 .25 L
.84266 .25 L
.84267 .25 L
.84267 .25 L
.84268 .25 L
.84268 .25 L
.84269 .25 L
.8427 .25 L
.8427 .25 L
.84271 .25 L
.84271 .25 L
.84272 .25 L
.84273 .25 L
.84273 .25 L
.84274 .25 L
.84275 .25 L
.84275 .25 L
.84276 .25 L
.84276 .25 L
.84276 .25 L
Mistroke
.84277 .25 L
.84278 .25 L
.84278 .25 L
.84279 .25 L
.8428 .25 L
.8428 .25 L
.84281 .25 L
.84281 .25 L
.84282 .25 L
.84283 .25 L
.84283 .25 L
.84284 .25 L
.84284 .25 L
.84285 .25 L
.84286 .25 L
.84286 .25 L
.84287 .25 L
.84288 .25 L
.84288 .25 L
.84289 .25 L
.84289 .25 L
.8429 .25 L
.8429 .25 L
.8429 .25 L
.84291 .25 L
.84291 .25 L
.84292 .25 L
.84292 .25 L
.84292 .25 L
.84293 .25 L
.84293 .25 L
.84294 .25 L
.84294 .25 L
.84294 .25 L
.84295 .25 L
.84296 .25 L
.84296 .25 L
.84297 .25 L
.84298 .25 L
.84298 .25 L
.84299 .25 L
.84299 .25 L
.843 .25 L
.84301 .25 L
.84301 .25 L
.84302 .25 L
.84303 .25 L
.84303 .25 L
.84304 .25 L
.84304 .25 L
Mistroke
.84305 .25 L
.84305 .25 L
.84306 .25 L
.84307 .25 L
.84307 .25 L
.84308 .25 L
.84309 .25 L
.84309 .25 L
.8431 .25 L
.8431 .25 L
.84311 .25 L
.84311 .25 L
.84312 .25 L
.84313 .25 L
.84313 .25 L
.84314 .25 L
.84314 .25 L
.84315 .25 L
.84315 .25 L
.84316 .25 L
.84317 .25 L
.84317 .25 L
.84318 .25 L
.84319 .25 L
.84319 .25 L
.8432 .25 L
.8432 .25 L
.84321 .25 L
.84322 .25 L
.84322 .25 L
.84323 .25 L
.84324 .25 L
.84324 .25 L
.84325 .25 L
.84325 .25 L
.84326 .25 L
.84326 .25 L
.84327 .25 L
.84328 .25 L
.84328 .25 L
.84329 .25 L
.84329 .25 L
.8433 .25 L
.8433 .25 L
.84331 .25 L
.84332 .25 L
.84332 .25 L
.84333 .25 L
.84333 .25 L
.84334 .25 L
Mistroke
.84334 .25 L
.84335 .25 L
.84335 .25 L
.84336 .25 L
.84337 .25 L
.84337 .25 L
.84338 .25 L
.84339 .25 L
.84339 .25 L
.8434 .25 L
.84341 .25 L
.84341 .25 L
.84342 .25 L
.84343 .25 L
.84343 .25 L
.84344 .25 L
.84344 .25 L
.84345 .25 L
.84345 .25 L
.84346 .25 L
.84347 .25 L
.84347 .25 L
.84348 .25 L
.84348 .25 L
.84349 .25 L
.8435 .25 L
.8435 .25 L
.84351 .25 L
.84351 .25 L
.84352 .25 L
.84353 .25 L
.84353 .25 L
.84354 .25 L
.84354 .25 L
.84355 .25 L
.84355 .25 L
.84356 .25 L
.84356 .25 L
.84357 .25 L
.84357 .25 L
.84358 .25 L
.84358 .25 L
.84359 .25 L
.8436 .25 L
.8436 .25 L
.84361 .25 L
.84361 .25 L
.84362 .25 L
.84362 .25 L
.84363 .25 L
Mistroke
.84364 .25 L
.84364 .25 L
.84364 .25 L
.84365 .25 L
.84366 .25 L
.84366 .25 L
.84367 .25 L
.84367 .25 L
.84368 .25 L
.84369 .25 L
.84369 .25 L
.8437 .25 L
.8437 .25 L
.84371 .25 L
.84372 .25 L
.84372 .25 L
.84373 .25 L
.84373 .25 L
.84374 .25 L
.84375 .25 L
.84375 .25 L
.84376 .25 L
.84377 .25 L
.84377 .25 L
.84378 .25 L
.84378 .25 L
.84379 .25 L
.84379 .25 L
.84379 .25 L
.8438 .25 L
.84381 .25 L
.84381 .25 L
.84382 .25 L
.84383 .25 L
.84383 .25 L
.84384 .25 L
.84385 .25 L
.84385 .25 L
.84386 .25 L
.84387 .25 L
.84387 .25 L
.84388 .25 L
.84388 .25 L
.84389 .25 L
.8439 .25 L
.8439 .25 L
.84391 .25 L
.84391 .25 L
.84392 .25 L
.84392 .25 L
Mistroke
.84393 .25 L
.84393 .25 L
.84393 .25 L
.84394 .25 L
.84394 .25 L
.84395 .25 L
.84395 .25 L
.84396 .25 L
.84396 .25 L
.84396 .25 L
.84397 .25 L
.84397 .25 L
.84398 .25 L
.84398 .25 L
.84399 .25 L
.844 .25 L
.844 .25 L
.84401 .25 L
.84402 .25 L
.84402 .25 L
.84403 .25 L
.84403 .25 L
.84404 .25 L
.84405 .25 L
.84405 .25 L
.84406 .25 L
.84407 .25 L
.84407 .25 L
.84407 .25 L
.84408 .25 L
.84409 .25 L
.84409 .25 L
.8441 .25 L
.84411 .25 L
.84411 .25 L
.84412 .25 L
.84412 .25 L
.84413 .25 L
.84413 .25 L
.84414 .25 L
.84415 .25 L
.84415 .25 L
.84416 .25 L
.84417 .25 L
.84417 .25 L
.84417 .25 L
.84418 .25 L
.84419 .25 L
.84419 .25 L
.8442 .25 L
Mistroke
.84421 .25 L
.84421 .25 L
.84422 .25 L
.84422 .25 L
.84423 .25 L
.84424 .25 L
.84424 .25 L
.84425 .25 L
.84426 .25 L
.84426 .25 L
.84427 .25 L
.84427 .25 L
.84428 .25 L
.84428 .25 L
.84429 .25 L
.8443 .25 L
.8443 .25 L
.84431 .25 L
.84431 .25 L
.84432 .25 L
.84433 .25 L
.84433 .25 L
.84434 .25 L
.84434 .25 L
.84435 .25 L
.84436 .25 L
.84436 .25 L
.84437 .25 L
.84437 .25 L
.84438 .25 L
.84438 .25 L
.84439 .25 L
.84439 .25 L
.8444 .25 L
.8444 .25 L
.84441 .25 L
.84441 .25 L
.84442 .25 L
.84443 .25 L
.84443 .25 L
.84444 .25 L
.84445 .25 L
.84445 .25 L
.84445 .25 L
.84446 .25 L
.84446 .25 L
.84447 .25 L
.84447 .25 L
.84448 .25 L
.84449 .25 L
Mistroke
.84449 .25 L
.8445 .25 L
.8445 .25 L
.84451 .25 L
.84452 .25 L
.84452 .25 L
.84453 .25 L
.84453 .25 L
.84454 .25 L
.84455 .25 L
.84455 .25 L
.84456 .25 L
.84457 .25 L
.84457 .25 L
.84458 .25 L
.84458 .25 L
.84459 .25 L
.8446 .25 L
.8446 .25 L
.84461 .25 L
.84461 .25 L
.84462 .25 L
.84462 .25 L
.84463 .25 L
.84463 .25 L
.84464 .25 L
.84465 .25 L
.84465 .25 L
.84466 .25 L
.84466 .25 L
.84467 .25 L
.84468 .25 L
.84468 .25 L
.84469 .25 L
.8447 .25 L
.8447 .25 L
.84471 .25 L
.84472 .25 L
.84472 .25 L
.84473 .25 L
.84473 .25 L
.84474 .25 L
.84474 .25 L
.84475 .25 L
.84475 .25 L
.84475 .25 L
.84476 .25 L
.84476 .25 L
.84477 .25 L
.84477 .25 L
Mistroke
.84478 .25 L
.84478 .25 L
.84478 .25 L
.84479 .25 L
.84479 .25 L
.84479 .25 L
.8448 .25 L
.84481 .25 L
.84481 .25 L
.84482 .25 L
.84483 .25 L
.84483 .25 L
.84484 .25 L
.84485 .25 L
.84485 .25 L
.84486 .25 L
.84486 .25 L
.84487 .25 L
.84488 .25 L
.84488 .25 L
.84489 .25 L
.84489 .25 L
.8449 .25 L
.84491 .25 L
.84491 .25 L
.84492 .25 L
.84492 .25 L
.84493 .25 L
.84494 .25 L
.84494 .25 L
.84495 .25 L
.84495 .25 L
.84496 .25 L
.84496 .25 L
.84497 .25 L
.84498 .25 L
.84498 .25 L
.84499 .25 L
.84499 .25 L
.845 .25 L
.845 .25 L
.84501 .25 L
.84502 .25 L
.84502 .25 L
.84503 .25 L
.84504 .25 L
.84504 .25 L
.84505 .25 L
.84505 .25 L
.84506 .25 L
Mistroke
.84507 .25 L
.84507 .25 L
.84508 .25 L
.84509 .25 L
.84509 .25 L
.8451 .25 L
.8451 .25 L
.84511 .25 L
.84511 .25 L
.84512 .25 L
.84513 .25 L
.84513 .25 L
.84514 .25 L
.84514 .25 L
.84515 .25 L
.84516 .25 L
.84516 .25 L
.84517 .25 L
.84517 .25 L
.84518 .25 L
.84519 .25 L
.84519 .25 L
.8452 .25 L
.8452 .25 L
.84521 .25 L
.84521 .25 L
.84522 .25 L
.84522 .25 L
.84523 .25 L
.84523 .25 L
.84524 .25 L
.84524 .25 L
.84525 .25 L
.84526 .25 L
.84526 .25 L
.84527 .25 L
.84527 .25 L
.84528 .25 L
.84528 .25 L
.84529 .25 L
.84529 .25 L
.8453 .25 L
.8453 .25 L
.84531 .25 L
.84532 .25 L
.84532 .25 L
.84533 .25 L
.84533 .25 L
.84534 .25 L
.84535 .25 L
Mistroke
.84535 .25 L
.84536 .25 L
.84536 .25 L
.84537 .25 L
.84538 .25 L
.84538 .25 L
.84539 .25 L
.8454 .25 L
.8454 .25 L
.84541 .25 L
.84541 .25 L
.84542 .25 L
.84543 .25 L
.84543 .25 L
.84544 .25 L
.84544 .25 L
.84544 .25 L
.84545 .25 L
.84546 .25 L
.84546 .25 L
.84547 .25 L
.84548 .25 L
.84548 .25 L
.84549 .25 L
.84549 .25 L
.8455 .25 L
.84551 .25 L
.84551 .25 L
.84552 .25 L
.84553 .25 L
.84553 .25 L
.84554 .25 L
.84555 .25 L
.84555 .25 L
.84556 .25 L
.84556 .25 L
.84557 .25 L
.84557 .25 L
.84557 .25 L
.84558 .25 L
.84558 .25 L
.84559 .25 L
.84559 .25 L
.8456 .25 L
.8456 .25 L
.8456 .25 L
.84561 .25 L
.84561 .25 L
.84561 .25 L
.84562 .25 L
Mistroke
.84562 .25 L
.84563 .25 L
.84564 .25 L
.84564 .25 L
.84565 .25 L
.84566 .25 L
.84566 .25 L
.84567 .25 L
.84568 .25 L
.84568 .25 L
.84569 .25 L
.84569 .25 L
.8457 .25 L
.84571 .25 L
.84571 .25 L
.84572 .25 L
.84572 .25 L
.84573 .25 L
.84574 .25 L
.84574 .25 L
.84575 .25 L
.84575 .25 L
.84576 .25 L
.84577 .25 L
.84577 .25 L
.84578 .25 L
.84578 .25 L
.84579 .25 L
.84579 .25 L
.8458 .25 L
.84581 .25 L
.84581 .25 L
.84582 .25 L
.84582 .25 L
.84583 .25 L
.84583 .25 L
.84584 .25 L
.84585 .25 L
.84585 .25 L
.84586 .25 L
.84587 .25 L
.84587 .25 L
.84588 .25 L
.84588 .25 L
.84589 .25 L
.8459 .25 L
.8459 .25 L
.84591 .25 L
.84592 .25 L
.84592 .25 L
Mistroke
.84592 .25 L
.84593 .25 L
.84594 .25 L
.84594 .25 L
.84595 .25 L
.84596 .25 L
.84596 .25 L
.84597 .25 L
.84597 .25 L
.84598 .25 L
.84598 .25 L
.84599 .25 L
.846 .25 L
.846 .25 L
.84601 .25 L
.84602 .25 L
.84602 .25 L
.84602 .25 L
.84603 .25 L
.84604 .25 L
.84604 .25 L
.84605 .25 L
.84605 .25 L
.84606 .25 L
.84606 .25 L
.84607 .25 L
.84607 .25 L
.84608 .25 L
.84609 .25 L
.84609 .25 L
.8461 .25 L
.8461 .25 L
.84611 .25 L
.84611 .25 L
.84611 .25 L
.84612 .25 L
.84613 .25 L
.84613 .25 L
.84614 .25 L
.84615 .25 L
.84615 .25 L
.84616 .25 L
.84616 .25 L
.84617 .25 L
.84618 .25 L
.84618 .25 L
.84619 .25 L
.84619 .25 L
.8462 .25 L
.84621 .25 L
Mistroke
.84621 .25 L
.84622 .25 L
.84623 .25 L
.84623 .25 L
.84624 .25 L
.84625 .25 L
.84625 .25 L
.84626 .25 L
.84626 .25 L
.84626 .25 L
.84627 .25 L
.84627 .25 L
.84628 .25 L
.84629 .25 L
.84629 .25 L
.8463 .25 L
.84631 .25 L
.84631 .25 L
.84632 .25 L
.84632 .25 L
.84633 .25 L
.84634 .25 L
.84634 .25 L
.84635 .25 L
.84636 .25 L
.84636 .25 L
.84637 .25 L
.84638 .25 L
.84638 .25 L
.84638 .25 L
.84639 .25 L
.84639 .25 L
.8464 .25 L
.8464 .25 L
.8464 .25 L
.84641 .25 L
.84642 .25 L
.84642 .25 L
.84642 .25 L
.84643 .25 L
.84643 .25 L
.84643 .25 L
.84644 .25 L
.84644 .25 L
.84645 .25 L
.84645 .25 L
.84646 .25 L
.84647 .25 L
.84647 .25 L
.84648 .25 L
Mistroke
.84649 .25 L
.84649 .25 L
.8465 .25 L
.8465 .25 L
.84651 .25 L
.84652 .25 L
.84652 .25 L
.84653 .25 L
.84654 .25 L
.84654 .25 L
.84655 .25 L
.84655 .25 L
.84656 .25 L
.84656 .25 L
.84657 .25 L
.84658 .25 L
.84658 .25 L
.84659 .25 L
.84659 .25 L
.8466 .25 L
.84661 .25 L
.84661 .25 L
.84662 .25 L
.84662 .25 L
.84663 .25 L
.84664 .25 L
.84664 .25 L
.84664 .25 L
.84665 .25 L
.84666 .25 L
.84666 .25 L
.84667 .25 L
.84668 .25 L
.84668 .25 L
.84669 .25 L
.84669 .25 L
.8467 .25 L
.84671 .25 L
.84671 .25 L
.84672 .25 L
.84673 .25 L
.84673 .25 L
.84674 .25 L
.84674 .25 L
.84675 .25 L
.84675 .25 L
.84676 .25 L
.84677 .25 L
.84677 .25 L
.84678 .25 L
Mistroke
.84679 .25 L
.84679 .25 L
.8468 .25 L
.8468 .25 L
.84681 .25 L
.84681 .25 L
.84682 .25 L
.84683 .25 L
.84683 .25 L
.84684 .25 L
.84684 .25 L
.84685 .25 L
.84685 .25 L
.84686 .25 L
.84687 .25 L
.84687 .25 L
.84687 .25 L
.84688 .25 L
.84689 .25 L
.84689 .25 L
.8469 .25 L
.8469 .25 L
.84691 .25 L
.84692 .25 L
.84692 .25 L
.84692 .25 L
.84693 .25 L
.84693 .25 L
.84694 .25 L
.84694 .25 L
.84695 .25 L
.84696 .25 L
.84696 .25 L
.84697 .25 L
.84698 .25 L
.84698 .25 L
.84699 .25 L
.84699 .25 L
.847 .25 L
.84701 .25 L
.84701 .25 L
.84702 .25 L
.84702 .25 L
.84703 .25 L
.84704 .25 L
.84704 .25 L
.84705 .25 L
.84706 .25 L
.84706 .25 L
.84707 .25 L
Mistroke
.84708 .25 L
.84708 .25 L
.84708 .25 L
.84709 .25 L
.84709 .25 L
.8471 .25 L
.8471 .25 L
.84711 .25 L
.84712 .25 L
.84712 .25 L
.84713 .25 L
.84713 .25 L
.84714 .25 L
.84715 .25 L
.84715 .25 L
.84716 .25 L
.84717 .25 L
.84717 .25 L
.84718 .25 L
.84719 .25 L
.84719 .25 L
.8472 .25 L
.8472 .25 L
.84721 .25 L
.84721 .25 L
.84722 .25 L
.84722 .25 L
.84722 .25 L
.84723 .25 L
.84723 .25 L
.84724 .25 L
.84724 .25 L
.84725 .25 L
.84725 .25 L
.84725 .25 L
.84726 .25 L
.84726 .25 L
.84726 .25 L
.84727 .25 L
.84728 .25 L
.84728 .25 L
.84729 .25 L
.8473 .25 L
.8473 .25 L
.84731 .25 L
.84732 .25 L
.84732 .25 L
.84733 .25 L
.84733 .25 L
.84734 .25 L
Mistroke
.84735 .25 L
.84735 .25 L
.84736 .25 L
.84737 .25 L
.84737 .25 L
.84738 .25 L
.84738 .25 L
.84739 .25 L
.84739 .25 L
.8474 .25 L
.84741 .25 L
.84741 .25 L
.84742 .25 L
.84742 .25 L
.84743 .25 L
.84744 .25 L
.84744 .25 L
.84745 .25 L
.84745 .25 L
.84746 .25 L
.84746 .25 L
.84747 .25 L
.84747 .25 L
.84748 .25 L
.84749 .25 L
.84749 .25 L
.8475 .25 L
.84751 .25 L
.84751 .25 L
.84752 .25 L
.84752 .25 L
.84753 .25 L
.84754 .25 L
.84754 .25 L
.84755 .25 L
.84756 .25 L
.84756 .25 L
.84757 .25 L
.84757 .25 L
.84758 .25 L
.84758 .25 L
.84759 .25 L
.8476 .25 L
.8476 .25 L
.84761 .25 L
.84761 .25 L
.84762 .25 L
.84763 .25 L
.84763 .25 L
.84764 .25 L
Mistroke
.84764 .25 L
.84765 .25 L
.84766 .25 L
.84766 .25 L
.84767 .25 L
.84767 .25 L
.84768 .25 L
.84768 .25 L
.84769 .25 L
.8477 .25 L
.8477 .25 L
.84771 .25 L
.84772 .25 L
.84772 .25 L
.84773 .25 L
.84773 .25 L
.84774 .25 L
.84775 .25 L
.84775 .25 L
.84776 .25 L
.84777 .25 L
.84777 .25 L
.84777 .25 L
.84778 .25 L
.84779 .25 L
.84779 .25 L
.8478 .25 L
.84781 .25 L
.84781 .25 L
.84782 .25 L
.84782 .25 L
.84783 .25 L
.84783 .25 L
.84784 .25 L
.84785 .25 L
.84785 .25 L
.84786 .25 L
.84787 .25 L
.84787 .25 L
.84787 .25 L
.84788 .25 L
.84789 .25 L
.84789 .25 L
.8479 .25 L
.8479 .25 L
.8479 .25 L
.84791 .25 L
.84792 .25 L
.84792 .25 L
.84793 .25 L
Mistroke
.84794 .25 L
.84794 .25 L
.84795 .25 L
.84795 .25 L
.84796 .25 L
.84796 .25 L
.84796 .25 L
.84797 .25 L
.84798 .25 L
.84798 .25 L
.84799 .25 L
.848 .25 L
.848 .25 L
.84801 .25 L
.84801 .25 L
.84802 .25 L
.84803 .25 L
.84803 .25 L
.84804 .25 L
.84804 .25 L
.84805 .25 L
.84806 .25 L
.84806 .25 L
.84807 .25 L
.84808 .25 L
.84808 .25 L
.84809 .25 L
.8481 .25 L
.8481 .25 L
.8481 .25 L
.84811 .25 L
.84811 .25 L
.84812 .25 L
.84812 .25 L
.84813 .25 L
.84814 .25 L
.84814 .25 L
.84815 .25 L
.84816 .25 L
.84816 .25 L
.84817 .25 L
.84817 .25 L
.84818 .25 L
.84819 .25 L
.84819 .25 L
.8482 .25 L
.84821 .25 L
.84821 .25 L
.84822 .25 L
.84823 .25 L
Mistroke
.84823 .25 L
.84823 .25 L
.84824 .25 L
.84824 .25 L
.84825 .25 L
.84825 .25 L
.84825 .25 L
.84826 .25 L
.84826 .25 L
.84827 .25 L
.84827 .25 L
.84828 .25 L
.84828 .25 L
.84828 .25 L
.84829 .25 L
.84829 .25 L
.8483 .25 L
.8483 .25 L
.84831 .25 L
.84832 .25 L
.84832 .25 L
.84833 .25 L
.84834 .25 L
.84834 .25 L
.84835 .25 L
.84835 .25 L
.84836 .25 L
.84837 .25 L
.84837 .25 L
.84838 .25 L
.84839 .25 L
.84839 .25 L
.8484 .25 L
.8484 .25 L
.84841 .25 L
.84841 .25 L
.84842 .25 L
.84843 .25 L
.84843 .25 L
.84844 .25 L
.84844 .25 L
.84845 .25 L
.84846 .25 L
.84846 .25 L
.84847 .25 L
.84847 .25 L
.84848 .25 L
.84849 .25 L
.84849 .25 L
.84849 .25 L
Mistroke
.8485 .25 L
.84851 .25 L
.84851 .25 L
.84852 .25 L
.84853 .25 L
.84853 .25 L
.84854 .25 L
.84854 .25 L
.84855 .25 L
.84856 .25 L
.84856 .25 L
.84857 .25 L
.84858 .25 L
.84858 .25 L
.84859 .25 L
.84859 .25 L
.8486 .25 L
.8486 .25 L
.84861 .25 L
.84862 .25 L
.84862 .25 L
.84863 .25 L
.84864 .25 L
.84864 .25 L
.84865 .25 L
.84865 .25 L
.84866 .25 L
.84866 .25 L
.84867 .25 L
.84868 .25 L
.84868 .25 L
.84869 .25 L
.84869 .25 L
.8487 .25 L
.8487 .25 L
.84871 .25 L
.84872 .25 L
.84872 .25 L
.84872 .25 L
.84873 .25 L
.84874 .25 L
.84874 .25 L
.84875 .25 L
.84875 .25 L
.84876 .25 L
.84877 .25 L
.84877 .25 L
.84877 .25 L
.84878 .25 L
.84878 .25 L
Mistroke
.84879 .25 L
.84879 .25 L
.8488 .25 L
.84881 .25 L
.84881 .25 L
.84882 .25 L
.84883 .25 L
.84883 .25 L
.84884 .25 L
.84884 .25 L
.84885 .25 L
.84886 .25 L
.84886 .25 L
.84887 .25 L
.84887 .25 L
.84888 .25 L
.84889 .25 L
.84889 .25 L
.8489 .25 L
.84891 .25 L
.84891 .25 L
.84892 .25 L
.84893 .25 L
.84893 .25 L
.84893 .25 L
.84894 .25 L
.84894 .25 L
.84895 .25 L
.84895 .25 L
.84896 .25 L
.84897 .25 L
.84897 .25 L
.84898 .25 L
.84898 .25 L
.84899 .25 L
.849 .25 L
.849 .25 L
.84901 .25 L
.84902 .25 L
.84902 .25 L
.84903 .25 L
.84904 .25 L
.84904 .25 L
.84905 .25 L
.84905 .25 L
.84906 .25 L
.84906 .25 L
.84907 .25 L
.84907 .25 L
.84907 .25 L
Mistroke
.84908 .25 L
.84909 .25 L
.84909 .25 L
.84909 .25 L
.8491 .25 L
.8491 .25 L
.8491 .25 L
.84911 .25 L
.84911 .25 L
.84911 .25 L
.84912 .25 L
.84913 .25 L
.84913 .25 L
.84914 .25 L
.84915 .25 L
.84915 .25 L
.84916 .25 L
.84917 .25 L
.84917 .25 L
.84918 .25 L
.84919 .25 L
.84919 .25 L
.8492 .25 L
.8492 .25 L
.84921 .25 L
.84922 .25 L
.84922 .25 L
.84923 .25 L
.84923 .25 L
.84924 .25 L
.84924 .25 L
.84925 .25 L
.84926 .25 L
.84926 .25 L
.84927 .25 L
.84927 .25 L
.84928 .25 L
.84929 .25 L
.84929 .25 L
.8493 .25 L
.8493 .25 L
.84931 .25 L
.84931 .25 L
.84932 .25 L
.84932 .25 L
.84933 .25 L
.84934 .25 L
.84934 .25 L
.84935 .25 L
.84936 .25 L
Mistroke
.84936 .25 L
.84937 .25 L
.84937 .25 L
.84938 .25 L
.84939 .25 L
.84939 .25 L
.8494 .25 L
.84941 .25 L
.84941 .25 L
.84942 .25 L
.84942 .25 L
.84943 .25 L
.84944 .25 L
.84944 .25 L
.84945 .25 L
.84945 .25 L
.84946 .25 L
.84947 .25 L
.84947 .25 L
.84948 .25 L
.84948 .25 L
.84949 .25 L
.84949 .25 L
.8495 .25 L
.84951 .25 L
.84951 .25 L
.84952 .25 L
.84952 .25 L
.84953 .25 L
.84953 .25 L
.84954 .25 L
.84954 .25 L
.84955 .25 L
.84955 .25 L
.84956 .25 L
.84957 .25 L
.84957 .25 L
.84958 .25 L
.84958 .25 L
.84959 .25 L
.84959 .25 L
.8496 .25 L
.8496 .25 L
.84961 .25 L
.84961 .25 L
.84962 .25 L
.84963 .25 L
.84963 .25 L
.84964 .25 L
.84964 .25 L
Mistroke
.84965 .25 L
.84966 .25 L
.84966 .25 L
.84967 .25 L
.84967 .25 L
.84968 .25 L
.84969 .25 L
.84969 .25 L
.8497 .25 L
.8497 .25 L
.84971 .25 L
.84972 .25 L
.84972 .25 L
.84973 .25 L
.84974 .25 L
.84974 .25 L
.84975 .25 L
.84975 .25 L
.84976 .25 L
.84976 .25 L
.84976 .25 L
.84977 .25 L
.84978 .25 L
.84978 .25 L
.84979 .25 L
.8498 .25 L
.8498 .25 L
.84981 .25 L
.84981 .25 L
.84982 .25 L
.84983 .25 L
.84983 .25 L
.84984 .25 L
.84985 .25 L
.84985 .25 L
.84986 .25 L
.84987 .25 L
.84987 .25 L
.84988 .25 L
.84988 .25 L
.84989 .25 L
.84989 .25 L
.84989 .25 L
.8499 .25 L
.8499 .25 L
.84991 .25 L
.84991 .25 L
.84992 .25 L
.84992 .25 L
.84992 .25 L
Mistroke
.84993 .25 L
.84993 .25 L
.84994 .25 L
.84994 .25 L
.84995 .25 L
.84995 .25 L
.84996 .25 L
.84997 .25 L
.84997 .25 L
.84998 .25 L
.84998 .25 L
.84999 .25 L
.85 .25 L
.85 .25 L
.85001 .25 L
.85002 .25 L
.85002 .25 L
.85003 .25 L
.85004 .25 L
.85004 .25 L
.85004 .25 L
.85005 .25 L
.85006 .25 L
.85006 .25 L
.85007 .25 L
.85007 .25 L
.85008 .25 L
.85009 .25 L
.85009 .25 L
.8501 .25 L
.8501 .25 L
.85011 .25 L
.85012 .25 L
.85012 .25 L
.85013 .25 L
.85013 .25 L
.85014 .25 L
.85014 .25 L
.85015 .25 L
.85015 .25 L
.85016 .25 L
.85017 .25 L
.85017 .25 L
.85018 .25 L
.85019 .25 L
.85019 .25 L
.8502 .25 L
.8502 .25 L
.85021 .25 L
.85022 .25 L
Mistroke
.85022 .25 L
.85023 .25 L
.85024 .25 L
.85024 .25 L
.85025 .25 L
.85025 .25 L
.85026 .25 L
.85026 .25 L
.85027 .25 L
.85028 .25 L
.85028 .25 L
.85029 .25 L
.85029 .25 L
.8503 .25 L
.85031 .25 L
.85031 .25 L
.85032 .25 L
.85032 .25 L
.85033 .25 L
.85034 .25 L
.85034 .25 L
.85034 .25 L
.85035 .25 L
.85036 .25 L
.85036 .25 L
.85037 .25 L
.85037 .25 L
.85038 .25 L
.85038 .25 L
.85039 .25 L
.85039 .25 L
.8504 .25 L
.85041 .25 L
.85041 .25 L
.85042 .25 L
.85042 .25 L
.85043 .25 L
.85043 .25 L
.85044 .25 L
.85044 .25 L
.85045 .25 L
.85046 .25 L
.85046 .25 L
.85047 .25 L
.85047 .25 L
.85048 .25 L
.85048 .25 L
.85049 .25 L
.8505 .25 L
.8505 .25 L
Mistroke
.85051 .25 L
.85052 .25 L
.85052 .25 L
.85053 .25 L
.85053 .25 L
.85054 .25 L
.85055 .25 L
.85055 .25 L
.85056 .25 L
.85057 .25 L
.85057 .25 L
.85058 .25 L
.85058 .25 L
.85058 .25 L
.85059 .25 L
.85059 .25 L
.8506 .25 L
.85061 .25 L
.85061 .25 L
.85062 .25 L
.85063 .25 L
.85063 .25 L
.85064 .25 L
.85064 .25 L
.85065 .25 L
.85066 .25 L
.85066 .25 L
.85067 .25 L
.85068 .25 L
.85068 .25 L
.85069 .25 L
.8507 .25 L
.8507 .25 L
.8507 .25 L
.85071 .25 L
.85071 .25 L
.85072 .25 L
.85072 .25 L
.85073 .25 L
.85073 .25 L
.85074 .25 L
.85074 .25 L
.85074 .25 L
.85075 .25 L
.85075 .25 L
.85075 .25 L
.85076 .25 L
.85076 .25 L
.85077 .25 L
.85078 .25 L
Mistroke
.85078 .25 L
.85079 .25 L
.8508 .25 L
.8508 .25 L
.85081 .25 L
.85081 .25 L
.85082 .25 L
.85083 .25 L
.85083 .25 L
.85084 .25 L
.85084 .25 L
.85085 .25 L
.85086 .25 L
.85086 .25 L
.85087 .25 L
.85087 .25 L
.85088 .25 L
.85089 .25 L
.85089 .25 L
.8509 .25 L
.8509 .25 L
.85091 .25 L
.85091 .25 L
.85092 .25 L
.85093 .25 L
.85093 .25 L
.85094 .25 L
.85095 .25 L
.85095 .25 L
.85096 .25 L
.85096 .25 L
.85096 .25 L
.85097 .25 L
.85098 .25 L
.85098 .25 L
.85099 .25 L
.851 .25 L
.851 .25 L
.85101 .25 L
.85102 .25 L
.85102 .25 L
.85103 .25 L
.85103 .25 L
.85104 .25 L
.85105 .25 L
.85105 .25 L
.85106 .25 L
.85106 .25 L
.85107 .25 L
.85108 .25 L
Mistroke
.85108 .25 L
.85109 .25 L
.85109 .25 L
.8511 .25 L
.85111 .25 L
.85111 .25 L
.85112 .25 L
.85112 .25 L
.85113 .25 L
.85113 .25 L
.85114 .25 L
.85115 .25 L
.85115 .25 L
.85116 .25 L
.85116 .25 L
.85117 .25 L
.85117 .25 L
.85118 .25 L
.85119 .25 L
.85119 .25 L
.8512 .25 L
.85121 .25 L
.85121 .25 L
.85122 .25 L
.85122 .25 L
.85123 .25 L
.85124 .25 L
.85124 .25 L
.85125 .25 L
.85126 .25 L
.85126 .25 L
.85127 .25 L
.85127 .25 L
.85128 .25 L
.85128 .25 L
.85129 .25 L
.8513 .25 L
.8513 .25 L
.85131 .25 L
.85131 .25 L
.85132 .25 L
.85133 .25 L
.85133 .25 L
.85134 .25 L
.85134 .25 L
.85135 .25 L
.85136 .25 L
.85136 .25 L
.85137 .25 L
.85137 .25 L
Mistroke
.85138 .25 L
.85138 .25 L
.85139 .25 L
.85139 .25 L
.8514 .25 L
.8514 .25 L
.85141 .25 L
.85141 .25 L
.85142 .25 L
.85143 .25 L
.85143 .25 L
.85144 .25 L
.85144 .25 L
.85145 .25 L
.85145 .25 L
.85146 .25 L
.85146 .25 L
.85147 .25 L
.85147 .25 L
.85148 .25 L
.85149 .25 L
.85149 .25 L
.8515 .25 L
.8515 .25 L
.85151 .25 L
.85152 .25 L
.85152 .25 L
.85153 .25 L
.85153 .25 L
.85154 .25 L
.85155 .25 L
.85155 .25 L
.85156 .25 L
.85157 .25 L
.85157 .25 L
.85158 .25 L
.85159 .25 L
.85159 .25 L
.8516 .25 L
.8516 .25 L
.85161 .25 L
.85161 .25 L
.85161 .25 L
.85162 .25 L
.85163 .25 L
.85163 .25 L
.85164 .25 L
.85165 .25 L
.85165 .25 L
.85166 .25 L
Mistroke
.85166 .25 L
.85167 .25 L
.85168 .25 L
.85168 .25 L
.85169 .25 L
.8517 .25 L
.8517 .25 L
.85171 .25 L
.85172 .25 L
.85172 .25 L
.85173 .25 L
.85173 .25 L
.85174 .25 L
.85174 .25 L
.85174 .25 L
.85175 .25 L
.85175 .25 L
.85176 .25 L
.85176 .25 L
.85177 .25 L
.85177 .25 L
.85177 .25 L
.85178 .25 L
.85178 .25 L
.85178 .25 L
.85179 .25 L
.85179 .25 L
.8518 .25 L
.85181 .25 L
.85182 .25 L
.85182 .25 L
.85183 .25 L
.85183 .25 L
.85184 .25 L
.85185 .25 L
.85185 .25 L
.85186 .25 L
.85187 .25 L
.85187 .25 L
.85188 .25 L
.85189 .25 L
.85189 .25 L
.85189 .25 L
.8519 .25 L
.85191 .25 L
.85191 .25 L
.85192 .25 L
.85192 .25 L
.85193 .25 L
.85194 .25 L
Mistroke
.85194 .25 L
.85195 .25 L
.85195 .25 L
.85196 .25 L
.85197 .25 L
.85197 .25 L
.85198 .25 L
.85198 .25 L
.85199 .25 L
.85199 .25 L
.852 .25 L
.852 .25 L
.85201 .25 L
.85202 .25 L
.85202 .25 L
.85203 .25 L
.85204 .25 L
.85204 .25 L
.85205 .25 L
.85205 .25 L
.85206 .25 L
.85207 .25 L
.85207 .25 L
.85208 .25 L
.85209 .25 L
.85209 .25 L
.8521 .25 L
.8521 .25 L
.85211 .25 L
.85211 .25 L
.85212 .25 L
.85213 .25 L
.85213 .25 L
.85214 .25 L
.85214 .25 L
.85215 .25 L
.85216 .25 L
.85216 .25 L
.85217 .25 L
.85217 .25 L
.85218 .25 L
.85219 .25 L
.85219 .25 L
.85219 .25 L
.8522 .25 L
.85221 .25 L
.85221 .25 L
.85222 .25 L
.85222 .25 L
.85223 .25 L
Mistroke
.85223 .25 L
.85224 .25 L
.85224 .25 L
.85225 .25 L
.85226 .25 L
.85226 .25 L
.85227 .25 L
.85227 .25 L
.85228 .25 L
.85228 .25 L
.85229 .25 L
.85229 .25 L
.8523 .25 L
.85231 .25 L
.85231 .25 L
.85232 .25 L
.85232 .25 L
.85233 .25 L
.85233 .25 L
.85234 .25 L
.85235 .25 L
.85235 .25 L
.85236 .25 L
.85237 .25 L
.85237 .25 L
.85238 .25 L
.85238 .25 L
.85239 .25 L
.8524 .25 L
.8524 .25 L
.85241 .25 L
.85242 .25 L
.85242 .25 L
.85243 .25 L
.85243 .25 L
.85243 .25 L
.85244 .25 L
.85244 .25 L
.85245 .25 L
.85246 .25 L
.85246 .25 L
.85247 .25 L
.85248 .25 L
.85248 .25 L
.85249 .25 L
.85249 .25 L
.8525 .25 L
.85251 .25 L
.85251 .25 L
.85252 .25 L
Mistroke
.85253 .25 L
.85253 .25 L
.85254 .25 L
.85255 .25 L
.85255 .25 L
.85255 .25 L
.85256 .25 L
.85256 .25 L
.85257 .25 L
.85257 .25 L
.85258 .25 L
.85258 .25 L
.85259 .25 L
.85259 .25 L
.85259 .25 L
.8526 .25 L
.8526 .25 L
.85261 .25 L
.85261 .25 L
.85261 .25 L
.85262 .25 L
.85263 .25 L
.85263 .25 L
.85264 .25 L
.85265 .25 L
.85265 .25 L
.85266 .25 L
.85266 .25 L
.85267 .25 L
.85268 .25 L
.85268 .25 L
.85269 .25 L
.8527 .25 L
.8527 .25 L
.85271 .25 L
.85271 .25 L
.85272 .25 L
.85272 .25 L
.85273 .25 L
.85274 .25 L
.85274 .25 L
.85275 .25 L
.85275 .25 L
.85276 .25 L
.85277 .25 L
.85277 .25 L
.85278 .25 L
.85278 .25 L
.85279 .25 L
.8528 .25 L
Mistroke
.8528 .25 L
.85281 .25 L
.85281 .25 L
.85281 .25 L
.85282 .25 L
.85283 .25 L
.85283 .25 L
.85284 .25 L
.85285 .25 L
.85285 .25 L
.85286 .25 L
.85287 .25 L
.85287 .25 L
.85288 .25 L
.85288 .25 L
.85289 .25 L
.8529 .25 L
.8529 .25 L
.85291 .25 L
.85292 .25 L
.85292 .25 L
.85293 .25 L
.85293 .25 L
.85294 .25 L
.85294 .25 L
.85295 .25 L
.85296 .25 L
.85296 .25 L
.85297 .25 L
.85297 .25 L
.85298 .25 L
.85299 .25 L
.85299 .25 L
.853 .25 L
.853 .25 L
.85301 .25 L
.85301 .25 L
.85302 .25 L
.85302 .25 L
.85303 .25 L
.85304 .25 L
.85304 .25 L
.85304 .25 L
.85305 .25 L
.85306 .25 L
.85306 .25 L
.85307 .25 L
.85307 .25 L
.85308 .25 L
.85309 .25 L
Mistroke
.85309 .25 L
.85309 .25 L
.8531 .25 L
.85311 .25 L
.85311 .25 L
.85312 .25 L
.85312 .25 L
.85313 .25 L
.85314 .25 L
.85314 .25 L
.85315 .25 L
.85315 .25 L
.85316 .25 L
.85316 .25 L
.85317 .25 L
.85318 .25 L
.85318 .25 L
.85319 .25 L
.8532 .25 L
.8532 .25 L
.85321 .25 L
.85321 .25 L
.85322 .25 L
.85323 .25 L
.85323 .25 L
.85324 .25 L
.85325 .25 L
.85325 .25 L
.85325 .25 L
.85326 .25 L
.85326 .25 L
.85327 .25 L
.85327 .25 L
.85328 .25 L
.85329 .25 L
.85329 .25 L
.8533 .25 L
.85331 .25 L
.85331 .25 L
.85332 .25 L
.85332 .25 L
.85333 .25 L
.85334 .25 L
.85334 .25 L
.85335 .25 L
.85336 .25 L
.85336 .25 L
.85337 .25 L
.85337 .25 L
.85338 .25 L
Mistroke
.85338 .25 L
.85339 .25 L
.85339 .25 L
.8534 .25 L
.8534 .25 L
.85341 .25 L
.85341 .25 L
.85341 .25 L
.85342 .25 L
.85342 .25 L
.85343 .25 L
.85343 .25 L
.85343 .25 L
.85344 .25 L
.85344 .25 L
.85345 .25 L
.85346 .25 L
.85346 .25 L
.85347 .25 L
.85348 .25 L
.85348 .25 L
.85349 .25 L
.85349 .25 L
.8535 .25 L
.85351 .25 L
.85351 .25 L
.85352 .25 L
.85353 .25 L
.85353 .25 L
.85354 .25 L
.85354 .25 L
.85355 .25 L
.85355 .25 L
.85356 .25 L
.85357 .25 L
.85357 .25 L
.85358 .25 L
.85358 .25 L
.85359 .25 L
.85359 .25 L
.8536 .25 L
.85361 .25 L
.85361 .25 L
.85362 .25 L
.85362 .25 L
.85363 .25 L
.85364 .25 L
.85364 .25 L
.85364 .25 L
.85365 .25 L
Mistroke
.85366 .25 L
.85367 .25 L
.85367 .25 L
.85368 .25 L
.85368 .25 L
.85369 .25 L
.8537 .25 L
.8537 .25 L
.85371 .25 L
.85372 .25 L
.85372 .25 L
.85373 .25 L
.85373 .25 L
.85374 .25 L
.85374 .25 L
.85375 .25 L
.85376 .25 L
.85376 .25 L
.85377 .25 L
.85377 .25 L
.85378 .25 L
.85379 .25 L
.85379 .25 L
.8538 .25 L
.8538 .25 L
.85381 .25 L
.85382 .25 L
.85382 .25 L
.85383 .25 L
.85383 .25 L
.85384 .25 L
.85384 .25 L
.85385 .25 L
.85385 .25 L
.85386 .25 L
.85386 .25 L
.85387 .25 L
.85387 .25 L
.85388 .25 L
.85389 .25 L
.85389 .25 L
.8539 .25 L
.8539 .25 L
.85391 .25 L
.85391 .25 L
.85392 .25 L
.85393 .25 L
.85393 .25 L
.85393 .25 L
.85394 .25 L
Mistroke
.85395 .25 L
.85395 .25 L
.85396 .25 L
.85396 .25 L
.85397 .25 L
.85398 .25 L
.85398 .25 L
.85399 .25 L
.85399 .25 L
.854 .25 L
.85401 .25 L
.85401 .25 L
.85402 .25 L
.85402 .25 L
.85403 .25 L
.85404 .25 L
.85404 .25 L
.85405 .25 L
.85406 .25 L
.85406 .25 L
.85407 .25 L
.85407 .25 L
.85408 .25 L
.85408 .25 L
.85408 .25 L
.85409 .25 L
.8541 .25 L
.8541 .25 L
.85411 .25 L
.85412 .25 L
.85412 .25 L
.85413 .25 L
.85414 .25 L
.85414 .25 L
.85415 .25 L
.85415 .25 L
.85416 .25 L
.85417 .25 L
.85417 .25 L
.85418 .25 L
.85419 .25 L
.85419 .25 L
.8542 .25 L
.8542 .25 L
.85421 .25 L
.85421 .25 L
.85422 .25 L
.85422 .25 L
.85422 .25 L
.85423 .25 L
Mistroke
.85423 .25 L
.85424 .25 L
.85424 .25 L
.85424 .25 L
.85425 .25 L
.85425 .25 L
.85426 .25 L
.85426 .25 L
.85427 .25 L
.85427 .25 L
.85428 .25 L
.85429 .25 L
.85429 .25 L
.8543 .25 L
.85431 .25 L
.85431 .25 L
.85432 .25 L
.85432 .25 L
.85433 .25 L
.85434 .25 L
.85434 .25 L
.85435 .25 L
.85436 .25 L
.85436 .25 L
.85436 .25 L
.85437 .25 L
.85438 .25 L
.85438 .25 L
.85439 .25 L
.8544 .25 L
.8544 .25 L
.85441 .25 L
.85441 .25 L
.85442 .25 L
.85442 .25 L
.85443 .25 L
.85444 .25 L
.85444 .25 L
.85445 .25 L
.85445 .25 L
.85446 .25 L
.85446 .25 L
.85447 .25 L
.85447 .25 L
.85448 .25 L
.85449 .25 L
.8545 .25 L
.8545 .25 L
.85451 .25 L
.85451 .25 L
Mistroke
.85452 .25 L
.85453 .25 L
.85453 .25 L
.85454 .25 L
.85454 .25 L
.85455 .25 L
.85456 .25 L
.85456 .25 L
.85457 .25 L
.85457 .25 L
.85458 .25 L
.85459 .25 L
.85459 .25 L
.8546 .25 L
.8546 .25 L
.85461 .25 L
.85461 .25 L
.85462 .25 L
.85463 .25 L
.85463 .25 L
.85464 .25 L
.85465 .25 L
.85465 .25 L
.85466 .25 L
.85466 .25 L
.85466 .25 L
.85467 .25 L
.85468 .25 L
.85468 .25 L
.85469 .25 L
.8547 .25 L
.8547 .25 L
.85471 .25 L
.85472 .25 L
.85472 .25 L
.85473 .25 L
.85473 .25 L
.85474 .25 L
.85475 .25 L
.85475 .25 L
.85476 .25 L
.85476 .25 L
.85477 .25 L
.85478 .25 L
.85478 .25 L
.85479 .25 L
.85479 .25 L
.8548 .25 L
.85481 .25 L
.85481 .25 L
Mistroke
.85482 .25 L
.85482 .25 L
.85483 .25 L
.85484 .25 L
.85484 .25 L
.85485 .25 L
.85485 .25 L
.85486 .25 L
.85486 .25 L
.85487 .25 L
.85487 .25 L
.85488 .25 L
.85489 .25 L
.85489 .25 L
.85489 .25 L
.8549 .25 L
.85491 .25 L
.85491 .25 L
.85492 .25 L
.85492 .25 L
.85493 .25 L
.85494 .25 L
.85494 .25 L
.85494 .25 L
.85495 .25 L
.85496 .25 L
.85496 .25 L
.85497 .25 L
.85497 .25 L
.85498 .25 L
.85498 .25 L
.85499 .25 L
.855 .25 L
.855 .25 L
.85501 .25 L
.85501 .25 L
.85502 .25 L
.85503 .25 L
.85503 .25 L
.85504 .25 L
.85505 .25 L
.85505 .25 L
.85506 .25 L
.85506 .25 L
.85507 .25 L
.85508 .25 L
.85508 .25 L
.85509 .25 L
.8551 .25 L
.8551 .25 L
Mistroke
.8551 .25 L
.85511 .25 L
.85511 .25 L
.85512 .25 L
.85512 .25 L
.85513 .25 L
.85514 .25 L
.85514 .25 L
.85515 .25 L
.85516 .25 L
.85516 .25 L
.85517 .25 L
.85517 .25 L
.85518 .25 L
.85519 .25 L
.85519 .25 L
.8552 .25 L
.85521 .25 L
.85521 .25 L
.85522 .25 L
.85522 .25 L
.85523 .25 L
.85523 .25 L
.85524 .25 L
.85524 .25 L
.85525 .25 L
.85525 .25 L
.85526 .25 L
.85526 .25 L
.85526 .25 L
.85527 .25 L
.85527 .25 L
.85527 .25 L
.85528 .25 L
.85528 .25 L
.85529 .25 L
.85529 .25 L
.8553 .25 L
.85531 .25 L
.85531 .25 L
.85532 .25 L
.85533 .25 L
.85533 .25 L
.85534 .25 L
.85534 .25 L
.85535 .25 L
.85536 .25 L
.85536 .25 L
.85537 .25 L
.85538 .25 L
Mistroke
.85538 .25 L
.85539 .25 L
.85539 .25 L
.8554 .25 L
.8554 .25 L
.85541 .25 L
.85542 .25 L
.85542 .25 L
.85543 .25 L
.85543 .25 L
.85544 .25 L
.85544 .25 L
.85545 .25 L
.85546 .25 L
.85546 .25 L
.85547 .25 L
.85547 .25 L
.85548 .25 L
.85549 .25 L
.85549 .25 L
.85549 .25 L
.8555 .25 L
.85551 .25 L
.85552 .25 L
.85552 .25 L
.85553 .25 L
.85553 .25 L
.85554 .25 L
.85555 .25 L
.85555 .25 L
.85556 .25 L
.85557 .25 L
.85557 .25 L
.85558 .25 L
.85559 .25 L
.85559 .25 L
.85559 .25 L
.8556 .25 L
.85561 .25 L
.85561 .25 L
.85562 .25 L
.85562 .25 L
.85563 .25 L
.85564 .25 L
.85564 .25 L
.85565 .25 L
.85565 .25 L
.85566 .25 L
.85567 .25 L
.85567 .25 L
Mistroke
.85568 .25 L
.85568 .25 L
.85569 .25 L
.85569 .25 L
.8557 .25 L
.8557 .25 L
.85571 .25 L
.85571 .25 L
.85572 .25 L
.85572 .25 L
.85573 .25 L
.85574 .25 L
.85574 .25 L
.85575 .25 L
.85575 .25 L
.85576 .25 L
.85577 .25 L
.85577 .25 L
.85578 .25 L
.85578 .25 L
.85578 .25 L
.85579 .25 L
.8558 .25 L
.8558 .25 L
.85581 .25 L
.85581 .25 L
.85582 .25 L
.85583 .25 L
.85583 .25 L
.85584 .25 L
.85584 .25 L
.85585 .25 L
.85586 .25 L
.85586 .25 L
.85587 .25 L
.85587 .25 L
.85588 .25 L
.85589 .25 L
.85589 .25 L
.8559 .25 L
.85591 .25 L
.85591 .25 L
.85592 .25 L
.85592 .25 L
.85593 .25 L
.85593 .25 L
.85594 .25 L
.85594 .25 L
.85595 .25 L
.85595 .25 L
Mistroke
.85596 .25 L
.85597 .25 L
.85597 .25 L
.85598 .25 L
.85599 .25 L
.85599 .25 L
.856 .25 L
.85601 .25 L
.85601 .25 L
.85602 .25 L
.85602 .25 L
.85603 .25 L
.85604 .25 L
.85604 .25 L
.85605 .25 L
.85605 .25 L
.85606 .25 L
.85606 .25 L
.85607 .25 L
.85607 .25 L
.85607 .25 L
.85608 .25 L
.85608 .25 L
.85609 .25 L
.85609 .25 L
.8561 .25 L
.8561 .25 L
.8561 .25 L
.85611 .25 L
.85611 .25 L
.85612 .25 L
.85612 .25 L
.85613 .25 L
.85614 .25 L
.85614 .25 L
.85615 .25 L
.85616 .25 L
.85616 .25 L
.85617 .25 L
.85617 .25 L
.85618 .25 L
.85619 .25 L
.85619 .25 L
.8562 .25 L
.85621 .25 L
.85621 .25 L
.85621 .25 L
.85622 .25 L
.85623 .25 L
.85623 .25 L
Mistroke
.85624 .25 L
.85625 .25 L
.85625 .25 L
.85626 .25 L
.85626 .25 L
.85627 .25 L
.85627 .25 L
.85628 .25 L
.85629 .25 L
.85629 .25 L
.8563 .25 L
.85631 .25 L
.85631 .25 L
.85631 .25 L
.85632 .25 L
.85633 .25 L
.85633 .25 L
.85634 .25 L
.85635 .25 L
.85635 .25 L
.85636 .25 L
.85636 .25 L
.85637 .25 L
.85638 .25 L
.85638 .25 L
.85639 .25 L
.8564 .25 L
.8564 .25 L
.85641 .25 L
.85641 .25 L
.85642 .25 L
.85642 .25 L
.85643 .25 L
.85644 .25 L
.85644 .25 L
.85645 .25 L
.85645 .25 L
.85646 .25 L
.85647 .25 L
.85647 .25 L
.85648 .25 L
.85648 .25 L
.85649 .25 L
.8565 .25 L
.8565 .25 L
.85651 .25 L
.85651 .25 L
.85652 .25 L
.85652 .25 L
.85653 .25 L
Mistroke
.85653 .25 L
.85654 .25 L
.85654 .25 L
.85655 .25 L
.85655 .25 L
.85656 .25 L
.85657 .25 L
.85657 .25 L
.85658 .25 L
.85659 .25 L
.85659 .25 L
.85659 .25 L
.8566 .25 L
.8566 .25 L
.85661 .25 L
.85661 .25 L
.85662 .25 L
.85663 .25 L
.85663 .25 L
.85664 .25 L
.85664 .25 L
.85665 .25 L
.85666 .25 L
.85666 .25 L
.85667 .25 L
.85667 .25 L
.85668 .25 L
.85669 .25 L
.85669 .25 L
.8567 .25 L
.8567 .25 L
.85671 .25 L
.85672 .25 L
.85672 .25 L
.85673 .25 L
.85674 .25 L
.85674 .25 L
.85675 .25 L
.85675 .25 L
.85676 .25 L
.85676 .25 L
.85677 .25 L
.85677 .25 L
.85678 .25 L
.85679 .25 L
.85679 .25 L
.8568 .25 L
.8568 .25 L
.85681 .25 L
.85682 .25 L
Mistroke
.85682 .25 L
.85683 .25 L
.85684 .25 L
.85684 .25 L
.85685 .25 L
.85686 .25 L
.85686 .25 L
.85687 .25 L
.85687 .25 L
.85688 .25 L
.85688 .25 L
.85689 .25 L
.85689 .25 L
.85689 .25 L
.8569 .25 L
.8569 .25 L
.85691 .25 L
.85691 .25 L
.85692 .25 L
.85692 .25 L
.85692 .25 L
.85693 .25 L
.85693 .25 L
.85693 .25 L
.85694 .25 L
.85695 .25 L
.85695 .25 L
.85696 .25 L
.85697 .25 L
.85697 .25 L
.85698 .25 L
.85698 .25 L
.85699 .25 L
.857 .25 L
.857 .25 L
.85701 .25 L
.85702 .25 L
.85702 .25 L
.85703 .25 L
.85703 .25 L
.85704 .25 L
.85704 .25 L
.85705 .25 L
.85706 .25 L
.85706 .25 L
.85707 .25 L
.85708 .25 L
.85708 .25 L
.85709 .25 L
.85709 .25 L
Mistroke
.8571 .25 L
.8571 .25 L
.85711 .25 L
.85712 .25 L
.85712 .25 L
.85713 .25 L
.85713 .25 L
.85714 .25 L
.85714 .25 L
.85715 .25 L
.85716 .25 L
.85716 .25 L
.85717 .25 L
.85718 .25 L
.85718 .25 L
.85719 .25 L
.85719 .25 L
.8572 .25 L
.85721 .25 L
.85721 .25 L
.85722 .25 L
.85723 .25 L
.85723 .25 L
.85724 .25 L
.85724 .25 L
.85725 .25 L
.85725 .25 L
.85726 .25 L
.85727 .25 L
.85727 .25 L
.85728 .25 L
.85728 .25 L
.85729 .25 L
.85729 .25 L
.8573 .25 L
.85731 .25 L
.85731 .25 L
.85732 .25 L
.85733 .25 L
.85733 .25 L
.85734 .25 L
.85734 .25 L
.85735 .25 L
.85735 .25 L
.85736 .25 L
.85736 .25 L
.85737 .25 L
.85737 .25 L
.85738 .25 L
.85738 .25 L
Mistroke
.85739 .25 L
.8574 .25 L
.8574 .25 L
.85741 .25 L
.85741 .25 L
.85742 .25 L
.85742 .25 L
.85743 .25 L
.85743 .25 L
.85744 .25 L
.85744 .25 L
.85745 .25 L
.85746 .25 L
.85746 .25 L
.85747 .25 L
.85747 .25 L
.85748 .25 L
.85749 .25 L
.85749 .25 L
.8575 .25 L
.8575 .25 L
.85751 .25 L
.85752 .25 L
.85752 .25 L
.85753 .25 L
.85754 .25 L
.85754 .25 L
.85755 .25 L
.85755 .25 L
.85756 .25 L
.85757 .25 L
.85757 .25 L
.85757 .25 L
.85758 .25 L
.85758 .25 L
.85759 .25 L
.8576 .25 L
.8576 .25 L
.85761 .25 L
.85761 .25 L
.85762 .25 L
.85763 .25 L
.85763 .25 L
.85764 .25 L
.85765 .25 L
.85765 .25 L
.85766 .25 L
.85767 .25 L
.85767 .25 L
.85768 .25 L
Mistroke
.85768 .25 L
.85769 .25 L
.8577 .25 L
.8577 .25 L
.85771 .25 L
.85771 .25 L
.85771 .25 L
.85772 .25 L
.85772 .25 L
.85773 .25 L
.85773 .25 L
.85773 .25 L
.85774 .25 L
.85774 .25 L
.85775 .25 L
.85775 .25 L
.85775 .25 L
.85776 .25 L
.85776 .25 L
.85777 .25 L
.85778 .25 L
.85778 .25 L
.85779 .25 L
.8578 .25 L
.8578 .25 L
.85781 .25 L
.85781 .25 L
.85782 .25 L
.85783 .25 L
.85783 .25 L
.85784 .25 L
.85785 .25 L
.85785 .25 L
.85786 .25 L
.85786 .25 L
.85787 .25 L
.85787 .25 L
.85788 .25 L
.85789 .25 L
.85789 .25 L
.8579 .25 L
.8579 .25 L
.85791 .25 L
.85792 .25 L
.85792 .25 L
.85793 .25 L
.85793 .25 L
.85794 .25 L
.85795 .25 L
.85795 .25 L
Mistroke
.85796 .25 L
.85796 .25 L
.85797 .25 L
.85797 .25 L
.85798 .25 L
.85799 .25 L
.85799 .25 L
.858 .25 L
.85801 .25 L
.85801 .25 L
.85802 .25 L
.85802 .25 L
.85803 .25 L
.85804 .25 L
.85804 .25 L
.85805 .25 L
.85806 .25 L
.85806 .25 L
.85806 .25 L
.85807 .25 L
.85808 .25 L
.85808 .25 L
.85809 .25 L
.8581 .25 L
.8581 .25 L
.85811 .25 L
.85811 .25 L
.85812 .25 L
.85812 .25 L
.85813 .25 L
.85814 .25 L
.85814 .25 L
.85815 .25 L
.85816 .25 L
.85816 .25 L
.85816 .25 L
.85817 .25 L
.85818 .25 L
.85818 .25 L
.85819 .25 L
.8582 .25 L
.8582 .25 L
.85821 .25 L
.85821 .25 L
.85822 .25 L
.85823 .25 L
.85823 .25 L
.85824 .25 L
.85825 .25 L
.85825 .25 L
Mistroke
.85826 .25 L
.85826 .25 L
.85827 .25 L
.85827 .25 L
.85828 .25 L
.85829 .25 L
.85829 .25 L
.8583 .25 L
.8583 .25 L
.85831 .25 L
.85832 .25 L
.85832 .25 L
.85833 .25 L
.85833 .25 L
.85834 .25 L
.85835 .25 L
.85835 .25 L
.85836 .25 L
.85836 .25 L
.85836 .25 L
.85837 .25 L
.85838 .25 L
.85838 .25 L
.85839 .25 L
.85839 .25 L
.8584 .25 L
.8584 .25 L
.85841 .25 L
.85842 .25 L
.85842 .25 L
.85843 .25 L
.85844 .25 L
.85844 .25 L
.85844 .25 L
.85845 .25 L
.85845 .25 L
.85846 .25 L
.85846 .25 L
.85847 .25 L
.85848 .25 L
.85848 .25 L
.85849 .25 L
.85849 .25 L
.8585 .25 L
.85851 .25 L
.85851 .25 L
.85852 .25 L
.85852 .25 L
.85853 .25 L
.85854 .25 L
Mistroke
.85854 .25 L
.85855 .25 L
.85855 .25 L
.85856 .25 L
.85857 .25 L
.85857 .25 L
.85858 .25 L
.85859 .25 L
.85859 .25 L
.8586 .25 L
.8586 .25 L
.85861 .25 L
.85861 .25 L
.85862 .25 L
.85862 .25 L
.85863 .25 L
.85864 .25 L
.85864 .25 L
.85865 .25 L
.85865 .25 L
.85866 .25 L
.85867 .25 L
.85867 .25 L
.85868 .25 L
.85869 .25 L
.85869 .25 L
.8587 .25 L
.85871 .25 L
.85871 .25 L
.85872 .25 L
.85872 .25 L
.85873 .25 L
.85873 .25 L
.85874 .25 L
.85874 .25 L
.85874 .25 L
.85875 .25 L
.85875 .25 L
.85876 .25 L
.85876 .25 L
.85877 .25 L
.85877 .25 L
.85877 .25 L
.85878 .25 L
.85878 .25 L
.85878 .25 L
.85879 .25 L
.8588 .25 L
.8588 .25 L
.85881 .25 L
Mistroke
.85882 .25 L
.85882 .25 L
.85883 .25 L
.85883 .25 L
.85884 .25 L
.85885 .25 L
.85885 .25 L
.85886 .25 L
.85887 .25 L
.85887 .25 L
.85888 .25 L
.85888 .25 L
.85889 .25 L
.85889 .25 L
.8589 .25 L
.85891 .25 L
.85891 .25 L
.85892 .25 L
.85893 .25 L
.85893 .25 L
.85894 .25 L
.85894 .25 L
.85895 .25 L
.85895 .25 L
.85896 .25 L
.85897 .25 L
.85897 .25 L
.85898 .25 L
.85898 .25 L
.85899 .25 L
.85899 .25 L
.859 .25 L
.85901 .25 L
.85901 .25 L
.85902 .25 L
.85903 .25 L
.85903 .25 L
.85904 .25 L
.85904 .25 L
.85905 .25 L
.85906 .25 L
.85906 .25 L
.85907 .25 L
.85908 .25 L
.85908 .25 L
.85909 .25 L
.85909 .25 L
.8591 .25 L
.8591 .25 L
.85911 .25 L
Mistroke
.85912 .25 L
.85912 .25 L
.85913 .25 L
.85913 .25 L
.85914 .25 L
.85915 .25 L
.85915 .25 L
.85916 .25 L
.85916 .25 L
.85917 .25 L
.85918 .25 L
.85918 .25 L
.85919 .25 L
.85919 .25 L
.8592 .25 L
.8592 .25 L
.85921 .25 L
.85921 .25 L
.85922 .25 L
.85922 .25 L
.85923 .25 L
.85923 .25 L
.85924 .25 L
.85925 .25 L
.85925 .25 L
.85926 .25 L
.85926 .25 L
.85927 .25 L
.85927 .25 L
.85928 .25 L
.85928 .25 L
.85929 .25 L
.85929 .25 L
.8593 .25 L
.85931 .25 L
.85931 .25 L
.85932 .25 L
.85932 .25 L
.85933 .25 L
.85934 .25 L
.85934 .25 L
.85935 .25 L
.85935 .25 L
.85936 .25 L
.85937 .25 L
.85937 .25 L
.85938 .25 L
.85939 .25 L
.85939 .25 L
.8594 .25 L
Mistroke
.8594 .25 L
.85941 .25 L
.85942 .25 L
.85942 .25 L
.85943 .25 L
.85943 .25 L
.85943 .25 L
.85944 .25 L
.85945 .25 L
.85945 .25 L
.85946 .25 L
.85947 .25 L
.85947 .25 L
.85948 .25 L
.85948 .25 L
.85949 .25 L
.8595 .25 L
.8595 .25 L
.85951 .25 L
.85952 .25 L
.85952 .25 L
.85953 .25 L
.85954 .25 L
.85954 .25 L
.85955 .25 L
.85955 .25 L
.85956 .25 L
.85956 .25 L
.85956 .25 L
.85957 .25 L
.85957 .25 L
.85958 .25 L
.85958 .25 L
.85959 .25 L
.85959 .25 L
.85959 .25 L
.8596 .25 L
.8596 .25 L
.8596 .25 L
.85961 .25 L
.85961 .25 L
.85962 .25 L
.85963 .25 L
.85963 .25 L
.85964 .25 L
.85965 .25 L
.85965 .25 L
.85966 .25 L
.85967 .25 L
.85967 .25 L
Mistroke
.85968 .25 L
.85969 .25 L
.85969 .25 L
.8597 .25 L
.8597 .25 L
.85971 .25 L
.85971 .25 L
.85972 .25 L
.85973 .25 L
.85973 .25 L
.85974 .25 L
.85974 .25 L
.85975 .25 L
.85976 .25 L
.85976 .25 L
.85977 .25 L
.85977 .25 L
.85978 .25 L
.85979 .25 L
.85979 .25 L
.8598 .25 L
.8598 .25 L
.85981 .25 L
.85981 .25 L
.85982 .25 L
.85982 .25 L
.85983 .25 L
.85984 .25 L
.85984 .25 L
.85985 .25 L
.85986 .25 L
.85986 .25 L
.85987 .25 L
.85987 .25 L
.85988 .25 L
.85989 .25 L
.85989 .25 L
.8599 .25 L
.85991 .25 L
.85991 .25 L
.85991 .25 L
.85992 .25 L
.85993 .25 L
.85993 .25 L
.85994 .25 L
.85995 .25 L
.85995 .25 L
.85996 .25 L
.85996 .25 L
.85997 .25 L
Mistroke
.85997 .25 L
.85998 .25 L
.85999 .25 L
.85999 .25 L
.86 .25 L
.86001 .25 L
.86001 .25 L
.86001 .25 L
.86002 .25 L
.86003 .25 L
.86003 .25 L
.86004 .25 L
.86004 .25 L
.86005 .25 L
.86005 .25 L
.86006 .25 L
.86006 .25 L
.86007 .25 L
.86008 .25 L
.86008 .25 L
.86009 .25 L
.86009 .25 L
.8601 .25 L
.8601 .25 L
.8601 .25 L
.86011 .25 L
.86012 .25 L
.86012 .25 L
.86013 .25 L
.86014 .25 L
.86014 .25 L
.86015 .25 L
.86015 .25 L
.86016 .25 L
.86017 .25 L
.86017 .25 L
.86018 .25 L
.86018 .25 L
.86019 .25 L
.8602 .25 L
.8602 .25 L
.86021 .25 L
.86022 .25 L
.86022 .25 L
.86023 .25 L
.86024 .25 L
.86024 .25 L
.86025 .25 L
.86025 .25 L
.86025 .25 L
Mistroke
.86026 .25 L
.86026 .25 L
.86027 .25 L
.86028 .25 L
.86028 .25 L
.86029 .25 L
.8603 .25 L
.8603 .25 L
.86031 .25 L
.86031 .25 L
.86032 .25 L
.86033 .25 L
.86033 .25 L
.86034 .25 L
.86035 .25 L
.86035 .25 L
.86036 .25 L
.86037 .25 L
.86037 .25 L
.86037 .25 L
.86038 .25 L
.86038 .25 L
.86039 .25 L
.86039 .25 L
.86039 .25 L
.8604 .25 L
.86041 .25 L
.86041 .25 L
.86041 .25 L
.86042 .25 L
.86042 .25 L
.86042 .25 L
.86043 .25 L
.86043 .25 L
.86044 .25 L
.86044 .25 L
.86045 .25 L
.86046 .25 L
.86047 .25 L
.86047 .25 L
.86048 .25 L
.86048 .25 L
.86049 .25 L
.8605 .25 L
.8605 .25 L
.86051 .25 L
.86051 .25 L
.86052 .25 L
.86053 .25 L
.86053 .25 L
Mistroke
.86054 .25 L
.86054 .25 L
.86055 .25 L
.86056 .25 L
.86056 .25 L
.86057 .25 L
.86057 .25 L
.86058 .25 L
.86058 .25 L
.86059 .25 L
.8606 .25 L
.8606 .25 L
.86061 .25 L
.86061 .25 L
.86062 .25 L
.86063 .25 L
.86063 .25 L
.86063 .25 L
.86064 .25 L
.86065 .25 L
.86065 .25 L
.86066 .25 L
.86067 .25 L
.86067 .25 L
.86068 .25 L
.86069 .25 L
.86069 .25 L
.8607 .25 L
.8607 .25 L
.86071 .25 L
.86072 .25 L
.86072 .25 L
.86073 .25 L
.86073 .25 L
.86074 .25 L
.86075 .25 L
.86075 .25 L
.86076 .25 L
.86076 .25 L
.86077 .25 L
.86078 .25 L
.86078 .25 L
.86079 .25 L
.86079 .25 L
.8608 .25 L
.8608 .25 L
.86081 .25 L
.86082 .25 L
.86082 .25 L
.86083 .25 L
Mistroke
.86083 .25 L
.86084 .25 L
.86084 .25 L
.86085 .25 L
.86086 .25 L
.86086 .25 L
.86086 .25 L
.86087 .25 L
.86088 .25 L
.86088 .25 L
.86089 .25 L
.86089 .25 L
.8609 .25 L
.86091 .25 L
.86091 .25 L
.86091 .25 L
.86092 .25 L
.86092 .25 L
.86093 .25 L
.86093 .25 L
.86094 .25 L
.86095 .25 L
.86095 .25 L
.86096 .25 L
.86097 .25 L
.86097 .25 L
.86098 .25 L
.86098 .25 L
.86099 .25 L
.861 .25 L
.861 .25 L
.86101 .25 L
.86101 .25 L
.86102 .25 L
.86103 .25 L
.86103 .25 L
.86104 .25 L
.86105 .25 L
.86105 .25 L
.86106 .25 L
.86107 .25 L
.86107 .25 L
.86107 .25 L
.86108 .25 L
.86108 .25 L
.86109 .25 L
.86109 .25 L
.8611 .25 L
.86111 .25 L
.86111 .25 L
Mistroke
.86112 .25 L
.86113 .25 L
.86113 .25 L
.86114 .25 L
.86114 .25 L
.86115 .25 L
.86116 .25 L
.86116 .25 L
.86117 .25 L
.86118 .25 L
.86118 .25 L
.86119 .25 L
.86119 .25 L
.8612 .25 L
.8612 .25 L
.86121 .25 L
.86121 .25 L
.86121 .25 L
.86122 .25 L
.86123 .25 L
.86123 .25 L
.86123 .25 L
.86124 .25 L
.86124 .25 L
.86124 .25 L
.86125 .25 L
.86125 .25 L
.86126 .25 L
.86126 .25 L
.86127 .25 L
.86128 .25 L
.86128 .25 L
.86129 .25 L
.86129 .25 L
.8613 .25 L
.86131 .25 L
.86131 .25 L
.86132 .25 L
.86133 .25 L
.86133 .25 L
.86134 .25 L
.86134 .25 L
.86135 .25 L
.86136 .25 L
.86136 .25 L
.86137 .25 L
.86137 .25 L
.86138 .25 L
.86138 .25 L
.86139 .25 L
Mistroke
.8614 .25 L
.8614 .25 L
.86141 .25 L
.86141 .25 L
.86142 .25 L
.86143 .25 L
.86143 .25 L
.86144 .25 L
.86144 .25 L
.86145 .25 L
.86145 .25 L
.86146 .25 L
.86146 .25 L
.86147 .25 L
.86148 .25 L
.86148 .25 L
.86149 .25 L
.8615 .25 L
.8615 .25 L
.86151 .25 L
.86152 .25 L
.86152 .25 L
.86153 .25 L
.86153 .25 L
.86154 .25 L
.86155 .25 L
.86155 .25 L
.86156 .25 L
.86156 .25 L
.86157 .25 L
.86158 .25 L
.86158 .25 L
.86159 .25 L
.86159 .25 L
.8616 .25 L
.86161 .25 L
.86161 .25 L
.86162 .25 L
.86162 .25 L
.86163 .25 L
.86163 .25 L
.86164 .25 L
.86165 .25 L
.86165 .25 L
.86166 .25 L
.86166 .25 L
.86167 .25 L
.86167 .25 L
.86168 .25 L
.86168 .25 L
Mistroke
.86169 .25 L
.86169 .25 L
.8617 .25 L
.86171 .25 L
.86171 .25 L
.86172 .25 L
.86172 .25 L
.86173 .25 L
.86173 .25 L
.86174 .25 L
.86174 .25 L
.86175 .25 L
.86175 .25 L
.86176 .25 L
.86177 .25 L
.86177 .25 L
.86178 .25 L
.86178 .25 L
.86179 .25 L
.8618 .25 L
.8618 .25 L
.86181 .25 L
.86181 .25 L
.86182 .25 L
.86183 .25 L
.86183 .25 L
.86184 .25 L
.86184 .25 L
.86185 .25 L
.86186 .25 L
.86186 .25 L
.86187 .25 L
.86188 .25 L
.86188 .25 L
.86189 .25 L
.86189 .25 L
.8619 .25 L
.8619 .25 L
.8619 .25 L
.86191 .25 L
.86192 .25 L
.86192 .25 L
.86193 .25 L
.86194 .25 L
.86194 .25 L
.86195 .25 L
.86195 .25 L
.86196 .25 L
.86197 .25 L
.86197 .25 L
Mistroke
.86198 .25 L
.86199 .25 L
.86199 .25 L
.862 .25 L
.86201 .25 L
.86201 .25 L
.86202 .25 L
.86202 .25 L
.86203 .25 L
.86203 .25 L
.86203 .25 L
.86204 .25 L
.86204 .25 L
.86205 .25 L
.86205 .25 L
.86206 .25 L
.86206 .25 L
.86206 .25 L
.86207 .25 L
.86207 .25 L
.86208 .25 L
.86208 .25 L
.86209 .25 L
.86209 .25 L
.8621 .25 L
.86211 .25 L
.86211 .25 L
.86212 .25 L
.86212 .25 L
.86213 .25 L
.86214 .25 L
.86214 .25 L
.86215 .25 L
.86216 .25 L
.86216 .25 L
.86217 .25 L
.86218 .25 L
.86218 .25 L
.86218 .25 L
.86219 .25 L
.8622 .25 L
.8622 .25 L
.86221 .25 L
.86221 .25 L
.86222 .25 L
.86223 .25 L
.86223 .25 L
.86224 .25 L
.86224 .25 L
.86225 .25 L
Mistroke
.86226 .25 L
.86226 .25 L
.86227 .25 L
.86227 .25 L
.86228 .25 L
.86228 .25 L
.86229 .25 L
.86229 .25 L
.8623 .25 L
.86231 .25 L
.86231 .25 L
.86232 .25 L
.86233 .25 L
.86233 .25 L
.86234 .25 L
.86234 .25 L
.86235 .25 L
.86236 .25 L
.86236 .25 L
.86237 .25 L
.86238 .25 L
.86238 .25 L
.86238 .25 L
.86239 .25 L
.8624 .25 L
.8624 .25 L
.86241 .25 L
.86242 .25 L
.86242 .25 L
.86243 .25 L
.86243 .25 L
.86244 .25 L
.86245 .25 L
.86245 .25 L
.86246 .25 L
.86246 .25 L
.86247 .25 L
.86248 .25 L
.86248 .25 L
.86248 .25 L
.86249 .25 L
.8625 .25 L
.8625 .25 L
.86251 .25 L
.86252 .25 L
.86252 .25 L
.86253 .25 L
.86253 .25 L
.86254 .25 L
.86255 .25 L
Mistroke
.86255 .25 L
.86256 .25 L
.86257 .25 L
.86257 .25 L
.86258 .25 L
.86258 .25 L
.86259 .25 L
.86259 .25 L
.8626 .25 L
.86261 .25 L
.86261 .25 L
.86262 .25 L
.86263 .25 L
.86263 .25 L
.86264 .25 L
.86264 .25 L
.86265 .25 L
.86265 .25 L
.86266 .25 L
.86267 .25 L
.86267 .25 L
.86268 .25 L
.86268 .25 L
.86269 .25 L
.86269 .25 L
.8627 .25 L
.86271 .25 L
.86271 .25 L
.86271 .25 L
.86272 .25 L
.86273 .25 L
.86273 .25 L
.86274 .25 L
.86274 .25 L
.86275 .25 L
.86276 .25 L
.86276 .25 L
.86276 .25 L
.86277 .25 L
.86277 .25 L
.86278 .25 L
.86278 .25 L
.86279 .25 L
.8628 .25 L
.8628 .25 L
.86281 .25 L
.86282 .25 L
.86282 .25 L
.86283 .25 L
.86283 .25 L
Mistroke
.86284 .25 L
.86285 .25 L
.86285 .25 L
.86286 .25 L
.86286 .25 L
.86287 .25 L
.86288 .25 L
.86288 .25 L
.86289 .25 L
.8629 .25 L
.8629 .25 L
.86291 .25 L
.86292 .25 L
.86292 .25 L
.86292 .25 L
.86293 .25 L
.86293 .25 L
.86294 .25 L
.86294 .25 L
.86295 .25 L
.86296 .25 L
.86296 .25 L
.86297 .25 L
.86297 .25 L
.86298 .25 L
.86299 .25 L
.86299 .25 L
.863 .25 L
.86301 .25 L
.86301 .25 L
.86302 .25 L
.86303 .25 L
.86303 .25 L
.86304 .25 L
.86304 .25 L
.86305 .25 L
.86305 .25 L
.86306 .25 L
.86306 .25 L
.86306 .25 L
.86307 .25 L
.86307 .25 L
.86308 .25 L
.86308 .25 L
.86309 .25 L
.86309 .25 L
.86309 .25 L
.8631 .25 L
.8631 .25 L
.8631 .25 L
Mistroke
.86311 .25 L
.86312 .25 L
.86312 .25 L
.86313 .25 L
.86314 .25 L
.86314 .25 L
.86315 .25 L
.86316 .25 L
.86316 .25 L
.86317 .25 L
.86318 .25 L
.86318 .25 L
.86319 .25 L
.86319 .25 L
.8632 .25 L
.86321 .25 L
.86321 .25 L
.86322 .25 L
.86322 .25 L
.86323 .25 L
.86323 .25 L
.86324 .25 L
.86325 .25 L
.86325 .25 L
.86326 .25 L
.86326 .25 L
.86327 .25 L
.86328 .25 L
.86328 .25 L
.86329 .25 L
.86329 .25 L
.8633 .25 L
.8633 .25 L
.86331 .25 L
.86331 .25 L
.86332 .25 L
.86333 .25 L
.86333 .25 L
.86334 .25 L
.86335 .25 L
.86335 .25 L
.86336 .25 L
.86336 .25 L
.86337 .25 L
.86338 .25 L
.86338 .25 L
.86339 .25 L
.8634 .25 L
.8634 .25 L
.86341 .25 L
Mistroke
.86341 .25 L
.86342 .25 L
.86343 .25 L
.86343 .25 L
.86344 .25 L
.86344 .25 L
.86345 .25 L
.86346 .25 L
.86346 .25 L
.86347 .25 L
.86347 .25 L
.86348 .25 L
.86348 .25 L
.86349 .25 L
.8635 .25 L
.8635 .25 L
.86351 .25 L
.86351 .25 L
.86352 .25 L
.86352 .25 L
.86353 .25 L
.86353 .25 L
.86354 .25 L
.86354 .25 L
.86355 .25 L
.86356 .25 L
.86356 .25 L
.86357 .25 L
.86357 .25 L
.86358 .25 L
.86358 .25 L
.86359 .25 L
.86359 .25 L
.8636 .25 L
.8636 .25 L
.86361 .25 L
.86362 .25 L
.86362 .25 L
.86363 .25 L
.86363 .25 L
.86364 .25 L
.86365 .25 L
.86365 .25 L
.86366 .25 L
.86366 .25 L
.86367 .25 L
.86368 .25 L
.86368 .25 L
.86369 .25 L
.86369 .25 L
Mistroke
.8637 .25 L
.86371 .25 L
.86371 .25 L
.86372 .25 L
.86373 .25 L
.86373 .25 L
.86374 .25 L
.86374 .25 L
.86375 .25 L
.86375 .25 L
.86375 .25 L
.86376 .25 L
.86377 .25 L
.86377 .25 L
.86378 .25 L
.86379 .25 L
.86379 .25 L
.8638 .25 L
.8638 .25 L
.86381 .25 L
.86382 .25 L
.86382 .25 L
.86383 .25 L
.86384 .25 L
.86384 .25 L
.86385 .25 L
.86386 .25 L
.86386 .25 L
.86387 .25 L
.86387 .25 L
.86388 .25 L
.86388 .25 L
.86388 .25 L
.86389 .25 L
.86389 .25 L
.8639 .25 L
.8639 .25 L
.86391 .25 L
.86391 .25 L
.86391 .25 L
.86392 .25 L
.86392 .25 L
.86393 .25 L
.86393 .25 L
.86394 .25 L
.86394 .25 L
.86395 .25 L
.86396 .25 L
.86396 .25 L
.86397 .25 L
Mistroke
.86397 .25 L
.86398 .25 L
.86399 .25 L
.86399 .25 L
.864 .25 L
.86401 .25 L
.86401 .25 L
.86402 .25 L
.86403 .25 L
.86403 .25 L
.86403 .25 L
.86404 .25 L
.86405 .25 L
.86405 .25 L
.86406 .25 L
.86406 .25 L
.86407 .25 L
.86408 .25 L
.86408 .25 L
.86409 .25 L
.86409 .25 L
.8641 .25 L
.86411 .25 L
.86411 .25 L
.86412 .25 L
.86412 .25 L
.86413 .25 L
.86413 .25 L
.86414 .25 L
.86414 .25 L
.86415 .25 L
.86416 .25 L
.86416 .25 L
.86417 .25 L
.86418 .25 L
.86418 .25 L
.86419 .25 L
.86419 .25 L
.8642 .25 L
.86421 .25 L
.86421 .25 L
.86422 .25 L
.86423 .25 L
.86423 .25 L
.86424 .25 L
.86424 .25 L
.86425 .25 L
.86425 .25 L
.86426 .25 L
.86427 .25 L
Mistroke
.86427 .25 L
.86428 .25 L
.86428 .25 L
.86429 .25 L
.8643 .25 L
.8643 .25 L
.86431 .25 L
.86431 .25 L
.86432 .25 L
.86433 .25 L
.86433 .25 L
.86433 .25 L
.86434 .25 L
.86435 .25 L
.86435 .25 L
.86436 .25 L
.86436 .25 L
.86437 .25 L
.86437 .25 L
.86438 .25 L
.86438 .25 L
.86439 .25 L
.8644 .25 L
.8644 .25 L
.86441 .25 L
.86441 .25 L
.86442 .25 L
.86442 .25 L
.86443 .25 L
.86443 .25 L
.86444 .25 L
.86445 .25 L
.86445 .25 L
.86446 .25 L
.86446 .25 L
.86447 .25 L
.86447 .25 L
.86448 .25 L
.86449 .25 L
.86449 .25 L
.8645 .25 L
.86451 .25 L
.86451 .25 L
.86452 .25 L
.86452 .25 L
.86453 .25 L
.86454 .25 L
.86454 .25 L
.86455 .25 L
.86456 .25 L
Mistroke
.86456 .25 L
.86457 .25 L
.86457 .25 L
.86457 .25 L
.86458 .25 L
.86458 .25 L
.86459 .25 L
.8646 .25 L
.8646 .25 L
.86461 .25 L
.86462 .25 L
.86462 .25 L
.86463 .25 L
.86463 .25 L
.86464 .25 L
.86465 .25 L
.86465 .25 L
.86466 .25 L
.86467 .25 L
.86467 .25 L
.86468 .25 L
.86469 .25 L
.86469 .25 L
.86469 .25 L
.8647 .25 L
.8647 .25 L
.86471 .25 L
.86471 .25 L
.86472 .25 L
.86472 .25 L
.86473 .25 L
.86473 .25 L
.86473 .25 L
.86474 .25 L
.86474 .25 L
.86475 .25 L
.86475 .25 L
.86475 .25 L
.86476 .25 L
.86477 .25 L
.86477 .25 L
.86478 .25 L
.86479 .25 L
.86479 .25 L
.8648 .25 L
.8648 .25 L
.86481 .25 L
.86482 .25 L
.86482 .25 L
.86483 .25 L
Mistroke
.86484 .25 L
.86484 .25 L
.86485 .25 L
.86485 .25 L
.86486 .25 L
.86486 .25 L
.86487 .25 L
.86488 .25 L
.86488 .25 L
.86489 .25 L
.86489 .25 L
.8649 .25 L
.86491 .25 L
.86491 .25 L
.86492 .25 L
.86492 .25 L
.86493 .25 L
.86494 .25 L
.86494 .25 L
.86495 .25 L
.86495 .25 L
.86495 .25 L
.86496 .25 L
.86497 .25 L
.86497 .25 L
.86498 .25 L
.86499 .25 L
.86499 .25 L
.865 .25 L
.86501 .25 L
.86501 .25 L
.86502 .25 L
.86502 .25 L
.86503 .25 L
.86504 .25 L
.86504 .25 L
.86505 .25 L
.86506 .25 L
.86506 .25 L
.86507 .25 L
.86507 .25 L
.86508 .25 L
.86508 .25 L
.86509 .25 L
.8651 .25 L
.8651 .25 L
.86511 .25 L
.86511 .25 L
.86512 .25 L
.86513 .25 L
Mistroke
.86513 .25 L
.86514 .25 L
.86514 .25 L
.86515 .25 L
.86515 .25 L
.86516 .25 L
.86516 .25 L
.86517 .25 L
.86518 .25 L
.86518 .25 L
.86518 .25 L
.86519 .25 L
.8652 .25 L
.8652 .25 L
.86521 .25 L
.86521 .25 L
.86522 .25 L
.86523 .25 L
.86523 .25 L
.86523 .25 L
.86524 .25 L
.86525 .25 L
.86525 .25 L
.86526 .25 L
.86526 .25 L
.86527 .25 L
.86528 .25 L
.86528 .25 L
.86529 .25 L
.86529 .25 L
.8653 .25 L
.8653 .25 L
.86531 .25 L
.86532 .25 L
.86532 .25 L
.86533 .25 L
.86534 .25 L
.86534 .25 L
.86535 .25 L
.86535 .25 L
.86536 .25 L
.86537 .25 L
.86537 .25 L
.86538 .25 L
.86539 .25 L
.86539 .25 L
.86539 .25 L
.8654 .25 L
.8654 .25 L
.86541 .25 L
Mistroke
.86541 .25 L
.86542 .25 L
.86543 .25 L
.86543 .25 L
.86544 .25 L
.86545 .25 L
.86545 .25 L
.86546 .25 L
.86546 .25 L
.86547 .25 L
.86548 .25 L
.86548 .25 L
.86549 .25 L
.8655 .25 L
.8655 .25 L
.86551 .25 L
.86551 .25 L
.86552 .25 L
.86552 .25 L
.86553 .25 L
.86553 .25 L
.86554 .25 L
.86554 .25 L
.86555 .25 L
.86555 .25 L
.86555 .25 L
.86556 .25 L
.86556 .25 L
.86556 .25 L
.86557 .25 L
.86557 .25 L
.86558 .25 L
.86558 .25 L
.86559 .25 L
.8656 .25 L
.8656 .25 L
.86561 .25 L
.86562 .25 L
.86562 .25 L
.86563 .25 L
.86563 .25 L
.86564 .25 L
.86565 .25 L
.86565 .25 L
.86566 .25 L
.86567 .25 L
.86567 .25 L
.86568 .25 L
.86568 .25 L
.86569 .25 L
Mistroke
.86569 .25 L
.8657 .25 L
.86571 .25 L
.86571 .25 L
.86572 .25 L
.86572 .25 L
.86573 .25 L
.86573 .25 L
.86574 .25 L
.86575 .25 L
.86575 .25 L
.86576 .25 L
.86576 .25 L
.86577 .25 L
.86577 .25 L
.86578 .25 L
.86578 .25 L
.86579 .25 L
.8658 .25 L
.8658 .25 L
.86581 .25 L
.86582 .25 L
.86582 .25 L
.86583 .25 L
.86584 .25 L
.86584 .25 L
.86585 .25 L
.86586 .25 L
.86586 .25 L
.86587 .25 L
.86587 .25 L
.86588 .25 L
.86588 .25 L
.86589 .25 L
.8659 .25 L
.8659 .25 L
.86591 .25 L
.86591 .25 L
.86592 .25 L
.86593 .25 L
.86593 .25 L
.86594 .25 L
.86594 .25 L
.86595 .25 L
.86596 .25 L
.86596 .25 L
.86597 .25 L
.86597 .25 L
.86598 .25 L
.86598 .25 L
Mistroke
.86599 .25 L
.86599 .25 L
.866 .25 L
.86601 .25 L
.86601 .25 L
.86602 .25 L
.86603 .25 L
.86603 .25 L
.86604 .25 L
.86604 .25 L
.86605 .25 L
.86606 .25 L
.86606 .25 L
.86607 .25 L
.86608 .25 L
.86608 .25 L
.86608 .25 L
.86609 .25 L
.8661 .25 L
.8661 .25 L
.86611 .25 L
.86612 .25 L
.86612 .25 L
.86613 .25 L
.86613 .25 L
.86614 .25 L
.86615 .25 L
.86615 .25 L
.86616 .25 L
.86616 .25 L
.86617 .25 L
.86618 .25 L
.86618 .25 L
.86618 .25 L
.86619 .25 L
.8662 .25 L
.8662 .25 L
.86621 .25 L
.86621 .25 L
.86622 .25 L
.86622 .25 L
.86623 .25 L
.86623 .25 L
.86624 .25 L
.86625 .25 L
.86625 .25 L
.86626 .25 L
.86626 .25 L
.86627 .25 L
.86627 .25 L
Mistroke
.86628 .25 L
.86628 .25 L
.86629 .25 L
.8663 .25 L
.8663 .25 L
.86631 .25 L
.86631 .25 L
.86632 .25 L
.86632 .25 L
.86633 .25 L
.86634 .25 L
.86634 .25 L
.86635 .25 L
.86636 .25 L
.86636 .25 L
.86637 .25 L
.86637 .25 L
.86638 .25 L
.86639 .25 L
.86639 .25 L
.8664 .25 L
.86641 .25 L
.86641 .25 L
.86642 .25 L
.86642 .25 L
.86642 .25 L
.86643 .25 L
.86643 .25 L
.86644 .25 L
.86645 .25 L
.86645 .25 L
.86646 .25 L
.86647 .25 L
.86647 .25 L
.86648 .25 L
.86648 .25 L
.86649 .25 L
.8665 .25 L
.8665 .25 L
.86651 .25 L
.86652 .25 L
.86652 .25 L
.86653 .25 L
.86654 .25 L
.86654 .25 L
.86654 .25 L
.86655 .25 L
.86655 .25 L
.86656 .25 L
.86656 .25 L
Mistroke
.86657 .25 L
.86657 .25 L
.86658 .25 L
.86658 .25 L
.86658 .25 L
.86659 .25 L
.86659 .25 L
.8666 .25 L
.8666 .25 L
.8666 .25 L
.86661 .25 L
.86662 .25 L
.86662 .25 L
.86663 .25 L
.86664 .25 L
.86664 .25 L
.86665 .25 L
.86665 .25 L
.86666 .25 L
.86667 .25 L
.86667 .25 L
.86668 .25 L
.86669 .25 L
.86669 .25 L
.8667 .25 L
.8667 .25 L
.86671 .25 L
.86671 .25 L
.86672 .25 L
.86673 .25 L
.86673 .25 L
.86674 .25 L
.86674 .25 L
.86675 .25 L
.86676 .25 L
.86676 .25 L
.86677 .25 L
.86677 .25 L
.86678 .25 L
.86679 .25 L
.86679 .25 L
.8668 .25 L
.8668 .25 L
.8668 .25 L
.86681 .25 L
.86682 .25 L
.86682 .25 L
.86683 .25 L
.86684 .25 L
.86684 .25 L
Mistroke
.86685 .25 L
.86686 .25 L
.86686 .25 L
.86687 .25 L
.86687 .25 L
.86688 .25 L
.86689 .25 L
.86689 .25 L
.8669 .25 L
.86691 .25 L
.86691 .25 L
.86692 .25 L
.86692 .25 L
.86693 .25 L
.86693 .25 L
.86694 .25 L
.86695 .25 L
.86695 .25 L
.86696 .25 L
.86696 .25 L
.86697 .25 L
.86698 .25 L
.86698 .25 L
.86699 .25 L
.86699 .25 L
.867 .25 L
.867 .25 L
.86701 .25 L
.86701 .25 L
.86702 .25 L
.86703 .25 L
.86703 .25 L
.86703 .25 L
.86704 .25 L
.86705 .25 L
.86705 .25 L
.86706 .25 L
.86706 .25 L
.86707 .25 L
.86708 .25 L
.86708 .25 L
.86708 .25 L
.86709 .25 L
.8671 .25 L
.8671 .25 L
.86711 .25 L
.86711 .25 L
.86712 .25 L
.86713 .25 L
.86713 .25 L
Mistroke
.86714 .25 L
.86714 .25 L
.86715 .25 L
.86715 .25 L
.86716 .25 L
.86717 .25 L
.86717 .25 L
.86718 .25 L
.86719 .25 L
.86719 .25 L
.8672 .25 L
.8672 .25 L
.86721 .25 L
.86722 .25 L
.86722 .25 L
.86723 .25 L
.86724 .25 L
.86724 .25 L
.86724 .25 L
.86725 .25 L
.86725 .25 L
.86726 .25 L
.86726 .25 L
.86727 .25 L
.86728 .25 L
.86728 .25 L
.86729 .25 L
.8673 .25 L
.8673 .25 L
.86731 .25 L
.86731 .25 L
.86732 .25 L
.86733 .25 L
.86733 .25 L
.86734 .25 L
.86735 .25 L
.86735 .25 L
.86736 .25 L
.86736 .25 L
.86737 .25 L
.86737 .25 L
.86738 .25 L
.86738 .25 L
.86739 .25 L
.86739 .25 L
.8674 .25 L
.8674 .25 L
.8674 .25 L
.86741 .25 L
.86741 .25 L
Mistroke
.86742 .25 L
.86742 .25 L
.86742 .25 L
.86743 .25 L
.86743 .25 L
.86744 .25 L
.86745 .25 L
.86745 .25 L
.86746 .25 L
.86747 .25 L
.86747 .25 L
.86748 .25 L
.86748 .25 L
.86749 .25 L
.8675 .25 L
.8675 .25 L
.86751 .25 L
.86752 .25 L
.86752 .25 L
.86753 .25 L
.86753 .25 L
.86754 .25 L
.86754 .25 L
.86755 .25 L
.86756 .25 L
.86756 .25 L
.86757 .25 L
.86757 .25 L
.86758 .25 L
.86758 .25 L
.86759 .25 L
.8676 .25 L
.8676 .25 L
.86761 .25 L
.86761 .25 L
.86762 .25 L
.86763 .25 L
.86763 .25 L
.86763 .25 L
.86764 .25 L
.86765 .25 L
.86766 .25 L
.86766 .25 L
.86767 .25 L
.86767 .25 L
.86768 .25 L
.86769 .25 L
.86769 .25 L
.8677 .25 L
.86771 .25 L
Mistroke
.86771 .25 L
.86772 .25 L
.86773 .25 L
.86773 .25 L
.86773 .25 L
.86774 .25 L
.86775 .25 L
.86775 .25 L
.86776 .25 L
.86776 .25 L
.86777 .25 L
.86778 .25 L
.86778 .25 L
.86779 .25 L
.86779 .25 L
.8678 .25 L
.86781 .25 L
.86781 .25 L
.86782 .25 L
.86782 .25 L
.86783 .25 L
.86783 .25 L
.86784 .25 L
.86784 .25 L
.86785 .25 L
.86785 .25 L
.86786 .25 L
.86786 .25 L
.86787 .25 L
.86788 .25 L
.86788 .25 L
.86789 .25 L
.86789 .25 L
.8679 .25 L
.8679 .25 L
.86791 .25 L
.86792 .25 L
.86792 .25 L
.86792 .25 L
.86793 .25 L
.86794 .25 L
.86794 .25 L
.86795 .25 L
.86795 .25 L
.86796 .25 L
.86797 .25 L
.86797 .25 L
.86798 .25 L
.86798 .25 L
.86799 .25 L
Mistroke
.868 .25 L
.868 .25 L
.86801 .25 L
.86801 .25 L
.86802 .25 L
.86803 .25 L
.86803 .25 L
.86804 .25 L
.86805 .25 L
.86805 .25 L
.86806 .25 L
.86806 .25 L
.86807 .25 L
.86807 .25 L
.86807 .25 L
.86808 .25 L
.86809 .25 L
.86809 .25 L
.8681 .25 L
.86811 .25 L
.86811 .25 L
.86812 .25 L
.86813 .25 L
.86813 .25 L
.86814 .25 L
.86815 .25 L
.86815 .25 L
.86816 .25 L
.86816 .25 L
.86817 .25 L
.86818 .25 L
.86818 .25 L
.86819 .25 L
.86819 .25 L
.8682 .25 L
.8682 .25 L
.86821 .25 L
.86821 .25 L
.86821 .25 L
.86822 .25 L
.86822 .25 L
.86823 .25 L
.86823 .25 L
.86824 .25 L
.86824 .25 L
.86824 .25 L
.86825 .25 L
.86825 .25 L
.86826 .25 L
.86826 .25 L
Mistroke
.86827 .25 L
.86828 .25 L
.86828 .25 L
.86829 .25 L
.8683 .25 L
.8683 .25 L
.86831 .25 L
.86831 .25 L
.86832 .25 L
.86833 .25 L
.86833 .25 L
.86834 .25 L
.86835 .25 L
.86835 .25 L
.86835 .25 L
.86836 .25 L
.86837 .25 L
.86837 .25 L
.86838 .25 L
.86839 .25 L
.86839 .25 L
.8684 .25 L
.8684 .25 L
.86841 .25 L
.86841 .25 L
.86842 .25 L
.86843 .25 L
.86843 .25 L
.86844 .25 L
.86845 .25 L
.86845 .25 L
.86845 .25 L
.86846 .25 L
.86847 .25 L
.86847 .25 L
.86848 .25 L
.86849 .25 L
.86849 .25 L
.8685 .25 L
.8685 .25 L
.86851 .25 L
.86852 .25 L
.86852 .25 L
.86853 .25 L
.86854 .25 L
.86854 .25 L
.86855 .25 L
.86855 .25 L
.86856 .25 L
.86856 .25 L
Mistroke
.86857 .25 L
.86858 .25 L
.86858 .25 L
.86859 .25 L
.86859 .25 L
.8686 .25 L
.86861 .25 L
.86861 .25 L
.86862 .25 L
.86862 .25 L
.86863 .25 L
.86864 .25 L
.86864 .25 L
.86865 .25 L
.86865 .25 L
.86865 .25 L
.86866 .25 L
.86867 .25 L
.86867 .25 L
.86868 .25 L
.86868 .25 L
.86869 .25 L
.86869 .25 L
.8687 .25 L
.86871 .25 L
.86871 .25 L
.86872 .25 L
.86872 .25 L
.86873 .25 L
.86873 .25 L
.86874 .25 L
.86874 .25 L
.86875 .25 L
.86875 .25 L
.86876 .25 L
.86877 .25 L
.86877 .25 L
.86878 .25 L
.86878 .25 L
.86879 .25 L
.8688 .25 L
.8688 .25 L
.86881 .25 L
.86881 .25 L
.86882 .25 L
.86883 .25 L
.86883 .25 L
.86884 .25 L
.86884 .25 L
.86885 .25 L
Mistroke
.86886 .25 L
.86886 .25 L
.86887 .25 L
.86888 .25 L
.86888 .25 L
.86889 .25 L
.86889 .25 L
.86889 .25 L
.8689 .25 L
.86891 .25 L
.86891 .25 L
.86892 .25 L
.86892 .25 L
.86893 .25 L
.86894 .25 L
.86894 .25 L
.86895 .25 L
.86896 .25 L
.86896 .25 L
.86897 .25 L
.86897 .25 L
.86898 .25 L
.86899 .25 L
.86899 .25 L
.869 .25 L
.86901 .25 L
.86901 .25 L
.86902 .25 L
.86902 .25 L
.86903 .25 L
.86903 .25 L
.86903 .25 L
.86904 .25 L
.86904 .25 L
.86905 .25 L
.86905 .25 L
.86905 .25 L
.86906 .25 L
.86906 .25 L
.86907 .25 L
.86907 .25 L
.86907 .25 L
.86908 .25 L
.86909 .25 L
.86909 .25 L
.8691 .25 L
.86911 .25 L
.86911 .25 L
.86912 .25 L
.86912 .25 L
Mistroke
.86913 .25 L
.86914 .25 L
.86914 .25 L
.86915 .25 L
.86916 .25 L
.86916 .25 L
.86917 .25 L
.86917 .25 L
.86918 .25 L
.86918 .25 L
.86919 .25 L
.8692 .25 L
.8692 .25 L
.86921 .25 L
.86922 .25 L
.86922 .25 L
.86923 .25 L
.86923 .25 L
.86924 .25 L
.86924 .25 L
.86925 .25 L
.86926 .25 L
.86926 .25 L
.86927 .25 L
.86927 .25 L
.86928 .25 L
.86928 .25 L
.86929 .25 L
.8693 .25 L
.8693 .25 L
.86931 .25 L
.86931 .25 L
.86932 .25 L
.86933 .25 L
.86933 .25 L
.86934 .25 L
.86935 .25 L
.86935 .25 L
.86936 .25 L
.86937 .25 L
.86937 .25 L
.86938 .25 L
.86938 .25 L
.86939 .25 L
.86939 .25 L
.8694 .25 L
.8694 .25 L
.86941 .25 L
.86942 .25 L
.86942 .25 L
Mistroke
.86943 .25 L
.86943 .25 L
.86944 .25 L
.86945 .25 L
.86945 .25 L
.86946 .25 L
.86946 .25 L
.86947 .25 L
.86947 .25 L
.86948 .25 L
.86948 .25 L
.86949 .25 L
.8695 .25 L
.8695 .25 L
.86951 .25 L
.86952 .25 L
.86952 .25 L
.86953 .25 L
.86954 .25 L
.86954 .25 L
.86955 .25 L
.86956 .25 L
.86956 .25 L
.86957 .25 L
.86957 .25 L
.86958 .25 L
.86958 .25 L
.86959 .25 L
.8696 .25 L
.8696 .25 L
.86961 .25 L
.86961 .25 L
.86962 .25 L
.86963 .25 L
.86963 .25 L
.86964 .25 L
.86964 .25 L
.86965 .25 L
.86966 .25 L
.86966 .25 L
.86967 .25 L
.86967 .25 L
.86968 .25 L
.86968 .25 L
.86969 .25 L
.86969 .25 L
.8697 .25 L
.8697 .25 L
.86971 .25 L
.86971 .25 L
Mistroke
.86972 .25 L
.86973 .25 L
.86973 .25 L
.86974 .25 L
.86974 .25 L
.86975 .25 L
.86975 .25 L
.86976 .25 L
.86977 .25 L
.86977 .25 L
.86977 .25 L
.86978 .25 L
.86979 .25 L
.86979 .25 L
.8698 .25 L
.8698 .25 L
.86981 .25 L
.86982 .25 L
.86982 .25 L
.86983 .25 L
.86983 .25 L
.86984 .25 L
.86985 .25 L
.86985 .25 L
.86986 .25 L
.86986 .25 L
.86987 .25 L
.86988 .25 L
.86988 .25 L
.86989 .25 L
.8699 .25 L
.8699 .25 L
.86991 .25 L
.86991 .25 L
.86992 .25 L
.86992 .25 L
.86992 .25 L
.86993 .25 L
.86994 .25 L
.86994 .25 L
.86995 .25 L
.86996 .25 L
.86996 .25 L
.86997 .25 L
.86998 .25 L
.86998 .25 L
.86999 .25 L
.86999 .25 L
.87 .25 L
.87001 .25 L
Mistroke
.87001 .25 L
.87002 .25 L
.87003 .25 L
.87003 .25 L
.87004 .25 L
.87004 .25 L
.87005 .25 L
.87005 .25 L
.87006 .25 L
.87006 .25 L
.87006 .25 L
.87007 .25 L
.87007 .25 L
.87008 .25 L
.87008 .25 L
.87009 .25 L
.87009 .25 L
.87009 .25 L
.8701 .25 L
.8701 .25 L
.87011 .25 L
.87011 .25 L
.87012 .25 L
.87013 .25 L
.87013 .25 L
.87014 .25 L
.87015 .25 L
.87015 .25 L
.87016 .25 L
.87016 .25 L
.87017 .25 L
.87018 .25 L
.87018 .25 L
.87019 .25 L
.8702 .25 L
.8702 .25 L
.8702 .25 L
.87021 .25 L
.87022 .25 L
.87022 .25 L
.87023 .25 L
.87024 .25 L
.87024 .25 L
.87025 .25 L
.87025 .25 L
.87026 .25 L
.87026 .25 L
.87027 .25 L
.87028 .25 L
.87028 .25 L
Mistroke
.87029 .25 L
.8703 .25 L
.8703 .25 L
.8703 .25 L
.87031 .25 L
.87032 .25 L
.87032 .25 L
.87032 .25 L
.87033 .25 L
.87034 .25 L
.87034 .25 L
.87034 .25 L
.87035 .25 L
.87036 .25 L
.87036 .25 L
.87036 .25 L
.87037 .25 L
Mfstroke
.87037 .25 m
.87038 .25 L
.87038 .25 L
.87039 .25 L
.8704 .25 L
.8704 .25 L
.87041 .25 L
.87041 .25 L
.87042 .25 L
.87042 .25 L
.87043 .25 L
.87044 .25 L
.87044 .25 L
.87045 .25 L
.87045 .25 L
.87046 .25 L
.87046 .25 L
.87047 .25 L
.87047 .25 L
.87048 .25 L
.87048 .25 L
.87049 .25 L
.87049 .25 L
.8705 .25 L
.8705 .25 L
.8705 .25 L
.87051 .25 L
.87051 .25 L
.87052 .25 L
.87053 .25 L
.87053 .25 L
.87054 .25 L
.87054 .25 L
.87055 .25 L
.87056 .25 L
.87056 .25 L
.87057 .25 L
.87058 .25 L
.87058 .25 L
.87058 .25 L
.87059 .25 L
.87059 .25 L
.8706 .25 L
.8706 .25 L
.87061 .25 L
.87061 .25 L
.87062 .25 L
.87062 .25 L
.87063 .25 L
.87063 .25 L
Mistroke
.87064 .25 L
.87064 .25 L
.87064 .25 L
.87065 .25 L
.87065 .25 L
.87066 .25 L
.87066 .25 L
.87066 .25 L
.87067 .25 L
.87067 .25 L
.87068 .25 L
.87068 .25 L
.87069 .25 L
.87069 .25 L
.87069 .25 L
.8707 .25 L
.87071 .25 L
.87071 .25 L
.87072 .25 L
.87073 .25 L
.87073 .25 L
.87074 .25 L
.87074 .25 L
.87075 .25 L
.87075 .25 L
.87075 .25 L
.87076 .25 L
.87076 .25 L
.87077 .25 L
.87077 .25 L
.87078 .25 L
.87078 .25 L
.87079 .25 L
.8708 .25 L
.8708 .25 L
.87081 .25 L
.87081 .25 L
.87082 .25 L
.87083 .25 L
.87083 .25 L
.87084 .25 L
.87084 .25 L
.87085 .25 L
.87085 .25 L
.87086 .25 L
.87086 .25 L
.87086 .25 L
.87087 .25 L
.87088 .25 L
.87088 .25 L
Mistroke
.87088 .25 L
.87089 .25 L
.87089 .25 L
.8709 .25 L
.87091 .25 L
.87091 .25 L
.87092 .25 L
.87093 .25 L
.87093 .25 L
.87094 .25 L
.87094 .25 L
.87095 .25 L
.87096 .25 L
.87096 .25 L
.87097 .25 L
.87097 .25 L
.87098 .25 L
.87099 .25 L
.87099 .25 L
.87099 .25 L
.871 .25 L
.87101 .25 L
.87101 .25 L
.87102 .25 L
.87103 .25 L
.87103 .25 L
.87104 .25 L
.87104 .25 L
.87105 .25 L
.87106 .25 L
.87106 .25 L
.87107 .25 L
.87108 .25 L
.87108 .25 L
.87109 .25 L
.87109 .25 L
.8711 .25 L
.8711 .25 L
.87111 .25 L
.87112 .25 L
.87112 .25 L
.87113 .25 L
.87114 .25 L
.87114 .25 L
.87115 .25 L
.87115 .25 L
.87116 .25 L
.87116 .25 L
.87117 .25 L
.87118 .25 L
Mistroke
.87118 .25 L
.87119 .25 L
.87119 .25 L
.8712 .25 L
.8712 .25 L
.87121 .25 L
.87122 .25 L
.87122 .25 L
.87123 .25 L
.87123 .25 L
.87124 .25 L
.87125 .25 L
.87125 .25 L
.87126 .25 L
.87127 .25 L
.87127 .25 L
.87128 .25 L
.87128 .25 L
.87129 .25 L
.8713 .25 L
.8713 .25 L
.87131 .25 L
.87131 .25 L
.87132 .25 L
.87132 .25 L
.87133 .25 L
.87134 .25 L
.87134 .25 L
.87135 .25 L
.87135 .25 L
.87136 .25 L
.87137 .25 L
.87137 .25 L
.87138 .25 L
.87138 .25 L
.87139 .25 L
.87139 .25 L
.8714 .25 L
.8714 .25 L
.87141 .25 L
.87142 .25 L
.87142 .25 L
.87143 .25 L
.87144 .25 L
.87144 .25 L
.87145 .25 L
.87146 .25 L
.87146 .25 L
.87147 .25 L
.87147 .25 L
Mistroke
.87148 .25 L
.87149 .25 L
.87149 .25 L
.8715 .25 L
.8715 .25 L
.87151 .25 L
.87152 .25 L
.87152 .25 L
.87153 .25 L
.87153 .25 L
.87154 .25 L
.87155 .25 L
.87155 .25 L
.87156 .25 L
.87156 .25 L
.87157 .25 L
.87157 .25 L
.87158 .25 L
.87159 .25 L
.87159 .25 L
.8716 .25 L
.8716 .25 L
.87161 .25 L
.87161 .25 L
.87162 .25 L
.87163 .25 L
.87163 .25 L
.87164 .25 L
.87165 .25 L
.87165 .25 L
.87166 .25 L
.87166 .25 L
.87167 .25 L
.87168 .25 L
.87168 .25 L
.87169 .25 L
.8717 .25 L
.8717 .25 L
.8717 .25 L
.87171 .25 L
.87172 .25 L
.87172 .25 L
.87173 .25 L
.87174 .25 L
.87174 .25 L
.87175 .25 L
.87175 .25 L
.87176 .25 L
.87176 .25 L
.87177 .25 L
Mistroke
.87178 .25 L
.87178 .25 L
.87179 .25 L
.8718 .25 L
.8718 .25 L
.8718 .25 L
.87181 .25 L
.87182 .25 L
.87182 .25 L
.87183 .25 L
.87183 .25 L
.87184 .25 L
.87184 .25 L
.87185 .25 L
.87185 .25 L
.87186 .25 L
.87187 .25 L
.87187 .25 L
.87188 .25 L
.87188 .25 L
.87189 .25 L
.87189 .25 L
.87189 .25 L
.8719 .25 L
.87191 .25 L
.87191 .25 L
.87192 .25 L
.87193 .25 L
.87193 .25 L
.87194 .25 L
.87194 .25 L
.87195 .25 L
.87196 .25 L
.87196 .25 L
.87197 .25 L
.87198 .25 L
.87198 .25 L
.87199 .25 L
.87199 .25 L
.872 .25 L
.87201 .25 L
.87201 .25 L
.87202 .25 L
.87203 .25 L
.87203 .25 L
.87204 .25 L
.87204 .25 L
.87204 .25 L
.87205 .25 L
.87205 .25 L
Mistroke
.87206 .25 L
.87207 .25 L
.87207 .25 L
.87208 .25 L
.87209 .25 L
.87209 .25 L
.8721 .25 L
.8721 .25 L
.87211 .25 L
.87212 .25 L
.87212 .25 L
.87213 .25 L
.87214 .25 L
.87214 .25 L
.87215 .25 L
.87216 .25 L
.87216 .25 L
.87216 .25 L
.87217 .25 L
.87217 .25 L
.87218 .25 L
.87218 .25 L
.87219 .25 L
.87219 .25 L
.8722 .25 L
.8722 .25 L
.8722 .25 L
.87221 .25 L
.87221 .25 L
.87221 .25 L
.87222 .25 L
.87222 .25 L
.87223 .25 L
.87224 .25 L
.87224 .25 L
.87225 .25 L
.87226 .25 L
.87226 .25 L
.87227 .25 L
.87227 .25 L
.87228 .25 L
.87229 .25 L
.87229 .25 L
.8723 .25 L
.87231 .25 L
.87231 .25 L
.87232 .25 L
.87232 .25 L
.87233 .25 L
.87233 .25 L
Mistroke
.87234 .25 L
.87235 .25 L
.87235 .25 L
.87236 .25 L
.87236 .25 L
.87237 .25 L
.87237 .25 L
.87238 .25 L
.87239 .25 L
.87239 .25 L
.8724 .25 L
.87241 .25 L
.87241 .25 L
.87242 .25 L
.87242 .25 L
.87242 .25 L
.87243 .25 L
.87244 .25 L
.87244 .25 L
.87245 .25 L
.87246 .25 L
.87246 .25 L
.87247 .25 L
.87248 .25 L
.87248 .25 L
.87249 .25 L
.87249 .25 L
.8725 .25 L
.87251 .25 L
.87251 .25 L
.87252 .25 L
.87253 .25 L
.87253 .25 L
.87254 .25 L
.87254 .25 L
.87255 .25 L
.87255 .25 L
.87256 .25 L
.87257 .25 L
.87257 .25 L
.87258 .25 L
.87258 .25 L
.87259 .25 L
.8726 .25 L
.8726 .25 L
.87261 .25 L
.87261 .25 L
.87262 .25 L
.87262 .25 L
.87263 .25 L
Mistroke
.87263 .25 L
.87264 .25 L
.87265 .25 L
.87265 .25 L
.87265 .25 L
.87266 .25 L
.87267 .25 L
.87267 .25 L
.87268 .25 L
.87268 .25 L
.87269 .25 L
.8727 .25 L
.8727 .25 L
.8727 .25 L
.87271 .25 L
.87272 .25 L
.87272 .25 L
.87273 .25 L
.87273 .25 L
.87274 .25 L
.87275 .25 L
.87275 .25 L
.87276 .25 L
.87276 .25 L
.87277 .25 L
.87277 .25 L
.87278 .25 L
.87279 .25 L
.87279 .25 L
.8728 .25 L
.87281 .25 L
.87281 .25 L
.87282 .25 L
.87282 .25 L
.87283 .25 L
.87284 .25 L
.87284 .25 L
.87285 .25 L
.87286 .25 L
.87286 .25 L
.87286 .25 L
.87287 .25 L
.87287 .25 L
.87288 .25 L
.87288 .25 L
.87289 .25 L
.8729 .25 L
.8729 .25 L
.87291 .25 L
.87292 .25 L
Mistroke
.87292 .25 L
.87293 .25 L
.87293 .25 L
.87294 .25 L
.87295 .25 L
.87295 .25 L
.87296 .25 L
.87297 .25 L
.87297 .25 L
.87298 .25 L
.87298 .25 L
.87299 .25 L
.87299 .25 L
.873 .25 L
.873 .25 L
.87301 .25 L
.87301 .25 L
.87302 .25 L
.87302 .25 L
.87302 .25 L
.87303 .25 L
.87303 .25 L
.87304 .25 L
.87304 .25 L
.87304 .25 L
.87305 .25 L
.87305 .25 L
.87306 .25 L
.87307 .25 L
.87307 .25 L
.87308 .25 L
.87309 .25 L
.87309 .25 L
.8731 .25 L
.8731 .25 L
.87311 .25 L
.87312 .25 L
.87312 .25 L
.87313 .25 L
.87314 .25 L
.87314 .25 L
.87315 .25 L
.87315 .25 L
.87316 .25 L
.87316 .25 L
.87317 .25 L
.87318 .25 L
.87318 .25 L
.87319 .25 L
.87319 .25 L
Mistroke
.8732 .25 L
.8732 .25 L
.87321 .25 L
.87322 .25 L
.87322 .25 L
.87323 .25 L
.87324 .25 L
.87324 .25 L
.87325 .25 L
.87325 .25 L
.87325 .25 L
.87326 .25 L
.87327 .25 L
.87328 .25 L
.87328 .25 L
.87329 .25 L
.87329 .25 L
.8733 .25 L
.87331 .25 L
.87331 .25 L
.87332 .25 L
.87333 .25 L
.87333 .25 L
.87334 .25 L
.87335 .25 L
.87335 .25 L
.87335 .25 L
.87336 .25 L
.87337 .25 L
.87337 .25 L
.87338 .25 L
.87338 .25 L
.87339 .25 L
.8734 .25 L
.8734 .25 L
.87341 .25 L
.87341 .25 L
.87342 .25 L
.87343 .25 L
.87343 .25 L
.87344 .25 L
.87344 .25 L
.87345 .25 L
.87345 .25 L
.87346 .25 L
.87346 .25 L
.87347 .25 L
.87347 .25 L
.87348 .25 L
.87348 .25 L
Mistroke
.87349 .25 L
.8735 .25 L
.8735 .25 L
.87351 .25 L
.87351 .25 L
.87352 .25 L
.87353 .25 L
.87353 .25 L
.87354 .25 L
.87354 .25 L
.87354 .25 L
.87355 .25 L
.87356 .25 L
.87356 .25 L
.87357 .25 L
.87357 .25 L
.87358 .25 L
.87359 .25 L
.87359 .25 L
.8736 .25 L
.8736 .25 L
.87361 .25 L
.87362 .25 L
.87362 .25 L
.87363 .25 L
.87364 .25 L
.87364 .25 L
.87365 .25 L
.87365 .25 L
.87366 .25 L
.87367 .25 L
.87367 .25 L
.87368 .25 L
.87368 .25 L
.87369 .25 L
.87369 .25 L
.8737 .25 L
.8737 .25 L
.87371 .25 L
.87371 .25 L
.87372 .25 L
.87373 .25 L
.87373 .25 L
.87374 .25 L
.87375 .25 L
.87375 .25 L
.87376 .25 L
.87377 .25 L
.87377 .25 L
.87378 .25 L
Mistroke
.87378 .25 L
.87379 .25 L
.8738 .25 L
.8738 .25 L
.87381 .25 L
.87381 .25 L
.87382 .25 L
.87382 .25 L
.87383 .25 L
.87383 .25 L
.87383 .25 L
.87384 .25 L
.87384 .25 L
.87385 .25 L
.87385 .25 L
.87386 .25 L
.87386 .25 L
.87386 .25 L
.87387 .25 L
.87387 .25 L
.87388 .25 L
.87388 .25 L
.87389 .25 L
.8739 .25 L
.8739 .25 L
.87391 .25 L
.87392 .25 L
.87392 .25 L
.87393 .25 L
.87393 .25 L
.87394 .25 L
.87395 .25 L
.87395 .25 L
.87396 .25 L
.87397 .25 L
.87397 .25 L
.87397 .25 L
.87398 .25 L
.87399 .25 L
.87399 .25 L
.874 .25 L
.87401 .25 L
.87401 .25 L
.87402 .25 L
.87402 .25 L
.87403 .25 L
.87403 .25 L
.87404 .25 L
.87405 .25 L
.87405 .25 L
Mistroke
.87406 .25 L
.87407 .25 L
.87407 .25 L
.87407 .25 L
.87408 .25 L
.87409 .25 L
.87409 .25 L
.8741 .25 L
.87411 .25 L
.87411 .25 L
.87412 .25 L
.87412 .25 L
.87413 .25 L
.87414 .25 L
.87414 .25 L
.87415 .25 L
.87416 .25 L
.87416 .25 L
.87417 .25 L
.87417 .25 L
.87418 .25 L
.87418 .25 L
.87419 .25 L
.8742 .25 L
.8742 .25 L
.87421 .25 L
.87421 .25 L
.87422 .25 L
.87423 .25 L
.87423 .25 L
.87424 .25 L
.87424 .25 L
.87425 .25 L
.87426 .25 L
.87426 .25 L
.87427 .25 L
.87427 .25 L
.87428 .25 L
.87428 .25 L
.87429 .25 L
.87429 .25 L
.8743 .25 L
.8743 .25 L
.87431 .25 L
.87431 .25 L
.87432 .25 L
.87433 .25 L
.87433 .25 L
.87434 .25 L
.87435 .25 L
Mistroke
.87435 .25 L
.87435 .25 L
.87436 .25 L
.87436 .25 L
.87437 .25 L
.87437 .25 L
.87438 .25 L
.87439 .25 L
.87439 .25 L
.8744 .25 L
.8744 .25 L
.87441 .25 L
.87442 .25 L
.87442 .25 L
.87443 .25 L
.87443 .25 L
.87444 .25 L
.87445 .25 L
.87445 .25 L
.87446 .25 L
.87446 .25 L
.87447 .25 L
.87448 .25 L
.87448 .25 L
.87449 .25 L
.8745 .25 L
.8745 .25 L
.87451 .25 L
.87451 .25 L
.87452 .25 L
.87452 .25 L
.87453 .25 L
.87453 .25 L
.87454 .25 L
.87455 .25 L
.87455 .25 L
.87456 .25 L
.87456 .25 L
.87457 .25 L
.87458 .25 L
.87458 .25 L
.87459 .25 L
.8746 .25 L
.8746 .25 L
.87461 .25 L
.87461 .25 L
.87462 .25 L
.87463 .25 L
.87463 .25 L
.87464 .25 L
Mistroke
.87464 .25 L
.87465 .25 L
.87465 .25 L
.87465 .25 L
.87466 .25 L
.87466 .25 L
.87467 .25 L
.87467 .25 L
.87467 .25 L
.87468 .25 L
.87468 .25 L
.87469 .25 L
.87469 .25 L
.87469 .25 L
.8747 .25 L
.87471 .25 L
.87471 .25 L
.87472 .25 L
.87473 .25 L
.87473 .25 L
.87474 .25 L
.87474 .25 L
.87475 .25 L
.87476 .25 L
.87476 .25 L
.87477 .25 L
.87478 .25 L
.87478 .25 L
.87479 .25 L
.87479 .25 L
.8748 .25 L
.8748 .25 L
.87481 .25 L
.87482 .25 L
.87482 .25 L
.87483 .25 L
.87484 .25 L
.87484 .25 L
.87485 .25 L
.87485 .25 L
.87486 .25 L
.87486 .25 L
.87487 .25 L
.87488 .25 L
.87488 .25 L
.87489 .25 L
.87489 .25 L
.8749 .25 L
.8749 .25 L
.87491 .25 L
Mistroke
.87492 .25 L
.87492 .25 L
.87493 .25 L
.87494 .25 L
.87494 .25 L
.87495 .25 L
.87495 .25 L
.87496 .25 L
.87497 .25 L
.87497 .25 L
.87498 .25 L
.87499 .25 L
.87499 .25 L
.875 .25 L
.875 .25 L
.87501 .25 L
.87501 .25 L
.87502 .25 L
.87503 .25 L
.87503 .25 L
.87504 .25 L
.87504 .25 L
.87505 .25 L
.87505 .25 L
.87506 .25 L
.87507 .25 L
.87507 .25 L
.87508 .25 L
.87508 .25 L
.87509 .25 L
.8751 .25 L
.8751 .25 L
.8751 .25 L
.87511 .25 L
.87512 .25 L
.87512 .25 L
.87512 .25 L
.87513 .25 L
.87514 .25 L
.87514 .25 L
.87515 .25 L
.87516 .25 L
.87516 .25 L
.87517 .25 L
.87517 .25 L
.87518 .25 L
.87518 .25 L
.87519 .25 L
.87519 .25 L
.8752 .25 L
Mistroke
.8752 .25 L
.87521 .25 L
.87522 .25 L
.87522 .25 L
.87523 .25 L
.87523 .25 L
.87524 .25 L
.87524 .25 L
.87525 .25 L
.87526 .25 L
.87526 .25 L
.87527 .25 L
.87528 .25 L
.87528 .25 L
.87529 .25 L
.87529 .25 L
.8753 .25 L
.87531 .25 L
.87531 .25 L
.87532 .25 L
.87533 .25 L
.87533 .25 L
.87533 .25 L
.87534 .25 L
.87534 .25 L
.87535 .25 L
.87535 .25 L
.87536 .25 L
.87537 .25 L
.87537 .25 L
.87538 .25 L
.87539 .25 L
.87539 .25 L
.8754 .25 L
.87541 .25 L
.87541 .25 L
.87542 .25 L
.87542 .25 L
.87543 .25 L
.87544 .25 L
.87544 .25 L
.87545 .25 L
.87546 .25 L
.87546 .25 L
.87547 .25 L
.87547 .25 L
.87547 .25 L
.87548 .25 L
.87548 .25 L
.87549 .25 L
Mistroke
.87549 .25 L
.87549 .25 L
.8755 .25 L
.8755 .25 L
.87551 .25 L
.87551 .25 L
.87551 .25 L
.87552 .25 L
.87552 .25 L
.87553 .25 L
.87554 .25 L
.87554 .25 L
.87555 .25 L
.87556 .25 L
.87556 .25 L
.87557 .25 L
.87557 .25 L
.87558 .25 L
.87559 .25 L
.87559 .25 L
.8756 .25 L
.87561 .25 L
.87561 .25 L
.87562 .25 L
.87562 .25 L
.87563 .25 L
.87563 .25 L
.87564 .25 L
.87565 .25 L
.87565 .25 L
.87566 .25 L
.87566 .25 L
.87567 .25 L
.87568 .25 L
.87568 .25 L
.87569 .25 L
.87569 .25 L
.8757 .25 L
.87571 .25 L
.87571 .25 L
.87572 .25 L
.87572 .25 L
.87573 .25 L
.87573 .25 L
.87574 .25 L
.87575 .25 L
.87575 .25 L
.87576 .25 L
.87576 .25 L
.87577 .25 L
Mistroke
.87578 .25 L
.87578 .25 L
.87579 .25 L
.8758 .25 L
.8758 .25 L
.87581 .25 L
.87582 .25 L
.87582 .25 L
.87582 .25 L
.87583 .25 L
.87584 .25 L
.87584 .25 L
.87585 .25 L
.87586 .25 L
.87586 .25 L
.87587 .25 L
.87587 .25 L
.87588 .25 L
.87588 .25 L
.87589 .25 L
.8759 .25 L
.8759 .25 L
.87591 .25 L
.87591 .25 L
.87592 .25 L
.87592 .25 L
.87593 .25 L
.87593 .25 L
.87594 .25 L
.87595 .25 L
.87595 .25 L
.87596 .25 L
.87597 .25 L
.87597 .25 L
.87598 .25 L
.87599 .25 L
.87599 .25 L
.876 .25 L
.876 .25 L
.87601 .25 L
.87602 .25 L
.87602 .25 L
.87603 .25 L
.87603 .25 L
.87604 .25 L
.87604 .25 L
.87605 .25 L
.87606 .25 L
.87606 .25 L
.87607 .25 L
Mistroke
.87607 .25 L
.87608 .25 L
.87609 .25 L
.87609 .25 L
.8761 .25 L
.87611 .25 L
.87611 .25 L
.87612 .25 L
.87612 .25 L
.87612 .25 L
.87613 .25 L
.87614 .25 L
.87614 .25 L
.87615 .25 L
.87615 .25 L
.87616 .25 L
.87616 .25 L
.87617 .25 L
.87618 .25 L
.87618 .25 L
.87619 .25 L
.87619 .25 L
.8762 .25 L
.8762 .25 L
.87621 .25 L
.87621 .25 L
.87622 .25 L
.87622 .25 L
.87623 .25 L
.87624 .25 L
.87624 .25 L
.87625 .25 L
.87625 .25 L
.87626 .25 L
.87626 .25 L
.87627 .25 L
.87628 .25 L
.87628 .25 L
.87629 .25 L
.8763 .25 L
.8763 .25 L
.87631 .25 L
.87631 .25 L
.87632 .25 L
.87633 .25 L
.87633 .25 L
.87634 .25 L
.87635 .25 L
.87635 .25 L
.87636 .25 L
Mistroke
.87636 .25 L
.87636 .25 L
.87637 .25 L
.87637 .25 L
.87638 .25 L
.87639 .25 L
.87639 .25 L
.8764 .25 L
.87641 .25 L
.87641 .25 L
.87642 .25 L
.87643 .25 L
.87643 .25 L
.87644 .25 L
.87644 .25 L
.87645 .25 L
.87646 .25 L
.87646 .25 L
.87647 .25 L
.87648 .25 L
.87648 .25 L
.87649 .25 L
.87649 .25 L
.8765 .25 L
.8765 .25 L
.8765 .25 L
.87651 .25 L
.87651 .25 L
.87652 .25 L
.87652 .25 L
.87652 .25 L
.87653 .25 L
.87653 .25 L
.87654 .25 L
.87654 .25 L
.87654 .25 L
.87655 .25 L
.87656 .25 L
.87656 .25 L
.87657 .25 L
.87658 .25 L
.87658 .25 L
.87659 .25 L
.87659 .25 L
.8766 .25 L
.87661 .25 L
.87661 .25 L
.87662 .25 L
.87663 .25 L
.87663 .25 L
Mistroke
.87664 .25 L
.87664 .25 L
.87665 .25 L
.87665 .25 L
.87666 .25 L
.87667 .25 L
.87667 .25 L
.87668 .25 L
.87669 .25 L
.87669 .25 L
.8767 .25 L
.8767 .25 L
.87671 .25 L
.87671 .25 L
.87672 .25 L
.87673 .25 L
.87673 .25 L
.87674 .25 L
.87674 .25 L
.87675 .25 L
.87675 .25 L
.87676 .25 L
.87677 .25 L
.87677 .25 L
.87678 .25 L
.87679 .25 L
.87679 .25 L
.8768 .25 L
.8768 .25 L
.87681 .25 L
.87682 .25 L
.87682 .25 L
.87683 .25 L
.87684 .25 L
.87684 .25 L
.87685 .25 L
.87685 .25 L
.87686 .25 L
.87686 .25 L
.87687 .25 L
.87688 .25 L
.87688 .25 L
.87689 .25 L
.87689 .25 L
.8769 .25 L
.8769 .25 L
.87691 .25 L
.87692 .25 L
.87692 .25 L
.87693 .25 L
Mistroke
.87693 .25 L
.87694 .25 L
.87694 .25 L
.87695 .25 L
.87695 .25 L
.87696 .25 L
.87697 .25 L
.87697 .25 L
.87697 .25 L
.87698 .25 L
.87699 .25 L
.87699 .25 L
.877 .25 L
.87701 .25 L
.87701 .25 L
.87702 .25 L
.87702 .25 L
.87703 .25 L
.87703 .25 L
.87704 .25 L
.87704 .25 L
.87705 .25 L
.87705 .25 L
.87706 .25 L
.87707 .25 L
.87707 .25 L
.87708 .25 L
.87708 .25 L
.87709 .25 L
.87709 .25 L
.8771 .25 L
.87711 .25 L
.87711 .25 L
.87712 .25 L
.87713 .25 L
.87713 .25 L
.87714 .25 L
.87714 .25 L
.87715 .25 L
.87716 .25 L
.87716 .25 L
.87717 .25 L
.87718 .25 L
.87718 .25 L
.87718 .25 L
.87719 .25 L
.87719 .25 L
.8772 .25 L
.87721 .25 L
.87721 .25 L
Mistroke
.87722 .25 L
.87722 .25 L
.87723 .25 L
.87724 .25 L
.87724 .25 L
.87725 .25 L
.87726 .25 L
.87726 .25 L
.87727 .25 L
.87728 .25 L
.87728 .25 L
.87729 .25 L
.87729 .25 L
.8773 .25 L
.87731 .25 L
.87731 .25 L
.87732 .25 L
.87732 .25 L
.87732 .25 L
.87733 .25 L
.87733 .25 L
.87734 .25 L
.87734 .25 L
.87734 .25 L
.87735 .25 L
.87735 .25 L
.87736 .25 L
.87736 .25 L
.87736 .25 L
.87737 .25 L
.87737 .25 L
.87738 .25 L
.87739 .25 L
.87739 .25 L
.8774 .25 L
.87741 .25 L
.87741 .25 L
.87742 .25 L
.87742 .25 L
.87743 .25 L
.87744 .25 L
.87744 .25 L
.87745 .25 L
.87746 .25 L
.87746 .25 L
.87747 .25 L
.87747 .25 L
.87748 .25 L
.87748 .25 L
.87749 .25 L
Mistroke
.8775 .25 L
.8775 .25 L
.87751 .25 L
.87751 .25 L
.87752 .25 L
.87753 .25 L
.87753 .25 L
.87754 .25 L
.87754 .25 L
.87755 .25 L
.87756 .25 L
.87756 .25 L
.87757 .25 L
.87757 .25 L
.87758 .25 L
.87758 .25 L
.87759 .25 L
.8776 .25 L
.8776 .25 L
.87761 .25 L
.87762 .25 L
.87762 .25 L
.87763 .25 L
.87763 .25 L
.87764 .25 L
.87765 .25 L
.87765 .25 L
.87766 .25 L
.87767 .25 L
.87767 .25 L
.87767 .25 L
.87768 .25 L
.87769 .25 L
.87769 .25 L
.8777 .25 L
.87771 .25 L
.87771 .25 L
.87772 .25 L
.87772 .25 L
.87773 .25 L
.87773 .25 L
.87774 .25 L
.87775 .25 L
.87775 .25 L
.87776 .25 L
.87777 .25 L
.87777 .25 L
.87777 .25 L
.87778 .25 L
.87779 .25 L
Mistroke
.87779 .25 L
.8778 .25 L
.8778 .25 L
.8778 .25 L
.87781 .25 L
.87782 .25 L
.87782 .25 L
.87783 .25 L
.87784 .25 L
.87784 .25 L
.87785 .25 L
.87785 .25 L
.87786 .25 L
.87786 .25 L
.87786 .25 L
.87787 .25 L
.87788 .25 L
.87788 .25 L
.87789 .25 L
.8779 .25 L
.8779 .25 L
.87791 .25 L
.87791 .25 L
.87792 .25 L
.87793 .25 L
.87793 .25 L
.87794 .25 L
.87794 .25 L
.87795 .25 L
.87796 .25 L
.87796 .25 L
.87797 .25 L
.87798 .25 L
.87798 .25 L
.87799 .25 L
.87799 .25 L
.878 .25 L
.878 .25 L
.87801 .25 L
.87801 .25 L
.87802 .25 L
.87802 .25 L
.87803 .25 L
.87804 .25 L
.87804 .25 L
.87805 .25 L
.87805 .25 L
.87806 .25 L
.87807 .25 L
.87807 .25 L
Mistroke
.87808 .25 L
.87809 .25 L
.87809 .25 L
.8781 .25 L
.87811 .25 L
.87811 .25 L
.87812 .25 L
.87813 .25 L
.87813 .25 L
.87813 .25 L
.87814 .25 L
.87814 .25 L
.87815 .25 L
.87815 .25 L
.87815 .25 L
.87816 .25 L
.87816 .25 L
.87817 .25 L
.87817 .25 L
.87818 .25 L
.87818 .25 L
.87818 .25 L
.87819 .25 L
.87819 .25 L
.8782 .25 L
.8782 .25 L
.87821 .25 L
.87822 .25 L
.87822 .25 L
.87823 .25 L
.87824 .25 L
.87824 .25 L
.87825 .25 L
.87825 .25 L
.87826 .25 L
.87827 .25 L
.87827 .25 L
.87828 .25 L
.87829 .25 L
.87829 .25 L
.87829 .25 L
.8783 .25 L
.87831 .25 L
.87831 .25 L
.87832 .25 L
.87833 .25 L
.87833 .25 L
.87834 .25 L
.87834 .25 L
.87835 .25 L
Mistroke
.87836 .25 L
.87836 .25 L
.87837 .25 L
.87837 .25 L
.87838 .25 L
.87839 .25 L
.87839 .25 L
.87839 .25 L
.8784 .25 L
.87841 .25 L
.87841 .25 L
.87842 .25 L
.87843 .25 L
.87843 .25 L
.87844 .25 L
.87844 .25 L
.87845 .25 L
.87846 .25 L
.87846 .25 L
.87847 .25 L
.87848 .25 L
.87848 .25 L
.87849 .25 L
.87849 .25 L
.8785 .25 L
.8785 .25 L
.87851 .25 L
.87852 .25 L
.87852 .25 L
.87853 .25 L
.87854 .25 L
.87854 .25 L
.87855 .25 L
.87855 .25 L
.87856 .25 L
.87856 .25 L
.87857 .25 L
.87858 .25 L
.87858 .25 L
.87859 .25 L
.87859 .25 L
.8786 .25 L
.8786 .25 L
.87861 .25 L
.87862 .25 L
.87862 .25 L
.87862 .25 L
.87863 .25 L
.87864 .25 L
.87864 .25 L
Mistroke
.87865 .25 L
.87865 .25 L
.87866 .25 L
.87867 .25 L
.87867 .25 L
.87867 .25 L
.87868 .25 L
.87868 .25 L
.87869 .25 L
.87869 .25 L
.8787 .25 L
.87871 .25 L
.87871 .25 L
.87872 .25 L
.87873 .25 L
.87873 .25 L
.87874 .25 L
.87874 .25 L
.87875 .25 L
.87876 .25 L
.87876 .25 L
.87877 .25 L
.87877 .25 L
.87878 .25 L
.87879 .25 L
.87879 .25 L
.8788 .25 L
.8788 .25 L
.87881 .25 L
.87882 .25 L
.87882 .25 L
.87883 .25 L
.87883 .25 L
.87884 .25 L
.87884 .25 L
.87885 .25 L
.87885 .25 L
.87886 .25 L
.87887 .25 L
.87887 .25 L
.87888 .25 L
.87888 .25 L
.87889 .25 L
.8789 .25 L
.8789 .25 L
.87891 .25 L
.87892 .25 L
.87892 .25 L
.87893 .25 L
.87894 .25 L
Mistroke
.87894 .25 L
.87895 .25 L
.87895 .25 L
.87896 .25 L
.87896 .25 L
.87897 .25 L
.87897 .25 L
.87897 .25 L
.87898 .25 L
.87898 .25 L
.87899 .25 L
.87899 .25 L
.879 .25 L
.879 .25 L
.879 .25 L
.87901 .25 L
.87901 .25 L
.87901 .25 L
.87902 .25 L
.87903 .25 L
.87903 .25 L
.87904 .25 L
.87905 .25 L
.87905 .25 L
.87906 .25 L
.87907 .25 L
.87907 .25 L
.87908 .25 L
.87908 .25 L
.87909 .25 L
.8791 .25 L
.8791 .25 L
.87911 .25 L
.87911 .25 L
.87912 .25 L
.87913 .25 L
.87913 .25 L
.87914 .25 L
.87914 .25 L
.87915 .25 L
.87916 .25 L
.87916 .25 L
.87917 .25 L
.87917 .25 L
.87918 .25 L
.87918 .25 L
.87919 .25 L
.8792 .25 L
.8792 .25 L
.87921 .25 L
Mistroke
.87921 .25 L
.87922 .25 L
.87922 .25 L
.87923 .25 L
.87924 .25 L
.87924 .25 L
.87925 .25 L
.87926 .25 L
.87926 .25 L
.87927 .25 L
.87927 .25 L
.87928 .25 L
.87929 .25 L
.87929 .25 L
.8793 .25 L
.87931 .25 L
.87931 .25 L
.87932 .25 L
.87932 .25 L
.87933 .25 L
.87933 .25 L
.87934 .25 L
.87935 .25 L
.87935 .25 L
.87936 .25 L
.87936 .25 L
.87937 .25 L
.87937 .25 L
.87938 .25 L
.87939 .25 L
.87939 .25 L
.8794 .25 L
.87941 .25 L
.87941 .25 L
.87942 .25 L
.87942 .25 L
.87943 .25 L
.87943 .25 L
.87944 .25 L
.87945 .25 L
.87945 .25 L
.87946 .25 L
.87946 .25 L
.87947 .25 L
.87948 .25 L
.87948 .25 L
.87949 .25 L
.8795 .25 L
.8795 .25 L
.87951 .25 L
Mistroke
.87952 .25 L
.87952 .25 L
.87952 .25 L
.87953 .25 L
.87954 .25 L
.87954 .25 L
.87955 .25 L
.87955 .25 L
.87956 .25 L
.87957 .25 L
.87957 .25 L
.87958 .25 L
.87958 .25 L
.87959 .25 L
.8796 .25 L
.8796 .25 L
.87961 .25 L
.87961 .25 L
.87962 .25 L
.87962 .25 L
.87963 .25 L
.87963 .25 L
.87964 .25 L
.87964 .25 L
.87965 .25 L
.87965 .25 L
.87966 .25 L
.87967 .25 L
.87967 .25 L
.87968 .25 L
.87969 .25 L
.87969 .25 L
.8797 .25 L
.8797 .25 L
.87971 .25 L
.87971 .25 L
.87971 .25 L
.87972 .25 L
.87973 .25 L
.87973 .25 L
.87974 .25 L
.87975 .25 L
.87975 .25 L
.87976 .25 L
.87976 .25 L
.87977 .25 L
.87977 .25 L
.87978 .25 L
.87979 .25 L
.87979 .25 L
Mistroke
.8798 .25 L
.87981 .25 L
.87981 .25 L
.87982 .25 L
.87983 .25 L
.87983 .25 L
.87984 .25 L
.87984 .25 L
.87985 .25 L
.87985 .25 L
.87986 .25 L
.87986 .25 L
.87987 .25 L
.87987 .25 L
.87988 .25 L
.87989 .25 L
.87989 .25 L
.8799 .25 L
.8799 .25 L
.87991 .25 L
.87992 .25 L
.87992 .25 L
.87993 .25 L
.87994 .25 L
.87994 .25 L
.87995 .25 L
.87996 .25 L
.87996 .25 L
.87997 .25 L
.87997 .25 L
.87998 .25 L
.87998 .25 L
.87999 .25 L
.87999 .25 L
.88 .25 L
.88 .25 L
.88 .25 L
.88001 .25 L
.88001 .25 L
.88002 .25 L
.88002 .25 L
.88003 .25 L
.88003 .25 L
.88003 .25 L
.88004 .25 L
.88004 .25 L
.88005 .25 L
.88005 .25 L
.88006 .25 L
.88007 .25 L
Mistroke
.88007 .25 L
.88008 .25 L
.88009 .25 L
.88009 .25 L
.8801 .25 L
.8801 .25 L
.88011 .25 L
.88012 .25 L
.88012 .25 L
.88013 .25 L
.88014 .25 L
.88014 .25 L
.88014 .25 L
.88015 .25 L
.88016 .25 L
.88016 .25 L
.88017 .25 L
.88018 .25 L
.88018 .25 L
.88019 .25 L
.88019 .25 L
.8802 .25 L
.88021 .25 L
.88021 .25 L
.88022 .25 L
.88022 .25 L
.88023 .25 L
.88024 .25 L
.88024 .25 L
.88024 .25 L
.88025 .25 L
.88026 .25 L
.88026 .25 L
.88027 .25 L
.88028 .25 L
.88028 .25 L
.88029 .25 L
.88029 .25 L
.8803 .25 L
.88031 .25 L
.88031 .25 L
.88032 .25 L
.88033 .25 L
.88033 .25 L
.88034 .25 L
.88034 .25 L
.88035 .25 L
.88035 .25 L
.88036 .25 L
.88037 .25 L
Mistroke
.88037 .25 L
.88038 .25 L
.88039 .25 L
.88039 .25 L
.8804 .25 L
.8804 .25 L
.88041 .25 L
.88041 .25 L
.88042 .25 L
.88043 .25 L
.88043 .25 L
.88044 .25 L
.88044 .25 L
.88045 .25 L
.88045 .25 L
.88046 .25 L
.88047 .25 L
.88047 .25 L
.88047 .25 L
.88048 .25 L
.88049 .25 L
.88049 .25 L
.8805 .25 L
.8805 .25 L
.88051 .25 L
.88052 .25 L
.88052 .25 L
.88052 .25 L
.88053 .25 L
.88053 .25 L
.88054 .25 L
.88054 .25 L
.88055 .25 L
.88056 .25 L
.88056 .25 L
.88057 .25 L
.88058 .25 L
.88058 .25 L
.88059 .25 L
.88059 .25 L
.8806 .25 L
.88061 .25 L
.88061 .25 L
.88062 .25 L
.88062 .25 L
.88063 .25 L
.88064 .25 L
.88064 .25 L
.88065 .25 L
.88066 .25 L
Mistroke
.88066 .25 L
.88067 .25 L
.88068 .25 L
.88068 .25 L
.88068 .25 L
.88069 .25 L
.88069 .25 L
.8807 .25 L
.8807 .25 L
.88071 .25 L
.88072 .25 L
.88072 .25 L
.88073 .25 L
.88073 .25 L
.88074 .25 L
.88075 .25 L
.88075 .25 L
.88076 .25 L
.88077 .25 L
.88077 .25 L
.88078 .25 L
.88079 .25 L
.88079 .25 L
.8808 .25 L
.8808 .25 L
.88081 .25 L
.88081 .25 L
.88082 .25 L
.88082 .25 L
.88082 .25 L
.88083 .25 L
.88083 .25 L
.88084 .25 L
.88084 .25 L
.88085 .25 L
.88085 .25 L
.88085 .25 L
.88086 .25 L
.88086 .25 L
.88086 .25 L
.88087 .25 L
.88088 .25 L
.88088 .25 L
.88089 .25 L
.8809 .25 L
.8809 .25 L
.88091 .25 L
.88092 .25 L
.88092 .25 L
.88093 .25 L
Mistroke
.88093 .25 L
.88094 .25 L
.88095 .25 L
.88095 .25 L
.88096 .25 L
.88097 .25 L
.88097 .25 L
.88098 .25 L
.88098 .25 L
.88099 .25 L
.88099 .25 L
.881 .25 L
.88101 .25 L
.88101 .25 L
.88102 .25 L
.88102 .25 L
.88103 .25 L
.88104 .25 L
.88104 .25 L
.88105 .25 L
.88105 .25 L
.88106 .25 L
.88106 .25 L
.88107 .25 L
.88107 .25 L
.88108 .25 L
.88109 .25 L
.88109 .25 L
.8811 .25 L
.88111 .25 L
.88111 .25 L
.88112 .25 L
.88112 .25 L
.88113 .25 L
.88114 .25 L
.88114 .25 L
.88115 .25 L
.88116 .25 L
.88116 .25 L
.88117 .25 L
.88117 .25 L
.88118 .25 L
.88118 .25 L
.88119 .25 L
.8812 .25 L
.8812 .25 L
.88121 .25 L
.88121 .25 L
.88122 .25 L
.88123 .25 L
Mistroke
.88123 .25 L
.88124 .25 L
.88124 .25 L
.88125 .25 L
.88126 .25 L
.88126 .25 L
.88127 .25 L
.88127 .25 L
.88128 .25 L
.88128 .25 L
.88129 .25 L
.88129 .25 L
.8813 .25 L
.8813 .25 L
.88131 .25 L
.88131 .25 L
.88132 .25 L
.88133 .25 L
.88133 .25 L
.88134 .25 L
.88134 .25 L
.88135 .25 L
.88135 .25 L
.88136 .25 L
.88136 .25 L
.88137 .25 L
.88137 .25 L
.88138 .25 L
.88139 .25 L
.88139 .25 L
.8814 .25 L
.8814 .25 L
.88141 .25 L
.88142 .25 L
.88142 .25 L
.88143 .25 L
.88143 .25 L
.88144 .25 L
.88145 .25 L
.88145 .25 L
.88146 .25 L
.88147 .25 L
.88147 .25 L
.88148 .25 L
.88149 .25 L
.88149 .25 L
.8815 .25 L
.8815 .25 L
.88151 .25 L
.88151 .25 L
Mistroke
.88151 .25 L
.88152 .25 L
.88153 .25 L
.88153 .25 L
.88154 .25 L
.88155 .25 L
.88155 .25 L
.88156 .25 L
.88156 .25 L
.88157 .25 L
.88158 .25 L
.88158 .25 L
.88159 .25 L
.8816 .25 L
.8816 .25 L
.88161 .25 L
.88162 .25 L
.88162 .25 L
.88163 .25 L
.88163 .25 L
.88164 .25 L
.88164 .25 L
.88164 .25 L
.88165 .25 L
.88165 .25 L
.88166 .25 L
.88166 .25 L
.88167 .25 L
.88167 .25 L
.88167 .25 L
.88168 .25 L
.88168 .25 L
.88168 .25 L
.88169 .25 L
.88169 .25 L
.8817 .25 L
.88171 .25 L
.88171 .25 L
.88172 .25 L
.88173 .25 L
.88173 .25 L
.88174 .25 L
.88175 .25 L
.88175 .25 L
.88176 .25 L
.88177 .25 L
.88177 .25 L
.88178 .25 L
.88178 .25 L
.88179 .25 L
Mistroke
.88179 .25 L
.8818 .25 L
.88181 .25 L
.88181 .25 L
.88182 .25 L
.88182 .25 L
.88183 .25 L
.88184 .25 L
.88184 .25 L
.88185 .25 L
.88185 .25 L
.88186 .25 L
.88187 .25 L
.88187 .25 L
.88188 .25 L
.88188 .25 L
.88189 .25 L
.88189 .25 L
.8819 .25 L
.8819 .25 L
.88191 .25 L
.88192 .25 L
.88192 .25 L
.88193 .25 L
.88194 .25 L
.88194 .25 L
.88195 .25 L
.88195 .25 L
.88196 .25 L
.88197 .25 L
.88197 .25 L
.88198 .25 L
.88199 .25 L
.88199 .25 L
.88199 .25 L
.882 .25 L
.88201 .25 L
.88201 .25 L
.88202 .25 L
.88203 .25 L
.88203 .25 L
.88204 .25 L
.88204 .25 L
.88205 .25 L
.88206 .25 L
.88206 .25 L
.88207 .25 L
.88207 .25 L
.88208 .25 L
.88209 .25 L
Mistroke
.88209 .25 L
.88209 .25 L
.8821 .25 L
.88211 .25 L
.88211 .25 L
.88212 .25 L
.88212 .25 L
.88213 .25 L
.88213 .25 L
.88214 .25 L
.88214 .25 L
.88215 .25 L
.88216 .25 L
.88216 .25 L
.88217 .25 L
.88217 .25 L
.88218 .25 L
.88218 .25 L
.88218 .25 L
.88219 .25 L
.8822 .25 L
.8822 .25 L
.88221 .25 L
.88222 .25 L
.88222 .25 L
.88223 .25 L
.88223 .25 L
.88224 .25 L
.88225 .25 L
.88225 .25 L
.88226 .25 L
.88227 .25 L
.88227 .25 L
.88228 .25 L
.88228 .25 L
.88229 .25 L
.8823 .25 L
.8823 .25 L
.88231 .25 L
.88232 .25 L
.88232 .25 L
.88233 .25 L
.88233 .25 L
.88233 .25 L
.88234 .25 L
.88234 .25 L
.88235 .25 L
.88236 .25 L
.88236 .25 L
.88237 .25 L
Mistroke
.88238 .25 L
.88238 .25 L
.88239 .25 L
.88239 .25 L
.8824 .25 L
.88241 .25 L
.88241 .25 L
.88242 .25 L
.88243 .25 L
.88243 .25 L
.88244 .25 L
.88245 .25 L
.88245 .25 L
.88245 .25 L
.88246 .25 L
.88246 .25 L
.88247 .25 L
.88247 .25 L
.88247 .25 L
.88248 .25 L
.88249 .25 L
.88249 .25 L
.88249 .25 L
.8825 .25 L
.8825 .25 L
.8825 .25 L
.88251 .25 L
.88251 .25 L
.88252 .25 L
.88253 .25 L
.88253 .25 L
.88254 .25 L
.88255 .25 L
.88255 .25 L
.88256 .25 L
.88256 .25 L
.88257 .25 L
.88258 .25 L
.88258 .25 L
.88259 .25 L
.88259 .25 L
.8826 .25 L
.88261 .25 L
.88261 .25 L
.88262 .25 L
.88262 .25 L
.88263 .25 L
.88263 .25 L
.88264 .25 L
.88265 .25 L
Mistroke
.88265 .25 L
.88266 .25 L
.88266 .25 L
.88267 .25 L
.88268 .25 L
.88268 .25 L
.88269 .25 L
.88269 .25 L
.8827 .25 L
.88271 .25 L
.88271 .25 L
.88271 .25 L
.88272 .25 L
.88273 .25 L
.88273 .25 L
.88274 .25 L
.88275 .25 L
.88275 .25 L
.88276 .25 L
.88277 .25 L
.88277 .25 L
.88278 .25 L
.88278 .25 L
.88279 .25 L
.8828 .25 L
.8828 .25 L
.88281 .25 L
.88281 .25 L
.88282 .25 L
.88283 .25 L
.88283 .25 L
.88284 .25 L
.88284 .25 L
.88285 .25 L
.88286 .25 L
.88286 .25 L
.88287 .25 L
.88287 .25 L
.88288 .25 L
.88288 .25 L
.88289 .25 L
.8829 .25 L
.8829 .25 L
.88291 .25 L
.88291 .25 L
.88292 .25 L
.88292 .25 L
.88293 .25 L
.88294 .25 L
.88294 .25 L
Mistroke
.88295 .25 L
.88296 .25 L
.88296 .25 L
.88297 .25 L
.88297 .25 L
.88298 .25 L
.88299 .25 L
.88299 .25 L
.883 .25 L
.88301 .25 L
.88301 .25 L
.88302 .25 L
.88302 .25 L
.88303 .25 L
.88303 .25 L
.88304 .25 L
.88305 .25 L
.88305 .25 L
.88306 .25 L
.88306 .25 L
.88307 .25 L
.88308 .25 L
.88308 .25 L
.88309 .25 L
.88309 .25 L
.8831 .25 L
.88311 .25 L
.88311 .25 L
.88312 .25 L
.88312 .25 L
.88313 .25 L
.88313 .25 L
.88314 .25 L
.88314 .25 L
.88315 .25 L
.88315 .25 L
.88316 .25 L
.88316 .25 L
.88317 .25 L
.88318 .25 L
.88318 .25 L
.88319 .25 L
.88319 .25 L
.8832 .25 L
.8832 .25 L
.88321 .25 L
.88321 .25 L
.88322 .25 L
.88322 .25 L
.88323 .25 L
Mistroke
.88324 .25 L
.88324 .25 L
.88325 .25 L
.88325 .25 L
.88326 .25 L
.88327 .25 L
.88327 .25 L
.88328 .25 L
.88328 .25 L
.88329 .25 L
.8833 .25 L
.8833 .25 L
.88331 .25 L
.88332 .25 L
.88332 .25 L
.88333 .25 L
.88334 .25 L
.88334 .25 L
.88335 .25 L
.88335 .25 L
.88336 .25 L
.88336 .25 L
.88336 .25 L
.88337 .25 L
.88338 .25 L
.88338 .25 L
.88339 .25 L
.8834 .25 L
.8834 .25 L
.88341 .25 L
.88341 .25 L
.88342 .25 L
.88343 .25 L
.88343 .25 L
.88344 .25 L
.88345 .25 L
.88345 .25 L
.88346 .25 L
.88347 .25 L
.88347 .25 L
.88348 .25 L
.88348 .25 L
.88349 .25 L
.88349 .25 L
.88349 .25 L
.8835 .25 L
.8835 .25 L
.88351 .25 L
.88351 .25 L
.88352 .25 L
Mistroke
.88352 .25 L
.88352 .25 L
.88353 .25 L
.88353 .25 L
.88353 .25 L
.88354 .25 L
.88354 .25 L
.88355 .25 L
.88356 .25 L
.88356 .25 L
.88357 .25 L
.88358 .25 L
.88358 .25 L
.88359 .25 L
.8836 .25 L
.8836 .25 L
.88361 .25 L
.88362 .25 L
.88362 .25 L
.88363 .25 L
.88363 .25 L
.88364 .25 L
.88364 .25 L
.88365 .25 L
.88366 .25 L
.88366 .25 L
.88367 .25 L
.88367 .25 L
.88368 .25 L
.88369 .25 L
.88369 .25 L
.8837 .25 L
.8837 .25 L
.88371 .25 L
.88372 .25 L
.88372 .25 L
.88373 .25 L
.88373 .25 L
.88374 .25 L
.88374 .25 L
.88375 .25 L
.88375 .25 L
.88376 .25 L
.88377 .25 L
.88377 .25 L
.88378 .25 L
.88379 .25 L
.88379 .25 L
.8838 .25 L
.8838 .25 L
Mistroke
.88381 .25 L
.88382 .25 L
.88382 .25 L
.88383 .25 L
.88384 .25 L
.88384 .25 L
.88384 .25 L
.88385 .25 L
.88386 .25 L
.88386 .25 L
.88387 .25 L
.88388 .25 L
.88388 .25 L
.88389 .25 L
.88389 .25 L
.8839 .25 L
.88391 .25 L
.88391 .25 L
.88392 .25 L
.88392 .25 L
.88393 .25 L
.88394 .25 L
.88394 .25 L
.88394 .25 L
.88395 .25 L
.88396 .25 L
.88396 .25 L
.88397 .25 L
.88397 .25 L
.88398 .25 L
.88398 .25 L
.88399 .25 L
.88399 .25 L
.884 .25 L
.88401 .25 L
.88401 .25 L
.88402 .25 L
.88402 .25 L
.88403 .25 L
.88403 .25 L
.88404 .25 L
.88404 .25 L
.88405 .25 L
.88406 .25 L
.88406 .25 L
.88407 .25 L
.88407 .25 L
.88408 .25 L
.88408 .25 L
.88409 .25 L
Mistroke
.8841 .25 L
.8841 .25 L
.88411 .25 L
.88412 .25 L
.88412 .25 L
.88413 .25 L
.88413 .25 L
.88414 .25 L
.88415 .25 L
.88415 .25 L
.88416 .25 L
.88417 .25 L
.88417 .25 L
.88418 .25 L
.88418 .25 L
.88418 .25 L
.88419 .25 L
.88419 .25 L
.8842 .25 L
.88421 .25 L
.88421 .25 L
.88422 .25 L
.88423 .25 L
.88423 .25 L
.88424 .25 L
.88424 .25 L
.88425 .25 L
.88426 .25 L
.88426 .25 L
.88427 .25 L
.88428 .25 L
.88428 .25 L
.88429 .25 L
.8843 .25 L
.8843 .25 L
.8843 .25 L
.88431 .25 L
.88431 .25 L
.88432 .25 L
.88432 .25 L
.88433 .25 L
.88433 .25 L
.88434 .25 L
.88434 .25 L
.88434 .25 L
.88435 .25 L
.88435 .25 L
.88436 .25 L
.88436 .25 L
.88436 .25 L
Mistroke
.88437 .25 L
.88438 .25 L
.88438 .25 L
.88439 .25 L
.8844 .25 L
.8844 .25 L
.88441 .25 L
.88441 .25 L
.88442 .25 L
.88443 .25 L
.88443 .25 L
.88444 .25 L
.88445 .25 L
.88445 .25 L
.88446 .25 L
.88446 .25 L
.88447 .25 L
.88447 .25 L
.88448 .25 L
.88449 .25 L
.88449 .25 L
.8845 .25 L
.8845 .25 L
.88451 .25 L
.88452 .25 L
.88452 .25 L
.88453 .25 L
.88453 .25 L
.88454 .25 L
.88455 .25 L
.88455 .25 L
.88456 .25 L
.88456 .25 L
.88456 .25 L
.88457 .25 L
.88458 .25 L
.88458 .25 L
.88459 .25 L
.8846 .25 L
.8846 .25 L
.88461 .25 L
.88462 .25 L
.88462 .25 L
.88463 .25 L
.88463 .25 L
.88464 .25 L
.88465 .25 L
.88465 .25 L
.88466 .25 L
.88467 .25 L
Mistroke
.88467 .25 L
.88468 .25 L
.88468 .25 L
.88469 .25 L
.88469 .25 L
.8847 .25 L
.88471 .25 L
.88471 .25 L
.88472 .25 L
.88472 .25 L
.88473 .25 L
.88474 .25 L
.88474 .25 L
.88475 .25 L
.88475 .25 L
.88476 .25 L
.88476 .25 L
.88477 .25 L
.88477 .25 L
.88478 .25 L
.88479 .25 L
.88479 .25 L
.88479 .25 L
.8848 .25 L
.88481 .25 L
.88481 .25 L
.88482 .25 L
.88482 .25 L
.88483 .25 L
.88484 .25 L
.88484 .25 L
.88484 .25 L
.88485 .25 L
.88486 .25 L
.88486 .25 L
.88487 .25 L
.88487 .25 L
.88488 .25 L
.88489 .25 L
.88489 .25 L
.8849 .25 L
.8849 .25 L
.88491 .25 L
.88491 .25 L
.88492 .25 L
.88493 .25 L
.88493 .25 L
.88494 .25 L
.88495 .25 L
.88495 .25 L
Mistroke
.88496 .25 L
.88496 .25 L
.88497 .25 L
.88498 .25 L
.88498 .25 L
.88499 .25 L
.885 .25 L
.885 .25 L
.885 .25 L
.88501 .25 L
.88501 .25 L
.88502 .25 L
.88502 .25 L
.88503 .25 L
.88504 .25 L
.88504 .25 L
.88505 .25 L
.88506 .25 L
.88506 .25 L
.88507 .25 L
.88507 .25 L
.88508 .25 L
.88509 .25 L
.88509 .25 L
.8851 .25 L
.88511 .25 L
.88511 .25 L
.88512 .25 L
.88512 .25 L
.88513 .25 L
.88513 .25 L
.88514 .25 L
.88514 .25 L
.88515 .25 L
.88515 .25 L
.88516 .25 L
.88516 .25 L
.88516 .25 L
.88517 .25 L
.88517 .25 L
.88518 .25 L
.88518 .25 L
.88518 .25 L
.88519 .25 L
.88519 .25 L
.8852 .25 L
.88521 .25 L
.88521 .25 L
.88522 .25 L
.88523 .25 L
Mistroke
.88523 .25 L
.88524 .25 L
.88524 .25 L
.88525 .25 L
.88526 .25 L
.88526 .25 L
.88527 .25 L
.88528 .25 L
.88528 .25 L
.88529 .25 L
.88529 .25 L
.8853 .25 L
.8853 .25 L
.88531 .25 L
.88532 .25 L
.88532 .25 L
.88533 .25 L
.88533 .25 L
.88534 .25 L
.88534 .25 L
.88535 .25 L
.88536 .25 L
.88536 .25 L
.88537 .25 L
.88537 .25 L
.88538 .25 L
.88539 .25 L
.88539 .25 L
.88539 .25 L
.8854 .25 L
.88541 .25 L
.88541 .25 L
.88542 .25 L
.88543 .25 L
.88543 .25 L
.88544 .25 L
.88545 .25 L
.88545 .25 L
.88546 .25 L
.88547 .25 L
.88547 .25 L
.88548 .25 L
.88548 .25 L
.88549 .25 L
.88549 .25 L
.8855 .25 L
.88551 .25 L
.88551 .25 L
.88552 .25 L
.88552 .25 L
Mistroke
.88553 .25 L
.88554 .25 L
.88554 .25 L
.88555 .25 L
.88555 .25 L
.88556 .25 L
.88557 .25 L
.88557 .25 L
.88558 .25 L
.88558 .25 L
.88559 .25 L
.88559 .25 L
.8856 .25 L
.8856 .25 L
.88561 .25 L
.88561 .25 L
.88562 .25 L
.88562 .25 L
.88563 .25 L
.88564 .25 L
.88564 .25 L
.88565 .25 L
.88565 .25 L
.88566 .25 L
.88566 .25 L
.88567 .25 L
.88568 .25 L
.88568 .25 L
.88568 .25 L
.88569 .25 L
.8857 .25 L
.8857 .25 L
.88571 .25 L
.88571 .25 L
.88572 .25 L
.88573 .25 L
.88573 .25 L
.88574 .25 L
.88574 .25 L
.88575 .25 L
.88576 .25 L
.88576 .25 L
.88577 .25 L
.88577 .25 L
.88578 .25 L
.88579 .25 L
.88579 .25 L
.8858 .25 L
.88581 .25 L
.88581 .25 L
Mistroke
.88582 .25 L
.88582 .25 L
.88583 .25 L
.88583 .25 L
.88583 .25 L
.88584 .25 L
.88585 .25 L
.88585 .25 L
.88586 .25 L
.88587 .25 L
.88587 .25 L
.88588 .25 L
.88589 .25 L
.88589 .25 L
.8859 .25 L
.8859 .25 L
.88591 .25 L
.88592 .25 L
.88592 .25 L
.88593 .25 L
.88594 .25 L
.88594 .25 L
.88595 .25 L
.88595 .25 L
.88596 .25 L
.88596 .25 L
.88597 .25 L
.88597 .25 L
.88597 .25 L
.88598 .25 L
.88598 .25 L
.88599 .25 L
.88599 .25 L
.88599 .25 L
.886 .25 L
.886 .25 L
.88601 .25 L
.88601 .25 L
.88602 .25 L
.88602 .25 L
.88603 .25 L
.88604 .25 L
.88604 .25 L
.88605 .25 L
.88606 .25 L
.88606 .25 L
.88607 .25 L
.88607 .25 L
.88608 .25 L
.88609 .25 L
Mistroke
.88609 .25 L
.8861 .25 L
.88611 .25 L
.88611 .25 L
.88611 .25 L
.88612 .25 L
.88613 .25 L
.88613 .25 L
.88614 .25 L
.88615 .25 L
.88615 .25 L
.88616 .25 L
.88616 .25 L
.88617 .25 L
.88617 .25 L
.88618 .25 L
.88619 .25 L
.88619 .25 L
.8862 .25 L
.8862 .25 L
.88621 .25 L
.88621 .25 L
.88622 .25 L
.88622 .25 L
.88623 .25 L
.88624 .25 L
.88625 .25 L
.88625 .25 L
.88626 .25 L
.88626 .25 L
.88627 .25 L
.88628 .25 L
.88628 .25 L
.88629 .25 L
.88629 .25 L
.8863 .25 L
.88631 .25 L
.88631 .25 L
.88632 .25 L
.88632 .25 L
.88633 .25 L
.88634 .25 L
.88634 .25 L
.88635 .25 L
.88635 .25 L
.88636 .25 L
.88636 .25 L
.88637 .25 L
.88638 .25 L
.88638 .25 L
Mistroke
.88639 .25 L
.8864 .25 L
.8864 .25 L
.88641 .25 L
.88641 .25 L
.88641 .25 L
.88642 .25 L
.88643 .25 L
.88643 .25 L
.88644 .25 L
.88645 .25 L
.88645 .25 L
.88646 .25 L
.88647 .25 L
.88647 .25 L
.88648 .25 L
.88648 .25 L
.88649 .25 L
.8865 .25 L
.8865 .25 L
.88651 .25 L
.88651 .25 L
.88652 .25 L
.88653 .25 L
.88653 .25 L
.88654 .25 L
.88654 .25 L
.88655 .25 L
.88656 .25 L
.88656 .25 L
.88657 .25 L
.88657 .25 L
.88658 .25 L
.88659 .25 L
.88659 .25 L
.8866 .25 L
.8866 .25 L
.88661 .25 L
.88661 .25 L
.88662 .25 L
.88662 .25 L
.88663 .25 L
.88664 .25 L
.88664 .25 L
.88664 .25 L
.88665 .25 L
.88666 .25 L
.88666 .25 L
.88667 .25 L
.88667 .25 L
Mistroke
.88668 .25 L
.88669 .25 L
.88669 .25 L
.88669 .25 L
.8867 .25 L
.88671 .25 L
.88671 .25 L
.88672 .25 L
.88672 .25 L
.88673 .25 L
.88673 .25 L
.88674 .25 L
.88675 .25 L
.88675 .25 L
.88676 .25 L
.88676 .25 L
.88677 .25 L
.88678 .25 L
.88678 .25 L
.88679 .25 L
.8868 .25 L
.8868 .25 L
.88681 .25 L
.88681 .25 L
.88682 .25 L
.88683 .25 L
.88683 .25 L
.88684 .25 L
.88685 .25 L
.88685 .25 L
.88685 .25 L
.88686 .25 L
.88686 .25 L
.88687 .25 L
.88687 .25 L
.88688 .25 L
.88689 .25 L
.88689 .25 L
.8869 .25 L
.88691 .25 L
.88691 .25 L
.88692 .25 L
.88692 .25 L
.88693 .25 L
.88694 .25 L
.88694 .25 L
.88695 .25 L
.88696 .25 L
.88696 .25 L
.88697 .25 L
Mistroke
.88697 .25 L
.88698 .25 L
.88698 .25 L
.88699 .25 L
.88699 .25 L
.887 .25 L
.887 .25 L
.88701 .25 L
.88701 .25 L
.88701 .25 L
.88702 .25 L
.88702 .25 L
.88703 .25 L
.88703 .25 L
.88703 .25 L
.88704 .25 L
.88704 .25 L
.88705 .25 L
.88706 .25 L
.88706 .25 L
.88707 .25 L
.88708 .25 L
.88708 .25 L
.88709 .25 L
.88709 .25 L
.8871 .25 L
.88711 .25 L
.88711 .25 L
.88712 .25 L
.88713 .25 L
.88713 .25 L
.88714 .25 L
.88714 .25 L
.88715 .25 L
.88715 .25 L
.88716 .25 L
.88717 .25 L
.88717 .25 L
.88718 .25 L
.88718 .25 L
.88719 .25 L
.88719 .25 L
.8872 .25 L
.88721 .25 L
.88721 .25 L
.88722 .25 L
.88723 .25 L
.88723 .25 L
.88724 .25 L
.88724 .25 L
Mistroke
.88725 .25 L
.88725 .25 L
.88726 .25 L
.88727 .25 L
.88727 .25 L
.88728 .25 L
.88728 .25 L
.88729 .25 L
.8873 .25 L
.8873 .25 L
.88731 .25 L
.88732 .25 L
.88732 .25 L
.88733 .25 L
.88734 .25 L
.88734 .25 L
.88734 .25 L
.88735 .25 L
.88736 .25 L
.88736 .25 L
.88737 .25 L
.88737 .25 L
.88738 .25 L
.88739 .25 L
.88739 .25 L
.8874 .25 L
.8874 .25 L
.88741 .25 L
.88742 .25 L
.88742 .25 L
.88743 .25 L
.88743 .25 L
.88744 .25 L
.88744 .25 L
.88745 .25 L
.88745 .25 L
.88746 .25 L
.88746 .25 L
.88747 .25 L
.88747 .25 L
.88748 .25 L
.88749 .25 L
.88749 .25 L
.8875 .25 L
.8875 .25 L
.88751 .25 L
.88752 .25 L
.88752 .25 L
.88753 .25 L
.88753 .25 L
Mistroke
.88753 .25 L
.88754 .25 L
.88755 .25 L
.88755 .25 L
.88756 .25 L
.88756 .25 L
.88757 .25 L
.88758 .25 L
.88758 .25 L
.88759 .25 L
.88759 .25 L
.8876 .25 L
.88761 .25 L
.88761 .25 L
.88762 .25 L
.88763 .25 L
.88763 .25 L
.88764 .25 L
.88764 .25 L
.88765 .25 L
.88766 .25 L
.88766 .25 L
.88767 .25 L
.88767 .25 L
.88768 .25 L
.88768 .25 L
.88769 .25 L
.88769 .25 L
.8877 .25 L
.8877 .25 L
.88771 .25 L
.88772 .25 L
.88772 .25 L
.88773 .25 L
.88774 .25 L
.88774 .25 L
.88775 .25 L
.88776 .25 L
.88776 .25 L
.88777 .25 L
.88777 .25 L
.88778 .25 L
.88779 .25 L
.88779 .25 L
.8878 .25 L
.8878 .25 L
.88781 .25 L
.88781 .25 L
.88782 .25 L
.88782 .25 L
Mistroke
.88782 .25 L
.88783 .25 L
.88783 .25 L
.88784 .25 L
.88784 .25 L
.88785 .25 L
.88785 .25 L
.88785 .25 L
.88786 .25 L
.88786 .25 L
.88787 .25 L
.88787 .25 L
.88788 .25 L
.88789 .25 L
.88789 .25 L
.8879 .25 L
.88791 .25 L
.88791 .25 L
.88792 .25 L
.88792 .25 L
.88793 .25 L
.88794 .25 L
.88794 .25 L
.88795 .25 L
.88796 .25 L
.88796 .25 L
.88796 .25 L
.88797 .25 L
.88798 .25 L
.88798 .25 L
.88799 .25 L
.888 .25 L
.888 .25 L
.88801 .25 L
.88801 .25 L
.88802 .25 L
.88802 .25 L
.88803 .25 L
.88804 .25 L
.88804 .25 L
.88805 .25 L
.88806 .25 L
.88806 .25 L
.88806 .25 L
.88807 .25 L
.88808 .25 L
.88808 .25 L
.88809 .25 L
.8881 .25 L
.8881 .25 L
Mistroke
.88811 .25 L
.88811 .25 L
.88812 .25 L
.88813 .25 L
.88813 .25 L
.88814 .25 L
.88815 .25 L
.88815 .25 L
.88816 .25 L
.88816 .25 L
.88817 .25 L
.88817 .25 L
.88818 .25 L
.88819 .25 L
.88819 .25 L
.8882 .25 L
.8882 .25 L
.88821 .25 L
.88822 .25 L
.88822 .25 L
.88823 .25 L
.88823 .25 L
.88824 .25 L
.88825 .25 L
.88825 .25 L
.88826 .25 L
.88826 .25 L
.88827 .25 L
.88827 .25 L
.88828 .25 L
.88828 .25 L
.88829 .25 L
.88829 .25 L
.8883 .25 L
.8883 .25 L
.88831 .25 L
.88832 .25 L
.88832 .25 L
.88833 .25 L
.88834 .25 L
.88834 .25 L
.88834 .25 L
.88835 .25 L
.88835 .25 L
.88836 .25 L
.88836 .25 L
.88837 .25 L
.88838 .25 L
.88838 .25 L
.88839 .25 L
Mistroke
.88839 .25 L
.8884 .25 L
.88841 .25 L
.88841 .25 L
.88842 .25 L
.88842 .25 L
.88843 .25 L
.88844 .25 L
.88844 .25 L
.88845 .25 L
.88846 .25 L
.88846 .25 L
.88847 .25 L
.88847 .25 L
.88848 .25 L
.88849 .25 L
.88849 .25 L
.8885 .25 L
.8885 .25 L
.88851 .25 L
.88851 .25 L
.88852 .25 L
.88852 .25 L
.88853 .25 L
.88854 .25 L
.88854 .25 L
.88855 .25 L
.88855 .25 L
.88856 .25 L
.88857 .25 L
.88857 .25 L
.88858 .25 L
.88859 .25 L
.88859 .25 L
.8886 .25 L
.88861 .25 L
.88861 .25 L
.88862 .25 L
.88862 .25 L
.88863 .25 L
.88863 .25 L
.88864 .25 L
.88864 .25 L
.88864 .25 L
.88865 .25 L
.88865 .25 L
.88866 .25 L
.88866 .25 L
.88867 .25 L
.88867 .25 L
Mistroke
.88867 .25 L
.88868 .25 L
.88868 .25 L
.88868 .25 L
.88869 .25 L
.8887 .25 L
.8887 .25 L
.88871 .25 L
.88872 .25 L
.88872 .25 L
.88873 .25 L
.88874 .25 L
.88874 .25 L
.88875 .25 L
.88875 .25 L
.88876 .25 L
.88877 .25 L
.88877 .25 L
.88878 .25 L
.88878 .25 L
.88879 .25 L
.8888 .25 L
.8888 .25 L
.88881 .25 L
.88881 .25 L
.88882 .25 L
.88883 .25 L
.88883 .25 L
.88884 .25 L
.88884 .25 L
.88885 .25 L
.88885 .25 L
.88886 .25 L
.88887 .25 L
.88887 .25 L
.88888 .25 L
.88888 .25 L
.88889 .25 L
.88889 .25 L
.8889 .25 L
.88891 .25 L
.88891 .25 L
.88892 .25 L
.88893 .25 L
.88893 .25 L
.88894 .25 L
.88894 .25 L
.88895 .25 L
.88896 .25 L
.88896 .25 L
Mistroke
.88897 .25 L
.88898 .25 L
.88898 .25 L
.88899 .25 L
.88899 .25 L
.889 .25 L
.889 .25 L
.88901 .25 L
.88902 .25 L
.88902 .25 L
.88903 .25 L
.88903 .25 L
.88904 .25 L
.88905 .25 L
.88905 .25 L
.88906 .25 L
.88906 .25 L
.88907 .25 L
.88908 .25 L
.88908 .25 L
.88909 .25 L
.88909 .25 L
.8891 .25 L
.8891 .25 L
.88911 .25 L
.88911 .25 L
.88912 .25 L
.88912 .25 L
.88913 .25 L
.88913 .25 L
.88914 .25 L
.88915 .25 L
.88915 .25 L
.88916 .25 L
.88916 .25 L
.88917 .25 L
.88917 .25 L
.88918 .25 L
.88918 .25 L
.88919 .25 L
.88919 .25 L
.8892 .25 L
.88921 .25 L
.88921 .25 L
.88922 .25 L
.88922 .25 L
.88923 .25 L
.88924 .25 L
.88924 .25 L
.88925 .25 L
Mistroke
.88925 .25 L
.88926 .25 L
.88927 .25 L
.88927 .25 L
.88928 .25 L
.88929 .25 L
.88929 .25 L
.8893 .25 L
.8893 .25 L
.88931 .25 L
.88932 .25 L
.88932 .25 L
.88933 .25 L
.88933 .25 L
.88933 .25 L
.88934 .25 L
.88935 .25 L
.88935 .25 L
.88936 .25 L
.88937 .25 L
.88937 .25 L
.88938 .25 L
.88938 .25 L
.88939 .25 L
.8894 .25 L
.8894 .25 L
.88941 .25 L
.88942 .25 L
.88942 .25 L
.88943 .25 L
.88943 .25 L
.88944 .25 L
.88945 .25 L
.88945 .25 L
.88946 .25 L
.88946 .25 L
.88946 .25 L
.88947 .25 L
.88947 .25 L
.88948 .25 L
.88948 .25 L
.88948 .25 L
.88949 .25 L
.88949 .25 L
.8895 .25 L
.8895 .25 L
.8895 .25 L
.88951 .25 L
.88951 .25 L
.88952 .25 L
Mistroke
.88953 .25 L
.88953 .25 L
.88954 .25 L
.88955 .25 L
.88955 .25 L
.88956 .25 L
.88957 .25 L
.88957 .25 L
.88958 .25 L
.88958 .25 L
.88959 .25 L
.8896 .25 L
.8896 .25 L
.88961 .25 L
.88961 .25 L
.88962 .25 L
.88963 .25 L
.88963 .25 L
.88964 .25 L
.88964 .25 L
.88965 .25 L
.88966 .25 L
.88966 .25 L
.88967 .25 L
.88967 .25 L
.88968 .25 L
.88968 .25 L
.88969 .25 L
.8897 .25 L
.8897 .25 L
.88971 .25 L
.88971 .25 L
.88972 .25 L
.88972 .25 L
.88973 .25 L
.88974 .25 L
.88974 .25 L
.88975 .25 L
.88976 .25 L
.88976 .25 L
.88977 .25 L
.88977 .25 L
.88978 .25 L
.88979 .25 L
.88979 .25 L
.8898 .25 L
.88981 .25 L
.88981 .25 L
.88981 .25 L
.88982 .25 L
Mistroke
.88983 .25 L
.88983 .25 L
.88984 .25 L
.88985 .25 L
.88985 .25 L
.88986 .25 L
.88986 .25 L
.88987 .25 L
.88987 .25 L
.88988 .25 L
.88989 .25 L
.88989 .25 L
.8899 .25 L
.88991 .25 L
.88991 .25 L
.88991 .25 L
.88992 .25 L
.88993 .25 L
.88993 .25 L
.88994 .25 L
.88994 .25 L
.88995 .25 L
.88995 .25 L
.88996 .25 L
.88996 .25 L
.88997 .25 L
.88998 .25 L
.88998 .25 L
.88999 .25 L
.88999 .25 L
.89 .25 L
.89 .25 L
.89 .25 L
.89001 .25 L
.89002 .25 L
.89002 .25 L
.89003 .25 L
.89004 .25 L
.89004 .25 L
.89005 .25 L
.89005 .25 L
.89006 .25 L
.89007 .25 L
.89007 .25 L
.89008 .25 L
.89008 .25 L
.89009 .25 L
.8901 .25 L
.8901 .25 L
.89011 .25 L
Mistroke
.89012 .25 L
.89012 .25 L
.89013 .25 L
.89014 .25 L
.89014 .25 L
.89014 .25 L
.89015 .25 L
.89015 .25 L
.89016 .25 L
.89016 .25 L
.89017 .25 L
.89018 .25 L
.89018 .25 L
.89019 .25 L
.89019 .25 L
.8902 .25 L
.89021 .25 L
.89021 .25 L
.89022 .25 L
.89023 .25 L
.89023 .25 L
.89024 .25 L
.89025 .25 L
.89025 .25 L
.89026 .25 L
.89027 .25 L
.89027 .25 L
.89027 .25 L
.89028 .25 L
.89028 .25 L
.89029 .25 L
.89029 .25 L
.89029 .25 L
.8903 .25 L
.8903 .25 L
.89031 .25 L
.89031 .25 L
.89032 .25 L
.89032 .25 L
.89032 .25 L
.89033 .25 L
.89033 .25 L
.89034 .25 L
.89034 .25 L
.89035 .25 L
.89036 .25 L
.89036 .25 L
.89037 .25 L
.89038 .25 L
.89038 .25 L
Mistroke
.89039 .25 L
.89039 .25 L
.8904 .25 L
.89041 .25 L
.89041 .25 L
.89042 .25 L
.89043 .25 L
.89043 .25 L
.89043 .25 L
.89044 .25 L
.89045 .25 L
.89045 .25 L
.89046 .25 L
.89047 .25 L
.89047 .25 L
.89048 .25 L
.89048 .25 L
.89049 .25 L
.8905 .25 L
.8905 .25 L
.89051 .25 L
.89051 .25 L
.89052 .25 L
.89053 .25 L
.89053 .25 L
.89053 .25 L
.89054 .25 L
.89055 .25 L
.89055 .25 L
.89056 .25 L
.89057 .25 L
.89057 .25 L
.89058 .25 L
.89058 .25 L
.89059 .25 L
.8906 .25 L
.8906 .25 L
.89061 .25 L
.89062 .25 L
.89062 .25 L
.89063 .25 L
.89063 .25 L
.89064 .25 L
.89064 .25 L
.89065 .25 L
.89066 .25 L
.89066 .25 L
.89067 .25 L
.89068 .25 L
.89068 .25 L
Mistroke
.89069 .25 L
.89069 .25 L
.8907 .25 L
.8907 .25 L
.89071 .25 L
.89072 .25 L
.89072 .25 L
.89073 .25 L
.89073 .25 L
.89074 .25 L
.89074 .25 L
.89075 .25 L
.89076 .25 L
.89076 .25 L
.89077 .25 L
.89078 .25 L
.89078 .25 L
.89079 .25 L
.89079 .25 L
.8908 .25 L
.89081 .25 L
.89081 .25 L
.89082 .25 L
.89083 .25 L
.89083 .25 L
.89084 .25 L
.89084 .25 L
.89085 .25 L
.89085 .25 L
.89086 .25 L
.89087 .25 L
.89087 .25 L
.89088 .25 L
.89088 .25 L
.89089 .25 L
.89089 .25 L
.8909 .25 L
.89091 .25 L
.89091 .25 L
.89092 .25 L
.89092 .25 L
.89093 .25 L
.89093 .25 L
.89094 .25 L
.89094 .25 L
.89095 .25 L
.89096 .25 L
.89096 .25 L
.89096 .25 L
.89097 .25 L
Mistroke
.89098 .25 L
.89098 .25 L
.89099 .25 L
.891 .25 L
.891 .25 L
.89101 .25 L
.89101 .25 L
.89102 .25 L
.89102 .25 L
.89103 .25 L
.89103 .25 L
.89104 .25 L
.89104 .25 L
.89105 .25 L
.89106 .25 L
.89106 .25 L
.89107 .25 L
.89107 .25 L
.89108 .25 L
.89108 .25 L
.89109 .25 L
.8911 .25 L
.8911 .25 L
.89111 .25 L
.89112 .25 L
.89112 .25 L
.89113 .25 L
.89113 .25 L
.89114 .25 L
.89115 .25 L
.89115 .25 L
.89116 .25 L
.89117 .25 L
.89117 .25 L
.89117 .25 L
.89118 .25 L
.89118 .25 L
.89119 .25 L
.8912 .25 L
.8912 .25 L
.89121 .25 L
.89121 .25 L
.89122 .25 L
.89123 .25 L
.89123 .25 L
.89124 .25 L
.89125 .25 L
.89125 .25 L
.89126 .25 L
.89127 .25 L
Mistroke
.89127 .25 L
.89128 .25 L
.89128 .25 L
.89129 .25 L
.8913 .25 L
.8913 .25 L
.89131 .25 L
.89131 .25 L
.89131 .25 L
.89132 .25 L
.89132 .25 L
.89133 .25 L
.89133 .25 L
.89133 .25 L
.89134 .25 L
.89134 .25 L
.89135 .25 L
.89135 .25 L
.89135 .25 L
.89136 .25 L
.89136 .25 L
.89137 .25 L
.89138 .25 L
.89138 .25 L
.89139 .25 L
.8914 .25 L
.8914 .25 L
.89141 .25 L
.89141 .25 L
.89142 .25 L
.89143 .25 L
.89143 .25 L
.89144 .25 L
.89145 .25 L
.89145 .25 L
.89146 .25 L
.89146 .25 L
.89147 .25 L
.89147 .25 L
.89148 .25 L
.89149 .25 L
.89149 .25 L
.8915 .25 L
.8915 .25 L
.89151 .25 L
.89152 .25 L
.89152 .25 L
.89153 .25 L
.89153 .25 L
.89154 .25 L
Mistroke
.89155 .25 L
.89155 .25 L
.89156 .25 L
.89156 .25 L
.89157 .25 L
.89157 .25 L
.89158 .25 L
.89159 .25 L
.89159 .25 L
.8916 .25 L
.89161 .25 L
.89161 .25 L
.89162 .25 L
.89162 .25 L
.89163 .25 L
.89164 .25 L
.89164 .25 L
.89165 .25 L
.89166 .25 L
.89166 .25 L
.89166 .25 L
.89167 .25 L
.89168 .25 L
.89168 .25 L
.89169 .25 L
.8917 .25 L
.8917 .25 L
.89171 .25 L
.89171 .25 L
.89172 .25 L
.89172 .25 L
.89173 .25 L
.89174 .25 L
.89174 .25 L
.89175 .25 L
.89176 .25 L
.89176 .25 L
.89176 .25 L
.89177 .25 L
.89178 .25 L
.89178 .25 L
.89179 .25 L
.89179 .25 L
.8918 .25 L
.8918 .25 L
.89181 .25 L
.89181 .25 L
.89182 .25 L
.89183 .25 L
.89183 .25 L
Mistroke
.89184 .25 L
.89184 .25 L
.89185 .25 L
.89185 .25 L
.89185 .25 L
.89186 .25 L
.89187 .25 L
.89187 .25 L
.89188 .25 L
.89189 .25 L
.89189 .25 L
.8919 .25 L
.8919 .25 L
.89191 .25 L
.89192 .25 L
.89192 .25 L
.89193 .25 L
.89193 .25 L
.89194 .25 L
.89195 .25 L
.89195 .25 L
.89196 .25 L
.89197 .25 L
.89197 .25 L
.89198 .25 L
.89199 .25 L
.89199 .25 L
.89199 .25 L
.892 .25 L
.892 .25 L
.89201 .25 L
.89201 .25 L
.89202 .25 L
.89203 .25 L
.89203 .25 L
.89204 .25 L
.89205 .25 L
.89205 .25 L
.89206 .25 L
.89206 .25 L
.89207 .25 L
.89208 .25 L
.89208 .25 L
.89209 .25 L
.8921 .25 L
.8921 .25 L
.89211 .25 L
.89212 .25 L
.89212 .25 L
.89212 .25 L
Mistroke
.89213 .25 L
.89213 .25 L
.89214 .25 L
.89214 .25 L
.89214 .25 L
.89215 .25 L
.89215 .25 L
.89216 .25 L
.89216 .25 L
.89217 .25 L
.89217 .25 L
.89217 .25 L
.89218 .25 L
.89218 .25 L
.89219 .25 L
.89219 .25 L
.8922 .25 L
.89221 .25 L
.89221 .25 L
.89222 .25 L
.89223 .25 L
.89223 .25 L
.89224 .25 L
.89224 .25 L
.89225 .25 L
.89226 .25 L
.89226 .25 L
.89227 .25 L
.89228 .25 L
.89228 .25 L
.89229 .25 L
.89229 .25 L
.8923 .25 L
.8923 .25 L
.89231 .25 L
.89232 .25 L
.89232 .25 L
.89233 .25 L
.89233 .25 L
.89234 .25 L
.89235 .25 L
.89235 .25 L
.89236 .25 L
.89236 .25 L
.89237 .25 L
.89238 .25 L
.89238 .25 L
.89238 .25 L
.89239 .25 L
.8924 .25 L
Mistroke
.8924 .25 L
.89241 .25 L
.89242 .25 L
.89242 .25 L
.89243 .25 L
.89243 .25 L
.89244 .25 L
.89245 .25 L
.89245 .25 L
.89246 .25 L
.89247 .25 L
.89247 .25 L
.89248 .25 L
.89248 .25 L
.89249 .25 L
.89249 .25 L
.8925 .25 L
.89251 .25 L
.89251 .25 L
.89252 .25 L
.89253 .25 L
.89253 .25 L
.89254 .25 L
.89254 .25 L
.89255 .25 L
.89255 .25 L
.89256 .25 L
.89257 .25 L
.89257 .25 L
.89258 .25 L
.89258 .25 L
.89259 .25 L
.89259 .25 L
.8926 .25 L
.89261 .25 L
.89261 .25 L
.89261 .25 L
.89262 .25 L
.89263 .25 L
.89263 .25 L
.89264 .25 L
.89264 .25 L
.89265 .25 L
.89266 .25 L
.89266 .25 L
.89266 .25 L
.89267 .25 L
.89267 .25 L
.89268 .25 L
.89268 .25 L
Mistroke
.89269 .25 L
.8927 .25 L
.8927 .25 L
.89271 .25 L
.89272 .25 L
.89272 .25 L
.89273 .25 L
.89273 .25 L
.89274 .25 L
.89275 .25 L
.89275 .25 L
.89276 .25 L
.89276 .25 L
.89277 .25 L
.89278 .25 L
.89278 .25 L
.89279 .25 L
.8928 .25 L
.8928 .25 L
.89281 .25 L
.89282 .25 L
.89282 .25 L
.89282 .25 L
.89283 .25 L
.89283 .25 L
.89284 .25 L
.89284 .25 L
.89285 .25 L
.89286 .25 L
.89286 .25 L
.89287 .25 L
.89287 .25 L
.89288 .25 L
.89289 .25 L
.89289 .25 L
.8929 .25 L
.89291 .25 L
.89291 .25 L
.89292 .25 L
.89293 .25 L
.89293 .25 L
.89294 .25 L
.89294 .25 L
.89295 .25 L
.89295 .25 L
.89296 .25 L
.89296 .25 L
.89296 .25 L
.89297 .25 L
.89297 .25 L
Mistroke
.89298 .25 L
.89298 .25 L
.89299 .25 L
.89299 .25 L
.89299 .25 L
.893 .25 L
.893 .25 L
.893 .25 L
.89301 .25 L
.89302 .25 L
.89302 .25 L
.89303 .25 L
.89304 .25 L
.89304 .25 L
.89305 .25 L
.89306 .25 L
.89306 .25 L
.89307 .25 L
.89307 .25 L
.89308 .25 L
.89309 .25 L
.89309 .25 L
.8931 .25 L
.89311 .25 L
.89311 .25 L
.89312 .25 L
.89312 .25 L
.89313 .25 L
.89313 .25 L
.89314 .25 L
.89315 .25 L
.89315 .25 L
.89316 .25 L
.89316 .25 L
.89317 .25 L
.89318 .25 L
.89318 .25 L
.89319 .25 L
.89319 .25 L
.8932 .25 L
.8932 .25 L
.89321 .25 L
.89321 .25 L
.89322 .25 L
.89323 .25 L
.89323 .25 L
.89324 .25 L
.89325 .25 L
.89325 .25 L
.89326 .25 L
Mistroke
.89326 .25 L
.89327 .25 L
.89328 .25 L
.89328 .25 L
.89329 .25 L
.8933 .25 L
.8933 .25 L
.89331 .25 L
.89331 .25 L
.89332 .25 L
.89332 .25 L
.89333 .25 L
.89334 .25 L
.89334 .25 L
.89335 .25 L
.89335 .25 L
.89336 .25 L
.89337 .25 L
.89337 .25 L
.89338 .25 L
.89338 .25 L
.89339 .25 L
.8934 .25 L
.8934 .25 L
.89341 .25 L
.89341 .25 L
.89342 .25 L
.89342 .25 L
.89343 .25 L
.89343 .25 L
.89344 .25 L
.89344 .25 L
.89345 .25 L
.89345 .25 L
.89346 .25 L
.89347 .25 L
.89347 .25 L
.89348 .25 L
.89348 .25 L
.89349 .25 L
.89349 .25 L
.8935 .25 L
.8935 .25 L
.89351 .25 L
.89351 .25 L
.89352 .25 L
.89353 .25 L
.89353 .25 L
.89354 .25 L
.89354 .25 L
Mistroke
.89355 .25 L
.89356 .25 L
.89356 .25 L
.89357 .25 L
.89357 .25 L
.89358 .25 L
.89359 .25 L
.89359 .25 L
.8936 .25 L
.89361 .25 L
.89361 .25 L
.89362 .25 L
.89363 .25 L
.89363 .25 L
.89364 .25 L
.89364 .25 L
.89365 .25 L
.89365 .25 L
.89365 .25 L
.89366 .25 L
.89367 .25 L
.89367 .25 L
.89368 .25 L
.89369 .25 L
.89369 .25 L
.8937 .25 L
.8937 .25 L
.89371 .25 L
.89372 .25 L
.89372 .25 L
.89373 .25 L
.89374 .25 L
.89374 .25 L
.89375 .25 L
.89376 .25 L
.89376 .25 L
.89377 .25 L
.89377 .25 L
.89378 .25 L
.89378 .25 L
.89378 .25 L
.89379 .25 L
.89379 .25 L
.8938 .25 L
.8938 .25 L
.89381 .25 L
.89381 .25 L
.89381 .25 L
.89382 .25 L
.89382 .25 L
Mistroke
.89382 .25 L
.89383 .25 L
.89383 .25 L
.89384 .25 L
.89385 .25 L
.89385 .25 L
.89386 .25 L
.89387 .25 L
.89387 .25 L
.89388 .25 L
.89389 .25 L
.89389 .25 L
.8939 .25 L
.89391 .25 L
.89391 .25 L
.89392 .25 L
.89392 .25 L
.89393 .25 L
.89393 .25 L
.89394 .25 L
.89395 .25 L
.89395 .25 L
.89396 .25 L
.89396 .25 L
.89397 .25 L
.89398 .25 L
.89398 .25 L
.89399 .25 L
.89399 .25 L
.894 .25 L
.89401 .25 L
.89401 .25 L
.89402 .25 L
.89402 .25 L
.89403 .25 L
.89403 .25 L
.89404 .25 L
.89404 .25 L
.89405 .25 L
.89406 .25 L
.89406 .25 L
.89407 .25 L
.89408 .25 L
.89408 .25 L
.89409 .25 L
.89409 .25 L
.8941 .25 L
.89411 .25 L
.89411 .25 L
.89412 .25 L
Mistroke
.89413 .25 L
.89413 .25 L
.89413 .25 L
.89414 .25 L
.89415 .25 L
.89415 .25 L
.89416 .25 L
.89417 .25 L
.89417 .25 L
.89418 .25 L
.89418 .25 L
.89419 .25 L
.89419 .25 L
.8942 .25 L
.89421 .25 L
.89421 .25 L
.89422 .25 L
.89423 .25 L
.89423 .25 L
.89423 .25 L
.89424 .25 L
.89425 .25 L
.89425 .25 L
.89426 .25 L
.89427 .25 L
.89427 .25 L
.89428 .25 L
.89428 .25 L
.89429 .25 L
.8943 .25 L
.8943 .25 L
.89431 .25 L
.89432 .25 L
.89432 .25 L
.89433 .25 L
.89433 .25 L
.89434 .25 L
.89434 .25 L
.89435 .25 L
.89436 .25 L
.89436 .25 L
.89437 .25 L
.89438 .25 L
.89438 .25 L
.89439 .25 L
.89439 .25 L
.8944 .25 L
.8944 .25 L
.89441 .25 L
.89442 .25 L
Mistroke
.89442 .25 L
.89443 .25 L
.89443 .25 L
.89444 .25 L
.89444 .25 L
.89445 .25 L
.89446 .25 L
.89446 .25 L
.89446 .25 L
.89447 .25 L
.89448 .25 L
.89448 .25 L
.89449 .25 L
.89449 .25 L
.8945 .25 L
.89451 .25 L
.89451 .25 L
.89451 .25 L
.89452 .25 L
.89452 .25 L
.89453 .25 L
.89453 .25 L
.89454 .25 L
.89455 .25 L
.89455 .25 L
.89456 .25 L
.89457 .25 L
.89457 .25 L
.89458 .25 L
.89458 .25 L
.89459 .25 L
.8946 .25 L
.8946 .25 L
.89461 .25 L
.89461 .25 L
.89462 .25 L
.89463 .25 L
.89463 .25 L
.89464 .25 L
.89464 .25 L
.89465 .25 L
.89466 .25 L
.89466 .25 L
.89467 .25 L
.89467 .25 L
.89468 .25 L
.89468 .25 L
.89469 .25 L
.89469 .25 L
.8947 .25 L
Mistroke
.89471 .25 L
.89471 .25 L
.89472 .25 L
.89472 .25 L
.89473 .25 L
.89474 .25 L
.89474 .25 L
.89475 .25 L
.89476 .25 L
.89476 .25 L
.89477 .25 L
.89478 .25 L
.89478 .25 L
.89479 .25 L
.89479 .25 L
.8948 .25 L
.8948 .25 L
.89481 .25 L
.89481 .25 L
.89481 .25 L
.89482 .25 L
.89482 .25 L
.89483 .25 L
.89483 .25 L
.89484 .25 L
.89484 .25 L
.89484 .25 L
.89485 .25 L
.89485 .25 L
.89485 .25 L
.89486 .25 L
.89487 .25 L
.89487 .25 L
.89488 .25 L
.89489 .25 L
.89489 .25 L
.8949 .25 L
.89491 .25 L
.89491 .25 L
.89492 .25 L
.89492 .25 L
.89493 .25 L
.89494 .25 L
.89494 .25 L
.89495 .25 L
.89496 .25 L
.89496 .25 L
.89497 .25 L
.89497 .25 L
.89498 .25 L
Mistroke
.89498 .25 L
.89499 .25 L
.895 .25 L
.895 .25 L
.89501 .25 L
.89501 .25 L
.89502 .25 L
.89503 .25 L
.89503 .25 L
.89504 .25 L
.89504 .25 L
.89505 .25 L
.89505 .25 L
.89506 .25 L
.89506 .25 L
.89507 .25 L
.89508 .25 L
.89508 .25 L
.89509 .25 L
.8951 .25 L
.8951 .25 L
.89511 .25 L
.89511 .25 L
.89512 .25 L
.89513 .25 L
.89513 .25 L
.89514 .25 L
.89515 .25 L
.89515 .25 L
.89516 .25 L
.89516 .25 L
.89517 .25 L
.89517 .25 L
.89518 .25 L
.89519 .25 L
.89519 .25 L
.8952 .25 L
.8952 .25 L
.89521 .25 L
.89522 .25 L
.89522 .25 L
.89523 .25 L
.89523 .25 L
.89524 .25 L
.89525 .25 L
.89525 .25 L
.89526 .25 L
.89526 .25 L
.89527 .25 L
.89527 .25 L
Mistroke
.89528 .25 L
.89528 .25 L
.89529 .25 L
.89529 .25 L
.8953 .25 L
.89531 .25 L
.89531 .25 L
.89532 .25 L
.89532 .25 L
.89533 .25 L
.89533 .25 L
.89534 .25 L
.89534 .25 L
.89535 .25 L
.89535 .25 L
.89536 .25 L
.89536 .25 L
.89537 .25 L
.89538 .25 L
.89538 .25 L
.89539 .25 L
.89539 .25 L
.8954 .25 L
.89541 .25 L
.89541 .25 L
.89542 .25 L
.89543 .25 L
.89543 .25 L
.89544 .25 L
.89544 .25 L
.89545 .25 L
.89546 .25 L
.89546 .25 L
.89547 .25 L
.89548 .25 L
.89548 .25 L
.89549 .25 L
.89549 .25 L
.8955 .25 L
.8955 .25 L
.8955 .25 L
.89551 .25 L
.89552 .25 L
.89552 .25 L
.89553 .25 L
.89554 .25 L
.89554 .25 L
.89555 .25 L
.89555 .25 L
.89556 .25 L
Mistroke
.89557 .25 L
.89557 .25 L
.89558 .25 L
.89559 .25 L
.89559 .25 L
.8956 .25 L
.89561 .25 L
.89561 .25 L
.89562 .25 L
.89562 .25 L
.89563 .25 L
.89563 .25 L
.89563 .25 L
.89564 .25 L
.89564 .25 L
.89565 .25 L
.89565 .25 L
.89566 .25 L
.89566 .25 L
.89566 .25 L
.89567 .25 L
.89567 .25 L
.89568 .25 L
.89568 .25 L
.89568 .25 L
.89569 .25 L
.8957 .25 L
.89571 .25 L
.89571 .25 L
.89572 .25 L
.89572 .25 L
.89573 .25 L
.89574 .25 L
.89574 .25 L
.89575 .25 L
.89576 .25 L
.89576 .25 L
.89577 .25 L
.89578 .25 L
.89578 .25 L
.89578 .25 L
.89579 .25 L
.8958 .25 L
.8958 .25 L
.89581 .25 L
.89581 .25 L
.89582 .25 L
.89583 .25 L
.89583 .25 L
.89584 .25 L
Mistroke
.89584 .25 L
.89585 .25 L
.89586 .25 L
.89586 .25 L
.89587 .25 L
.89587 .25 L
.89588 .25 L
.89588 .25 L
.89589 .25 L
.89589 .25 L
.8959 .25 L
.89591 .25 L
.89591 .25 L
.89592 .25 L
.89593 .25 L
.89593 .25 L
.89594 .25 L
.89594 .25 L
.89595 .25 L
.89596 .25 L
.89596 .25 L
.89597 .25 L
.89598 .25 L
.89598 .25 L
.89599 .25 L
.89599 .25 L
.896 .25 L
.896 .25 L
.89601 .25 L
.89602 .25 L
.89602 .25 L
.89603 .25 L
.89603 .25 L
.89604 .25 L
.89605 .25 L
.89605 .25 L
.89606 .25 L
.89606 .25 L
.89607 .25 L
.89608 .25 L
.89608 .25 L
.89608 .25 L
.89609 .25 L
.8961 .25 L
.8961 .25 L
.89611 .25 L
.89611 .25 L
.89612 .25 L
.89612 .25 L
.89613 .25 L
Mistroke
.89613 .25 L
.89614 .25 L
.89615 .25 L
.89615 .25 L
.89616 .25 L
.89616 .25 L
.89617 .25 L
.89617 .25 L
.89618 .25 L
.89618 .25 L
.89619 .25 L
.8962 .25 L
.8962 .25 L
.89621 .25 L
.89621 .25 L
.89622 .25 L
.89622 .25 L
.89623 .25 L
.89624 .25 L
.89624 .25 L
.89625 .25 L
.89626 .25 L
.89626 .25 L
.89627 .25 L
.89627 .25 L
.89628 .25 L
.89629 .25 L
.89629 .25 L
.8963 .25 L
.89631 .25 L
.89631 .25 L
.89632 .25 L
.89632 .25 L
.89632 .25 L
.89633 .25 L
.89633 .25 L
.89634 .25 L
.89635 .25 L
.89635 .25 L
.89636 .25 L
.89637 .25 L
.89637 .25 L
.89638 .25 L
.89638 .25 L
.89639 .25 L
.8964 .25 L
.8964 .25 L
.89641 .25 L
.89642 .25 L
.89642 .25 L
Mistroke
.89643 .25 L
.89644 .25 L
.89644 .25 L
.89644 .25 L
.89645 .25 L
.89645 .25 L
.89646 .25 L
.89646 .25 L
.89647 .25 L
.89647 .25 L
.89648 .25 L
.89648 .25 L
.89648 .25 L
.89649 .25 L
.89649 .25 L
.8965 .25 L
.8965 .25 L
.8965 .25 L
.89651 .25 L
.89652 .25 L
.89652 .25 L
.89653 .25 L
.89654 .25 L
.89654 .25 L
.89655 .25 L
.89655 .25 L
.89656 .25 L
.89657 .25 L
.89657 .25 L
.89658 .25 L
.89659 .25 L
.89659 .25 L
.8966 .25 L
.8966 .25 L
.89661 .25 L
.89661 .25 L
.89662 .25 L
.89663 .25 L
.89663 .25 L
.89664 .25 L
.89664 .25 L
.89665 .25 L
.89665 .25 L
.89666 .25 L
.89667 .25 L
.89667 .25 L
.89668 .25 L
.89669 .25 L
.89669 .25 L
.8967 .25 L
Mistroke
.8967 .25 L
.8967 .25 L
.89671 .25 L
.89672 .25 L
.89672 .25 L
.89673 .25 L
.89674 .25 L
.89674 .25 L
.89675 .25 L
.89676 .25 L
.89676 .25 L
.89677 .25 L
.89677 .25 L
.89678 .25 L
.89679 .25 L
.89679 .25 L
.8968 .25 L
.89681 .25 L
.89681 .25 L
.89682 .25 L
.89682 .25 L
.89683 .25 L
.89683 .25 L
.89684 .25 L
.89685 .25 L
.89685 .25 L
.89686 .25 L
.89686 .25 L
.89687 .25 L
.89688 .25 L
.89688 .25 L
.89689 .25 L
.89689 .25 L
.8969 .25 L
.8969 .25 L
.89691 .25 L
.89691 .25 L
.89692 .25 L
.89693 .25 L
.89693 .25 L
.89693 .25 L
.89694 .25 L
.89695 .25 L
.89695 .25 L
.89696 .25 L
.89696 .25 L
.89697 .25 L
.89698 .25 L
.89698 .25 L
.89698 .25 L
Mistroke
.89699 .25 L
.897 .25 L
.897 .25 L
.89701 .25 L
.89701 .25 L
.89702 .25 L
.89702 .25 L
.89703 .25 L
.89704 .25 L
.89704 .25 L
.89705 .25 L
.89705 .25 L
.89706 .25 L
.89707 .25 L
.89707 .25 L
.89708 .25 L
.89709 .25 L
.89709 .25 L
.8971 .25 L
.8971 .25 L
.89711 .25 L
.89712 .25 L
.89712 .25 L
.89713 .25 L
.89714 .25 L
.89714 .25 L
.89714 .25 L
.89715 .25 L
.89715 .25 L
.89716 .25 L
.89716 .25 L
.89717 .25 L
.89718 .25 L
.89718 .25 L
.89719 .25 L
.8972 .25 L
.8972 .25 L
.89721 .25 L
.89721 .25 L
.89722 .25 L
.89723 .25 L
.89723 .25 L
.89724 .25 L
.89725 .25 L
.89725 .25 L
.89726 .25 L
.89726 .25 L
.89727 .25 L
.89727 .25 L
.89728 .25 L
Mistroke
.89728 .25 L
.89729 .25 L
.89729 .25 L
.8973 .25 L
.8973 .25 L
.8973 .25 L
.89731 .25 L
.89731 .25 L
.89731 .25 L
.89732 .25 L
.89732 .25 L
.89733 .25 L
.89733 .25 L
.89734 .25 L
.89735 .25 L
.89735 .25 L
.89736 .25 L
.89737 .25 L
.89737 .25 L
.89738 .25 L
.89738 .25 L
.89739 .25 L
.8974 .25 L
.8974 .25 L
.89741 .25 L
.89742 .25 L
.89742 .25 L
.89743 .25 L
.89743 .25 L
.89744 .25 L
.89744 .25 L
.89745 .25 L
.89746 .25 L
.89746 .25 L
.89747 .25 L
.89747 .25 L
.89748 .25 L
.89748 .25 L
.89749 .25 L
.8975 .25 L
.8975 .25 L
.89751 .25 L
.89751 .25 L
.89752 .25 L
.89752 .25 L
.89753 .25 L
.89753 .25 L
.89754 .25 L
.89755 .25 L
.89755 .25 L
Mistroke
.89756 .25 L
.89757 .25 L
.89757 .25 L
.89758 .25 L
.89759 .25 L
.89759 .25 L
.8976 .25 L
.8976 .25 L
.89761 .25 L
.89762 .25 L
.89762 .25 L
.89763 .25 L
.89763 .25 L
.89764 .25 L
.89765 .25 L
.89765 .25 L
.89766 .25 L
.89766 .25 L
.89767 .25 L
.89768 .25 L
.89768 .25 L
.89769 .25 L
.89769 .25 L
.8977 .25 L
.89771 .25 L
.89771 .25 L
.89772 .25 L
.89772 .25 L
.89773 .25 L
.89773 .25 L
.89774 .25 L
.89774 .25 L
.89775 .25 L
.89776 .25 L
.89776 .25 L
.89777 .25 L
.89778 .25 L
.89778 .25 L
.89779 .25 L
.89779 .25 L
.8978 .25 L
.89781 .25 L
.89781 .25 L
.89782 .25 L
.89783 .25 L
.89783 .25 L
.89783 .25 L
.89784 .25 L
.89785 .25 L
.89785 .25 L
Mistroke
.89786 .25 L
.89787 .25 L
.89787 .25 L
.89788 .25 L
.89788 .25 L
.89789 .25 L
.8979 .25 L
.8979 .25 L
.89791 .25 L
.89791 .25 L
.89792 .25 L
.89793 .25 L
.89793 .25 L
.89793 .25 L
.89794 .25 L
.89795 .25 L
.89795 .25 L
.89796 .25 L
.89796 .25 L
.89797 .25 L
.89797 .25 L
.89798 .25 L
.89798 .25 L
.89799 .25 L
.898 .25 L
.898 .25 L
.89801 .25 L
.89801 .25 L
.89802 .25 L
.89802 .25 L
.89803 .25 L
.89803 .25 L
.89804 .25 L
.89804 .25 L
.89805 .25 L
.89806 .25 L
.89806 .25 L
.89807 .25 L
.89807 .25 L
.89808 .25 L
.89809 .25 L
.89809 .25 L
.8981 .25 L
.89811 .25 L
.89811 .25 L
.89812 .25 L
.89812 .25 L
.89813 .25 L
.89814 .25 L
.89814 .25 L
Mistroke
.89815 .25 L
.89816 .25 L
.89816 .25 L
.89817 .25 L
.89817 .25 L
.89817 .25 L
.89818 .25 L
.89818 .25 L
.89819 .25 L
.8982 .25 L
.8982 .25 L
.89821 .25 L
.89822 .25 L
.89822 .25 L
.89823 .25 L
.89823 .25 L
.89824 .25 L
.89825 .25 L
.89825 .25 L
.89826 .25 L
.89827 .25 L
.89827 .25 L
.89828 .25 L
.89829 .25 L
.89829 .25 L
.89829 .25 L
.8983 .25 L
.8983 .25 L
.89831 .25 L
.89831 .25 L
.89832 .25 L
.89832 .25 L
.89833 .25 L
.89833 .25 L
.89833 .25 L
.89834 .25 L
.89834 .25 L
.89834 .25 L
.89835 .25 L
.89835 .25 L
.89836 .25 L
.89837 .25 L
.89837 .25 L
.89838 .25 L
.89839 .25 L
.89839 .25 L
.8984 .25 L
.8984 .25 L
.89841 .25 L
.89842 .25 L
Mistroke
.89842 .25 L
.89843 .25 L
.89844 .25 L
.89844 .25 L
.89845 .25 L
.89845 .25 L
.89846 .25 L
.89846 .25 L
.89847 .25 L
.89848 .25 L
.89848 .25 L
.89849 .25 L
.89849 .25 L
.8985 .25 L
.8985 .25 L
.89851 .25 L
.89852 .25 L
.89852 .25 L
.89853 .25 L
.89854 .25 L
.89854 .25 L
.89855 .25 L
.89855 .25 L
.89855 .25 L
.89856 .25 L
.89857 .25 L
.89857 .25 L
.89858 .25 L
.89859 .25 L
.89859 .25 L
.8986 .25 L
.89861 .25 L
.89861 .25 L
.89862 .25 L
.89862 .25 L
.89863 .25 L
.89864 .25 L
.89864 .25 L
.89865 .25 L
.89866 .25 L
.89866 .25 L
.89867 .25 L
.89867 .25 L
.89868 .25 L
.89868 .25 L
.89869 .25 L
.8987 .25 L
.8987 .25 L
.89871 .25 L
.89871 .25 L
Mistroke
.89872 .25 L
.89873 .25 L
.89873 .25 L
.89874 .25 L
.89874 .25 L
.89875 .25 L
.89875 .25 L
.89876 .25 L
.89876 .25 L
.89877 .25 L
.89878 .25 L
.89878 .25 L
.89878 .25 L
.89879 .25 L
.8988 .25 L
.8988 .25 L
.89881 .25 L
.89881 .25 L
.89882 .25 L
.89883 .25 L
.89883 .25 L
.89883 .25 L
.89884 .25 L
.89885 .25 L
.89885 .25 L
.89886 .25 L
.89886 .25 L
.89887 .25 L
.89888 .25 L
.89888 .25 L
.89889 .25 L
.89889 .25 L
.8989 .25 L
.8989 .25 L
.89891 .25 L
.89892 .25 L
.89892 .25 L
.89893 .25 L
.89894 .25 L
.89894 .25 L
.89895 .25 L
.89895 .25 L
.89896 .25 L
.89897 .25 L
.89897 .25 L
.89898 .25 L
.89899 .25 L
.89899 .25 L
.89899 .25 L
.899 .25 L
Mistroke
.899 .25 L
.89901 .25 L
.89901 .25 L
.89902 .25 L
.89903 .25 L
.89903 .25 L
.89904 .25 L
.89905 .25 L
.89905 .25 L
.89906 .25 L
.89906 .25 L
.89907 .25 L
.89908 .25 L
.89908 .25 L
.89909 .25 L
.8991 .25 L
.8991 .25 L
.89911 .25 L
.89911 .25 L
.89912 .25 L
.89912 .25 L
.89913 .25 L
.89913 .25 L
.89914 .25 L
.89914 .25 L
.89915 .25 L
.89915 .25 L
.89915 .25 L
.89916 .25 L
.89916 .25 L
.89917 .25 L
.89917 .25 L
.89917 .25 L
.89918 .25 L
.89918 .25 L
.89919 .25 L
.8992 .25 L
.8992 .25 L
.89921 .25 L
.89922 .25 L
.89922 .25 L
.89923 .25 L
.89923 .25 L
.89924 .25 L
.89925 .25 L
.89925 .25 L
.89926 .25 L
.89927 .25 L
.89927 .25 L
.89928 .25 L
Mistroke
.89928 .25 L
.89929 .25 L
.89929 .25 L
.8993 .25 L
.89931 .25 L
.89931 .25 L
.89932 .25 L
.89932 .25 L
.89933 .25 L
.89933 .25 L
.89934 .25 L
.89935 .25 L
.89935 .25 L
.89936 .25 L
.89936 .25 L
.89937 .25 L
.89938 .25 L
.89938 .25 L
.89938 .25 L
.89939 .25 L
.8994 .25 L
.89941 .25 L
.89941 .25 L
.89942 .25 L
.89942 .25 L
.89943 .25 L
.89944 .25 L
.89944 .25 L
.89945 .25 L
.89946 .25 L
.89946 .25 L
.89947 .25 L
.89948 .25 L
.89948 .25 L
.89948 .25 L
.89949 .25 L
.8995 .25 L
.8995 .25 L
.89951 .25 L
.89951 .25 L
.89952 .25 L
.89953 .25 L
.89953 .25 L
.89954 .25 L
.89954 .25 L
.89955 .25 L
.89956 .25 L
.89956 .25 L
.89957 .25 L
.89957 .25 L
Mistroke
.89958 .25 L
.89958 .25 L
.89959 .25 L
.89959 .25 L
.8996 .25 L
.8996 .25 L
.89961 .25 L
.89961 .25 L
.89962 .25 L
.89963 .25 L
.89963 .25 L
.89964 .25 L
.89964 .25 L
.89965 .25 L
.89966 .25 L
.89966 .25 L
.89967 .25 L
.89967 .25 L
.89967 .25 L
.89968 .25 L
.89969 .25 L
.89969 .25 L
.8997 .25 L
.8997 .25 L
.89971 .25 L
.89972 .25 L
.89972 .25 L
.89973 .25 L
.89973 .25 L
.89974 .25 L
.89975 .25 L
.89975 .25 L
.89976 .25 L
.89976 .25 L
.89977 .25 L
.89978 .25 L
.89978 .25 L
.89979 .25 L
.8998 .25 L
.8998 .25 L
.89981 .25 L
.89981 .25 L
.89982 .25 L
.89982 .25 L
.89983 .25 L
.89983 .25 L
.89984 .25 L
.89984 .25 L
.89985 .25 L
.89986 .25 L
Mistroke
.89986 .25 L
.89987 .25 L
.89988 .25 L
.89988 .25 L
.89989 .25 L
.8999 .25 L
.8999 .25 L
.89991 .25 L
.89991 .25 L
.89992 .25 L
.89993 .25 L
.89993 .25 L
.89994 .25 L
.89994 .25 L
.89995 .25 L
.89995 .25 L
.89996 .25 L
.89996 .25 L
.89996 .25 L
.89997 .25 L
.89997 .25 L
.89998 .25 L
.89998 .25 L
.89999 .25 L
.89999 .25 L
.89999 .25 L
.9 .25 L
.9 .25 L
.90001 .25 L
.90001 .25 L
.90002 .25 L
.90003 .25 L
.90003 .25 L
.90004 .25 L
.90005 .25 L
.90005 .25 L
.90006 .25 L
.90006 .25 L
.90007 .25 L
.90008 .25 L
.90008 .25 L
.90009 .25 L
.9001 .25 L
.9001 .25 L
.9001 .25 L
.90011 .25 L
.90012 .25 L
.90012 .25 L
.90013 .25 L
.90014 .25 L
Mistroke
.90014 .25 L
.90015 .25 L
.90015 .25 L
.90016 .25 L
.90016 .25 L
.90017 .25 L
.90018 .25 L
.90018 .25 L
.90019 .25 L
.9002 .25 L
.9002 .25 L
.9002 .25 L
.90021 .25 L
.90022 .25 L
.90022 .25 L
.90023 .25 L
.90024 .25 L
.90024 .25 L
.90025 .25 L
.90025 .25 L
.90026 .25 L
.90027 .25 L
.90027 .25 L
.90028 .25 L
.90029 .25 L
.90029 .25 L
.9003 .25 L
.9003 .25 L
.90031 .25 L
.90031 .25 L
.90032 .25 L
.90033 .25 L
.90033 .25 L
.90034 .25 L
.90034 .25 L
.90035 .25 L
.90036 .25 L
.90036 .25 L
.90037 .25 L
.90037 .25 L
.90038 .25 L
.90039 .25 L
.90039 .25 L
.9004 .25 L
.9004 .25 L
.9004 .25 L
.90041 .25 L
.90042 .25 L
.90042 .25 L
.90043 .25 L
Mistroke
.90043 .25 L
.90044 .25 L
.90044 .25 L
.90045 .25 L
.90046 .25 L
.90046 .25 L
.90047 .25 L
.90047 .25 L
.90048 .25 L
.90048 .25 L
.90049 .25 L
.90049 .25 L
.9005 .25 L
.9005 .25 L
.90051 .25 L
.90052 .25 L
.90052 .25 L
.90053 .25 L
.90053 .25 L
.90054 .25 L
.90055 .25 L
.90055 .25 L
.90056 .25 L
.90056 .25 L
.90057 .25 L
.90058 .25 L
.90058 .25 L
.90059 .25 L
.90059 .25 L
.9006 .25 L
.90061 .25 L
.90061 .25 L
.90062 .25 L
.90063 .25 L
.90063 .25 L
.90064 .25 L
.90064 .25 L
.90064 .25 L
.90065 .25 L
.90066 .25 L
.90066 .25 L
.90067 .25 L
.90068 .25 L
.90068 .25 L
.90069 .25 L
.90069 .25 L
.9007 .25 L
.90071 .25 L
.90071 .25 L
.90072 .25 L
Mistroke
.90072 .25 L
.90073 .25 L
.90074 .25 L
.90074 .25 L
.90075 .25 L
.90076 .25 L
.90076 .25 L
.90077 .25 L
.90077 .25 L
.90078 .25 L
.90078 .25 L
.90078 .25 L
.90079 .25 L
.90079 .25 L
.9008 .25 L
.9008 .25 L
.9008 .25 L
.90081 .25 L
.90081 .25 L
.90082 .25 L
.90082 .25 L
.90082 .25 L
.90083 .25 L
.90084 .25 L
.90084 .25 L
.90085 .25 L
.90086 .25 L
.90086 .25 L
.90087 .25 L
.90087 .25 L
.90088 .25 L
.90089 .25 L
.90089 .25 L
.9009 .25 L
.90091 .25 L
.90091 .25 L
.90092 .25 L
.90092 .25 L
.90093 .25 L
.90093 .25 L
.90094 .25 L
.90095 .25 L
.90095 .25 L
.90096 .25 L
.90097 .25 L
.90097 .25 L
.90098 .25 L
.90098 .25 L
.90099 .25 L
.90099 .25 L
Mistroke
.901 .25 L
.90101 .25 L
.90101 .25 L
.90102 .25 L
.90102 .25 L
.90103 .25 L
.90103 .25 L
.90104 .25 L
.90105 .25 L
.90105 .25 L
.90106 .25 L
.90107 .25 L
.90107 .25 L
.90108 .25 L
.90108 .25 L
.90109 .25 L
.9011 .25 L
.9011 .25 L
.90111 .25 L
.90112 .25 L
.90112 .25 L
.90113 .25 L
.90113 .25 L
.90114 .25 L
.90114 .25 L
.90115 .25 L
.90116 .25 L
.90116 .25 L
.90117 .25 L
.90117 .25 L
.90118 .25 L
.90118 .25 L
.90119 .25 L
.9012 .25 L
.9012 .25 L
.90121 .25 L
.90121 .25 L
.90122 .25 L
.90122 .25 L
.90123 .25 L
.90123 .25 L
.90124 .25 L
.90125 .25 L
.90125 .25 L
.90126 .25 L
.90127 .25 L
.90127 .25 L
.90128 .25 L
.90129 .25 L
.90129 .25 L
Mistroke
.9013 .25 L
.90131 .25 L
.90131 .25 L
.90132 .25 L
.90132 .25 L
.90133 .25 L
.90133 .25 L
.90134 .25 L
.90135 .25 L
.90135 .25 L
.90136 .25 L
.90136 .25 L
.90137 .25 L
.90138 .25 L
.90138 .25 L
.90139 .25 L
.90139 .25 L
.9014 .25 L
.90141 .25 L
.90141 .25 L
.90142 .25 L
.90142 .25 L
.90143 .25 L
.90143 .25 L
.90144 .25 L
.90144 .25 L
.90145 .25 L
.90145 .25 L
.90146 .25 L
.90146 .25 L
.90147 .25 L
.90148 .25 L
.90148 .25 L
.90149 .25 L
.90149 .25 L
.9015 .25 L
.9015 .25 L
.90151 .25 L
.90152 .25 L
.90152 .25 L
.90152 .25 L
.90153 .25 L
.90154 .25 L
.90154 .25 L
.90155 .25 L
.90155 .25 L
.90156 .25 L
.90157 .25 L
.90157 .25 L
.90158 .25 L
Mistroke
.90158 .25 L
.90159 .25 L
.9016 .25 L
.9016 .25 L
.90161 .25 L
.90161 .25 L
.90162 .25 L
.90163 .25 L
.90163 .25 L
.90164 .25 L
.90165 .25 L
.90165 .25 L
.90166 .25 L
.90166 .25 L
.90167 .25 L
.90167 .25 L
.90167 .25 L
.90168 .25 L
.90169 .25 L
.90169 .25 L
.9017 .25 L
.90171 .25 L
.90171 .25 L
.90172 .25 L
.90173 .25 L
.90173 .25 L
.90174 .25 L
.90175 .25 L
.90175 .25 L
.90176 .25 L
.90176 .25 L
.90177 .25 L
.90178 .25 L
.90178 .25 L
.90179 .25 L
.90179 .25 L
.9018 .25 L
.9018 .25 L
.90181 .25 L
.90181 .25 L
.90181 .25 L
.90182 .25 L
.90182 .25 L
.90183 .25 L
.90183 .25 L
.90184 .25 L
.90184 .25 L
.90184 .25 L
.90185 .25 L
.90185 .25 L
Mistroke
.90186 .25 L
.90186 .25 L
.90187 .25 L
.90188 .25 L
.90188 .25 L
.90189 .25 L
.9019 .25 L
.9019 .25 L
.90191 .25 L
.90191 .25 L
.90192 .25 L
.90193 .25 L
.90193 .25 L
.90194 .25 L
.90195 .25 L
.90195 .25 L
.90195 .25 L
.90196 .25 L
.90197 .25 L
.90197 .25 L
.90198 .25 L
.90199 .25 L
.90199 .25 L
.902 .25 L
.902 .25 L
.90201 .25 L
.90201 .25 L
.90202 .25 L
.90203 .25 L
.90203 .25 L
.90204 .25 L
.90205 .25 L
.90205 .25 L
.90205 .25 L
.90206 .25 L
.90207 .25 L
.90207 .25 L
.90208 .25 L
.90209 .25 L
.90209 .25 L
.9021 .25 L
.9021 .25 L
.90211 .25 L
.90212 .25 L
.90212 .25 L
.90213 .25 L
.90214 .25 L
.90214 .25 L
.90215 .25 L
.90215 .25 L
Mistroke
.90216 .25 L
.90216 .25 L
.90217 .25 L
.90218 .25 L
.90218 .25 L
.90219 .25 L
.90219 .25 L
.9022 .25 L
.90221 .25 L
.90221 .25 L
.90222 .25 L
.90222 .25 L
.90223 .25 L
.90224 .25 L
.90224 .25 L
.90225 .25 L
.90225 .25 L
.90226 .25 L
.90226 .25 L
.90227 .25 L
.90227 .25 L
.90228 .25 L
.90228 .25 L
.90229 .25 L
.90229 .25 L
.9023 .25 L
.90231 .25 L
.90231 .25 L
.90232 .25 L
.90233 .25 L
.90233 .25 L
.90233 .25 L
.90234 .25 L
.90234 .25 L
.90235 .25 L
.90235 .25 L
.90236 .25 L
.90237 .25 L
.90237 .25 L
.90238 .25 L
.90238 .25 L
.90239 .25 L
.9024 .25 L
.9024 .25 L
.90241 .25 L
.90241 .25 L
.90242 .25 L
.90243 .25 L
.90243 .25 L
.90244 .25 L
Mistroke
.90244 .25 L
.90245 .25 L
.90246 .25 L
.90246 .25 L
.90247 .25 L
.90248 .25 L
.90248 .25 L
.90249 .25 L
.90249 .25 L
.9025 .25 L
.9025 .25 L
.90251 .25 L
.90251 .25 L
.90252 .25 L
.90253 .25 L
.90253 .25 L
.90254 .25 L
.90254 .25 L
.90255 .25 L
.90256 .25 L
.90256 .25 L
.90257 .25 L
.90258 .25 L
.90258 .25 L
.90259 .25 L
.9026 .25 L
.9026 .25 L
.90261 .25 L
.90261 .25 L
.90262 .25 L
.90262 .25 L
.90263 .25 L
.90263 .25 L
.90263 .25 L
.90264 .25 L
.90264 .25 L
.90265 .25 L
.90265 .25 L
.90266 .25 L
.90266 .25 L
.90266 .25 L
.90267 .25 L
.90267 .25 L
.90267 .25 L
.90268 .25 L
.90269 .25 L
.90269 .25 L
.9027 .25 L
.90271 .25 L
.90271 .25 L
Mistroke
.90272 .25 L
.90273 .25 L
.90273 .25 L
.90274 .25 L
.90274 .25 L
.90275 .25 L
.90276 .25 L
.90276 .25 L
.90277 .25 L
.90277 .25 L
.90278 .25 L
.90279 .25 L
.90279 .25 L
.9028 .25 L
.9028 .25 L
.90281 .25 L
.90282 .25 L
.90282 .25 L
.90283 .25 L
.90283 .25 L
.90284 .25 L
.90284 .25 L
.90285 .25 L
.90286 .25 L
.90286 .25 L
.90287 .25 L
.90287 .25 L
.90288 .25 L
.90288 .25 L
.90289 .25 L
.9029 .25 L
.9029 .25 L
.90291 .25 L
.90292 .25 L
.90292 .25 L
.90293 .25 L
.90293 .25 L
.90294 .25 L
.90295 .25 L
.90295 .25 L
.90296 .25 L
.90297 .25 L
.90297 .25 L
.90298 .25 L
.90298 .25 L
.90299 .25 L
.90299 .25 L
.903 .25 L
.90301 .25 L
.90301 .25 L
Mistroke
.90302 .25 L
.90302 .25 L
.90303 .25 L
.90304 .25 L
.90304 .25 L
.90305 .25 L
.90305 .25 L
.90306 .25 L
.90307 .25 L
.90307 .25 L
.90308 .25 L
.90308 .25 L
.90309 .25 L
.90309 .25 L
.9031 .25 L
.9031 .25 L
.90311 .25 L
.90311 .25 L
.90312 .25 L
.90312 .25 L
.90313 .25 L
.90314 .25 L
.90314 .25 L
.90315 .25 L
.90315 .25 L
.90316 .25 L
.90316 .25 L
.90317 .25 L
.90317 .25 L
.90318 .25 L
.90318 .25 L
.90319 .25 L
.9032 .25 L
.9032 .25 L
.90321 .25 L
.90321 .25 L
.90322 .25 L
.90323 .25 L
.90323 .25 L
.90324 .25 L
.90324 .25 L
.90325 .25 L
.90326 .25 L
.90326 .25 L
.90327 .25 L
.90328 .25 L
.90328 .25 L
.90329 .25 L
.90329 .25 L
.9033 .25 L
Mistroke
.90331 .25 L
.90331 .25 L
.90332 .25 L
.90332 .25 L
.90332 .25 L
.90333 .25 L
.90334 .25 L
.90334 .25 L
.90335 .25 L
.90336 .25 L
.90336 .25 L
.90337 .25 L
.90337 .25 L
.90338 .25 L
.90339 .25 L
.90339 .25 L
.9034 .25 L
.90341 .25 L
.90341 .25 L
.90342 .25 L
.90343 .25 L
.90343 .25 L
.90344 .25 L
.90344 .25 L
.90345 .25 L
.90345 .25 L
.90345 .25 L
.90346 .25 L
.90346 .25 L
.90347 .25 L
.90347 .25 L
.90348 .25 L
.90348 .25 L
.90348 .25 L
.90349 .25 L
.90349 .25 L
.90349 .25 L
.9035 .25 L
.9035 .25 L
.90351 .25 L
.90352 .25 L
.90352 .25 L
.90353 .25 L
.90354 .25 L
.90354 .25 L
.90355 .25 L
.90356 .25 L
.90356 .25 L
.90357 .25 L
.90357 .25 L
Mistroke
.90358 .25 L
.90359 .25 L
.90359 .25 L
.9036 .25 L
.9036 .25 L
.90361 .25 L
.90362 .25 L
.90362 .25 L
.90363 .25 L
.90363 .25 L
.90364 .25 L
.90365 .25 L
.90365 .25 L
.90366 .25 L
.90366 .25 L
.90367 .25 L
.90367 .25 L
.90368 .25 L
.90369 .25 L
.90369 .25 L
.9037 .25 L
.9037 .25 L
.90371 .25 L
.90371 .25 L
.90372 .25 L
.90373 .25 L
.90373 .25 L
.90374 .25 L
.90375 .25 L
.90375 .25 L
.90376 .25 L
.90376 .25 L
.90377 .25 L
.90378 .25 L
.90378 .25 L
.90379 .25 L
.9038 .25 L
.9038 .25 L
.9038 .25 L
.90381 .25 L
.90382 .25 L
.90382 .25 L
.90383 .25 L
.90384 .25 L
.90384 .25 L
.90385 .25 L
.90385 .25 L
.90386 .25 L
.90386 .25 L
.90387 .25 L
Mistroke
.90388 .25 L
.90388 .25 L
.90389 .25 L
.9039 .25 L
.9039 .25 L
.9039 .25 L
.90391 .25 L
.90392 .25 L
.90392 .25 L
.90393 .25 L
.90393 .25 L
.90394 .25 L
.90394 .25 L
.90395 .25 L
.90395 .25 L
.90396 .25 L
.90397 .25 L
.90397 .25 L
.90398 .25 L
.90398 .25 L
.90399 .25 L
.90399 .25 L
.90399 .25 L
.904 .25 L
.90401 .25 L
.90401 .25 L
.90402 .25 L
.90403 .25 L
.90403 .25 L
.90404 .25 L
.90404 .25 L
.90405 .25 L
.90406 .25 L
.90406 .25 L
.90407 .25 L
.90407 .25 L
.90408 .25 L
.90409 .25 L
.90409 .25 L
.9041 .25 L
.90411 .25 L
.90411 .25 L
.90412 .25 L
.90413 .25 L
.90413 .25 L
.90414 .25 L
.90414 .25 L
.90414 .25 L
.90415 .25 L
.90415 .25 L
Mistroke
.90416 .25 L
.90417 .25 L
.90417 .25 L
.90418 .25 L
.90419 .25 L
.90419 .25 L
.9042 .25 L
.9042 .25 L
.90421 .25 L
.90422 .25 L
.90422 .25 L
.90423 .25 L
.90424 .25 L
.90424 .25 L
.90425 .25 L
.90426 .25 L
.90426 .25 L
.90426 .25 L
.90427 .25 L
.90427 .25 L
.90428 .25 L
.90428 .25 L
.90428 .25 L
.90429 .25 L
.9043 .25 L
.9043 .25 L
.9043 .25 L
.90431 .25 L
.90431 .25 L
.90431 .25 L
.90432 .25 L
.90432 .25 L
.90433 .25 L
.90433 .25 L
.90434 .25 L
.90435 .25 L
.90435 .25 L
.90436 .25 L
.90437 .25 L
.90437 .25 L
.90438 .25 L
.90438 .25 L
.90439 .25 L
.9044 .25 L
.9044 .25 L
.90441 .25 L
.90442 .25 L
.90442 .25 L
.90443 .25 L
.90443 .25 L
Mistroke
.90444 .25 L
.90444 .25 L
.90445 .25 L
.90446 .25 L
.90446 .25 L
.90447 .25 L
.90447 .25 L
.90448 .25 L
.90449 .25 L
.90449 .25 L
.9045 .25 L
.9045 .25 L
.90451 .25 L
.90452 .25 L
.90452 .25 L
.90452 .25 L
.90453 .25 L
.90454 .25 L
.90454 .25 L
.90455 .25 L
.90456 .25 L
.90456 .25 L
.90457 .25 L
.90457 .25 L
.90458 .25 L
.90459 .25 L
.90459 .25 L
.9046 .25 L
.90461 .25 L
.90461 .25 L
.90462 .25 L
.90462 .25 L
.90463 .25 L
.90463 .25 L
.90464 .25 L
.90465 .25 L
.90465 .25 L
.90466 .25 L
.90467 .25 L
.90467 .25 L
.90468 .25 L
.90468 .25 L
.90469 .25 L
.90469 .25 L
.9047 .25 L
.90471 .25 L
.90471 .25 L
.90472 .25 L
.90472 .25 L
.90473 .25 L
Mistroke
.90473 .25 L
.90474 .25 L
.90475 .25 L
.90475 .25 L
.90475 .25 L
.90476 .25 L
.90477 .25 L
.90477 .25 L
.90478 .25 L
.90478 .25 L
.90479 .25 L
.9048 .25 L
.9048 .25 L
.9048 .25 L
.90481 .25 L
.90481 .25 L
.90482 .25 L
.90482 .25 L
.90483 .25 L
.90484 .25 L
.90484 .25 L
.90485 .25 L
.90486 .25 L
.90486 .25 L
.90487 .25 L
.90487 .25 L
.90488 .25 L
.90489 .25 L
.90489 .25 L
.9049 .25 L
.9049 .25 L
.90491 .25 L
.90492 .25 L
.90492 .25 L
.90493 .25 L
.90494 .25 L
.90494 .25 L
.90495 .25 L
.90496 .25 L
.90496 .25 L
.90496 .25 L
.90497 .25 L
.90497 .25 L
.90498 .25 L
.90498 .25 L
.90499 .25 L
.905 .25 L
.905 .25 L
.90501 .25 L
.90501 .25 L
Mistroke
.90502 .25 L
.90503 .25 L
.90503 .25 L
.90504 .25 L
.90505 .25 L
.90505 .25 L
.90506 .25 L
.90507 .25 L
.90507 .25 L
.90508 .25 L
.90508 .25 L
.90509 .25 L
.90509 .25 L
.9051 .25 L
.9051 .25 L
.9051 .25 L
.90511 .25 L
.90511 .25 L
.90512 .25 L
.90512 .25 L
.90513 .25 L
.90513 .25 L
.90513 .25 L
.90514 .25 L
.90514 .25 L
.90514 .25 L
.90515 .25 L
.90516 .25 L
.90516 .25 L
.90517 .25 L
.90518 .25 L
.90518 .25 L
.90519 .25 L
.9052 .25 L
.9052 .25 L
.90521 .25 L
.90521 .25 L
.90522 .25 L
.90523 .25 L
.90523 .25 L
.90524 .25 L
.90525 .25 L
.90525 .25 L
.90526 .25 L
.90526 .25 L
.90527 .25 L
.90527 .25 L
.90528 .25 L
.90529 .25 L
.90529 .25 L
Mistroke
.9053 .25 L
.9053 .25 L
.90531 .25 L
.90532 .25 L
.90532 .25 L
.90533 .25 L
.90533 .25 L
.90534 .25 L
.90534 .25 L
.90535 .25 L
.90535 .25 L
.90536 .25 L
.90537 .25 L
.90537 .25 L
.90538 .25 L
.90539 .25 L
.90539 .25 L
.9054 .25 L
.9054 .25 L
.90541 .25 L
.90542 .25 L
.90542 .25 L
.90543 .25 L
.90544 .25 L
.90544 .25 L
.90545 .25 L
.90545 .25 L
.90546 .25 L
.90546 .25 L
.90547 .25 L
.90548 .25 L
.90548 .25 L
.90549 .25 L
.90549 .25 L
.9055 .25 L
.90551 .25 L
.90551 .25 L
.90552 .25 L
.90552 .25 L
.90553 .25 L
.90554 .25 L
.90554 .25 L
.90555 .25 L
.90555 .25 L
.90556 .25 L
.90556 .25 L
.90557 .25 L
.90558 .25 L
.90558 .25 L
.90559 .25 L
Mistroke
.90559 .25 L
.9056 .25 L
.90561 .25 L
.90561 .25 L
.90562 .25 L
.90563 .25 L
.90563 .25 L
.90564 .25 L
.90565 .25 L
.90565 .25 L
.90565 .25 L
.90566 .25 L
.90567 .25 L
.90567 .25 L
.90568 .25 L
.90569 .25 L
.90569 .25 L
.9057 .25 L
.9057 .25 L
.90571 .25 L
.90571 .25 L
.90572 .25 L
.90573 .25 L
.90573 .25 L
.90574 .25 L
.90574 .25 L
.90575 .25 L
.90575 .25 L
.90576 .25 L
.90577 .25 L
.90577 .25 L
.90578 .25 L
.90578 .25 L
.90578 .25 L
.90579 .25 L
.9058 .25 L
.9058 .25 L
.90581 .25 L
.90582 .25 L
.90582 .25 L
.90583 .25 L
.90583 .25 L
.90584 .25 L
.90584 .25 L
.90584 .25 L
.90585 .25 L
.90586 .25 L
.90586 .25 L
.90587 .25 L
.90588 .25 L
Mistroke
.90588 .25 L
.90589 .25 L
.90589 .25 L
.9059 .25 L
.90591 .25 L
.90591 .25 L
.90592 .25 L
.90592 .25 L
.90593 .25 L
.90594 .25 L
.90594 .25 L
.90595 .25 L
.90596 .25 L
.90596 .25 L
.90597 .25 L
.90597 .25 L
.90598 .25 L
.90598 .25 L
.90599 .25 L
.90599 .25 L
.906 .25 L
.906 .25 L
.90601 .25 L
.90602 .25 L
.90602 .25 L
.90603 .25 L
.90603 .25 L
.90604 .25 L
.90605 .25 L
.90605 .25 L
.90606 .25 L
.90607 .25 L
.90607 .25 L
.90608 .25 L
.90609 .25 L
.90609 .25 L
.9061 .25 L
.90611 .25 L
.90611 .25 L
.90611 .25 L
.90612 .25 L
.90612 .25 L
.90613 .25 L
.90613 .25 L
.90613 .25 L
.90614 .25 L
.90614 .25 L
.90615 .25 L
.90615 .25 L
.90616 .25 L
Mistroke
.90616 .25 L
.90616 .25 L
.90617 .25 L
.90617 .25 L
.90618 .25 L
.90618 .25 L
.90619 .25 L
.9062 .25 L
.9062 .25 L
.90621 .25 L
.90622 .25 L
.90622 .25 L
.90623 .25 L
.90623 .25 L
.90624 .25 L
.90625 .25 L
.90625 .25 L
.90626 .25 L
.90627 .25 L
.90627 .25 L
.90628 .25 L
.90628 .25 L
.90629 .25 L
.90629 .25 L
.9063 .25 L
.90631 .25 L
.90631 .25 L
.90632 .25 L
.90632 .25 L
.90633 .25 L
.90634 .25 L
.90634 .25 L
.90635 .25 L
.90635 .25 L
.90636 .25 L
.90637 .25 L
.90637 .25 L
.90637 .25 L
.90638 .25 L
.90639 .25 L
.90639 .25 L
.9064 .25 L
.90641 .25 L
.90641 .25 L
.90642 .25 L
.90642 .25 L
.90643 .25 L
.90644 .25 L
.90644 .25 L
.90645 .25 L
Mistroke
.90646 .25 L
.90646 .25 L
.90647 .25 L
.90647 .25 L
.90648 .25 L
.90648 .25 L
.90649 .25 L
.9065 .25 L
.9065 .25 L
.90651 .25 L
.90652 .25 L
.90652 .25 L
.90653 .25 L
.90653 .25 L
.90654 .25 L
.90654 .25 L
.90655 .25 L
.90656 .25 L
.90656 .25 L
.90657 .25 L
.90657 .25 L
.90658 .25 L
.90658 .25 L
.90659 .25 L
.9066 .25 L
.9066 .25 L
.9066 .25 L
.90661 .25 L
.90662 .25 L
.90662 .25 L
.90663 .25 L
.90663 .25 L
.90664 .25 L
.90665 .25 L
.90665 .25 L
.90665 .25 L
.90666 .25 L
.90666 .25 L
.90667 .25 L
.90667 .25 L
.90668 .25 L
.90669 .25 L
.90669 .25 L
.9067 .25 L
.90671 .25 L
.90671 .25 L
.90672 .25 L
.90672 .25 L
.90673 .25 L
.90674 .25 L
Mistroke
.90674 .25 L
.90675 .25 L
.90675 .25 L
.90676 .25 L
.90677 .25 L
.90677 .25 L
.90678 .25 L
.90679 .25 L
.90679 .25 L
.9068 .25 L
.90681 .25 L
.90681 .25 L
.90681 .25 L
.90682 .25 L
.90682 .25 L
.90683 .25 L
.90683 .25 L
.90684 .25 L
.90685 .25 L
.90685 .25 L
.90686 .25 L
.90686 .25 L
.90687 .25 L
.90688 .25 L
.90688 .25 L
.90689 .25 L
.9069 .25 L
.9069 .25 L
.90691 .25 L
.90692 .25 L
.90692 .25 L
.90693 .25 L
.90693 .25 L
.90694 .25 L
.90694 .25 L
.90695 .25 L
.90695 .25 L
.90695 .25 L
.90696 .25 L
.90696 .25 L
.90697 .25 L
.90697 .25 L
.90698 .25 L
.90698 .25 L
.90698 .25 L
.90699 .25 L
.90699 .25 L
.90699 .25 L
.907 .25 L
.90701 .25 L
Mistroke
.90701 .25 L
.90702 .25 L
.90703 .25 L
.90703 .25 L
.90704 .25 L
.90705 .25 L
.90705 .25 L
.90706 .25 L
.90706 .25 L
.90707 .25 L
.90708 .25 L
.90708 .25 L
.90709 .25 L
.9071 .25 L
.9071 .25 L
.90711 .25 L
.90711 .25 L
.90712 .25 L
.90712 .25 L
.90713 .25 L
.90714 .25 L
.90714 .25 L
.90715 .25 L
.90715 .25 L
.90716 .25 L
.90717 .25 L
.90717 .25 L
.90718 .25 L
.90718 .25 L
.90719 .25 L
.90719 .25 L
.9072 .25 L
.9072 .25 L
.90721 .25 L
.90722 .25 L
.90722 .25 L
.90723 .25 L
.90724 .25 L
.90724 .25 L
.90725 .25 L
.90725 .25 L
.90726 .25 L
.90727 .25 L
.90727 .25 L
.90728 .25 L
.90729 .25 L
.90729 .25 L
.9073 .25 L
.9073 .25 L
.90731 .25 L
Mistroke
.90731 .25 L
.90732 .25 L
.90733 .25 L
.90733 .25 L
.90734 .25 L
.90734 .25 L
.90735 .25 L
.90736 .25 L
.90736 .25 L
.90737 .25 L
.90737 .25 L
.90738 .25 L
.90739 .25 L
.90739 .25 L
.9074 .25 L
.9074 .25 L
.90741 .25 L
.90741 .25 L
.90742 .25 L
.90742 .25 L
.90743 .25 L
.90743 .25 L
.90744 .25 L
.90745 .25 L
.90745 .25 L
.90746 .25 L
.90746 .25 L
.90747 .25 L
.90747 .25 L
.90748 .25 L
.90748 .25 L
.90749 .25 L
.90749 .25 L
.9075 .25 L
.90751 .25 L
.90751 .25 L
.90752 .25 L
.90752 .25 L
.90753 .25 L
.90754 .25 L
.90754 .25 L
.90755 .25 L
.90755 .25 L
.90756 .25 L
.90757 .25 L
.90757 .25 L
.90758 .25 L
.90758 .25 L
.90759 .25 L
.9076 .25 L
Mistroke
.9076 .25 L
.90761 .25 L
.90762 .25 L
.90762 .25 L
.90763 .25 L
.90763 .25 L
.90764 .25 L
.90764 .25 L
.90764 .25 L
.90765 .25 L
.90766 .25 L
.90766 .25 L
.90767 .25 L
.90768 .25 L
.90768 .25 L
.90769 .25 L
.90769 .25 L
.9077 .25 L
.90771 .25 L
.90771 .25 L
.90772 .25 L
.90773 .25 L
.90773 .25 L
.90774 .25 L
.90775 .25 L
.90775 .25 L
.90776 .25 L
.90776 .25 L
.90777 .25 L
.90777 .25 L
.90777 .25 L
.90778 .25 L
.90778 .25 L
.90779 .25 L
.90779 .25 L
.9078 .25 L
.9078 .25 L
.9078 .25 L
.90781 .25 L
.90781 .25 L
.90782 .25 L
.90782 .25 L
.90782 .25 L
.90783 .25 L
.90784 .25 L
.90785 .25 L
.90785 .25 L
.90786 .25 L
.90786 .25 L
.90787 .25 L
Mistroke
.90788 .25 L
.90788 .25 L
.90789 .25 L
.9079 .25 L
.9079 .25 L
.90791 .25 L
.90792 .25 L
.90792 .25 L
.90792 .25 L
.90793 .25 L
.90794 .25 L
.90794 .25 L
.90795 .25 L
.90795 .25 L
.90796 .25 L
.90797 .25 L
.90797 .25 L
.90798 .25 L
.90798 .25 L
.90799 .25 L
.908 .25 L
.908 .25 L
.90801 .25 L
.90801 .25 L
.90802 .25 L
.90802 .25 L
.90803 .25 L
.90803 .25 L
.90804 .25 L
.90805 .25 L
.90805 .25 L
.90806 .25 L
.90807 .25 L
.90807 .25 L
.90808 .25 L
.90808 .25 L
.90809 .25 L
.9081 .25 L
.9081 .25 L
.90811 .25 L
.90812 .25 L
.90812 .25 L
.90812 .25 L
.90813 .25 L
.90814 .25 L
.90814 .25 L
.90815 .25 L
.90816 .25 L
.90816 .25 L
.90817 .25 L
Mistroke
.90817 .25 L
.90818 .25 L
.90819 .25 L
.90819 .25 L
.9082 .25 L
.9082 .25 L
.90821 .25 L
.90822 .25 L
.90822 .25 L
.90822 .25 L
.90823 .25 L
.90824 .25 L
.90824 .25 L
.90825 .25 L
.90825 .25 L
.90826 .25 L
.90826 .25 L
.90827 .25 L
.90827 .25 L
.90828 .25 L
.90829 .25 L
.90829 .25 L
.9083 .25 L
.9083 .25 L
.90831 .25 L
.90831 .25 L
.90832 .25 L
.90832 .25 L
.90833 .25 L
.90834 .25 L
.90834 .25 L
.90835 .25 L
.90835 .25 L
.90836 .25 L
.90836 .25 L
.90837 .25 L
.90838 .25 L
.90838 .25 L
.90839 .25 L
.9084 .25 L
.9084 .25 L
.90841 .25 L
.90841 .25 L
.90842 .25 L
.90843 .25 L
.90843 .25 L
.90844 .25 L
.90845 .25 L
.90845 .25 L
.90846 .25 L
Mistroke
.90846 .25 L
.90846 .25 L
.90847 .25 L
.90847 .25 L
.90848 .25 L
.90849 .25 L
.90849 .25 L
.9085 .25 L
.90851 .25 L
.90851 .25 L
.90852 .25 L
.90852 .25 L
.90853 .25 L
.90854 .25 L
.90854 .25 L
.90855 .25 L
.90856 .25 L
.90856 .25 L
.90857 .25 L
.90858 .25 L
.90858 .25 L
.90858 .25 L
.90859 .25 L
.90859 .25 L
.9086 .25 L
.9086 .25 L
.90861 .25 L
.90861 .25 L
.90862 .25 L
.90862 .25 L
.90862 .25 L
.90863 .25 L
.90863 .25 L
.90863 .25 L
.90864 .25 L
.90864 .25 L
.90865 .25 L
.90866 .25 L
.90866 .25 L
.90867 .25 L
.90868 .25 L
.90868 .25 L
.90869 .25 L
.90869 .25 L
.9087 .25 L
.90871 .25 L
.90871 .25 L
.90872 .25 L
.90872 .25 L
.90873 .25 L
Mistroke
.90874 .25 L
.90874 .25 L
.90875 .25 L
.90875 .25 L
.90876 .25 L
.90877 .25 L
.90877 .25 L
.90878 .25 L
.90878 .25 L
.90879 .25 L
.90879 .25 L
.9088 .25 L
.90881 .25 L
.90881 .25 L
.90882 .25 L
.90883 .25 L
.90883 .25 L
.90884 .25 L
.90884 .25 L
.90884 .25 L
.90885 .25 L
.90886 .25 L
.90886 .25 L
.90887 .25 L
.90888 .25 L
.90888 .25 L
.90889 .25 L
.9089 .25 L
.9089 .25 L
.90891 .25 L
.90891 .25 L
.90892 .25 L
.90893 .25 L
.90893 .25 L
.90894 .25 L
.90894 .25 L
.90895 .25 L
.90896 .25 L
.90896 .25 L
.90897 .25 L
.90897 .25 L
.90898 .25 L
.90899 .25 L
.90899 .25 L
.909 .25 L
.909 .25 L
.90901 .25 L
.90901 .25 L
.90902 .25 L
.90903 .25 L
Mistroke
.90903 .25 L
.90904 .25 L
.90904 .25 L
.90905 .25 L
.90905 .25 L
.90906 .25 L
.90907 .25 L
.90907 .25 L
.90908 .25 L
.90909 .25 L
.90909 .25 L
.9091 .25 L
.9091 .25 L
.90911 .25 L
.90912 .25 L
.90912 .25 L
.90913 .25 L
.90914 .25 L
.90914 .25 L
.90915 .25 L
.90915 .25 L
.90916 .25 L
.90916 .25 L
.90917 .25 L
.90918 .25 L
.90918 .25 L
.90919 .25 L
.90919 .25 L
.9092 .25 L
.90921 .25 L
.90921 .25 L
.90922 .25 L
.90922 .25 L
.90923 .25 L
.90924 .25 L
.90924 .25 L
.90925 .25 L
.90925 .25 L
.90926 .25 L
.90926 .25 L
.90927 .25 L
.90927 .25 L
.90928 .25 L
.90928 .25 L
.90929 .25 L
.90929 .25 L
.9093 .25 L
.90931 .25 L
.90931 .25 L
.90932 .25 L
Mistroke
.90932 .25 L
.90933 .25 L
.90933 .25 L
.90934 .25 L
.90934 .25 L
.90935 .25 L
.90935 .25 L
.90936 .25 L
.90937 .25 L
.90937 .25 L
.90938 .25 L
.90938 .25 L
.90939 .25 L
.9094 .25 L
.9094 .25 L
.90941 .25 L
.90941 .25 L
.90942 .25 L
.90943 .25 L
.90943 .25 L
.90944 .25 L
.90945 .25 L
.90945 .25 L
.90946 .25 L
.90947 .25 L
.90947 .25 L
.90948 .25 L
.90948 .25 L
.90949 .25 L
.90949 .25 L
.90949 .25 L
.9095 .25 L
.90951 .25 L
.90951 .25 L
.90952 .25 L
.90953 .25 L
.90953 .25 L
.90954 .25 L
.90954 .25 L
.90955 .25 L
.90956 .25 L
.90956 .25 L
.90957 .25 L
.90958 .25 L
.90958 .25 L
.90959 .25 L
.9096 .25 L
.9096 .25 L
.90961 .25 L
.90961 .25 L
Mistroke
.90962 .25 L
.90962 .25 L
.90962 .25 L
.90963 .25 L
.90963 .25 L
.90964 .25 L
.90964 .25 L
.90965 .25 L
.90965 .25 L
.90965 .25 L
.90966 .25 L
.90966 .25 L
.90966 .25 L
.90967 .25 L
.90967 .25 L
.90968 .25 L
.90969 .25 L
.90969 .25 L
.9097 .25 L
.90971 .25 L
.90971 .25 L
.90972 .25 L
.90973 .25 L
.90973 .25 L
.90974 .25 L
.90975 .25 L
.90975 .25 L
.90976 .25 L
.90976 .25 L
.90977 .25 L
.90977 .25 L
.90978 .25 L
.90979 .25 L
.90979 .25 L
.9098 .25 L
.9098 .25 L
.90981 .25 L
.90982 .25 L
.90982 .25 L
.90983 .25 L
.90983 .25 L
.90984 .25 L
.90985 .25 L
.90985 .25 L
.90986 .25 L
.90986 .25 L
.90987 .25 L
.90987 .25 L
.90988 .25 L
.90988 .25 L
Mistroke
.90989 .25 L
.9099 .25 L
.9099 .25 L
.90991 .25 L
.90992 .25 L
.90992 .25 L
.90993 .25 L
.90993 .25 L
.90994 .25 L
.90995 .25 L
.90995 .25 L
.90996 .25 L
.90997 .25 L
.90997 .25 L
.90997 .25 L
.90998 .25 L
.90999 .25 L
.90999 .25 L
.91 .25 L
.91001 .25 L
.91001 .25 L
.91002 .25 L
.91002 .25 L
.91003 .25 L
.91004 .25 L
.91004 .25 L
.91005 .25 L
.91005 .25 L
.91006 .25 L
.91007 .25 L
.91007 .25 L
.91007 .25 L
.91008 .25 L
.91009 .25 L
.91009 .25 L
.9101 .25 L
.9101 .25 L
.91011 .25 L
.91011 .25 L
.91012 .25 L
.91012 .25 L
.91013 .25 L
.91014 .25 L
.91014 .25 L
.91015 .25 L
.91015 .25 L
.91016 .25 L
.91016 .25 L
.91017 .25 L
.91017 .25 L
Mistroke
.91018 .25 L
.91019 .25 L
.91019 .25 L
.9102 .25 L
.9102 .25 L
.91021 .25 L
.91021 .25 L
.91022 .25 L
.91023 .25 L
.91023 .25 L
.91024 .25 L
.91025 .25 L
.91025 .25 L
.91026 .25 L
.91026 .25 L
.91027 .25 L
.91028 .25 L
.91028 .25 L
.91029 .25 L
.9103 .25 L
.9103 .25 L
.91031 .25 L
.91031 .25 L
.91031 .25 L
.91032 .25 L
.91032 .25 L
.91033 .25 L
.91034 .25 L
.91034 .25 L
.91035 .25 L
.91036 .25 L
.91036 .25 L
.91037 .25 L
.91037 .25 L
.91038 .25 L
.91039 .25 L
.91039 .25 L
.9104 .25 L
.91041 .25 L
.91041 .25 L
.91042 .25 L
.91043 .25 L
.91043 .25 L
.91043 .25 L
.91044 .25 L
.91044 .25 L
.91045 .25 L
.91045 .25 L
.91046 .25 L
.91046 .25 L
Mistroke
.91047 .25 L
.91047 .25 L
.91047 .25 L
.91048 .25 L
.91048 .25 L
.91049 .25 L
.91049 .25 L
.91049 .25 L
.9105 .25 L
.91051 .25 L
.91051 .25 L
.91052 .25 L
.91053 .25 L
.91053 .25 L
.91054 .25 L
.91054 .25 L
.91055 .25 L
.91056 .25 L
.91056 .25 L
.91057 .25 L
.91058 .25 L
.91058 .25 L
.91059 .25 L
.91059 .25 L
.9106 .25 L
.9106 .25 L
.91061 .25 L
.91062 .25 L
.91062 .25 L
.91063 .25 L
.91063 .25 L
.91064 .25 L
.91065 .25 L
.91065 .25 L
.91066 .25 L
.91066 .25 L
.91067 .25 L
.91068 .25 L
.91068 .25 L
.91069 .25 L
.91069 .25 L
.91069 .25 L
.9107 .25 L
.91071 .25 L
.91071 .25 L
.91072 .25 L
.91073 .25 L
.91073 .25 L
.91074 .25 L
.91075 .25 L
Mistroke
.91075 .25 L
.91076 .25 L
.91076 .25 L
.91077 .25 L
.91078 .25 L
.91078 .25 L
.91079 .25 L
.9108 .25 L
.9108 .25 L
.91081 .25 L
.91081 .25 L
.91082 .25 L
.91082 .25 L
.91083 .25 L
.91084 .25 L
.91084 .25 L
.91085 .25 L
.91085 .25 L
.91086 .25 L
.91087 .25 L
.91087 .25 L
.91088 .25 L
.91088 .25 L
.91089 .25 L
.91089 .25 L
.9109 .25 L
.9109 .25 L
.91091 .25 L
.91092 .25 L
.91092 .25 L
.91092 .25 L
.91093 .25 L
.91094 .25 L
.91094 .25 L
.91095 .25 L
.91095 .25 L
.91096 .25 L
.91097 .25 L
.91097 .25 L
.91097 .25 L
.91098 .25 L
.91099 .25 L
.91099 .25 L
.911 .25 L
.911 .25 L
.91101 .25 L
.91101 .25 L
.91102 .25 L
.91103 .25 L
.91103 .25 L
Mistroke
.91104 .25 L
.91104 .25 L
.91105 .25 L
.91106 .25 L
.91106 .25 L
.91107 .25 L
.91108 .25 L
.91108 .25 L
.91109 .25 L
.91109 .25 L
.9111 .25 L
.91111 .25 L
.91111 .25 L
.91112 .25 L
.91113 .25 L
.91113 .25 L
.91113 .25 L
.91114 .25 L
.91114 .25 L
.91115 .25 L
.91115 .25 L
.91116 .25 L
.91117 .25 L
.91117 .25 L
.91118 .25 L
.91119 .25 L
.91119 .25 L
.9112 .25 L
.9112 .25 L
.91121 .25 L
.91122 .25 L
.91122 .25 L
.91123 .25 L
.91124 .25 L
.91124 .25 L
.91125 .25 L
.91125 .25 L
.91126 .25 L
.91126 .25 L
.91127 .25 L
.91127 .25 L
.91128 .25 L
.91128 .25 L
.91129 .25 L
.91129 .25 L
.91129 .25 L
.9113 .25 L
.9113 .25 L
.9113 .25 L
.91131 .25 L
Mistroke
.91131 .25 L
.91132 .25 L
.91132 .25 L
.91133 .25 L
.91134 .25 L
.91134 .25 L
.91135 .25 L
.91136 .25 L
.91136 .25 L
.91137 .25 L
.91137 .25 L
.91138 .25 L
.91139 .25 L
.91139 .25 L
.9114 .25 L
.91141 .25 L
.91141 .25 L
.91142 .25 L
.91142 .25 L
.91143 .25 L
.91143 .25 L
.91144 .25 L
.91145 .25 L
.91145 .25 L
.91146 .25 L
.91146 .25 L
.91147 .25 L
.91147 .25 L
.91148 .25 L
.91149 .25 L
.91149 .25 L
.9115 .25 L
.9115 .25 L
.91151 .25 L
.91151 .25 L
.91152 .25 L
.91152 .25 L
.91153 .25 L
.91154 .25 L
.91154 .25 L
.91155 .25 L
.91156 .25 L
.91156 .25 L
.91157 .25 L
.91158 .25 L
.91158 .25 L
.91159 .25 L
.9116 .25 L
.9116 .25 L
.91161 .25 L
Mistroke
.91161 .25 L
.91162 .25 L
.91162 .25 L
.91163 .25 L
.91164 .25 L
.91164 .25 L
.91165 .25 L
.91165 .25 L
.91166 .25 L
.91167 .25 L
.91167 .25 L
.91168 .25 L
.91168 .25 L
.91169 .25 L
.9117 .25 L
.9117 .25 L
.91171 .25 L
.91171 .25 L
.91172 .25 L
.91172 .25 L
.91173 .25 L
.91173 .25 L
.91174 .25 L
.91174 .25 L
.91175 .25 L
.91175 .25 L
.91176 .25 L
.91177 .25 L
.91177 .25 L
.91178 .25 L
.91178 .25 L
.91179 .25 L
.91179 .25 L
.9118 .25 L
.91181 .25 L
.91181 .25 L
.91181 .25 L
.91182 .25 L
.91183 .25 L
.91183 .25 L
.91184 .25 L
.91184 .25 L
.91185 .25 L
.91186 .25 L
.91186 .25 L
.91187 .25 L
.91187 .25 L
.91188 .25 L
.91189 .25 L
.91189 .25 L
Mistroke
.9119 .25 L
.9119 .25 L
.91191 .25 L
.91192 .25 L
.91192 .25 L
.91193 .25 L
.91194 .25 L
.91194 .25 L
.91195 .25 L
.91195 .25 L
.91196 .25 L
.91196 .25 L
.91196 .25 L
.91197 .25 L
.91198 .25 L
.91198 .25 L
.91199 .25 L
.912 .25 L
.912 .25 L
.91201 .25 L
.91201 .25 L
.91202 .25 L
.91203 .25 L
.91203 .25 L
.91204 .25 L
.91205 .25 L
.91205 .25 L
.91206 .25 L
.91207 .25 L
.91207 .25 L
.91208 .25 L
.91208 .25 L
.91209 .25 L
.91209 .25 L
.9121 .25 L
.9121 .25 L
.9121 .25 L
.91211 .25 L
.91211 .25 L
.91212 .25 L
.91212 .25 L
.91212 .25 L
.91213 .25 L
.91213 .25 L
.91214 .25 L
.91214 .25 L
.91215 .25 L
.91215 .25 L
.91216 .25 L
.91217 .25 L
Mistroke
.91217 .25 L
.91218 .25 L
.91218 .25 L
.91219 .25 L
.9122 .25 L
.9122 .25 L
.91221 .25 L
.91222 .25 L
.91222 .25 L
.91223 .25 L
.91224 .25 L
.91224 .25 L
.91224 .25 L
.91225 .25 L
.91226 .25 L
.91226 .25 L
.91227 .25 L
.91228 .25 L
.91228 .25 L
.91229 .25 L
.91229 .25 L
.9123 .25 L
.9123 .25 L
.91231 .25 L
.91232 .25 L
.91232 .25 L
.91233 .25 L
.91233 .25 L
.91234 .25 L
.91234 .25 L
.91235 .25 L
.91235 .25 L
.91236 .25 L
.91237 .25 L
.91237 .25 L
.91238 .25 L
.91239 .25 L
.91239 .25 L
.9124 .25 L
.91241 .25 L
.91241 .25 L
.91242 .25 L
.91242 .25 L
.91243 .25 L
.91244 .25 L
.91244 .25 L
.91245 .25 L
.91245 .25 L
.91246 .25 L
.91246 .25 L
Mistroke
.91247 .25 L
.91248 .25 L
.91248 .25 L
.91249 .25 L
.91249 .25 L
.9125 .25 L
.91251 .25 L
.91251 .25 L
.91252 .25 L
.91252 .25 L
.91253 .25 L
.91254 .25 L
.91254 .25 L
.91254 .25 L
.91255 .25 L
.91256 .25 L
.91256 .25 L
.91257 .25 L
.91258 .25 L
.91258 .25 L
.91259 .25 L
.9126 .25 L
.9126 .25 L
.91261 .25 L
.91261 .25 L
.91262 .25 L
.91263 .25 L
.91263 .25 L
.91264 .25 L
.91264 .25 L
.91265 .25 L
.91266 .25 L
.91266 .25 L
.91267 .25 L
.91267 .25 L
.91268 .25 L
.91269 .25 L
.91269 .25 L
.9127 .25 L
.9127 .25 L
.91271 .25 L
.91271 .25 L
.91272 .25 L
.91273 .25 L
.91273 .25 L
.91274 .25 L
.91274 .25 L
.91275 .25 L
.91275 .25 L
.91276 .25 L
Mistroke
.91277 .25 L
.91277 .25 L
.91277 .25 L
.91278 .25 L
.91279 .25 L
.91279 .25 L
.9128 .25 L
.9128 .25 L
.91281 .25 L
.91282 .25 L
.91282 .25 L
.91282 .25 L
.91283 .25 L
.91284 .25 L
.91284 .25 L
.91285 .25 L
.91285 .25 L
.91286 .25 L
.91286 .25 L
.91287 .25 L
.91288 .25 L
.91288 .25 L
.91289 .25 L
.91289 .25 L
.9129 .25 L
.91291 .25 L
.91291 .25 L
.91292 .25 L
.91293 .25 L
.91293 .25 L
.91294 .25 L
.91294 .25 L
.91295 .25 L
.91296 .25 L
.91296 .25 L
.91297 .25 L
.91298 .25 L
.91298 .25 L
.91298 .25 L
.91299 .25 L
.91299 .25 L
.913 .25 L
.913 .25 L
.91301 .25 L
.91302 .25 L
.91302 .25 L
.91303 .25 L
.91304 .25 L
.91304 .25 L
.91305 .25 L
Mistroke
.91305 .25 L
.91306 .25 L
.91307 .25 L
.91307 .25 L
.91308 .25 L
.91309 .25 L
.91309 .25 L
.9131 .25 L
.9131 .25 L
.91311 .25 L
.91311 .25 L
.91312 .25 L
.91312 .25 L
.91313 .25 L
.91313 .25 L
.91314 .25 L
.91314 .25 L
.91314 .25 L
.91315 .25 L
.91315 .25 L
.91315 .25 L
.91316 .25 L
.91316 .25 L
.91317 .25 L
.91317 .25 L
.91318 .25 L
.91319 .25 L
.91319 .25 L
.9132 .25 L
.91321 .25 L
.91321 .25 L
.91322 .25 L
.91322 .25 L
.91323 .25 L
.91324 .25 L
.91324 .25 L
.91325 .25 L
.91326 .25 L
.91326 .25 L
.91327 .25 L
.91327 .25 L
.91328 .25 L
.91328 .25 L
.91329 .25 L
.9133 .25 L
.9133 .25 L
.91331 .25 L
.91331 .25 L
.91332 .25 L
.91332 .25 L
Mistroke
.91333 .25 L
.91334 .25 L
.91334 .25 L
.91335 .25 L
.91335 .25 L
.91336 .25 L
.91336 .25 L
.91337 .25 L
.91337 .25 L
.91338 .25 L
.91339 .25 L
.91339 .25 L
.9134 .25 L
.91341 .25 L
.91341 .25 L
.91342 .25 L
.91343 .25 L
.91343 .25 L
.91344 .25 L
.91345 .25 L
.91345 .25 L
.91346 .25 L
.91346 .25 L
.91347 .25 L
.91347 .25 L
.91348 .25 L
.91349 .25 L
.91349 .25 L
.9135 .25 L
.9135 .25 L
.91351 .25 L
.91352 .25 L
.91352 .25 L
.91353 .25 L
.91353 .25 L
.91354 .25 L
.91355 .25 L
.91355 .25 L
.91356 .25 L
.91356 .25 L
.91357 .25 L
.91357 .25 L
.91358 .25 L
.91358 .25 L
.91359 .25 L
.91359 .25 L
.9136 .25 L
.9136 .25 L
.91361 .25 L
.91362 .25 L
Mistroke
.91362 .25 L
.91363 .25 L
.91363 .25 L
.91364 .25 L
.91364 .25 L
.91365 .25 L
.91366 .25 L
.91366 .25 L
.91366 .25 L
.91367 .25 L
.91368 .25 L
.91368 .25 L
.91369 .25 L
.91369 .25 L
.9137 .25 L
.91371 .25 L
.91371 .25 L
.91372 .25 L
.91372 .25 L
.91373 .25 L
.91374 .25 L
.91374 .25 L
.91375 .25 L
.91375 .25 L
.91376 .25 L
.91377 .25 L
.91377 .25 L
.91378 .25 L
.91379 .25 L
.91379 .25 L
.9138 .25 L
.9138 .25 L
.91381 .25 L
.91381 .25 L
.91381 .25 L
.91382 .25 L
.91383 .25 L
.91383 .25 L
.91384 .25 L
.91385 .25 L
.91385 .25 L
.91386 .25 L
.91387 .25 L
.91387 .25 L
.91388 .25 L
.91389 .25 L
.91389 .25 L
.9139 .25 L
.9139 .25 L
.91391 .25 L
Mistroke
.91392 .25 L
.91392 .25 L
.91393 .25 L
.91393 .25 L
.91394 .25 L
.91394 .25 L
.91395 .25 L
.91395 .25 L
.91395 .25 L
.91396 .25 L
.91396 .25 L
.91397 .25 L
.91397 .25 L
.91398 .25 L
.91398 .25 L
.91398 .25 L
.91399 .25 L
.91399 .25 L
.914 .25 L
.914 .25 L
.91401 .25 L
.91402 .25 L
.91402 .25 L
.91403 .25 L
.91404 .25 L
.91404 .25 L
.91405 .25 L
.91405 .25 L
.91406 .25 L
.91407 .25 L
.91407 .25 L
.91408 .25 L
.91409 .25 L
.91409 .25 L
.91409 .25 L
.9141 .25 L
.91411 .25 L
.91411 .25 L
.91412 .25 L
.91413 .25 L
.91413 .25 L
.91414 .25 L
.91414 .25 L
.91415 .25 L
.91415 .25 L
.91416 .25 L
.91417 .25 L
.91417 .25 L
.91418 .25 L
.91419 .25 L
Mistroke
.91419 .25 L
.91419 .25 L
.9142 .25 L
.91421 .25 L
.91421 .25 L
.91422 .25 L
.91423 .25 L
.91423 .25 L
.91424 .25 L
.91424 .25 L
.91425 .25 L
.91426 .25 L
.91426 .25 L
.91427 .25 L
.91428 .25 L
.91428 .25 L
.91429 .25 L
.91429 .25 L
.9143 .25 L
.9143 .25 L
.91431 .25 L
.91432 .25 L
.91432 .25 L
.91433 .25 L
.91433 .25 L
.91434 .25 L
.91435 .25 L
.91435 .25 L
.91436 .25 L
.91436 .25 L
.91437 .25 L
.91438 .25 L
.91438 .25 L
.91439 .25 L
.91439 .25 L
.91439 .25 L
.9144 .25 L
.91441 .25 L
.91441 .25 L
.91442 .25 L
.91442 .25 L
.91443 .25 L
.91443 .25 L
.91444 .25 L
.91445 .25 L
.91445 .25 L
.91446 .25 L
.91446 .25 L
.91447 .25 L
.91447 .25 L
Mistroke
.91448 .25 L
.91448 .25 L
.91449 .25 L
.91449 .25 L
.9145 .25 L
.91451 .25 L
.91451 .25 L
.91452 .25 L
.91452 .25 L
.91453 .25 L
.91454 .25 L
.91454 .25 L
.91455 .25 L
.91455 .25 L
.91456 .25 L
.91457 .25 L
.91457 .25 L
.91458 .25 L
.91458 .25 L
.91459 .25 L
.9146 .25 L
.9146 .25 L
.91461 .25 L
.91462 .25 L
.91462 .25 L
.91463 .25 L
.91463 .25 L
.91463 .25 L
.91464 .25 L
.91465 .25 L
.91465 .25 L
.91466 .25 L
.91467 .25 L
.91467 .25 L
.91468 .25 L
.91468 .25 L
.91469 .25 L
.9147 .25 L
.9147 .25 L
.91471 .25 L
.91471 .25 L
.91472 .25 L
.91473 .25 L
.91473 .25 L
.91474 .25 L
.91475 .25 L
.91475 .25 L
.91476 .25 L
.91476 .25 L
.91477 .25 L
Mistroke
.91477 .25 L
.91477 .25 L
.91478 .25 L
.91478 .25 L
.91479 .25 L
.91479 .25 L
.91479 .25 L
.9148 .25 L
.9148 .25 L
.91481 .25 L
.91481 .25 L
.91481 .25 L
.91482 .25 L
.91483 .25 L
.91483 .25 L
.91484 .25 L
.91485 .25 L
.91485 .25 L
.91486 .25 L
.91486 .25 L
.91487 .25 L
.91488 .25 L
.91488 .25 L
.91489 .25 L
.9149 .25 L
.9149 .25 L
.91491 .25 L
.91491 .25 L
.91492 .25 L
.91492 .25 L
.91493 .25 L
.91494 .25 L
.91494 .25 L
.91495 .25 L
.91496 .25 L
.91496 .25 L
.91497 .25 L
.91497 .25 L
.91498 .25 L
.91498 .25 L
.91499 .25 L
.915 .25 L
.915 .25 L
.91501 .25 L
.91501 .25 L
.91502 .25 L
.91502 .25 L
.91503 .25 L
.91504 .25 L
.91504 .25 L
Mistroke
.91505 .25 L
.91506 .25 L
.91506 .25 L
.91507 .25 L
.91507 .25 L
.91508 .25 L
.91509 .25 L
.91509 .25 L
.9151 .25 L
.91511 .25 L
.91511 .25 L
.91512 .25 L
.91512 .25 L
.91513 .25 L
.91513 .25 L
.91514 .25 L
.91515 .25 L
.91515 .25 L
.91516 .25 L
.91516 .25 L
.91517 .25 L
.91517 .25 L
.91518 .25 L
.91519 .25 L
.91519 .25 L
.9152 .25 L
.9152 .25 L
.91521 .25 L
.91522 .25 L
.91522 .25 L
.91522 .25 L
.91523 .25 L
.91524 .25 L
.91524 .25 L
.91524 .25 L
.91525 .25 L
.91526 .25 L
.91526 .25 L
.91527 .25 L
.91528 .25 L
.91528 .25 L
.91529 .25 L
.91529 .25 L
.9153 .25 L
.9153 .25 L
.91531 .25 L
.91531 .25 L
.91532 .25 L
.91532 .25 L
.91533 .25 L
Mistroke
.91534 .25 L
.91534 .25 L
.91535 .25 L
.91535 .25 L
.91536 .25 L
.91536 .25 L
.91537 .25 L
.91538 .25 L
.91538 .25 L
.91539 .25 L
.9154 .25 L
.9154 .25 L
.91541 .25 L
.91541 .25 L
.91542 .25 L
.91543 .25 L
.91543 .25 L
.91544 .25 L
.91545 .25 L
.91545 .25 L
.91545 .25 L
.91546 .25 L
.91546 .25 L
.91547 .25 L
.91547 .25 L
.91548 .25 L
.91549 .25 L
.91549 .25 L
.9155 .25 L
.91551 .25 L
.91551 .25 L
.91552 .25 L
.91553 .25 L
.91553 .25 L
.91554 .25 L
.91554 .25 L
.91555 .25 L
.91556 .25 L
.91556 .25 L
.91557 .25 L
.91558 .25 L
.91558 .25 L
.91559 .25 L
.91559 .25 L
.91559 .25 L
.9156 .25 L
.9156 .25 L
.91561 .25 L
.91561 .25 L
.91561 .25 L
Mistroke
.91562 .25 L
.91562 .25 L
.91563 .25 L
.91563 .25 L
.91563 .25 L
.91564 .25 L
.91564 .25 L
.91565 .25 L
.91566 .25 L
.91566 .25 L
.91567 .25 L
.91568 .25 L
.91568 .25 L
.91569 .25 L
.91569 .25 L
.9157 .25 L
.91571 .25 L
.91571 .25 L
.91572 .25 L
.91573 .25 L
.91573 .25 L
.91574 .25 L
.91574 .25 L
.91575 .25 L
.91575 .25 L
.91576 .25 L
.91577 .25 L
.91577 .25 L
.91578 .25 L
.91578 .25 L
.91579 .25 L
.9158 .25 L
.9158 .25 L
.91581 .25 L
.91581 .25 L
.91582 .25 L
.91583 .25 L
.91583 .25 L
.91584 .25 L
.91584 .25 L
.91585 .25 L
.91585 .25 L
.91586 .25 L
.91587 .25 L
.91587 .25 L
.91588 .25 L
.91588 .25 L
.91589 .25 L
.9159 .25 L
.9159 .25 L
Mistroke
.91591 .25 L
.91592 .25 L
.91592 .25 L
.91593 .25 L
.91594 .25 L
.91594 .25 L
.91594 .25 L
.91595 .25 L
.91596 .25 L
.91596 .25 L
.91597 .25 L
.91598 .25 L
.91598 .25 L
.91599 .25 L
.91599 .25 L
.916 .25 L
.916 .25 L
.91601 .25 L
.91602 .25 L
.91602 .25 L
.91603 .25 L
.91603 .25 L
.91604 .25 L
.91604 .25 L
.91605 .25 L
.91605 .25 L
.91606 .25 L
.91607 .25 L
.91607 .25 L
.91608 .25 L
.91609 .25 L
.91609 .25 L
.9161 .25 L
.91611 .25 L
.91611 .25 L
.91612 .25 L
.91612 .25 L
.91613 .25 L
.91614 .25 L
.91614 .25 L
.91615 .25 L
.91615 .25 L
.91616 .25 L
.91617 .25 L
.91617 .25 L
.91618 .25 L
.91618 .25 L
.91619 .25 L
.91619 .25 L
.9162 .25 L
Mistroke
.91621 .25 L
.91621 .25 L
.91622 .25 L
.91623 .25 L
.91623 .25 L
.91624 .25 L
.91624 .25 L
.91624 .25 L
.91625 .25 L
.91626 .25 L
.91626 .25 L
.91627 .25 L
.91627 .25 L
.91628 .25 L
.91628 .25 L
.91629 .25 L
.9163 .25 L
.9163 .25 L
.91631 .25 L
.91631 .25 L
.91632 .25 L
.91632 .25 L
.91633 .25 L
.91633 .25 L
.91634 .25 L
.91634 .25 L
.91635 .25 L
.91636 .25 L
.91636 .25 L
.91637 .25 L
.91637 .25 L
.91638 .25 L
.91639 .25 L
.91639 .25 L
.9164 .25 L
.9164 .25 L
.91641 .25 L
.91642 .25 L
.91642 .25 L
.91643 .25 L
.91643 .25 L
.91644 .25 L
.91645 .25 L
.91645 .25 L
.91646 .25 L
.91647 .25 L
.91647 .25 L
.91648 .25 L
.91648 .25 L
.91648 .25 L
Mistroke
.91649 .25 L
.9165 .25 L
.9165 .25 L
.91651 .25 L
.91652 .25 L
.91652 .25 L
.91653 .25 L
.91653 .25 L
.91654 .25 L
.91655 .25 L
.91655 .25 L
.91656 .25 L
.91656 .25 L
.91657 .25 L
.91658 .25 L
.91658 .25 L
.91659 .25 L
.9166 .25 L
.9166 .25 L
.91661 .25 L
.91661 .25 L
.91662 .25 L
.91662 .25 L
.91662 .25 L
.91663 .25 L
.91663 .25 L
.91664 .25 L
.91664 .25 L
.91664 .25 L
.91665 .25 L
.91665 .25 L
.91666 .25 L
.91666 .25 L
.91666 .25 L
.91667 .25 L
.91668 .25 L
.91668 .25 L
.91669 .25 L
.9167 .25 L
.9167 .25 L
.91671 .25 L
.91671 .25 L
.91672 .25 L
.91673 .25 L
.91673 .25 L
.91674 .25 L
.91675 .25 L
.91675 .25 L
.91676 .25 L
.91676 .25 L
Mistroke
.91677 .25 L
.91677 .25 L
.91678 .25 L
.91679 .25 L
.91679 .25 L
.9168 .25 L
.91681 .25 L
.91681 .25 L
.91682 .25 L
.91682 .25 L
.91683 .25 L
.91683 .25 L
.91684 .25 L
.91685 .25 L
.91685 .25 L
.91686 .25 L
.91686 .25 L
.91687 .25 L
.91687 .25 L
.91688 .25 L
.91689 .25 L
.91689 .25 L
.9169 .25 L
.91691 .25 L
.91691 .25 L
.91692 .25 L
.91692 .25 L
.91693 .25 L
.91694 .25 L
.91694 .25 L
.91695 .25 L
.91696 .25 L
.91696 .25 L
.91697 .25 L
.91697 .25 L
.91698 .25 L
.91698 .25 L
.91699 .25 L
.917 .25 L
.917 .25 L
.91701 .25 L
.91701 .25 L
.91702 .25 L
.91702 .25 L
.91703 .25 L
.91704 .25 L
.91704 .25 L
.91705 .25 L
.91706 .25 L
.91706 .25 L
Mistroke
.91707 .25 L
.91707 .25 L
.91708 .25 L
.91708 .25 L
.91709 .25 L
.91709 .25 L
.9171 .25 L
.9171 .25 L
.91711 .25 L
.91711 .25 L
.91712 .25 L
.91713 .25 L
.91713 .25 L
.91714 .25 L
.91714 .25 L
.91715 .25 L
.91715 .25 L
.91716 .25 L
.91716 .25 L
.91717 .25 L
.91717 .25 L
.91718 .25 L
.91719 .25 L
.91719 .25 L
.9172 .25 L
.9172 .25 L
.91721 .25 L
.91722 .25 L
.91722 .25 L
.91723 .25 L
.91723 .25 L
.91724 .25 L
.91725 .25 L
.91725 .25 L
.91726 .25 L
.91727 .25 L
.91727 .25 L
.91728 .25 L
.91728 .25 L
.91729 .25 L
.9173 .25 L
.9173 .25 L
.91731 .25 L
.91731 .25 L
.91731 .25 L
.91732 .25 L
.91733 .25 L
.91733 .25 L
.91734 .25 L
.91735 .25 L
Mistroke
.91735 .25 L
.91736 .25 L
.91736 .25 L
.91737 .25 L
.91738 .25 L
.91738 .25 L
.91739 .25 L
.9174 .25 L
.9174 .25 L
.91741 .25 L
.91741 .25 L
.91742 .25 L
.91743 .25 L
.91743 .25 L
.91744 .25 L
.91744 .25 L
.91744 .25 L
.91745 .25 L
.91745 .25 L
.91746 .25 L
.91746 .25 L
.91746 .25 L
.91747 .25 L
.91747 .25 L
.91748 .25 L
.91748 .25 L
.91748 .25 L
.91749 .25 L
.91749 .25 L
.9175 .25 L
.91751 .25 L
.91751 .25 L
.91752 .25 L
.91753 .25 L
.91753 .25 L
.91754 .25 L
.91755 .25 L
.91755 .25 L
.91756 .25 L
.91756 .25 L
.91757 .25 L
.91758 .25 L
.91758 .25 L
.91759 .25 L
.91759 .25 L
.9176 .25 L
.91761 .25 L
.91761 .25 L
.91762 .25 L
.91762 .25 L
Mistroke
.91763 .25 L
.91764 .25 L
.91764 .25 L
.91765 .25 L
.91765 .25 L
.91766 .25 L
.91766 .25 L
.91767 .25 L
.91768 .25 L
.91768 .25 L
.91769 .25 L
.91769 .25 L
.9177 .25 L
.9177 .25 L
.91771 .25 L
.91772 .25 L
.91772 .25 L
.91773 .25 L
.91774 .25 L
.91774 .25 L
.91775 .25 L
.91775 .25 L
.91776 .25 L
.91777 .25 L
.91777 .25 L
.91778 .25 L
.91779 .25 L
.91779 .25 L
.91779 .25 L
.9178 .25 L
.91781 .25 L
.91781 .25 L
.91782 .25 L
.91783 .25 L
.91783 .25 L
.91784 .25 L
.91784 .25 L
.91785 .25 L
.91785 .25 L
.91786 .25 L
.91787 .25 L
.91787 .25 L
.91788 .25 L
.91789 .25 L
.91789 .25 L
.91789 .25 L
.9179 .25 L
.91791 .25 L
.91791 .25 L
.91792 .25 L
Mistroke
.91792 .25 L
.91793 .25 L
.91793 .25 L
.91794 .25 L
.91794 .25 L
.91795 .25 L
.91796 .25 L
.91796 .25 L
.91797 .25 L
.91797 .25 L
.91798 .25 L
.91798 .25 L
.91798 .25 L
.91799 .25 L
.918 .25 L
.918 .25 L
.91801 .25 L
.91802 .25 L
.91802 .25 L
.91803 .25 L
.91803 .25 L
.91804 .25 L
.91805 .25 L
.91805 .25 L
.91806 .25 L
.91806 .25 L
.91807 .25 L
.91808 .25 L
.91808 .25 L
.91809 .25 L
.9181 .25 L
.9181 .25 L
.91811 .25 L
.91812 .25 L
.91812 .25 L
.91813 .25 L
.91813 .25 L
.91813 .25 L
.91814 .25 L
.91814 .25 L
.91815 .25 L
.91816 .25 L
.91816 .25 L
.91817 .25 L
.91818 .25 L
.91818 .25 L
.91819 .25 L
.91819 .25 L
.9182 .25 L
.91821 .25 L
Mistroke
.91821 .25 L
.91822 .25 L
.91823 .25 L
.91823 .25 L
.91824 .25 L
.91825 .25 L
.91825 .25 L
.91825 .25 L
.91826 .25 L
.91826 .25 L
.91827 .25 L
.91827 .25 L
.91827 .25 L
.91828 .25 L
.91829 .25 L
.91829 .25 L
.91829 .25 L
.9183 .25 L
.9183 .25 L
.9183 .25 L
.91831 .25 L
.91831 .25 L
.91832 .25 L
.91832 .25 L
.91833 .25 L
.91834 .25 L
.91834 .25 L
.91835 .25 L
.91836 .25 L
.91836 .25 L
.91837 .25 L
.91837 .25 L
.91838 .25 L
.91839 .25 L
.91839 .25 L
.9184 .25 L
.91841 .25 L
.91841 .25 L
.91842 .25 L
.91842 .25 L
.91843 .25 L
.91843 .25 L
.91844 .25 L
.91845 .25 L
.91845 .25 L
.91846 .25 L
.91846 .25 L
.91847 .25 L
.91848 .25 L
.91848 .25 L
Mistroke
.91849 .25 L
.91849 .25 L
.9185 .25 L
.91851 .25 L
.91851 .25 L
.91851 .25 L
.91852 .25 L
.91853 .25 L
.91853 .25 L
.91854 .25 L
.91855 .25 L
.91855 .25 L
.91856 .25 L
.91856 .25 L
.91857 .25 L
.91858 .25 L
.91858 .25 L
.91859 .25 L
.9186 .25 L
.9186 .25 L
.91861 .25 L
.91861 .25 L
.91862 .25 L
.91862 .25 L
.91863 .25 L
.91864 .25 L
.91864 .25 L
.91865 .25 L
.91866 .25 L
.91866 .25 L
.91867 .25 L
.91867 .25 L
.91868 .25 L
.91868 .25 L
.91869 .25 L
.9187 .25 L
.9187 .25 L
.91871 .25 L
.91871 .25 L
.91872 .25 L
.91872 .25 L
.91873 .25 L
.91874 .25 L
.91874 .25 L
.91874 .25 L
.91875 .25 L
.91876 .25 L
.91876 .25 L
.91877 .25 L
.91877 .25 L
Mistroke
.91878 .25 L
.91879 .25 L
.91879 .25 L
.91879 .25 L
.9188 .25 L
.9188 .25 L
.91881 .25 L
.91881 .25 L
.91882 .25 L
.91883 .25 L
.91883 .25 L
.91884 .25 L
.91885 .25 L
.91885 .25 L
.91886 .25 L
.91886 .25 L
.91887 .25 L
.91888 .25 L
.91888 .25 L
.91889 .25 L
.91889 .25 L
.9189 .25 L
.91891 .25 L
.91891 .25 L
.91892 .25 L
.91893 .25 L
.91893 .25 L
.91894 .25 L
.91895 .25 L
.91895 .25 L
.91895 .25 L
.91896 .25 L
.91896 .25 L
.91897 .25 L
.91897 .25 L
.91898 .25 L
.91899 .25 L
.91899 .25 L
.919 .25 L
.919 .25 L
.91901 .25 L
.91902 .25 L
.91902 .25 L
.91903 .25 L
.91904 .25 L
.91904 .25 L
.91905 .25 L
.91906 .25 L
.91906 .25 L
.91907 .25 L
Mistroke
.91907 .25 L
.91908 .25 L
.91908 .25 L
.91909 .25 L
.91909 .25 L
.91909 .25 L
.9191 .25 L
.9191 .25 L
.91911 .25 L
.91911 .25 L
.91912 .25 L
.91912 .25 L
.91912 .25 L
.91913 .25 L
.91913 .25 L
.91913 .25 L
.91914 .25 L
.91915 .25 L
.91915 .25 L
.91916 .25 L
.91917 .25 L
.91917 .25 L
.91918 .25 L
.91919 .25 L
.91919 .25 L
.9192 .25 L
.91921 .25 L
.91921 .25 L
.91922 .25 L
.91922 .25 L
.91923 .25 L
.91924 .25 L
.91924 .25 L
.91925 .25 L
.91925 .25 L
.91926 .25 L
.91926 .25 L
.91927 .25 L
.91928 .25 L
.91928 .25 L
.91929 .25 L
.91929 .25 L
.9193 .25 L
.91931 .25 L
.91931 .25 L
.91932 .25 L
.91932 .25 L
.91933 .25 L
.91933 .25 L
.91934 .25 L
Mistroke
.91934 .25 L
.91935 .25 L
.91936 .25 L
.91936 .25 L
.91937 .25 L
.91938 .25 L
.91938 .25 L
.91939 .25 L
.91939 .25 L
.9194 .25 L
.91941 .25 L
.91941 .25 L
.91942 .25 L
.91943 .25 L
.91943 .25 L
.91944 .25 L
.91944 .25 L
.91945 .25 L
.91945 .25 L
.91946 .25 L
.91947 .25 L
.91947 .25 L
.91948 .25 L
.91948 .25 L
.91949 .25 L
.9195 .25 L
.9195 .25 L
.91951 .25 L
.91951 .25 L
.91952 .25 L
.91953 .25 L
.91953 .25 L
.91954 .25 L
.91954 .25 L
.91955 .25 L
.91955 .25 L
.91956 .25 L
.91957 .25 L
.91957 .25 L
.91958 .25 L
.91958 .25 L
.91959 .25 L
.9196 .25 L
.9196 .25 L
.91961 .25 L
.91962 .25 L
.91962 .25 L
.91963 .25 L
.91964 .25 L
.91964 .25 L
Mistroke
.91964 .25 L
.91965 .25 L
.91966 .25 L
.91966 .25 L
.91967 .25 L
.91968 .25 L
.91968 .25 L
.91969 .25 L
.91969 .25 L
.9197 .25 L
.9197 .25 L
.91971 .25 L
.91972 .25 L
.91972 .25 L
.91973 .25 L
.91974 .25 L
.91974 .25 L
.91974 .25 L
.91975 .25 L
.91976 .25 L
.91976 .25 L
.91977 .25 L
.91977 .25 L
.91978 .25 L
.91978 .25 L
.91979 .25 L
.91979 .25 L
.9198 .25 L
.91981 .25 L
.91981 .25 L
.91982 .25 L
.91982 .25 L
.91983 .25 L
.91983 .25 L
.91983 .25 L
.91984 .25 L
.91985 .25 L
.91985 .25 L
.91986 .25 L
.91987 .25 L
.91987 .25 L
.91988 .25 L
.91988 .25 L
.91989 .25 L
.9199 .25 L
.9199 .25 L
.91991 .25 L
.91991 .25 L
.91992 .25 L
.91993 .25 L
Mistroke
.91993 .25 L
.91994 .25 L
.91995 .25 L
.91995 .25 L
.91996 .25 L
.91997 .25 L
.91997 .25 L
.91998 .25 L
.91998 .25 L
.91998 .25 L
.91999 .25 L
.91999 .25 L
.92 .25 L
.92001 .25 L
.92001 .25 L
.92002 .25 L
.92003 .25 L
.92003 .25 L
.92004 .25 L
.92004 .25 L
.92005 .25 L
.92006 .25 L
.92006 .25 L
.92007 .25 L
.92008 .25 L
.92008 .25 L
.92009 .25 L
.9201 .25 L
.9201 .25 L
.9201 .25 L
.92011 .25 L
.92011 .25 L
.92012 .25 L
.92012 .25 L
.92012 .25 L
.92013 .25 L
.92014 .25 L
.92014 .25 L
.92014 .25 L
.92015 .25 L
.92015 .25 L
.92015 .25 L
.92016 .25 L
.92016 .25 L
.92017 .25 L
.92017 .25 L
.92018 .25 L
.92019 .25 L
.92019 .25 L
.9202 .25 L
Mistroke
.92021 .25 L
.92021 .25 L
.92022 .25 L
.92023 .25 L
.92023 .25 L
.92024 .25 L
.92024 .25 L
.92025 .25 L
.92026 .25 L
.92026 .25 L
.92027 .25 L
.92027 .25 L
.92028 .25 L
.92028 .25 L
.92029 .25 L
.9203 .25 L
.9203 .25 L
.92031 .25 L
.92031 .25 L
.92032 .25 L
.92033 .25 L
.92033 .25 L
.92034 .25 L
.92034 .25 L
.92035 .25 L
.92036 .25 L
.92036 .25 L
.92036 .25 L
.92037 .25 L
.92038 .25 L
.92038 .25 L
.92039 .25 L
.9204 .25 L
.9204 .25 L
.92041 .25 L
.92042 .25 L
.92042 .25 L
.92043 .25 L
.92043 .25 L
.92044 .25 L
.92045 .25 L
.92045 .25 L
.92046 .25 L
.92046 .25 L
.92047 .25 L
.92048 .25 L
.92048 .25 L
.92049 .25 L
.92049 .25 L
.9205 .25 L
Mistroke
.92051 .25 L
.92051 .25 L
.92052 .25 L
.92052 .25 L
.92053 .25 L
.92053 .25 L
.92054 .25 L
.92055 .25 L
.92055 .25 L
.92056 .25 L
.92056 .25 L
.92057 .25 L
.92057 .25 L
.92058 .25 L
.92059 .25 L
.92059 .25 L
.92059 .25 L
.9206 .25 L
.92061 .25 L
.92061 .25 L
.92062 .25 L
.92062 .25 L
.92063 .25 L
.92064 .25 L
.92064 .25 L
.92064 .25 L
.92065 .25 L
.92066 .25 L
.92066 .25 L
.92067 .25 L
.92067 .25 L
.92068 .25 L
.92068 .25 L
.92069 .25 L
.9207 .25 L
.9207 .25 L
.92071 .25 L
.92071 .25 L
.92072 .25 L
.92073 .25 L
.92073 .25 L
.92074 .25 L
.92075 .25 L
.92075 .25 L
.92076 .25 L
.92076 .25 L
.92077 .25 L
.92078 .25 L
.92078 .25 L
.92079 .25 L
Mistroke
.9208 .25 L
.9208 .25 L
.9208 .25 L
.92081 .25 L
.92081 .25 L
.92082 .25 L
.92082 .25 L
.92083 .25 L
.92084 .25 L
.92084 .25 L
.92085 .25 L
.92086 .25 L
.92086 .25 L
.92087 .25 L
.92087 .25 L
.92088 .25 L
.92089 .25 L
.92089 .25 L
.9209 .25 L
.92091 .25 L
.92091 .25 L
.92092 .25 L
.92092 .25 L
.92093 .25 L
.92093 .25 L
.92094 .25 L
.92094 .25 L
.92095 .25 L
.92095 .25 L
.92096 .25 L
.92096 .25 L
.92096 .25 L
.92097 .25 L
.92097 .25 L
.92097 .25 L
.92098 .25 L
.92098 .25 L
.92099 .25 L
.92099 .25 L
.921 .25 L
.92101 .25 L
.92101 .25 L
.92102 .25 L
.92103 .25 L
.92103 .25 L
.92104 .25 L
.92104 .25 L
.92105 .25 L
.92106 .25 L
.92106 .25 L
Mistroke
.92107 .25 L
.92108 .25 L
.92108 .25 L
.92109 .25 L
.92109 .25 L
.9211 .25 L
.9211 .25 L
.92111 .25 L
.92112 .25 L
.92112 .25 L
.92113 .25 L
.92113 .25 L
.92114 .25 L
.92114 .25 L
.92115 .25 L
.92116 .25 L
.92116 .25 L
.92117 .25 L
.92117 .25 L
.92118 .25 L
.92118 .25 L
.92119 .25 L
.92119 .25 L
.9212 .25 L
.92121 .25 L
.92121 .25 L
.92122 .25 L
.92123 .25 L
.92123 .25 L
.92124 .25 L
.92125 .25 L
.92125 .25 L
.92126 .25 L
.92127 .25 L
.92127 .25 L
.92128 .25 L
.92128 .25 L
.92129 .25 L
.92129 .25 L
.9213 .25 L
.92131 .25 L
.92131 .25 L
.92132 .25 L
.92132 .25 L
.92133 .25 L
.92134 .25 L
.92134 .25 L
.92135 .25 L
.92135 .25 L
.92136 .25 L
Mistroke
.92137 .25 L
.92137 .25 L
.92138 .25 L
.92138 .25 L
.92139 .25 L
.92139 .25 L
.9214 .25 L
.9214 .25 L
.92141 .25 L
.92141 .25 L
.92142 .25 L
.92142 .25 L
.92143 .25 L
.92144 .25 L
.92144 .25 L
.92145 .25 L
.92145 .25 L
.92146 .25 L
.92146 .25 L
.92147 .25 L
.92148 .25 L
.92148 .25 L
.92148 .25 L
.92149 .25 L
.9215 .25 L
.9215 .25 L
.92151 .25 L
.92151 .25 L
.92152 .25 L
.92153 .25 L
.92153 .25 L
.92154 .25 L
.92154 .25 L
.92155 .25 L
.92156 .25 L
.92156 .25 L
.92157 .25 L
.92157 .25 L
.92158 .25 L
.92159 .25 L
.92159 .25 L
.9216 .25 L
.92161 .25 L
.92161 .25 L
.92162 .25 L
.92162 .25 L
.92163 .25 L
.92163 .25 L
.92163 .25 L
.92164 .25 L
Mistroke
.92165 .25 L
.92165 .25 L
.92166 .25 L
.92167 .25 L
.92167 .25 L
.92168 .25 L
.92168 .25 L
.92169 .25 L
.9217 .25 L
.9217 .25 L
.92171 .25 L
.92172 .25 L
.92172 .25 L
.92173 .25 L
.92174 .25 L
.92174 .25 L
.92175 .25 L
.92175 .25 L
.92176 .25 L
.92176 .25 L
.92177 .25 L
.92177 .25 L
.92177 .25 L
.92178 .25 L
.92178 .25 L
.92179 .25 L
.92179 .25 L
.92179 .25 L
.9218 .25 L
.9218 .25 L
.92181 .25 L
.92181 .25 L
.92182 .25 L
.92182 .25 L
.92183 .25 L
.92184 .25 L
.92184 .25 L
.92185 .25 L
.92186 .25 L
.92186 .25 L
.92187 .25 L
.92187 .25 L
.92188 .25 L
.92189 .25 L
.92189 .25 L
.9219 .25 L
.92191 .25 L
.92191 .25 L
.92191 .25 L
.92192 .25 L
Mistroke
.92193 .25 L
.92193 .25 L
.92194 .25 L
.92195 .25 L
.92195 .25 L
.92196 .25 L
.92196 .25 L
.92197 .25 L
.92197 .25 L
.92198 .25 L
.92199 .25 L
.92199 .25 L
.922 .25 L
.922 .25 L
.92201 .25 L
.92201 .25 L
.92202 .25 L
.92202 .25 L
.92203 .25 L
.92204 .25 L
.92205 .25 L
.92205 .25 L
.92206 .25 L
.92206 .25 L
.92207 .25 L
.92208 .25 L
.92208 .25 L
.92209 .25 L
.92209 .25 L
.9221 .25 L
.92211 .25 L
.92211 .25 L
.92212 .25 L
.92212 .25 L
.92213 .25 L
.92214 .25 L
.92214 .25 L
.92215 .25 L
.92215 .25 L
.92216 .25 L
.92216 .25 L
.92217 .25 L
.92218 .25 L
.92218 .25 L
.92219 .25 L
.9222 .25 L
.9222 .25 L
.92221 .25 L
.92221 .25 L
.92221 .25 L
Mistroke
.92222 .25 L
.92223 .25 L
.92223 .25 L
.92224 .25 L
.92224 .25 L
.92225 .25 L
.92225 .25 L
.92226 .25 L
.92227 .25 L
.92227 .25 L
.92228 .25 L
.92228 .25 L
.92229 .25 L
.92229 .25 L
.9223 .25 L
.9223 .25 L
.92231 .25 L
.92231 .25 L
.92232 .25 L
.92233 .25 L
.92233 .25 L
.92234 .25 L
.92234 .25 L
.92235 .25 L
.92235 .25 L
.92236 .25 L
.92237 .25 L
.92237 .25 L
.92238 .25 L
.92239 .25 L
.92239 .25 L
.9224 .25 L
.9224 .25 L
.92241 .25 L
.92242 .25 L
.92242 .25 L
.92243 .25 L
.92244 .25 L
.92244 .25 L
.92245 .25 L
.92245 .25 L
.92245 .25 L
.92246 .25 L
.92246 .25 L
.92247 .25 L
.92248 .25 L
.92248 .25 L
.92249 .25 L
.9225 .25 L
.9225 .25 L
Mistroke
.92251 .25 L
.92252 .25 L
.92252 .25 L
.92253 .25 L
.92253 .25 L
.92254 .25 L
.92255 .25 L
.92255 .25 L
.92256 .25 L
.92257 .25 L
.92257 .25 L
.92258 .25 L
.92258 .25 L
.92259 .25 L
.92259 .25 L
.92259 .25 L
.9226 .25 L
.9226 .25 L
.92261 .25 L
.92261 .25 L
.92261 .25 L
.92262 .25 L
.92262 .25 L
.92263 .25 L
.92263 .25 L
.92263 .25 L
.92264 .25 L
.92265 .25 L
.92265 .25 L
.92266 .25 L
.92267 .25 L
.92267 .25 L
.92268 .25 L
.92268 .25 L
.92269 .25 L
.9227 .25 L
.9227 .25 L
.92271 .25 L
.92272 .25 L
.92272 .25 L
.92273 .25 L
.92273 .25 L
.92274 .25 L
.92274 .25 L
.92275 .25 L
.92276 .25 L
.92276 .25 L
.92277 .25 L
.92278 .25 L
.92278 .25 L
Mistroke
.92279 .25 L
.92279 .25 L
.9228 .25 L
.9228 .25 L
.92281 .25 L
.92282 .25 L
.92282 .25 L
.92283 .25 L
.92283 .25 L
.92284 .25 L
.92284 .25 L
.92285 .25 L
.92285 .25 L
.92286 .25 L
.92287 .25 L
.92287 .25 L
.92288 .25 L
.92289 .25 L
.92289 .25 L
.9229 .25 L
.92291 .25 L
.92291 .25 L
.92292 .25 L
.92292 .25 L
.92293 .25 L
.92294 .25 L
.92294 .25 L
.92295 .25 L
.92295 .25 L
.92296 .25 L
.92296 .25 L
.92297 .25 L
.92298 .25 L
.92298 .25 L
.92299 .25 L
.92299 .25 L
.923 .25 L
.92301 .25 L
.92301 .25 L
.92302 .25 L
.92302 .25 L
.92303 .25 L
.92303 .25 L
.92304 .25 L
.92304 .25 L
.92305 .25 L
.92306 .25 L
.92306 .25 L
.92306 .25 L
.92307 .25 L
Mistroke
.92308 .25 L
.92308 .25 L
.92309 .25 L
.92309 .25 L
.9231 .25 L
.92311 .25 L
.92311 .25 L
.92312 .25 L
.92312 .25 L
.92313 .25 L
.92313 .25 L
.92314 .25 L
.92314 .25 L
.92315 .25 L
.92316 .25 L
.92316 .25 L
.92317 .25 L
.92317 .25 L
.92318 .25 L
.92318 .25 L
.92319 .25 L
.9232 .25 L
.9232 .25 L
.92321 .25 L
.92322 .25 L
.92322 .25 L
.92323 .25 L
.92323 .25 L
.92324 .25 L
.92325 .25 L
.92325 .25 L
.92326 .25 L
.92327 .25 L
.92327 .25 L
.92327 .25 L
.92328 .25 L
.92328 .25 L
.92329 .25 L
.92329 .25 L
.9233 .25 L
.92331 .25 L
.92331 .25 L
.92332 .25 L
.92333 .25 L
.92333 .25 L
.92334 .25 L
.92335 .25 L
.92335 .25 L
.92336 .25 L
.92336 .25 L
Mistroke
.92337 .25 L
.92338 .25 L
.92338 .25 L
.92339 .25 L
.92339 .25 L
.9234 .25 L
.92341 .25 L
.92341 .25 L
.92341 .25 L
.92342 .25 L
.92342 .25 L
.92343 .25 L
.92343 .25 L
.92343 .25 L
.92344 .25 L
.92344 .25 L
.92345 .25 L
.92345 .25 L
.92345 .25 L
.92346 .25 L
.92346 .25 L
.92347 .25 L
.92348 .25 L
.92348 .25 L
.92349 .25 L
.9235 .25 L
.9235 .25 L
.92351 .25 L
.92351 .25 L
.92352 .25 L
.92353 .25 L
.92353 .25 L
.92354 .25 L
.92355 .25 L
.92355 .25 L
.92356 .25 L
.92356 .25 L
.92357 .25 L
.92357 .25 L
.92358 .25 L
.92359 .25 L
.92359 .25 L
.9236 .25 L
.9236 .25 L
.92361 .25 L
.92361 .25 L
.92362 .25 L
.92363 .25 L
.92363 .25 L
.92364 .25 L
Mistroke
.92365 .25 L
.92365 .25 L
.92366 .25 L
.92366 .25 L
.92367 .25 L
.92367 .25 L
.92368 .25 L
.92369 .25 L
.92369 .25 L
.9237 .25 L
.9237 .25 L
.92371 .25 L
.92372 .25 L
.92372 .25 L
.92373 .25 L
.92374 .25 L
.92374 .25 L
.92375 .25 L
.92376 .25 L
.92376 .25 L
.92376 .25 L
.92377 .25 L
.92378 .25 L
.92378 .25 L
.92379 .25 L
.92379 .25 L
.9238 .25 L
.92381 .25 L
.92381 .25 L
.92382 .25 L
.92382 .25 L
.92383 .25 L
.92384 .25 L
.92384 .25 L
.92385 .25 L
.92385 .25 L
.92386 .25 L
.92386 .25 L
.92387 .25 L
.92387 .25 L
.92388 .25 L
.92389 .25 L
.92389 .25 L
.9239 .25 L
.92391 .25 L
.92391 .25 L
.92392 .25 L
.92392 .25 L
.92393 .25 L
.92394 .25 L
Mistroke
.92394 .25 L
.92395 .25 L
.92396 .25 L
.92396 .25 L
.92397 .25 L
.92397 .25 L
.92398 .25 L
.92398 .25 L
.92399 .25 L
.924 .25 L
.924 .25 L
.92401 .25 L
.92401 .25 L
.92402 .25 L
.92403 .25 L
.92403 .25 L
.92404 .25 L
.92404 .25 L
.92405 .25 L
.92406 .25 L
.92406 .25 L
.92406 .25 L
.92407 .25 L
.92408 .25 L
.92408 .25 L
.92409 .25 L
.92409 .25 L
.9241 .25 L
.9241 .25 L
.92411 .25 L
.92411 .25 L
.92412 .25 L
.92413 .25 L
.92413 .25 L
.92414 .25 L
.92414 .25 L
.92415 .25 L
.92415 .25 L
.92416 .25 L
.92416 .25 L
.92417 .25 L
.92418 .25 L
.92418 .25 L
.92419 .25 L
.92419 .25 L
.9242 .25 L
.9242 .25 L
.92421 .25 L
.92422 .25 L
.92422 .25 L
Mistroke
.92423 .25 L
.92424 .25 L
.92424 .25 L
.92425 .25 L
.92425 .25 L
.92426 .25 L
.92427 .25 L
.92427 .25 L
.92428 .25 L
.92429 .25 L
.92429 .25 L
.9243 .25 L
.9243 .25 L
.9243 .25 L
.92431 .25 L
.92431 .25 L
.92432 .25 L
.92433 .25 L
.92433 .25 L
.92434 .25 L
.92435 .25 L
.92435 .25 L
.92436 .25 L
.92436 .25 L
.92437 .25 L
.92438 .25 L
.92438 .25 L
.92439 .25 L
.9244 .25 L
.9244 .25 L
.92441 .25 L
.92442 .25 L
.92442 .25 L
.92442 .25 L
.92443 .25 L
.92443 .25 L
.92444 .25 L
.92444 .25 L
.92445 .25 L
.92445 .25 L
.92446 .25 L
.92446 .25 L
.92446 .25 L
.92447 .25 L
.92447 .25 L
.92448 .25 L
.92448 .25 L
.92448 .25 L
.92449 .25 L
.9245 .25 L
Mistroke
.9245 .25 L
.92451 .25 L
.92452 .25 L
.92452 .25 L
.92453 .25 L
.92453 .25 L
.92454 .25 L
.92455 .25 L
.92455 .25 L
.92456 .25 L
.92457 .25 L
.92457 .25 L
.92458 .25 L
.92458 .25 L
.92459 .25 L
.92459 .25 L
.9246 .25 L
.92461 .25 L
.92461 .25 L
.92462 .25 L
.92462 .25 L
.92463 .25 L
.92464 .25 L
.92464 .25 L
.92465 .25 L
.92465 .25 L
.92466 .25 L
.92467 .25 L
.92467 .25 L
.92468 .25 L
.92468 .25 L
.92469 .25 L
.92469 .25 L
.9247 .25 L
.9247 .25 L
.92471 .25 L
.92472 .25 L
.92472 .25 L
.92473 .25 L
.92474 .25 L
.92474 .25 L
.92475 .25 L
.92476 .25 L
.92476 .25 L
.92477 .25 L
.92477 .25 L
.92478 .25 L
.92479 .25 L
.92479 .25 L
.9248 .25 L
Mistroke
.9248 .25 L
.92481 .25 L
.92481 .25 L
.92482 .25 L
.92483 .25 L
.92483 .25 L
.92484 .25 L
.92484 .25 L
.92485 .25 L
.92486 .25 L
.92486 .25 L
.92487 .25 L
.92487 .25 L
.92488 .25 L
.92488 .25 L
.92489 .25 L
.92489 .25 L
.9249 .25 L
.92491 .25 L
.92491 .25 L
.92491 .25 L
.92492 .25 L
.92493 .25 L
.92493 .25 L
.92494 .25 L
.92494 .25 L
.92495 .25 L
.92496 .25 L
.92496 .25 L
.92497 .25 L
.92497 .25 L
.92498 .25 L
.92498 .25 L
.92499 .25 L
.92499 .25 L
.925 .25 L
.92501 .25 L
.92501 .25 L
.92502 .25 L
.92502 .25 L
.92503 .25 L
.92503 .25 L
.92504 .25 L
.92505 .25 L
.92505 .25 L
.92506 .25 L
.92507 .25 L
.92507 .25 L
.92508 .25 L
.92508 .25 L
Mistroke
.92509 .25 L
.9251 .25 L
.9251 .25 L
.92511 .25 L
.92512 .25 L
.92512 .25 L
.92512 .25 L
.92513 .25 L
.92513 .25 L
.92514 .25 L
.92514 .25 L
.92515 .25 L
.92516 .25 L
.92516 .25 L
.92517 .25 L
.92518 .25 L
.92518 .25 L
.92519 .25 L
.9252 .25 L
.9252 .25 L
.92521 .25 L
.92521 .25 L
.92522 .25 L
.92523 .25 L
.92523 .25 L
.92524 .25 L
.92525 .25 L
.92525 .25 L
.92526 .25 L
.92526 .25 L
.92526 .25 L
.92527 .25 L
.92527 .25 L
.92528 .25 L
.92528 .25 L
.92528 .25 L
.92529 .25 L
.92529 .25 L
.9253 .25 L
.9253 .25 L
.9253 .25 L
.92531 .25 L
.92531 .25 L
.92532 .25 L
.92533 .25 L
.92533 .25 L
.92534 .25 L
.92535 .25 L
.92535 .25 L
.92536 .25 L
Mistroke
.92536 .25 L
.92537 .25 L
.92538 .25 L
.92538 .25 L
.92539 .25 L
.9254 .25 L
.9254 .25 L
.92541 .25 L
.92541 .25 L
.92542 .25 L
.92542 .25 L
.92543 .25 L
.92544 .25 L
.92544 .25 L
.92545 .25 L
.92545 .25 L
.92546 .25 L
.92547 .25 L
.92547 .25 L
.92548 .25 L
.92548 .25 L
.92549 .25 L
.9255 .25 L
.9255 .25 L
.92551 .25 L
.92551 .25 L
.92552 .25 L
.92552 .25 L
.92553 .25 L
.92554 .25 L
.92554 .25 L
.92555 .25 L
.92555 .25 L
.92556 .25 L
.92557 .25 L
.92557 .25 L
.92558 .25 L
.92559 .25 L
.92559 .25 L
.9256 .25 L
.92561 .25 L
.92561 .25 L
.92561 .25 L
.92562 .25 L
.92563 .25 L
.92563 .25 L
.92564 .25 L
.92565 .25 L
.92565 .25 L
.92566 .25 L
Mistroke
.92566 .25 L
.92567 .25 L
.92567 .25 L
.92568 .25 L
.92569 .25 L
.92569 .25 L
.9257 .25 L
.9257 .25 L
.92571 .25 L
.92571 .25 L
.92572 .25 L
.92572 .25 L
.92573 .25 L
.92573 .25 L
.92574 .25 L
.92574 .25 L
.92575 .25 L
.92576 .25 L
.92576 .25 L
.92577 .25 L
.92578 .25 L
.92578 .25 L
.92579 .25 L
.92579 .25 L
.9258 .25 L
.9258 .25 L
.9258 .25 L
.92581 .25 L
.92582 .25 L
.92582 .25 L
.92583 .25 L
.92584 .25 L
.92584 .25 L
.92585 .25 L
.92585 .25 L
.92586 .25 L
.92586 .25 L
.92587 .25 L
.92588 .25 L
.92588 .25 L
.92589 .25 L
.9259 .25 L
.9259 .25 L
.92591 .25 L
.92592 .25 L
.92592 .25 L
.92593 .25 L
.92593 .25 L
.92594 .25 L
.92594 .25 L
Mistroke
.92595 .25 L
.92595 .25 L
.92596 .25 L
.92596 .25 L
.92597 .25 L
.92598 .25 L
.92598 .25 L
.92599 .25 L
.92599 .25 L
.926 .25 L
.92601 .25 L
.92601 .25 L
.92602 .25 L
.92603 .25 L
.92603 .25 L
.92604 .25 L
.92605 .25 L
.92605 .25 L
.92606 .25 L
.92606 .25 L
.92607 .25 L
.92607 .25 L
.92608 .25 L
.92608 .25 L
.92609 .25 L
.92609 .25 L
.92609 .25 L
.9261 .25 L
.9261 .25 L
.92611 .25 L
.92611 .25 L
.92612 .25 L
.92612 .25 L
.92612 .25 L
.92613 .25 L
.92613 .25 L
.92614 .25 L
.92614 .25 L
.92615 .25 L
.92616 .25 L
.92616 .25 L
.92617 .25 L
.92618 .25 L
.92618 .25 L
.92619 .25 L
.92619 .25 L
.9262 .25 L
.92621 .25 L
.92621 .25 L
.92622 .25 L
Mistroke
.92623 .25 L
.92623 .25 L
.92623 .25 L
.92624 .25 L
.92625 .25 L
.92625 .25 L
.92626 .25 L
.92627 .25 L
.92627 .25 L
.92628 .25 L
.92628 .25 L
.92629 .25 L
.92629 .25 L
.9263 .25 L
.92631 .25 L
.92631 .25 L
.92632 .25 L
.92633 .25 L
.92633 .25 L
.92633 .25 L
.92634 .25 L
.92635 .25 L
.92635 .25 L
.92636 .25 L
.92637 .25 L
.92637 .25 L
.92638 .25 L
.92638 .25 L
.92639 .25 L
.9264 .25 L
.9264 .25 L
.92641 .25 L
.92642 .25 L
.92642 .25 L
.92643 .25 L
.92643 .25 L
.92644 .25 L
.92644 .25 L
.92645 .25 L
.92646 .25 L
.92646 .25 L
.92647 .25 L
.92647 .25 L
.92648 .25 L
.92649 .25 L
.92649 .25 L
.9265 .25 L
.9265 .25 L
.92651 .25 L
.92652 .25 L
Mistroke
.92652 .25 L
.92653 .25 L
.92653 .25 L
.92654 .25 L
.92654 .25 L
.92655 .25 L
.92655 .25 L
.92656 .25 L
.92656 .25 L
.92657 .25 L
.92657 .25 L
.92658 .25 L
.92659 .25 L
.92659 .25 L
.9266 .25 L
.92661 .25 L
.92661 .25 L
.92661 .25 L
.92662 .25 L
.92662 .25 L
.92663 .25 L
.92663 .25 L
.92664 .25 L
.92665 .25 L
.92665 .25 L
.92666 .25 L
.92666 .25 L
.92667 .25 L
.92668 .25 L
.92668 .25 L
.92669 .25 L
.92669 .25 L
.9267 .25 L
.92671 .25 L
.92671 .25 L
.92672 .25 L
.92673 .25 L
.92673 .25 L
.92674 .25 L
.92674 .25 L
.92675 .25 L
.92676 .25 L
.92676 .25 L
.92677 .25 L
.92677 .25 L
.92678 .25 L
.92678 .25 L
.92679 .25 L
.92679 .25 L
.9268 .25 L
Mistroke
.92681 .25 L
.92681 .25 L
.92682 .25 L
.92682 .25 L
.92683 .25 L
.92684 .25 L
.92684 .25 L
.92685 .25 L
.92686 .25 L
.92686 .25 L
.92687 .25 L
.92688 .25 L
.92688 .25 L
.92689 .25 L
.92689 .25 L
.9269 .25 L
.9269 .25 L
.92691 .25 L
.92691 .25 L
.92691 .25 L
.92692 .25 L
.92692 .25 L
.92693 .25 L
.92693 .25 L
.92694 .25 L
.92694 .25 L
.92694 .25 L
.92695 .25 L
.92695 .25 L
.92695 .25 L
.92696 .25 L
.92697 .25 L
.92697 .25 L
.92698 .25 L
.92699 .25 L
.92699 .25 L
.927 .25 L
.927 .25 L
.92701 .25 L
.92702 .25 L
.92702 .25 L
.92703 .25 L
.92704 .25 L
.92704 .25 L
.92705 .25 L
.92705 .25 L
.92706 .25 L
.92706 .25 L
.92707 .25 L
.92708 .25 L
Mistroke
.92708 .25 L
.92709 .25 L
.9271 .25 L
.9271 .25 L
.92711 .25 L
.92711 .25 L
.92712 .25 L
.92712 .25 L
.92713 .25 L
.92714 .25 L
.92714 .25 L
.92715 .25 L
.92715 .25 L
.92716 .25 L
.92716 .25 L
.92717 .25 L
.92718 .25 L
.92718 .25 L
.92719 .25 L
.9272 .25 L
.9272 .25 L
.92721 .25 L
.92721 .25 L
.92722 .25 L
.92723 .25 L
.92723 .25 L
.92724 .25 L
.92725 .25 L
.92725 .25 L
.92726 .25 L
.92726 .25 L
.92727 .25 L
.92727 .25 L
.92728 .25 L
.92729 .25 L
.92729 .25 L
.9273 .25 L
.9273 .25 L
.92731 .25 L
.92731 .25 L
.92732 .25 L
.92733 .25 L
.92733 .25 L
.92734 .25 L
.92734 .25 L
.92735 .25 L
.92736 .25 L
.92736 .25 L
.92736 .25 L
.92737 .25 L
Mistroke
.92738 .25 L
.92739 .25 L
.92739 .25 L
.9274 .25 L
.9274 .25 L
.92741 .25 L
.92742 .25 L
.92742 .25 L
.92743 .25 L
.92744 .25 L
.92744 .25 L
.92745 .25 L
.92746 .25 L
.92746 .25 L
.92746 .25 L
.92747 .25 L
.92748 .25 L
.92748 .25 L
.92749 .25 L
.92749 .25 L
.9275 .25 L
.92751 .25 L
.92751 .25 L
.92752 .25 L
.92752 .25 L
.92753 .25 L
.92754 .25 L
.92754 .25 L
.92755 .25 L
.92755 .25 L
.92756 .25 L
.92756 .25 L
.92757 .25 L
.92757 .25 L
.92758 .25 L
.92758 .25 L
.92759 .25 L
.92759 .25 L
.9276 .25 L
.92761 .25 L
.92761 .25 L
.92762 .25 L
.92762 .25 L
.92763 .25 L
.92764 .25 L
.92764 .25 L
.92765 .25 L
.92765 .25 L
.92765 .25 L
.92766 .25 L
Mistroke
.92767 .25 L
.92767 .25 L
.92768 .25 L
.92768 .25 L
.92769 .25 L
.9277 .25 L
.9277 .25 L
.92771 .25 L
.92771 .25 L
.92772 .25 L
.92773 .25 L
.92773 .25 L
.92774 .25 L
.92775 .25 L
.92775 .25 L
.92776 .25 L
.92776 .25 L
.92777 .25 L
.92778 .25 L
.92778 .25 L
.92779 .25 L
.92779 .25 L
.9278 .25 L
.9278 .25 L
.92781 .25 L
.92781 .25 L
.92782 .25 L
.92782 .25 L
.92783 .25 L
.92784 .25 L
.92784 .25 L
.92785 .25 L
.92786 .25 L
.92786 .25 L
.92787 .25 L
.92788 .25 L
.92788 .25 L
.92789 .25 L
.9279 .25 L
.9279 .25 L
.92791 .25 L
.92791 .25 L
.92792 .25 L
.92792 .25 L
.92793 .25 L
.92793 .25 L
.92794 .25 L
.92794 .25 L
.92794 .25 L
.92795 .25 L
Mistroke
.92795 .25 L
.92796 .25 L
.92796 .25 L
.92797 .25 L
.92797 .25 L
.92797 .25 L
.92798 .25 L
.92798 .25 L
.92799 .25 L
.92799 .25 L
.928 .25 L
.92801 .25 L
.92801 .25 L
.92802 .25 L
.92803 .25 L
.92803 .25 L
.92804 .25 L
.92804 .25 L
.92805 .25 L
.92806 .25 L
.92806 .25 L
.92807 .25 L
.92808 .25 L
.92808 .25 L
.92808 .25 L
.92809 .25 L
.9281 .25 L
.9281 .25 L
.92811 .25 L
.92812 .25 L
.92812 .25 L
.92813 .25 L
.92813 .25 L
.92814 .25 L
.92814 .25 L
.92815 .25 L
.92816 .25 L
.92816 .25 L
.92817 .25 L
.92818 .25 L
.92818 .25 L
.92818 .25 L
.92819 .25 L
.9282 .25 L
.9282 .25 L
.92821 .25 L
.92822 .25 L
.92822 .25 L
.92823 .25 L
.92823 .25 L
Mistroke
.92824 .25 L
.92825 .25 L
.92825 .25 L
.92826 .25 L
.92827 .25 L
.92827 .25 L
.92828 .25 L
.92828 .25 L
.92829 .25 L
.92829 .25 L
.9283 .25 L
.92831 .25 L
.92831 .25 L
.92832 .25 L
.92832 .25 L
.92833 .25 L
.92834 .25 L
.92834 .25 L
.92835 .25 L
.92835 .25 L
.92836 .25 L
.92837 .25 L
.92837 .25 L
.92838 .25 L
.92838 .25 L
.92839 .25 L
.92839 .25 L
.9284 .25 L
.9284 .25 L
.92841 .25 L
.92841 .25 L
.92842 .25 L
.92842 .25 L
.92843 .25 L
.92844 .25 L
.92844 .25 L
.92845 .25 L
.92846 .25 L
.92846 .25 L
.92846 .25 L
.92847 .25 L
.92847 .25 L
.92848 .25 L
.92848 .25 L
.92849 .25 L
.9285 .25 L
.9285 .25 L
.92851 .25 L
.92851 .25 L
.92852 .25 L
Mistroke
.92853 .25 L
.92853 .25 L
.92854 .25 L
.92855 .25 L
.92855 .25 L
.92856 .25 L
.92856 .25 L
.92857 .25 L
.92858 .25 L
.92858 .25 L
.92859 .25 L
.92859 .25 L
.9286 .25 L
.92861 .25 L
.92861 .25 L
.92862 .25 L
.92862 .25 L
.92863 .25 L
.92863 .25 L
.92864 .25 L
.92864 .25 L
.92865 .25 L
.92866 .25 L
.92866 .25 L
.92867 .25 L
.92867 .25 L
.92868 .25 L
.92869 .25 L
.92869 .25 L
.9287 .25 L
.92871 .25 L
.92871 .25 L
.92872 .25 L
.92873 .25 L
.92873 .25 L
.92874 .25 L
.92874 .25 L
.92875 .25 L
.92875 .25 L
.92876 .25 L
.92876 .25 L
.92876 .25 L
.92877 .25 L
.92877 .25 L
.92878 .25 L
.92878 .25 L
.92879 .25 L
.92879 .25 L
.92879 .25 L
.9288 .25 L
Mistroke
.9288 .25 L
.9288 .25 L
.92881 .25 L
.92882 .25 L
.92882 .25 L
.92883 .25 L
.92884 .25 L
.92884 .25 L
.92885 .25 L
.92886 .25 L
.92886 .25 L
.92887 .25 L
.92887 .25 L
.92888 .25 L
.92889 .25 L
.92889 .25 L
.9289 .25 L
.9289 .25 L
.92891 .25 L
.92892 .25 L
.92892 .25 L
.92893 .25 L
.92893 .25 L
.92894 .25 L
.92895 .25 L
.92895 .25 L
.92896 .25 L
.92896 .25 L
.92897 .25 L
.92897 .25 L
.92898 .25 L
.92899 .25 L
.92899 .25 L
.929 .25 L
.929 .25 L
.92901 .25 L
.92901 .25 L
.92902 .25 L
.92903 .25 L
.92903 .25 L
.92904 .25 L
.92905 .25 L
.92905 .25 L
.92906 .25 L
.92906 .25 L
.92907 .25 L
.92908 .25 L
.92908 .25 L
.92909 .25 L
.9291 .25 L
Mistroke
.9291 .25 L
.92911 .25 L
.92911 .25 L
.92912 .25 L
.92912 .25 L
.92913 .25 L
.92914 .25 L
.92914 .25 L
.92915 .25 L
.92915 .25 L
.92916 .25 L
.92917 .25 L
.92917 .25 L
.92918 .25 L
.92918 .25 L
.92919 .25 L
.9292 .25 L
.9292 .25 L
.92921 .25 L
.92921 .25 L
.92922 .25 L
.92922 .25 L
.92923 .25 L
.92923 .25 L
.92924 .25 L
.92924 .25 L
.92925 .25 L
.92925 .25 L
.92926 .25 L
.92927 .25 L
.92927 .25 L
.92928 .25 L
.92928 .25 L
.92929 .25 L
.92929 .25 L
.9293 .25 L
.9293 .25 L
.92931 .25 L
.92931 .25 L
.92932 .25 L
.92933 .25 L
.92933 .25 L
.92934 .25 L
.92934 .25 L
.92935 .25 L
.92936 .25 L
.92936 .25 L
.92937 .25 L
.92937 .25 L
.92938 .25 L
Mistroke
.92939 .25 L
.92939 .25 L
.9294 .25 L
.92941 .25 L
.92941 .25 L
.92942 .25 L
.92943 .25 L
.92943 .25 L
.92944 .25 L
.92944 .25 L
.92945 .25 L
.92945 .25 L
.92945 .25 L
.92946 .25 L
.92947 .25 L
.92947 .25 L
.92948 .25 L
.92949 .25 L
.92949 .25 L
.9295 .25 L
.9295 .25 L
.92951 .25 L
.92952 .25 L
.92952 .25 L
.92953 .25 L
.92954 .25 L
.92954 .25 L
.92955 .25 L
.92956 .25 L
.92956 .25 L
.92957 .25 L
.92957 .25 L
.92958 .25 L
.92958 .25 L
.92958 .25 L
.92959 .25 L
.92959 .25 L
.9296 .25 L
.9296 .25 L
.92961 .25 L
.92961 .25 L
.92961 .25 L
.92962 .25 L
.92962 .25 L
.92962 .25 L
.92963 .25 L
.92963 .25 L
.92964 .25 L
.92965 .25 L
.92965 .25 L
Mistroke
.92966 .25 L
.92967 .25 L
.92967 .25 L
.92968 .25 L
.92969 .25 L
.92969 .25 L
.9297 .25 L
.92971 .25 L
.92971 .25 L
.92972 .25 L
.92972 .25 L
.92973 .25 L
.92973 .25 L
.92974 .25 L
.92975 .25 L
.92975 .25 L
.92976 .25 L
.92976 .25 L
.92977 .25 L
.92978 .25 L
.92978 .25 L
.92979 .25 L
.92979 .25 L
.9298 .25 L
.92981 .25 L
.92981 .25 L
.92982 .25 L
.92982 .25 L
.92983 .25 L
.92983 .25 L
.92984 .25 L
.92984 .25 L
.92985 .25 L
.92986 .25 L
.92986 .25 L
.92987 .25 L
.92988 .25 L
.92988 .25 L
.92989 .25 L
.92989 .25 L
.9299 .25 L
.92991 .25 L
.92991 .25 L
.92992 .25 L
.92993 .25 L
.92993 .25 L
.92993 .25 L
.92994 .25 L
.92995 .25 L
.92995 .25 L
Mistroke
.92996 .25 L
.92997 .25 L
.92997 .25 L
.92998 .25 L
.92998 .25 L
.92999 .25 L
.92999 .25 L
.93 .25 L
.93001 .25 L
.93001 .25 L
.93002 .25 L
.93003 .25 L
.93003 .25 L
.93003 .25 L
.93004 .25 L
.93005 .25 L
.93005 .25 L
.93006 .25 L
.93006 .25 L
.93007 .25 L
.93007 .25 L
.93008 .25 L
.93008 .25 L
.93009 .25 L
.9301 .25 L
.9301 .25 L
.93011 .25 L
.93011 .25 L
.93012 .25 L
.93012 .25 L
.93012 .25 L
.93013 .25 L
.93014 .25 L
.93014 .25 L
.93015 .25 L
.93016 .25 L
.93016 .25 L
.93017 .25 L
.93017 .25 L
.93018 .25 L
.93019 .25 L
.93019 .25 L
.9302 .25 L
.9302 .25 L
.93021 .25 L
.93022 .25 L
.93022 .25 L
.93023 .25 L
.93024 .25 L
.93024 .25 L
Mistroke
.93025 .25 L
.93026 .25 L
.93026 .25 L
.93027 .25 L
.93027 .25 L
.93027 .25 L
.93028 .25 L
.93028 .25 L
.93029 .25 L
.9303 .25 L
.9303 .25 L
.93031 .25 L
.93032 .25 L
.93032 .25 L
.93033 .25 L
.93033 .25 L
.93034 .25 L
.93035 .25 L
.93035 .25 L
.93036 .25 L
.93037 .25 L
.93037 .25 L
.93038 .25 L
.93039 .25 L
.93039 .25 L
.93039 .25 L
.9304 .25 L
.9304 .25 L
.93041 .25 L
.93041 .25 L
.93041 .25 L
.93042 .25 L
.93043 .25 L
.93043 .25 L
.93043 .25 L
.93044 .25 L
.93044 .25 L
.93044 .25 L
.93045 .25 L
.93045 .25 L
.93046 .25 L
.93046 .25 L
.93047 .25 L
.93048 .25 L
.93048 .25 L
.93049 .25 L
.9305 .25 L
.9305 .25 L
.93051 .25 L
.93051 .25 L
Mistroke
.93052 .25 L
.93053 .25 L
.93053 .25 L
.93054 .25 L
.93055 .25 L
.93055 .25 L
.93056 .25 L
.93056 .25 L
.93057 .25 L
.93057 .25 L
.93058 .25 L
.93059 .25 L
.93059 .25 L
.9306 .25 L
.9306 .25 L
.93061 .25 L
.93062 .25 L
.93062 .25 L
.93063 .25 L
.93063 .25 L
.93064 .25 L
.93065 .25 L
.93065 .25 L
.93065 .25 L
.93066 .25 L
.93067 .25 L
.93067 .25 L
.93068 .25 L
.93069 .25 L
.93069 .25 L
.9307 .25 L
.9307 .25 L
.93071 .25 L
.93072 .25 L
.93072 .25 L
.93073 .25 L
.93074 .25 L
.93074 .25 L
.93075 .25 L
.93075 .25 L
.93076 .25 L
.93076 .25 L
.93077 .25 L
.93078 .25 L
.93078 .25 L
.93079 .25 L
.9308 .25 L
.9308 .25 L
.93081 .25 L
.93081 .25 L
Mistroke
.93082 .25 L
.93082 .25 L
.93083 .25 L
.93084 .25 L
.93084 .25 L
.93085 .25 L
.93085 .25 L
.93086 .25 L
.93086 .25 L
.93087 .25 L
.93088 .25 L
.93088 .25 L
.93089 .25 L
.9309 .25 L
.9309 .25 L
.93091 .25 L
.93091 .25 L
.93092 .25 L
.93093 .25 L
.93093 .25 L
.93094 .25 L
.93095 .25 L
.93095 .25 L
.93096 .25 L
.93096 .25 L
.93097 .25 L
.93097 .25 L
.93098 .25 L
.93099 .25 L
.93099 .25 L
.931 .25 L
.931 .25 L
.93101 .25 L
.93102 .25 L
.93102 .25 L
.93103 .25 L
.93103 .25 L
.93104 .25 L
.93105 .25 L
.93105 .25 L
.93106 .25 L
.93106 .25 L
.93107 .25 L
.93107 .25 L
.93108 .25 L
.93108 .25 L
.93109 .25 L
.93109 .25 L
.9311 .25 L
.9311 .25 L
Mistroke
.93111 .25 L
.93112 .25 L
.93112 .25 L
.93113 .25 L
.93113 .25 L
.93114 .25 L
.93114 .25 L
.93115 .25 L
.93115 .25 L
.93116 .25 L
.93116 .25 L
.93117 .25 L
.93118 .25 L
.93118 .25 L
.93119 .25 L
.93119 .25 L
.9312 .25 L
.93121 .25 L
.93121 .25 L
.93122 .25 L
.93122 .25 L
.93123 .25 L
.93124 .25 L
.93124 .25 L
.93125 .25 L
.93126 .25 L
.93126 .25 L
.93127 .25 L
.93127 .25 L
.93128 .25 L
.93129 .25 L
.93129 .25 L
.9313 .25 L
.9313 .25 L
.9313 .25 L
.93131 .25 L
.93132 .25 L
.93132 .25 L
.93133 .25 L
.93134 .25 L
.93134 .25 L
.93135 .25 L
.93135 .25 L
.93136 .25 L
.93137 .25 L
.93137 .25 L
.93138 .25 L
.93139 .25 L
.93139 .25 L
.9314 .25 L
Mistroke
.93141 .25 L
.93141 .25 L
.93142 .25 L
.93142 .25 L
.93143 .25 L
.93143 .25 L
.93143 .25 L
.93144 .25 L
.93144 .25 L
.93145 .25 L
.93145 .25 L
.93146 .25 L
.93146 .25 L
.93146 .25 L
.93147 .25 L
.93147 .25 L
.93147 .25 L
.93148 .25 L
.93148 .25 L
.93149 .25 L
.9315 .25 L
.9315 .25 L
.93151 .25 L
.93152 .25 L
.93152 .25 L
.93153 .25 L
.93154 .25 L
.93154 .25 L
.93155 .25 L
.93156 .25 L
.93156 .25 L
.93157 .25 L
.93157 .25 L
.93158 .25 L
.93158 .25 L
.93159 .25 L
.9316 .25 L
.9316 .25 L
.93161 .25 L
.93161 .25 L
.93162 .25 L
.93163 .25 L
.93163 .25 L
.93164 .25 L
.93164 .25 L
.93165 .25 L
.93166 .25 L
.93166 .25 L
.93167 .25 L
.93167 .25 L
Mistroke
.93168 .25 L
.93168 .25 L
.93169 .25 L
.93169 .25 L
.9317 .25 L
.93171 .25 L
.93171 .25 L
.93172 .25 L
.93173 .25 L
.93173 .25 L
.93174 .25 L
.93174 .25 L
.93175 .25 L
.93176 .25 L
.93176 .25 L
.93177 .25 L
.93178 .25 L
.93178 .25 L
.93178 .25 L
.93179 .25 L
.9318 .25 L
.9318 .25 L
.93181 .25 L
.93182 .25 L
.93182 .25 L
.93183 .25 L
.93183 .25 L
.93184 .25 L
.93185 .25 L
.93185 .25 L
.93186 .25 L
.93186 .25 L
.93187 .25 L
.93188 .25 L
.93188 .25 L
.93188 .25 L
.93189 .25 L
.9319 .25 L
.9319 .25 L
.93191 .25 L
.93191 .25 L
.93192 .25 L
.93192 .25 L
.93193 .25 L
.93193 .25 L
.93194 .25 L
.93195 .25 L
.93195 .25 L
.93196 .25 L
.93196 .25 L
Mistroke
.93197 .25 L
.93197 .25 L
.93198 .25 L
.93198 .25 L
.93199 .25 L
.93199 .25 L
.932 .25 L
.93201 .25 L
.93201 .25 L
.93202 .25 L
.93202 .25 L
.93203 .25 L
.93204 .25 L
.93204 .25 L
.93205 .25 L
.93206 .25 L
.93206 .25 L
.93207 .25 L
.93207 .25 L
.93208 .25 L
.93209 .25 L
.93209 .25 L
.9321 .25 L
.93211 .25 L
.93211 .25 L
.93212 .25 L
.93212 .25 L
.93212 .25 L
.93213 .25 L
.93213 .25 L
.93214 .25 L
.93215 .25 L
.93215 .25 L
.93216 .25 L
.93217 .25 L
.93217 .25 L
.93218 .25 L
.93218 .25 L
.93219 .25 L
.9322 .25 L
.9322 .25 L
.93221 .25 L
.93222 .25 L
.93222 .25 L
.93223 .25 L
.93224 .25 L
.93224 .25 L
.93224 .25 L
.93225 .25 L
.93225 .25 L
Mistroke
.93226 .25 L
.93226 .25 L
.93227 .25 L
.93227 .25 L
.93228 .25 L
.93228 .25 L
.93228 .25 L
.93229 .25 L
.93229 .25 L
.93229 .25 L
.9323 .25 L
.9323 .25 L
.93231 .25 L
.93232 .25 L
.93232 .25 L
.93233 .25 L
.93234 .25 L
.93234 .25 L
.93235 .25 L
.93235 .25 L
.93236 .25 L
.93237 .25 L
.93237 .25 L
.93238 .25 L
.93239 .25 L
.93239 .25 L
.9324 .25 L
.9324 .25 L
.93241 .25 L
.93241 .25 L
.93242 .25 L
.93243 .25 L
.93243 .25 L
.93244 .25 L
.93244 .25 L
.93245 .25 L
.93245 .25 L
.93246 .25 L
.93247 .25 L
.93247 .25 L
.93248 .25 L
.93249 .25 L
.93249 .25 L
.9325 .25 L
.9325 .25 L
.9325 .25 L
.93251 .25 L
.93252 .25 L
.93252 .25 L
.93253 .25 L
Mistroke
.93254 .25 L
.93254 .25 L
.93255 .25 L
.93256 .25 L
.93256 .25 L
.93257 .25 L
.93257 .25 L
.93258 .25 L
.93259 .25 L
.93259 .25 L
.9326 .25 L
.9326 .25 L
.93261 .25 L
.93262 .25 L
.93262 .25 L
.93263 .25 L
.93263 .25 L
.93264 .25 L
.93265 .25 L
.93265 .25 L
.93266 .25 L
.93266 .25 L
.93267 .25 L
.93268 .25 L
.93268 .25 L
.93269 .25 L
.93269 .25 L
.9327 .25 L
.9327 .25 L
.93271 .25 L
.93271 .25 L
.93272 .25 L
.93273 .25 L
.93273 .25 L
.93273 .25 L
.93274 .25 L
.93275 .25 L
.93275 .25 L
.93276 .25 L
.93276 .25 L
.93277 .25 L
.93278 .25 L
.93278 .25 L
.93278 .25 L
.93279 .25 L
.9328 .25 L
.9328 .25 L
.93281 .25 L
.93281 .25 L
.93282 .25 L
Mistroke
.93282 .25 L
.93283 .25 L
.93284 .25 L
.93284 .25 L
.93285 .25 L
.93285 .25 L
.93286 .25 L
.93287 .25 L
.93287 .25 L
.93288 .25 L
.93289 .25 L
.93289 .25 L
.9329 .25 L
.9329 .25 L
.93291 .25 L
.93292 .25 L
.93292 .25 L
.93293 .25 L
.93294 .25 L
.93294 .25 L
.93294 .25 L
.93295 .25 L
.93295 .25 L
.93296 .25 L
.93296 .25 L
.93297 .25 L
.93298 .25 L
.93298 .25 L
.93299 .25 L
.933 .25 L
.933 .25 L
.93301 .25 L
.93301 .25 L
.93302 .25 L
.93303 .25 L
.93303 .25 L
.93304 .25 L
.93305 .25 L
.93305 .25 L
.93306 .25 L
.93306 .25 L
.93307 .25 L
.93307 .25 L
.93308 .25 L
.93308 .25 L
.93309 .25 L
.93309 .25 L
.9331 .25 L
.9331 .25 L
.9331 .25 L
Mistroke
.93311 .25 L
.93311 .25 L
.93311 .25 L
.93312 .25 L
.93312 .25 L
.93313 .25 L
.93313 .25 L
.93314 .25 L
.93315 .25 L
.93315 .25 L
.93316 .25 L
.93317 .25 L
.93317 .25 L
.93318 .25 L
.93318 .25 L
.93319 .25 L
.9332 .25 L
.9332 .25 L
.93321 .25 L
.93322 .25 L
.93322 .25 L
.93323 .25 L
.93323 .25 L
.93324 .25 L
.93324 .25 L
.93325 .25 L
.93326 .25 L
.93326 .25 L
.93327 .25 L
.93327 .25 L
.93328 .25 L
.93328 .25 L
.93329 .25 L
.9333 .25 L
.9333 .25 L
.93331 .25 L
.93331 .25 L
.93332 .25 L
.93332 .25 L
.93333 .25 L
.93333 .25 L
.93334 .25 L
.93335 .25 L
.93335 .25 L
.93336 .25 L
.93337 .25 L
.93337 .25 L
.93338 .25 L
.93339 .25 L
.93339 .25 L
Mistroke
.9334 .25 L
.93341 .25 L
.93341 .25 L
.93342 .25 L
.93342 .25 L
.93343 .25 L
.93343 .25 L
.93344 .25 L
.93345 .25 L
.93345 .25 L
.93346 .25 L
.93346 .25 L
.93347 .25 L
.93348 .25 L
.93348 .25 L
.93349 .25 L
.93349 .25 L
.9335 .25 L
.93351 .25 L
.93351 .25 L
.93352 .25 L
.93352 .25 L
.93353 .25 L
.93353 .25 L
.93354 .25 L
.93354 .25 L
.93355 .25 L
.93355 .25 L
.93356 .25 L
.93356 .25 L
.93357 .25 L
.93358 .25 L
.93358 .25 L
.93359 .25 L
.93359 .25 L
.9336 .25 L
.9336 .25 L
.93361 .25 L
.93362 .25 L
.93362 .25 L
.93362 .25 L
.93363 .25 L
.93364 .25 L
.93364 .25 L
.93365 .25 L
.93365 .25 L
.93366 .25 L
.93367 .25 L
.93367 .25 L
.93368 .25 L
Mistroke
.93368 .25 L
.93369 .25 L
.9337 .25 L
.9337 .25 L
.93371 .25 L
.93371 .25 L
.93372 .25 L
.93373 .25 L
.93373 .25 L
.93374 .25 L
.93375 .25 L
.93375 .25 L
.93376 .25 L
.93376 .25 L
.93377 .25 L
.93377 .25 L
.93377 .25 L
.93378 .25 L
.93379 .25 L
.93379 .25 L
.9338 .25 L
.93381 .25 L
.93381 .25 L
.93382 .25 L
.93382 .25 L
.93383 .25 L
.93384 .25 L
.93384 .25 L
.93385 .25 L
.93386 .25 L
.93386 .25 L
.93387 .25 L
.93388 .25 L
.93388 .25 L
.93389 .25 L
.93389 .25 L
.9339 .25 L
.9339 .25 L
.93391 .25 L
.93391 .25 L
.93391 .25 L
.93392 .25 L
.93392 .25 L
.93393 .25 L
.93393 .25 L
.93393 .25 L
.93394 .25 L
.93394 .25 L
.93395 .25 L
.93395 .25 L
Mistroke
.93396 .25 L
.93396 .25 L
.93397 .25 L
.93398 .25 L
.93398 .25 L
.93399 .25 L
.93399 .25 L
.934 .25 L
.93401 .25 L
.93401 .25 L
.93402 .25 L
.93403 .25 L
.93403 .25 L
.93404 .25 L
.93405 .25 L
.93405 .25 L
.93405 .25 L
.93406 .25 L
.93407 .25 L
.93407 .25 L
.93408 .25 L
.93409 .25 L
.93409 .25 L
.9341 .25 L
.9341 .25 L
.93411 .25 L
.93411 .25 L
.93412 .25 L
.93413 .25 L
.93413 .25 L
.93414 .25 L
.93414 .25 L
.93415 .25 L
.93415 .25 L
.93416 .25 L
.93416 .25 L
.93417 .25 L
.93418 .25 L
.93418 .25 L
.93419 .25 L
.9342 .25 L
.9342 .25 L
.93421 .25 L
.93422 .25 L
.93422 .25 L
.93423 .25 L
.93423 .25 L
.93424 .25 L
.93425 .25 L
.93425 .25 L
Mistroke
.93426 .25 L
.93426 .25 L
.93427 .25 L
.93427 .25 L
.93428 .25 L
.93429 .25 L
.93429 .25 L
.9343 .25 L
.9343 .25 L
.93431 .25 L
.93432 .25 L
.93432 .25 L
.93433 .25 L
.93433 .25 L
.93434 .25 L
.93435 .25 L
.93435 .25 L
.93435 .25 L
.93436 .25 L
.93437 .25 L
.93437 .25 L
.93438 .25 L
.93439 .25 L
.93439 .25 L
.9344 .25 L
.93441 .25 L
.93441 .25 L
.93442 .25 L
.93442 .25 L
.93443 .25 L
.93444 .25 L
.93444 .25 L
.93445 .25 L
.93445 .25 L
.93446 .25 L
.93447 .25 L
.93447 .25 L
.93448 .25 L
.93448 .25 L
.93449 .25 L
.9345 .25 L
.9345 .25 L
.93451 .25 L
.93451 .25 L
.93452 .25 L
.93452 .25 L
.93453 .25 L
.93454 .25 L
.93454 .25 L
.93455 .25 L
Mistroke
.93455 .25 L
.93456 .25 L
.93456 .25 L
.93457 .25 L
.93458 .25 L
.93458 .25 L
.93458 .25 L
.93459 .25 L
.9346 .25 L
.9346 .25 L
.93461 .25 L
.93461 .25 L
.93462 .25 L
.93463 .25 L
.93463 .25 L
.93463 .25 L
.93464 .25 L
.93465 .25 L
.93465 .25 L
.93466 .25 L
.93466 .25 L
.93467 .25 L
.93467 .25 L
.93468 .25 L
.93469 .25 L
.93469 .25 L
.9347 .25 L
.9347 .25 L
.93471 .25 L
.93472 .25 L
.93472 .25 L
.93473 .25 L
.93474 .25 L
.93474 .25 L
.93475 .25 L
.93475 .25 L
.93476 .25 L
.93477 .25 L
.93477 .25 L
.93478 .25 L
.93479 .25 L
.93479 .25 L
.93479 .25 L
.9348 .25 L
.9348 .25 L
.93481 .25 L
.93481 .25 L
.93482 .25 L
.93483 .25 L
.93483 .25 L
Mistroke
.93484 .25 L
.93485 .25 L
.93485 .25 L
.93486 .25 L
.93486 .25 L
.93487 .25 L
.93488 .25 L
.93488 .25 L
.93489 .25 L
.9349 .25 L
.9349 .25 L
.93491 .25 L
.93491 .25 L
.93492 .25 L
.93492 .25 L
.93493 .25 L
.93493 .25 L
.93494 .25 L
.93494 .25 L
.93495 .25 L
.93495 .25 L
.93495 .25 L
.93496 .25 L
.93496 .25 L
.93496 .25 L
.93497 .25 L
.93497 .25 L
.93498 .25 L
.93498 .25 L
.93499 .25 L
.935 .25 L
.935 .25 L
.93501 .25 L
.93502 .25 L
.93502 .25 L
.93503 .25 L
.93503 .25 L
.93504 .25 L
.93505 .25 L
.93505 .25 L
.93506 .25 L
.93507 .25 L
.93507 .25 L
.93508 .25 L
.93508 .25 L
.93509 .25 L
.93509 .25 L
.9351 .25 L
.93511 .25 L
.93511 .25 L
Mistroke
.93512 .25 L
.93512 .25 L
.93513 .25 L
.93513 .25 L
.93514 .25 L
.93515 .25 L
.93515 .25 L
.93516 .25 L
.93516 .25 L
.93517 .25 L
.93518 .25 L
.93518 .25 L
.93518 .25 L
.93519 .25 L
.9352 .25 L
.93521 .25 L
.93521 .25 L
.93522 .25 L
.93522 .25 L
.93523 .25 L
.93524 .25 L
.93524 .25 L
.93525 .25 L
.93526 .25 L
.93526 .25 L
.93527 .25 L
.93528 .25 L
.93528 .25 L
.93528 .25 L
.93529 .25 L
.9353 .25 L
.9353 .25 L
.93531 .25 L
.93531 .25 L
.93532 .25 L
.93533 .25 L
.93533 .25 L
.93534 .25 L
.93534 .25 L
.93535 .25 L
.93536 .25 L
.93536 .25 L
.93537 .25 L
.93537 .25 L
.93538 .25 L
.93538 .25 L
.93539 .25 L
.93539 .25 L
.9354 .25 L
.9354 .25 L
Mistroke
.93541 .25 L
.93541 .25 L
.93542 .25 L
.93543 .25 L
.93543 .25 L
.93544 .25 L
.93544 .25 L
.93545 .25 L
.93546 .25 L
.93546 .25 L
.93547 .25 L
.93547 .25 L
.93547 .25 L
.93548 .25 L
.93549 .25 L
.93549 .25 L
.9355 .25 L
.9355 .25 L
.93551 .25 L
.93552 .25 L
.93552 .25 L
.93553 .25 L
.93553 .25 L
.93554 .25 L
.93555 .25 L
.93555 .25 L
.93556 .25 L
.93556 .25 L
.93557 .25 L
.93558 .25 L
.93558 .25 L
.93559 .25 L
.9356 .25 L
.9356 .25 L
.93561 .25 L
.93561 .25 L
.93562 .25 L
.93562 .25 L
.93563 .25 L
.93563 .25 L
.93564 .25 L
.93564 .25 L
.93565 .25 L
.93566 .25 L
.93566 .25 L
.93567 .25 L
.93568 .25 L
.93568 .25 L
.93569 .25 L
.9357 .25 L
Mistroke
.9357 .25 L
.93571 .25 L
.93571 .25 L
.93572 .25 L
.93573 .25 L
.93573 .25 L
.93574 .25 L
.93574 .25 L
.93575 .25 L
.93575 .25 L
.93576 .25 L
.93576 .25 L
.93576 .25 L
.93577 .25 L
.93577 .25 L
.93578 .25 L
.93578 .25 L
.93579 .25 L
.93579 .25 L
.93579 .25 L
.9358 .25 L
.9358 .25 L
.93581 .25 L
.93581 .25 L
.93582 .25 L
.93583 .25 L
.93583 .25 L
.93584 .25 L
.93585 .25 L
.93585 .25 L
.93586 .25 L
.93586 .25 L
.93587 .25 L
.93588 .25 L
.93588 .25 L
.93589 .25 L
.9359 .25 L
.9359 .25 L
.9359 .25 L
.93591 .25 L
.93592 .25 L
.93592 .25 L
.93593 .25 L
.93594 .25 L
.93594 .25 L
.93595 .25 L
.93595 .25 L
.93596 .25 L
.93596 .25 L
.93597 .25 L
Mistroke
.93598 .25 L
.93598 .25 L
.93599 .25 L
.936 .25 L
.936 .25 L
.936 .25 L
.93601 .25 L
.93602 .25 L
.93602 .25 L
.93603 .25 L
.93604 .25 L
.93604 .25 L
.93605 .25 L
.93605 .25 L
.93606 .25 L
.93607 .25 L
.93607 .25 L
.93608 .25 L
.93609 .25 L
.93609 .25 L
.9361 .25 L
.9361 .25 L
.93611 .25 L
.93611 .25 L
.93612 .25 L
.93613 .25 L
.93613 .25 L
.93614 .25 L
.93614 .25 L
.93615 .25 L
.93616 .25 L
.93616 .25 L
.93617 .25 L
.93617 .25 L
.93618 .25 L
.93619 .25 L
.93619 .25 L
.9362 .25 L
.9362 .25 L
.93621 .25 L
.93621 .25 L
.93622 .25 L
.93622 .25 L
.93623 .25 L
.93623 .25 L
.93624 .25 L
.93624 .25 L
.93625 .25 L
.93626 .25 L
.93626 .25 L
Mistroke
.93627 .25 L
.93628 .25 L
.93628 .25 L
.93628 .25 L
.93629 .25 L
.93629 .25 L
.9363 .25 L
.9363 .25 L
.93631 .25 L
.93632 .25 L
.93632 .25 L
.93633 .25 L
.93633 .25 L
.93634 .25 L
.93635 .25 L
.93635 .25 L
.93636 .25 L
.93636 .25 L
.93637 .25 L
.93638 .25 L
.93638 .25 L
.93639 .25 L
.93639 .25 L
.9364 .25 L
.93641 .25 L
.93641 .25 L
.93642 .25 L
.93643 .25 L
.93643 .25 L
.93644 .25 L
.93644 .25 L
.93645 .25 L
.93645 .25 L
.93646 .25 L
.93646 .25 L
.93647 .25 L
.93648 .25 L
.93648 .25 L
.93649 .25 L
.93649 .25 L
.9365 .25 L
.93651 .25 L
.93651 .25 L
.93652 .25 L
.93653 .25 L
.93653 .25 L
.93654 .25 L
.93655 .25 L
.93655 .25 L
.93656 .25 L
Mistroke
.93656 .25 L
.93657 .25 L
.93657 .25 L
.93658 .25 L
.93658 .25 L
.93658 .25 L
.93659 .25 L
.93659 .25 L
.9366 .25 L
.9366 .25 L
.93661 .25 L
.93661 .25 L
.93661 .25 L
.93662 .25 L
.93662 .25 L
.93662 .25 L
.93663 .25 L
.93664 .25 L
.93664 .25 L
.93665 .25 L
.93666 .25 L
.93666 .25 L
.93667 .25 L
.93668 .25 L
.93668 .25 L
.93669 .25 L
.93669 .25 L
.9367 .25 L
.93671 .25 L
.93671 .25 L
.93672 .25 L
.93672 .25 L
.93673 .25 L
.93673 .25 L
.93674 .25 L
.93675 .25 L
.93675 .25 L
.93676 .25 L
.93677 .25 L
.93677 .25 L
.93678 .25 L
.93678 .25 L
.93679 .25 L
.93679 .25 L
.9368 .25 L
.93681 .25 L
.93681 .25 L
.93682 .25 L
.93682 .25 L
.93683 .25 L
Mistroke
.93683 .25 L
.93684 .25 L
.93685 .25 L
.93685 .25 L
.93686 .25 L
.93687 .25 L
.93687 .25 L
.93688 .25 L
.93688 .25 L
.93689 .25 L
.9369 .25 L
.9369 .25 L
.93691 .25 L
.93692 .25 L
.93692 .25 L
.93693 .25 L
.93693 .25 L
.93694 .25 L
.93694 .25 L
.93695 .25 L
.93696 .25 L
.93696 .25 L
.93697 .25 L
.93697 .25 L
.93698 .25 L
.93698 .25 L
.93699 .25 L
.937 .25 L
.937 .25 L
.93701 .25 L
.93702 .25 L
.93702 .25 L
.93703 .25 L
.93703 .25 L
.93704 .25 L
.93704 .25 L
.93705 .25 L
.93705 .25 L
.93706 .25 L
.93706 .25 L
.93707 .25 L
.93707 .25 L
.93708 .25 L
.93709 .25 L
.93709 .25 L
.9371 .25 L
.9371 .25 L
.93711 .25 L
.93711 .25 L
.93712 .25 L
Mistroke
.93712 .25 L
.93713 .25 L
.93713 .25 L
.93714 .25 L
.93715 .25 L
.93715 .25 L
.93716 .25 L
.93716 .25 L
.93717 .25 L
.93718 .25 L
.93718 .25 L
.93719 .25 L
.93719 .25 L
.9372 .25 L
.93721 .25 L
.93721 .25 L
.93722 .25 L
.93723 .25 L
.93723 .25 L
.93724 .25 L
.93724 .25 L
.93725 .25 L
.93726 .25 L
.93726 .25 L
.93727 .25 L
.93727 .25 L
.93727 .25 L
.93728 .25 L
.93729 .25 L
.93729 .25 L
.9373 .25 L
.93731 .25 L
.93731 .25 L
.93732 .25 L
.93732 .25 L
.93733 .25 L
.93734 .25 L
.93734 .25 L
.93735 .25 L
.93736 .25 L
.93736 .25 L
.93737 .25 L
.93737 .25 L
.93738 .25 L
.93739 .25 L
.93739 .25 L
.9374 .25 L
.9374 .25 L
.9374 .25 L
.93741 .25 L
Mistroke
.93741 .25 L
.93742 .25 L
.93742 .25 L
.93742 .25 L
.93743 .25 L
.93743 .25 L
.93744 .25 L
.93744 .25 L
.93744 .25 L
.93745 .25 L
.93745 .25 L
.93746 .25 L
.93747 .25 L
.93747 .25 L
.93748 .25 L
.93749 .25 L
.93749 .25 L
.9375 .25 L
.93751 .25 L
.93751 .25 L
.93752 .25 L
.93752 .25 L
.93753 .25 L
.93754 .25 L
.93754 .25 L
.93755 .25 L
.93755 .25 L
.93756 .25 L
.93757 .25 L
.93757 .25 L
.93758 .25 L
.93758 .25 L
.93759 .25 L
.9376 .25 L
.9376 .25 L
.93761 .25 L
.93761 .25 L
.93762 .25 L
.93762 .25 L
.93763 .25 L
.93764 .25 L
.93764 .25 L
.93765 .25 L
.93765 .25 L
.93766 .25 L
.93766 .25 L
.93767 .25 L
.93768 .25 L
.93768 .25 L
.93769 .25 L
Mistroke
.9377 .25 L
.9377 .25 L
.93771 .25 L
.93771 .25 L
.93772 .25 L
.93773 .25 L
.93773 .25 L
.93774 .25 L
.93775 .25 L
.93775 .25 L
.93775 .25 L
.93776 .25 L
.93777 .25 L
.93777 .25 L
.93778 .25 L
.93779 .25 L
.93779 .25 L
.9378 .25 L
.9378 .25 L
.93781 .25 L
.93781 .25 L
.93782 .25 L
.93783 .25 L
.93783 .25 L
.93784 .25 L
.93785 .25 L
.93785 .25 L
.93785 .25 L
.93786 .25 L
.93787 .25 L
.93787 .25 L
.93788 .25 L
.93788 .25 L
.93789 .25 L
.93789 .25 L
.9379 .25 L
.9379 .25 L
.93791 .25 L
.93792 .25 L
.93792 .25 L
.93793 .25 L
.93793 .25 L
.93794 .25 L
.93794 .25 L
.93794 .25 L
.93795 .25 L
.93796 .25 L
.93796 .25 L
.93797 .25 L
.93798 .25 L
Mistroke
.93798 .25 L
.93799 .25 L
.93799 .25 L
.938 .25 L
.93801 .25 L
.93801 .25 L
.93802 .25 L
.93802 .25 L
.93803 .25 L
.93804 .25 L
.93804 .25 L
.93805 .25 L
.93806 .25 L
.93806 .25 L
.93807 .25 L
.93807 .25 L
.93808 .25 L
.93808 .25 L
.93809 .25 L
.93809 .25 L
.9381 .25 L
.9381 .25 L
.93811 .25 L
.93812 .25 L
.93812 .25 L
.93813 .25 L
.93813 .25 L
.93814 .25 L
.93815 .25 L
.93815 .25 L
.93816 .25 L
.93817 .25 L
.93817 .25 L
.93818 .25 L
.93819 .25 L
.93819 .25 L
.9382 .25 L
.93821 .25 L
.93821 .25 L
.93821 .25 L
.93822 .25 L
.93822 .25 L
.93823 .25 L
.93823 .25 L
.93823 .25 L
.93824 .25 L
.93824 .25 L
.93825 .25 L
.93825 .25 L
.93826 .25 L
Mistroke
.93826 .25 L
.93826 .25 L
.93827 .25 L
.93827 .25 L
.93828 .25 L
.93828 .25 L
.93829 .25 L
.9383 .25 L
.9383 .25 L
.93831 .25 L
.93832 .25 L
.93832 .25 L
.93833 .25 L
.93833 .25 L
.93834 .25 L
.93835 .25 L
.93835 .25 L
.93836 .25 L
.93837 .25 L
.93837 .25 L
.93837 .25 L
.93838 .25 L
.93839 .25 L
.93839 .25 L
.9384 .25 L
.93841 .25 L
.93841 .25 L
.93842 .25 L
.93842 .25 L
.93843 .25 L
.93844 .25 L
.93844 .25 L
.93845 .25 L
.93845 .25 L
.93846 .25 L
.93847 .25 L
.93847 .25 L
.93847 .25 L
.93848 .25 L
.93849 .25 L
.93849 .25 L
.9385 .25 L
.93851 .25 L
.93851 .25 L
.93852 .25 L
.93852 .25 L
.93853 .25 L
.93854 .25 L
.93854 .25 L
.93855 .25 L
Mistroke
.93856 .25 L
.93856 .25 L
.93857 .25 L
.93857 .25 L
.93858 .25 L
.93858 .25 L
.93859 .25 L
.9386 .25 L
.9386 .25 L
.93861 .25 L
.93862 .25 L
.93862 .25 L
.93863 .25 L
.93863 .25 L
.93864 .25 L
.93864 .25 L
.93865 .25 L
.93866 .25 L
.93866 .25 L
.93867 .25 L
.93867 .25 L
.93868 .25 L
.93868 .25 L
.93869 .25 L
.9387 .25 L
.9387 .25 L
.93871 .25 L
.93871 .25 L
.93872 .25 L
.93873 .25 L
.93873 .25 L
.93874 .25 L
.93875 .25 L
.93875 .25 L
.93876 .25 L
.93877 .25 L
.93877 .25 L
.93878 .25 L
.93878 .25 L
.93879 .25 L
.93879 .25 L
.9388 .25 L
.93881 .25 L
.93881 .25 L
.93882 .25 L
.93882 .25 L
.93883 .25 L
.93883 .25 L
.93884 .25 L
.93885 .25 L
Mistroke
.93885 .25 L
.93886 .25 L
.93886 .25 L
.93887 .25 L
.93887 .25 L
.93888 .25 L
.93888 .25 L
.93889 .25 L
.9389 .25 L
.9389 .25 L
.9389 .25 L
.93891 .25 L
.93892 .25 L
.93892 .25 L
.93893 .25 L
.93894 .25 L
.93894 .25 L
.93895 .25 L
.93895 .25 L
.93896 .25 L
.93896 .25 L
.93897 .25 L
.93897 .25 L
.93898 .25 L
.93898 .25 L
.93899 .25 L
.939 .25 L
.939 .25 L
.93901 .25 L
.93901 .25 L
.93902 .25 L
.93902 .25 L
.93903 .25 L
.93904 .25 L
.93904 .25 L
.93905 .25 L
.93906 .25 L
.93906 .25 L
.93907 .25 L
.93907 .25 L
.93908 .25 L
.93909 .25 L
.93909 .25 L
.9391 .25 L
.93911 .25 L
.93911 .25 L
.93911 .25 L
.93912 .25 L
.93912 .25 L
.93913 .25 L
Mistroke
.93913 .25 L
.93914 .25 L
.93915 .25 L
.93915 .25 L
.93916 .25 L
.93917 .25 L
.93917 .25 L
.93918 .25 L
.93919 .25 L
.93919 .25 L
.9392 .25 L
.9392 .25 L
.93921 .25 L
.93922 .25 L
.93922 .25 L
.93923 .25 L
.93924 .25 L
.93924 .25 L
.93925 .25 L
.93925 .25 L
.93925 .25 L
.93926 .25 L
.93926 .25 L
.93927 .25 L
.93927 .25 L
.93927 .25 L
.93928 .25 L
.93928 .25 L
.93929 .25 L
.93929 .25 L
.93929 .25 L
.9393 .25 L
.9393 .25 L
.93931 .25 L
.93932 .25 L
.93932 .25 L
.93933 .25 L
.93934 .25 L
.93934 .25 L
.93935 .25 L
.93935 .25 L
.93936 .25 L
.93937 .25 L
.93937 .25 L
.93938 .25 L
.93939 .25 L
.93939 .25 L
.9394 .25 L
.9394 .25 L
.93941 .25 L
Mistroke
.93941 .25 L
.93942 .25 L
.93943 .25 L
.93943 .25 L
.93944 .25 L
.93944 .25 L
.93945 .25 L
.93946 .25 L
.93946 .25 L
.93947 .25 L
.93947 .25 L
.93948 .25 L
.93949 .25 L
.93949 .25 L
.9395 .25 L
.9395 .25 L
.93951 .25 L
.93951 .25 L
.93952 .25 L
.93953 .25 L
.93953 .25 L
.93954 .25 L
.93955 .25 L
.93955 .25 L
.93956 .25 L
.93956 .25 L
.93957 .25 L
.93958 .25 L
.93958 .25 L
.93959 .25 L
.9396 .25 L
.9396 .25 L
.9396 .25 L
.93961 .25 L
.93962 .25 L
.93962 .25 L
.93963 .25 L
.93964 .25 L
.93964 .25 L
.93965 .25 L
.93965 .25 L
.93966 .25 L
.93966 .25 L
.93967 .25 L
.93968 .25 L
.93968 .25 L
.93969 .25 L
.9397 .25 L
.9397 .25 L
.9397 .25 L
Mistroke
.93971 .25 L
.93972 .25 L
.93972 .25 L
.93973 .25 L
.93973 .25 L
.93974 .25 L
.93974 .25 L
.93975 .25 L
.93975 .25 L
.93976 .25 L
.93977 .25 L
.93977 .25 L
.93978 .25 L
.93978 .25 L
.93979 .25 L
.93979 .25 L
.93979 .25 L
.9398 .25 L
.93981 .25 L
.93981 .25 L
.93982 .25 L
.93983 .25 L
.93983 .25 L
.93984 .25 L
.93984 .25 L
.93985 .25 L
.93986 .25 L
.93986 .25 L
.93987 .25 L
.93987 .25 L
.93988 .25 L
.93989 .25 L
.93989 .25 L
.9399 .25 L
.93991 .25 L
.93991 .25 L
.93992 .25 L
.93993 .25 L
.93993 .25 L
.93993 .25 L
.93994 .25 L
.93994 .25 L
.93995 .25 L
.93995 .25 L
.93996 .25 L
.93997 .25 L
.93997 .25 L
.93998 .25 L
.93999 .25 L
.93999 .25 L
Mistroke
.94 .25 L
.94 .25 L
.94001 .25 L
.94002 .25 L
.94002 .25 L
.94003 .25 L
.94004 .25 L
.94004 .25 L
.94005 .25 L
.94006 .25 L
.94006 .25 L
.94006 .25 L
.94007 .25 L
.94007 .25 L
.94008 .25 L
.94008 .25 L
.94008 .25 L
.94009 .25 L
.94009 .25 L
.9401 .25 L
.9401 .25 L
.94011 .25 L
.94011 .25 L
.94011 .25 L
.94012 .25 L
.94012 .25 L
.94013 .25 L
.94013 .25 L
.94014 .25 L
.94015 .25 L
.94015 .25 L
.94016 .25 L
.94017 .25 L
.94017 .25 L
.94018 .25 L
.94018 .25 L
.94019 .25 L
.9402 .25 L
.9402 .25 L
.94021 .25 L
.94022 .25 L
.94022 .25 L
.94023 .25 L
.94023 .25 L
.94024 .25 L
.94024 .25 L
.94025 .25 L
.94026 .25 L
.94026 .25 L
.94027 .25 L
Mistroke
.94027 .25 L
.94028 .25 L
.94029 .25 L
.94029 .25 L
.9403 .25 L
.9403 .25 L
.94031 .25 L
.94032 .25 L
.94032 .25 L
.94032 .25 L
.94033 .25 L
.94034 .25 L
.94034 .25 L
.94035 .25 L
.94036 .25 L
.94036 .25 L
.94037 .25 L
.94037 .25 L
.94038 .25 L
.94039 .25 L
.94039 .25 L
.9404 .25 L
.94041 .25 L
.94041 .25 L
.94042 .25 L
.94042 .25 L
.94043 .25 L
.94043 .25 L
.94044 .25 L
.94045 .25 L
.94045 .25 L
.94046 .25 L
.94047 .25 L
.94047 .25 L
.94048 .25 L
.94048 .25 L
.94049 .25 L
.94049 .25 L
.9405 .25 L
.94051 .25 L
.94051 .25 L
.94052 .25 L
.94052 .25 L
.94053 .25 L
.94053 .25 L
.94054 .25 L
.94055 .25 L
.94055 .25 L
.94055 .25 L
.94056 .25 L
Mistroke
.94057 .25 L
.94057 .25 L
.94058 .25 L
.94058 .25 L
.94059 .25 L
.9406 .25 L
.9406 .25 L
.9406 .25 L
.94061 .25 L
.94061 .25 L
.94062 .25 L
.94062 .25 L
.94063 .25 L
.94064 .25 L
.94064 .25 L
.94065 .25 L
.94066 .25 L
.94066 .25 L
.94067 .25 L
.94067 .25 L
.94068 .25 L
.94069 .25 L
.94069 .25 L
.9407 .25 L
.9407 .25 L
.94071 .25 L
.94072 .25 L
.94072 .25 L
.94073 .25 L
.94074 .25 L
.94074 .25 L
.94075 .25 L
.94076 .25 L
.94076 .25 L
.94076 .25 L
.94077 .25 L
.94077 .25 L
.94078 .25 L
.94078 .25 L
.94079 .25 L
.9408 .25 L
.9408 .25 L
.94081 .25 L
.94081 .25 L
.94082 .25 L
.94083 .25 L
.94083 .25 L
.94084 .25 L
.94085 .25 L
.94085 .25 L
Mistroke
.94086 .25 L
.94087 .25 L
.94087 .25 L
.94088 .25 L
.94088 .25 L
.94089 .25 L
.94089 .25 L
.9409 .25 L
.9409 .25 L
.9409 .25 L
.94091 .25 L
.94091 .25 L
.94092 .25 L
.94092 .25 L
.94093 .25 L
.94093 .25 L
.94093 .25 L
.94094 .25 L
.94094 .25 L
.94094 .25 L
.94095 .25 L
.94096 .25 L
.94096 .25 L
.94097 .25 L
.94098 .25 L
.94098 .25 L
.94099 .25 L
.941 .25 L
.941 .25 L
.94101 .25 L
.94101 .25 L
.94102 .25 L
.94103 .25 L
.94103 .25 L
.94104 .25 L
.94105 .25 L
.94105 .25 L
.94106 .25 L
.94106 .25 L
.94107 .25 L
.94107 .25 L
.94108 .25 L
.94109 .25 L
.94109 .25 L
.9411 .25 L
.9411 .25 L
.94111 .25 L
.94112 .25 L
.94112 .25 L
.94113 .25 L
Mistroke
.94113 .25 L
.94114 .25 L
.94114 .25 L
.94115 .25 L
.94115 .25 L
.94116 .25 L
.94117 .25 L
.94117 .25 L
.94118 .25 L
.94119 .25 L
.94119 .25 L
.9412 .25 L
.9412 .25 L
.94121 .25 L
.94122 .25 L
.94122 .25 L
.94123 .25 L
.94124 .25 L
.94124 .25 L
.94125 .25 L
.94125 .25 L
.94126 .25 L
.94126 .25 L
.94127 .25 L
.94128 .25 L
.94128 .25 L
.94129 .25 L
.94129 .25 L
.9413 .25 L
.94131 .25 L
.94131 .25 L
.94132 .25 L
.94132 .25 L
.94133 .25 L
.94134 .25 L
.94134 .25 L
.94135 .25 L
.94135 .25 L
.94136 .25 L
.94136 .25 L
.94137 .25 L
.94137 .25 L
.94138 .25 L
.94138 .25 L
.94139 .25 L
.94139 .25 L
.9414 .25 L
.94141 .25 L
.94141 .25 L
.94142 .25 L
Mistroke
.94142 .25 L
.94143 .25 L
.94143 .25 L
.94144 .25 L
.94144 .25 L
.94145 .25 L
.94145 .25 L
.94146 .25 L
.94147 .25 L
.94147 .25 L
.94148 .25 L
.94148 .25 L
.94149 .25 L
.9415 .25 L
.9415 .25 L
.94151 .25 L
.94151 .25 L
.94152 .25 L
.94153 .25 L
.94153 .25 L
.94154 .25 L
.94155 .25 L
.94155 .25 L
.94156 .25 L
.94157 .25 L
.94157 .25 L
.94158 .25 L
.94158 .25 L
.94159 .25 L
.94159 .25 L
.94159 .25 L
.9416 .25 L
.94161 .25 L
.94161 .25 L
.94162 .25 L
.94163 .25 L
.94163 .25 L
.94164 .25 L
.94164 .25 L
.94165 .25 L
.94166 .25 L
.94166 .25 L
.94167 .25 L
.94168 .25 L
.94168 .25 L
.94169 .25 L
.9417 .25 L
.9417 .25 L
.94171 .25 L
.94171 .25 L
Mistroke
.94172 .25 L
.94172 .25 L
.94172 .25 L
.94173 .25 L
.94173 .25 L
.94174 .25 L
.94174 .25 L
.94175 .25 L
.94175 .25 L
.94175 .25 L
.94176 .25 L
.94176 .25 L
.94176 .25 L
.94177 .25 L
.94177 .25 L
.94178 .25 L
.94179 .25 L
.94179 .25 L
.9418 .25 L
.94181 .25 L
.94181 .25 L
.94182 .25 L
.94183 .25 L
.94183 .25 L
.94184 .25 L
.94185 .25 L
.94185 .25 L
.94186 .25 L
.94186 .25 L
.94187 .25 L
.94187 .25 L
.94188 .25 L
.94189 .25 L
.94189 .25 L
.9419 .25 L
.9419 .25 L
.94191 .25 L
.94192 .25 L
.94192 .25 L
.94193 .25 L
.94193 .25 L
.94194 .25 L
.94195 .25 L
.94195 .25 L
.94196 .25 L
.94196 .25 L
.94197 .25 L
.94197 .25 L
.94198 .25 L
.94198 .25 L
Mistroke
.94199 .25 L
.942 .25 L
.942 .25 L
.94201 .25 L
.94202 .25 L
.94202 .25 L
.94203 .25 L
.94203 .25 L
.94204 .25 L
.94205 .25 L
.94205 .25 L
.94206 .25 L
.94207 .25 L
.94207 .25 L
.94207 .25 L
.94208 .25 L
.94209 .25 L
.94209 .25 L
.9421 .25 L
.94211 .25 L
.94211 .25 L
.94212 .25 L
.94212 .25 L
.94213 .25 L
.94213 .25 L
.94214 .25 L
.94215 .25 L
.94215 .25 L
.94216 .25 L
.94217 .25 L
.94217 .25 L
.94217 .25 L
.94218 .25 L
.94219 .25 L
.94219 .25 L
.9422 .25 L
.94221 .25 L
.94221 .25 L
.94222 .25 L
.94222 .25 L
.94223 .25 L
.94224 .25 L
.94224 .25 L
.94225 .25 L
.94226 .25 L
.94226 .25 L
.94227 .25 L
.94227 .25 L
.94228 .25 L
.94228 .25 L
Mistroke
.94229 .25 L
.9423 .25 L
.9423 .25 L
.94231 .25 L
.94232 .25 L
.94232 .25 L
.94233 .25 L
.94233 .25 L
.94234 .25 L
.94234 .25 L
.94235 .25 L
.94236 .25 L
.94236 .25 L
.94237 .25 L
.94237 .25 L
.94238 .25 L
.94238 .25 L
.94239 .25 L
.9424 .25 L
.9424 .25 L
.9424 .25 L
.94241 .25 L
.94242 .25 L
.94242 .25 L
.94243 .25 L
.94243 .25 L
.94244 .25 L
.94245 .25 L
.94245 .25 L
.94245 .25 L
.94246 .25 L
.94246 .25 L
.94247 .25 L
.94247 .25 L
.94248 .25 L
.94249 .25 L
.94249 .25 L
.9425 .25 L
.94251 .25 L
.94251 .25 L
.94252 .25 L
.94252 .25 L
.94253 .25 L
.94254 .25 L
.94254 .25 L
.94255 .25 L
.94255 .25 L
.94256 .25 L
.94257 .25 L
.94257 .25 L
Mistroke
.94258 .25 L
.94258 .25 L
.94259 .25 L
.9426 .25 L
.9426 .25 L
.94261 .25 L
.94261 .25 L
.94262 .25 L
.94262 .25 L
.94263 .25 L
.94263 .25 L
.94264 .25 L
.94265 .25 L
.94265 .25 L
.94266 .25 L
.94266 .25 L
.94267 .25 L
.94268 .25 L
.94268 .25 L
.94269 .25 L
.9427 .25 L
.9427 .25 L
.94271 .25 L
.94272 .25 L
.94272 .25 L
.94273 .25 L
.94273 .25 L
.94274 .25 L
.94274 .25 L
.94275 .25 L
.94275 .25 L
.94275 .25 L
.94276 .25 L
.94276 .25 L
.94277 .25 L
.94277 .25 L
.94278 .25 L
.94278 .25 L
.94278 .25 L
.94279 .25 L
.94279 .25 L
.94279 .25 L
.9428 .25 L
.94281 .25 L
.94281 .25 L
.94282 .25 L
.94283 .25 L
.94283 .25 L
.94284 .25 L
.94285 .25 L
Mistroke
.94285 .25 L
.94286 .25 L
.94286 .25 L
.94287 .25 L
.94288 .25 L
.94288 .25 L
.94289 .25 L
.9429 .25 L
.9429 .25 L
.94291 .25 L
.94291 .25 L
.94292 .25 L
.94292 .25 L
.94293 .25 L
.94294 .25 L
.94294 .25 L
.94295 .25 L
.94295 .25 L
.94296 .25 L
.94297 .25 L
.94297 .25 L
.94298 .25 L
.94298 .25 L
.94299 .25 L
.94299 .25 L
.943 .25 L
.943 .25 L
.94301 .25 L
.94302 .25 L
.94302 .25 L
.94303 .25 L
.94304 .25 L
.94304 .25 L
.94305 .25 L
.94305 .25 L
.94306 .25 L
.94307 .25 L
.94307 .25 L
.94308 .25 L
.94309 .25 L
.94309 .25 L
.9431 .25 L
.9431 .25 L
.94311 .25 L
.94311 .25 L
.94312 .25 L
.94313 .25 L
.94313 .25 L
.94314 .25 L
.94314 .25 L
Mistroke
.94315 .25 L
.94316 .25 L
.94316 .25 L
.94317 .25 L
.94317 .25 L
.94318 .25 L
.94319 .25 L
.94319 .25 L
.9432 .25 L
.9432 .25 L
.94321 .25 L
.94321 .25 L
.94322 .25 L
.94322 .25 L
.94323 .25 L
.94323 .25 L
.94324 .25 L
.94325 .25 L
.94325 .25 L
.94326 .25 L
.94326 .25 L
.94327 .25 L
.94327 .25 L
.94328 .25 L
.94328 .25 L
.94329 .25 L
.94329 .25 L
.9433 .25 L
.9433 .25 L
.94331 .25 L
.94332 .25 L
.94332 .25 L
.94333 .25 L
.94333 .25 L
.94334 .25 L
.94335 .25 L
.94335 .25 L
.94336 .25 L
.94337 .25 L
.94337 .25 L
.94338 .25 L
.94338 .25 L
.94339 .25 L
.9434 .25 L
.9434 .25 L
.94341 .25 L
.94342 .25 L
.94342 .25 L
.94343 .25 L
.94343 .25 L
Mistroke
.94344 .25 L
.94344 .25 L
.94344 .25 L
.94345 .25 L
.94346 .25 L
.94346 .25 L
.94347 .25 L
.94348 .25 L
.94348 .25 L
.94349 .25 L
.94349 .25 L
.9435 .25 L
.94351 .25 L
.94351 .25 L
.94352 .25 L
.94353 .25 L
.94353 .25 L
.94354 .25 L
.94355 .25 L
.94355 .25 L
.94356 .25 L
.94356 .25 L
.94357 .25 L
.94357 .25 L
.94357 .25 L
.94358 .25 L
.94358 .25 L
.94359 .25 L
.94359 .25 L
.9436 .25 L
.9436 .25 L
.9436 .25 L
.94361 .25 L
.94361 .25 L
.94362 .25 L
.94362 .25 L
.94362 .25 L
.94363 .25 L
.94364 .25 L
.94365 .25 L
.94365 .25 L
.94366 .25 L
.94366 .25 L
.94367 .25 L
.94368 .25 L
.94368 .25 L
.94369 .25 L
.9437 .25 L
.9437 .25 L
.94371 .25 L
Mistroke
.94372 .25 L
.94372 .25 L
.94372 .25 L
.94373 .25 L
.94374 .25 L
.94374 .25 L
.94375 .25 L
.94375 .25 L
.94376 .25 L
.94377 .25 L
.94377 .25 L
.94378 .25 L
.94378 .25 L
.94379 .25 L
.9438 .25 L
.9438 .25 L
.94381 .25 L
.94381 .25 L
.94382 .25 L
.94382 .25 L
.94383 .25 L
.94383 .25 L
.94384 .25 L
.94385 .25 L
.94385 .25 L
.94386 .25 L
.94387 .25 L
.94387 .25 L
.94388 .25 L
.94388 .25 L
.94389 .25 L
.9439 .25 L
.9439 .25 L
.94391 .25 L
.94392 .25 L
.94392 .25 L
.94393 .25 L
.94393 .25 L
.94394 .25 L
.94394 .25 L
.94395 .25 L
.94396 .25 L
.94396 .25 L
.94397 .25 L
.94397 .25 L
.94398 .25 L
.94399 .25 L
.94399 .25 L
.944 .25 L
.944 .25 L
Mistroke
.94401 .25 L
.94402 .25 L
.94402 .25 L
.94402 .25 L
.94403 .25 L
.94404 .25 L
.94404 .25 L
.94405 .25 L
.94405 .25 L
.94406 .25 L
.94406 .25 L
.94407 .25 L
.94407 .25 L
.94408 .25 L
.94409 .25 L
.94409 .25 L
.9441 .25 L
.9441 .25 L
.94411 .25 L
.94411 .25 L
.94412 .25 L
.94412 .25 L
.94413 .25 L
.94414 .25 L
.94414 .25 L
.94415 .25 L
.94415 .25 L
.94416 .25 L
.94416 .25 L
.94417 .25 L
.94418 .25 L
.94418 .25 L
.94419 .25 L
.9442 .25 L
.9442 .25 L
.94421 .25 L
.94421 .25 L
.94422 .25 L
.94423 .25 L
.94423 .25 L
.94424 .25 L
.94425 .25 L
.94425 .25 L
.94426 .25 L
.94426 .25 L
.94426 .25 L
.94427 .25 L
.94427 .25 L
.94428 .25 L
.94429 .25 L
Mistroke
.94429 .25 L
.9443 .25 L
.94431 .25 L
.94431 .25 L
.94432 .25 L
.94432 .25 L
.94433 .25 L
.94434 .25 L
.94434 .25 L
.94435 .25 L
.94436 .25 L
.94436 .25 L
.94437 .25 L
.94438 .25 L
.94438 .25 L
.94438 .25 L
.94439 .25 L
.94439 .25 L
.9444 .25 L
.9444 .25 L
.94441 .25 L
.94441 .25 L
.94442 .25 L
.94442 .25 L
.94442 .25 L
.94443 .25 L
.94443 .25 L
.94444 .25 L
.94444 .25 L
.94444 .25 L
.94445 .25 L
.94446 .25 L
.94446 .25 L
.94447 .25 L
.94448 .25 L
.94448 .25 L
.94449 .25 L
.94449 .25 L
.9445 .25 L
.94451 .25 L
.94451 .25 L
.94452 .25 L
.94453 .25 L
.94453 .25 L
.94454 .25 L
.94454 .25 L
.94455 .25 L
.94455 .25 L
.94456 .25 L
.94457 .25 L
Mistroke
.94457 .25 L
.94458 .25 L
.94458 .25 L
.94459 .25 L
.9446 .25 L
.9446 .25 L
.94461 .25 L
.94461 .25 L
.94462 .25 L
.94463 .25 L
.94463 .25 L
.94464 .25 L
.94464 .25 L
.94464 .25 L
.94465 .25 L
.94466 .25 L
.94466 .25 L
.94467 .25 L
.94468 .25 L
.94468 .25 L
.94469 .25 L
.9447 .25 L
.9447 .25 L
.94471 .25 L
.94471 .25 L
.94472 .25 L
.94473 .25 L
.94473 .25 L
.94474 .25 L
.94475 .25 L
.94475 .25 L
.94476 .25 L
.94476 .25 L
.94477 .25 L
.94477 .25 L
.94478 .25 L
.94479 .25 L
.94479 .25 L
.9448 .25 L
.9448 .25 L
.94481 .25 L
.94482 .25 L
.94482 .25 L
.94483 .25 L
.94483 .25 L
.94484 .25 L
.94484 .25 L
.94485 .25 L
.94485 .25 L
.94486 .25 L
Mistroke
.94487 .25 L
.94487 .25 L
.94487 .25 L
.94488 .25 L
.94489 .25 L
.94489 .25 L
.9449 .25 L
.9449 .25 L
.94491 .25 L
.94492 .25 L
.94492 .25 L
.94492 .25 L
.94493 .25 L
.94494 .25 L
.94494 .25 L
.94495 .25 L
.94495 .25 L
.94496 .25 L
.94496 .25 L
.94497 .25 L
.94498 .25 L
.94498 .25 L
.94499 .25 L
.94499 .25 L
.945 .25 L
.94501 .25 L
.94501 .25 L
.94502 .25 L
.94503 .25 L
.94503 .25 L
.94504 .25 L
.94504 .25 L
.94505 .25 L
.94506 .25 L
.94506 .25 L
.94507 .25 L
.94508 .25 L
.94508 .25 L
.94508 .25 L
.94509 .25 L
.94509 .25 L
.9451 .25 L
.9451 .25 L
.94511 .25 L
.94512 .25 L
.94512 .25 L
.94513 .25 L
.94514 .25 L
.94514 .25 L
.94515 .25 L
Mistroke
.94515 .25 L
.94516 .25 L
.94517 .25 L
.94517 .25 L
.94518 .25 L
.94519 .25 L
.94519 .25 L
.9452 .25 L
.9452 .25 L
.94521 .25 L
.94521 .25 L
.94522 .25 L
.94522 .25 L
.94523 .25 L
.94523 .25 L
.94524 .25 L
.94524 .25 L
.94524 .25 L
.94525 .25 L
.94525 .25 L
.94525 .25 L
.94526 .25 L
.94526 .25 L
.94527 .25 L
.94527 .25 L
.94528 .25 L
.94529 .25 L
.94529 .25 L
.9453 .25 L
.94531 .25 L
.94531 .25 L
.94532 .25 L
.94532 .25 L
.94533 .25 L
.94534 .25 L
.94534 .25 L
.94535 .25 L
.94536 .25 L
.94536 .25 L
.94537 .25 L
.94537 .25 L
.94538 .25 L
.94538 .25 L
.94539 .25 L
.9454 .25 L
.9454 .25 L
.94541 .25 L
.94541 .25 L
.94542 .25 L
.94542 .25 L
Mistroke
.94543 .25 L
.94544 .25 L
.94544 .25 L
.94545 .25 L
.94545 .25 L
.94546 .25 L
.94546 .25 L
.94547 .25 L
.94547 .25 L
.94548 .25 L
.94549 .25 L
.94549 .25 L
.9455 .25 L
.94551 .25 L
.94551 .25 L
.94552 .25 L
.94553 .25 L
.94553 .25 L
.94554 .25 L
.94555 .25 L
.94555 .25 L
.94556 .25 L
.94556 .25 L
.94557 .25 L
.94557 .25 L
.94558 .25 L
.94559 .25 L
.94559 .25 L
.9456 .25 L
.9456 .25 L
.94561 .25 L
.94562 .25 L
.94562 .25 L
.94563 .25 L
.94563 .25 L
.94564 .25 L
.94565 .25 L
.94565 .25 L
.94566 .25 L
.94566 .25 L
.94567 .25 L
.94567 .25 L
.94568 .25 L
.94568 .25 L
.94569 .25 L
.9457 .25 L
.9457 .25 L
.94571 .25 L
.94572 .25 L
.94572 .25 L
Mistroke
.94573 .25 L
.94573 .25 L
.94574 .25 L
.94575 .25 L
.94575 .25 L
.94576 .25 L
.94577 .25 L
.94577 .25 L
.94577 .25 L
.94578 .25 L
.94579 .25 L
.94579 .25 L
.9458 .25 L
.94581 .25 L
.94581 .25 L
.94582 .25 L
.94582 .25 L
.94583 .25 L
.94584 .25 L
.94584 .25 L
.94585 .25 L
.94585 .25 L
.94586 .25 L
.94587 .25 L
.94587 .25 L
.94587 .25 L
.94588 .25 L
.94589 .25 L
.94589 .25 L
.9459 .25 L
.9459 .25 L
.94591 .25 L
.94591 .25 L
.94592 .25 L
.94592 .25 L
.94593 .25 L
.94594 .25 L
.94594 .25 L
.94595 .25 L
.94595 .25 L
.94596 .25 L
.94596 .25 L
.94597 .25 L
.94597 .25 L
.94598 .25 L
.94599 .25 L
.94599 .25 L
.946 .25 L
.946 .25 L
.94601 .25 L
Mistroke
.94601 .25 L
.94602 .25 L
.94603 .25 L
.94603 .25 L
.94604 .25 L
.94605 .25 L
.94605 .25 L
.94606 .25 L
.94606 .25 L
.94607 .25 L
.94608 .25 L
.94608 .25 L
.94609 .25 L
.9461 .25 L
.9461 .25 L
.94611 .25 L
.94611 .25 L
.94611 .25 L
.94612 .25 L
.94612 .25 L
.94613 .25 L
.94614 .25 L
.94614 .25 L
.94615 .25 L
.94616 .25 L
.94616 .25 L
.94617 .25 L
.94617 .25 L
.94618 .25 L
.94619 .25 L
.94619 .25 L
.9462 .25 L
.94621 .25 L
.94621 .25 L
.94622 .25 L
.94623 .25 L
.94623 .25 L
.94623 .25 L
.94624 .25 L
.94624 .25 L
.94625 .25 L
.94625 .25 L
.94626 .25 L
.94626 .25 L
.94627 .25 L
.94627 .25 L
.94627 .25 L
.94628 .25 L
.94628 .25 L
.94629 .25 L
Mistroke
.94629 .25 L
.94629 .25 L
.9463 .25 L
.94631 .25 L
.94631 .25 L
.94632 .25 L
.94633 .25 L
.94633 .25 L
.94634 .25 L
.94634 .25 L
.94635 .25 L
.94636 .25 L
.94636 .25 L
.94637 .25 L
.94638 .25 L
.94638 .25 L
.94639 .25 L
.94639 .25 L
.9464 .25 L
.9464 .25 L
.94641 .25 L
.94642 .25 L
.94642 .25 L
.94643 .25 L
.94643 .25 L
.94644 .25 L
.94645 .25 L
.94645 .25 L
.94646 .25 L
.94646 .25 L
.94647 .25 L
.94648 .25 L
.94648 .25 L
.94649 .25 L
.94649 .25 L
.94649 .25 L
.9465 .25 L
.94651 .25 L
.94651 .25 L
.94652 .25 L
.94653 .25 L
.94653 .25 L
.94654 .25 L
.94655 .25 L
.94655 .25 L
.94656 .25 L
.94656 .25 L
.94657 .25 L
.94658 .25 L
.94658 .25 L
Mistroke
.94659 .25 L
.9466 .25 L
.9466 .25 L
.94661 .25 L
.94661 .25 L
.94662 .25 L
.94662 .25 L
.94663 .25 L
.94664 .25 L
.94664 .25 L
.94665 .25 L
.94665 .25 L
.94666 .25 L
.94667 .25 L
.94667 .25 L
.94668 .25 L
.94668 .25 L
.94669 .25 L
.94669 .25 L
.9467 .25 L
.9467 .25 L
.94671 .25 L
.94672 .25 L
.94672 .25 L
.94672 .25 L
.94673 .25 L
.94674 .25 L
.94674 .25 L
.94675 .25 L
.94675 .25 L
.94676 .25 L
.94677 .25 L
.94677 .25 L
.94677 .25 L
.94678 .25 L
.94679 .25 L
.94679 .25 L
.9468 .25 L
.9468 .25 L
.94681 .25 L
.94682 .25 L
.94682 .25 L
.94683 .25 L
.94683 .25 L
.94684 .25 L
.94684 .25 L
.94685 .25 L
.94686 .25 L
.94686 .25 L
.94687 .25 L
Mistroke
.94688 .25 L
.94688 .25 L
.94689 .25 L
.94689 .25 L
.9469 .25 L
.94691 .25 L
.94691 .25 L
.94692 .25 L
.94693 .25 L
.94693 .25 L
.94693 .25 L
.94694 .25 L
.94694 .25 L
.94695 .25 L
.94695 .25 L
.94696 .25 L
.94697 .25 L
.94697 .25 L
.94698 .25 L
.94699 .25 L
.94699 .25 L
.947 .25 L
.94701 .25 L
.94701 .25 L
.94702 .25 L
.94702 .25 L
.94703 .25 L
.94704 .25 L
.94704 .25 L
.94705 .25 L
.94705 .25 L
.94706 .25 L
.94706 .25 L
.94707 .25 L
.94707 .25 L
.94708 .25 L
.94708 .25 L
.94709 .25 L
.94709 .25 L
.94709 .25 L
.9471 .25 L
.9471 .25 L
.94711 .25 L
.94711 .25 L
.94711 .25 L
.94712 .25 L
.94712 .25 L
.94713 .25 L
.94714 .25 L
.94714 .25 L
Mistroke
.94715 .25 L
.94716 .25 L
.94716 .25 L
.94717 .25 L
.94717 .25 L
.94718 .25 L
.94719 .25 L
.94719 .25 L
.9472 .25 L
.94721 .25 L
.94721 .25 L
.94722 .25 L
.94722 .25 L
.94723 .25 L
.94723 .25 L
.94724 .25 L
.94725 .25 L
.94725 .25 L
.94726 .25 L
.94726 .25 L
.94727 .25 L
.94727 .25 L
.94728 .25 L
.94729 .25 L
.94729 .25 L
.9473 .25 L
.94731 .25 L
.94731 .25 L
.94732 .25 L
.94732 .25 L
.94733 .25 L
.94733 .25 L
.94734 .25 L
.94735 .25 L
.94735 .25 L
.94736 .25 L
.94736 .25 L
.94737 .25 L
.94738 .25 L
.94738 .25 L
.94739 .25 L
.9474 .25 L
.9474 .25 L
.94741 .25 L
.94742 .25 L
.94742 .25 L
.94742 .25 L
.94743 .25 L
.94744 .25 L
.94744 .25 L
Mistroke
.94745 .25 L
.94745 .25 L
.94746 .25 L
.94747 .25 L
.94747 .25 L
.94748 .25 L
.94748 .25 L
.94749 .25 L
.9475 .25 L
.9475 .25 L
.94751 .25 L
.94751 .25 L
.94752 .25 L
.94752 .25 L
.94753 .25 L
.94753 .25 L
.94754 .25 L
.94754 .25 L
.94755 .25 L
.94755 .25 L
.94756 .25 L
.94757 .25 L
.94757 .25 L
.94758 .25 L
.94758 .25 L
.94759 .25 L
.9476 .25 L
.9476 .25 L
.94761 .25 L
.94761 .25 L
.94761 .25 L
.94762 .25 L
.94763 .25 L
.94763 .25 L
.94764 .25 L
.94764 .25 L
.94765 .25 L
.94766 .25 L
.94766 .25 L
.94767 .25 L
.94767 .25 L
.94768 .25 L
.94769 .25 L
.94769 .25 L
.9477 .25 L
.94771 .25 L
.94771 .25 L
.94772 .25 L
.94772 .25 L
.94773 .25 L
Mistroke
.94774 .25 L
.94774 .25 L
.94775 .25 L
.94775 .25 L
.94776 .25 L
.94776 .25 L
.94777 .25 L
.94777 .25 L
.94778 .25 L
.94778 .25 L
.94779 .25 L
.9478 .25 L
.9478 .25 L
.94781 .25 L
.94782 .25 L
.94782 .25 L
.94783 .25 L
.94784 .25 L
.94784 .25 L
.94785 .25 L
.94785 .25 L
.94786 .25 L
.94787 .25 L
.94787 .25 L
.94788 .25 L
.94788 .25 L
.94789 .25 L
.94789 .25 L
.9479 .25 L
.9479 .25 L
.9479 .25 L
.94791 .25 L
.94791 .25 L
.94792 .25 L
.94792 .25 L
.94793 .25 L
.94793 .25 L
.94793 .25 L
.94794 .25 L
.94794 .25 L
.94795 .25 L
.94795 .25 L
.94796 .25 L
.94797 .25 L
.94797 .25 L
.94798 .25 L
.94799 .25 L
.94799 .25 L
.948 .25 L
.948 .25 L
Mistroke
.94801 .25 L
.94802 .25 L
.94802 .25 L
.94803 .25 L
.94804 .25 L
.94804 .25 L
.94804 .25 L
.94805 .25 L
.94806 .25 L
.94806 .25 L
.94807 .25 L
.94808 .25 L
.94808 .25 L
.94809 .25 L
.94809 .25 L
.9481 .25 L
.9481 .25 L
.94811 .25 L
.94812 .25 L
.94812 .25 L
.94813 .25 L
.94814 .25 L
.94814 .25 L
.94814 .25 L
.94815 .25 L
.94816 .25 L
.94816 .25 L
.94817 .25 L
.94818 .25 L
.94818 .25 L
.94819 .25 L
.94819 .25 L
.9482 .25 L
.94821 .25 L
.94821 .25 L
.94822 .25 L
.94823 .25 L
.94823 .25 L
.94824 .25 L
.94824 .25 L
.94825 .25 L
.94825 .25 L
.94826 .25 L
.94827 .25 L
.94827 .25 L
.94828 .25 L
.94828 .25 L
.94829 .25 L
.9483 .25 L
.9483 .25 L
Mistroke
.94831 .25 L
.94831 .25 L
.94832 .25 L
.94833 .25 L
.94833 .25 L
.94834 .25 L
.94834 .25 L
.94834 .25 L
.94835 .25 L
.94836 .25 L
.94836 .25 L
.94837 .25 L
.94837 .25 L
.94838 .25 L
.94838 .25 L
.94839 .25 L
.9484 .25 L
.9484 .25 L
.94841 .25 L
.94842 .25 L
.94842 .25 L
.94842 .25 L
.94843 .25 L
.94843 .25 L
.94844 .25 L
.94844 .25 L
.94845 .25 L
.94846 .25 L
.94846 .25 L
.94847 .25 L
.94847 .25 L
.94848 .25 L
.94849 .25 L
.94849 .25 L
.9485 .25 L
.9485 .25 L
.94851 .25 L
.94852 .25 L
.94852 .25 L
.94853 .25 L
.94853 .25 L
.94854 .25 L
.94855 .25 L
.94855 .25 L
.94856 .25 L
.94857 .25 L
.94857 .25 L
.94858 .25 L
.94858 .25 L
.94859 .25 L
Mistroke
.94859 .25 L
.9486 .25 L
.9486 .25 L
.94861 .25 L
.94862 .25 L
.94862 .25 L
.94863 .25 L
.94863 .25 L
.94864 .25 L
.94865 .25 L
.94865 .25 L
.94866 .25 L
.94866 .25 L
.94867 .25 L
.94868 .25 L
.94868 .25 L
.94869 .25 L
.9487 .25 L
.9487 .25 L
.94871 .25 L
.94871 .25 L
.94872 .25 L
.94872 .25 L
.94872 .25 L
.94873 .25 L
.94873 .25 L
.94874 .25 L
.94874 .25 L
.94874 .25 L
.94875 .25 L
.94875 .25 L
.94876 .25 L
.94876 .25 L
.94876 .25 L
.94877 .25 L
.94878 .25 L
.94878 .25 L
.94879 .25 L
.9488 .25 L
.9488 .25 L
.94881 .25 L
.94881 .25 L
.94882 .25 L
.94883 .25 L
.94883 .25 L
.94884 .25 L
.94885 .25 L
.94885 .25 L
.94886 .25 L
.94886 .25 L
Mistroke
.94887 .25 L
.94887 .25 L
.94888 .25 L
.94889 .25 L
.94889 .25 L
.9489 .25 L
.94891 .25 L
.94891 .25 L
.94892 .25 L
.94892 .25 L
.94893 .25 L
.94893 .25 L
.94894 .25 L
.94895 .25 L
.94895 .25 L
.94896 .25 L
.94896 .25 L
.94897 .25 L
.94897 .25 L
.94898 .25 L
.94899 .25 L
.94899 .25 L
.949 .25 L
.94901 .25 L
.94901 .25 L
.94902 .25 L
.94902 .25 L
.94903 .25 L
.94904 .25 L
.94904 .25 L
.94905 .25 L
.94906 .25 L
.94906 .25 L
.94907 .25 L
.94907 .25 L
.94908 .25 L
.94908 .25 L
.94909 .25 L
.9491 .25 L
.9491 .25 L
.94911 .25 L
.94911 .25 L
.94912 .25 L
.94912 .25 L
.94913 .25 L
.94914 .25 L
.94914 .25 L
.94915 .25 L
.94915 .25 L
.94916 .25 L
Mistroke
.94916 .25 L
.94917 .25 L
.94917 .25 L
.94918 .25 L
.94919 .25 L
.94919 .25 L
.9492 .25 L
.94921 .25 L
.94921 .25 L
.94922 .25 L
.94923 .25 L
.94923 .25 L
.94924 .25 L
.94925 .25 L
.94925 .25 L
.94926 .25 L
.94926 .25 L
.94927 .25 L
.94927 .25 L
.94928 .25 L
.94929 .25 L
.94929 .25 L
.9493 .25 L
.9493 .25 L
.94931 .25 L
.94932 .25 L
.94932 .25 L
.94933 .25 L
.94933 .25 L
.94934 .25 L
.94935 .25 L
.94935 .25 L
.94936 .25 L
.94936 .25 L
.94937 .25 L
.94937 .25 L
.94938 .25 L
.94938 .25 L
.94939 .25 L
.94939 .25 L
.9494 .25 L
.9494 .25 L
.94941 .25 L
.94942 .25 L
.94942 .25 L
.94943 .25 L
.94943 .25 L
.94944 .25 L
.94944 .25 L
.94945 .25 L
Mistroke
.94946 .25 L
.94946 .25 L
.94946 .25 L
.94947 .25 L
.94948 .25 L
.94948 .25 L
.94949 .25 L
.94949 .25 L
.9495 .25 L
.94951 .25 L
.94951 .25 L
.94952 .25 L
.94952 .25 L
.94953 .25 L
.94954 .25 L
.94954 .25 L
.94955 .25 L
.94955 .25 L
.94956 .25 L
.94957 .25 L
.94957 .25 L
.94958 .25 L
.94959 .25 L
.94959 .25 L
.9496 .25 L
.9496 .25 L
.94961 .25 L
.94961 .25 L
.94962 .25 L
.94962 .25 L
.94963 .25 L
.94963 .25 L
.94964 .25 L
.94965 .25 L
.94965 .25 L
.94966 .25 L
.94967 .25 L
.94967 .25 L
.94968 .25 L
.94969 .25 L
.94969 .25 L
.9497 .25 L
.9497 .25 L
.94971 .25 L
.94972 .25 L
.94972 .25 L
.94973 .25 L
.94973 .25 L
.94974 .25 L
.94974 .25 L
Mistroke
.94975 .25 L
.94975 .25 L
.94975 .25 L
.94976 .25 L
.94976 .25 L
.94977 .25 L
.94977 .25 L
.94978 .25 L
.94978 .25 L
.94978 .25 L
.94979 .25 L
.94979 .25 L
.9498 .25 L
.9498 .25 L
.94981 .25 L
.94982 .25 L
.94982 .25 L
.94983 .25 L
.94984 .25 L
.94984 .25 L
.94985 .25 L
.94985 .25 L
.94986 .25 L
.94987 .25 L
.94987 .25 L
.94988 .25 L
.94989 .25 L
.94989 .25 L
.94989 .25 L
.9499 .25 L
.94991 .25 L
.94991 .25 L
.94992 .25 L
.94993 .25 L
.94993 .25 L
.94994 .25 L
.94994 .25 L
.94995 .25 L
.94995 .25 L
.94996 .25 L
.94997 .25 L
.94997 .25 L
.94998 .25 L
.94999 .25 L
.94999 .25 L
.94999 .25 L
.95 .25 L
.95001 .25 L
.95001 .25 L
.95002 .25 L
Mistroke
.95003 .25 L
.95003 .25 L
.95004 .25 L
.95004 .25 L
.95005 .25 L
.95006 .25 L
.95006 .25 L
.95007 .25 L
.95008 .25 L
.95008 .25 L
.95009 .25 L
.95009 .25 L
.9501 .25 L
.9501 .25 L
.95011 .25 L
.95012 .25 L
.95012 .25 L
.95013 .25 L
.95013 .25 L
.95014 .25 L
.95015 .25 L
.95015 .25 L
.95016 .25 L
.95016 .25 L
.95017 .25 L
.95018 .25 L
.95018 .25 L
.95019 .25 L
.95019 .25 L
.9502 .25 L
.9502 .25 L
.95021 .25 L
.95021 .25 L
.95022 .25 L
.95022 .25 L
.95023 .25 L
.95023 .25 L
.95024 .25 L
.95025 .25 L
.95025 .25 L
.95026 .25 L
.95027 .25 L
.95027 .25 L
.95027 .25 L
.95028 .25 L
.95028 .25 L
.95029 .25 L
.95029 .25 L
.9503 .25 L
.95031 .25 L
Mistroke
.95031 .25 L
.95032 .25 L
.95032 .25 L
.95033 .25 L
.95034 .25 L
.95034 .25 L
.95035 .25 L
.95035 .25 L
.95036 .25 L
.95037 .25 L
.95037 .25 L
.95038 .25 L
.95039 .25 L
.95039 .25 L
.9504 .25 L
.9504 .25 L
.95041 .25 L
.95042 .25 L
.95042 .25 L
.95043 .25 L
.95043 .25 L
.95044 .25 L
.95044 .25 L
.95045 .25 L
.95045 .25 L
.95046 .25 L
.95047 .25 L
.95047 .25 L
.95048 .25 L
.95048 .25 L
.95049 .25 L
.9505 .25 L
.9505 .25 L
.95051 .25 L
.95052 .25 L
.95052 .25 L
.95053 .25 L
.95054 .25 L
.95054 .25 L
.95055 .25 L
.95055 .25 L
.95056 .25 L
.95056 .25 L
.95057 .25 L
.95057 .25 L
.95057 .25 L
.95058 .25 L
.95058 .25 L
.95059 .25 L
.95059 .25 L
Mistroke
.9506 .25 L
.9506 .25 L
.9506 .25 L
.95061 .25 L
.95061 .25 L
.95061 .25 L
.95062 .25 L
.95063 .25 L
.95063 .25 L
.95064 .25 L
.95065 .25 L
.95065 .25 L
.95066 .25 L
.95067 .25 L
.95067 .25 L
.95068 .25 L
.95068 .25 L
.95069 .25 L
.9507 .25 L
.9507 .25 L
.95071 .25 L
.95071 .25 L
.95072 .25 L
.95073 .25 L
.95073 .25 L
.95074 .25 L
.95074 .25 L
.95075 .25 L
.95076 .25 L
.95076 .25 L
.95077 .25 L
.95077 .25 L
.95078 .25 L
.95078 .25 L
.95079 .25 L
.9508 .25 L
.9508 .25 L
.95081 .25 L
.95081 .25 L
.95082 .25 L
.95082 .25 L
.95083 .25 L
.95084 .25 L
.95084 .25 L
.95085 .25 L
.95086 .25 L
.95086 .25 L
.95087 .25 L
.95087 .25 L
.95088 .25 L
Mistroke
.95089 .25 L
.95089 .25 L
.9509 .25 L
.95091 .25 L
.95091 .25 L
.95092 .25 L
.95092 .25 L
.95093 .25 L
.95093 .25 L
.95094 .25 L
.95095 .25 L
.95095 .25 L
.95096 .25 L
.95096 .25 L
.95097 .25 L
.95098 .25 L
.95098 .25 L
.95099 .25 L
.95099 .25 L
.951 .25 L
.95101 .25 L
.95101 .25 L
.95102 .25 L
.95102 .25 L
.95103 .25 L
.95103 .25 L
.95104 .25 L
.95104 .25 L
.95105 .25 L
.95105 .25 L
.95106 .25 L
.95106 .25 L
.95107 .25 L
.95108 .25 L
.95108 .25 L
.95109 .25 L
.95109 .25 L
.9511 .25 L
.9511 .25 L
.95111 .25 L
.95111 .25 L
.95112 .25 L
.95112 .25 L
.95113 .25 L
.95114 .25 L
.95114 .25 L
.95115 .25 L
.95115 .25 L
.95116 .25 L
.95117 .25 L
Mistroke
.95117 .25 L
.95118 .25 L
.95118 .25 L
.95119 .25 L
.9512 .25 L
.9512 .25 L
.95121 .25 L
.95122 .25 L
.95122 .25 L
.95123 .25 L
.95124 .25 L
.95124 .25 L
.95125 .25 L
.95125 .25 L
.95126 .25 L
.95126 .25 L
.95126 .25 L
.95127 .25 L
.95128 .25 L
.95128 .25 L
.95129 .25 L
.9513 .25 L
.9513 .25 L
.95131 .25 L
.95131 .25 L
.95132 .25 L
.95133 .25 L
.95133 .25 L
.95134 .25 L
.95135 .25 L
.95135 .25 L
.95136 .25 L
.95137 .25 L
.95137 .25 L
.95138 .25 L
.95138 .25 L
.95139 .25 L
.95139 .25 L
.95139 .25 L
.9514 .25 L
.9514 .25 L
.95141 .25 L
.95141 .25 L
.95142 .25 L
.95142 .25 L
.95142 .25 L
.95143 .25 L
.95143 .25 L
.95143 .25 L
.95144 .25 L
Mistroke
.95144 .25 L
.95145 .25 L
.95146 .25 L
.95146 .25 L
.95147 .25 L
.95148 .25 L
.95148 .25 L
.95149 .25 L
.9515 .25 L
.9515 .25 L
.95151 .25 L
.95152 .25 L
.95152 .25 L
.95153 .25 L
.95153 .25 L
.95154 .25 L
.95154 .25 L
.95155 .25 L
.95156 .25 L
.95156 .25 L
.95157 .25 L
.95157 .25 L
.95158 .25 L
.95159 .25 L
.95159 .25 L
.9516 .25 L
.9516 .25 L
.95161 .25 L
.95162 .25 L
.95162 .25 L
.95163 .25 L
.95163 .25 L
.95164 .25 L
.95164 .25 L
.95165 .25 L
.95165 .25 L
.95166 .25 L
.95167 .25 L
.95167 .25 L
.95168 .25 L
.95169 .25 L
.95169 .25 L
.9517 .25 L
.9517 .25 L
.95171 .25 L
.95172 .25 L
.95172 .25 L
.95173 .25 L
.95174 .25 L
.95174 .25 L
Mistroke
.95174 .25 L
.95175 .25 L
.95176 .25 L
.95176 .25 L
.95177 .25 L
.95178 .25 L
.95178 .25 L
.95179 .25 L
.95179 .25 L
.9518 .25 L
.9518 .25 L
.95181 .25 L
.95182 .25 L
.95182 .25 L
.95183 .25 L
.95184 .25 L
.95184 .25 L
.95184 .25 L
.95185 .25 L
.95186 .25 L
.95186 .25 L
.95187 .25 L
.95187 .25 L
.95188 .25 L
.95188 .25 L
.95189 .25 L
.95189 .25 L
.9519 .25 L
.95191 .25 L
.95191 .25 L
.95192 .25 L
.95192 .25 L
.95193 .25 L
.95193 .25 L
.95193 .25 L
.95194 .25 L
.95195 .25 L
.95195 .25 L
.95196 .25 L
.95197 .25 L
.95197 .25 L
.95198 .25 L
.95198 .25 L
.95199 .25 L
.952 .25 L
.952 .25 L
.95201 .25 L
.95201 .25 L
.95202 .25 L
.95203 .25 L
Mistroke
.95203 .25 L
.95204 .25 L
.95205 .25 L
.95205 .25 L
.95206 .25 L
.95207 .25 L
.95207 .25 L
.95208 .25 L
.95208 .25 L
.95208 .25 L
.95209 .25 L
.95209 .25 L
.9521 .25 L
.95211 .25 L
.95211 .25 L
.95212 .25 L
.95213 .25 L
.95213 .25 L
.95214 .25 L
.95214 .25 L
.95215 .25 L
.95216 .25 L
.95216 .25 L
.95217 .25 L
.95218 .25 L
.95218 .25 L
.95219 .25 L
.9522 .25 L
.9522 .25 L
.9522 .25 L
.95221 .25 L
.95221 .25 L
.95222 .25 L
.95222 .25 L
.95222 .25 L
.95223 .25 L
.95224 .25 L
.95224 .25 L
.95224 .25 L
.95225 .25 L
.95225 .25 L
.95225 .25 L
.95226 .25 L
.95226 .25 L
.95227 .25 L
.95227 .25 L
.95228 .25 L
.95229 .25 L
.95229 .25 L
.9523 .25 L
Mistroke
.95231 .25 L
.95231 .25 L
.95232 .25 L
.95233 .25 L
.95233 .25 L
.95234 .25 L
.95234 .25 L
.95235 .25 L
.95236 .25 L
.95236 .25 L
.95237 .25 L
.95237 .25 L
.95238 .25 L
.95238 .25 L
.95239 .25 L
.9524 .25 L
.9524 .25 L
.95241 .25 L
.95241 .25 L
.95242 .25 L
.95243 .25 L
.95243 .25 L
.95244 .25 L
.95244 .25 L
.95245 .25 L
.95246 .25 L
.95246 .25 L
.95246 .25 L
.95247 .25 L
.95248 .25 L
.95248 .25 L
.95249 .25 L
.9525 .25 L
.9525 .25 L
.95251 .25 L
.95251 .25 L
.95252 .25 L
.95253 .25 L
.95253 .25 L
.95254 .25 L
.95255 .25 L
.95255 .25 L
.95256 .25 L
.95256 .25 L
.95257 .25 L
.95257 .25 L
.95258 .25 L
.95259 .25 L
.95259 .25 L
.9526 .25 L
Mistroke
.95261 .25 L
.95261 .25 L
.95262 .25 L
.95262 .25 L
.95263 .25 L
.95263 .25 L
.95264 .25 L
.95265 .25 L
.95265 .25 L
.95266 .25 L
.95266 .25 L
.95267 .25 L
.95267 .25 L
.95268 .25 L
.95269 .25 L
.95269 .25 L
.95269 .25 L
.9527 .25 L
.95271 .25 L
.95271 .25 L
.95272 .25 L
.95272 .25 L
.95273 .25 L
.95274 .25 L
.95274 .25 L
.95274 .25 L
.95275 .25 L
.95275 .25 L
.95276 .25 L
.95276 .25 L
.95277 .25 L
.95278 .25 L
.95278 .25 L
.95279 .25 L
.9528 .25 L
.9528 .25 L
.95281 .25 L
.95281 .25 L
.95282 .25 L
.95283 .25 L
.95283 .25 L
.95284 .25 L
.95284 .25 L
.95285 .25 L
.95286 .25 L
.95286 .25 L
.95287 .25 L
.95288 .25 L
.95288 .25 L
.95289 .25 L
Mistroke
.9529 .25 L
.9529 .25 L
.9529 .25 L
.95291 .25 L
.95291 .25 L
.95292 .25 L
.95292 .25 L
.95293 .25 L
.95294 .25 L
.95294 .25 L
.95295 .25 L
.95295 .25 L
.95296 .25 L
.95297 .25 L
.95297 .25 L
.95298 .25 L
.95299 .25 L
.95299 .25 L
.953 .25 L
.95301 .25 L
.95301 .25 L
.95302 .25 L
.95302 .25 L
.95303 .25 L
.95303 .25 L
.95304 .25 L
.95304 .25 L
.95304 .25 L
.95305 .25 L
.95305 .25 L
.95306 .25 L
.95306 .25 L
.95307 .25 L
.95307 .25 L
.95307 .25 L
.95308 .25 L
.95308 .25 L
.95308 .25 L
.95309 .25 L
.9531 .25 L
.9531 .25 L
.95311 .25 L
.95312 .25 L
.95312 .25 L
.95313 .25 L
.95314 .25 L
.95314 .25 L
.95315 .25 L
.95316 .25 L
.95316 .25 L
Mistroke
.95317 .25 L
.95317 .25 L
.95318 .25 L
.95319 .25 L
.95319 .25 L
.9532 .25 L
.9532 .25 L
.95321 .25 L
.95321 .25 L
.95322 .25 L
.95323 .25 L
.95323 .25 L
.95324 .25 L
.95324 .25 L
.95325 .25 L
.95326 .25 L
.95326 .25 L
.95327 .25 L
.95327 .25 L
.95328 .25 L
.95328 .25 L
.95329 .25 L
.95329 .25 L
.9533 .25 L
.95331 .25 L
.95331 .25 L
.95332 .25 L
.95333 .25 L
.95333 .25 L
.95334 .25 L
.95334 .25 L
.95335 .25 L
.95336 .25 L
.95336 .25 L
.95337 .25 L
.95338 .25 L
.95338 .25 L
.95339 .25 L
.95339 .25 L
.9534 .25 L
.9534 .25 L
.95341 .25 L
.95342 .25 L
.95342 .25 L
.95343 .25 L
.95343 .25 L
.95344 .25 L
.95345 .25 L
.95345 .25 L
.95346 .25 L
Mistroke
.95346 .25 L
.95347 .25 L
.95348 .25 L
.95348 .25 L
.95349 .25 L
.95349 .25 L
.9535 .25 L
.9535 .25 L
.95351 .25 L
.95352 .25 L
.95352 .25 L
.95353 .25 L
.95354 .25 L
.95354 .25 L
.95355 .25 L
.95355 .25 L
.95356 .25 L
.95357 .25 L
.95357 .25 L
.95358 .25 L
.95359 .25 L
.95359 .25 L
.95359 .25 L
.9536 .25 L
.95361 .25 L
.95361 .25 L
.95362 .25 L
.95363 .25 L
.95363 .25 L
.95364 .25 L
.95364 .25 L
.95365 .25 L
.95365 .25 L
.95366 .25 L
.95367 .25 L
.95367 .25 L
.95368 .25 L
.95369 .25 L
.95369 .25 L
.95369 .25 L
.9537 .25 L
.95371 .25 L
.95371 .25 L
.95372 .25 L
.95372 .25 L
.95373 .25 L
.95373 .25 L
.95374 .25 L
.95374 .25 L
.95375 .25 L
Mistroke
.95376 .25 L
.95376 .25 L
.95377 .25 L
.95377 .25 L
.95378 .25 L
.95378 .25 L
.95378 .25 L
.95379 .25 L
.9538 .25 L
.9538 .25 L
.95381 .25 L
.95382 .25 L
.95382 .25 L
.95383 .25 L
.95383 .25 L
.95384 .25 L
.95385 .25 L
.95385 .25 L
.95386 .25 L
.95386 .25 L
.95387 .25 L
.95388 .25 L
.95388 .25 L
.95389 .25 L
.9539 .25 L
.9539 .25 L
.95391 .25 L
.95392 .25 L
.95392 .25 L
.95392 .25 L
.95393 .25 L
.95393 .25 L
.95394 .25 L
.95394 .25 L
.95395 .25 L
.95396 .25 L
.95396 .25 L
.95397 .25 L
.95398 .25 L
.95398 .25 L
.95399 .25 L
.95399 .25 L
.954 .25 L
.95401 .25 L
.95401 .25 L
.95402 .25 L
.95403 .25 L
.95403 .25 L
.95404 .25 L
.95405 .25 L
Mistroke
.95405 .25 L
.95405 .25 L
.95406 .25 L
.95406 .25 L
.95407 .25 L
.95407 .25 L
.95407 .25 L
.95408 .25 L
.95409 .25 L
.95409 .25 L
.95409 .25 L
.9541 .25 L
.9541 .25 L
.9541 .25 L
.95411 .25 L
.95411 .25 L
.95412 .25 L
.95412 .25 L
.95413 .25 L
.95414 .25 L
.95414 .25 L
.95415 .25 L
.95416 .25 L
.95416 .25 L
.95417 .25 L
.95417 .25 L
.95418 .25 L
.95419 .25 L
.95419 .25 L
.9542 .25 L
.95421 .25 L
.95421 .25 L
.95422 .25 L
.95422 .25 L
.95423 .25 L
.95423 .25 L
.95424 .25 L
.95425 .25 L
.95425 .25 L
.95426 .25 L
.95426 .25 L
.95427 .25 L
.95428 .25 L
.95428 .25 L
.95429 .25 L
.95429 .25 L
.9543 .25 L
.95431 .25 L
.95431 .25 L
.95431 .25 L
Mistroke
.95432 .25 L
.95433 .25 L
.95433 .25 L
.95434 .25 L
.95435 .25 L
.95435 .25 L
.95436 .25 L
.95436 .25 L
.95437 .25 L
.95438 .25 L
.95438 .25 L
.95439 .25 L
.9544 .25 L
.9544 .25 L
.95441 .25 L
.95441 .25 L
.95442 .25 L
.95442 .25 L
.95443 .25 L
.95444 .25 L
.95444 .25 L
.95445 .25 L
.95446 .25 L
.95446 .25 L
.95447 .25 L
.95447 .25 L
.95448 .25 L
.95448 .25 L
.95449 .25 L
.9545 .25 L
.9545 .25 L
.95451 .25 L
.95451 .25 L
.95452 .25 L
.95452 .25 L
.95453 .25 L
.95454 .25 L
.95454 .25 L
.95454 .25 L
.95455 .25 L
.95456 .25 L
.95456 .25 L
.95457 .25 L
.95457 .25 L
.95458 .25 L
.95459 .25 L
.95459 .25 L
.95459 .25 L
.9546 .25 L
.9546 .25 L
Mistroke
.95461 .25 L
.95461 .25 L
.95462 .25 L
.95463 .25 L
.95463 .25 L
.95464 .25 L
.95465 .25 L
.95465 .25 L
.95466 .25 L
.95466 .25 L
.95467 .25 L
.95468 .25 L
.95468 .25 L
.95469 .25 L
.95469 .25 L
.9547 .25 L
.95471 .25 L
.95471 .25 L
.95472 .25 L
.95473 .25 L
.95473 .25 L
.95474 .25 L
.95475 .25 L
.95475 .25 L
.95475 .25 L
.95476 .25 L
.95476 .25 L
.95477 .25 L
.95477 .25 L
.95478 .25 L
.95479 .25 L
.95479 .25 L
.9548 .25 L
.95481 .25 L
.95481 .25 L
.95482 .25 L
.95482 .25 L
.95483 .25 L
.95484 .25 L
.95484 .25 L
.95485 .25 L
.95486 .25 L
.95486 .25 L
.95487 .25 L
.95487 .25 L
.95488 .25 L
.95488 .25 L
.95489 .25 L
.95489 .25 L
.95489 .25 L
Mistroke
.9549 .25 L
.95491 .25 L
.95491 .25 L
.95491 .25 L
.95492 .25 L
.95492 .25 L
.95492 .25 L
.95493 .25 L
.95493 .25 L
.95494 .25 L
.95494 .25 L
.95495 .25 L
.95495 .25 L
.95496 .25 L
.95497 .25 L
.95497 .25 L
.95498 .25 L
.95499 .25 L
.95499 .25 L
.955 .25 L
.95501 .25 L
.95501 .25 L
.95502 .25 L
.95502 .25 L
.95503 .25 L
.95504 .25 L
.95504 .25 L
.95505 .25 L
.95505 .25 L
.95506 .25 L
.95506 .25 L
.95507 .25 L
.95508 .25 L
.95508 .25 L
.95509 .25 L
.95509 .25 L
.9551 .25 L
.95511 .25 L
.95511 .25 L
.95512 .25 L
.95512 .25 L
.95513 .25 L
.95513 .25 L
.95514 .25 L
.95514 .25 L
.95515 .25 L
.95516 .25 L
.95516 .25 L
.95517 .25 L
.95518 .25 L
Mistroke
.95518 .25 L
.95519 .25 L
.9552 .25 L
.9552 .25 L
.95521 .25 L
.95521 .25 L
.95522 .25 L
.95523 .25 L
.95523 .25 L
.95524 .25 L
.95524 .25 L
.95525 .25 L
.95526 .25 L
.95526 .25 L
.95527 .25 L
.95527 .25 L
.95528 .25 L
.95529 .25 L
.95529 .25 L
.9553 .25 L
.9553 .25 L
.95531 .25 L
.95531 .25 L
.95532 .25 L
.95533 .25 L
.95533 .25 L
.95534 .25 L
.95534 .25 L
.95535 .25 L
.95535 .25 L
.95536 .25 L
.95536 .25 L
.95537 .25 L
.95537 .25 L
.95538 .25 L
.95539 .25 L
.95539 .25 L
.9554 .25 L
.9554 .25 L
.95541 .25 L
.95541 .25 L
.95542 .25 L
.95542 .25 L
.95543 .25 L
.95543 .25 L
.95544 .25 L
.95545 .25 L
.95545 .25 L
.95546 .25 L
.95546 .25 L
Mistroke
.95547 .25 L
.95548 .25 L
.95548 .25 L
.95549 .25 L
.95549 .25 L
.9555 .25 L
.95551 .25 L
.95551 .25 L
.95552 .25 L
.95552 .25 L
.95553 .25 L
.95554 .25 L
.95554 .25 L
.95555 .25 L
.95556 .25 L
.95556 .25 L
.95557 .25 L
.95557 .25 L
.95558 .25 L
.95558 .25 L
.95558 .25 L
.95559 .25 L
.9556 .25 L
.9556 .25 L
.95561 .25 L
.95562 .25 L
.95562 .25 L
.95563 .25 L
.95563 .25 L
.95564 .25 L
.95565 .25 L
.95565 .25 L
.95566 .25 L
.95567 .25 L
.95567 .25 L
.95568 .25 L
.95569 .25 L
.95569 .25 L
.9557 .25 L
.9557 .25 L
.95571 .25 L
.95571 .25 L
.95571 .25 L
.95572 .25 L
.95572 .25 L
.95573 .25 L
.95573 .25 L
.95574 .25 L
.95574 .25 L
.95574 .25 L
Mistroke
.95575 .25 L
.95575 .25 L
.95576 .25 L
.95576 .25 L
.95577 .25 L
.95577 .25 L
.95578 .25 L
.95579 .25 L
.95579 .25 L
.9558 .25 L
.9558 .25 L
.95581 .25 L
.95582 .25 L
.95582 .25 L
.95583 .25 L
.95584 .25 L
.95584 .25 L
.95585 .25 L
.95586 .25 L
.95586 .25 L
.95586 .25 L
.95587 .25 L
.95588 .25 L
.95588 .25 L
.95589 .25 L
.95589 .25 L
.9559 .25 L
.95591 .25 L
.95591 .25 L
.95592 .25 L
.95592 .25 L
.95593 .25 L
.95594 .25 L
.95594 .25 L
.95595 .25 L
.95595 .25 L
.95596 .25 L
.95596 .25 L
.95597 .25 L
.95597 .25 L
.95598 .25 L
.95599 .25 L
.95599 .25 L
.956 .25 L
.95601 .25 L
.95601 .25 L
.95602 .25 L
.95602 .25 L
.95603 .25 L
.95604 .25 L
Mistroke
.95604 .25 L
.95605 .25 L
.95606 .25 L
.95606 .25 L
.95607 .25 L
.95607 .25 L
.95608 .25 L
.95608 .25 L
.95609 .25 L
.9561 .25 L
.9561 .25 L
.95611 .25 L
.95611 .25 L
.95612 .25 L
.95613 .25 L
.95613 .25 L
.95614 .25 L
.95614 .25 L
.95615 .25 L
.95616 .25 L
.95616 .25 L
.95616 .25 L
.95617 .25 L
.95618 .25 L
.95618 .25 L
.95619 .25 L
.95619 .25 L
.9562 .25 L
.9562 .25 L
.95621 .25 L
.95621 .25 L
.95622 .25 L
.95623 .25 L
.95623 .25 L
.95624 .25 L
.95624 .25 L
.95625 .25 L
.95625 .25 L
.95626 .25 L
.95626 .25 L
.95627 .25 L
.95628 .25 L
.95628 .25 L
.95629 .25 L
.95629 .25 L
.9563 .25 L
.9563 .25 L
.95631 .25 L
.95632 .25 L
.95632 .25 L
Mistroke
.95633 .25 L
.95634 .25 L
.95634 .25 L
.95635 .25 L
.95635 .25 L
.95636 .25 L
.95637 .25 L
.95637 .25 L
.95638 .25 L
.95639 .25 L
.95639 .25 L
.9564 .25 L
.9564 .25 L
.9564 .25 L
.95641 .25 L
.95641 .25 L
.95642 .25 L
.95643 .25 L
.95643 .25 L
.95644 .25 L
.95645 .25 L
.95645 .25 L
.95646 .25 L
.95646 .25 L
.95647 .25 L
.95648 .25 L
.95648 .25 L
.95649 .25 L
.9565 .25 L
.9565 .25 L
.95651 .25 L
.95652 .25 L
.95652 .25 L
.95652 .25 L
.95653 .25 L
.95653 .25 L
.95654 .25 L
.95654 .25 L
.95655 .25 L
.95655 .25 L
.95656 .25 L
.95656 .25 L
.95656 .25 L
.95657 .25 L
.95657 .25 L
.95658 .25 L
.95658 .25 L
.95658 .25 L
.95659 .25 L
.9566 .25 L
Mistroke
.9566 .25 L
.95661 .25 L
.95662 .25 L
.95662 .25 L
.95663 .25 L
.95663 .25 L
.95664 .25 L
.95665 .25 L
.95665 .25 L
.95666 .25 L
.95667 .25 L
.95667 .25 L
.95668 .25 L
.95668 .25 L
.95669 .25 L
.95669 .25 L
.9567 .25 L
.95671 .25 L
.95671 .25 L
.95672 .25 L
.95672 .25 L
.95673 .25 L
.95673 .25 L
.95674 .25 L
.95675 .25 L
.95675 .25 L
.95676 .25 L
.95677 .25 L
.95677 .25 L
.95678 .25 L
.95678 .25 L
.95678 .25 L
.95679 .25 L
.9568 .25 L
.9568 .25 L
.95681 .25 L
.95682 .25 L
.95682 .25 L
.95683 .25 L
.95684 .25 L
.95684 .25 L
.95685 .25 L
.95685 .25 L
.95686 .25 L
.95687 .25 L
.95687 .25 L
.95688 .25 L
.95688 .25 L
.95689 .25 L
.9569 .25 L
Mistroke
.9569 .25 L
.95691 .25 L
.95691 .25 L
.95692 .25 L
.95693 .25 L
.95693 .25 L
.95694 .25 L
.95694 .25 L
.95695 .25 L
.95696 .25 L
.95696 .25 L
.95697 .25 L
.95697 .25 L
.95698 .25 L
.95698 .25 L
.95699 .25 L
.95699 .25 L
.957 .25 L
.95701 .25 L
.95701 .25 L
.95702 .25 L
.95703 .25 L
.95703 .25 L
.95704 .25 L
.95704 .25 L
.95705 .25 L
.95706 .25 L
.95706 .25 L
.95707 .25 L
.95708 .25 L
.95708 .25 L
.95709 .25 L
.95709 .25 L
.9571 .25 L
.9571 .25 L
.95711 .25 L
.95712 .25 L
.95712 .25 L
.95713 .25 L
.95713 .25 L
.95714 .25 L
.95715 .25 L
.95715 .25 L
.95716 .25 L
.95716 .25 L
.95717 .25 L
.95718 .25 L
.95718 .25 L
.95719 .25 L
.95719 .25 L
Mistroke
.9572 .25 L
.9572 .25 L
.95721 .25 L
.95721 .25 L
.95722 .25 L
.95722 .25 L
.95723 .25 L
.95723 .25 L
.95724 .25 L
.95725 .25 L
.95725 .25 L
.95726 .25 L
.95726 .25 L
.95727 .25 L
.95727 .25 L
.95728 .25 L
.95728 .25 L
.95729 .25 L
.95729 .25 L
.9573 .25 L
.95731 .25 L
.95731 .25 L
.95732 .25 L
.95732 .25 L
.95733 .25 L
.95734 .25 L
.95734 .25 L
.95735 .25 L
.95736 .25 L
.95736 .25 L
.95737 .25 L
.95737 .25 L
.95738 .25 L
.95739 .25 L
.95739 .25 L
.9574 .25 L
.95741 .25 L
.95741 .25 L
.95742 .25 L
.95742 .25 L
.95743 .25 L
.95743 .25 L
.95743 .25 L
.95744 .25 L
.95745 .25 L
.95745 .25 L
.95746 .25 L
.95747 .25 L
.95747 .25 L
.95748 .25 L
Mistroke
.95748 .25 L
.95749 .25 L
.9575 .25 L
.9575 .25 L
.95751 .25 L
.95752 .25 L
.95752 .25 L
.95753 .25 L
.95754 .25 L
.95754 .25 L
.95755 .25 L
.95755 .25 L
.95756 .25 L
.95756 .25 L
.95756 .25 L
.95757 .25 L
.95757 .25 L
.95758 .25 L
.95758 .25 L
.95759 .25 L
.95759 .25 L
.95759 .25 L
.9576 .25 L
.9576 .25 L
.95761 .25 L
.95761 .25 L
.95761 .25 L
.95762 .25 L
.95763 .25 L
.95764 .25 L
.95764 .25 L
.95765 .25 L
.95765 .25 L
.95766 .25 L
.95767 .25 L
.95767 .25 L
.95768 .25 L
.95769 .25 L
.95769 .25 L
.9577 .25 L
.95771 .25 L
.95771 .25 L
.95771 .25 L
.95772 .25 L
.95773 .25 L
.95773 .25 L
.95774 .25 L
.95774 .25 L
.95775 .25 L
.95776 .25 L
Mistroke
.95776 .25 L
.95777 .25 L
.95777 .25 L
.95778 .25 L
.95779 .25 L
.95779 .25 L
.9578 .25 L
.9578 .25 L
.95781 .25 L
.95781 .25 L
.95782 .25 L
.95782 .25 L
.95783 .25 L
.95784 .25 L
.95784 .25 L
.95785 .25 L
.95786 .25 L
.95786 .25 L
.95787 .25 L
.95787 .25 L
.95788 .25 L
.95789 .25 L
.95789 .25 L
.9579 .25 L
.95791 .25 L
.95791 .25 L
.95792 .25 L
.95792 .25 L
.95793 .25 L
.95793 .25 L
.95794 .25 L
.95795 .25 L
.95795 .25 L
.95796 .25 L
.95796 .25 L
.95797 .25 L
.95798 .25 L
.95798 .25 L
.95799 .25 L
.95799 .25 L
.958 .25 L
.95801 .25 L
.95801 .25 L
.95801 .25 L
.95802 .25 L
.95803 .25 L
.95803 .25 L
.95804 .25 L
.95804 .25 L
.95805 .25 L
Mistroke
.95805 .25 L
.95806 .25 L
.95806 .25 L
.95807 .25 L
.95808 .25 L
.95808 .25 L
.95809 .25 L
.95809 .25 L
.9581 .25 L
.9581 .25 L
.95811 .25 L
.95811 .25 L
.95812 .25 L
.95813 .25 L
.95813 .25 L
.95814 .25 L
.95814 .25 L
.95815 .25 L
.95815 .25 L
.95816 .25 L
.95817 .25 L
.95817 .25 L
.95818 .25 L
.95819 .25 L
.95819 .25 L
.9582 .25 L
.9582 .25 L
.95821 .25 L
.95822 .25 L
.95822 .25 L
.95823 .25 L
.95824 .25 L
.95824 .25 L
.95825 .25 L
.95825 .25 L
.95825 .25 L
.95826 .25 L
.95826 .25 L
.95827 .25 L
.95828 .25 L
.95828 .25 L
.95829 .25 L
.9583 .25 L
.9583 .25 L
.95831 .25 L
.95831 .25 L
.95832 .25 L
.95833 .25 L
.95833 .25 L
.95834 .25 L
Mistroke
.95835 .25 L
.95835 .25 L
.95836 .25 L
.95837 .25 L
.95837 .25 L
.95837 .25 L
.95838 .25 L
.95838 .25 L
.95839 .25 L
.95839 .25 L
.9584 .25 L
.9584 .25 L
.95841 .25 L
.95841 .25 L
.95841 .25 L
.95842 .25 L
.95842 .25 L
.95843 .25 L
.95843 .25 L
.95843 .25 L
.95844 .25 L
.95845 .25 L
.95845 .25 L
.95846 .25 L
.95847 .25 L
.95847 .25 L
.95848 .25 L
.95848 .25 L
.95849 .25 L
.9585 .25 L
.9585 .25 L
.95851 .25 L
.95852 .25 L
.95852 .25 L
.95853 .25 L
.95853 .25 L
.95854 .25 L
.95854 .25 L
.95855 .25 L
.95856 .25 L
.95856 .25 L
.95857 .25 L
.95857 .25 L
.95858 .25 L
.95859 .25 L
.95859 .25 L
.9586 .25 L
.9586 .25 L
.95861 .25 L
.95862 .25 L
Mistroke
.95862 .25 L
.95863 .25 L
.95863 .25 L
.95864 .25 L
.95864 .25 L
.95865 .25 L
.95865 .25 L
.95866 .25 L
.95867 .25 L
.95867 .25 L
.95868 .25 L
.95869 .25 L
.95869 .25 L
.9587 .25 L
.95871 .25 L
.95871 .25 L
.95872 .25 L
.95872 .25 L
.95873 .25 L
.95874 .25 L
.95874 .25 L
.95875 .25 L
.95875 .25 L
.95876 .25 L
.95876 .25 L
.95877 .25 L
.95878 .25 L
.95878 .25 L
.95879 .25 L
.95879 .25 L
.9588 .25 L
.95881 .25 L
.95881 .25 L
.95882 .25 L
.95882 .25 L
.95883 .25 L
.95883 .25 L
.95884 .25 L
.95884 .25 L
.95885 .25 L
.95886 .25 L
.95886 .25 L
.95886 .25 L
.95887 .25 L
.95888 .25 L
.95888 .25 L
.95889 .25 L
.95889 .25 L
.9589 .25 L
.95891 .25 L
Mistroke
.95891 .25 L
.95891 .25 L
.95892 .25 L
.95893 .25 L
.95893 .25 L
.95894 .25 L
.95894 .25 L
.95895 .25 L
.95896 .25 L
.95896 .25 L
.95897 .25 L
.95897 .25 L
.95898 .25 L
.95898 .25 L
.95899 .25 L
.959 .25 L
.959 .25 L
.95901 .25 L
.95902 .25 L
.95902 .25 L
.95903 .25 L
.95903 .25 L
.95904 .25 L
.95905 .25 L
.95905 .25 L
.95906 .25 L
.95907 .25 L
.95907 .25 L
.95907 .25 L
.95908 .25 L
.95908 .25 L
.95909 .25 L
.95909 .25 L
.9591 .25 L
.95911 .25 L
.95911 .25 L
.95912 .25 L
.95913 .25 L
.95913 .25 L
.95914 .25 L
.95915 .25 L
.95915 .25 L
.95916 .25 L
.95916 .25 L
.95917 .25 L
.95918 .25 L
.95918 .25 L
.95919 .25 L
.95919 .25 L
.9592 .25 L
Mistroke
.9592 .25 L
.95921 .25 L
.95921 .25 L
.95922 .25 L
.95922 .25 L
.95923 .25 L
.95923 .25 L
.95923 .25 L
.95924 .25 L
.95924 .25 L
.95925 .25 L
.95925 .25 L
.95925 .25 L
.95926 .25 L
.95926 .25 L
.95927 .25 L
.95928 .25 L
.95928 .25 L
.95929 .25 L
.9593 .25 L
.9593 .25 L
.95931 .25 L
.95931 .25 L
.95932 .25 L
.95933 .25 L
.95933 .25 L
.95934 .25 L
.95935 .25 L
.95935 .25 L
.95936 .25 L
.95936 .25 L
.95937 .25 L
.95937 .25 L
.95938 .25 L
.95939 .25 L
.95939 .25 L
.9594 .25 L
.9594 .25 L
.95941 .25 L
.95941 .25 L
.95942 .25 L
.95943 .25 L
.95943 .25 L
.95944 .25 L
.95945 .25 L
.95945 .25 L
.95946 .25 L
.95946 .25 L
.95946 .25 L
.95947 .25 L
Mistroke
.95948 .25 L
.95949 .25 L
.95949 .25 L
.9595 .25 L
.9595 .25 L
.95951 .25 L
.95952 .25 L
.95952 .25 L
.95953 .25 L
.95954 .25 L
.95954 .25 L
.95955 .25 L
.95956 .25 L
.95956 .25 L
.95956 .25 L
.95957 .25 L
.95958 .25 L
.95958 .25 L
.95959 .25 L
.95959 .25 L
.9596 .25 L
.95961 .25 L
.95961 .25 L
.95962 .25 L
.95962 .25 L
.95963 .25 L
.95964 .25 L
.95964 .25 L
.95965 .25 L
.95965 .25 L
.95966 .25 L
.95966 .25 L
.95967 .25 L
.95967 .25 L
.95968 .25 L
.95968 .25 L
.95969 .25 L
.95969 .25 L
.9597 .25 L
.95971 .25 L
.95971 .25 L
.95972 .25 L
.95972 .25 L
.95973 .25 L
.95973 .25 L
.95974 .25 L
.95975 .25 L
.95975 .25 L
.95975 .25 L
.95976 .25 L
Mistroke
.95977 .25 L
.95977 .25 L
.95978 .25 L
.95978 .25 L
.95979 .25 L
.9598 .25 L
.9598 .25 L
.95981 .25 L
.95981 .25 L
.95982 .25 L
.95983 .25 L
.95983 .25 L
.95984 .25 L
.95984 .25 L
.95985 .25 L
.95986 .25 L
.95986 .25 L
.95987 .25 L
.95988 .25 L
.95988 .25 L
.95989 .25 L
.95989 .25 L
.9599 .25 L
.9599 .25 L
.9599 .25 L
.95991 .25 L
.95992 .25 L
.95992 .25 L
.95993 .25 L
.95994 .25 L
.95994 .25 L
.95995 .25 L
.95996 .25 L
.95996 .25 L
.95997 .25 L
.95998 .25 L
.95998 .25 L
.95999 .25 L
.95999 .25 L
.96 .25 L
.96001 .25 L
.96001 .25 L
.96002 .25 L
.96002 .25 L
.96003 .25 L
.96003 .25 L
.96004 .25 L
.96004 .25 L
.96004 .25 L
.96005 .25 L
Mistroke
.96005 .25 L
.96006 .25 L
.96006 .25 L
.96007 .25 L
.96007 .25 L
.96007 .25 L
.96008 .25 L
.96008 .25 L
.96009 .25 L
.96009 .25 L
.9601 .25 L
.96011 .25 L
.96011 .25 L
.96012 .25 L
.96013 .25 L
.96013 .25 L
.96014 .25 L
.96014 .25 L
.96015 .25 L
.96016 .25 L
.96016 .25 L
.96017 .25 L
.96018 .25 L
.96018 .25 L
.96018 .25 L
.96019 .25 L
.9602 .25 L
.9602 .25 L
.96021 .25 L
.96022 .25 L
.96022 .25 L
.96023 .25 L
.96023 .25 L
.96024 .25 L
.96024 .25 L
.96025 .25 L
.96026 .25 L
.96026 .25 L
.96027 .25 L
.96027 .25 L
.96028 .25 L
.96028 .25 L
.96029 .25 L
.9603 .25 L
.9603 .25 L
.96031 .25 L
.96032 .25 L
.96032 .25 L
.96033 .25 L
.96033 .25 L
Mistroke
.96034 .25 L
.96035 .25 L
.96035 .25 L
.96036 .25 L
.96036 .25 L
.96037 .25 L
.96038 .25 L
.96038 .25 L
.96039 .25 L
.96039 .25 L
.9604 .25 L
.96041 .25 L
.96041 .25 L
.96042 .25 L
.96042 .25 L
.96043 .25 L
.96043 .25 L
.96044 .25 L
.96045 .25 L
.96045 .25 L
.96046 .25 L
.96047 .25 L
.96047 .25 L
.96048 .25 L
.96048 .25 L
.96048 .25 L
.96049 .25 L
.9605 .25 L
.9605 .25 L
.96051 .25 L
.96052 .25 L
.96052 .25 L
.96053 .25 L
.96054 .25 L
.96054 .25 L
.96055 .25 L
.96055 .25 L
.96056 .25 L
.96057 .25 L
.96057 .25 L
.96058 .25 L
.96058 .25 L
.96059 .25 L
.9606 .25 L
.9606 .25 L
.96061 .25 L
.96061 .25 L
.96062 .25 L
.96063 .25 L
.96063 .25 L
Mistroke
.96064 .25 L
.96064 .25 L
.96065 .25 L
.96066 .25 L
.96066 .25 L
.96067 .25 L
.96067 .25 L
.96068 .25 L
.96068 .25 L
.96069 .25 L
.96069 .25 L
.9607 .25 L
.96071 .25 L
.96071 .25 L
.96071 .25 L
.96072 .25 L
.96073 .25 L
.96073 .25 L
.96074 .25 L
.96074 .25 L
.96075 .25 L
.96076 .25 L
.96076 .25 L
.96076 .25 L
.96077 .25 L
.96078 .25 L
.96078 .25 L
.96079 .25 L
.96079 .25 L
.9608 .25 L
.96081 .25 L
.96081 .25 L
.96082 .25 L
.96082 .25 L
.96083 .25 L
.96083 .25 L
.96084 .25 L
.96085 .25 L
.96085 .25 L
.96086 .25 L
.96087 .25 L
.96087 .25 L
.96088 .25 L
.96088 .25 L
.96089 .25 L
.9609 .25 L
.9609 .25 L
.96091 .25 L
.96092 .25 L
.96092 .25 L
Mistroke
.96092 .25 L
.96093 .25 L
.96093 .25 L
.96094 .25 L
.96094 .25 L
.96095 .25 L
.96096 .25 L
.96096 .25 L
.96097 .25 L
.96098 .25 L
.96098 .25 L
.96099 .25 L
.96099 .25 L
.961 .25 L
.96101 .25 L
.96101 .25 L
.96102 .25 L
.96103 .25 L
.96103 .25 L
.96104 .25 L
.96104 .25 L
.96105 .25 L
.96105 .25 L
.96106 .25 L
.96106 .25 L
.96107 .25 L
.96107 .25 L
.96108 .25 L
.96108 .25 L
.96108 .25 L
.96109 .25 L
.96109 .25 L
.9611 .25 L
.9611 .25 L
.9611 .25 L
.96111 .25 L
.96111 .25 L
.96112 .25 L
.96113 .25 L
.96113 .25 L
.96114 .25 L
.96115 .25 L
.96115 .25 L
.96116 .25 L
.96116 .25 L
.96117 .25 L
.96118 .25 L
.96118 .25 L
.96119 .25 L
.9612 .25 L
Mistroke
.9612 .25 L
.96121 .25 L
.96121 .25 L
.96122 .25 L
.96122 .25 L
.96123 .25 L
.96124 .25 L
.96124 .25 L
.96125 .25 L
.96125 .25 L
.96126 .25 L
.96126 .25 L
.96127 .25 L
.96128 .25 L
.96128 .25 L
.96129 .25 L
.9613 .25 L
.9613 .25 L
.96131 .25 L
.96131 .25 L
.96132 .25 L
.96132 .25 L
.96133 .25 L
.96134 .25 L
.96134 .25 L
.96135 .25 L
.96135 .25 L
.96136 .25 L
.96137 .25 L
.96137 .25 L
.96138 .25 L
.96139 .25 L
.96139 .25 L
.9614 .25 L
.96141 .25 L
.96141 .25 L
.96141 .25 L
.96142 .25 L
.96143 .25 L
.96143 .25 L
.96144 .25 L
.96144 .25 L
.96145 .25 L
.96146 .25 L
.96146 .25 L
.96147 .25 L
.96147 .25 L
.96148 .25 L
.96149 .25 L
.96149 .25 L
Mistroke
.9615 .25 L
.9615 .25 L
.96151 .25 L
.96151 .25 L
.96152 .25 L
.96152 .25 L
.96153 .25 L
.96153 .25 L
.96154 .25 L
.96154 .25 L
.96155 .25 L
.96156 .25 L
.96156 .25 L
.96157 .25 L
.96157 .25 L
.96158 .25 L
.96159 .25 L
.96159 .25 L
.9616 .25 L
.9616 .25 L
.9616 .25 L
.96161 .25 L
.96162 .25 L
.96162 .25 L
.96163 .25 L
.96163 .25 L
.96164 .25 L
.96165 .25 L
.96165 .25 L
.96166 .25 L
.96166 .25 L
.96167 .25 L
.96168 .25 L
.96168 .25 L
.96169 .25 L
.9617 .25 L
.9617 .25 L
.96171 .25 L
.96171 .25 L
.96172 .25 L
.96173 .25 L
.96173 .25 L
.96174 .25 L
.96174 .25 L
.96175 .25 L
.96175 .25 L
.96176 .25 L
.96176 .25 L
.96177 .25 L
.96177 .25 L
Mistroke
.96178 .25 L
.96179 .25 L
.96179 .25 L
.9618 .25 L
.96181 .25 L
.96181 .25 L
.96182 .25 L
.96183 .25 L
.96183 .25 L
.96184 .25 L
.96184 .25 L
.96185 .25 L
.96186 .25 L
.96186 .25 L
.96187 .25 L
.96187 .25 L
.96188 .25 L
.96188 .25 L
.96189 .25 L
.96189 .25 L
.96189 .25 L
.9619 .25 L
.9619 .25 L
.96191 .25 L
.96191 .25 L
.96192 .25 L
.96192 .25 L
.96192 .25 L
.96193 .25 L
.96193 .25 L
.96194 .25 L
.96194 .25 L
.96195 .25 L
.96196 .25 L
.96196 .25 L
.96197 .25 L
.96198 .25 L
.96198 .25 L
.96199 .25 L
.96199 .25 L
.962 .25 L
.96201 .25 L
.96201 .25 L
.96202 .25 L
.96203 .25 L
.96203 .25 L
.96203 .25 L
.96204 .25 L
.96205 .25 L
.96205 .25 L
Mistroke
.96206 .25 L
.96207 .25 L
.96207 .25 L
.96208 .25 L
.96208 .25 L
.96209 .25 L
.96209 .25 L
.9621 .25 L
.96211 .25 L
.96211 .25 L
.96212 .25 L
.96213 .25 L
.96213 .25 L
.96213 .25 L
.96214 .25 L
.96215 .25 L
.96215 .25 L
.96216 .25 L
.96217 .25 L
.96217 .25 L
.96218 .25 L
.96218 .25 L
.96219 .25 L
.9622 .25 L
.9622 .25 L
.96221 .25 L
.96222 .25 L
.96222 .25 L
.96223 .25 L
.96223 .25 L
.96224 .25 L
.96224 .25 L
.96225 .25 L
.96226 .25 L
.96226 .25 L
.96227 .25 L
.96227 .25 L
.96228 .25 L
.96229 .25 L
.96229 .25 L
.9623 .25 L
.9623 .25 L
.96231 .25 L
.96232 .25 L
.96232 .25 L
.96233 .25 L
.96233 .25 L
.96234 .25 L
.96234 .25 L
.96235 .25 L
Mistroke
.96235 .25 L
.96236 .25 L
.96236 .25 L
.96237 .25 L
.96237 .25 L
.96238 .25 L
.96239 .25 L
.96239 .25 L
.9624 .25 L
.96241 .25 L
.96241 .25 L
.96241 .25 L
.96242 .25 L
.96242 .25 L
.96243 .25 L
.96243 .25 L
.96244 .25 L
.96245 .25 L
.96245 .25 L
.96246 .25 L
.96246 .25 L
.96247 .25 L
.96248 .25 L
.96248 .25 L
.96249 .25 L
.96249 .25 L
.9625 .25 L
.96251 .25 L
.96251 .25 L
.96252 .25 L
.96252 .25 L
.96253 .25 L
.96254 .25 L
.96254 .25 L
.96255 .25 L
.96256 .25 L
.96256 .25 L
.96257 .25 L
.96257 .25 L
.96258 .25 L
.96258 .25 L
.96259 .25 L
.96259 .25 L
.9626 .25 L
.96261 .25 L
.96261 .25 L
.96262 .25 L
.96262 .25 L
.96263 .25 L
.96264 .25 L
Mistroke
.96264 .25 L
.96265 .25 L
.96266 .25 L
.96266 .25 L
.96267 .25 L
.96268 .25 L
.96268 .25 L
.96269 .25 L
.96269 .25 L
.9627 .25 L
.9627 .25 L
.96271 .25 L
.96271 .25 L
.96271 .25 L
.96272 .25 L
.96272 .25 L
.96273 .25 L
.96273 .25 L
.96274 .25 L
.96274 .25 L
.96274 .25 L
.96275 .25 L
.96275 .25 L
.96275 .25 L
.96276 .25 L
.96277 .25 L
.96277 .25 L
.96278 .25 L
.96279 .25 L
.96279 .25 L
.9628 .25 L
.96281 .25 L
.96281 .25 L
.96282 .25 L
.96282 .25 L
.96283 .25 L
.96284 .25 L
.96284 .25 L
.96285 .25 L
.96285 .25 L
.96286 .25 L
.96286 .25 L
.96287 .25 L
.96288 .25 L
.96288 .25 L
.96289 .25 L
.9629 .25 L
.9629 .25 L
.96291 .25 L
.96291 .25 L
Mistroke
.96292 .25 L
.96292 .25 L
.96293 .25 L
.96294 .25 L
.96294 .25 L
.96295 .25 L
.96295 .25 L
.96296 .25 L
.96296 .25 L
.96297 .25 L
.96298 .25 L
.96298 .25 L
.96299 .25 L
.963 .25 L
.963 .25 L
.96301 .25 L
.96301 .25 L
.96302 .25 L
.96303 .25 L
.96303 .25 L
.96304 .25 L
.96305 .25 L
.96305 .25 L
.96306 .25 L
.96306 .25 L
.96307 .25 L
.96307 .25 L
.96308 .25 L
.96309 .25 L
.96309 .25 L
.9631 .25 L
.9631 .25 L
.96311 .25 L
.96311 .25 L
.96312 .25 L
.96313 .25 L
.96313 .25 L
.96314 .25 L
.96315 .25 L
.96315 .25 L
.96316 .25 L
.96316 .25 L
.96317 .25 L
.96317 .25 L
.96318 .25 L
.96318 .25 L
.96319 .25 L
.96319 .25 L
.9632 .25 L
.9632 .25 L
Mistroke
.96321 .25 L
.96322 .25 L
.96322 .25 L
.96323 .25 L
.96323 .25 L
.96324 .25 L
.96324 .25 L
.96325 .25 L
.96325 .25 L
.96326 .25 L
.96326 .25 L
.96327 .25 L
.96328 .25 L
.96328 .25 L
.96329 .25 L
.96329 .25 L
.9633 .25 L
.96331 .25 L
.96331 .25 L
.96332 .25 L
.96332 .25 L
.96333 .25 L
.96334 .25 L
.96334 .25 L
.96335 .25 L
.96336 .25 L
.96336 .25 L
.96337 .25 L
.96337 .25 L
.96338 .25 L
.96339 .25 L
.96339 .25 L
.9634 .25 L
.9634 .25 L
.9634 .25 L
.96341 .25 L
.96342 .25 L
.96342 .25 L
.96343 .25 L
.96344 .25 L
.96344 .25 L
.96345 .25 L
.96345 .25 L
.96346 .25 L
.96347 .25 L
.96347 .25 L
.96348 .25 L
.96349 .25 L
.96349 .25 L
.9635 .25 L
Mistroke
.9635 .25 L
.96351 .25 L
.96352 .25 L
.96352 .25 L
.96353 .25 L
.96353 .25 L
.96353 .25 L
.96354 .25 L
.96354 .25 L
.96355 .25 L
.96355 .25 L
.96355 .25 L
.96356 .25 L
.96356 .25 L
.96357 .25 L
.96357 .25 L
.96357 .25 L
.96358 .25 L
.96358 .25 L
.96359 .25 L
.9636 .25 L
.9636 .25 L
.96361 .25 L
.96362 .25 L
.96362 .25 L
.96363 .25 L
.96363 .25 L
.96364 .25 L
.96365 .25 L
.96365 .25 L
.96366 .25 L
.96367 .25 L
.96367 .25 L
.96368 .25 L
.96368 .25 L
.96369 .25 L
.9637 .25 L
.9637 .25 L
.96371 .25 L
.96371 .25 L
.96372 .25 L
.96372 .25 L
.96373 .25 L
.96374 .25 L
.96374 .25 L
.96375 .25 L
.96375 .25 L
.96376 .25 L
.96377 .25 L
.96377 .25 L
Mistroke
.96378 .25 L
.96378 .25 L
.96379 .25 L
.96379 .25 L
.9638 .25 L
.96381 .25 L
.96381 .25 L
.96382 .25 L
.96383 .25 L
.96383 .25 L
.96384 .25 L
.96384 .25 L
.96385 .25 L
.96386 .25 L
.96386 .25 L
.96387 .25 L
.96388 .25 L
.96388 .25 L
.96388 .25 L
.96389 .25 L
.9639 .25 L
.9639 .25 L
.96391 .25 L
.96392 .25 L
.96392 .25 L
.96393 .25 L
.96393 .25 L
.96394 .25 L
.96394 .25 L
.96395 .25 L
.96396 .25 L
.96396 .25 L
.96397 .25 L
.96398 .25 L
.96398 .25 L
.96398 .25 L
.96399 .25 L
.964 .25 L
.964 .25 L
.96401 .25 L
.96402 .25 L
.96402 .25 L
.96403 .25 L
.96403 .25 L
.96404 .25 L
.96405 .25 L
.96405 .25 L
.96406 .25 L
.96407 .25 L
.96407 .25 L
Mistroke
.96408 .25 L
.96408 .25 L
.96409 .25 L
.96409 .25 L
.9641 .25 L
.96411 .25 L
.96411 .25 L
.96412 .25 L
.96412 .25 L
.96413 .25 L
.96414 .25 L
.96414 .25 L
.96415 .25 L
.96415 .25 L
.96416 .25 L
.96417 .25 L
.96417 .25 L
.96418 .25 L
.96418 .25 L
.96418 .25 L
.96419 .25 L
.9642 .25 L
.9642 .25 L
.96421 .25 L
.96421 .25 L
.96422 .25 L
.96422 .25 L
.96423 .25 L
.96424 .25 L
.96424 .25 L
.96425 .25 L
.96426 .25 L
.96426 .25 L
.96426 .25 L
.96427 .25 L
.96427 .25 L
.96428 .25 L
.96428 .25 L
.96429 .25 L
.9643 .25 L
.9643 .25 L
.96431 .25 L
.96431 .25 L
.96432 .25 L
.96433 .25 L
.96433 .25 L
.96434 .25 L
.96434 .25 L
.96435 .25 L
.96436 .25 L
Mistroke
.96436 .25 L
.96437 .25 L
.96437 .25 L
.96438 .25 L
.96439 .25 L
.96439 .25 L
.9644 .25 L
.96441 .25 L
.96441 .25 L
.96442 .25 L
.96442 .25 L
.96443 .25 L
.96443 .25 L
.96444 .25 L
.96444 .25 L
.96445 .25 L
.96446 .25 L
.96446 .25 L
.96447 .25 L
.96447 .25 L
.96448 .25 L
.96449 .25 L
.96449 .25 L
.9645 .25 L
.96451 .25 L
.96451 .25 L
.96452 .25 L
.96453 .25 L
.96453 .25 L
.96454 .25 L
.96454 .25 L
.96455 .25 L
.96455 .25 L
.96456 .25 L
.96456 .25 L
.96456 .25 L
.96457 .25 L
.96457 .25 L
.96458 .25 L
.96458 .25 L
.96459 .25 L
.96459 .25 L
.96459 .25 L
.9646 .25 L
.9646 .25 L
.9646 .25 L
.96461 .25 L
.96462 .25 L
.96462 .25 L
.96463 .25 L
Mistroke
.96464 .25 L
.96464 .25 L
.96465 .25 L
.96466 .25 L
.96466 .25 L
.96467 .25 L
.96467 .25 L
.96468 .25 L
.96469 .25 L
.96469 .25 L
.9647 .25 L
.9647 .25 L
.96471 .25 L
.96472 .25 L
.96472 .25 L
.96473 .25 L
.96473 .25 L
.96474 .25 L
.96475 .25 L
.96475 .25 L
.96476 .25 L
.96476 .25 L
.96477 .25 L
.96477 .25 L
.96478 .25 L
.96479 .25 L
.96479 .25 L
.9648 .25 L
.9648 .25 L
.96481 .25 L
.96481 .25 L
.96482 .25 L
.96483 .25 L
.96483 .25 L
.96484 .25 L
.96485 .25 L
.96485 .25 L
.96486 .25 L
.96486 .25 L
.96487 .25 L
.96488 .25 L
.96488 .25 L
.96489 .25 L
.9649 .25 L
.9649 .25 L
.96491 .25 L
.96491 .25 L
.96492 .25 L
.96492 .25 L
.96493 .25 L
Mistroke
.96494 .25 L
.96494 .25 L
.96495 .25 L
.96495 .25 L
.96496 .25 L
.96497 .25 L
.96497 .25 L
.96498 .25 L
.96498 .25 L
.96499 .25 L
.965 .25 L
.965 .25 L
.96501 .25 L
.96501 .25 L
.96502 .25 L
.96502 .25 L
.96503 .25 L
.96503 .25 L
.96504 .25 L
.96504 .25 L
.96505 .25 L
.96505 .25 L
.96506 .25 L
.96507 .25 L
.96507 .25 L
.96508 .25 L
.96508 .25 L
.96509 .25 L
.96509 .25 L
.9651 .25 L
.9651 .25 L
.96511 .25 L
.96511 .25 L
.96512 .25 L
.96513 .25 L
.96513 .25 L
.96514 .25 L
.96514 .25 L
.96515 .25 L
.96516 .25 L
.96516 .25 L
.96517 .25 L
.96517 .25 L
.96518 .25 L
.96519 .25 L
.96519 .25 L
.9652 .25 L
.96521 .25 L
.96521 .25 L
.96522 .25 L
Mistroke
.96523 .25 L
.96523 .25 L
.96524 .25 L
.96524 .25 L
.96525 .25 L
.96525 .25 L
.96525 .25 L
.96526 .25 L
.96527 .25 L
.96527 .25 L
.96528 .25 L
.96529 .25 L
.96529 .25 L
.9653 .25 L
.9653 .25 L
.96531 .25 L
.96532 .25 L
.96532 .25 L
.96533 .25 L
.96534 .25 L
.96534 .25 L
.96535 .25 L
.96536 .25 L
.96536 .25 L
.96537 .25 L
.96537 .25 L
.96538 .25 L
.96538 .25 L
.96538 .25 L
.96539 .25 L
.96539 .25 L
.9654 .25 L
.9654 .25 L
.96541 .25 L
.96541 .25 L
.96541 .25 L
.96542 .25 L
.96542 .25 L
.96542 .25 L
.96543 .25 L
.96543 .25 L
.96544 .25 L
.96545 .25 L
.96545 .25 L
.96546 .25 L
.96547 .25 L
.96547 .25 L
.96548 .25 L
.96549 .25 L
.96549 .25 L
Mistroke
.9655 .25 L
.96551 .25 L
.96551 .25 L
.96552 .25 L
.96552 .25 L
.96553 .25 L
.96553 .25 L
.96554 .25 L
.96555 .25 L
.96555 .25 L
.96556 .25 L
.96556 .25 L
.96557 .25 L
.96558 .25 L
.96558 .25 L
.96559 .25 L
.96559 .25 L
.9656 .25 L
.96561 .25 L
.96561 .25 L
.96562 .25 L
.96562 .25 L
.96563 .25 L
.96563 .25 L
.96564 .25 L
.96564 .25 L
.96565 .25 L
.96566 .25 L
.96566 .25 L
.96567 .25 L
.96568 .25 L
.96568 .25 L
.96569 .25 L
.96569 .25 L
.9657 .25 L
.96571 .25 L
.96571 .25 L
.96572 .25 L
.96573 .25 L
.96573 .25 L
.96573 .25 L
.96574 .25 L
.96575 .25 L
.96575 .25 L
.96576 .25 L
.96577 .25 L
.96577 .25 L
.96578 .25 L
.96578 .25 L
.96579 .25 L
Mistroke
.9658 .25 L
.9658 .25 L
.96581 .25 L
.96581 .25 L
.96582 .25 L
.96583 .25 L
.96583 .25 L
.96583 .25 L
.96584 .25 L
.96585 .25 L
.96585 .25 L
.96586 .25 L
.96586 .25 L
.96587 .25 L
.96587 .25 L
.96588 .25 L
.96588 .25 L
.96589 .25 L
.9659 .25 L
.9659 .25 L
.96591 .25 L
.96591 .25 L
.96592 .25 L
.96592 .25 L
.96592 .25 L
.96593 .25 L
.96594 .25 L
.96594 .25 L
.96595 .25 L
.96596 .25 L
.96596 .25 L
.96597 .25 L
.96597 .25 L
.96598 .25 L
.96599 .25 L
.96599 .25 L
.966 .25 L
.96601 .25 L
.96601 .25 L
.96602 .25 L
.96602 .25 L
.96603 .25 L
.96604 .25 L
.96604 .25 L
.96605 .25 L
.96606 .25 L
.96606 .25 L
.96607 .25 L
.96607 .25 L
.96607 .25 L
Mistroke
.96608 .25 L
.96608 .25 L
.96609 .25 L
.9661 .25 L
.9661 .25 L
.96611 .25 L
.96612 .25 L
.96612 .25 L
.96613 .25 L
.96613 .25 L
.96614 .25 L
.96615 .25 L
.96615 .25 L
.96616 .25 L
.96617 .25 L
.96617 .25 L
.96618 .25 L
.96619 .25 L
.96619 .25 L
.96619 .25 L
.9662 .25 L
.9662 .25 L
.96621 .25 L
.96621 .25 L
.96622 .25 L
.96622 .25 L
.96623 .25 L
.96623 .25 L
.96623 .25 L
.96624 .25 L
.96624 .25 L
.96624 .25 L
.96625 .25 L
.96625 .25 L
.96626 .25 L
.96627 .25 L
.96627 .25 L
.96628 .25 L
.96629 .25 L
.96629 .25 L
.9663 .25 L
.9663 .25 L
.96631 .25 L
.96632 .25 L
.96632 .25 L
.96633 .25 L
.96633 .25 L
.96634 .25 L
.96635 .25 L
.96635 .25 L
Mistroke
.96636 .25 L
.96636 .25 L
.96637 .25 L
.96638 .25 L
.96638 .25 L
.96639 .25 L
.96639 .25 L
.9664 .25 L
.9664 .25 L
.96641 .25 L
.96642 .25 L
.96642 .25 L
.96643 .25 L
.96644 .25 L
.96644 .25 L
.96645 .25 L
.96645 .25 L
.96645 .25 L
.96646 .25 L
.96647 .25 L
.96647 .25 L
.96648 .25 L
.96649 .25 L
.96649 .25 L
.9665 .25 L
.96651 .25 L
.96651 .25 L
.96652 .25 L
.96652 .25 L
.96653 .25 L
.96654 .25 L
.96654 .25 L
.96655 .25 L
.96655 .25 L
.96656 .25 L
.96657 .25 L
.96657 .25 L
.96658 .25 L
.96658 .25 L
.96659 .25 L
.9666 .25 L
.9666 .25 L
.96661 .25 L
.96661 .25 L
.96662 .25 L
.96662 .25 L
.96663 .25 L
.96664 .25 L
.96664 .25 L
.96665 .25 L
Mistroke
.96665 .25 L
.96666 .25 L
.96666 .25 L
.96667 .25 L
.96668 .25 L
.96668 .25 L
.96668 .25 L
.96669 .25 L
.9667 .25 L
.9667 .25 L
.96671 .25 L
.96671 .25 L
.96672 .25 L
.96673 .25 L
.96673 .25 L
.96673 .25 L
.96674 .25 L
.96675 .25 L
.96675 .25 L
.96676 .25 L
.96676 .25 L
.96677 .25 L
.96677 .25 L
.96678 .25 L
.96679 .25 L
.96679 .25 L
.9668 .25 L
.9668 .25 L
.96681 .25 L
.96682 .25 L
.96682 .25 L
.96683 .25 L
.96683 .25 L
.96684 .25 L
.96685 .25 L
.96685 .25 L
.96686 .25 L
.96687 .25 L
.96687 .25 L
.96688 .25 L
.96689 .25 L
.96689 .25 L
.96689 .25 L
.9669 .25 L
.9669 .25 L
.96691 .25 L
.96691 .25 L
.96692 .25 L
.96693 .25 L
.96693 .25 L
Mistroke
.96694 .25 L
.96695 .25 L
.96695 .25 L
.96696 .25 L
.96696 .25 L
.96697 .25 L
.96698 .25 L
.96698 .25 L
.96699 .25 L
.967 .25 L
.967 .25 L
.96701 .25 L
.96701 .25 L
.96702 .25 L
.96702 .25 L
.96703 .25 L
.96703 .25 L
.96703 .25 L
.96704 .25 L
.96705 .25 L
.96705 .25 L
.96705 .25 L
.96706 .25 L
.96706 .25 L
.96706 .25 L
.96707 .25 L
.96707 .25 L
.96708 .25 L
.96708 .25 L
.96709 .25 L
.9671 .25 L
.9671 .25 L
.96711 .25 L
.96711 .25 L
.96712 .25 L
.96713 .25 L
.96713 .25 L
.96714 .25 L
.96715 .25 L
.96715 .25 L
.96716 .25 L
.96716 .25 L
.96717 .25 L
.96718 .25 L
.96718 .25 L
.96719 .25 L
.96719 .25 L
.9672 .25 L
.9672 .25 L
.96721 .25 L
Mistroke
.96722 .25 L
.96722 .25 L
.96723 .25 L
.96723 .25 L
.96724 .25 L
.96725 .25 L
.96725 .25 L
.96726 .25 L
.96726 .25 L
.96727 .25 L
.96727 .25 L
.96728 .25 L
.96728 .25 L
.96729 .25 L
.9673 .25 L
.9673 .25 L
.96731 .25 L
.96732 .25 L
.96732 .25 L
.96733 .25 L
.96734 .25 L
.96734 .25 L
.96735 .25 L
.96735 .25 L
.96736 .25 L
.96737 .25 L
.96737 .25 L
.96738 .25 L
.96738 .25 L
.96739 .25 L
.9674 .25 L
.9674 .25 L
.96741 .25 L
.96741 .25 L
.96742 .25 L
.96743 .25 L
.96743 .25 L
.96744 .25 L
.96744 .25 L
.96745 .25 L
.96745 .25 L
.96746 .25 L
.96747 .25 L
.96747 .25 L
.96748 .25 L
.96748 .25 L
.96749 .25 L
.96749 .25 L
.9675 .25 L
.9675 .25 L
Mistroke
.96751 .25 L
.96751 .25 L
.96752 .25 L
.96753 .25 L
.96753 .25 L
.96754 .25 L
.96754 .25 L
.96755 .25 L
.96755 .25 L
.96756 .25 L
.96756 .25 L
.96757 .25 L
.96757 .25 L
.96758 .25 L
.96759 .25 L
.96759 .25 L
.9676 .25 L
.9676 .25 L
.96761 .25 L
.96762 .25 L
.96762 .25 L
.96763 .25 L
.96763 .25 L
.96764 .25 L
.96765 .25 L
.96765 .25 L
.96766 .25 L
.96766 .25 L
.96767 .25 L
.96768 .25 L
.96768 .25 L
.96769 .25 L
.9677 .25 L
.9677 .25 L
.96771 .25 L
.96771 .25 L
.96772 .25 L
.96772 .25 L
.96772 .25 L
.96773 .25 L
.96774 .25 L
.96774 .25 L
.96775 .25 L
.96776 .25 L
.96776 .25 L
.96777 .25 L
.96777 .25 L
.96778 .25 L
.96779 .25 L
.96779 .25 L
Mistroke
.9678 .25 L
.96781 .25 L
.96781 .25 L
.96782 .25 L
.96783 .25 L
.96783 .25 L
.96784 .25 L
.96784 .25 L
.96785 .25 L
.96785 .25 L
.96785 .25 L
.96786 .25 L
.96786 .25 L
.96787 .25 L
.96787 .25 L
.96788 .25 L
.96788 .25 L
.96788 .25 L
.96789 .25 L
.96789 .25 L
.9679 .25 L
.9679 .25 L
.96791 .25 L
.96791 .25 L
.96792 .25 L
.96793 .25 L
.96793 .25 L
.96794 .25 L
.96794 .25 L
.96795 .25 L
.96796 .25 L
.96796 .25 L
.96797 .25 L
.96798 .25 L
.96798 .25 L
.96799 .25 L
.968 .25 L
.968 .25 L
.968 .25 L
.96801 .25 L
.96802 .25 L
.96802 .25 L
.96803 .25 L
.96803 .25 L
.96804 .25 L
.96805 .25 L
.96805 .25 L
.96806 .25 L
.96806 .25 L
.96807 .25 L
Mistroke
.96808 .25 L
.96808 .25 L
.96809 .25 L
.96809 .25 L
.9681 .25 L
.9681 .25 L
.96811 .25 L
.96811 .25 L
.96812 .25 L
.96813 .25 L
.96813 .25 L
.96814 .25 L
.96815 .25 L
.96815 .25 L
.96816 .25 L
.96816 .25 L
.96817 .25 L
.96818 .25 L
.96818 .25 L
.96819 .25 L
.9682 .25 L
.9682 .25 L
.96821 .25 L
.96821 .25 L
.96822 .25 L
.96822 .25 L
.96823 .25 L
.96824 .25 L
.96824 .25 L
.96825 .25 L
.96825 .25 L
.96826 .25 L
.96827 .25 L
.96827 .25 L
.96828 .25 L
.96828 .25 L
.96829 .25 L
.9683 .25 L
.9683 .25 L
.9683 .25 L
.96831 .25 L
.96832 .25 L
.96832 .25 L
.96833 .25 L
.96834 .25 L
.96834 .25 L
.96835 .25 L
.96835 .25 L
.96836 .25 L
.96837 .25 L
Mistroke
.96837 .25 L
.96838 .25 L
.96839 .25 L
.96839 .25 L
.9684 .25 L
.9684 .25 L
.96841 .25 L
.96841 .25 L
.96842 .25 L
.96843 .25 L
.96843 .25 L
.96844 .25 L
.96845 .25 L
.96845 .25 L
.96846 .25 L
.96846 .25 L
.96847 .25 L
.96847 .25 L
.96848 .25 L
.96849 .25 L
.96849 .25 L
.9685 .25 L
.9685 .25 L
.96851 .25 L
.96851 .25 L
.96852 .25 L
.96853 .25 L
.96853 .25 L
.96853 .25 L
.96854 .25 L
.96855 .25 L
.96855 .25 L
.96856 .25 L
.96856 .25 L
.96857 .25 L
.96858 .25 L
.96858 .25 L
.96858 .25 L
.96859 .25 L
.96859 .25 L
.9686 .25 L
.9686 .25 L
.96861 .25 L
.96862 .25 L
.96862 .25 L
.96863 .25 L
.96864 .25 L
.96864 .25 L
.96865 .25 L
.96865 .25 L
Mistroke
.96866 .25 L
.96867 .25 L
.96867 .25 L
.96868 .25 L
.96868 .25 L
.96869 .25 L
.9687 .25 L
.9687 .25 L
.96871 .25 L
.96872 .25 L
.96872 .25 L
.96873 .25 L
.96874 .25 L
.96874 .25 L
.96874 .25 L
.96875 .25 L
.96875 .25 L
.96876 .25 L
.96876 .25 L
.96877 .25 L
.96878 .25 L
.96878 .25 L
.96879 .25 L
.96879 .25 L
.9688 .25 L
.96881 .25 L
.96881 .25 L
.96882 .25 L
.96883 .25 L
.96883 .25 L
.96884 .25 L
.96885 .25 L
.96885 .25 L
.96886 .25 L
.96886 .25 L
.96887 .25 L
.96887 .25 L
.96888 .25 L
.96888 .25 L
.96888 .25 L
.96889 .25 L
.9689 .25 L
.9689 .25 L
.9689 .25 L
.96891 .25 L
.96891 .25 L
.96891 .25 L
.96892 .25 L
.96892 .25 L
.96892 .25 L
Mistroke
.96893 .25 L
.96894 .25 L
.96894 .25 L
.96895 .25 L
.96896 .25 L
.96896 .25 L
.96897 .25 L
.96898 .25 L
.96898 .25 L
.96899 .25 L
.969 .25 L
.969 .25 L
.96901 .25 L
.96901 .25 L
.96902 .25 L
.96903 .25 L
.96903 .25 L
.96904 .25 L
.96904 .25 L
.96905 .25 L
.96905 .25 L
.96906 .25 L
.96907 .25 L
.96907 .25 L
.96908 .25 L
.96908 .25 L
.96909 .25 L
.9691 .25 L
.9691 .25 L
.96911 .25 L
.96911 .25 L
.96912 .25 L
.96912 .25 L
.96913 .25 L
.96913 .25 L
.96914 .25 L
.96915 .25 L
.96915 .25 L
.96916 .25 L
.96917 .25 L
.96917 .25 L
.96918 .25 L
.96918 .25 L
.96919 .25 L
.9692 .25 L
.9692 .25 L
.96921 .25 L
.96922 .25 L
.96922 .25 L
.96923 .25 L
Mistroke
.96923 .25 L
.96924 .25 L
.96925 .25 L
.96925 .25 L
.96926 .25 L
.96926 .25 L
.96927 .25 L
.96928 .25 L
.96928 .25 L
.96929 .25 L
.96929 .25 L
.9693 .25 L
.9693 .25 L
.96931 .25 L
.96932 .25 L
.96932 .25 L
.96933 .25 L
.96933 .25 L
.96934 .25 L
.96934 .25 L
.96935 .25 L
.96935 .25 L
.96936 .25 L
.96936 .25 L
.96937 .25 L
.96938 .25 L
.96938 .25 L
.96939 .25 L
.96939 .25 L
.9694 .25 L
.9694 .25 L
.96941 .25 L
.96941 .25 L
.96942 .25 L
.96942 .25 L
.96943 .25 L
.96944 .25 L
.96944 .25 L
.96945 .25 L
.96945 .25 L
.96946 .25 L
.96947 .25 L
.96947 .25 L
.96948 .25 L
.96948 .25 L
.96949 .25 L
.9695 .25 L
.9695 .25 L
.96951 .25 L
.96951 .25 L
Mistroke
.96952 .25 L
.96953 .25 L
.96953 .25 L
.96954 .25 L
.96955 .25 L
.96955 .25 L
.96956 .25 L
.96956 .25 L
.96957 .25 L
.96957 .25 L
.96957 .25 L
.96958 .25 L
.96959 .25 L
.96959 .25 L
.9696 .25 L
.96961 .25 L
.96961 .25 L
.96962 .25 L
.96962 .25 L
.96963 .25 L
.96964 .25 L
.96964 .25 L
.96965 .25 L
.96966 .25 L
.96966 .25 L
.96967 .25 L
.96968 .25 L
.96968 .25 L
.96969 .25 L
.96969 .25 L
.9697 .25 L
.9697 .25 L
.9697 .25 L
.96971 .25 L
.96971 .25 L
.96972 .25 L
.96972 .25 L
.96973 .25 L
.96973 .25 L
.96973 .25 L
.96974 .25 L
.96974 .25 L
.96975 .25 L
.96975 .25 L
.96976 .25 L
.96976 .25 L
.96977 .25 L
.96978 .25 L
.96978 .25 L
.96979 .25 L
Mistroke
.96979 .25 L
.9698 .25 L
.96981 .25 L
.96981 .25 L
.96982 .25 L
.96983 .25 L
.96983 .25 L
.96984 .25 L
.96985 .25 L
.96985 .25 L
.96985 .25 L
.96986 .25 L
.96987 .25 L
.96987 .25 L
.96988 .25 L
.96988 .25 L
.96989 .25 L
.9699 .25 L
.9699 .25 L
.96991 .25 L
.96991 .25 L
.96992 .25 L
.96993 .25 L
.96993 .25 L
.96994 .25 L
.96994 .25 L
.96995 .25 L
.96995 .25 L
.96996 .25 L
.96996 .25 L
.96997 .25 L
.96998 .25 L
.96998 .25 L
.96999 .25 L
.97 .25 L
.97 .25 L
.97001 .25 L
.97001 .25 L
.97002 .25 L
.97003 .25 L
.97003 .25 L
.97004 .25 L
.97005 .25 L
.97005 .25 L
.97006 .25 L
.97006 .25 L
.97007 .25 L
.97007 .25 L
.97008 .25 L
.97009 .25 L
Mistroke
.97009 .25 L
.9701 .25 L
.9701 .25 L
.97011 .25 L
.97012 .25 L
.97012 .25 L
.97013 .25 L
.97013 .25 L
.97014 .25 L
.97015 .25 L
.97015 .25 L
.97015 .25 L
.97016 .25 L
.97017 .25 L
.97017 .25 L
.97018 .25 L
.97018 .25 L
.97019 .25 L
.97019 .25 L
.9702 .25 L
.9702 .25 L
.97021 .25 L
.97022 .25 L
.97022 .25 L
.97023 .25 L
.97023 .25 L
.97024 .25 L
.97024 .25 L
.97025 .25 L
.97025 .25 L
.97026 .25 L
.97027 .25 L
.97027 .25 L
.97028 .25 L
.97028 .25 L
.97029 .25 L
.97029 .25 L
.9703 .25 L
.97031 .25 L
.97031 .25 L
.97032 .25 L
.97033 .25 L
.97033 .25 L
.97034 .25 L
.97034 .25 L
.97035 .25 L
.97036 .25 L
.97036 .25 L
.97037 .25 L
.97038 .25 L
Mistroke
.97038 .25 L
.97039 .25 L
.97039 .25 L
.97039 .25 L
.9704 .25 L
.9704 .25 L
.97041 .25 L
.97042 .25 L
.97042 .25 L
.97043 .25 L
.97044 .25 L
.97044 .25 L
.97045 .25 L
.97045 .25 L
.97046 .25 L
.97047 .25 L
.97047 .25 L
.97048 .25 L
.97049 .25 L
.97049 .25 L
.9705 .25 L
.97051 .25 L
.97051 .25 L
.97051 .25 L
.97052 .25 L
.97052 .25 L
.97053 .25 L
.97053 .25 L
.97054 .25 L
.97054 .25 L
.97055 .25 L
.97055 .25 L
.97055 .25 L
.97056 .25 L
.97056 .25 L
.97057 .25 L
.97057 .25 L
.97057 .25 L
.97058 .25 L
.97059 .25 L
.97059 .25 L
.9706 .25 L
.97061 .25 L
.97061 .25 L
.97062 .25 L
.97062 .25 L
.97063 .25 L
.97064 .25 L
.97064 .25 L
.97065 .25 L
Mistroke
.97066 .25 L
.97066 .25 L
.97067 .25 L
.97067 .25 L
.97068 .25 L
.97068 .25 L
.97069 .25 L
.9707 .25 L
.9707 .25 L
.97071 .25 L
.97071 .25 L
.97072 .25 L
.97073 .25 L
.97073 .25 L
.97074 .25 L
.97074 .25 L
.97075 .25 L
.97076 .25 L
.97076 .25 L
.97077 .25 L
.97077 .25 L
.97078 .25 L
.97078 .25 L
.97079 .25 L
.97079 .25 L
.9708 .25 L
.97081 .25 L
.97081 .25 L
.97082 .25 L
.97083 .25 L
.97083 .25 L
.97084 .25 L
.97084 .25 L
.97085 .25 L
.97086 .25 L
.97086 .25 L
.97087 .25 L
.97088 .25 L
.97088 .25 L
.97089 .25 L
.97089 .25 L
.9709 .25 L
.9709 .25 L
.97091 .25 L
.97092 .25 L
.97092 .25 L
.97093 .25 L
.97093 .25 L
.97094 .25 L
.97095 .25 L
Mistroke
.97095 .25 L
.97096 .25 L
.97096 .25 L
.97097 .25 L
.97097 .25 L
.97098 .25 L
.97098 .25 L
.97099 .25 L
.971 .25 L
.971 .25 L
.971 .25 L
.97101 .25 L
.97102 .25 L
.97102 .25 L
.97103 .25 L
.97103 .25 L
.97104 .25 L
.97105 .25 L
.97105 .25 L
.97105 .25 L
.97106 .25 L
.97107 .25 L
.97107 .25 L
.97108 .25 L
.97108 .25 L
.97109 .25 L
.9711 .25 L
.9711 .25 L
.97111 .25 L
.97111 .25 L
.97112 .25 L
.97112 .25 L
.97113 .25 L
.97114 .25 L
.97114 .25 L
.97115 .25 L
.97116 .25 L
.97116 .25 L
.97117 .25 L
.97117 .25 L
.97118 .25 L
.97119 .25 L
.97119 .25 L
.9712 .25 L
.97121 .25 L
.97121 .25 L
.97121 .25 L
.97122 .25 L
.97122 .25 L
.97123 .25 L
Mistroke
.97123 .25 L
.97124 .25 L
.97125 .25 L
.97125 .25 L
.97126 .25 L
.97127 .25 L
.97127 .25 L
.97128 .25 L
.97128 .25 L
.97129 .25 L
.9713 .25 L
.9713 .25 L
.97131 .25 L
.97132 .25 L
.97132 .25 L
.97133 .25 L
.97133 .25 L
.97134 .25 L
.97134 .25 L
.97135 .25 L
.97135 .25 L
.97136 .25 L
.97136 .25 L
.97137 .25 L
.97137 .25 L
.97137 .25 L
.97138 .25 L
.97138 .25 L
.97138 .25 L
.97139 .25 L
.97139 .25 L
.9714 .25 L
.9714 .25 L
.97141 .25 L
.97142 .25 L
.97142 .25 L
.97143 .25 L
.97144 .25 L
.97144 .25 L
.97145 .25 L
.97145 .25 L
.97146 .25 L
.97147 .25 L
.97147 .25 L
.97148 .25 L
.97149 .25 L
.97149 .25 L
.9715 .25 L
.9715 .25 L
.97151 .25 L
Mistroke
.97151 .25 L
.97152 .25 L
.97153 .25 L
.97153 .25 L
.97154 .25 L
.97154 .25 L
.97155 .25 L
.97155 .25 L
.97156 .25 L
.97157 .25 L
.97157 .25 L
.97158 .25 L
.97158 .25 L
.97159 .25 L
.97159 .25 L
.9716 .25 L
.9716 .25 L
.97161 .25 L
.97162 .25 L
.97162 .25 L
.97163 .25 L
.97164 .25 L
.97164 .25 L
.97165 .25 L
.97166 .25 L
.97166 .25 L
.97167 .25 L
.97168 .25 L
.97168 .25 L
.97169 .25 L
.97169 .25 L
.9717 .25 L
.9717 .25 L
.97171 .25 L
.97172 .25 L
.97172 .25 L
.97173 .25 L
.97173 .25 L
.97174 .25 L
.97175 .25 L
.97175 .25 L
.97176 .25 L
.97176 .25 L
.97177 .25 L
.97178 .25 L
.97178 .25 L
.97179 .25 L
.97179 .25 L
.9718 .25 L
.9718 .25 L
Mistroke
.97181 .25 L
.97181 .25 L
.97182 .25 L
.97183 .25 L
.97183 .25 L
.97184 .25 L
.97185 .25 L
.97185 .25 L
.97186 .25 L
.97186 .25 L
.97187 .25 L
.97188 .25 L
.97188 .25 L
.97189 .25 L
.9719 .25 L
.9719 .25 L
.9719 .25 L
.97191 .25 L
.97192 .25 L
.97192 .25 L
.97193 .25 L
.97194 .25 L
.97194 .25 L
.97195 .25 L
.97195 .25 L
.97196 .25 L
.97197 .25 L
.97197 .25 L
.97198 .25 L
.97198 .25 L
.97199 .25 L
.972 .25 L
.972 .25 L
.972 .25 L
.97201 .25 L
.97202 .25 L
.97202 .25 L
.97203 .25 L
.97203 .25 L
.97204 .25 L
.97204 .25 L
.97205 .25 L
.97205 .25 L
.97206 .25 L
.97207 .25 L
.97207 .25 L
.97208 .25 L
.97208 .25 L
.97209 .25 L
.97209 .25 L
Mistroke
.9721 .25 L
.9721 .25 L
.97211 .25 L
.97212 .25 L
.97212 .25 L
.97213 .25 L
.97213 .25 L
.97214 .25 L
.97214 .25 L
.97215 .25 L
.97216 .25 L
.97216 .25 L
.97217 .25 L
.97218 .25 L
.97218 .25 L
.97219 .25 L
.97219 .25 L
.9722 .25 L
.97221 .25 L
.97221 .25 L
.97222 .25 L
.97223 .25 L
.97223 .25 L
.97224 .25 L
.97224 .25 L
.97224 .25 L
.97225 .25 L
.97225 .25 L
.97226 .25 L
.97227 .25 L
.97227 .25 L
.97228 .25 L
.97229 .25 L
.97229 .25 L
.9723 .25 L
.9723 .25 L
.97231 .25 L
.97232 .25 L
.97232 .25 L
.97233 .25 L
.97234 .25 L
.97234 .25 L
.97235 .25 L
.97236 .25 L
.97236 .25 L
.97236 .25 L
.97237 .25 L
.97237 .25 L
.97238 .25 L
.97238 .25 L
Mistroke
.97239 .25 L
.97239 .25 L
.9724 .25 L
.9724 .25 L
.9724 .25 L
.97241 .25 L
.97241 .25 L
.97242 .25 L
.97242 .25 L
.97242 .25 L
.97243 .25 L
.97244 .25 L
.97244 .25 L
.97245 .25 L
.97246 .25 L
.97246 .25 L
.97247 .25 L
.97247 .25 L
.97248 .25 L
.97249 .25 L
.97249 .25 L
.9725 .25 L
.97251 .25 L
.97251 .25 L
.97252 .25 L
.97252 .25 L
.97253 .25 L
.97253 .25 L
.97254 .25 L
.97255 .25 L
.97255 .25 L
.97256 .25 L
.97256 .25 L
.97257 .25 L
.97258 .25 L
.97258 .25 L
.97259 .25 L
.97259 .25 L
.9726 .25 L
.97261 .25 L
.97261 .25 L
.97262 .25 L
.97262 .25 L
.97262 .25 L
.97263 .25 L
.97264 .25 L
.97264 .25 L
.97265 .25 L
.97266 .25 L
.97266 .25 L
Mistroke
.97267 .25 L
.97268 .25 L
.97268 .25 L
.97269 .25 L
.97269 .25 L
.9727 .25 L
.97271 .25 L
.97271 .25 L
.97272 .25 L
.97273 .25 L
.97273 .25 L
.97274 .25 L
.97274 .25 L
.97275 .25 L
.97275 .25 L
.97276 .25 L
.97277 .25 L
.97277 .25 L
.97278 .25 L
.97278 .25 L
.97279 .25 L
.9728 .25 L
.9728 .25 L
.97281 .25 L
.97281 .25 L
.97282 .25 L
.97282 .25 L
.97283 .25 L
.97283 .25 L
.97284 .25 L
.97285 .25 L
.97285 .25 L
.97285 .25 L
.97286 .25 L
.97287 .25 L
.97287 .25 L
.97288 .25 L
.97288 .25 L
.97289 .25 L
.9729 .25 L
.9729 .25 L
.9729 .25 L
.97291 .25 L
.97292 .25 L
.97292 .25 L
.97293 .25 L
.97293 .25 L
.97294 .25 L
.97295 .25 L
.97295 .25 L
Mistroke
.97296 .25 L
.97296 .25 L
.97297 .25 L
.97297 .25 L
.97298 .25 L
.97299 .25 L
.97299 .25 L
.973 .25 L
.97301 .25 L
.97301 .25 L
.97302 .25 L
.97302 .25 L
.97303 .25 L
.97304 .25 L
.97304 .25 L
.97305 .25 L
.97306 .25 L
.97306 .25 L
.97306 .25 L
.97307 .25 L
.97307 .25 L
.97308 .25 L
.97308 .25 L
.97309 .25 L
.9731 .25 L
.9731 .25 L
.97311 .25 L
.97312 .25 L
.97312 .25 L
.97313 .25 L
.97314 .25 L
.97314 .25 L
.97315 .25 L
.97315 .25 L
.97316 .25 L
.97317 .25 L
.97317 .25 L
.97318 .25 L
.97318 .25 L
.97319 .25 L
.97319 .25 L
.9732 .25 L
.9732 .25 L
.97321 .25 L
.97321 .25 L
.97322 .25 L
.97322 .25 L
.97322 .25 L
.97323 .25 L
.97323 .25 L
Mistroke
.97324 .25 L
.97324 .25 L
.97324 .25 L
.97325 .25 L
.97325 .25 L
.97326 .25 L
.97327 .25 L
.97327 .25 L
.97328 .25 L
.97329 .25 L
.97329 .25 L
.9733 .25 L
.9733 .25 L
.97331 .25 L
.97332 .25 L
.97332 .25 L
.97333 .25 L
.97334 .25 L
.97334 .25 L
.97335 .25 L
.97335 .25 L
.97336 .25 L
.97336 .25 L
.97337 .25 L
.97338 .25 L
.97338 .25 L
.97339 .25 L
.97339 .25 L
.9734 .25 L
.9734 .25 L
.97341 .25 L
.97342 .25 L
.97342 .25 L
.97343 .25 L
.97344 .25 L
.97344 .25 L
.97345 .25 L
.97345 .25 L
.97346 .25 L
.97346 .25 L
.97347 .25 L
.97348 .25 L
.97348 .25 L
.97349 .25 L
.97349 .25 L
.9735 .25 L
.97351 .25 L
.97351 .25 L
.97352 .25 L
.97353 .25 L
Mistroke
.97353 .25 L
.97354 .25 L
.97355 .25 L
.97355 .25 L
.97355 .25 L
.97356 .25 L
.97357 .25 L
.97357 .25 L
.97358 .25 L
.97358 .25 L
.97359 .25 L
.9736 .25 L
.9736 .25 L
.97361 .25 L
.97361 .25 L
.97362 .25 L
.97363 .25 L
.97363 .25 L
.97364 .25 L
.97364 .25 L
.97365 .25 L
.97365 .25 L
.97366 .25 L
.97366 .25 L
.97367 .25 L
.97367 .25 L
.97368 .25 L
.97368 .25 L
.97369 .25 L
.9737 .25 L
.9737 .25 L
.97371 .25 L
.97371 .25 L
.97372 .25 L
.97373 .25 L
.97373 .25 L
.97374 .25 L
.97374 .25 L
.97374 .25 L
.97375 .25 L
.97376 .25 L
.97376 .25 L
.97377 .25 L
.97377 .25 L
.97378 .25 L
.97379 .25 L
.97379 .25 L
.9738 .25 L
.9738 .25 L
.97381 .25 L
Mistroke
.97382 .25 L
.97382 .25 L
.97383 .25 L
.97383 .25 L
.97384 .25 L
.97385 .25 L
.97385 .25 L
.97386 .25 L
.97387 .25 L
.97387 .25 L
.97388 .25 L
.97388 .25 L
.97389 .25 L
.97389 .25 L
.9739 .25 L
.9739 .25 L
.97391 .25 L
.97391 .25 L
.97392 .25 L
.97393 .25 L
.97393 .25 L
.97394 .25 L
.97395 .25 L
.97395 .25 L
.97396 .25 L
.97397 .25 L
.97397 .25 L
.97398 .25 L
.97398 .25 L
.97399 .25 L
.974 .25 L
.974 .25 L
.97401 .25 L
.97401 .25 L
.97402 .25 L
.97402 .25 L
.97403 .25 L
.97403 .25 L
.97403 .25 L
.97404 .25 L
.97404 .25 L
.97405 .25 L
.97405 .25 L
.97406 .25 L
.97406 .25 L
.97406 .25 L
.97407 .25 L
.97407 .25 L
.97408 .25 L
.97408 .25 L
Mistroke
.97409 .25 L
.9741 .25 L
.9741 .25 L
.97411 .25 L
.97412 .25 L
.97412 .25 L
.97413 .25 L
.97413 .25 L
.97414 .25 L
.97415 .25 L
.97415 .25 L
.97416 .25 L
.97417 .25 L
.97417 .25 L
.97417 .25 L
.97418 .25 L
.97419 .25 L
.97419 .25 L
.9742 .25 L
.97421 .25 L
.97421 .25 L
.97422 .25 L
.97422 .25 L
.97423 .25 L
.97423 .25 L
.97424 .25 L
.97425 .25 L
.97425 .25 L
.97426 .25 L
.97427 .25 L
.97427 .25 L
.97427 .25 L
.97428 .25 L
.97429 .25 L
.97429 .25 L
.9743 .25 L
.97431 .25 L
.97431 .25 L
.97432 .25 L
.97432 .25 L
.97433 .25 L
.97434 .25 L
.97434 .25 L
.97435 .25 L
.97436 .25 L
.97436 .25 L
.97437 .25 L
.97437 .25 L
.97438 .25 L
.97438 .25 L
Mistroke
.97439 .25 L
.9744 .25 L
.9744 .25 L
.97441 .25 L
.97441 .25 L
.97442 .25 L
.97443 .25 L
.97443 .25 L
.97444 .25 L
.97444 .25 L
.97445 .25 L
.97446 .25 L
.97446 .25 L
.97447 .25 L
.97447 .25 L
.97447 .25 L
.97448 .25 L
.97449 .25 L
.97449 .25 L
.9745 .25 L
.9745 .25 L
.97451 .25 L
.97451 .25 L
.97452 .25 L
.97453 .25 L
.97453 .25 L
.97454 .25 L
.97454 .25 L
.97455 .25 L
.97455 .25 L
.97456 .25 L
.97456 .25 L
.97457 .25 L
.97457 .25 L
.97458 .25 L
.97459 .25 L
.97459 .25 L
.9746 .25 L
.9746 .25 L
.97461 .25 L
.97462 .25 L
.97462 .25 L
.97463 .25 L
.97463 .25 L
.97464 .25 L
.97465 .25 L
.97465 .25 L
.97466 .25 L
.97466 .25 L
.97467 .25 L
Mistroke
.97468 .25 L
.97468 .25 L
.97469 .25 L
.9747 .25 L
.9747 .25 L
.97471 .25 L
.97471 .25 L
.97471 .25 L
.97472 .25 L
.97473 .25 L
.97473 .25 L
.97474 .25 L
.97475 .25 L
.97475 .25 L
.97476 .25 L
.97476 .25 L
.97477 .25 L
.97478 .25 L
.97478 .25 L
.97479 .25 L
.97479 .25 L
.9748 .25 L
.97481 .25 L
.97481 .25 L
.97482 .25 L
.97483 .25 L
.97483 .25 L
.97484 .25 L
.97484 .25 L
.97485 .25 L
.97485 .25 L
.97485 .25 L
.97486 .25 L
.97486 .25 L
.97487 .25 L
.97487 .25 L
.97487 .25 L
.97488 .25 L
.97488 .25 L
.97489 .25 L
.97489 .25 L
.97489 .25 L
.9749 .25 L
.97491 .25 L
.97491 .25 L
.97492 .25 L
.97493 .25 L
.97493 .25 L
.97494 .25 L
.97494 .25 L
Mistroke
.97495 .25 L
.97496 .25 L
.97496 .25 L
.97497 .25 L
.97498 .25 L
.97498 .25 L
.97499 .25 L
.97499 .25 L
.975 .25 L
.975 .25 L
.97501 .25 L
.97502 .25 L
.97502 .25 L
.97503 .25 L
.97504 .25 L
.97504 .25 L
.97505 .25 L
.97505 .25 L
.97506 .25 L
.97506 .25 L
.97507 .25 L
.97508 .25 L
.97508 .25 L
.97509 .25 L
.97509 .25 L
.9751 .25 L
.9751 .25 L
.97511 .25 L
.97512 .25 L
.97512 .25 L
.97513 .25 L
.97514 .25 L
.97514 .25 L
.97515 .25 L
.97515 .25 L
.97516 .25 L
.97517 .25 L
.97517 .25 L
.97518 .25 L
.97519 .25 L
.97519 .25 L
.9752 .25 L
.9752 .25 L
.97521 .25 L
.97521 .25 L
.97522 .25 L
.97523 .25 L
.97523 .25 L
.97524 .25 L
.97524 .25 L
Mistroke
.97525 .25 L
.97525 .25 L
.97526 .25 L
.97527 .25 L
.97527 .25 L
.97528 .25 L
.97528 .25 L
.97529 .25 L
.97529 .25 L
.9753 .25 L
.9753 .25 L
.97531 .25 L
.97532 .25 L
.97532 .25 L
.97533 .25 L
.97534 .25 L
.97534 .25 L
.97535 .25 L
.97536 .25 L
.97536 .25 L
.97537 .25 L
.97538 .25 L
.97538 .25 L
.97539 .25 L
.97539 .25 L
.9754 .25 L
.9754 .25 L
.97541 .25 L
.97542 .25 L
.97542 .25 L
.97543 .25 L
.97543 .25 L
.97544 .25 L
.97545 .25 L
.97545 .25 L
.97546 .25 L
.97546 .25 L
.97547 .25 L
.97548 .25 L
.97548 .25 L
.97549 .25 L
.97549 .25 L
.9755 .25 L
.9755 .25 L
.97551 .25 L
.97551 .25 L
.97552 .25 L
.97552 .25 L
.97553 .25 L
.97553 .25 L
Mistroke
.97554 .25 L
.97555 .25 L
.97555 .25 L
.97556 .25 L
.97556 .25 L
.97557 .25 L
.97557 .25 L
.97558 .25 L
.97559 .25 L
.97559 .25 L
.97559 .25 L
.9756 .25 L
.97561 .25 L
.97561 .25 L
.97562 .25 L
.97562 .25 L
.97563 .25 L
.97564 .25 L
.97564 .25 L
.97565 .25 L
.97565 .25 L
.97566 .25 L
.97567 .25 L
.97567 .25 L
.97568 .25 L
.97568 .25 L
.97569 .25 L
.9757 .25 L
.9757 .25 L
.97571 .25 L
.97572 .25 L
.97572 .25 L
.97573 .25 L
.97573 .25 L
.97574 .25 L
.97574 .25 L
.97574 .25 L
.97575 .25 L
.97576 .25 L
.97576 .25 L
.97577 .25 L
.97578 .25 L
.97578 .25 L
.97579 .25 L
.9758 .25 L
.9758 .25 L
.97581 .25 L
.97582 .25 L
.97582 .25 L
.97583 .25 L
Mistroke
.97583 .25 L
.97584 .25 L
.97585 .25 L
.97585 .25 L
.97586 .25 L
.97586 .25 L
.97587 .25 L
.97587 .25 L
.97588 .25 L
.97588 .25 L
.97588 .25 L
.97589 .25 L
.97589 .25 L
.9759 .25 L
.9759 .25 L
.97591 .25 L
.97591 .25 L
.97591 .25 L
.97592 .25 L
.97592 .25 L
.97593 .25 L
.97593 .25 L
.97594 .25 L
.97595 .25 L
.97595 .25 L
.97596 .25 L
.97597 .25 L
.97597 .25 L
.97598 .25 L
.97598 .25 L
.97599 .25 L
.976 .25 L
.976 .25 L
.97601 .25 L
.97602 .25 L
.97602 .25 L
.97602 .25 L
.97603 .25 L
.97604 .25 L
.97604 .25 L
.97605 .25 L
.97606 .25 L
.97606 .25 L
.97607 .25 L
.97607 .25 L
.97608 .25 L
.97608 .25 L
.97609 .25 L
.9761 .25 L
.9761 .25 L
Mistroke
.97611 .25 L
.97612 .25 L
.97612 .25 L
.97612 .25 L
.97613 .25 L
.97614 .25 L
.97614 .25 L
.97614 .25 L
.97615 .25 L
.97616 .25 L
.97616 .25 L
.97616 .25 L
.97617 .25 L
.97618 .25 L
.97618 .25 L
.97618 .25 L
.97619 .25 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[90]:=",
  ImageSize->{405, 202.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006E0000bR000`400?l00000o`00003oo`3ooonF
0?ooo`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00fP3oool01@000000oooo0?oo
o`3oool000000;H0oooo003K0?ooo`040000003oool0oooo00000;H0oooo003L0?ooo`800000]`3o
ool00=d0oooo00<000000?ooo`3oool0]@3oool00=`0oooo00<000000?ooo`000000]P3oool00=`0
oooo00@000000?ooo`3oool00000]@3oool00?l0ooooUP3oool00?l0ooooUP3oool00?l0ooooUP3o
ool00?l0ooooUP3oool00?l0ooooUP3oool004T0oooo00<000000?ooo`3oool0?@3oool5000003`0
oooo0`0000100?ooo`D00000@P3oool00`000000oooo0?ooo`0n0?ooo`00B@3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool00P00000o0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0?P3oool00400oooo1@0000000`3oool000000000
0004000003L0oooo1@0000020?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo
000000100?ooo`030000003oool0oooo0400oooo1P00000n0?ooo`00A`3oool010000000oooo0?oo
o`0000100?ooo`800000?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo
0P0000110?ooo`040000003oool0oooo000003l0oooo00180?ooo`030000003oool000000480oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0000000o0?ooo`00B@3oool00`000000oooo0000
00120?ooo`030000003oool0oooo03T0oooo00D000000?ooo`3oool0oooo000000130?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`000000?P3oool004X0oooo0P00000n0?ooo`050000003o
ool0oooo0?ooo`000000>`3oool200000080oooo00<000000?ooo`3oool0?@3oool01@000000oooo
0?ooo`3oool000000480oooo0P00000n0?ooo`00B`3oool00`000000oooo0?ooo`0m0?ooo`<00000
?@3oool300000440oooo0`0000140?ooo`030000003oool0oooo03`0oooo003o0?oooiH0oooo003o
0?oooiH0oooo003o0?oooiH0oooo000^0?ooo`030000003oool0oooo0080oooo0`0000070?ooool0
0000@P00000G0?ooo`00;P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000060?ooo`<0
00001@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo000V0?ooo`D00000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool002l0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00;`3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000_0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0E0?ooo`00;P3oool300000080oooo0P0000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool09`3ooolS0000od80oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0E0?ooo`00<03oool010000000oooo0?ooo`3oool3000000H0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo
000m0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`0E0?ooo`00?@3oool3000008`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E
0?ooo`00?@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool05@3oool003d0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?ooo`03
0000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo
0`00002<0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E
0?ooo`00?@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool05@3oool003d0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?ooo`03
0000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`<00000S03oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E
0?ooo`00?@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo01h0oooo00<000000?oo
o`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`190?ooob<0
003o803oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3o
ool3000008`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool0
03d0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo
01D0oooo000m0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0[P3oool00`000000
oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`2^0?ooo`030000003oool0oooo01D0oooo000b0?ooo`<00000203oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool00340oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0[P3oool0
0`000000oooo0?ooo`0E0?ooo`00:`3oool5000000030?ooo`000000oooo00<0oooo00<000000?oo
o`3oool0103oool3000008`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?oo
o`00=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool4000000L0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?ooo`030000003o
ool0oooo01D0oooo000c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000c0?ooo`@000001P3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0
oooo000m0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0E0?ooo`00?@3oool3000008`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`0E0?ooo`00?@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo00<00000
0?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?oo
o`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0
oooo06/0oooo8`000?n_0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool3000008`0
oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E
0?ooo`00?@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool05@3oool003d0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2^0?ooo`03
0000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool3000008`0oooo00<000000?ooo`3oool0[P3o
ool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<0
00000?ooo`3oool03`3oool60?l007L0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`0E0?ooo`00?@3oool00`000000oooo0?ooo`0<0?ooo`@0o`00103oool50?l007<0oooo00<00000
0?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`0;0?oo
o`80o`002`3oool30?l00740oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?oo
o`00?@3oool3000000X0oooo0P3o000>0?ooo`80o`00L03oool00`000000oooo0?ooo`2^0?ooo`03
0000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo00T0oooo0P3o000@0?ooo`80o`00
K`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003o
ool0oooo00T0oooo00<0o`000?ooo`3oool0403oool30?l006d0oooo00<000000?ooo`3oool0[P3o
ool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`080?ooo`80o`00503oool2
0?l006`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`00
0000oooo0?ooo`080?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo00L0
oooo0P3o000G0?ooo`030?l0003oool0oooo06T0oooo00<000000?ooo`3oool0[P3oool00`000000
oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo01H0oooo
0P3o001Z0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool001l0oooo00<0
00000?ooo`3oool0403oool3000000P0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0G0?ooo`80o`003`3oool50?l005D0oooo00<000000?ooo`3oool0:03oool?0?l007L0oooo00<0
00000?ooo`3oool05@3oool001l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`02
000000L0oooo2P0000000`3o000000000000000H000000030?l000000000000000X00000103o0003
000000D0o`00D@00002[0000o`L000005`3oool001l0oooo00<000000?ooo`3oool03`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool20?l001X0oooo0P3o0009
0?ooo`<0o`002P3oool30?l004l0oooo00<000000?ooo`3oool0603oool70?l002@0oooo2@3o001R
0?ooo`030000003oool0oooo01D0oooo000P0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0o`000?oo
o`3oool06P3oool00`3o0000oooo0?ooo`060?ooo`80o`003P3oool30?l004d0oooo00<000000?oo
o`3oool05@3oool40?l00380oooo203o001K0?ooo`030000003oool0oooo01D0oooo000P0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<0o`000?ooo`3oool06P3oool20?l000L0oooo00<0o`000?ooo`3o
ool03`3oool20?l004`0oooo00<000000?ooo`3oool04P3oool40?l003`0oooo1P3o001F0?ooo`03
0000003oool0oooo01D0oooo000O0?ooo`<00000403oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool04@3oool20?l004/0oooo00<000000?ooo`3oool03`3oool30?l004H0
oooo1P3o001@0?ooo`030000003oool0oooo01D0oooo000P0?ooo`030000003oool0oooo00l0oooo
0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo00<0oooo0P3o000D0?ooo`80o`00BP3oool00`000000oooo
0?ooo`0=0?ooo`<0o`00C@3oool60?l004/0oooo00<000000?ooo`3oool05@3oool00240oooo0P00
000@0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo01/0oooo0P3o
00040?ooo`030?l0003oool0oooo01@0oooo0P3o00190?ooo`030000003oool0oooo00/0oooo0`3o
001D0?ooo`D0o`00A`3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`06
0?ooo`030?l0003oool0oooo01`0oooo00@0o`000?ooo`3oool0oooo0P3o000G0?ooo`80o`003`3o
ool90?l00300oooo00<000000?ooo`3oool02P3oool20?l005X0oooo1P3o00120?ooo`030000003o
ool0oooo01D0oooo000m0?ooo`<000001P3oool00`3o0000oooo0?ooo`0L0?ooo`050?l0003oool0
oooo0?ooo`3o00006@3oool00`3o0000oooo0?ooo`0;0?ooo`<0o`00203oool30?l002d0oooo00<0
00000?ooo`3oool0203oool20?l00640oooo1@3o000n0?ooo`030000003oool0oooo01D0oooo000m
0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0703oool01@3o0000oooo0?ooo`3o
ool0o`0001T0oooo0P3o000:0?ooo`<0o`00303oool30?l002/0oooo00<000000?ooo`3oool01`3o
ool20?l006H0oooo1@3o000j0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0
oooo00H0oooo00<0o`000?ooo`3oool0703oool01@3o0000oooo0?ooo`3oool0o`0001X0oooo00<0
o`000?ooo`3oool01`3oool20?l00100oooo0P3o000G0?ooo`H0o`003@3oool00`000000oooo0?oo
o`060?ooo`80o`00J`3oool50?l003H0oooo00<000000?ooo`3oool05@3oool003d0oooo00<00000
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0M0?ooo`040?l0003oool0o`000?l001/0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0@0?ooo`<0o`004@3oool50?l000@0oooo103o
000:0?ooo`030000003oool0oooo00D0oooo0P3o001`0?ooo`@0o`00<`3oool00`000000oooo0?oo
o`0E0?ooo`00?@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01h0oooo00<0o`00
0?ooo`3o0000703oool00`3o0000oooo0?ooo`050?ooo`80o`00503oool20?l000h0oooo0`3o000;
0?ooo`<0o`00203oool00`000000oooo0?ooo`040?ooo`80o`00M03oool50?l002l0oooo00<00000
0?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0N0?oo
o`030?l0003oool0o`0001`0oooo0P3o00050?ooo`80o`005P3oool00`3o0000oooo0?ooo`0;0?oo
o`80o`003`3oool30?l000H0oooo00<000000?ooo`3oool00`3oool20?l007T0oooo103o000/0?oo
o`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3o
ool07P3oool00`3o0000oooo0?l0000M0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool05@3oool20?l000/0oooo0P3o000B0?ooo`80o`001@3oool00`000000oooo0?ooo`030?ooo`03
0?l0003oool0oooo07/0oooo1@3o000X0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000
003oool0oooo00D0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?l0000M0?ooo`030?l0
003oool0oooo0080oooo0P3o000H0?ooo`80o`002@3oool20?l001@0oooo0P3o00040?ooo`030000
003oool0oooo0080oooo0P3o00210?ooo`@0o`009@3oool00`000000oooo0?ooo`0E0?ooo`00?@3o
ool3000000D0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?l0000M0?ooo`80o`000`3o
ool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo00H0oooo0P3o000F0?ooo`80o`000`3o
ool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo08<0oooo103o000R0?ooo`030000003o
ool0oooo01D0oooo000m0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool07P3oool0
0`3o0000oooo0?l0000N0?ooo`050?l0003oool0oooo0?ooo`3o00006P3oool20?l000L0oooo00<0
o`000?ooo`3oool05P3oool01@3o0000oooo0?ooo`3oool0000000<0oooo00<0o`000?ooo`3oool0
R03oool40?l001h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0o`0001h0oooo00D0o`000?ooo`3oool0oooo
0?l0000K0?ooo`030?l0003oool0oooo00@0oooo0P3o000H0?ooo`80o`000P3oool01@000000oooo
0?ooo`3oool0o`0008d0oooo103o000K0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000
003oool0oooo00D0oooo00<0o`000?ooo`3oool07P3oool20?l001l0oooo00<0o`000?ooo`3oool0
0P3o000K0?ooo`80o`001@3oool00`3o0000oooo0?ooo`0H0?ooo`040?l0003oool0oooo00000080
oooo0P3o002@0?ooo`@0o`00603oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo
0?ooo`050?ooo`030?l0003oool0oooo01h0oooo0P3o000O0?ooo`040?l0003oool0oooo0?l001d0
oooo00<0o`000?ooo`3oool00P3oool20?l001X0oooo0P3o00001@3oool000000?ooo`3oool0o`00
09@0oooo103o000E0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo00D0
oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0o`0001d0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool000000080
oooo00<0o`000?ooo`3oool0U@3oool40?l00180oooo00<000000?ooo`3oool05@3oool003d0oooo
00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo
00<0o`000?ooo`3o00007@3oool20?l000<0oooo00<0o`000?ooo`3oool06P3oool0103o0000oooo
0000003oool20?l009X0oooo103o000?0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000
003oool0oooo00D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0
003oool0o`0001h0oooo00<0o`000?ooo`3oool00P3o000L0?ooo`050?l0003oool000000?ooo`3o
0000WP3oool40?l000`0oooo00<000000?ooo`3oool05@3oool003d0oooo0`0000050?ooo`030?l0
003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?l0000N0?ooo`040?l0
003oool0oooo0?l001h0oooo00@0o`000000003oool0o`00X@3oool40?l000T0oooo00<000000?oo
o`3oool05@3oool003d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O0?ooo`03
0?l0003oool0oooo01h0oooo00<0o`000?ooo`3o00007P3oool0103o0000oooo0?ooo`3o000N0?oo
o`040?l000000000oooo0?l00:@0oooo103o00060?ooo`030000003oool0oooo01D0oooo000m0?oo
o`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?oo
o`80o`007`3oool0103o0000oooo0?ooo`3o000N0?ooo`040?l000000000oooo0?l00:h0oooo00<0
00000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O
0?ooo`030?l0003oool0oooo01h0oooo0P3o000O0?ooo`040?l0003oool0oooo0?l001h0oooo00@0
o`000000003o0000o`00[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?oo
o`050?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3oool20?l00200oooo00<0
o`000?ooo`3o00007P3oool00`3o000000000?l0002_0?ooo`030000003oool0oooo01D0oooo000m
0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N
0?ooo`80o`00803oool30?l001h0oooo0`3o002_0?ooo`030000003oool0oooo01D0oooo000m0?oo
o`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?oo
o`80o`00803oool20?l00200oooo0P3o002_0?ooo`030000003oool0oooo01D0oooo000m0?ooo`03
0000003oool0oooo00D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?ooo`80
o`00803oool20?l00200oooo0P3o002_0?ooo`030000003oool0oooo01D0oooo000m0?ooo`<00000
1@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo0P3o000P0?ooo`80o`00
803oool20?l00:l0oooo00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo0P3o000P0?ooo`80o`00803o
ool20?l00:l0oooo00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo0P3o000P0?ooo`80o`00803oool2
0?l00:l0oooo00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3oool20?l0
0200oooo0P3o002_0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo00D0
oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0
oooo0P3o000P0?ooo`80o`00[`3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo
0?ooo`050?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo
0?ooo`0N0?ooo`80o`00803oool20?l00:l0oooo00<000000?ooo`3oool05@3oool00380oooo0`00
00080?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?oo
o`0O0?ooo`030?l0003oool0oooo01h0oooo0P3o000P0?ooo`80o`00[`3oool00`000000oooo0?oo
o`0E0?ooo`00<@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3o
ool20?l00200oooo0P3o002_0?ooo`030000003oool0oooo01D0oooo000a0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool3000000D0oooo00<0o`000?ooo`3oool07`3oool0
0`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo0P3o000P0?ooo`80o`00[`3oool0
0`000000oooo0?ooo`0E0?ooo`00=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo
01h0oooo0P3o000P0?ooo`80o`00[`3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool4000000L0
oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0
oooo00<0o`000?ooo`3oool07P3oool20?l00200oooo0P3o002_0?ooo`030000003oool0oooo01D0
oooo000b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3oool20?l00200oooo
0P3o002_0?ooo`030000003oool0oooo01D0oooo000c0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0
o`000?ooo`3oool07P3oool20?l00200oooo0P3o002_0?ooo`030000003oool0oooo01D0oooo000c
0?ooo`@000001P3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01l0oooo00<0o`00
0?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?ooo`80o`00803oool20?l00:l0oooo00<00000
0?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O0?oo
o`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3oool20?l00200oooo00<0o`000?oo
o`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`050?ooo`03
0?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?ooo`80
o`00803oool00`3o0000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`<00000
1@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0
7P3oool20?l00200oooo00<0o`000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3o
ool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3o
ool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0[P3o
ool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0
oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0
oooo01h0oooo00<0o`000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`00
0000oooo0?ooo`050?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o
0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0[P3oool00`00
0000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01l0
oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0
oooo00<0o`000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo
0?ooo`050?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo
0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01l0oooo00<0
o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo00<0
o`000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`05
0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O
0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E
0?ooo`00?@3oool3000000D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?oo
o`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`2^0?oo
o`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3o
ool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3o
ool07P3oool00`3o0000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000
003oool0oooo00D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0
003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`2^0?ooo`030000
003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool07`3o
ool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3o
ool00`3o0000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0
oooo00D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0
oooo01l0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`2^0?ooo`030000003oool0
oooo01D0oooo000m0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool07`3oool00`3o
0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3oool00`3o
0000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000003oool0oooo00D0
oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0
oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`2^0?ooo`030000003oool0oooo01D0
oooo000m0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo
0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo
0?ooo`2^0?ooo`030000003oool0oooo01D0oooo000m0?ooo`<000001@3oool00`3o0000oooo0?oo
o`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?oo
o`0N0?ooo`030?l0003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<00000
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`00
0?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0:h0oooo00<00000
0?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O0?oo
o`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?oo
o`030?l0003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3o
ool07`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0:h0oooo00<000000?ooo`3o
ool05@3oool003d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0
003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0
003oool0oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo00<000000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3o
ool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0:h0oooo00<000000?ooo`3oool05@3o
ool003d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0
oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0
oooo0:h0oooo00<000000?ooo`3oool05@3oool003d0oooo0`0000050?ooo`030?l0003oool0oooo
01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo
01h0oooo00<0o`000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000
oooo0?ooo`050?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000
oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0[P3oool00`000000
oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01l0oooo
00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo
00<0o`000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?oo
o`050?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?oo
o`0O0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0[P3oool00`000000oooo0?oo
o`0E0?ooo`00?@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01l0oooo00<0o`00
0?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo00<0o`00
0?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`000000oooo0?ooo`050?oo
o`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?oo
o`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0[P3oool00`000000oooo0?ooo`0E0?oo
o`00?@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3o
ool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0E0?ooo`00;P3oool00`000000oooo0?ooo`020?ooo`<00000
1`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0
7`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0E0?ooo`00;P3oool01@000000oooo0?ooo`3oool000000080oooo
0P0000060?ooo`<000001@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01l0oooo
00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0:h0oooo
00<000000?ooo`3oool05@3oool002h0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo200000000`3o000000000000000O000000030?l000000000000001l00000
00<0o`000000000000007`0000000`3o000000000000000N000000030?l00000000000000:l00000
5`3oool002l0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?oooe`0oooo
000_0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00;`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00;P3o
ool300000080oooo0P0000020?ooo`030000003oool0oooo0?l0ooooG03oool00300oooo00@00000
0?ooo`3oool0oooo0`00003o0?oooel0oooo003F0?ooo`8000002`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0:P0oooo003E0?ooo`040000003oool0oooo000000T0oooo0P000007
0?ooo`030000003oool0oooo0:L0oooo003>0?ooo`030000003oool0oooo00<000000`3oool30000
00040?ooo`0000000000000000@0oooo00<000000?ooo`0000000`0000040?ooo`030000003oool0
oooo0:H0oooo003>0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`2V0?ooo`00cP3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0YP3oool00<l0oooo00<000000?ooo`0000000`3oool2000000<0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0YP3oool00<l0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
00000:P0oooo003?0?ooo`030000003oool0oooo00<000000`3oool3000000030?ooo`000000oooo
00<0oooo0P0000020?ooo`@000000P3oool00`000000oooo0?ooo`2W0?ooo`00d03oool00`000000
oooo0?ooo`080?ooo`H000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:L0
oooo003@0?ooo`030000003oool0oooo0<80oooo0000\
\>"],
  ImageRangeCache->{{{0, 404}, {201.5, 0}} -> {-6.05769, -13.4331, 0.0295646, \
0.126392}}],

Cell[TextData[{
  "These two graphics show the real part (left) and imaginary part (right) of \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " over the ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  "\[Hyphen]",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "\[Dash]plane."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.00912e-16 1.04977 -0.0679587 1.04977 [
[.13542 .20373 -16.9542 -11.1875 ]
[.13542 .20373 .04582 0 ]
[.3345 .12542 -9.36936 -11.1875 ]
[.3345 .12542 .69314 0 ]
[.54972 .04081 -8.75741 -11.1875 ]
[.54972 .04081 1.36759 0 ]
[.29165 .07573 -8.90381 -11.1875 ]
[.29165 .07573 .65869 0 ]
[.76189 .08851 0 -7.66985 ]
[.76189 .08851 17 3.51765 ]
[.8565 .23339 0 -7.4972 ]
[.8565 .23339 10.0625 3.6903 ]
[.93905 .3598 0 -7.35106 ]
[.93905 .3598 10.125 3.83644 ]
[.91861 .21225 0 -7.4972 ]
[.91861 .21225 9.6875 3.6903 ]
[.02494 .25992 -22.4375 -3.40341 ]
[.02494 .25992 0 7.78409 ]
[.01611 .31527 -17.0625 -3.46156 ]
[.01611 .31527 0 7.72594 ]
[.00696 .37264 -10.0625 -3.52206 ]
[.00696 .37264 0 7.66544 ]
[-0.00254 .43215 -10.1875 -3.58506 ]
[-0.00254 .43215 0 7.60244 ]
[-0.0124 .49393 -15.5625 -3.65071 ]
[-0.0124 .49393 0 7.53679 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.14467 .21304 m
.1493 .21769 L
s
gsave
.13542 .20373 -77.9542 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -70.3694 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.55745 .05141 m
.56132 .05671 L
s
gsave
.54972 .04081 -69.7574 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.19287 .19417 m
.1956 .197 L
s
.24198 .17493 m
.24466 .17782 L
s
.29204 .15533 m
.29467 .15827 L
s
.39509 .11498 m
.3976 .11801 L
s
.44814 .09421 m
.45059 .09729 L
s
.50225 .07302 m
.50464 .07615 L
s
.09737 .23156 m
.10019 .23431 L
s
.05093 .24975 m
.05379 .25245 L
s
.61378 .02935 m
.61603 .03258 L
s
.67126 .00684 m
.67344 .01012 L
s
gsave
.29165 .07573 -69.9038 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.562 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74959 .09308 m
.74344 .09536 L
s
gsave
.76189 .08851 -61 -11.6699 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.4972 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.92653 .36374 m
.92027 .3657 L
s
gsave
.93905 .3598 -61 -11.3511 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.77448 .13116 m
.77078 .1325 L
s
.79849 .16789 m
.79478 .16921 L
s
.82168 .20336 m
.81796 .20465 L
s
.86572 .27073 m
.86199 .27197 L
s
.88666 .30275 m
.88291 .30397 L
s
.90691 .33374 m
.90316 .33494 L
s
.72377 .05359 m
.72009 .05499 L
s
.69697 .0126 m
.69331 .01403 L
s
.94552 .3928 m
.94176 .39396 L
s
.96393 .42096 m
.96017 .4221 L
s
gsave
.91861 .21225 -61 -11.4972 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
68.688 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -83.4375 -7.40341 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -78.0625 -7.46156 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -71.0625 -7.52206 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -71.1875 -7.58506 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -76.5625 -7.65071 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.40678 .69175 m .41017 .68474 L .41534 .68932 L F
.40678 .69175 m .40159 .68718 L .41017 .68474 L F
.41534 .68932 m .41878 .68229 L .42393 .68689 L F
.41534 .68932 m .41017 .68474 L .41878 .68229 L F
.40159 .68718 m .40498 .68013 L .41017 .68474 L F
.40159 .68718 m .39638 .68259 L .40498 .68013 L F
.42393 .68689 m .42741 .67983 L .43254 .68444 L F
.42393 .68689 m .41878 .68229 L .42741 .67983 L F
.41017 .68474 m .4136 .67767 L .41878 .68229 L F
.41017 .68474 m .40498 .68013 L .4136 .67767 L F
.43254 .68444 m .43608 .67737 L .44119 .68199 L F
.43254 .68444 m .42741 .67983 L .43608 .67737 L F
.39638 .68259 m .39975 .6755 L .40498 .68013 L F
.39638 .68259 m .39114 .67797 L .39975 .6755 L F
.41878 .68229 m .42225 .6752 L .42741 .67983 L F
.41878 .68229 m .4136 .67767 L .42225 .6752 L F
.44119 .68199 m .44476 .6749 L .44986 .67953 L F
.44119 .68199 m .43608 .67737 L .44476 .6749 L F
.40498 .68013 m .40839 .67302 L .4136 .67767 L F
.40498 .68013 m .39975 .6755 L .40839 .67302 L F
.42741 .67983 m .43093 .67272 L .43608 .67737 L F
.42741 .67983 m .42225 .6752 L .43093 .67272 L F
.44986 .67953 m .45348 .67242 L .45856 .67707 L F
.44986 .67953 m .44476 .6749 L .45348 .67242 L F
.39114 .67797 m .39449 .67084 L .39975 .6755 L F
.39114 .67797 m .38586 .67332 L .39449 .67084 L F
.4136 .67767 m .41706 .67054 L .42225 .6752 L F
.4136 .67767 m .40839 .67302 L .41706 .67054 L F
.43608 .67737 m .43964 .67023 L .44476 .6749 L F
.43608 .67737 m .43093 .67272 L .43964 .67023 L F
.45856 .67707 m .46223 .66993 L .46728 .67459 L F
.45856 .67707 m .45348 .67242 L .46223 .66993 L F
.39975 .6755 m .40315 .66835 L .40839 .67302 L F
.39975 .6755 m .39449 .67084 L .40315 .66835 L F
.42225 .6752 m .42576 .66804 L .43093 .67272 L F
.42225 .6752 m .41706 .67054 L .42576 .66804 L F
.44476 .6749 m .44838 .66774 L .45348 .67242 L F
.44476 .6749 m .43964 .67023 L .44838 .66774 L F
.46728 .67459 m .471 .66743 L .47604 .67211 L F
.46728 .67459 m .46223 .66993 L .471 .66743 L F
.38586 .67332 m .38921 .66615 L .39449 .67084 L F
.38586 .67332 m .38056 .66865 L .38921 .66615 L F
.40839 .67302 m .41184 .66584 L .41706 .67054 L F
.40839 .67302 m .40315 .66835 L .41184 .66584 L F
.43093 .67272 m .43449 .66554 L .43964 .67023 L F
.43093 .67272 m .42576 .66804 L .43449 .66554 L F
.45348 .67242 m .45714 .66523 L .46223 .66993 L F
.45348 .67242 m .44838 .66774 L .45714 .66523 L F
.47604 .67211 m .4798 .66493 L .48482 .66962 L F
.47604 .67211 m .471 .66743 L .4798 .66493 L F
.39449 .67084 m .39788 .66364 L .40315 .66835 L F
.39449 .67084 m .38921 .66615 L .39788 .66364 L F
.41706 .67054 m .42056 .66333 L .42576 .66804 L F
.41706 .67054 m .41184 .66584 L .42056 .66333 L F
.43964 .67023 m .44324 .66303 L .44838 .66774 L F
.43964 .67023 m .43449 .66554 L .44324 .66303 L F
.46223 .66993 m .46593 .66272 L .471 .66743 L F
.46223 .66993 m .45714 .66523 L .46593 .66272 L F
.48482 .66962 m .48863 .66241 L .49363 .66713 L F
.48482 .66962 m .4798 .66493 L .48863 .66241 L F
.38056 .66865 m .38388 .66143 L .38921 .66615 L F
.38056 .66865 m .37522 .66395 L .38388 .66143 L F
.40315 .66835 m .40659 .66112 L .41184 .66584 L F
.40315 .66835 m .39788 .66364 L .40659 .66112 L F
.42576 .66804 m .4293 .66082 L .43449 .66554 L F
.42576 .66804 m .42056 .66333 L .4293 .66082 L F
.44838 .66774 m .45202 .66051 L .45714 .66523 L F
.44838 .66774 m .44324 .66303 L .45202 .66051 L F
.471 .66743 m .47475 .6602 L .4798 .66493 L F
.471 .66743 m .46593 .66272 L .47475 .6602 L F
.49363 .66713 m .49749 .65989 L .50247 .66462 L F
.49363 .66713 m .48863 .66241 L .49749 .65989 L F
.656 .752 .92 r
.38921 .66615 m .39258 .65891 L .39788 .66364 L F
.38921 .66615 m .38388 .66143 L .39258 .65891 L F
.656 .751 .92 r
.41184 .66584 m .41532 .6586 L .42056 .66333 L F
.41184 .66584 m .40659 .66112 L .41532 .6586 L F
.43449 .66554 m .43807 .65829 L .44324 .66303 L F
.43449 .66554 m .4293 .66082 L .43807 .65829 L F
.45714 .66523 m .46083 .65798 L .46593 .66272 L F
.45714 .66523 m .45202 .66051 L .46083 .65798 L F
.4798 .66493 m .4836 .65767 L .48863 .66241 L F
.4798 .66493 m .47475 .6602 L .4836 .65767 L F
.50247 .66462 m .50638 .65737 L .51134 .66211 L F
.50247 .66462 m .49749 .65989 L .50638 .65737 L F
.656 .752 .92 r
.37522 .66395 m .37853 .65669 L .38388 .66143 L F
.37522 .66395 m .36984 .65922 L .37853 .65669 L F
.39788 .66364 m .4013 .65638 L .40659 .66112 L F
.39788 .66364 m .39258 .65891 L .4013 .65638 L F
.42056 .66333 m .42408 .65607 L .4293 .66082 L F
.42056 .66333 m .41532 .6586 L .42408 .65607 L F
.656 .751 .92 r
.44324 .66303 m .44687 .65576 L .45202 .66051 L F
.44324 .66303 m .43807 .65829 L .44687 .65576 L F
.46593 .66272 m .46967 .65545 L .47475 .6602 L F
.46593 .66272 m .46083 .65798 L .46967 .65545 L F
.48863 .66241 m .49248 .65514 L .49749 .65989 L F
.48863 .66241 m .4836 .65767 L .49248 .65514 L F
.51134 .66211 m .5153 .65483 L .52024 .65959 L F
.51134 .66211 m .50638 .65737 L .5153 .65483 L F
.656 .752 .92 r
.38388 .66143 m .38724 .65415 L .39258 .65891 L F
.38388 .66143 m .37853 .65669 L .38724 .65415 L F
.40659 .66112 m .41005 .65384 L .41532 .6586 L F
.40659 .66112 m .4013 .65638 L .41005 .65384 L F
.4293 .66082 m .43287 .65353 L .43807 .65829 L F
.4293 .66082 m .42408 .65607 L .43287 .65353 L F
.45202 .66051 m .4557 .65322 L .46083 .65798 L F
.45202 .66051 m .44687 .65576 L .4557 .65322 L F
.656 .751 .92 r
.47475 .6602 m .47854 .65291 L .4836 .65767 L F
.47475 .6602 m .46967 .65545 L .47854 .65291 L F
.49749 .65989 m .50139 .6526 L .50638 .65737 L F
.49749 .65989 m .49248 .65514 L .50139 .6526 L F
.52024 .65959 m .52424 .65229 L .52917 .65706 L F
.52024 .65959 m .5153 .65483 L .52424 .65229 L F
.656 .752 .92 r
.36984 .65922 m .37314 .65192 L .37853 .65669 L F
.36984 .65922 m .36444 .65446 L .37314 .65192 L F
.39258 .65891 m .39598 .6516 L .4013 .65638 L F
.39258 .65891 m .38724 .65415 L .39598 .6516 L F
.41532 .6586 m .41883 .65129 L .42408 .65607 L F
.41532 .6586 m .41005 .65384 L .41883 .65129 L F
.43807 .65829 m .44169 .65098 L .44687 .65576 L F
.43807 .65829 m .43287 .65353 L .44169 .65098 L F
.46083 .65798 m .46456 .65067 L .46967 .65545 L F
.46083 .65798 m .4557 .65322 L .46456 .65067 L F
.4836 .65767 m .48744 .65036 L .49248 .65514 L F
.4836 .65767 m .47854 .65291 L .48744 .65036 L F
.50638 .65737 m .51032 .65004 L .5153 .65483 L F
.50638 .65737 m .50139 .6526 L .51032 .65004 L F
.52917 .65706 m .53322 .64973 L .53812 .65452 L F
.52917 .65706 m .52424 .65229 L .53322 .64973 L F
.37853 .65669 m .38187 .64936 L .38724 .65415 L F
.37853 .65669 m .37314 .65192 L .38187 .64936 L F
.4013 .65638 m .40475 .64905 L .41005 .65384 L F
.4013 .65638 m .39598 .6516 L .40475 .64905 L F
.42408 .65607 m .42764 .64873 L .43287 .65353 L F
.42408 .65607 m .41883 .65129 L .42764 .64873 L F
.44687 .65576 m .45054 .64842 L .4557 .65322 L F
.44687 .65576 m .44169 .65098 L .45054 .64842 L F
.46967 .65545 m .47345 .64811 L .47854 .65291 L F
.46967 .65545 m .46456 .65067 L .47345 .64811 L F
.49248 .65514 m .49636 .6478 L .50139 .6526 L F
.49248 .65514 m .48744 .65036 L .49636 .6478 L F
.5153 .65483 m .51929 .64749 L .52424 .65229 L F
.5153 .65483 m .51032 .65004 L .51929 .64749 L F
.53812 .65452 m .54222 .64717 L .54711 .65198 L F
.53812 .65452 m .53322 .64973 L .54222 .64717 L F
.656 .752 .921 r
.36444 .65446 m .36772 .64712 L .37314 .65192 L F
.36444 .65446 m .359 .64968 L .36772 .64712 L F
.656 .752 .92 r
.38724 .65415 m .39063 .6468 L .39598 .6516 L F
.38724 .65415 m .38187 .64936 L .39063 .6468 L F
.41005 .65384 m .41355 .64649 L .41883 .65129 L F
.41005 .65384 m .40475 .64905 L .41355 .64649 L F
.43287 .65353 m .43648 .64617 L .44169 .65098 L F
.43287 .65353 m .42764 .64873 L .43648 .64617 L F
.4557 .65322 m .45942 .64586 L .46456 .65067 L F
.4557 .65322 m .45054 .64842 L .45942 .64586 L F
.47854 .65291 m .48236 .64554 L .48744 .65036 L F
.47854 .65291 m .47345 .64811 L .48236 .64554 L F
.50139 .6526 m .50532 .64523 L .51032 .65004 L F
.50139 .6526 m .49636 .6478 L .50532 .64523 L F
.52424 .65229 m .52828 .64492 L .53322 .64973 L F
.52424 .65229 m .51929 .64749 L .52828 .64492 L F
.54711 .65198 m .55126 .64461 L .55612 .64942 L F
.54711 .65198 m .54222 .64717 L .55126 .64461 L F
.656 .752 .921 r
.37314 .65192 m .37647 .64455 L .38187 .64936 L F
.37314 .65192 m .36772 .64712 L .37647 .64455 L F
.39598 .6516 m .39942 .64423 L .40475 .64905 L F
.39598 .6516 m .39063 .6468 L .39942 .64423 L F
.41883 .65129 m .42238 .64391 L .42764 .64873 L F
.41883 .65129 m .41355 .64649 L .42238 .64391 L F
.656 .752 .92 r
.44169 .65098 m .44534 .6436 L .45054 .64842 L F
.44169 .65098 m .43648 .64617 L .44534 .6436 L F
.46456 .65067 m .46832 .64328 L .47345 .64811 L F
.46456 .65067 m .45942 .64586 L .46832 .64328 L F
.48744 .65036 m .49131 .64297 L .49636 .6478 L F
.48744 .65036 m .48236 .64554 L .49131 .64297 L F
.51032 .65004 m .5143 .64266 L .51929 .64749 L F
.51032 .65004 m .50532 .64523 L .5143 .64266 L F
.53322 .64973 m .53731 .64234 L .54222 .64717 L F
.53322 .64973 m .52828 .64492 L .53731 .64234 L F
.656 .752 .921 r
.359 .64968 m .36227 .64229 L .36772 .64712 L F
.359 .64968 m .35353 .64486 L .36227 .64229 L F
.55612 .64942 m .56032 .64203 L .56517 .64686 L F
.55612 .64942 m .55126 .64461 L .56032 .64203 L F
.38187 .64936 m .38525 .64197 L .39063 .6468 L F
.38187 .64936 m .37647 .64455 L .38525 .64197 L F
.40475 .64905 m .40824 .64165 L .41355 .64649 L F
.40475 .64905 m .39942 .64423 L .40824 .64165 L F
.42764 .64873 m .43123 .64134 L .43648 .64617 L F
.42764 .64873 m .42238 .64391 L .43123 .64134 L F
.45054 .64842 m .45424 .64102 L .45942 .64586 L F
.45054 .64842 m .44534 .6436 L .45424 .64102 L F
.47345 .64811 m .47726 .6407 L .48236 .64554 L F
.47345 .64811 m .46832 .64328 L .47726 .6407 L F
.49636 .6478 m .50028 .64039 L .50532 .64523 L F
.49636 .6478 m .49131 .64297 L .50028 .64039 L F
.51929 .64749 m .52332 .64007 L .52828 .64492 L F
.51929 .64749 m .5143 .64266 L .52332 .64007 L F
.54222 .64717 m .54636 .63976 L .55126 .64461 L F
.54222 .64717 m .53731 .64234 L .54636 .63976 L F
.36772 .64712 m .37103 .6397 L .37647 .64455 L F
.36772 .64712 m .36227 .64229 L .37103 .6397 L F
.56517 .64686 m .56941 .63945 L .57424 .6443 L F
.56517 .64686 m .56032 .64203 L .56941 .63945 L F
.39063 .6468 m .39405 .63938 L .39942 .64423 L F
.39063 .6468 m .38525 .64197 L .39405 .63938 L F
.41355 .64649 m .41708 .63907 L .42238 .64391 L F
.41355 .64649 m .40824 .64165 L .41708 .63907 L F
.43648 .64617 m .44012 .63875 L .44534 .6436 L F
.43648 .64617 m .43123 .64134 L .44012 .63875 L F
.45942 .64586 m .46317 .63843 L .46832 .64328 L F
.45942 .64586 m .45424 .64102 L .46317 .63843 L F
.48236 .64554 m .48622 .63811 L .49131 .64297 L F
.48236 .64554 m .47726 .6407 L .48622 .63811 L F
.50532 .64523 m .50929 .6378 L .5143 .64266 L F
.50532 .64523 m .50028 .64039 L .50929 .6378 L F
.52828 .64492 m .53236 .63748 L .53731 .64234 L F
.52828 .64492 m .52332 .64007 L .53236 .63748 L F
.35353 .64486 m .35678 .63743 L .36227 .64229 L F
.35353 .64486 m .34802 .64003 L .35678 .63743 L F
.55126 .64461 m .55544 .63717 L .56032 .64203 L F
.55126 .64461 m .54636 .63976 L .55544 .63717 L F
.37647 .64455 m .37983 .63711 L .38525 .64197 L F
.37647 .64455 m .37103 .6397 L .37983 .63711 L F
.57424 .6443 m .57854 .63686 L .58334 .64172 L F
.57424 .6443 m .56941 .63945 L .57854 .63686 L F
.39942 .64423 m .40289 .63679 L .40824 .64165 L F
.39942 .64423 m .39405 .63938 L .40289 .63679 L F
.42238 .64391 m .42596 .63647 L .43123 .64134 L F
.42238 .64391 m .41708 .63907 L .42596 .63647 L F
.44534 .6436 m .44903 .63615 L .45424 .64102 L F
.44534 .6436 m .44012 .63875 L .44903 .63615 L F
.46832 .64328 m .47212 .63583 L .47726 .6407 L F
.46832 .64328 m .46317 .63843 L .47212 .63583 L F
.49131 .64297 m .49522 .63552 L .50028 .64039 L F
.49131 .64297 m .48622 .63811 L .49522 .63552 L F
.5143 .64266 m .51832 .6352 L .52332 .64007 L F
.5143 .64266 m .50929 .6378 L .51832 .6352 L F
.53731 .64234 m .54143 .63489 L .54636 .63976 L F
.53731 .64234 m .53236 .63748 L .54143 .63489 L F
.36227 .64229 m .36556 .63484 L .37103 .6397 L F
.36227 .64229 m .35678 .63743 L .36556 .63484 L F
.655 .752 .921 r
.56032 .64203 m .56456 .63457 L .56941 .63945 L F
.56032 .64203 m .55544 .63717 L .56456 .63457 L F
.656 .752 .921 r
.38525 .64197 m .38865 .63451 L .39405 .63938 L F
.38525 .64197 m .37983 .63711 L .38865 .63451 L F
.655 .752 .921 r
.58334 .64172 m .58769 .63426 L .59248 .63913 L F
.58334 .64172 m .57854 .63686 L .58769 .63426 L F
.656 .752 .921 r
.40824 .64165 m .41175 .63419 L .41708 .63907 L F
.40824 .64165 m .40289 .63679 L .41175 .63419 L F
.43123 .64134 m .43486 .63387 L .44012 .63875 L F
.43123 .64134 m .42596 .63647 L .43486 .63387 L F
.45424 .64102 m .45798 .63355 L .46317 .63843 L F
.45424 .64102 m .44903 .63615 L .45798 .63355 L F
.47726 .6407 m .4811 .63323 L .48622 .63811 L F
.47726 .6407 m .47212 .63583 L .4811 .63323 L F
.50028 .64039 m .50424 .63291 L .50929 .6378 L F
.50028 .64039 m .49522 .63552 L .50424 .63291 L F
.52332 .64007 m .52738 .63259 L .53236 .63748 L F
.52332 .64007 m .51832 .6352 L .52738 .63259 L F
.655 .752 .921 r
.34802 .64003 m .35126 .63256 L .35678 .63743 L F
.34802 .64003 m .34248 .63516 L .35126 .63256 L F
.54636 .63976 m .55054 .63228 L .55544 .63717 L F
.54636 .63976 m .54143 .63489 L .55054 .63228 L F
.656 .752 .921 r
.37103 .6397 m .37438 .63223 L .37983 .63711 L F
.37103 .6397 m .36556 .63484 L .37438 .63223 L F
.655 .752 .921 r
.56941 .63945 m .5737 .63196 L .57854 .63686 L F
.56941 .63945 m .56456 .63457 L .5737 .63196 L F
.656 .752 .921 r
.39405 .63938 m .39751 .6319 L .40289 .63679 L F
.39405 .63938 m .38865 .63451 L .39751 .6319 L F
.655 .752 .921 r
.59248 .63913 m .59687 .63165 L .60164 .63654 L F
.59248 .63913 m .58769 .63426 L .59687 .63165 L F
.656 .752 .921 r
.41708 .63907 m .42065 .63158 L .42596 .63647 L F
.41708 .63907 m .41175 .63419 L .42065 .63158 L F
.44012 .63875 m .44379 .63126 L .44903 .63615 L F
.44012 .63875 m .43486 .63387 L .44379 .63126 L F
.46317 .63843 m .46695 .63094 L .47212 .63583 L F
.46317 .63843 m .45798 .63355 L .46695 .63094 L F
.48622 .63811 m .49012 .63062 L .49522 .63552 L F
.48622 .63811 m .4811 .63323 L .49012 .63062 L F
.655 .752 .921 r
.50929 .6378 m .51329 .6303 L .51832 .6352 L F
.50929 .6378 m .50424 .63291 L .51329 .6303 L F
.53236 .63748 m .53648 .62998 L .54143 .63489 L F
.53236 .63748 m .52738 .63259 L .53648 .62998 L F
.35678 .63743 m .36006 .62994 L .36556 .63484 L F
.35678 .63743 m .35126 .63256 L .36006 .62994 L F
.55544 .63717 m .55967 .62966 L .56456 .63457 L F
.55544 .63717 m .55054 .63228 L .55967 .62966 L F
.37983 .63711 m .38322 .62961 L .38865 .63451 L F
.37983 .63711 m .37438 .63223 L .38322 .62961 L F
.57854 .63686 m .58288 .62935 L .58769 .63426 L F
.57854 .63686 m .5737 .63196 L .58288 .62935 L F
.40289 .63679 m .40639 .62929 L .41175 .63419 L F
.40289 .63679 m .39751 .6319 L .40639 .62929 L F
.60164 .63654 m .60609 .62904 L .61083 .63394 L F
.60164 .63654 m .59687 .63165 L .60609 .62904 L F
.42596 .63647 m .42957 .62896 L .43486 .63387 L F
.42596 .63647 m .42065 .63158 L .42957 .62896 L F
.656 .752 .921 r
.44903 .63615 m .45276 .62864 L .45798 .63355 L F
.44903 .63615 m .44379 .63126 L .45276 .62864 L F
.655 .752 .921 r
.47212 .63583 m .47595 .62832 L .4811 .63323 L F
.47212 .63583 m .46695 .63094 L .47595 .62832 L F
.49522 .63552 m .49916 .628 L .50424 .63291 L F
.49522 .63552 m .49012 .63062 L .49916 .628 L F
.51832 .6352 m .52238 .62768 L .52738 .63259 L F
.51832 .6352 m .51329 .6303 L .52238 .62768 L F
.34248 .63516 m .3457 .62765 L .35126 .63256 L F
.34248 .63516 m .33691 .63028 L .3457 .62765 L F
.54143 .63489 m .5456 .62736 L .55054 .63228 L F
.54143 .63489 m .53648 .62998 L .5456 .62736 L F
.36556 .63484 m .36889 .62732 L .37438 .63223 L F
.36556 .63484 m .36006 .62994 L .36889 .62732 L F
.56456 .63457 m .56884 .62704 L .5737 .63196 L F
.56456 .63457 m .55967 .62966 L .56884 .62704 L F
.38865 .63451 m .39209 .62699 L .39751 .6319 L F
.38865 .63451 m .38322 .62961 L .39209 .62699 L F
.58769 .63426 m .59208 .62673 L .59687 .63165 L F
.58769 .63426 m .58288 .62935 L .59208 .62673 L F
.41175 .63419 m .4153 .62666 L .42065 .63158 L F
.41175 .63419 m .40639 .62929 L .4153 .62666 L F
.61083 .63394 m .61533 .62641 L .62006 .63134 L F
.61083 .63394 m .60609 .62904 L .61533 .62641 L F
.43486 .63387 m .43852 .62634 L .44379 .63126 L F
.43486 .63387 m .42957 .62896 L .43852 .62634 L F
.45798 .63355 m .46175 .62601 L .46695 .63094 L F
.45798 .63355 m .45276 .62864 L .46175 .62601 L F
.4811 .63323 m .48499 .62569 L .49012 .63062 L F
.4811 .63323 m .47595 .62832 L .48499 .62569 L F
.50424 .63291 m .50823 .62537 L .51329 .6303 L F
.50424 .63291 m .49916 .628 L .50823 .62537 L F
.52738 .63259 m .53149 .62505 L .53648 .62998 L F
.52738 .63259 m .52238 .62768 L .53149 .62505 L F
.35126 .63256 m .35452 .62503 L .36006 .62994 L F
.35126 .63256 m .3457 .62765 L .35452 .62503 L F
.55054 .63228 m .55476 .62473 L .55967 .62966 L F
.55054 .63228 m .5456 .62736 L .55476 .62473 L F
.37438 .63223 m .37775 .62469 L .38322 .62961 L F
.37438 .63223 m .36889 .62732 L .37775 .62469 L F
.5737 .63196 m .57803 .62441 L .58288 .62935 L F
.5737 .63196 m .56884 .62704 L .57803 .62441 L F
.39751 .6319 m .40099 .62436 L .40639 .62929 L F
.39751 .6319 m .39209 .62699 L .40099 .62436 L F
.59687 .63165 m .60132 .6241 L .60609 .62904 L F
.59687 .63165 m .59208 .62673 L .60132 .6241 L F
.42065 .63158 m .42424 .62403 L .42957 .62896 L F
.42065 .63158 m .4153 .62666 L .42424 .62403 L F
.62006 .63134 m .62461 .62378 L .62931 .62872 L F
.62006 .63134 m .61533 .62641 L .62461 .62378 L F
.44379 .63126 m .4475 .6237 L .45276 .62864 L F
.44379 .63126 m .43852 .62634 L .4475 .6237 L F
.46695 .63094 m .47077 .62338 L .47595 .62832 L F
.46695 .63094 m .46175 .62601 L .47077 .62338 L F
.49012 .63062 m .49405 .62305 L .49916 .628 L F
.49012 .63062 m .48499 .62569 L .49405 .62305 L F
.51329 .6303 m .51734 .62273 L .52238 .62768 L F
.51329 .6303 m .50823 .62537 L .51734 .62273 L F
.655 .753 .921 r
.33691 .63028 m .34011 .62273 L .3457 .62765 L F
.33691 .63028 m .3313 .62537 L .34011 .62273 L F
.655 .752 .921 r
.53648 .62998 m .54063 .62241 L .5456 .62736 L F
.53648 .62998 m .53149 .62505 L .54063 .62241 L F
.36006 .62994 m .36337 .62239 L .36889 .62732 L F
.36006 .62994 m .35452 .62503 L .36337 .62239 L F
.55967 .62966 m .56394 .62209 L .56884 .62704 L F
.55967 .62966 m .55476 .62473 L .56394 .62209 L F
.38322 .62961 m .38664 .62205 L .39209 .62699 L F
.38322 .62961 m .37775 .62469 L .38664 .62205 L F
.58288 .62935 m .58726 .62178 L .59208 .62673 L F
.58288 .62935 m .57803 .62441 L .58726 .62178 L F
.40639 .62929 m .40992 .62172 L .4153 .62666 L F
.40639 .62929 m .40099 .62436 L .40992 .62172 L F
.60609 .62904 m .61058 .62146 L .61533 .62641 L F
.60609 .62904 m .60132 .6241 L .61058 .62146 L F
.42957 .62896 m .43322 .62139 L .43852 .62634 L F
.42957 .62896 m .42424 .62403 L .43322 .62139 L F
.62931 .62872 m .63392 .62115 L .6386 .6261 L F
.62931 .62872 m .62461 .62378 L .63392 .62115 L F
.45276 .62864 m .45651 .62106 L .46175 .62601 L F
.45276 .62864 m .4475 .6237 L .45651 .62106 L F
.47595 .62832 m .47982 .62073 L .48499 .62569 L F
.47595 .62832 m .47077 .62338 L .47982 .62073 L F
.49916 .628 m .50314 .62041 L .50823 .62537 L F
.49916 .628 m .49405 .62305 L .50314 .62041 L F
.52238 .62768 m .52647 .62009 L .53149 .62505 L F
.52238 .62768 m .51734 .62273 L .52647 .62009 L F
.655 .753 .922 r
.3457 .62765 m .34895 .62009 L .35452 .62503 L F
.3457 .62765 m .34011 .62273 L .34895 .62009 L F
.655 .752 .921 r
.5456 .62736 m .54981 .61977 L .55476 .62473 L F
.5456 .62736 m .54063 .62241 L .54981 .61977 L F
.36889 .62732 m .37225 .61974 L .37775 .62469 L F
.36889 .62732 m .36337 .62239 L .37225 .61974 L F
.56884 .62704 m .57315 .61945 L .57803 .62441 L F
.56884 .62704 m .56394 .62209 L .57315 .61945 L F
.39209 .62699 m .39556 .6194 L .40099 .62436 L F
.39209 .62699 m .38664 .62205 L .39556 .6194 L F
.59208 .62673 m .59651 .61913 L .60132 .6241 L F
.59208 .62673 m .58726 .62178 L .59651 .61913 L F
.4153 .62666 m .41889 .61907 L .42424 .62403 L F
.4153 .62666 m .40992 .62172 L .41889 .61907 L F
.61533 .62641 m .61988 .61882 L .62461 .62378 L F
.61533 .62641 m .61058 .62146 L .61988 .61882 L F
.43852 .62634 m .44222 .61874 L .4475 .6237 L F
.43852 .62634 m .43322 .62139 L .44222 .61874 L F
.6386 .6261 m .64325 .6185 L .64791 .62347 L F
.6386 .6261 m .63392 .62115 L .64325 .6185 L F
.46175 .62601 m .46556 .61841 L .47077 .62338 L F
.46175 .62601 m .45651 .62106 L .46556 .61841 L F
.48499 .62569 m .48891 .61808 L .49405 .62305 L F
.48499 .62569 m .47982 .62073 L .48891 .61808 L F
.50823 .62537 m .51227 .61776 L .51734 .62273 L F
.50823 .62537 m .50314 .62041 L .51227 .61776 L F
.655 .753 .922 r
.3313 .62537 m .33448 .6178 L .34011 .62273 L F
.3313 .62537 m .32565 .62045 L .33448 .6178 L F
.655 .752 .921 r
.53149 .62505 m .53563 .61744 L .54063 .62241 L F
.53149 .62505 m .52647 .62009 L .53563 .61744 L F
.655 .753 .922 r
.35452 .62503 m .35782 .61744 L .36337 .62239 L F
.35452 .62503 m .34895 .62009 L .35782 .61744 L F
.655 .752 .921 r
.55476 .62473 m .55901 .61711 L .56394 .62209 L F
.55476 .62473 m .54981 .61977 L .55901 .61711 L F
.37775 .62469 m .38116 .61709 L .38664 .62205 L F
.37775 .62469 m .37225 .61974 L .38116 .61709 L F
.57803 .62441 m .5824 .6168 L .58726 .62178 L F
.57803 .62441 m .57315 .61945 L .5824 .6168 L F
.40099 .62436 m .40451 .61675 L .40992 .62172 L F
.40099 .62436 m .39556 .6194 L .40451 .61675 L F
.60132 .6241 m .6058 .61648 L .61058 .62146 L F
.60132 .6241 m .59651 .61913 L .6058 .61648 L F
.42424 .62403 m .42788 .61641 L .43322 .62139 L F
.42424 .62403 m .41889 .61907 L .42788 .61641 L F
.62461 .62378 m .62921 .61616 L .63392 .62115 L F
.62461 .62378 m .61988 .61882 L .62921 .61616 L F
.4475 .6237 m .45125 .61608 L .45651 .62106 L F
.4475 .6237 m .44222 .61874 L .45125 .61608 L F
.64791 .62347 m .65262 .61585 L .65726 .62084 L F
.64791 .62347 m .64325 .6185 L .65262 .61585 L F
.47077 .62338 m .47463 .61575 L .47982 .62073 L F
.47077 .62338 m .46556 .61841 L .47463 .61575 L F
.49405 .62305 m .49802 .61542 L .50314 .62041 L F
.49405 .62305 m .48891 .61808 L .49802 .61542 L F
.51734 .62273 m .52142 .6151 L .52647 .62009 L F
.51734 .62273 m .51227 .61776 L .52142 .6151 L F
.655 .753 .922 r
.34011 .62273 m .34334 .61514 L .34895 .62009 L F
.34011 .62273 m .33448 .6178 L .34334 .61514 L F
.655 .752 .921 r
.54063 .62241 m .54483 .61478 L .54981 .61977 L F
.54063 .62241 m .53563 .61744 L .54483 .61478 L F
.655 .753 .922 r
.36337 .62239 m .36671 .61478 L .37225 .61974 L F
.36337 .62239 m .35782 .61744 L .36671 .61478 L F
.655 .752 .921 r
.56394 .62209 m .56825 .61445 L .57315 .61945 L F
.56394 .62209 m .55901 .61711 L .56825 .61445 L F
.655 .753 .921 r
.38664 .62205 m .3901 .61443 L .39556 .6194 L F
.38664 .62205 m .38116 .61709 L .3901 .61443 L F
.655 .752 .921 r
.58726 .62178 m .59168 .61414 L .59651 .61913 L F
.58726 .62178 m .5824 .6168 L .59168 .61414 L F
.40992 .62172 m .41349 .61409 L .41889 .61907 L F
.40992 .62172 m .40451 .61675 L .41349 .61409 L F
.61058 .62146 m .61512 .61382 L .61988 .61882 L F
.61058 .62146 m .6058 .61648 L .61512 .61382 L F
.43322 .62139 m .4369 .61375 L .44222 .61874 L F
.43322 .62139 m .42788 .61641 L .4369 .61375 L F
.63392 .62115 m .63856 .61351 L .64325 .6185 L F
.63392 .62115 m .62921 .61616 L .63856 .61351 L F
.45651 .62106 m .46031 .61342 L .46556 .61841 L F
.45651 .62106 m .45125 .61608 L .46031 .61342 L F
.65726 .62084 m .66202 .6132 L .66664 .61819 L F
.65726 .62084 m .65262 .61585 L .66202 .6132 L F
.47982 .62073 m .48373 .61308 L .48891 .61808 L F
.47982 .62073 m .47463 .61575 L .48373 .61308 L F
.50314 .62041 m .50716 .61276 L .51227 .61776 L F
.50314 .62041 m .49802 .61542 L .50716 .61276 L F
.655 .754 .923 r
.32565 .62045 m .32881 .61285 L .33448 .6178 L F
.32565 .62045 m .31997 .61552 L .32881 .61285 L F
.655 .752 .921 r
.52647 .62009 m .5306 .61243 L .53563 .61744 L F
.52647 .62009 m .52142 .6151 L .5306 .61243 L F
.655 .753 .922 r
.34895 .62009 m .35222 .61247 L .35782 .61744 L F
.34895 .62009 m .34334 .61514 L .35222 .61247 L F
.655 .752 .921 r
.54981 .61977 m .55406 .61211 L .55901 .61711 L F
.54981 .61977 m .54483 .61478 L .55406 .61211 L F
.655 .753 .922 r
.37225 .61974 m .37564 .61211 L .38116 .61709 L F
.37225 .61974 m .36671 .61478 L .37564 .61211 L F
.655 .752 .921 r
.57315 .61945 m .57752 .61179 L .5824 .6168 L F
.57315 .61945 m .56825 .61445 L .57752 .61179 L F
.655 .753 .921 r
.39556 .6194 m .39907 .61176 L .40451 .61675 L F
.39556 .6194 m .3901 .61443 L .39907 .61176 L F
.655 .752 .921 r
.59651 .61913 m .60099 .61147 L .6058 .61648 L F
.59651 .61913 m .59168 .61414 L .60099 .61147 L F
.41889 .61907 m .4225 .61141 L .42788 .61641 L F
.41889 .61907 m .41349 .61409 L .4225 .61141 L F
.61988 .61882 m .62447 .61115 L .62921 .61616 L F
.61988 .61882 m .61512 .61382 L .62447 .61115 L F
.44222 .61874 m .44595 .61108 L .45125 .61608 L F
.44222 .61874 m .4369 .61375 L .44595 .61108 L F
.64325 .6185 m .64796 .61084 L .65262 .61585 L F
.64325 .6185 m .63856 .61351 L .64796 .61084 L F
.46556 .61841 m .4694 .61074 L .47463 .61575 L F
.46556 .61841 m .46031 .61342 L .4694 .61074 L F
.66664 .61819 m .67146 .61053 L .67605 .61555 L F
.66664 .61819 m .66202 .6132 L .67146 .61053 L F
.48891 .61808 m .49286 .61041 L .49802 .61542 L F
.48891 .61808 m .48373 .61308 L .49286 .61041 L F
.51227 .61776 m .51634 .61008 L .52142 .6151 L F
.51227 .61776 m .50716 .61276 L .51634 .61008 L F
.655 .754 .923 r
.33448 .6178 m .33769 .61018 L .34334 .61514 L F
.33448 .6178 m .32881 .61285 L .33769 .61018 L F
.655 .752 .921 r
.53563 .61744 m .53982 .60976 L .54483 .61478 L F
.53563 .61744 m .5306 .61243 L .53982 .60976 L F
.655 .753 .922 r
.35782 .61744 m .36114 .6098 L .36671 .61478 L F
.35782 .61744 m .35222 .61247 L .36114 .6098 L F
.655 .752 .921 r
.55901 .61711 m .56331 .60943 L .56825 .61445 L F
.55901 .61711 m .55406 .61211 L .56331 .60943 L F
.655 .753 .922 r
.38116 .61709 m .3846 .60943 L .3901 .61443 L F
.38116 .61709 m .37564 .61211 L .3846 .60943 L F
.655 .752 .921 r
.5824 .6168 m .58681 .60911 L .59168 .61414 L F
.5824 .6168 m .57752 .61179 L .58681 .60911 L F
.655 .753 .922 r
.40451 .61675 m .40807 .60908 L .41349 .61409 L F
.40451 .61675 m .39907 .61176 L .40807 .60908 L F
.655 .752 .921 r
.6058 .61648 m .61033 .60879 L .61512 .61382 L F
.6058 .61648 m .60099 .61147 L .61033 .60879 L F
.42788 .61641 m .43154 .60873 L .4369 .61375 L F
.42788 .61641 m .4225 .61141 L .43154 .60873 L F
.62921 .61616 m .63385 .60848 L .63856 .61351 L F
.62921 .61616 m .62447 .61115 L .63385 .60848 L F
.45125 .61608 m .45503 .6084 L .46031 .61342 L F
.45125 .61608 m .44595 .61108 L .45503 .6084 L F
.65262 .61585 m .65738 .60817 L .66202 .6132 L F
.65262 .61585 m .64796 .61084 L .65738 .60817 L F
.47463 .61575 m .47852 .60806 L .48373 .61308 L F
.47463 .61575 m .4694 .61074 L .47852 .60806 L F
.67605 .61555 m .68092 .60786 L .68549 .61289 L F
.67605 .61555 m .67146 .61053 L .68092 .60786 L F
.49802 .61542 m .50203 .60773 L .50716 .61276 L F
.49802 .61542 m .49286 .61041 L .50203 .60773 L F
.655 .756 .924 r
.31997 .61552 m .32311 .60792 L .32881 .61285 L F
.31997 .61552 m .31425 .61059 L .32311 .60792 L F
.655 .752 .921 r
.52142 .6151 m .52554 .6074 L .5306 .61243 L F
.52142 .6151 m .51634 .61008 L .52554 .6074 L F
.655 .754 .923 r
.34334 .61514 m .3466 .6075 L .35222 .61247 L F
.34334 .61514 m .33769 .61018 L .3466 .6075 L F
.655 .752 .921 r
.54483 .61478 m .54907 .60707 L .55406 .61211 L F
.54483 .61478 m .53982 .60976 L .54907 .60707 L F
.655 .754 .922 r
.36671 .61478 m .37009 .60711 L .37564 .61211 L F
.36671 .61478 m .36114 .6098 L .37009 .60711 L F
.655 .752 .921 r
.56825 .61445 m .5726 .60675 L .57752 .61179 L F
.56825 .61445 m .56331 .60943 L .5726 .60675 L F
.655 .753 .922 r
.3901 .61443 m .39359 .60675 L .39907 .61176 L F
.3901 .61443 m .3846 .60943 L .39359 .60675 L F
.655 .752 .921 r
.59168 .61414 m .59614 .60643 L .60099 .61147 L F
.59168 .61414 m .58681 .60911 L .59614 .60643 L F
.655 .753 .922 r
.41349 .61409 m .4171 .60639 L .4225 .61141 L F
.41349 .61409 m .40807 .60908 L .4171 .60639 L F
.655 .752 .921 r
.61512 .61382 m .6197 .60611 L .62447 .61115 L F
.61512 .61382 m .61033 .60879 L .6197 .60611 L F
.4369 .61375 m .44061 .60605 L .44595 .61108 L F
.4369 .61375 m .43154 .60873 L .44061 .60605 L F
.63856 .61351 m .64326 .6058 L .64796 .61084 L F
.63856 .61351 m .63385 .60848 L .64326 .6058 L F
.46031 .61342 m .46414 .60571 L .4694 .61074 L F
.46031 .61342 m .45503 .6084 L .46414 .60571 L F
.66202 .6132 m .66683 .60549 L .67146 .61053 L F
.66202 .6132 m .65738 .60817 L .66683 .60549 L F
.48373 .61308 m .48768 .60537 L .49286 .61041 L F
.48373 .61308 m .47852 .60806 L .48768 .60537 L F
.654 .752 .921 r
.68549 .61289 m .69042 .60519 L .69497 .61023 L F
.68549 .61289 m .68092 .60786 L .69042 .60519 L F
.655 .752 .921 r
.50716 .61276 m .51122 .60504 L .51634 .61008 L F
.50716 .61276 m .50203 .60773 L .51122 .60504 L F
.655 .756 .924 r
.32881 .61285 m .33201 .60523 L .33769 .61018 L F
.32881 .61285 m .32311 .60792 L .33201 .60523 L F
.655 .752 .921 r
.5306 .61243 m .53478 .60471 L .53982 .60976 L F
.5306 .61243 m .52554 .6074 L .53478 .60471 L F
.655 .754 .923 r
.35222 .61247 m .35553 .60481 L .36114 .6098 L F
.35222 .61247 m .3466 .6075 L .35553 .60481 L F
.655 .752 .921 r
.55406 .61211 m .55834 .60438 L .56331 .60943 L F
.55406 .61211 m .54907 .60707 L .55834 .60438 L F
.655 .754 .922 r
.37564 .61211 m .37906 .60442 L .3846 .60943 L F
.37564 .61211 m .37009 .60711 L .37906 .60442 L F
.655 .752 .921 r
.57752 .61179 m .58192 .60406 L .58681 .60911 L F
.57752 .61179 m .5726 .60675 L .58192 .60406 L F
.655 .753 .922 r
.39907 .61176 m .40261 .60406 L .40807 .60908 L F
.39907 .61176 m .39359 .60675 L .40261 .60406 L F
.655 .752 .921 r
.60099 .61147 m .6055 .60374 L .61033 .60879 L F
.60099 .61147 m .59614 .60643 L .6055 .60374 L F
.655 .753 .922 r
.4225 .61141 m .42616 .6037 L .43154 .60873 L F
.4225 .61141 m .4171 .60639 L .42616 .6037 L F
.655 .752 .921 r
.62447 .61115 m .6291 .60343 L .63385 .60848 L F
.62447 .61115 m .6197 .60611 L .6291 .60343 L F
.655 .753 .922 r
.44595 .61108 m .44971 .60335 L .45503 .6084 L F
.44595 .61108 m .44061 .60605 L .44971 .60335 L F
.655 .752 .921 r
.64796 .61084 m .6527 .60311 L .65738 .60817 L F
.64796 .61084 m .64326 .6058 L .6527 .60311 L F
.4694 .61074 m .47328 .60301 L .47852 .60806 L F
.4694 .61074 m .46414 .60571 L .47328 .60301 L F
.654 .752 .921 r
.67146 .61053 m .67632 .60281 L .68092 .60786 L F
.67146 .61053 m .66683 .60549 L .67632 .60281 L F
.655 .752 .921 r
.49286 .61041 m .49686 .60267 L .50203 .60773 L F
.49286 .61041 m .48768 .60537 L .49686 .60267 L F
.654 .758 .926 r
.31425 .61059 m .31737 .60301 L .32311 .60792 L F
.31425 .61059 m .30849 .6057 L .31737 .60301 L F
.654 .752 .922 r
.69497 .61023 m .69994 .60251 L .70447 .60757 L F
.69497 .61023 m .69042 .60519 L .69994 .60251 L F
.655 .752 .921 r
.51634 .61008 m .52045 .60234 L .52554 .6074 L F
.51634 .61008 m .51122 .60504 L .52045 .60234 L F
.655 .756 .924 r
.33769 .61018 m .34093 .60254 L .3466 .6075 L F
.33769 .61018 m .33201 .60523 L .34093 .60254 L F
.655 .752 .921 r
.53982 .60976 m .54405 .60201 L .54907 .60707 L F
.53982 .60976 m .53478 .60471 L .54405 .60201 L F
.655 .754 .923 r
.36114 .6098 m .3645 .60212 L .37009 .60711 L F
.36114 .6098 m .35553 .60481 L .3645 .60212 L F
.655 .752 .921 r
.56331 .60943 m .56765 .60169 L .5726 .60675 L F
.56331 .60943 m .55834 .60438 L .56765 .60169 L F
.655 .754 .922 r
.3846 .60943 m .38807 .60173 L .39359 .60675 L F
.3846 .60943 m .37906 .60442 L .38807 .60173 L F
.655 .752 .921 r
.58681 .60911 m .59127 .60136 L .59614 .60643 L F
.58681 .60911 m .58192 .60406 L .59127 .60136 L F
.655 .753 .922 r
.40807 .60908 m .41165 .60136 L .4171 .60639 L F
.40807 .60908 m .40261 .60406 L .41165 .60136 L F
.655 .752 .921 r
.61033 .60879 m .6149 .60104 L .6197 .60611 L F
.61033 .60879 m .6055 .60374 L .6149 .60104 L F
.655 .753 .922 r
.43154 .60873 m .43525 .601 L .44061 .60605 L F
.43154 .60873 m .42616 .6037 L .43525 .601 L F
.655 .752 .921 r
.63385 .60848 m .63853 .60073 L .64326 .6058 L F
.63385 .60848 m .6291 .60343 L .63853 .60073 L F
.655 .753 .922 r
.45503 .6084 m .45885 .60065 L .46414 .60571 L F
.45503 .6084 m .44971 .60335 L .45885 .60065 L F
.655 .752 .921 r
.65738 .60817 m .66218 .60042 L .66683 .60549 L F
.65738 .60817 m .6527 .60311 L .66218 .60042 L F
.47852 .60806 m .48246 .60031 L .48768 .60537 L F
.47852 .60806 m .47328 .60301 L .48246 .60031 L F
.654 .752 .922 r
.68092 .60786 m .68584 .60012 L .69042 .60519 L F
.68092 .60786 m .67632 .60281 L .68584 .60012 L F
.655 .752 .921 r
.50203 .60773 m .50608 .59997 L .51122 .60504 L F
.50203 .60773 m .49686 .60267 L .50608 .59997 L F
.654 .758 .926 r
.32311 .60792 m .32628 .60031 L .33201 .60523 L F
.32311 .60792 m .31737 .60301 L .32628 .60031 L F
.654 .752 .922 r
.70447 .60757 m .7095 .59983 L .71401 .6049 L F
.70447 .60757 m .69994 .60251 L .7095 .59983 L F
.655 .752 .921 r
.52554 .6074 m .52971 .59964 L .53478 .60471 L F
.52554 .6074 m .52045 .60234 L .52971 .59964 L F
.655 .756 .924 r
.3466 .6075 m .34988 .59983 L .35553 .60481 L F
.3466 .6075 m .34093 .60254 L .34988 .59983 L F
.655 .752 .921 r
.54907 .60707 m .55334 .59931 L .55834 .60438 L F
.54907 .60707 m .54405 .60201 L .55334 .59931 L F
.655 .755 .923 r
.37009 .60711 m .37349 .59941 L .37906 .60442 L F
.37009 .60711 m .3645 .60212 L .37349 .59941 L F
.655 .752 .921 r
.5726 .60675 m .57699 .59898 L .58192 .60406 L F
.5726 .60675 m .56765 .60169 L .57699 .59898 L F
.655 .754 .923 r
.39359 .60675 m .39711 .59902 L .40261 .60406 L F
.39359 .60675 m .38807 .60173 L .39711 .59902 L F
.655 .752 .921 r
.59614 .60643 m .60065 .59866 L .6055 .60374 L F
.59614 .60643 m .59127 .60136 L .60065 .59866 L F
.655 .753 .922 r
.4171 .60639 m .42073 .59865 L .42616 .6037 L F
.4171 .60639 m .41165 .60136 L .42073 .59865 L F
.655 .752 .921 r
.6197 .60611 m .62432 .59834 L .6291 .60343 L F
.6197 .60611 m .6149 .60104 L .62432 .59834 L F
.655 .753 .922 r
.44061 .60605 m .44437 .59829 L .44971 .60335 L F
.44061 .60605 m .43525 .601 L .44437 .59829 L F
.655 .752 .922 r
.64326 .6058 m .648 .59803 L .6527 .60311 L F
.64326 .6058 m .63853 .60073 L .648 .59803 L F
.655 .753 .922 r
.46414 .60571 m .46801 .59794 L .47328 .60301 L F
.46414 .60571 m .45885 .60065 L .46801 .59794 L F
.654 .752 .922 r
.66683 .60549 m .67169 .59772 L .67632 .60281 L F
.66683 .60549 m .66218 .60042 L .67169 .59772 L F
.655 .753 .922 r
.48768 .60537 m .49166 .59759 L .49686 .60267 L F
.48768 .60537 m .48246 .60031 L .49166 .59759 L F
.654 .762 .929 r
.30849 .6057 m .31158 .59818 L .31737 .60301 L F
.30849 .6057 m .30268 .60088 L .31158 .59818 L F
.654 .752 .922 r
.69042 .60519 m .69539 .59743 L .69994 .60251 L F
.69042 .60519 m .68584 .60012 L .69539 .59743 L F
.655 .752 .921 r
.51122 .60504 m .51532 .59726 L .52045 .60234 L F
.51122 .60504 m .50608 .59997 L .51532 .59726 L F
.654 .758 .926 r
.33201 .60523 m .33522 .5976 L .34093 .60254 L F
.33201 .60523 m .32628 .60031 L .33522 .5976 L F
.654 .752 .922 r
.71401 .6049 m .7191 .59714 L .72358 .60222 L F
.71401 .6049 m .7095 .59983 L .7191 .59714 L F
.655 .752 .921 r
.53478 .60471 m .53899 .59692 L .54405 .60201 L F
.53478 .60471 m .52971 .59964 L .53899 .59692 L F
.654 .756 .924 r
.35553 .60481 m .35887 .59712 L .3645 .60212 L F
.35553 .60481 m .34988 .59983 L .35887 .59712 L F
.655 .752 .921 r
.55834 .60438 m .56267 .59659 L .56765 .60169 L F
.55834 .60438 m .55334 .59931 L .56267 .59659 L F
.655 .755 .923 r
.37906 .60442 m .38252 .5967 L .38807 .60173 L F
.37906 .60442 m .37349 .59941 L .38252 .5967 L F
.655 .752 .921 r
.58192 .60406 m .58637 .59627 L .59127 .60136 L F
.58192 .60406 m .57699 .59898 L .58637 .59627 L F
.655 .754 .923 r
.40261 .60406 m .40618 .5963 L .41165 .60136 L F
.40261 .60406 m .39711 .59902 L .40618 .5963 L F
.655 .752 .921 r
.6055 .60374 m .61007 .59595 L .6149 .60104 L F
.6055 .60374 m .60065 .59866 L .61007 .59595 L F
.655 .753 .922 r
.42616 .6037 m .42984 .59593 L .43525 .601 L F
.42616 .6037 m .42073 .59865 L .42984 .59593 L F
.655 .752 .922 r
.6291 .60343 m .63378 .59563 L .63853 .60073 L F
.6291 .60343 m .62432 .59834 L .63378 .59563 L F
.655 .753 .922 r
.44971 .60335 m .45352 .59557 L .45885 .60065 L F
.44971 .60335 m .44437 .59829 L .45352 .59557 L F
.654 .752 .922 r
.6527 .60311 m .6575 .59532 L .66218 .60042 L F
.6527 .60311 m .648 .59803 L .6575 .59532 L F
.655 .753 .922 r
.47328 .60301 m .4772 .59522 L .48246 .60031 L F
.47328 .60301 m .46801 .59794 L .4772 .59522 L F
.654 .752 .922 r
.67632 .60281 m .68123 .59502 L .68584 .60012 L F
.67632 .60281 m .67169 .59772 L .68123 .59502 L F
.655 .753 .922 r
.49686 .60267 m .5009 .59487 L .50608 .59997 L F
.49686 .60267 m .49166 .59759 L .5009 .59487 L F
.654 .762 .929 r
.31737 .60301 m .32051 .59546 L .32628 .60031 L F
.31737 .60301 m .31158 .59818 L .32051 .59546 L F
.654 .752 .922 r
.69994 .60251 m .70497 .59473 L .7095 .59983 L F
.69994 .60251 m .69539 .59743 L .70497 .59473 L F
.655 .752 .922 r
.52045 .60234 m .5246 .59454 L .52971 .59964 L F
.52045 .60234 m .51532 .59726 L .5246 .59454 L F
.654 .758 .926 r
.34093 .60254 m .3442 .59489 L .34988 .59983 L F
.34093 .60254 m .33522 .5976 L .3442 .59489 L F
.655 .752 .922 r
.54405 .60201 m .54831 .5942 L .55334 .59931 L F
.54405 .60201 m .53899 .59692 L .54831 .5942 L F
.654 .752 .922 r
.72358 .60222 m .72873 .59445 L .73318 .59954 L F
.72358 .60222 m .7191 .59714 L .72873 .59445 L F
.654 .756 .924 r
.3645 .60212 m .36788 .59441 L .37349 .59941 L F
.3645 .60212 m .35887 .59712 L .36788 .59441 L F
.655 .752 .922 r
.56765 .60169 m .57204 .59387 L .57699 .59898 L F
.56765 .60169 m .56267 .59659 L .57204 .59387 L F
.655 .755 .923 r
.38807 .60173 m .39158 .59398 L .39711 .59902 L F
.38807 .60173 m .38252 .5967 L .39158 .59398 L F
.655 .752 .922 r
.59127 .60136 m .59577 .59355 L .60065 .59866 L F
.59127 .60136 m .58637 .59627 L .59577 .59355 L F
.655 .754 .923 r
.41165 .60136 m .41528 .59358 L .42073 .59865 L F
.41165 .60136 m .40618 .5963 L .41528 .59358 L F
.655 .752 .922 r
.6149 .60104 m .61951 .59323 L .62432 .59834 L F
.6149 .60104 m .61007 .59595 L .61951 .59323 L F
.655 .753 .922 r
.43525 .601 m .43898 .59321 L .44437 .59829 L F
.43525 .601 m .42984 .59593 L .43898 .59321 L F
.654 .752 .922 r
.63853 .60073 m .64327 .59292 L .648 .59803 L F
.63853 .60073 m .63378 .59563 L .64327 .59292 L F
.655 .753 .922 r
.45885 .60065 m .4627 .59284 L .46801 .59794 L F
.45885 .60065 m .45352 .59557 L .4627 .59284 L F
.654 .752 .922 r
.66218 .60042 m .66703 .59261 L .67169 .59772 L F
.66218 .60042 m .6575 .59532 L .66703 .59261 L F
.655 .753 .922 r
.48246 .60031 m .48643 .59249 L .49166 .59759 L F
.48246 .60031 m .4772 .59522 L .48643 .59249 L F
.654 .752 .922 r
.68584 .60012 m .6908 .59232 L .69539 .59743 L F
.68584 .60012 m .68123 .59502 L .6908 .59232 L F
.655 .753 .922 r
.50608 .59997 m .51016 .59215 L .51532 .59726 L F
.50608 .59997 m .5009 .59487 L .51016 .59215 L F
.653 .769 .934 r
.30268 .60088 m .30575 .59349 L .31158 .59818 L F
.30268 .60088 m .29682 .59622 L .30575 .59349 L F
.654 .762 .929 r
.32628 .60031 m .32948 .59274 L .33522 .5976 L F
.32628 .60031 m .32051 .59546 L .32948 .59274 L F
.654 .752 .922 r
.7095 .59983 m .71459 .59203 L .7191 .59714 L F
.7095 .59983 m .70497 .59473 L .71459 .59203 L F
.655 .753 .922 r
.52971 .59964 m .53391 .59181 L .53899 .59692 L F
.52971 .59964 m .5246 .59454 L .53391 .59181 L F
.654 .758 .926 r
.34988 .59983 m .3532 .59216 L .35887 .59712 L F
.34988 .59983 m .3442 .59489 L .3532 .59216 L F
.655 .752 .922 r
.55334 .59931 m .55766 .59148 L .56267 .59659 L F
.55334 .59931 m .54831 .5942 L .55766 .59148 L F
.653 .752 .922 r
.73318 .59954 m .73839 .59176 L .74282 .59686 L F
.73318 .59954 m .72873 .59445 L .73839 .59176 L F
.654 .756 .925 r
.37349 .59941 m .37693 .59168 L .38252 .5967 L F
.37349 .59941 m .36788 .59441 L .37693 .59168 L F
.655 .752 .922 r
.57699 .59898 m .58143 .59115 L .58637 .59627 L F
.57699 .59898 m .57204 .59387 L .58143 .59115 L F
.655 .755 .924 r
.39711 .59902 m .40066 .59125 L .40618 .5963 L F
.39711 .59902 m .39158 .59398 L .40066 .59125 L F
.655 .752 .922 r
.60065 .59866 m .6052 .59083 L .61007 .59595 L F
.60065 .59866 m .59577 .59355 L .6052 .59083 L F
.655 .754 .923 r
.42073 .59865 m .42441 .59085 L .42984 .59593 L F
.42073 .59865 m .41528 .59358 L .42441 .59085 L F
.654 .752 .922 r
.62432 .59834 m .62899 .59051 L .63378 .59563 L F
.62432 .59834 m .61951 .59323 L .62899 .59051 L F
.655 .754 .922 r
.44437 .59829 m .44816 .59047 L .45352 .59557 L F
.44437 .59829 m .43898 .59321 L .44816 .59047 L F
.654 .752 .922 r
.648 .59803 m .65279 .5902 L .6575 .59532 L F
.648 .59803 m .64327 .59292 L .65279 .5902 L F
.655 .753 .922 r
.46801 .59794 m .47191 .59011 L .4772 .59522 L F
.46801 .59794 m .4627 .59284 L .47191 .59011 L F
.654 .752 .922 r
.67169 .59772 m .67659 .5899 L .68123 .59502 L F
.67169 .59772 m .66703 .59261 L .67659 .5899 L F
.655 .753 .922 r
.49166 .59759 m .49568 .58976 L .5009 .59487 L F
.49166 .59759 m .48643 .59249 L .49568 .58976 L F
.654 .752 .922 r
.69539 .59743 m .70041 .58961 L .70497 .59473 L F
.69539 .59743 m .6908 .59232 L .70041 .58961 L F
.655 .753 .922 r
.51532 .59726 m .51946 .58941 L .5246 .59454 L F
.51532 .59726 m .51016 .59215 L .51946 .58941 L F
.653 .769 .934 r
.31158 .59818 m .3147 .59076 L .32051 .59546 L F
.31158 .59818 m .30575 .59349 L .3147 .59076 L F
.654 .762 .929 r
.33522 .5976 m .33847 .59001 L .3442 .59489 L F
.33522 .5976 m .32948 .59274 L .33847 .59001 L F
.655 .753 .922 r
.53899 .59692 m .54325 .58907 L .54831 .5942 L F
.53899 .59692 m .53391 .59181 L .54325 .58907 L F
.653 .752 .922 r
.7191 .59714 m .72424 .58933 L .72873 .59445 L F
.7191 .59714 m .71459 .59203 L .72424 .58933 L F
.654 .758 .926 r
.35887 .59712 m .36224 .58943 L .36788 .59441 L F
.35887 .59712 m .3532 .59216 L .36224 .58943 L F
.655 .753 .922 r
.56267 .59659 m .56705 .58874 L .57204 .59387 L F
.56267 .59659 m .55766 .59148 L .56705 .58874 L F
.653 .752 .923 r
.74282 .59686 m .74808 .58906 L .75249 .59418 L F
.74282 .59686 m .73839 .59176 L .74808 .58906 L F
.654 .756 .925 r
.38252 .5967 m .38601 .58894 L .39158 .59398 L F
.38252 .5967 m .37693 .59168 L .38601 .58894 L F
.655 .752 .922 r
.58637 .59627 m .59086 .58842 L .59577 .59355 L F
.58637 .59627 m .58143 .59115 L .59086 .58842 L F
.654 .755 .924 r
.40618 .5963 m .40978 .58851 L .41528 .59358 L F
.40618 .5963 m .40066 .59125 L .40978 .58851 L F
.654 .752 .922 r
.61007 .59595 m .61467 .58809 L .61951 .59323 L F
.61007 .59595 m .6052 .59083 L .61467 .58809 L F
.655 .754 .923 r
.42984 .59593 m .43357 .58811 L .43898 .59321 L F
.42984 .59593 m .42441 .59085 L .43357 .58811 L F
.654 .752 .922 r
.63378 .59563 m .6385 .58778 L .64327 .59292 L F
.63378 .59563 m .62899 .59051 L .6385 .58778 L F
.655 .754 .923 r
.45352 .59557 m .45736 .58773 L .4627 .59284 L F
.45352 .59557 m .44816 .59047 L .45736 .58773 L F
.654 .752 .922 r
.6575 .59532 m .66234 .58747 L .66703 .59261 L F
.6575 .59532 m .65279 .5902 L .66234 .58747 L F
.655 .753 .922 r
.4772 .59522 m .48116 .58737 L .48643 .59249 L F
.4772 .59522 m .47191 .59011 L .48116 .58737 L F
.654 .752 .922 r
.68123 .59502 m .68619 .58718 L .6908 .59232 L F
.68123 .59502 m .67659 .5899 L .68619 .58718 L F
.655 .753 .922 r
.5009 .59487 m .50497 .58702 L .51016 .59215 L F
.5009 .59487 m .49568 .58976 L .50497 .58702 L F
.652 .783 .944 r
.29682 .59622 m .29985 .58911 L .30575 .59349 L F
.29682 .59622 m .29091 .59186 L .29985 .58911 L F
.653 .752 .922 r
.70497 .59473 m .71005 .58689 L .71459 .59203 L F
.70497 .59473 m .70041 .58961 L .71005 .58689 L F
.655 .753 .922 r
.5246 .59454 m .52879 .58667 L .53391 .59181 L F
.5246 .59454 m .51946 .58941 L .52879 .58667 L F
.653 .769 .934 r
.32051 .59546 m .32368 .58802 L .32948 .59274 L F
.32051 .59546 m .3147 .59076 L .32368 .58802 L F
.654 .762 .929 r
.3442 .59489 m .34749 .58727 L .3532 .59216 L F
.3442 .59489 m .33847 .59001 L .34749 .58727 L F
.655 .753 .922 r
.54831 .5942 m .55262 .58633 L .55766 .59148 L F
.54831 .5942 m .54325 .58907 L .55262 .58633 L F
.653 .752 .923 r
.72873 .59445 m .73392 .58662 L .73839 .59176 L F
.72873 .59445 m .72424 .58933 L .73392 .58662 L F
.654 .759 .926 r
.36788 .59441 m .3713 .58669 L .37693 .59168 L F
.36788 .59441 m .36224 .58943 L .3713 .58669 L F
.654 .753 .922 r
.57204 .59387 m .57646 .586 L .58143 .59115 L F
.57204 .59387 m .56705 .58874 L .57646 .586 L F
.652 .752 .923 r
.75249 .59418 m .75781 .58637 L .76219 .5915 L F
.75249 .59418 m .74808 .58906 L .75781 .58637 L F
.654 .756 .925 r
.39158 .59398 m .39511 .5862 L .40066 .59125 L F
.39158 .59398 m .38601 .58894 L .39511 .5862 L F
.654 .753 .922 r
.59577 .59355 m .60031 .58568 L .6052 .59083 L F
.59577 .59355 m .59086 .58842 L .60031 .58568 L F
.654 .755 .924 r
.41528 .59358 m .41893 .58577 L .42441 .59085 L F
.41528 .59358 m .40978 .58851 L .41893 .58577 L F
.654 .752 .922 r
.61951 .59323 m .62417 .58536 L .62899 .59051 L F
.61951 .59323 m .61467 .58809 L .62417 .58536 L F
.654 .754 .923 r
.43898 .59321 m .44276 .58537 L .44816 .59047 L F
.43898 .59321 m .43357 .58811 L .44276 .58537 L F
.654 .752 .922 r
.64327 .59292 m .64804 .58505 L .65279 .5902 L F
.64327 .59292 m .6385 .58778 L .64804 .58505 L F
.655 .754 .923 r
.4627 .59284 m .46659 .58499 L .47191 .59011 L F
.4627 .59284 m .45736 .58773 L .46659 .58499 L F
.654 .752 .922 r
.66703 .59261 m .67193 .58475 L .67659 .5899 L F
.66703 .59261 m .66234 .58747 L .67193 .58475 L F
.655 .753 .922 r
.48643 .59249 m .49044 .58462 L .49568 .58976 L F
.48643 .59249 m .48116 .58737 L .49044 .58462 L F
.653 .752 .922 r
.6908 .59232 m .69582 .58445 L .70041 .58961 L F
.6908 .59232 m .68619 .58718 L .69582 .58445 L F
.655 .753 .922 r
.51016 .59215 m .51429 .58427 L .51946 .58941 L F
.51016 .59215 m .50497 .58702 L .51429 .58427 L F
.652 .782 .944 r
.30575 .59349 m .30882 .58635 L .3147 .59076 L F
.30575 .59349 m .29985 .58911 L .30882 .58635 L F
.654 .753 .922 r
.53391 .59181 m .53815 .58392 L .54325 .58907 L F
.53391 .59181 m .52879 .58667 L .53815 .58392 L F
.653 .752 .923 r
.71459 .59203 m .71972 .58418 L .72424 .58933 L F
.71459 .59203 m .71005 .58689 L .71972 .58418 L F
.653 .769 .934 r
.32948 .59274 m .33269 .58527 L .33847 .59001 L F
.32948 .59274 m .32368 .58802 L .33269 .58527 L F
.654 .762 .929 r
.3532 .59216 m .35655 .58452 L .36224 .58943 L F
.3532 .59216 m .34749 .58727 L .35655 .58452 L F
.654 .753 .922 r
.55766 .59148 m .56203 .58358 L .56705 .58874 L F
.55766 .59148 m .55262 .58633 L .56203 .58358 L F
.653 .752 .923 r
.73839 .59176 m .74364 .58392 L .74808 .58906 L F
.73839 .59176 m .73392 .58662 L .74364 .58392 L F
.654 .759 .927 r
.37693 .59168 m .3804 .58394 L .38601 .58894 L F
.37693 .59168 m .3713 .58669 L .3804 .58394 L F
.654 .753 .922 r
.58143 .59115 m .58591 .58325 L .59086 .58842 L F
.58143 .59115 m .57646 .586 L .58591 .58325 L F
.652 .752 .923 r
.76219 .5915 m .76757 .58368 L .77193 .58882 L F
.76219 .5915 m .75781 .58637 L .76757 .58368 L F
.654 .757 .925 r
.40066 .59125 m .40425 .58345 L .40978 .58851 L F
.40066 .59125 m .39511 .5862 L .40425 .58345 L F
.654 .753 .922 r
.6052 .59083 m .6098 .58293 L .61467 .58809 L F
.6052 .59083 m .60031 .58568 L .6098 .58293 L F
.654 .755 .924 r
.42441 .59085 m .42811 .58302 L .43357 .58811 L F
.42441 .59085 m .41893 .58577 L .42811 .58302 L F
.654 .753 .922 r
.62899 .59051 m .63371 .58262 L .6385 .58778 L F
.62899 .59051 m .62417 .58536 L .63371 .58262 L F
.654 .754 .923 r
.44816 .59047 m .45198 .58261 L .45736 .58773 L F
.44816 .59047 m .44276 .58537 L .45198 .58261 L F
.654 .753 .922 r
.65279 .5902 m .65762 .58231 L .66234 .58747 L F
.65279 .5902 m .64804 .58505 L .65762 .58231 L F
.654 .754 .923 r
.47191 .59011 m .47586 .58223 L .48116 .58737 L F
.47191 .59011 m .46659 .58499 L .47586 .58223 L F
.654 .753 .922 r
.67659 .5899 m .68155 .58201 L .68619 .58718 L F
.67659 .5899 m .67193 .58475 L .68155 .58201 L F
.654 .753 .923 r
.49568 .58976 m .49975 .58187 L .50497 .58702 L F
.49568 .58976 m .49044 .58462 L .49975 .58187 L F
.653 .753 .923 r
.70041 .58961 m .70548 .58173 L .71005 .58689 L F
.70041 .58961 m .69582 .58445 L .70548 .58173 L F
.654 .753 .922 r
.51946 .58941 m .52364 .58151 L .52879 .58667 L F
.51946 .58941 m .51429 .58427 L .52364 .58151 L F
.652 .782 .943 r
.3147 .59076 m .31783 .58358 L .32368 .58802 L F
.3147 .59076 m .30882 .58635 L .31783 .58358 L F
.648 .811 .962 r
.29091 .59186 m .29387 .58534 L .29985 .58911 L F
.29091 .59186 m .2849 .58815 L .29387 .58534 L F
.654 .753 .922 r
.54325 .58907 m .54755 .58117 L .55262 .58633 L F
.54325 .58907 m .53815 .58392 L .54755 .58117 L F
.653 .753 .923 r
.72424 .58933 m .72943 .58146 L .73392 .58662 L F
.72424 .58933 m .71972 .58418 L .72943 .58146 L F
.653 .769 .934 r
.33847 .59001 m .34174 .58251 L .34749 .58727 L F
.33847 .59001 m .33269 .58527 L .34174 .58251 L F
.654 .762 .929 r
.36224 .58943 m .36563 .58177 L .3713 .58669 L F
.36224 .58943 m .35655 .58452 L .36563 .58177 L F
.654 .753 .922 r
.56705 .58874 m .57146 .58083 L .57646 .586 L F
.56705 .58874 m .56203 .58358 L .57146 .58083 L F
.652 .753 .923 r
.74808 .58906 m .75339 .58121 L .75781 .58637 L F
.74808 .58906 m .74364 .58392 L .75339 .58121 L F
.654 .759 .927 r
.38601 .58894 m .38952 .58118 L .39511 .5862 L F
.38601 .58894 m .3804 .58394 L .38952 .58118 L F
.654 .753 .922 r
.59086 .58842 m .59539 .5805 L .60031 .58568 L F
.59086 .58842 m .58591 .58325 L .59539 .5805 L F
.651 .753 .924 r
.77193 .58882 m .77737 .58099 L .7817 .58614 L F
.77193 .58882 m .76757 .58368 L .77737 .58099 L F
.654 .757 .925 r
.40978 .58851 m .41342 .58069 L .41893 .58577 L F
.40978 .58851 m .40425 .58345 L .41342 .58069 L F
.654 .753 .922 r
.61467 .58809 m .61933 .58018 L .62417 .58536 L F
.61467 .58809 m .6098 .58293 L .61933 .58018 L F
.654 .755 .924 r
.43357 .58811 m .43733 .58026 L .44276 .58537 L F
.43357 .58811 m .42811 .58302 L .43733 .58026 L F
.654 .753 .922 r
.6385 .58778 m .64327 .57987 L .64804 .58505 L F
.6385 .58778 m .63371 .58262 L .64327 .57987 L F
.654 .755 .923 r
.45736 .58773 m .46124 .57985 L .46659 .58499 L F
.45736 .58773 m .45198 .58261 L .46124 .57985 L F
.625 .869 .988 r
.2849 .58815 m .27874 .58586 L .28775 .58292 L F
.401 .856 .832 r
.27874 .58586 m .28134 .58373 L .28775 .58292 L F
.44 .878 .871 r
.28775 .58292 m .28134 .58373 L .29043 .58042 L F
.625 .869 .988 r
.2849 .58815 m .28775 .58292 L .29387 .58534 L F
.628 .865 .987 r
.29387 .58534 m .28775 .58292 L .29678 .57998 L F
.44 .878 .871 r
.28775 .58292 m .29043 .58042 L .29678 .57998 L F
.227 0 .042 r
.28134 .58373 m .28345 .58903 L .29043 .58042 L F
.28134 .58373 m .27422 .59351 L .28345 .58903 L F
.186 0 0 r
.29043 .58042 m .28345 .58903 L .2927 .58466 L F
.428 .167 .413 r
.27422 .59351 m .27434 .62563 L .28345 .58903 L F
.419 .151 .398 r
.28345 .58903 m .28402 .61696 L .2927 .58466 L F
.28345 .58903 m .27434 .62563 L .28402 .61696 L F
.458 .239 .493 r
.2782 .66834 m .28402 .61696 L .27434 .62563 L F
.543 .322 .53 r
.28015 .64871 m .29599 .42412 L .2903 .41831 L F
.654 .753 .922 r
.66234 .58747 m .66723 .57957 L .67193 .58475 L F
.66234 .58747 m .65762 .58231 L .66723 .57957 L F
.654 .754 .923 r
.48116 .58737 m .48516 .57947 L .49044 .58462 L F
.48116 .58737 m .47586 .58223 L .48516 .57947 L F
.653 .753 .923 r
.68619 .58718 m .6912 .57928 L .69582 .58445 L F
.68619 .58718 m .68155 .58201 L .6912 .57928 L F
.654 .754 .923 r
.50497 .58702 m .50909 .5791 L .51429 .58427 L F
.50497 .58702 m .49975 .58187 L .50909 .5791 L F
.654 .753 .923 r
.52879 .58667 m .53302 .57875 L .53815 .58392 L F
.52879 .58667 m .52364 .58151 L .53302 .57875 L F
.653 .753 .923 r
.71005 .58689 m .71518 .579 L .71972 .58418 L F
.71005 .58689 m .70548 .58173 L .71518 .579 L F
.652 .781 .943 r
.32368 .58802 m .32686 .5808 L .33269 .58527 L F
.32368 .58802 m .31783 .58358 L .32686 .5808 L F
.648 .809 .961 r
.29985 .58911 m .30286 .58253 L .30882 .58635 L F
.29985 .58911 m .29387 .58534 L .30286 .58253 L F
.654 .753 .922 r
.55262 .58633 m .55697 .5784 L .56203 .58358 L F
.55262 .58633 m .54755 .58117 L .55697 .5784 L F
.652 .753 .923 r
.73392 .58662 m .73917 .57874 L .74364 .58392 L F
.73392 .58662 m .72943 .58146 L .73917 .57874 L F
.653 .769 .934 r
.34749 .58727 m .35081 .57975 L .35655 .58452 L F
.34749 .58727 m .34174 .58251 L .35081 .57975 L F
.653 .762 .93 r
.3713 .58669 m .37475 .579 L .3804 .58394 L F
.3713 .58669 m .36563 .58177 L .37475 .579 L F
.654 .753 .922 r
.57646 .586 m .58093 .57807 L .58591 .58325 L F
.57646 .586 m .57146 .58083 L .58093 .57807 L F
.652 .753 .924 r
.75781 .58637 m .76318 .57851 L .76757 .58368 L F
.75781 .58637 m .75339 .58121 L .76318 .57851 L F
.654 .759 .927 r
.39511 .5862 m .39868 .57842 L .40425 .58345 L F
.39511 .5862 m .38952 .58118 L .39868 .57842 L F
.654 .753 .922 r
.60031 .58568 m .6049 .57774 L .6098 .58293 L F
.60031 .58568 m .59539 .5805 L .6049 .57774 L F
.651 .753 .924 r
.7817 .58614 m .7872 .57831 L .79151 .58347 L F
.7817 .58614 m .77737 .58099 L .7872 .57831 L F
.654 .757 .925 r
.41893 .58577 m .42262 .57793 L .42811 .58302 L F
.41893 .58577 m .41342 .58069 L .42262 .57793 L F
.654 .753 .922 r
.62417 .58536 m .62888 .57742 L .63371 .58262 L F
.62417 .58536 m .61933 .58018 L .62888 .57742 L F
.654 .756 .924 r
.44276 .58537 m .44657 .57749 L .45198 .58261 L F
.44276 .58537 m .43733 .58026 L .44657 .57749 L F
.654 .753 .923 r
.64804 .58505 m .65287 .57712 L .65762 .58231 L F
.64804 .58505 m .64327 .57987 L .65287 .57712 L F
.654 .755 .924 r
.46659 .58499 m .47052 .57708 L .47586 .58223 L F
.46659 .58499 m .46124 .57985 L .47052 .57708 L F
.653 .753 .923 r
.67193 .58475 m .67687 .57682 L .68155 .58201 L F
.67193 .58475 m .66723 .57957 L .67687 .57682 L F
.654 .754 .923 r
.49044 .58462 m .49449 .5767 L .49975 .58187 L F
.49044 .58462 m .48516 .57947 L .49449 .5767 L F
.653 .753 .923 r
.69582 .58445 m .70089 .57654 L .70548 .58173 L F
.69582 .58445 m .6912 .57928 L .70089 .57654 L F
.654 .754 .923 r
.51429 .58427 m .51846 .57633 L .52364 .58151 L F
.51429 .58427 m .50909 .5791 L .51846 .57633 L F
.654 .753 .923 r
.53815 .58392 m .54244 .57598 L .54755 .58117 L F
.53815 .58392 m .53302 .57875 L .54244 .57598 L F
.652 .753 .923 r
.71972 .58418 m .72491 .57627 L .72943 .58146 L F
.71972 .58418 m .71518 .579 L .72491 .57627 L F
.652 .781 .943 r
.33269 .58527 m .33593 .57802 L .34174 .58251 L F
.33269 .58527 m .32686 .5808 L .33593 .57802 L F
.648 .808 .96 r
.30882 .58635 m .31189 .5797 L .31783 .58358 L F
.30882 .58635 m .30286 .58253 L .31189 .5797 L F
.654 .753 .923 r
.56203 .58358 m .56643 .57564 L .57146 .58083 L F
.56203 .58358 m .55697 .5784 L .56643 .57564 L F
.653 .769 .934 r
.35655 .58452 m .35992 .57697 L .36563 .58177 L F
.35655 .58452 m .35081 .57975 L .35992 .57697 L F
.652 .753 .924 r
.74364 .58392 m .74895 .57603 L .75339 .58121 L F
.74364 .58392 m .73917 .57874 L .74895 .57603 L F
.653 .763 .93 r
.3804 .58394 m .3839 .57623 L .38952 .58118 L F
.3804 .58394 m .37475 .579 L .3839 .57623 L F
.654 .753 .923 r
.58591 .58325 m .59043 .5753 L .59539 .5805 L F
.58591 .58325 m .58093 .57807 L .59043 .5753 L F
.651 .753 .924 r
.76757 .58368 m .773 .57581 L .77737 .58099 L F
.76757 .58368 m .76318 .57851 L .773 .57581 L F
.654 .759 .927 r
.40425 .58345 m .40787 .57565 L .41342 .58069 L F
.40425 .58345 m .39868 .57842 L .40787 .57565 L F
.543 .322 .53 r
.28808 .41907 m .28022 .5576 L .2903 .41831 L F
.629 .39 .536 r
.28376 .41435 m .28022 .5576 L .28808 .41907 L F
.654 .753 .923 r
.6098 .58293 m .61445 .57498 L .61933 .58018 L F
.6098 .58293 m .6049 .57774 L .61445 .57498 L F
.654 .757 .925 r
.42811 .58302 m .43186 .57515 L .43733 .58026 L F
.42811 .58302 m .42262 .57793 L .43186 .57515 L F
.65 .753 .925 r
.79151 .58347 m .79706 .57563 L .80135 .5808 L F
.79151 .58347 m .7872 .57831 L .79706 .57563 L F
.654 .753 .923 r
.63371 .58262 m .63847 .57466 L .64327 .57987 L F
.63371 .58262 m .62888 .57742 L .63847 .57466 L F
.654 .756 .924 r
.45198 .58261 m .45584 .57471 L .46124 .57985 L F
.45198 .58261 m .44657 .57749 L .45584 .57471 L F
.401 .856 .832 r
.27874 .58586 m .27228 .58705 L .28134 .58373 L F
.262 0 .099 r
.27228 .58705 m .27422 .59351 L .28134 .58373 L F
.543 .322 .53 r
.28015 .64871 m .2903 .41831 L .28022 .5576 L F
.653 .753 .923 r
.65762 .58231 m .6625 .57436 L .66723 .57957 L F
.65762 .58231 m .65287 .57712 L .6625 .57436 L F
.654 .755 .924 r
.47586 .58223 m .47984 .57431 L .48516 .57947 L F
.47586 .58223 m .47052 .57708 L .47984 .57431 L F
.653 .753 .923 r
.68155 .58201 m .68655 .57407 L .6912 .57928 L F
.68155 .58201 m .67687 .57682 L .68655 .57407 L F
.654 .754 .923 r
.49975 .58187 m .50385 .57392 L .50909 .5791 L F
.49975 .58187 m .49449 .5767 L .50385 .57392 L F
.52364 .58151 m .52786 .57356 L .53302 .57875 L F
.52364 .58151 m .51846 .57633 L .52786 .57356 L F
.653 .753 .923 r
.70548 .58173 m .71061 .5738 L .71518 .579 L F
.70548 .58173 m .70089 .57654 L .71061 .5738 L F
.654 .753 .923 r
.54755 .58117 m .55189 .5732 L .55697 .5784 L F
.54755 .58117 m .54244 .57598 L .55189 .5732 L F
.652 .753 .924 r
.72943 .58146 m .73468 .57354 L .73917 .57874 L F
.72943 .58146 m .72491 .57627 L .73468 .57354 L F
.55 .301 .491 r
.22823 .41689 m .23517 .42897 L .23614 .41463 L F
.22823 .41689 m .22688 .42511 L .23517 .42897 L F
.652 .781 .942 r
.34174 .58251 m .34502 .57522 L .35081 .57975 L F
.34174 .58251 m .33593 .57802 L .34502 .57522 L F
.648 .806 .959 r
.31783 .58358 m .32095 .57687 L .32686 .5808 L F
.31783 .58358 m .31189 .5797 L .32095 .57687 L F
.654 .753 .923 r
.57146 .58083 m .57592 .57286 L .58093 .57807 L F
.57146 .58083 m .56643 .57564 L .57592 .57286 L F
.653 .769 .934 r
.36563 .58177 m .36905 .57419 L .37475 .579 L F
.36563 .58177 m .35992 .57697 L .36905 .57419 L F
.651 .753 .924 r
.75339 .58121 m .75876 .57332 L .76318 .57851 L F
.75339 .58121 m .74895 .57603 L .75876 .57332 L F
.628 .865 .987 r
.29387 .58534 m .29678 .57998 L .30286 .58253 L F
.653 .763 .93 r
.38952 .58118 m .39307 .57345 L .39868 .57842 L F
.38952 .58118 m .3839 .57623 L .39307 .57345 L F
.654 .753 .923 r
.59539 .5805 m .59997 .57253 L .6049 .57774 L F
.59539 .5805 m .59043 .5753 L .59997 .57253 L F
.65 .753 .925 r
.77737 .58099 m .78286 .57312 L .7872 .57831 L F
.77737 .58099 m .773 .57581 L .78286 .57312 L F
.654 .759 .927 r
.41342 .58069 m .4171 .57287 L .42262 .57793 L F
.41342 .58069 m .40787 .57565 L .4171 .57287 L F
.654 .753 .923 r
.61933 .58018 m .62403 .57221 L .62888 .57742 L F
.61933 .58018 m .61445 .57498 L .62403 .57221 L F
.654 .757 .926 r
.43733 .58026 m .44112 .57237 L .44657 .57749 L F
.43733 .58026 m .43186 .57515 L .44112 .57237 L F
.649 .753 .925 r
.80135 .5808 m .80697 .57297 L .81123 .57814 L F
.80135 .5808 m .79706 .57563 L .80697 .57297 L F
.629 .39 .536 r
.27567 .41553 m .27642 .51949 L .28376 .41435 L F
.725 .449 .509 r
.2755 .41535 m .27642 .51949 L .27567 .41553 L F
.653 .753 .923 r
.64327 .57987 m .64809 .5719 L .65287 .57712 L F
.64327 .57987 m .63847 .57466 L .64809 .5719 L F
.725 .449 .509 r
.2755 .41535 m .27061 .50889 L .27642 .51949 L F
.27508 .41531 m .27061 .50889 L .2755 .41535 L F
.654 .756 .925 r
.46124 .57985 m .46515 .57193 L .47052 .57708 L F
.46124 .57985 m .45584 .57471 L .46515 .57193 L F
.725 .449 .509 r
.27508 .41531 m .265 .46576 L .27061 .50889 L F
.645 .393 .523 r
.26851 .41256 m .265 .46576 L .27508 .41531 L F
.653 .753 .923 r
.66723 .57957 m .67217 .5716 L .67687 .57682 L F
.66723 .57957 m .6625 .57436 L .67217 .5716 L F
.654 .755 .924 r
.48516 .57947 m .48919 .57152 L .49449 .5767 L F
.48516 .57947 m .47984 .57431 L .48919 .57152 L F
.653 .753 .923 r
.6912 .57928 m .69626 .57132 L .70089 .57654 L F
.6912 .57928 m .68655 .57407 L .69626 .57132 L F
.55 .301 .491 r
.23614 .41463 m .23517 .42897 L .23771 .41439 L F
.654 .754 .923 r
.50909 .5791 m .51324 .57114 L .51846 .57633 L F
.50909 .5791 m .50385 .57392 L .51324 .57114 L F
.588 .33 .494 r
.23771 .41439 m .24286 .44052 L .2446 .41296 L F
.23771 .41439 m .23517 .42897 L .24286 .44052 L F
.629 .39 .536 r
.28376 .41435 m .27642 .51949 L .28022 .5576 L F
.654 .754 .923 r
.53302 .57875 m .5373 .57077 L .54244 .57598 L F
.53302 .57875 m .52786 .57356 L .5373 .57077 L F
.652 .753 .924 r
.71518 .579 m .72036 .57106 L .72491 .57627 L F
.71518 .579 m .71061 .5738 L .72036 .57106 L F
.654 .754 .923 r
.55697 .5784 m .56137 .57042 L .56643 .57564 L F
.55697 .5784 m .55189 .5732 L .56137 .57042 L F
.651 .753 .924 r
.73917 .57874 m .74448 .57082 L .74895 .57603 L F
.73917 .57874 m .73468 .57354 L .74448 .57082 L F
.652 .78 .942 r
.35081 .57975 m .35415 .57242 L .35992 .57697 L F
.35081 .57975 m .34502 .57522 L .35415 .57242 L F
.649 .804 .958 r
.32686 .5808 m .33004 .57404 L .33593 .57802 L F
.32686 .5808 m .32095 .57687 L .33004 .57404 L F
.606 .364 .525 r
.25844 .41361 m .25968 .42251 L .26035 .41325 L F
.63 .36 .491 r
.25267 .41249 m .25968 .42251 L .25844 .41361 L F
.654 .753 .923 r
.58093 .57807 m .58545 .57008 L .59043 .5753 L F
.58093 .57807 m .57592 .57286 L .58545 .57008 L F
.653 .769 .934 r
.37475 .579 m .37822 .5714 L .3839 .57623 L F
.37475 .579 m .36905 .57419 L .37822 .5714 L F
.651 .753 .924 r
.76318 .57851 m .76861 .57061 L .773 .57581 L F
.76318 .57851 m .75876 .57332 L .76861 .57061 L F
.645 .393 .523 r
.26089 .41333 m .265 .46576 L .26851 .41256 L F
.26089 .41333 m .25968 .42251 L .265 .46576 L F
.606 .364 .525 r
.26035 .41325 m .25968 .42251 L .26089 .41333 L F
.631 .86 .985 r
.30286 .58253 m .30584 .57703 L .31189 .5797 L F
.30286 .58253 m .29678 .57998 L .30584 .57703 L F
.653 .763 .93 r
.39868 .57842 m .40229 .57066 L .40787 .57565 L F
.39868 .57842 m .39307 .57345 L .40229 .57066 L F
.654 .753 .923 r
.6049 .57774 m .60954 .56975 L .61445 .57498 L F
.6049 .57774 m .59997 .57253 L .60954 .56975 L F
.63 .36 .491 r
.24838 .41298 m .25016 .45793 L .25267 .41249 L F
.24838 .41298 m .24286 .44052 L .25016 .45793 L F
.588 .33 .494 r
.2446 .41296 m .24286 .44052 L .24838 .41298 L F
.649 .753 .925 r
.7872 .57831 m .79275 .57044 L .79706 .57563 L F
.7872 .57831 m .78286 .57312 L .79275 .57044 L F
.653 .759 .927 r
.42262 .57793 m .42635 .57008 L .43186 .57515 L F
.42262 .57793 m .4171 .57287 L .42635 .57008 L F
.653 .753 .923 r
.62888 .57742 m .63364 .56944 L .63847 .57466 L F
.62888 .57742 m .62403 .57221 L .63364 .56944 L F
.654 .757 .926 r
.44657 .57749 m .45042 .56958 L .45584 .57471 L F
.44657 .57749 m .44112 .57237 L .45042 .56958 L F
.63 .36 .491 r
.25267 .41249 m .25016 .45793 L .25968 .42251 L F
.648 .753 .926 r
.81123 .57814 m .81691 .57032 L .82115 .5755 L F
.81123 .57814 m .80697 .57297 L .81691 .57032 L F
.653 .753 .923 r
.65287 .57712 m .65775 .56913 L .6625 .57436 L F
.65287 .57712 m .64809 .5719 L .65775 .56913 L F
.654 .756 .925 r
.47052 .57708 m .47449 .56914 L .47984 .57431 L F
.47052 .57708 m .46515 .57193 L .47449 .56914 L F
.653 .753 .923 r
.67687 .57682 m .68187 .56884 L .68655 .57407 L F
.67687 .57682 m .67217 .5716 L .68187 .56884 L F
.654 .755 .924 r
.49449 .5767 m .49858 .56873 L .50385 .57392 L F
.49449 .5767 m .48919 .57152 L .49858 .56873 L F
.652 .753 .924 r
.70089 .57654 m .70601 .56857 L .71061 .5738 L F
.70089 .57654 m .69626 .57132 L .70601 .56857 L F
.654 .754 .924 r
.51846 .57633 m .52267 .56835 L .52786 .57356 L F
.51846 .57633 m .51324 .57114 L .52267 .56835 L F
.507 .218 .409 r
.22688 .42511 m .22589 .45745 L .23517 .42897 L F
.22688 .42511 m .21707 .45827 L .22589 .45745 L F
.654 .754 .923 r
.54244 .57598 m .54677 .56798 L .55189 .5732 L F
.54244 .57598 m .5373 .57077 L .54677 .56798 L F
.652 .753 .924 r
.72491 .57627 m .73015 .56832 L .73468 .57354 L F
.72491 .57627 m .72036 .57106 L .73015 .56832 L F
.654 .754 .923 r
.56643 .57564 m .57088 .56763 L .57592 .57286 L F
.56643 .57564 m .56137 .57042 L .57088 .56763 L F
.651 .753 .924 r
.74895 .57603 m .75431 .5681 L .75876 .57332 L F
.74895 .57603 m .74448 .57082 L .75431 .5681 L F
.649 .803 .957 r
.33593 .57802 m .33916 .57119 L .34502 .57522 L F
.33593 .57802 m .33004 .57404 L .33916 .57119 L F
.652 .78 .942 r
.35992 .57697 m .36331 .56961 L .36905 .57419 L F
.35992 .57697 m .35415 .57242 L .36331 .56961 L F
.654 .754 .923 r
.59043 .5753 m .59501 .56729 L .59997 .57253 L F
.59043 .5753 m .58545 .57008 L .59501 .56729 L F
.653 .769 .934 r
.3839 .57623 m .38742 .5686 L .39307 .57345 L F
.3839 .57623 m .37822 .5714 L .38742 .5686 L F
.65 .753 .925 r
.773 .57581 m .77849 .56791 L .78286 .57312 L F
.773 .57581 m .76861 .57061 L .77849 .56791 L F
.633 .856 .984 r
.31189 .5797 m .31493 .57408 L .32095 .57687 L F
.31189 .5797 m .30584 .57703 L .31493 .57408 L F
.653 .763 .93 r
.40787 .57565 m .41153 .56787 L .4171 .57287 L F
.40787 .57565 m .40229 .57066 L .41153 .56787 L F
.653 .753 .923 r
.61445 .57498 m .61914 .56697 L .62403 .57221 L F
.61445 .57498 m .60954 .56975 L .61914 .56697 L F
.653 .759 .927 r
.43186 .57515 m .43563 .56729 L .44112 .57237 L F
.43186 .57515 m .42635 .57008 L .43563 .56729 L F
.648 .753 .926 r
.79706 .57563 m .80268 .56777 L .80697 .57297 L F
.79706 .57563 m .79275 .57044 L .80268 .56777 L F
.653 .753 .923 r
.63847 .57466 m .64328 .56666 L .64809 .5719 L F
.63847 .57466 m .63364 .56944 L .64328 .56666 L F
.654 .757 .926 r
.45584 .57471 m .45974 .56679 L .46515 .57193 L F
.45584 .57471 m .45042 .56958 L .45974 .56679 L F
.647 .753 .927 r
.82115 .5755 m .82689 .56768 L .8311 .57287 L F
.82115 .5755 m .81691 .57032 L .82689 .56768 L F
.653 .753 .923 r
.6625 .57436 m .66744 .56636 L .67217 .5716 L F
.6625 .57436 m .65775 .56913 L .66744 .56636 L F
.654 .756 .925 r
.47984 .57431 m .48386 .56634 L .48919 .57152 L F
.47984 .57431 m .47449 .56914 L .48386 .56634 L F
.652 .753 .924 r
.68655 .57407 m .69161 .56608 L .69626 .57132 L F
.68655 .57407 m .68187 .56884 L .69161 .56608 L F
.654 .755 .924 r
.50385 .57392 m .50799 .56594 L .51324 .57114 L F
.50385 .57392 m .49858 .56873 L .50799 .56594 L F
.52786 .57356 m .53213 .56555 L .5373 .57077 L F
.52786 .57356 m .52267 .56835 L .53213 .56555 L F
.652 .753 .924 r
.71061 .5738 m .71578 .56582 L .72036 .57106 L F
.71061 .5738 m .70601 .56857 L .71578 .56582 L F
.654 .754 .924 r
.55189 .5732 m .55627 .56519 L .56137 .57042 L F
.55189 .5732 m .54677 .56798 L .55627 .56519 L F
.651 .753 .924 r
.73468 .57354 m .73998 .56558 L .74448 .57082 L F
.73468 .57354 m .73015 .56832 L .73998 .56558 L F
.653 .754 .923 r
.57592 .57286 m .58043 .56484 L .58545 .57008 L F
.57592 .57286 m .57088 .56763 L .58043 .56484 L F
.687 .397 .477 r
.25968 .42251 m .25731 .47905 L .265 .46576 L F
.25968 .42251 m .25016 .45793 L .25731 .47905 L F
.65 .753 .925 r
.75876 .57332 m .76418 .56538 L .76861 .57061 L F
.75876 .57332 m .75431 .5681 L .76418 .56538 L F
.649 .802 .956 r
.34502 .57522 m .34832 .56834 L .35415 .57242 L F
.34502 .57522 m .33916 .57119 L .34832 .56834 L F
.652 .779 .942 r
.36905 .57419 m .3725 .56679 L .37822 .5714 L F
.36905 .57419 m .36331 .56961 L .3725 .56679 L F
.653 .754 .923 r
.59997 .57253 m .6046 .5645 L .60954 .56975 L F
.59997 .57253 m .59501 .56729 L .6046 .5645 L F
.653 .769 .934 r
.39307 .57345 m .39665 .56579 L .40229 .57066 L F
.39307 .57345 m .38742 .5686 L .39665 .56579 L F
.636 .852 .982 r
.32095 .57687 m .32405 .57112 L .33004 .57404 L F
.32095 .57687 m .31493 .57408 L .32405 .57112 L F
.649 .753 .925 r
.78286 .57312 m .78841 .56522 L .79275 .57044 L F
.78286 .57312 m .77849 .56791 L .78841 .56522 L F
.653 .763 .93 r
.4171 .57287 m .4208 .56507 L .42635 .57008 L F
.4171 .57287 m .41153 .56787 L .4208 .56507 L F
.653 .753 .923 r
.62403 .57221 m .62877 .56418 L .63364 .56944 L F
.62403 .57221 m .61914 .56697 L .62877 .56418 L F
.653 .76 .928 r
.44112 .57237 m .44495 .56448 L .45042 .56958 L F
.44112 .57237 m .43563 .56729 L .44495 .56448 L F
.647 .753 .926 r
.80697 .57297 m .81264 .56511 L .81691 .57032 L F
.80697 .57297 m .80268 .56777 L .81264 .56511 L F
.653 .753 .923 r
.64809 .5719 m .65296 .56388 L .65775 .56913 L F
.64809 .5719 m .64328 .56666 L .65296 .56388 L F
.653 .757 .926 r
.46515 .57193 m .46911 .56398 L .47449 .56914 L F
.46515 .57193 m .45974 .56679 L .46911 .56398 L F
.652 .753 .924 r
.67217 .5716 m .67716 .56359 L .68187 .56884 L F
.67217 .5716 m .66744 .56636 L .67716 .56359 L F
.645 .753 .927 r
.8311 .57287 m .8369 .56507 L .84109 .57026 L F
.8311 .57287 m .82689 .56768 L .8369 .56507 L F
.653 .756 .925 r
.48919 .57152 m .49327 .56354 L .49858 .56873 L F
.48919 .57152 m .48386 .56634 L .49327 .56354 L F
.474 .893 .903 r
.29678 .57998 m .29955 .57713 L .30584 .57703 L F
.29678 .57998 m .29043 .58042 L .29955 .57713 L F
.652 .753 .924 r
.69626 .57132 m .70137 .56332 L .70601 .56857 L F
.69626 .57132 m .69161 .56608 L .70137 .56332 L F
.654 .755 .924 r
.51324 .57114 m .51744 .56313 L .52267 .56835 L F
.51324 .57114 m .50799 .56594 L .51744 .56313 L F
.653 .755 .924 r
.5373 .57077 m .54162 .56275 L .54677 .56798 L F
.5373 .57077 m .53213 .56555 L .54162 .56275 L F
.651 .753 .924 r
.72036 .57106 m .7256 .56307 L .73015 .56832 L F
.72036 .57106 m .71578 .56582 L .7256 .56307 L F
.653 .754 .924 r
.56137 .57042 m .56581 .56239 L .57088 .56763 L F
.56137 .57042 m .55627 .56519 L .56581 .56239 L F
.65 .753 .925 r
.74448 .57082 m .74984 .56285 L .75431 .5681 L F
.74448 .57082 m .73998 .56558 L .74984 .56285 L F
.571 .269 .418 r
.23517 .42897 m .2343 .4617 L .24286 .44052 L F
.23517 .42897 m .22589 .45745 L .2343 .4617 L F
.653 .754 .924 r
.58545 .57008 m .59001 .56204 L .59501 .56729 L F
.58545 .57008 m .58043 .56484 L .59001 .56204 L F
.649 .753 .925 r
.76861 .57061 m .77409 .56267 L .77849 .56791 L F
.76861 .57061 m .76418 .56538 L .77409 .56267 L F
.649 .8 .955 r
.35415 .57242 m .3575 .56548 L .36331 .56961 L F
.35415 .57242 m .34832 .56834 L .3575 .56548 L F
.652 .779 .941 r
.37822 .5714 m .38172 .56397 L .38742 .5686 L F
.37822 .5714 m .3725 .56679 L .38172 .56397 L F
.653 .754 .924 r
.60954 .56975 m .61422 .56171 L .61914 .56697 L F
.60954 .56975 m .6046 .5645 L .61422 .56171 L F
.652 .769 .934 r
.40229 .57066 m .40592 .56298 L .41153 .56787 L F
.40229 .57066 m .39665 .56579 L .40592 .56298 L F
.637 .848 .981 r
.33004 .57404 m .33321 .56817 L .33916 .57119 L F
.33004 .57404 m .32405 .57112 L .33321 .56817 L F
.648 .753 .926 r
.79275 .57044 m .79836 .56254 L .80268 .56777 L F
.79275 .57044 m .78841 .56522 L .79836 .56254 L F
.653 .763 .93 r
.42635 .57008 m .43011 .56225 L .43563 .56729 L F
.42635 .57008 m .4208 .56507 L .43011 .56225 L F
.653 .754 .924 r
.63364 .56944 m .63844 .56139 L .64328 .56666 L F
.63364 .56944 m .62877 .56418 L .63844 .56139 L F
.653 .76 .928 r
.45042 .56958 m .4543 .56167 L .45974 .56679 L F
.45042 .56958 m .44495 .56448 L .4543 .56167 L F
.646 .753 .927 r
.81691 .57032 m .82265 .56247 L .82689 .56768 L F
.81691 .57032 m .81264 .56511 L .82265 .56247 L F
.652 .753 .924 r
.65775 .56913 m .66268 .56109 L .66744 .56636 L F
.65775 .56913 m .65296 .56388 L .66268 .56109 L F
.653 .758 .926 r
.47449 .56914 m .4785 .56117 L .48386 .56634 L F
.47449 .56914 m .46911 .56398 L .4785 .56117 L F
.504 .903 .928 r
.30584 .57703 m .3087 .57386 L .31493 .57408 L F
.30584 .57703 m .29955 .57713 L .3087 .57386 L F
.652 .753 .924 r
.68187 .56884 m .68692 .56081 L .69161 .56608 L F
.68187 .56884 m .67716 .56359 L .68692 .56081 L F
.653 .756 .925 r
.49858 .56873 m .5027 .56073 L .50799 .56594 L F
.49858 .56873 m .49327 .56354 L .5027 .56073 L F
.644 .753 .928 r
.84109 .57026 m .84696 .56248 L .85112 .56767 L F
.84109 .57026 m .8369 .56507 L .84696 .56248 L F
.262 0 .099 r
.27228 .58705 m .265 .5981 L .27422 .59351 L F
.653 .755 .925 r
.52267 .56835 m .52692 .56032 L .53213 .56555 L F
.52267 .56835 m .51744 .56313 L .52692 .56032 L F
.651 .753 .924 r
.70601 .56857 m .71118 .56056 L .71578 .56582 L F
.70601 .56857 m .70137 .56332 L .71118 .56056 L F
.653 .755 .924 r
.54677 .56798 m .55114 .55994 L .55627 .56519 L F
.54677 .56798 m .54162 .56275 L .55114 .55994 L F
.651 .753 .925 r
.73015 .56832 m .73545 .56033 L .73998 .56558 L F
.73015 .56832 m .7256 .56307 L .73545 .56033 L F
.653 .754 .924 r
.57088 .56763 m .57538 .55958 L .58043 .56484 L F
.57088 .56763 m .56581 .56239 L .57538 .55958 L F
.65 .753 .925 r
.75431 .5681 m .75973 .56013 L .76418 .56538 L F
.75431 .5681 m .74984 .56285 L .75973 .56013 L F
.653 .754 .924 r
.59501 .56729 m .59962 .55924 L .6046 .5645 L F
.59501 .56729 m .59001 .56204 L .59962 .55924 L F
.648 .753 .926 r
.77849 .56791 m .78403 .55998 L .78841 .56522 L F
.77849 .56791 m .77409 .56267 L .78403 .55998 L F
.65 .799 .954 r
.36331 .56961 m .36671 .56262 L .3725 .56679 L F
.36331 .56961 m .3575 .56548 L .36671 .56262 L F
.652 .779 .941 r
.38742 .5686 m .39098 .56114 L .39665 .56579 L F
.38742 .5686 m .38172 .56397 L .39098 .56114 L F
.653 .754 .924 r
.61914 .56697 m .62388 .55891 L .62877 .56418 L F
.61914 .56697 m .61422 .56171 L .62388 .55891 L F
.652 .768 .934 r
.41153 .56787 m .41521 .56016 L .4208 .56507 L F
.41153 .56787 m .40592 .56298 L .41521 .56016 L F
.639 .844 .979 r
.33916 .57119 m .34239 .5652 L .34832 .56834 L F
.33916 .57119 m .33321 .56817 L .34239 .5652 L F
.653 .763 .93 r
.43563 .56729 m .43945 .55944 L .44495 .56448 L F
.43563 .56729 m .43011 .56225 L .43945 .55944 L F
.647 .753 .927 r
.80268 .56777 m .80835 .55988 L .81264 .56511 L F
.80268 .56777 m .79836 .56254 L .80835 .55988 L F
.652 .754 .924 r
.64328 .56666 m .64814 .5586 L .65296 .56388 L F
.64328 .56666 m .63844 .56139 L .64814 .5586 L F
.653 .76 .928 r
.45974 .56679 m .46368 .55886 L .46911 .56398 L F
.45974 .56679 m .4543 .56167 L .46368 .55886 L F
.652 .754 .924 r
.66744 .56636 m .67242 .55831 L .67716 .56359 L F
.66744 .56636 m .66268 .56109 L .67242 .55831 L F
.645 .753 .928 r
.82689 .56768 m .83269 .55986 L .8369 .56507 L F
.82689 .56768 m .82265 .56247 L .83269 .55986 L F
.653 .758 .926 r
.48386 .56634 m .48793 .55836 L .49327 .56354 L F
.48386 .56634 m .4785 .56117 L .48793 .55836 L F
.529 .908 .947 r
.31493 .57408 m .31787 .5706 L .32405 .57112 L F
.31493 .57408 m .3087 .57386 L .31787 .5706 L F
.652 .754 .924 r
.69161 .56608 m .69671 .55804 L .70137 .56332 L F
.69161 .56608 m .68692 .56081 L .69671 .55804 L F
.653 .756 .925 r
.50799 .56594 m .51217 .55791 L .51744 .56313 L F
.50799 .56594 m .5027 .56073 L .51217 .55791 L F
.642 .753 .929 r
.85112 .56767 m .85706 .55993 L .86119 .56512 L F
.85112 .56767 m .84696 .56248 L .85706 .55993 L F
.653 .756 .925 r
.53213 .56555 m .53643 .55751 L .54162 .56275 L F
.53213 .56555 m .52692 .56032 L .53643 .55751 L F
.651 .753 .925 r
.71578 .56582 m .72102 .5578 L .7256 .56307 L F
.71578 .56582 m .71118 .56056 L .72102 .5578 L F
.653 .755 .924 r
.55627 .56519 m .5607 .55713 L .56581 .56239 L F
.55627 .56519 m .55114 .55994 L .5607 .55713 L F
.65 .753 .925 r
.73998 .56558 m .74533 .55759 L .74984 .56285 L F
.73998 .56558 m .73545 .56033 L .74533 .55759 L F
.653 .755 .924 r
.58043 .56484 m .58498 .55677 L .59001 .56204 L F
.58043 .56484 m .57538 .55958 L .58498 .55677 L F
.649 .753 .926 r
.76418 .56538 m .76967 .55741 L .77409 .56267 L F
.76418 .56538 m .75973 .56013 L .76967 .55741 L F
.653 .754 .924 r
.6046 .5645 m .60927 .55643 L .61422 .56171 L F
.6046 .5645 m .59962 .55924 L .60927 .55643 L F
.65 .798 .954 r
.3725 .56679 m .37596 .55974 L .38172 .56397 L F
.3725 .56679 m .36671 .56262 L .37596 .55974 L F
.652 .778 .941 r
.39665 .56579 m .40026 .55829 L .40592 .56298 L F
.39665 .56579 m .39098 .56114 L .40026 .55829 L F
.647 .753 .927 r
.78841 .56522 m .79402 .55729 L .79836 .56254 L F
.78841 .56522 m .78403 .55998 L .79402 .55729 L F
.652 .754 .924 r
.62877 .56418 m .63357 .55611 L .63844 .56139 L F
.62877 .56418 m .62388 .55891 L .63357 .55611 L F
.652 .768 .934 r
.4208 .56507 m .42454 .55733 L .43011 .56225 L F
.4208 .56507 m .41521 .56016 L .42454 .55733 L F
.641 .841 .977 r
.34832 .56834 m .3516 .56224 L .3575 .56548 L F
.34832 .56834 m .34239 .5652 L .3516 .56224 L F
.653 .763 .93 r
.44495 .56448 m .44882 .55661 L .4543 .56167 L F
.44495 .56448 m .43945 .55944 L .44882 .55661 L F
.645 .753 .928 r
.81264 .56511 m .81838 .55724 L .82265 .56247 L F
.81264 .56511 m .80835 .55988 L .81838 .55724 L F
.652 .754 .924 r
.65296 .56388 m .65788 .55581 L .66268 .56109 L F
.65296 .56388 m .64814 .5586 L .65788 .55581 L F
.653 .76 .928 r
.46911 .56398 m .4731 .55603 L .4785 .56117 L F
.46911 .56398 m .46368 .55886 L .4731 .55603 L F
.186 0 0 r
.29043 .58042 m .2927 .58466 L .29955 .57713 L F
.652 .754 .924 r
.67716 .56359 m .6822 .55553 L .68692 .56081 L F
.67716 .56359 m .67242 .55831 L .6822 .55553 L F
.653 .758 .927 r
.49327 .56354 m .49738 .55553 L .5027 .56073 L F
.49327 .56354 m .48793 .55836 L .49738 .55553 L F
.643 .753 .929 r
.8369 .56507 m .84278 .55727 L .84696 .56248 L F
.8369 .56507 m .83269 .55986 L .84278 .55727 L F
.55 .91 .962 r
.32405 .57112 m .32707 .56735 L .33321 .56817 L F
.32405 .57112 m .31787 .5706 L .32707 .56735 L F
.651 .754 .925 r
.70137 .56332 m .70654 .55527 L .71118 .56056 L F
.70137 .56332 m .69671 .55804 L .70654 .55527 L F
.653 .757 .926 r
.51744 .56313 m .52168 .55509 L .52692 .56032 L F
.51744 .56313 m .51217 .55791 L .52168 .55509 L F
.64 .753 .93 r
.86119 .56512 m .86719 .55741 L .8713 .5626 L F
.86119 .56512 m .85706 .55993 L .86719 .55741 L F
.653 .756 .925 r
.54162 .56275 m .54598 .55469 L .55114 .55994 L F
.54162 .56275 m .53643 .55751 L .54598 .55469 L F
.65 .754 .925 r
.7256 .56307 m .73089 .55504 L .73545 .56033 L F
.7256 .56307 m .72102 .5578 L .73089 .55504 L F
.653 .755 .925 r
.56581 .56239 m .57029 .55431 L .57538 .55958 L F
.56581 .56239 m .5607 .55713 L .57029 .55431 L F
.649 .753 .926 r
.74984 .56285 m .75525 .55485 L .75973 .56013 L F
.74984 .56285 m .74533 .55759 L .75525 .55485 L F
.653 .755 .924 r
.59001 .56204 m .59462 .55395 L .59962 .55924 L F
.59001 .56204 m .58498 .55677 L .59462 .55395 L F
.648 .753 .926 r
.77409 .56267 m .77964 .55471 L .78403 .55998 L F
.77409 .56267 m .76967 .55741 L .77964 .55471 L F
.652 .754 .924 r
.61422 .56171 m .61895 .55362 L .62388 .55891 L F
.61422 .56171 m .60927 .55643 L .61895 .55362 L F
.65 .796 .953 r
.38172 .56397 m .38524 .55686 L .39098 .56114 L F
.38172 .56397 m .37596 .55974 L .38524 .55686 L F
.652 .778 .941 r
.40592 .56298 m .40958 .55545 L .41521 .56016 L F
.40592 .56298 m .40026 .55829 L .40958 .55545 L F
.646 .753 .927 r
.79836 .56254 m .80403 .55463 L .80835 .55988 L F
.79836 .56254 m .79402 .55729 L .80403 .55463 L F
.652 .754 .924 r
.63844 .56139 m .6433 .5533 L .64814 .5586 L F
.63844 .56139 m .63357 .55611 L .6433 .5533 L F
.652 .768 .934 r
.43011 .56225 m .4339 .55449 L .43945 .55944 L F
.43011 .56225 m .42454 .55733 L .4339 .55449 L F
.642 .837 .975 r
.3575 .56548 m .36085 .55927 L .36671 .56262 L F
.3575 .56548 m .3516 .56224 L .36085 .55927 L F
.653 .763 .93 r
.4543 .56167 m .45822 .55378 L .46368 .55886 L F
.4543 .56167 m .44882 .55661 L .45822 .55378 L F
.652 .754 .925 r
.66268 .56109 m .66765 .55301 L .67242 .55831 L F
.66268 .56109 m .65788 .55581 L .66765 .55301 L F
.644 .753 .928 r
.82265 .56247 m .82845 .55462 L .83269 .55986 L F
.82265 .56247 m .81838 .55724 L .82845 .55462 L F
.138 0 0 r
.29955 .57713 m .30196 .58039 L .3087 .57386 L F
.29955 .57713 m .2927 .58466 L .30196 .58039 L F
.653 .76 .928 r
.4785 .56117 m .48255 .5532 L .48793 .55836 L F
.4785 .56117 m .4731 .55603 L .48255 .5532 L F
.651 .754 .925 r
.68692 .56081 m .69202 .55274 L .69671 .55804 L F
.68692 .56081 m .6822 .55553 L .69202 .55274 L F
.653 .758 .927 r
.5027 .56073 m .50688 .5527 L .51217 .55791 L F
.5027 .56073 m .49738 .55553 L .50688 .5527 L F
.567 .909 .972 r
.33321 .56817 m .3363 .56412 L .34239 .5652 L F
.33321 .56817 m .32707 .56735 L .3363 .56412 L F
.641 .753 .93 r
.84696 .56248 m .8529 .55472 L .85706 .55993 L F
.84696 .56248 m .84278 .55727 L .8529 .55472 L F
.653 .757 .926 r
.52692 .56032 m .53121 .55226 L .53643 .55751 L F
.52692 .56032 m .52168 .55509 L .53121 .55226 L F
.65 .754 .925 r
.71118 .56056 m .7164 .5525 L .72102 .5578 L F
.71118 .56056 m .70654 .55527 L .7164 .5525 L F
.643 .833 .974 r
.36671 .56262 m .37012 .5563 L .37596 .55974 L F
.644 .83 .972 r
.37596 .55974 m .37943 .55332 L .38524 .55686 L F
.37596 .55974 m .37012 .5563 L .37943 .55332 L F
.645 .827 .97 r
.38524 .55686 m .37943 .55332 L .38877 .55034 L F
.612 .891 .989 r
.37012 .5563 m .37351 .55127 L .37943 .55332 L F
.619 .885 .989 r
.37943 .55332 m .38289 .54808 L .38877 .55034 L F
.37943 .55332 m .37351 .55127 L .38289 .54808 L F
.4 .854 .809 r
.37351 .55127 m .37682 .54888 L .38289 .54808 L F
.37351 .55127 m .36738 .55261 L .37682 .54888 L F
.453 .885 .864 r
.38289 .54808 m .37682 .54888 L .38628 .5452 L F
.643 .833 .974 r
.36671 .56262 m .36085 .55927 L .37012 .5563 L F
.604 .897 .988 r
.36085 .55927 m .36416 .55447 L .37012 .5563 L F
.612 .891 .989 r
.37012 .5563 m .36416 .55447 L .37351 .55127 L F
.338 .811 .739 r
.36416 .55447 m .36738 .55261 L .37351 .55127 L F
.209 0 .057 r
.36738 .55261 m .37032 .55776 L .37682 .54888 L F
.625 .879 .989 r
.38877 .55034 m .38289 .54808 L .39229 .54489 L F
.453 .885 .864 r
.38289 .54808 m .38628 .5452 L .39229 .54489 L F
.155 0 0 r
.37682 .54888 m .37991 .55261 L .38628 .5452 L F
.37682 .54888 m .37032 .55776 L .37991 .55261 L F
.392 .129 .391 r
.37032 .55776 m .37235 .58435 L .37991 .55261 L F
.377 .103 .366 r
.37991 .55261 m .37235 .58435 L .3823 .57437 L F
.43 .218 .488 r
.3775 .63149 m .3823 .57437 L .37235 .58435 L F
.3775 .63149 m .37235 .58435 L .37132 .63354 L F
.37132 .63354 m .37235 .58435 L .36836 .63498 L F
.543 .322 .53 r
.37137 .61408 m .38645 .39334 L .3767 .61989 L F
.995 .861 .584 r
.3764 .50137 m .36984 .5085 L .37075 .5055 L F
.543 .322 .53 r
.37921 .49932 m .3815 .38714 L .38645 .39334 L F
.3764 .50137 m .37651 .49888 L .37921 .49932 L F
.37651 .49888 m .3815 .38714 L .37928 .49569 L F
.37651 .49888 m .37928 .49569 L .37921 .49932 L F
.37137 .61408 m .3764 .50137 L .37651 .49888 L F
.37651 .49888 m .37651 .49888 L .3815 .38714 L F
.37137 .61408 m .37651 .49888 L .37651 .49888 L F
.3815 .38714 m .37651 .49888 L .38897 .42761 L F
.37651 .49888 m .3764 .50137 L .37723 .49649 L F
.37651 .49888 m .37723 .49649 L .38897 .42761 L F
.943 .807 .68 r
.37075 .5055 m .37436 .48109 L .38099 .47168 L F
.36984 .5085 m .37024 .50608 L .37075 .5055 L F
.37024 .50608 m .37436 .48109 L .37075 .5055 L F
.995 .861 .584 r
.3764 .50137 m .37075 .5055 L .38099 .47168 L F
.543 .322 .53 r
.37137 .61408 m .3764 .50137 L .37921 .49932 L F
.633 .311 .408 r
.24286 .44052 m .24243 .47018 L .25016 .45793 L F
.24286 .44052 m .2343 .4617 L .24243 .47018 L F
.653 .756 .925 r
.55114 .55994 m .55556 .55186 L .5607 .55713 L F
.55114 .55994 m .54598 .55469 L .55556 .55186 L F
.637 .752 .932 r
.8713 .5626 m .87738 .55495 L .88145 .56013 L F
.8713 .5626 m .86719 .55741 L .87738 .55495 L F
.649 .754 .926 r
.73545 .56033 m .7408 .5523 L .74533 .55759 L F
.73545 .56033 m .73089 .55504 L .7408 .5523 L F
.653 .755 .925 r
.57538 .55958 m .57992 .55148 L .58498 .55677 L F
.57538 .55958 m .57029 .55431 L .57992 .55148 L F
.648 .754 .926 r
.75973 .56013 m .76521 .55213 L .76967 .55741 L F
.75973 .56013 m .75525 .55485 L .76521 .55213 L F
.652 .755 .925 r
.59962 .55924 m .60429 .55113 L .60927 .55643 L F
.59962 .55924 m .59462 .55395 L .60429 .55113 L F
.647 .753 .927 r
.78403 .55998 m .78964 .55202 L .79402 .55729 L F
.78403 .55998 m .77964 .55471 L .78964 .55202 L F
.652 .755 .925 r
.62388 .55891 m .62867 .55081 L .63357 .55611 L F
.62388 .55891 m .61895 .55362 L .62867 .55081 L F
.65 .795 .952 r
.39098 .56114 m .39455 .55397 L .40026 .55829 L F
.39098 .56114 m .38524 .55686 L .39455 .55397 L F
.652 .777 .94 r
.41521 .56016 m .41893 .55259 L .42454 .55733 L F
.41521 .56016 m .40958 .55545 L .41893 .55259 L F
.652 .768 .934 r
.43945 .55944 m .4433 .55165 L .44882 .55661 L F
.43945 .55944 m .4339 .55449 L .4433 .55165 L F
.652 .754 .925 r
.64814 .5586 m .65306 .5505 L .65788 .55581 L F
.64814 .5586 m .6433 .5533 L .65306 .5505 L F
.645 .753 .928 r
.80835 .55988 m .81409 .55198 L .81838 .55724 L F
.80835 .55988 m .80403 .55463 L .81409 .55198 L F
.083 0 0 r
.3087 .57386 m .31124 .5762 L .31787 .5706 L F
.3087 .57386 m .30196 .58039 L .31124 .5762 L F
.652 .763 .931 r
.46368 .55886 m .46766 .55094 L .4731 .55603 L F
.46368 .55886 m .45822 .55378 L .46766 .55094 L F
.651 .754 .925 r
.67242 .55831 m .67746 .55022 L .6822 .55553 L F
.67242 .55831 m .66765 .55301 L .67746 .55022 L F
.653 .76 .928 r
.48793 .55836 m .49203 .55036 L .49738 .55553 L F
.48793 .55836 m .48255 .5532 L .49203 .55036 L F
.642 .753 .929 r
.83269 .55986 m .83856 .55203 L .84278 .55727 L F
.83269 .55986 m .82845 .55462 L .83856 .55203 L F
.582 .907 .98 r
.34239 .5652 m .34556 .56089 L .3516 .56224 L F
.34239 .5652 m .3363 .56412 L .34556 .56089 L F
.651 .754 .925 r
.69671 .55804 m .70187 .54996 L .70654 .55527 L F
.69671 .55804 m .69202 .55274 L .70187 .54996 L F
.653 .758 .927 r
.51217 .55791 m .5164 .54987 L .52168 .55509 L F
.51217 .55791 m .50688 .5527 L .5164 .54987 L F
.639 .753 .931 r
.85706 .55993 m .86307 .5522 L .86719 .55741 L F
.85706 .55993 m .8529 .55472 L .86307 .5522 L F
.653 .757 .926 r
.53643 .55751 m .54078 .54943 L .54598 .55469 L F
.53643 .55751 m .53121 .55226 L .54078 .54943 L F
.65 .754 .926 r
.72102 .5578 m .7263 .54974 L .73089 .55504 L F
.72102 .5578 m .7164 .5525 L .7263 .54974 L F
.652 .756 .926 r
.5607 .55713 m .56518 .54903 L .57029 .55431 L F
.5607 .55713 m .55556 .55186 L .56518 .54903 L F
.649 .754 .926 r
.74533 .55759 m .75075 .54956 L .75525 .55485 L F
.74533 .55759 m .7408 .5523 L .75075 .54956 L F
.634 .752 .933 r
.88145 .56013 m .8876 .55253 L .89165 .55771 L F
.88145 .56013 m .87738 .55495 L .8876 .55253 L F
.652 .755 .925 r
.58498 .55677 m .58958 .54866 L .59462 .55395 L F
.58498 .55677 m .57992 .55148 L .58958 .54866 L F
.647 .754 .927 r
.76967 .55741 m .77521 .54942 L .77964 .55471 L F
.76967 .55741 m .76521 .55213 L .77521 .54942 L F
.652 .755 .925 r
.60927 .55643 m .61399 .54831 L .61895 .55362 L F
.60927 .55643 m .60429 .55113 L .61399 .54831 L F
.645 .753 .928 r
.79402 .55729 m .79969 .54935 L .80403 .55463 L F
.79402 .55729 m .78964 .55202 L .79969 .54935 L F
.652 .755 .925 r
.63357 .55611 m .63842 .54799 L .6433 .5533 L F
.63357 .55611 m .62867 .55081 L .63842 .54799 L F
.65 .794 .951 r
.40026 .55829 m .40389 .55108 L .40958 .55545 L F
.40026 .55829 m .39455 .55397 L .40389 .55108 L F
.651 .777 .94 r
.42454 .55733 m .42832 .54972 L .4339 .55449 L F
.42454 .55733 m .41893 .55259 L .42832 .54972 L F
.022 0 0 r
.31787 .5706 m .32054 .5721 L .32707 .56735 L F
.31787 .5706 m .31124 .5762 L .32054 .5721 L F
.652 .768 .934 r
.44882 .55661 m .45272 .54879 L .45822 .55378 L F
.44882 .55661 m .4433 .55165 L .45272 .54879 L F
.651 .754 .925 r
.65788 .55581 m .66285 .54769 L .66765 .55301 L F
.65788 .55581 m .65306 .5505 L .66285 .54769 L F
.436 .18 .426 r
.265 .5981 m .26461 .63492 L .27422 .59351 L F
.265 .5981 m .25484 .64487 L .26461 .63492 L F
.643 .753 .929 r
.81838 .55724 m .82419 .54936 L .82845 .55462 L F
.81838 .55724 m .81409 .55198 L .82419 .54936 L F
.652 .763 .931 r
.4731 .55603 m .47713 .54809 L .48255 .5532 L F
.4731 .55603 m .46766 .55094 L .47713 .54809 L F
.651 .754 .925 r
.6822 .55553 m .6873 .54742 L .69202 .55274 L F
.6822 .55553 m .67746 .55022 L .6873 .54742 L F
.652 .76 .929 r
.49738 .55553 m .50154 .54752 L .50688 .5527 L F
.49738 .55553 m .49203 .55036 L .50154 .54752 L F
.64 .753 .931 r
.84278 .55727 m .84872 .54948 L .8529 .55472 L F
.84278 .55727 m .83856 .55203 L .84872 .54948 L F
.594 .902 .985 r
.3516 .56224 m .35484 .55767 L .36085 .55927 L F
.3516 .56224 m .34556 .56089 L .35484 .55767 L F
.65 .754 .926 r
.70654 .55527 m .71176 .54718 L .7164 .5525 L F
.70654 .55527 m .70187 .54996 L .71176 .54718 L F
.652 .758 .927 r
.52168 .55509 m .52596 .54703 L .53121 .55226 L F
.52168 .55509 m .5164 .54987 L .52596 .54703 L F
.543 .322 .53 r
.3815 .38714 m .38897 .42761 L .3908 .38397 L F
.652 .757 .926 r
.54598 .55469 m .55039 .54659 L .55556 .55186 L F
.54598 .55469 m .54078 .54943 L .55039 .54659 L F
.649 .754 .926 r
.73089 .55504 m .73624 .54698 L .7408 .5523 L F
.73089 .55504 m .7263 .54974 L .73624 .54698 L F
.636 .752 .932 r
.86719 .55741 m .87328 .54974 L .87738 .55495 L F
.86719 .55741 m .86307 .5522 L .87328 .54974 L F
.652 .756 .926 r
.57029 .55431 m .57482 .54619 L .57992 .55148 L F
.57029 .55431 m .56518 .54903 L .57482 .54619 L F
.648 .754 .927 r
.75525 .55485 m .76073 .54683 L .76521 .55213 L F
.75525 .55485 m .75075 .54956 L .76073 .54683 L F
.652 .756 .925 r
.59462 .55395 m .59927 .54582 L .60429 .55113 L F
.59462 .55395 m .58958 .54866 L .59927 .54582 L F
.63 .752 .935 r
.89165 .55771 m .89787 .55019 L .90189 .55536 L F
.89165 .55771 m .8876 .55253 L .89787 .55019 L F
.646 .754 .928 r
.77964 .55471 m .78524 .54673 L .78964 .55202 L F
.77964 .55471 m .77521 .54942 L .78524 .54673 L F
.428 .167 .413 r
.27422 .59351 m .26461 .63492 L .27434 .62563 L F
.652 .755 .925 r
.61895 .55362 m .62373 .54549 L .62867 .55081 L F
.61895 .55362 m .61399 .54831 L .62373 .54549 L F
.651 .755 .925 r
.6433 .5533 m .6482 .54517 L .65306 .5505 L F
.6433 .5533 m .63842 .54799 L .6482 .54517 L F
.644 .754 .929 r
.80403 .55463 m .80977 .5467 L .81409 .55198 L F
.80403 .55463 m .79969 .54935 L .80977 .5467 L F
0 0 0 r
.32707 .56735 m .32986 .56807 L .3363 .56412 L F
.32707 .56735 m .32054 .5721 L .32986 .56807 L F
.65 .793 .951 r
.40958 .55545 m .41327 .54817 L .41893 .55259 L F
.40958 .55545 m .40389 .55108 L .41327 .54817 L F
.651 .777 .94 r
.4339 .55449 m .43773 .54685 L .4433 .55165 L F
.4339 .55449 m .42832 .54972 L .43773 .54685 L F
.645 .827 .97 r
.38524 .55686 m .38877 .55034 L .39455 .55397 L F
.652 .768 .934 r
.45822 .55378 m .46218 .54594 L .46766 .55094 L F
.45822 .55378 m .45272 .54879 L .46218 .54594 L F
.651 .755 .925 r
.66765 .55301 m .67268 .54489 L .67746 .55022 L F
.66765 .55301 m .66285 .54769 L .67268 .54489 L F
.641 .753 .93 r
.82845 .55462 m .83433 .54677 L .83856 .55203 L F
.82845 .55462 m .82419 .54936 L .83433 .54677 L F
.652 .763 .931 r
.48255 .5532 m .48663 .54524 L .49203 .55036 L F
.48255 .5532 m .47713 .54809 L .48663 .54524 L F
.65 .754 .926 r
.69202 .55274 m .69718 .54463 L .70187 .54996 L F
.69202 .55274 m .6873 .54742 L .69718 .54463 L F
.652 .76 .929 r
.50688 .5527 m .51109 .54467 L .5164 .54987 L F
.50688 .5527 m .50154 .54752 L .51109 .54467 L F
.604 .897 .988 r
.36085 .55927 m .35484 .55767 L .36416 .55447 L F
.638 .753 .932 r
.8529 .55472 m .85891 .54697 L .86307 .5522 L F
.8529 .55472 m .84872 .54948 L .85891 .54697 L F
.652 .758 .927 r
.53121 .55226 m .53555 .54418 L .54078 .54943 L F
.53121 .55226 m .52596 .54703 L .53555 .54418 L F
.649 .754 .926 r
.7164 .5525 m .72169 .54441 L .7263 .54974 L F
.7164 .5525 m .71176 .54718 L .72169 .54441 L F
.543 .322 .53 r
.3908 .38397 m .38897 .42761 L .3908 .38397 L F
.3908 .38397 m .38897 .42761 L .40006 .3808 L F
.374 .001 .196 r
.21707 .45827 m .21799 .46915 L .22589 .45745 L F
.21707 .45827 m .20892 .472 L .21799 .46915 L F
.652 .757 .927 r
.55556 .55186 m .56002 .54374 L .56518 .54903 L F
.55556 .55186 m .55039 .54659 L .56002 .54374 L F
.648 .754 .927 r
.7408 .5523 m .74621 .54423 L .75075 .54956 L F
.7408 .5523 m .73624 .54698 L .74621 .54423 L F
.633 .752 .934 r
.87738 .55495 m .88353 .54734 L .8876 .55253 L F
.87738 .55495 m .87328 .54974 L .88353 .54734 L F
.652 .756 .926 r
.57992 .55148 m .58451 .54335 L .58958 .54866 L F
.57992 .55148 m .57482 .54619 L .58451 .54335 L F
.647 .754 .927 r
.76521 .55213 m .77075 .54411 L .77521 .54942 L F
.76521 .55213 m .76073 .54683 L .77075 .54411 L F
.652 .756 .926 r
.60429 .55113 m .609 .54299 L .61399 .54831 L F
.60429 .55113 m .59927 .54582 L .609 .54299 L F
.626 .751 .937 r
.90189 .55536 m .9082 .54793 L .91218 .55308 L F
.90189 .55536 m .89787 .55019 L .9082 .54793 L F
.645 .754 .928 r
.78964 .55202 m .79531 .54405 L .79969 .54935 L F
.78964 .55202 m .78524 .54673 L .79531 .54405 L F
.651 .755 .926 r
.62867 .55081 m .6335 .54266 L .63842 .54799 L F
.62867 .55081 m .62373 .54549 L .6335 .54266 L F
0 0 0 r
.3363 .56412 m .33921 .56411 L .34556 .56089 L F
.3363 .56412 m .32986 .56807 L .33921 .56411 L F
.651 .755 .926 r
.65306 .5505 m .65802 .54236 L .66285 .54769 L F
.65306 .5505 m .6482 .54517 L .65802 .54236 L F
.65 .792 .95 r
.41893 .55259 m .42268 .54527 L .42832 .54972 L F
.41893 .55259 m .41327 .54817 L .42268 .54527 L F
.642 .753 .93 r
.81409 .55198 m .8199 .54408 L .82419 .54936 L F
.81409 .55198 m .80977 .5467 L .8199 .54408 L F
.651 .776 .94 r
.4433 .55165 m .44718 .54397 L .45272 .54879 L F
.4433 .55165 m .43773 .54685 L .44718 .54397 L F
.646 .824 .968 r
.39455 .55397 m .39814 .54735 L .40389 .55108 L F
.39455 .55397 m .38877 .55034 L .39814 .54735 L F
.652 .768 .934 r
.46766 .55094 m .47168 .54307 L .47713 .54809 L F
.46766 .55094 m .46218 .54594 L .47168 .54307 L F
.65 .755 .926 r
.67746 .55022 m .68255 .54208 L .6873 .54742 L F
.67746 .55022 m .67268 .54489 L .68255 .54208 L F
.652 .763 .931 r
.49203 .55036 m .49617 .54238 L .50154 .54752 L F
.49203 .55036 m .48663 .54524 L .49617 .54238 L F
.639 .753 .931 r
.83856 .55203 m .84451 .54422 L .84872 .54948 L F
.83856 .55203 m .83433 .54677 L .84451 .54422 L F
.649 .754 .926 r
.70187 .54996 m .70709 .54185 L .71176 .54718 L F
.70187 .54996 m .69718 .54463 L .70709 .54185 L F
.409 .133 .38 r
.2927 .58466 m .29366 .60883 L .30196 .58039 L F
.2927 .58466 m .28402 .61696 L .29366 .60883 L F
.652 .76 .929 r
.5164 .54987 m .52067 .54181 L .52596 .54703 L F
.5164 .54987 m .51109 .54467 L .52067 .54181 L F
.652 .759 .928 r
.54078 .54943 m .54518 .54133 L .55039 .54659 L F
.54078 .54943 m .53555 .54418 L .54518 .54133 L F
.648 .754 .927 r
.7263 .54974 m .73165 .54165 L .73624 .54698 L F
.7263 .54974 m .72169 .54441 L .73165 .54165 L F
.635 .753 .933 r
.86307 .5522 m .86915 .54452 L .87328 .54974 L F
.86307 .5522 m .85891 .54697 L .86915 .54452 L F
.112 0 .298 r
.40006 .3808 m .39167 .44233 L .4001 .38075 L F
.40006 .3808 m .38897 .42761 L .39167 .44233 L F
.36 .128 .421 r
.4001 .38075 m .40194 .42084 L .40015 .38072 L F
.4001 .38075 m .39167 .44233 L .40194 .42084 L F
.40015 .38072 m .40194 .42084 L .40768 .37566 L F
.652 .757 .927 r
.56518 .54903 m .5697 .54089 L .57482 .54619 L F
.56518 .54903 m .56002 .54374 L .5697 .54089 L F
.647 .754 .927 r
.75075 .54956 m .75622 .5415 L .76073 .54683 L F
.75075 .54956 m .74621 .54423 L .75622 .5415 L F
.652 .756 .926 r
.58958 .54866 m .59422 .54051 L .59927 .54582 L F
.58958 .54866 m .58451 .54335 L .59422 .54051 L F
.629 .752 .936 r
.8876 .55253 m .89383 .54501 L .89787 .55019 L F
.8876 .55253 m .88353 .54734 L .89383 .54501 L F
.645 .754 .928 r
.77521 .54942 m .78081 .54141 L .78524 .54673 L F
.77521 .54942 m .77075 .54411 L .78081 .54141 L F
.651 .756 .926 r
.61399 .54831 m .61876 .54015 L .62373 .54549 L F
.61399 .54831 m .609 .54299 L .61876 .54015 L F
.493 .104 .23 r
.22589 .45745 m .22677 .46991 L .2343 .4617 L F
.22589 .45745 m .21799 .46915 L .22677 .46991 L F
.651 .755 .926 r
.63842 .54799 m .64331 .53983 L .6482 .54517 L F
.63842 .54799 m .6335 .54266 L .64331 .53983 L F
0 0 0 r
.34556 .56089 m .34857 .56022 L .35484 .55767 L F
.34556 .56089 m .33921 .56411 L .34857 .56022 L F
.643 .754 .929 r
.79969 .54935 m .80542 .5414 L .80977 .5467 L F
.79969 .54935 m .79531 .54405 L .80542 .5414 L F
.621 .75 .939 r
.91218 .55308 m .91857 .54576 L .92253 .55089 L F
.91218 .55308 m .9082 .54793 L .91857 .54576 L F
.65 .755 .926 r
.66285 .54769 m .66787 .53954 L .67268 .54489 L F
.66285 .54769 m .65802 .54236 L .66787 .53954 L F
.65 .79 .949 r
.42832 .54972 m .43212 .54235 L .43773 .54685 L F
.42832 .54972 m .42268 .54527 L .43212 .54235 L F
.397 .112 .36 r
.30196 .58039 m .30328 .60118 L .31124 .5762 L F
.30196 .58039 m .29366 .60883 L .30328 .60118 L F
.651 .776 .94 r
.45272 .54879 m .45666 .54109 L .46218 .54594 L F
.45272 .54879 m .44718 .54397 L .45666 .54109 L F
.647 .821 .967 r
.40389 .55108 m .40755 .54436 L .41327 .54817 L F
.40389 .55108 m .39814 .54735 L .40755 .54436 L F
.64 .753 .931 r
.82419 .54936 m .83006 .54149 L .83433 .54677 L F
.82419 .54936 m .8199 .54408 L .83006 .54149 L F
.652 .768 .934 r
.47713 .54809 m .4812 .5402 L .48663 .54524 L F
.47713 .54809 m .47168 .54307 L .4812 .5402 L F
.706 .351 .371 r
.25016 .45793 m .25038 .48177 L .25731 .47905 L F
.25016 .45793 m .24243 .47018 L .25038 .48177 L F
.65 .755 .926 r
.6873 .54742 m .69245 .53928 L .69718 .54463 L F
.6873 .54742 m .68255 .54208 L .69245 .53928 L F
.784 .452 .427 r
.265 .46576 m .26451 .50158 L .27061 .50889 L F
.265 .46576 m .25731 .47905 L .26451 .50158 L F
.652 .763 .931 r
.50154 .54752 m .50574 .53951 L .51109 .54467 L F
.50154 .54752 m .49617 .54238 L .50574 .53951 L F
.636 .753 .932 r
.84872 .54948 m .85473 .54172 L .85891 .54697 L F
.84872 .54948 m .84451 .54422 L .85473 .54172 L F
.649 .755 .927 r
.71176 .54718 m .71704 .53906 L .72169 .54441 L F
.71176 .54718 m .70709 .54185 L .71704 .53906 L F
.652 .761 .929 r
.52596 .54703 m .53029 .53895 L .53555 .54418 L F
.52596 .54703 m .52067 .54181 L .53029 .53895 L F
.652 .759 .928 r
.55039 .54659 m .55484 .53847 L .56002 .54374 L F
.55039 .54659 m .54518 .54133 L .55484 .53847 L F
.648 .754 .927 r
.73624 .54698 m .74165 .53889 L .74621 .54423 L F
.73624 .54698 m .73165 .54165 L .74165 .53889 L F
.631 .752 .935 r
.87328 .54974 m .87943 .54212 L .88353 .54734 L F
.87328 .54974 m .86915 .54452 L .87943 .54212 L F
.652 .758 .927 r
.57482 .54619 m .5794 .53804 L .58451 .54335 L F
.57482 .54619 m .5697 .54089 L .5794 .53804 L F
.646 .754 .928 r
.76073 .54683 m .76627 .53878 L .77075 .54411 L F
.76073 .54683 m .75622 .5415 L .76627 .53878 L F
.651 .757 .927 r
.59927 .54582 m .60397 .53766 L .609 .54299 L F
.59927 .54582 m .59422 .54051 L .60397 .53766 L F
.644 .754 .929 r
.78524 .54673 m .79091 .53873 L .79531 .54405 L F
.78524 .54673 m .78081 .54141 L .79091 .53873 L F
.651 .756 .926 r
.62373 .54549 m .62856 .53731 L .6335 .54266 L F
.62373 .54549 m .61876 .54015 L .62856 .53731 L F
.624 .751 .938 r
.89787 .55019 m .90419 .54276 L .9082 .54793 L F
.89787 .55019 m .89383 .54501 L .90419 .54276 L F
.382 .088 .335 r
.31124 .5762 m .31287 .59398 L .32054 .5721 L F
.31124 .5762 m .30328 .60118 L .31287 .59398 L F
.269 .754 .657 r
.35484 .55767 m .35796 .55639 L .36416 .55447 L F
.35484 .55767 m .34857 .56022 L .35796 .55639 L F
.65 .756 .926 r
.6482 .54517 m .65316 .537 L .65802 .54236 L F
.6482 .54517 m .64331 .53983 L .65316 .537 L F
.641 .754 .93 r
.80977 .5467 m .81558 .53878 L .8199 .54408 L F
.80977 .5467 m .80542 .5414 L .81558 .53878 L F
.65 .755 .927 r
.67268 .54489 m .67777 .53673 L .68255 .54208 L F
.67268 .54489 m .66787 .53954 L .67777 .53673 L F
.65 .789 .949 r
.43773 .54685 m .44159 .53943 L .44718 .54397 L F
.43773 .54685 m .43212 .54235 L .44159 .53943 L F
.438 .197 .449 r
.40768 .37566 m .41187 .40689 L .41088 .37413 L F
.40768 .37566 m .40194 .42084 L .41187 .40689 L F
.651 .775 .939 r
.46218 .54594 m .46618 .53819 L .47168 .54307 L F
.46218 .54594 m .45666 .54109 L .46618 .53819 L F
.615 .749 .941 r
.92253 .55089 m .929 .54371 L .93292 .54882 L F
.92253 .55089 m .91857 .54576 L .929 .54371 L F
.647 .818 .965 r
.41327 .54817 m .41698 .54137 L .42268 .54527 L F
.41327 .54817 m .40755 .54436 L .41698 .54137 L F
.651 .768 .934 r
.48663 .54524 m .49076 .53732 L .49617 .54238 L F
.48663 .54524 m .4812 .5402 L .49076 .53732 L F
.638 .753 .932 r
.83433 .54677 m .84027 .53895 L .84451 .54422 L F
.83433 .54677 m .83006 .54149 L .84027 .53895 L F
.649 .755 .927 r
.69718 .54463 m .70239 .53649 L .70709 .54185 L F
.69718 .54463 m .69245 .53928 L .70239 .53649 L F
.651 .763 .931 r
.51109 .54467 m .51535 .53664 L .52067 .54181 L F
.51109 .54467 m .50574 .53951 L .51535 .53664 L F
.625 .879 .989 r
.38877 .55034 m .39229 .54489 L .39814 .54735 L F
.651 .761 .929 r
.53555 .54418 m .53994 .53608 L .54518 .54133 L F
.53555 .54418 m .53029 .53895 L .53994 .53608 L F
.648 .755 .927 r
.72169 .54441 m .72703 .53629 L .73165 .54165 L F
.72169 .54441 m .71704 .53906 L .72703 .53629 L F
.633 .753 .934 r
.85891 .54697 m .865 .53927 L .86915 .54452 L F
.85891 .54697 m .85473 .54172 L .865 .53927 L F
.651 .759 .928 r
.56002 .54374 m .56453 .53561 L .5697 .54089 L F
.56002 .54374 m .55484 .53847 L .56453 .53561 L F
.647 .755 .928 r
.74621 .54423 m .75168 .53615 L .75622 .5415 L F
.74621 .54423 m .74165 .53889 L .75168 .53615 L F
.438 .197 .449 r
.41088 .37413 m .41187 .40689 L .41648 .3718 L F
.651 .758 .927 r
.58451 .54335 m .58914 .53519 L .59422 .54051 L F
.58451 .54335 m .5794 .53804 L .58914 .53519 L F
.627 .752 .937 r
.88353 .54734 m .88977 .5398 L .89383 .54501 L F
.88353 .54734 m .87943 .54212 L .88977 .5398 L F
.365 .059 .307 r
.32054 .5721 m .32245 .58717 L .32986 .56807 L F
.32054 .5721 m .31287 .59398 L .32245 .58717 L F
.645 .754 .929 r
.77075 .54411 m .77635 .53607 L .78081 .54141 L F
.77075 .54411 m .76627 .53878 L .77635 .53607 L F
.651 .757 .927 r
.609 .54299 m .61376 .53481 L .61876 .54015 L F
.609 .54299 m .60397 .53766 L .61376 .53481 L F
.65 .756 .927 r
.6335 .54266 m .63839 .53448 L .64331 .53983 L F
.6335 .54266 m .62856 .53731 L .63839 .53448 L F
.338 .811 .739 r
.36416 .55447 m .35796 .55639 L .36738 .55261 L F
.642 .754 .93 r
.79531 .54405 m .80105 .53608 L .80542 .5414 L F
.79531 .54405 m .79091 .53873 L .80105 .53608 L F
.619 .75 .94 r
.9082 .54793 m .91459 .54061 L .91857 .54576 L F
.9082 .54793 m .90419 .54276 L .91459 .54061 L F
.65 .756 .927 r
.65802 .54236 m .66304 .53418 L .66787 .53954 L F
.65802 .54236 m .65316 .537 L .66304 .53418 L F
.639 .754 .931 r
.8199 .54408 m .82577 .53619 L .83006 .54149 L F
.8199 .54408 m .81558 .53878 L .82577 .53619 L F
.65 .788 .948 r
.44718 .54397 m .4511 .5365 L .45666 .54109 L F
.44718 .54397 m .44159 .53943 L .4511 .5365 L F
.649 .755 .927 r
.68255 .54208 m .68769 .53392 L .69245 .53928 L F
.68255 .54208 m .67777 .53673 L .68769 .53392 L F
.651 .775 .939 r
.47168 .54307 m .47573 .53529 L .4812 .5402 L F
.47168 .54307 m .46618 .53819 L .47573 .53529 L F
.648 .815 .964 r
.42268 .54527 m .42645 .53837 L .43212 .54235 L F
.42268 .54527 m .41698 .54137 L .42645 .53837 L F
.651 .768 .934 r
.49617 .54238 m .50036 .53443 L .50574 .53951 L F
.49617 .54238 m .49076 .53732 L .50036 .53443 L F
.588 .17 .217 r
.2343 .4617 m .23532 .47391 L .24243 .47018 L F
.2343 .4617 m .22677 .46991 L .23532 .47391 L F
.648 .755 .927 r
.70709 .54185 m .71236 .5337 L .71704 .53906 L F
.70709 .54185 m .70239 .53649 L .71236 .5337 L F
.635 .753 .933 r
.84451 .54422 m .85052 .53645 L .85473 .54172 L F
.84451 .54422 m .84027 .53895 L .85052 .53645 L F
.607 .748 .944 r
.93292 .54882 m .93949 .54179 L .94338 .54687 L F
.93292 .54882 m .929 .54371 L .93949 .54179 L F
.651 .763 .931 r
.52067 .54181 m .52498 .53376 L .53029 .53895 L F
.52067 .54181 m .51535 .53664 L .52498 .53376 L F
.63 .873 .987 r
.39814 .54735 m .40173 .54171 L .40755 .54436 L F
.39814 .54735 m .39229 .54489 L .40173 .54171 L F
.482 .231 .456 r
.41648 .3718 m .42156 .39972 L .42058 .37019 L F
.41648 .3718 m .41187 .40689 L .42156 .39972 L F
.651 .761 .93 r
.54518 .54133 m .54962 .53321 L .55484 .53847 L F
.54518 .54133 m .53994 .53608 L .54962 .53321 L F
.647 .755 .928 r
.73165 .54165 m .73705 .53353 L .74165 .53889 L F
.73165 .54165 m .72703 .53629 L .73705 .53353 L F
.345 .026 .273 r
.32986 .56807 m .33202 .58071 L .33921 .56411 L F
.32986 .56807 m .32245 .58717 L .33202 .58071 L F
.63 .752 .936 r
.86915 .54452 m .87531 .53689 L .87943 .54212 L F
.86915 .54452 m .865 .53927 L .87531 .53689 L F
.651 .759 .928 r
.5697 .54089 m .57426 .53274 L .5794 .53804 L F
.5697 .54089 m .56453 .53561 L .57426 .53274 L F
.645 .755 .929 r
.75622 .5415 m .76175 .53342 L .76627 .53878 L F
.75622 .5415 m .75168 .53615 L .76175 .53342 L F
.651 .758 .928 r
.59422 .54051 m .59892 .53233 L .60397 .53766 L F
.59422 .54051 m .58914 .53519 L .59892 .53233 L F
.643 .754 .93 r
.78081 .54141 m .78648 .53339 L .79091 .53873 L F
.78081 .54141 m .77635 .53607 L .78648 .53339 L F
.65 .757 .927 r
.61876 .54015 m .62358 .53196 L .62856 .53731 L F
.61876 .54015 m .61376 .53481 L .62358 .53196 L F
.623 .751 .939 r
.89383 .54501 m .90015 .53757 L .90419 .54276 L F
.89383 .54501 m .88977 .5398 L .90015 .53757 L F
.482 .231 .456 r
.42058 .37019 m .42156 .39972 L .42616 .36884 L F
.65 .756 .927 r
.64331 .53983 m .64826 .53164 L .65316 .537 L F
.64331 .53983 m .63839 .53448 L .64826 .53164 L F
.641 .754 .931 r
.80542 .5414 m .81123 .53346 L .81558 .53878 L F
.80542 .5414 m .80105 .53608 L .81123 .53346 L F
.649 .756 .927 r
.66787 .53954 m .67295 .53135 L .67777 .53673 L F
.66787 .53954 m .66304 .53418 L .67295 .53135 L F
.613 .749 .942 r
.91857 .54576 m .92506 .53858 L .929 .54371 L F
.91857 .54576 m .91459 .54061 L .92506 .53858 L F
.637 .753 .933 r
.83006 .54149 m .83601 .53365 L .84027 .53895 L F
.83006 .54149 m .82577 .53619 L .83601 .53365 L F
.65 .787 .947 r
.45666 .54109 m .46064 .53356 L .46618 .53819 L F
.45666 .54109 m .4511 .5365 L .46064 .53356 L F
.648 .755 .928 r
.69245 .53928 m .69766 .53111 L .70239 .53649 L F
.69245 .53928 m .68769 .53392 L .69766 .53111 L F
.651 .775 .939 r
.4812 .5402 m .48531 .53238 L .49076 .53732 L F
.4812 .5402 m .47573 .53529 L .48531 .53238 L F
.648 .812 .962 r
.43212 .54235 m .43595 .53536 L .44159 .53943 L F
.43212 .54235 m .42645 .53837 L .43595 .53536 L F
.651 .768 .934 r
.50574 .53951 m .50998 .53154 L .51535 .53664 L F
.50574 .53951 m .50036 .53443 L .50998 .53154 L F
.518 .252 .452 r
.42616 .36884 m .43109 .39825 L .42971 .36772 L F
.42616 .36884 m .42156 .39972 L .43109 .39825 L F
.647 .755 .928 r
.71704 .53906 m .72238 .53092 L .72703 .53629 L F
.71704 .53906 m .71236 .5337 L .72238 .53092 L F
.32 0 .233 r
.33921 .56411 m .34159 .57457 L .34857 .56022 L F
.33921 .56411 m .33202 .58071 L .34159 .57457 L F
.651 .764 .932 r
.53029 .53895 m .53466 .53088 L .53994 .53608 L F
.53029 .53895 m .52498 .53376 L .53466 .53088 L F
.633 .866 .986 r
.40755 .54436 m .4112 .53854 L .41698 .54137 L F
.40755 .54436 m .40173 .54171 L .4112 .53854 L F
.632 .753 .935 r
.85473 .54172 m .86082 .534 L .865 .53927 L F
.85473 .54172 m .85052 .53645 L .86082 .534 L F
.651 .761 .93 r
.55484 .53847 m .55934 .53034 L .56453 .53561 L F
.55484 .53847 m .54962 .53321 L .55934 .53034 L F
.646 .755 .929 r
.74165 .53889 m .74711 .53078 L .75168 .53615 L F
.74165 .53889 m .73705 .53353 L .74711 .53078 L F
.599 .746 .947 r
.94338 .54687 m .95005 .54003 L .9539 .54508 L F
.94338 .54687 m .93949 .54179 L .95005 .54003 L F
.651 .759 .929 r
.5794 .53804 m .58403 .52987 L .58914 .53519 L F
.5794 .53804 m .57426 .53274 L .58403 .52987 L F
.626 .752 .937 r
.87943 .54212 m .88567 .53458 L .88977 .5398 L F
.87943 .54212 m .87531 .53689 L .88567 .53458 L F
.518 .252 .452 r
.42971 .36772 m .43109 .39825 L .43701 .36711 L F
.644 .755 .929 r
.76627 .53878 m .77187 .53072 L .77635 .53607 L F
.76627 .53878 m .76175 .53342 L .77187 .53072 L F
.65 .758 .928 r
.60397 .53766 m .60873 .52947 L .61376 .53481 L F
.60397 .53766 m .59892 .53233 L .60873 .52947 L F
.65 .757 .928 r
.62856 .53731 m .63344 .52911 L .63839 .53448 L F
.62856 .53731 m .62358 .53196 L .63344 .52911 L F
.554 .267 .434 r
.43701 .36711 m .44054 .40123 L .43821 .36683 L F
.43701 .36711 m .43109 .39825 L .44054 .40123 L F
.642 .754 .931 r
.79091 .53873 m .79665 .53074 L .80105 .53608 L F
.79091 .53873 m .78648 .53339 L .79665 .53074 L F
.543 .322 .53 r
.44037 .36703 m .44689 .3793 L .44725 .36468 L F
.554 .267 .434 r
.43821 .36683 m .44689 .3793 L .44037 .36703 L F
0 0 0 r
.20892 .472 m .21068 .47351 L .21799 .46915 L F
.20892 .472 m .20146 .47736 L .21068 .47351 L F
.554 .267 .434 r
.43821 .36683 m .44054 .40123 L .44689 .3793 L F
.617 .75 .941 r
.90419 .54276 m .91059 .53544 L .91459 .54061 L F
.90419 .54276 m .90015 .53757 L .91059 .53544 L F
.649 .756 .928 r
.65316 .537 m .65817 .5288 L .66304 .53418 L F
.65316 .537 m .64826 .53164 L .65817 .5288 L F
.638 .754 .932 r
.81558 .53878 m .82145 .53087 L .82577 .53619 L F
.81558 .53878 m .81123 .53346 L .82145 .53087 L F
.649 .756 .928 r
.67777 .53673 m .6829 .52853 L .68769 .53392 L F
.67777 .53673 m .67295 .53135 L .6829 .52853 L F
.65 .786 .947 r
.46618 .53819 m .47022 .53062 L .47573 .53529 L F
.46618 .53819 m .46064 .53356 L .47022 .53062 L F
.29 0 .184 r
.34857 .56022 m .35116 .56872 L .35796 .55639 L F
.34857 .56022 m .34159 .57457 L .35116 .56872 L F
.649 .81 .961 r
.44159 .53943 m .44549 .53236 L .4511 .5365 L F
.44159 .53943 m .43595 .53536 L .44549 .53236 L F
.651 .774 .939 r
.49076 .53732 m .49493 .52947 L .50036 .53443 L F
.49076 .53732 m .48531 .53238 L .49493 .52947 L F
.648 .756 .928 r
.70239 .53649 m .70766 .52832 L .71236 .5337 L F
.70239 .53649 m .69766 .53111 L .70766 .52832 L F
.634 .753 .934 r
.84027 .53895 m .84629 .53115 L .85052 .53645 L F
.84027 .53895 m .83601 .53365 L .84629 .53115 L F
.605 .747 .945 r
.929 .54371 m .93558 .53669 L .93949 .54179 L F
.929 .54371 m .92506 .53858 L .93558 .53669 L F
.651 .768 .934 r
.51535 .53664 m .51965 .52864 L .52498 .53376 L F
.51535 .53664 m .50998 .53154 L .51965 .52864 L F
.637 .86 .984 r
.41698 .54137 m .42071 .53537 L .42645 .53837 L F
.41698 .54137 m .4112 .53854 L .42071 .53537 L F
.646 .755 .929 r
.72703 .53629 m .73243 .52815 L .73705 .53353 L F
.72703 .53629 m .72238 .53092 L .73243 .52815 L F
.651 .764 .932 r
.53994 .53608 m .54436 .52799 L .54962 .53321 L F
.53994 .53608 m .53466 .53088 L .54436 .52799 L F
.651 .761 .93 r
.56453 .53561 m .56909 .52746 L .57426 .53274 L F
.56453 .53561 m .55934 .53034 L .56909 .52746 L F
.629 .752 .936 r
.865 .53927 m .87116 .53163 L .87531 .53689 L F
.865 .53927 m .86082 .534 L .87116 .53163 L F
.645 .755 .929 r
.75168 .53615 m .75721 .52805 L .76175 .53342 L F
.75168 .53615 m .74711 .53078 L .75721 .52805 L F
.543 .322 .53 r
.44725 .36468 m .45599 .39814 L .45677 .36142 L F
.44725 .36468 m .44689 .3793 L .45599 .39814 L F
.44725 .36468 m .44689 .3793 L .44725 .36468 L F
.65 .759 .929 r
.58914 .53519 m .59383 .527 L .59892 .53233 L F
.58914 .53519 m .58403 .52987 L .59383 .527 L F
.588 .743 .95 r
.9539 .54508 m .96067 .53846 L .96449 .54347 L F
.9539 .54508 m .95005 .54003 L .96067 .53846 L F
.642 .755 .93 r
.77635 .53607 m .78202 .52803 L .78648 .53339 L F
.77635 .53607 m .77187 .53072 L .78202 .52803 L F
.65 .758 .928 r
.61376 .53481 m .61857 .52661 L .62358 .53196 L F
.61376 .53481 m .60873 .52947 L .61857 .52661 L F
.621 .751 .939 r
.88977 .5398 m .89609 .53236 L .90015 .53757 L F
.88977 .5398 m .88567 .53458 L .89609 .53236 L F
.497 .904 .907 r
.39229 .54489 m .39578 .54156 L .40173 .54171 L F
.39229 .54489 m .38628 .5452 L .39578 .54156 L F
.649 .757 .928 r
.63839 .53448 m .64333 .52626 L .64826 .53164 L F
.63839 .53448 m .63344 .52911 L .64333 .52626 L F
.64 .754 .932 r
.80105 .53608 m .80685 .52812 L .81123 .53346 L F
.80105 .53608 m .79665 .53074 L .80685 .52812 L F
.219 0 0 r
.21799 .46915 m .21967 .47237 L .22677 .46991 L F
.21799 .46915 m .21068 .47351 L .21967 .47237 L F
.649 .757 .928 r
.66304 .53418 m .66811 .52597 L .67295 .53135 L F
.66304 .53418 m .65817 .5288 L .66811 .52597 L F
.254 0 .126 r
.35796 .55639 m .36073 .56312 L .36738 .55261 L F
.35796 .55639 m .35116 .56872 L .36073 .56312 L F
.61 .749 .943 r
.91459 .54061 m .92108 .53343 L .92506 .53858 L F
.91459 .54061 m .91059 .53544 L .92108 .53343 L F
.636 .754 .933 r
.82577 .53619 m .83171 .52833 L .83601 .53365 L F
.82577 .53619 m .82145 .53087 L .83171 .52833 L F
.648 .756 .928 r
.68769 .53392 m .69289 .52572 L .69766 .53111 L F
.68769 .53392 m .6829 .52853 L .69289 .52572 L F
.65 .785 .946 r
.47573 .53529 m .47983 .52767 L .48531 .53238 L F
.47573 .53529 m .47022 .53062 L .47983 .52767 L F
.649 .807 .959 r
.4511 .5365 m .45505 .52934 L .46064 .53356 L F
.4511 .5365 m .44549 .53236 L .45505 .52934 L F
.651 .774 .939 r
.50036 .53443 m .50458 .52655 L .50998 .53154 L F
.50036 .53443 m .49493 .52947 L .50458 .52655 L F
.647 .756 .929 r
.71236 .5337 m .71769 .52553 L .72238 .53092 L F
.71236 .5337 m .70766 .52832 L .71769 .52553 L F
.673 .209 .142 r
.24243 .47018 m .24371 .48053 L .25038 .48177 L F
.24243 .47018 m .23532 .47391 L .24371 .48053 L F
.651 .767 .935 r
.52498 .53376 m .52934 .52574 L .53466 .53088 L F
.52498 .53376 m .51965 .52864 L .52934 .52574 L F
.631 .753 .935 r
.85052 .53645 m .85661 .52872 L .86082 .534 L F
.85052 .53645 m .84629 .53115 L .85661 .52872 L F
.639 .854 .982 r
.42645 .53837 m .43024 .5322 L .43595 .53536 L F
.42645 .53837 m .42071 .53537 L .43024 .5322 L F
.65 .764 .932 r
.54962 .53321 m .55411 .5251 L .55934 .53034 L F
.54962 .53321 m .54436 .52799 L .55411 .5251 L F
.645 .755 .929 r
.73705 .53353 m .74251 .5254 L .74711 .53078 L F
.73705 .53353 m .73243 .52815 L .74251 .5254 L F
.596 .745 .948 r
.93949 .54179 m .94617 .53496 L .95005 .54003 L F
.93949 .54179 m .93558 .53669 L .94617 .53496 L F
.8 .385 .26 r
.25731 .47905 m .25831 .49512 L .26451 .50158 L F
.25731 .47905 m .25038 .48177 L .25831 .49512 L F
.65 .761 .93 r
.57426 .53274 m .57888 .52457 L .58403 .52987 L F
.57426 .53274 m .56909 .52746 L .57888 .52457 L F
.649 .803 .957 r
.47022 .53062 m .47429 .52331 L .47983 .52767 L F
.649 .8 .955 r
.47983 .52767 m .47429 .52331 L .48396 .52028 L F
.647 .828 .97 r
.47429 .52331 m .4784 .51642 L .48396 .52028 L F
.47429 .52331 m .4687 .51957 L .4784 .51642 L F
.636 .877 .986 r
.4687 .51957 m .47279 .51359 L .4784 .51642 L F
.641 .868 .984 r
.4784 .51642 m .47279 .51359 L .48255 .5102 L F
.583 .925 .959 r
.47279 .51359 m .4769 .50897 L .48255 .5102 L F
.47279 .51359 m .46708 .51288 L .4769 .50897 L F
.607 .92 .975 r
.48255 .5102 m .4769 .50897 L .48674 .50514 L F
0 0 0 r
.46708 .51288 m .47111 .51217 L .4769 .50897 L F
.4769 .50897 m .48102 .50713 L .48674 .50514 L F
.4769 .50897 m .47111 .51217 L .48102 .50713 L F
.543 .323 .53 r
.46637 .3582 m .46525 .41666 L .47471 .43328 L F
.69 .147 0 r
.47345 .43106 m .4691 .42432 L .47471 .43328 L F
.46525 .41666 m .4691 .42432 L .47345 .43106 L F
.46525 .41666 m .4595 .41544 L .4691 .42432 L F
.028 .358 .831 r
.4691 .42432 m .46343 .41674 L .46472 .41753 L F
.4691 .42432 m .46472 .41753 L .47318 .4227 L F
0 .21 .736 r
.47471 .43328 m .4691 .42432 L .4708 .42584 L F
.543 .323 .53 r
.47614 .43599 m .47964 .36162 L .47588 .35497 L F
.4786 .44067 m .47964 .36162 L .47614 .43599 L F
.46637 .3582 m .47471 .43328 L .47588 .35497 L F
.47473 .43465 m .47588 .35497 L .47471 .43328 L F
.636 .877 .986 r
.4687 .51957 m .46305 .517 L .47279 .51359 L F
.549 .923 .931 r
.46305 .517 m .46708 .51288 L .47279 .51359 L F
.257 0 .238 r
.47111 .51217 m .47505 .52178 L .48102 .50713 L F
.648 .824 .967 r
.48396 .52028 m .4784 .51642 L .48814 .51327 L F
.641 .868 .984 r
.4784 .51642 m .48255 .5102 L .48814 .51327 L F
.195 0 .147 r
.48102 .50713 m .47505 .52178 L .48164 .51618 L F
.644 .859 .981 r
.48814 .51327 m .48255 .5102 L .49235 .50684 L F
.195 0 .147 r
.48338 .51065 m .48164 .51618 L .48511 .51323 L F
.607 .92 .975 r
.48255 .5102 m .48674 .50514 L .49235 .50684 L F
.195 0 .147 r
.48102 .50713 m .48164 .51618 L .48338 .51065 L F
.124 .001 .427 r
.4841 .59526 m .47505 .52178 L .47393 .59829 L F
.65 .784 .946 r
.48531 .53238 m .47983 .52767 L .48947 .52471 L F
.649 .8 .955 r
.47983 .52767 m .48396 .52028 L .48947 .52471 L F
.65 .798 .954 r
.48947 .52471 m .48396 .52028 L .49366 .51726 L F
.648 .824 .967 r
.48396 .52028 m .48814 .51327 L .49366 .51726 L F
.124 .001 .427 r
.4841 .59526 m .48511 .51323 L .47505 .52178 L F
.543 .323 .53 r
.47594 .53422 m .47614 .43782 L .47473 .43465 L F
.47662 .59005 m .47644 .53264 L .47594 .53422 L F
.47644 .53264 m .47614 .43782 L .47594 .53422 L F
.47614 .43782 m .47588 .35497 L .47473 .43465 L F
.028 .358 .831 r
.4708 .42584 m .47318 .4227 L .4788 .43304 L F
.4691 .42432 m .46996 .42397 L .4708 .42584 L F
.46996 .42397 m .47318 .4227 L .4708 .42584 L F
0 .21 .736 r
.47471 .43328 m .4708 .42584 L .4788 .43304 L F
.543 .323 .53 r
.47662 .59005 m .4786 .44067 L .47614 .43599 L F
.643 .755 .93 r
.76175 .53342 m .76735 .52534 L .77187 .53072 L F
.76175 .53342 m .75721 .52805 L .76735 .52534 L F
.624 .752 .938 r
.87531 .53689 m .88156 .52933 L .88567 .53458 L F
.87531 .53689 m .87116 .53163 L .88156 .52933 L F
.543 .322 .53 r
.45677 .36142 m .46525 .41666 L .46633 .35816 L F
.45677 .36142 m .45599 .39814 L .46525 .41666 L F
.45677 .36142 m .45599 .39814 L .45677 .36142 L F
.65 .759 .929 r
.59892 .53233 m .60366 .52413 L .60873 .52947 L F
.59892 .53233 m .59383 .527 L .60366 .52413 L F
.65 .758 .929 r
.62358 .53196 m .62846 .52375 L .63344 .52911 L F
.62358 .53196 m .61857 .52661 L .62846 .52375 L F
.533 .914 .937 r
.40173 .54171 m .4053 .53795 L .4112 .53854 L F
.40173 .54171 m .39578 .54156 L .4053 .53795 L F
.641 .755 .931 r
.78648 .53339 m .79221 .52538 L .79665 .53074 L F
.78648 .53339 m .78202 .52803 L .79221 .52538 L F
.649 .757 .929 r
.64826 .53164 m .65326 .52342 L .65817 .5288 L F
.64826 .53164 m .64333 .52626 L .65326 .52342 L F
.615 .75 .942 r
.90015 .53757 m .90656 .53025 L .91059 .53544 L F
.90015 .53757 m .89609 .53236 L .90656 .53025 L F
.209 0 .057 r
.36738 .55261 m .36073 .56312 L .37032 .55776 L F
.637 .754 .933 r
.81123 .53346 m .8171 .52553 L .82145 .53087 L F
.81123 .53346 m .80685 .52812 L .8171 .52553 L F
.648 .757 .929 r
.67295 .53135 m .67808 .52314 L .6829 .52853 L F
.67295 .53135 m .66811 .52597 L .67808 .52314 L F
.647 .756 .929 r
.69766 .53111 m .70292 .52292 L .70766 .52832 L F
.69766 .53111 m .69289 .52572 L .70292 .52292 L F
.633 .753 .935 r
.83601 .53365 m .84202 .52584 L .84629 .53115 L F
.83601 .53365 m .83171 .52833 L .84202 .52584 L F
.65 .784 .946 r
.48531 .53238 m .48947 .52471 L .49493 .52947 L F
.649 .805 .958 r
.46064 .53356 m .46466 .52633 L .47022 .53062 L F
.46064 .53356 m .45505 .52934 L .46466 .52633 L F
.603 .747 .946 r
.92506 .53858 m .93164 .53157 L .93558 .53669 L F
.92506 .53858 m .92108 .53343 L .93164 .53157 L F
.65 .774 .939 r
.50998 .53154 m .51427 .52363 L .51965 .52864 L F
.50998 .53154 m .50458 .52655 L .51427 .52363 L F
.646 .756 .929 r
.72238 .53092 m .72777 .52275 L .73243 .52815 L F
.72238 .53092 m .71769 .52553 L .72777 .52275 L F
.65 .767 .935 r
.53466 .53088 m .53907 .52283 L .54436 .52799 L F
.53466 .53088 m .52934 .52574 L .53907 .52283 L F
.995 .861 .584 r
.38046 .47757 m .38099 .47168 L .38897 .42761 L F
.3764 .50137 m .38099 .47168 L .38046 .47757 L F
.895 .926 .541 r
.38099 .47168 m .37436 .48109 L .38153 .46573 L F
.112 0 .298 r
.38897 .42761 m .38099 .47168 L .39167 .44233 L F
.895 .926 .541 r
.38099 .47168 m .38153 .46573 L .38486 .45859 L F
.642 .849 .979 r
.43595 .53536 m .43981 .52904 L .44549 .53236 L F
.43595 .53536 m .43024 .5322 L .43981 .52904 L F
.65 .764 .932 r
.55934 .53034 m .56388 .5222 L .56909 .52746 L F
.55934 .53034 m .55411 .5251 L .56388 .5222 L F
.627 .752 .937 r
.86082 .534 m .86699 .52635 L .87116 .53163 L F
.86082 .534 m .85661 .52872 L .86699 .52635 L F
.644 .755 .93 r
.74711 .53078 m .75264 .52266 L .75721 .52805 L F
.74711 .53078 m .74251 .5254 L .75264 .52266 L F
.65 .761 .931 r
.58403 .52987 m .5887 .52169 L .59383 .527 L F
.58403 .52987 m .57888 .52457 L .5887 .52169 L F
.543 .322 .53 r
.46633 .35816 m .46525 .41666 L .46637 .3582 L F
.382 0 0 r
.22677 .46991 m .22847 .4738 L .23532 .47391 L F
.22677 .46991 m .21967 .47237 L .22847 .4738 L F
.642 .755 .931 r
.77187 .53072 m .77753 .52265 L .78202 .52803 L F
.77187 .53072 m .76735 .52534 L .77753 .52265 L F
.65 .76 .93 r
.60873 .52947 m .61353 .52125 L .61857 .52661 L F
.60873 .52947 m .60366 .52413 L .61353 .52125 L F
.585 .742 .951 r
.95005 .54003 m .95683 .53343 L .96067 .53846 L F
.95005 .54003 m .94617 .53496 L .95683 .53343 L F
.619 .751 .94 r
.88567 .53458 m .892 .52713 L .89609 .53236 L F
.88567 .53458 m .88156 .52933 L .892 .52713 L F
.561 .917 .958 r
.4112 .53854 m .41485 .53439 L .42071 .53537 L F
.4112 .53854 m .4053 .53795 L .41485 .53439 L F
.649 .758 .929 r
.63344 .52911 m .63837 .52089 L .64333 .52626 L F
.63344 .52911 m .62846 .52375 L .63837 .52089 L F
.639 .755 .932 r
.79665 .53074 m .80245 .52275 L .80685 .52812 L F
.79665 .53074 m .79221 .52538 L .80245 .52275 L F
.648 .757 .929 r
.65817 .5288 m .66323 .52057 L .66811 .52597 L F
.65817 .5288 m .65326 .52342 L .66323 .52057 L F
.635 .754 .934 r
.82145 .53087 m .8274 .52299 L .83171 .52833 L F
.82145 .53087 m .8171 .52553 L .8274 .52299 L F
.608 .748 .944 r
.91059 .53544 m .91709 .52826 L .92108 .53343 L F
.91059 .53544 m .90656 .53025 L .91709 .52826 L F
.647 .757 .929 r
.6829 .52853 m .6881 .52032 L .69289 .52572 L F
.6829 .52853 m .67808 .52314 L .6881 .52032 L F
.646 .756 .929 r
.70766 .52832 m .71298 .52012 L .71769 .52553 L F
.70766 .52832 m .70292 .52292 L .71298 .52012 L F
.6 .275 .392 r
.44689 .3793 m .45 .40737 L .45599 .39814 L F
.44689 .3793 m .44054 .40123 L .45 .40737 L F
.65 .783 .945 r
.49493 .52947 m .49914 .52175 L .50458 .52655 L F
.49493 .52947 m .48947 .52471 L .49914 .52175 L F
.649 .803 .957 r
.47022 .53062 m .46466 .52633 L .47429 .52331 L F
.63 .753 .936 r
.84629 .53115 m .85238 .52341 L .85661 .52872 L F
.84629 .53115 m .84202 .52584 L .85238 .52341 L F
.65 .773 .938 r
.51965 .52864 m .52399 .5207 L .52934 .52574 L F
.51965 .52864 m .51427 .52363 L .52399 .5207 L F
.645 .756 .93 r
.73243 .52815 m .73788 .51999 L .74251 .5254 L F
.73243 .52815 m .72777 .52275 L .73788 .51999 L F
.65 .767 .935 r
.54436 .52799 m .54884 .51992 L .55411 .5251 L F
.54436 .52799 m .53907 .52283 L .54884 .51992 L F
.644 .843 .977 r
.44549 .53236 m .44941 .52588 L .45505 .52934 L F
.44549 .53236 m .43981 .52904 L .44941 .52588 L F
.593 .745 .949 r
.93558 .53669 m .94227 .52987 L .94617 .53496 L F
.93558 .53669 m .93164 .53157 L .94227 .52987 L F
.65 .764 .932 r
.56909 .52746 m .5737 .5193 L .57888 .52457 L F
.56909 .52746 m .56388 .5222 L .5737 .5193 L F
.642 .755 .931 r
.75721 .52805 m .76281 .51994 L .76735 .52534 L F
.75721 .52805 m .75264 .52266 L .76281 .51994 L F
.623 .752 .939 r
.87116 .53163 m .87741 .52407 L .88156 .52933 L F
.87116 .53163 m .86699 .52635 L .87741 .52407 L F
.65 .761 .931 r
.59383 .527 m .59856 .5188 L .60366 .52413 L F
.59383 .527 m .5887 .52169 L .59856 .5188 L F
.458 .239 .493 r
.2782 .66834 m .27434 .62563 L .27187 .67038 L F
.27187 .67038 m .27434 .62563 L .26929 .67151 L F
.46 .243 .497 r
.26929 .67151 m .27434 .62563 L .26461 .63492 L F
.455 .235 .489 r
.28706 .66508 m .28402 .61696 L .28158 .66686 L F
.28706 .66508 m .29366 .60883 L .28402 .61696 L F
.28158 .66686 m .28402 .61696 L .2782 .66834 L F
.46 .243 .497 r
.26929 .67151 m .26461 .63492 L .26226 .67378 L F
.26226 .67378 m .26461 .63492 L .26034 .67461 L F
.462 .247 .5 r
.26034 .67461 m .26461 .63492 L .25484 .64487 L F
.089 0 0 r
.38628 .5452 m .38951 .54765 L .39578 .54156 L F
.38628 .5452 m .37991 .55261 L .38951 .54765 L F
.649 .76 .93 r
.61857 .52661 m .62344 .51838 L .62846 .52375 L F
.61857 .52661 m .61353 .52125 L .62344 .51838 L F
.583 .915 .972 r
.42071 .53537 m .42443 .53085 L .43024 .5322 L F
.42071 .53537 m .41485 .53439 L .42443 .53085 L F
.64 .755 .932 r
.78202 .52803 m .78775 .51999 L .79221 .52538 L F
.78202 .52803 m .77753 .52265 L .78775 .51999 L F
.541 .927 .884 r
.20146 .47736 m .20363 .47416 L .21068 .47351 L F
.20146 .47736 m .19433 .47856 L .20363 .47416 L F
.452 .229 .484 r
.29585 .66172 m .29366 .60883 L .29138 .66319 L F
.29585 .66172 m .30328 .60118 L .29366 .60883 L F
.29138 .66319 m .29366 .60883 L .28706 .66508 L F
.648 .758 .93 r
.64333 .52626 m .64833 .51803 L .65326 .52342 L F
.64333 .52626 m .63837 .52089 L .64833 .51803 L F
.462 .247 .5 r
.26034 .67461 m .25484 .64487 L .25272 .67706 L F
.25272 .67706 m .25484 .64487 L .25136 .67765 L F
.613 .75 .942 r
.89609 .53236 m .9025 .52504 L .90656 .53025 L F
.89609 .53236 m .892 .52713 L .9025 .52504 L F
.636 .754 .933 r
.80685 .52812 m .81273 .52017 L .8171 .52553 L F
.80685 .52812 m .80245 .52275 L .81273 .52017 L F
.448 .223 .478 r
.30458 .65825 m .30328 .60118 L .30129 .65933 L F
.30458 .65825 m .31287 .59398 L .30328 .60118 L F
.30129 .65933 m .30328 .60118 L .29585 .66172 L F
.648 .758 .929 r
.66811 .52597 m .67323 .51774 L .67808 .52314 L F
.66811 .52597 m .66323 .52057 L .67323 .51774 L F
.646 .757 .93 r
.69289 .52572 m .69815 .5175 L .70292 .52292 L F
.69289 .52572 m .6881 .52032 L .69815 .5175 L F
.632 .754 .935 r
.83171 .52833 m .83773 .52051 L .84202 .52584 L F
.83171 .52833 m .8274 .52299 L .83773 .52051 L F
.6 .747 .947 r
.92108 .53343 m .92768 .52643 L .93164 .53157 L F
.92108 .53343 m .91709 .52826 L .92768 .52643 L F
.443 .215 .471 r
.31321 .65466 m .31287 .59398 L .31133 .65528 L F
.31321 .65466 m .32245 .58717 L .31287 .59398 L F
.31133 .65528 m .31287 .59398 L .30458 .65825 L F
.645 .756 .93 r
.71769 .52553 m .72308 .51734 L .72777 .52275 L F
.71769 .52553 m .71298 .52012 L .72308 .51734 L F
.543 .322 .53 r
.28015 .64871 m .28017 .6269 L .27402 .64328 L F
.28017 .6269 m .28022 .5576 L .27855 .58067 L F
.28017 .6269 m .27855 .58067 L .27402 .64328 L F
.27402 .64328 m .27855 .58067 L .27601 .64268 L F
.27855 .58067 m .28022 .5576 L .27874 .58747 L F
.27855 .58067 m .27874 .58747 L .27601 .64268 L F
.967 .707 .277 r
.27601 .64268 m .27847 .59306 L .27898 .61037 L F
.27847 .59306 m .28022 .5576 L .27952 .58715 L F
.27847 .59306 m .27952 .58715 L .27898 .61037 L F
.959 .621 .291 r
.27764 .56262 m .27681 .5478 L .27898 .61037 L F
.27642 .51949 m .27061 .50889 L .27681 .5478 L F
.91 .505 .135 r
.27442 .53283 m .27195 .52325 L .27681 .5478 L F
.27061 .50889 m .27195 .52325 L .27442 .53283 L F
.27061 .50889 m .26451 .50158 L .27195 .52325 L F
.795 .325 0 r
.26967 .51662 m .26633 .50882 L .27195 .52325 L F
.26451 .50158 m .26633 .50882 L .26967 .51662 L F
.26451 .50158 m .25831 .49512 L .26305 .50321 L F
.26584 .50686 m .26305 .50321 L .26633 .50882 L F
.26451 .50158 m .26305 .50321 L .26584 .50686 L F
.725 .202 0 r
.25814 .49483 m .25204 .48895 L .25831 .49512 L F
.25038 .48177 m .25204 .48895 L .25814 .49483 L F
.466 0 0 r
.25187 .48877 m .24572 .48289 L .25204 .48895 L F
.24371 .48053 m .24572 .48289 L .25187 .48877 L F
.476 0 0 r
.23532 .47391 m .23714 .47748 L .24371 .48053 L F
.466 0 0 r
.24371 .48053 m .23714 .47748 L .24572 .48289 L F
0 .372 .827 r
.24572 .48289 m .23935 .47687 L .23953 .47697 L F
.725 .202 0 r
.25038 .48177 m .24371 .48053 L .25204 .48895 L F
0 .372 .827 r
.24572 .48289 m .23953 .47697 L .24809 .48144 L F
0 .179 .67 r
.25204 .48895 m .24572 .48289 L .24591 .48303 L F
.25204 .48895 m .24591 .48303 L .2543 .48936 L F
.58 .075 0 r
.26424 .50525 m .2604 .49821 L .26633 .50882 L F
.25831 .49512 m .2604 .49821 L .26424 .50525 L F
.25831 .49512 m .25204 .48895 L .2604 .49821 L F
0 .26 .77 r
.2604 .49821 m .2543 .48936 L .25653 .49111 L F
.2604 .49821 m .25653 .49111 L .26294 .49614 L F
0 .179 .67 r
.25267 .48965 m .2543 .48936 L .2604 .49821 L F
.25204 .48895 m .25215 .48897 L .25267 .48965 L F
.25215 .48897 m .2543 .48936 L .25267 .48965 L F
0 .14 .686 r
.26633 .50882 m .2604 .49821 L .26297 .50096 L F
.26633 .50882 m .26297 .50096 L .26887 .50729 L F
0 .036 .6 r
.27195 .52325 m .26633 .50882 L .26946 .51361 L F
.27195 .52325 m .26946 .51361 L .27456 .52144 L F
.27195 .52325 m .27456 .52144 L .27541 .5248 L F
.959 .621 .291 r
.27648 .52152 m .27676 .54395 L .27734 .55213 L F
.27643 .52015 m .27681 .5478 L .27648 .52152 L F
.967 .707 .277 r
.28022 .5576 m .27642 .51949 L .27898 .61037 L F
0 .036 .6 r
.27598 .53292 m .27541 .5248 L .27977 .54199 L F
.27195 .52325 m .27541 .5248 L .27598 .53292 L F
.959 .621 .291 r
.27734 .55213 m .27681 .5478 L .27764 .56262 L F
.27676 .54395 m .27681 .5478 L .27734 .55213 L F
0 .017 .544 r
.27681 .5478 m .27195 .52325 L .27598 .53292 L F
.27681 .5478 m .27598 .53292 L .27977 .54199 L F
.27681 .5478 m .27977 .54199 L .28274 .56923 L F
.28223 .57204 m .28274 .56923 L .28381 .57911 L F
.27681 .5478 m .28274 .56923 L .28223 .57204 L F
.959 .621 .291 r
.27642 .51949 m .27643 .52015 L .27648 .52152 L F
.65 .782 .944 r
.50458 .52655 m .50886 .51879 L .51427 .52363 L F
.50458 .52655 m .49914 .52175 L .50886 .51879 L F
.65 .773 .938 r
.52934 .52574 m .53375 .51776 L .53907 .52283 L F
.52934 .52574 m .52399 .5207 L .53375 .51776 L F
.645 .838 .974 r
.45505 .52934 m .45904 .52272 L .46466 .52633 L F
.45505 .52934 m .44941 .52588 L .45904 .52272 L F
.626 .752 .938 r
.85661 .52872 m .86278 .52105 L .86699 .52635 L F
.85661 .52872 m .85238 .52341 L .86278 .52105 L F
.65 .767 .935 r
.55411 .5251 m .55864 .517 L .56388 .5222 L F
.55411 .5251 m .54884 .51992 L .55864 .517 L F
.643 .756 .931 r
.74251 .5254 m .74804 .51725 L .75264 .52266 L F
.74251 .5254 m .73788 .51999 L .74804 .51725 L F
.649 .764 .933 r
.57888 .52457 m .58354 .5164 L .5887 .52169 L F
.57888 .52457 m .5737 .5193 L .58354 .5164 L F
.012 0 0 r
.39578 .54156 m .39913 .54286 L .4053 .53795 L F
.39578 .54156 m .38951 .54765 L .39913 .54286 L F
.438 .206 .463 r
.32172 .65091 m .32245 .58717 L .32151 .65099 L F
.32172 .65091 m .33202 .58071 L .32245 .58717 L F
.32151 .65099 m .32245 .58717 L .31321 .65466 L F
.641 .755 .932 r
.76735 .52534 m .77301 .51725 L .77753 .52265 L F
.76735 .52534 m .76281 .51994 L .77301 .51725 L F
.305 .799 .834 r
.21068 .47351 m .21277 .47187 L .21967 .47237 L F
.21068 .47351 m .20363 .47416 L .21277 .47187 L F
.649 .761 .931 r
.60366 .52413 m .60846 .51591 L .61353 .52125 L F
.60366 .52413 m .59856 .5188 L .60846 .51591 L F
.582 .742 .952 r
.94617 .53496 m .95296 .52838 L .95683 .53343 L F
.94617 .53496 m .94227 .52987 L .95296 .52838 L F
.617 .751 .941 r
.88156 .52933 m .88789 .52188 L .892 .52713 L F
.88156 .52933 m .87741 .52407 L .88789 .52188 L F
.6 .91 .981 r
.43024 .5322 m .43404 .52735 L .43981 .52904 L F
.43024 .5322 m .42443 .53085 L .43404 .52735 L F
.648 .76 .93 r
.62846 .52375 m .63338 .51551 L .63837 .52089 L F
.62846 .52375 m .62344 .51838 L .63338 .51551 L F
.638 .755 .933 r
.79221 .52538 m .79802 .51737 L .80245 .52275 L F
.79221 .52538 m .78775 .51999 L .79802 .51737 L F
.476 0 0 r
.23532 .47391 m .22847 .4738 L .23714 .47748 L F
.648 .759 .93 r
.65326 .52342 m .65832 .51517 L .66323 .52057 L F
.65326 .52342 m .64833 .51803 L .65832 .51517 L F
.647 .758 .93 r
.67808 .52314 m .68327 .5149 L .6881 .52032 L F
.67808 .52314 m .67323 .51774 L .68327 .5149 L F
.432 .196 .454 r
.33202 .58071 m .33188 .63581 L .34159 .57457 L F
.32279 .65044 m .33202 .58071 L .32172 .65091 L F
.32279 .65044 m .33188 .63581 L .33202 .58071 L F
.634 .754 .935 r
.8171 .52553 m .82305 .51763 L .8274 .52299 L F
.8171 .52553 m .81273 .52017 L .82305 .51763 L F
.606 .748 .945 r
.90656 .53025 m .91306 .52308 L .91709 .52826 L F
.90656 .53025 m .9025 .52504 L .91306 .52308 L F
.645 .757 .93 r
.70292 .52292 m .70824 .5147 L .71298 .52012 L F
.70292 .52292 m .69815 .5175 L .70824 .5147 L F
.628 .753 .937 r
.84202 .52584 m .84812 .51808 L .85238 .52341 L F
.84202 .52584 m .83773 .52051 L .84812 .51808 L F
.65 .798 .954 r
.48947 .52471 m .49366 .51726 L .49914 .52175 L F
.644 .756 .931 r
.72777 .52275 m .73323 .51457 L .73788 .51999 L F
.72777 .52275 m .72308 .51734 L .73323 .51457 L F
.65 .781 .944 r
.51427 .52363 m .5186 .51582 L .52399 .5207 L F
.51427 .52363 m .50886 .51879 L .5186 .51582 L F
.65 .772 .938 r
.53907 .52283 m .54354 .51482 L .54884 .51992 L F
.53907 .52283 m .53375 .51776 L .54354 .51482 L F
.646 .833 .972 r
.46466 .52633 m .4687 .51957 L .47429 .52331 L F
.46466 .52633 m .45904 .52272 L .4687 .51957 L F
.649 .767 .935 r
.56388 .5222 m .56848 .51408 L .5737 .5193 L F
.56388 .5222 m .55864 .517 L .56848 .51408 L F
.59 .744 .95 r
.93164 .53157 m .93834 .52477 L .94227 .52987 L F
.93164 .53157 m .92768 .52643 L .93834 .52477 L F
.425 .183 .442 r
.34159 .57457 m .34214 .62086 L .35116 .56872 L F
.34159 .57457 m .33188 .63581 L .34214 .62086 L F
.642 .756 .932 r
.75264 .52266 m .75823 .51453 L .76281 .51994 L F
.75264 .52266 m .74804 .51725 L .75823 .51453 L F
0 0 0 r
.4053 .53795 m .40877 .53822 L .41485 .53439 L F
.4053 .53795 m .39913 .54286 L .40877 .53822 L F
.621 .752 .94 r
.86699 .52635 m .87324 .51878 L .87741 .52407 L F
.86699 .52635 m .86278 .52105 L .87324 .51878 L F
.649 .764 .933 r
.5887 .52169 m .59343 .5135 L .59856 .5188 L F
.5887 .52169 m .58354 .5164 L .59343 .5135 L F
.649 .761 .932 r
.61353 .52125 m .61839 .51302 L .62344 .51838 L F
.61353 .52125 m .60846 .51591 L .61839 .51302 L F
.639 .755 .933 r
.77753 .52265 m .78326 .51459 L .78775 .51999 L F
.77753 .52265 m .77301 .51725 L .78326 .51459 L F
.613 .903 .985 r
.43981 .52904 m .44368 .52387 L .44941 .52588 L F
.43981 .52904 m .43404 .52735 L .44368 .52387 L F
.648 .76 .931 r
.63837 .52089 m .64336 .51264 L .64833 .51803 L F
.63837 .52089 m .63338 .51551 L .64336 .51264 L F
.611 .75 .943 r
.892 .52713 m .89842 .51981 L .9025 .52504 L F
.892 .52713 m .88789 .52188 L .89842 .51981 L F
.635 .755 .934 r
.80245 .52275 m .80832 .51479 L .81273 .52017 L F
.80245 .52275 m .79802 .51737 L .80832 .51479 L F
.647 .759 .931 r
.66323 .52057 m .66835 .51232 L .67323 .51774 L F
.66323 .52057 m .65832 .51517 L .66835 .51232 L F
.087 .643 .793 r
.21967 .47237 m .22174 .47169 L .22847 .4738 L F
.21967 .47237 m .21277 .47187 L .22174 .47169 L F
.416 .168 .428 r
.35116 .56872 m .35229 .60744 L .36073 .56312 L F
.35116 .56872 m .34214 .62086 L .35229 .60744 L F
.646 .758 .931 r
.6881 .52032 m .69335 .51208 L .69815 .5175 L F
.6881 .52032 m .68327 .5149 L .69335 .51208 L F
.631 .754 .936 r
.8274 .52299 m .83342 .51515 L .83773 .52051 L F
.8274 .52299 m .82305 .51763 L .83342 .51515 L F
.644 .757 .931 r
.71298 .52012 m .71837 .51191 L .72308 .51734 L F
.71298 .52012 m .70824 .5147 L .71837 .51191 L F
.598 .746 .948 r
.91709 .52826 m .92369 .52127 L .92768 .52643 L F
.91709 .52826 m .91306 .52308 L .92369 .52127 L F
.65 .796 .953 r
.49914 .52175 m .5034 .51423 L .50886 .51879 L F
.49914 .52175 m .49366 .51726 L .5034 .51423 L F
.65 .781 .943 r
.52399 .5207 m .52838 .51284 L .53375 .51776 L F
.52399 .5207 m .5186 .51582 L .52838 .51284 L F
.624 .753 .939 r
.85238 .52341 m .85855 .51574 L .86278 .52105 L F
.85238 .52341 m .84812 .51808 L .85855 .51574 L F
.642 .756 .932 r
.73788 .51999 m .74341 .51182 L .74804 .51725 L F
.73788 .51999 m .73323 .51457 L .74341 .51182 L F
.199 0 .194 r
.41187 .40689 m .41509 .41524 L .42156 .39972 L F
.41187 .40689 m .40521 .42533 L .41509 .41524 L F
.021 0 .116 r
.40194 .42084 m .40521 .42533 L .41187 .40689 L F
.649 .772 .938 r
.54884 .51992 m .55336 .51188 L .55864 .517 L F
.54884 .51992 m .54354 .51482 L .55336 .51188 L F
0 0 0 r
.41485 .53439 m .41843 .53372 L .42443 .53085 L F
.41485 .53439 m .40877 .53822 L .41843 .53372 L F
.649 .767 .935 r
.5737 .5193 m .57835 .51116 L .58354 .5164 L F
.5737 .5193 m .56848 .51408 L .57835 .51116 L F
.64 .756 .932 r
.76281 .51994 m .76847 .51184 L .77301 .51725 L F
.76281 .51994 m .75823 .51453 L .76847 .51184 L F
.405 .151 .411 r
.36073 .56312 m .36236 .59533 L .37032 .55776 L F
.36073 .56312 m .35229 .60744 L .36236 .59533 L F
.649 .764 .933 r
.59856 .5188 m .60335 .51059 L .60846 .51591 L F
.59856 .5188 m .59343 .5135 L .60335 .51059 L F
.616 .751 .942 r
.87741 .52407 m .88375 .51661 L .88789 .52188 L F
.87741 .52407 m .87324 .51878 L .88375 .51661 L F
.623 .894 .987 r
.44941 .52588 m .45335 .52042 L .45904 .52272 L F
.44941 .52588 m .44368 .52387 L .45335 .52042 L F
.579 .741 .953 r
.94227 .52987 m .94907 .52332 L .95296 .52838 L F
.94227 .52987 m .93834 .52477 L .94907 .52332 L F
.648 .761 .932 r
.62344 .51838 m .62836 .51014 L .63338 .51551 L F
.62344 .51838 m .61839 .51302 L .62836 .51014 L F
.305 0 .204 r
.42156 .39972 m .42484 .40934 L .43109 .39825 L F
.42156 .39972 m .41509 .41524 L .42484 .40934 L F
.637 .755 .934 r
.78775 .51999 m .79355 .51197 L .79802 .51737 L F
.78775 .51999 m .78326 .51459 L .79355 .51197 L F
.647 .76 .931 r
.64833 .51803 m .65338 .50977 L .65832 .51517 L F
.64833 .51803 m .64336 .51264 L .65338 .50977 L F
.696 .931 .966 r
.19433 .47856 m .19672 .47273 L .20363 .47416 L F
.19433 .47856 m .18735 .47745 L .19672 .47273 L F
.646 .759 .931 r
.67323 .51774 m .67841 .50948 L .68327 .5149 L F
.67323 .51774 m .66835 .51232 L .67841 .50948 L F
.633 .754 .936 r
.81273 .52017 m .81867 .51225 L .82305 .51763 L F
.81273 .52017 m .80832 .51479 L .81867 .51225 L F
.604 .748 .946 r
.9025 .52504 m .90902 .51787 L .91306 .52308 L F
.9025 .52504 m .89842 .51981 L .90902 .51787 L F
.645 .758 .931 r
.69815 .5175 m .70347 .50927 L .70824 .5147 L F
.69815 .5175 m .69335 .51208 L .70347 .50927 L F
.392 .129 .391 r
.37032 .55776 m .36236 .59533 L .37235 .58435 L F
.627 .753 .938 r
.83773 .52051 m .84383 .51274 L .84812 .51808 L F
.83773 .52051 m .83342 .51515 L .84383 .51274 L F
.643 .757 .932 r
.72308 .51734 m .72854 .50914 L .73323 .51457 L F
.72308 .51734 m .71837 .51191 L .72854 .50914 L F
.021 0 .116 r
.40194 .42084 m .39514 .43983 L .40521 .42533 L F
0 0 0 r
.39167 .44233 m .39514 .43983 L .40194 .42084 L F
.42443 .53085 m .42811 .52935 L .43404 .52735 L F
.42443 .53085 m .41843 .53372 L .42811 .52935 L F
.65 .794 .952 r
.50886 .51879 m .51317 .51119 L .5186 .51582 L F
.50886 .51879 m .5034 .51423 L .51317 .51119 L F
.65 .78 .943 r
.53375 .51776 m .5382 .50986 L .54354 .51482 L F
.53375 .51776 m .52838 .51284 L .5382 .50986 L F
.649 .772 .938 r
.55864 .517 m .56323 .50893 L .56848 .51408 L F
.55864 .517 m .55336 .51188 L .56323 .50893 L F
.641 .756 .932 r
.74804 .51725 m .75363 .5091 L .75823 .51453 L F
.74804 .51725 m .74341 .51182 L .75363 .5091 L F
.588 .744 .951 r
.92768 .52643 m .93438 .51964 L .93834 .52477 L F
.92768 .52643 m .92369 .52127 L .93438 .51964 L F
.62 .752 .941 r
.86278 .52105 m .86904 .51348 L .87324 .51878 L F
.86278 .52105 m .85855 .51574 L .86904 .51348 L F
.649 .767 .935 r
.58354 .5164 m .58826 .50823 L .59343 .5135 L F
.58354 .5164 m .57835 .51116 L .58826 .50823 L F
.648 .764 .933 r
.60846 .51591 m .61331 .50769 L .61839 .51302 L F
.60846 .51591 m .60335 .51059 L .61331 .50769 L F
.638 .756 .933 r
.77301 .51725 m .77874 .50917 L .78326 .51459 L F
.77301 .51725 m .76847 .51184 L .77874 .50917 L F
.573 .894 .986 r
.20363 .47416 m .20596 .4697 L .21277 .47187 L F
.20363 .47416 m .19672 .47273 L .20596 .4697 L F
.63 .886 .987 r
.45904 .52272 m .46305 .517 L .4687 .51957 L F
.45904 .52272 m .45335 .52042 L .46305 .517 L F
.647 .761 .932 r
.63338 .51551 m .63836 .50725 L .64336 .51264 L F
.63338 .51551 m .62836 .51014 L .63836 .50725 L F
0 .509 .787 r
.22847 .4738 m .23059 .47347 L .23714 .47748 L F
.22847 .4738 m .22174 .47169 L .23059 .47347 L F
.377 .103 .366 r
.37991 .55261 m .3823 .57437 L .38951 .54765 L F
.609 .749 .944 r
.88789 .52188 m .89431 .51455 L .89842 .51981 L F
.88789 .52188 m .88375 .51661 L .89431 .51455 L F
.634 .755 .935 r
.79802 .51737 m .80389 .50939 L .80832 .51479 L F
.79802 .51737 m .79355 .51197 L .80389 .50939 L F
.646 .76 .932 r
.65832 .51517 m .66343 .50691 L .66835 .51232 L F
.65832 .51517 m .65338 .50977 L .66343 .50691 L F
.645 .759 .932 r
.68327 .5149 m .68852 .50665 L .69335 .51208 L F
.68327 .5149 m .67841 .50948 L .68852 .50665 L F
.384 0 .158 r
.43109 .39825 m .4345 .40721 L .44054 .40123 L F
.43109 .39825 m .42484 .40934 L .4345 .40721 L F
.629 .754 .937 r
.82305 .51763 m .82907 .50978 L .83342 .51515 L F
.82305 .51763 m .81867 .51225 L .82907 .50978 L F
.644 .758 .932 r
.70824 .5147 m .71362 .50647 L .71837 .51191 L F
.70824 .5147 m .70347 .50927 L .71362 .50647 L F
.668 .267 .276 r
.45599 .39814 m .4595 .41544 L .46525 .41666 L F
.45599 .39814 m .45 .40737 L .4595 .41544 L F
.595 .746 .949 r
.91306 .52308 m .91967 .51609 L .92369 .52127 L F
.91306 .52308 m .90902 .51787 L .91967 .51609 L F
.362 .823 .733 r
.43404 .52735 m .43782 .52509 L .44368 .52387 L F
.43404 .52735 m .42811 .52935 L .43782 .52509 L F
.642 .757 .932 r
.73323 .51457 m .73874 .50638 L .74341 .51182 L F
.73323 .51457 m .72854 .50914 L .73874 .50638 L F
.623 .753 .939 r
.84812 .51808 m .8543 .5104 L .85855 .51574 L F
.84812 .51808 m .84383 .51274 L .8543 .5104 L F
.65 .792 .951 r
.5186 .51582 m .52298 .50815 L .52838 .51284 L F
.5186 .51582 m .51317 .51119 L .52298 .50815 L F
.649 .779 .943 r
.54354 .51482 m .54805 .50688 L .55336 .51188 L F
.54354 .51482 m .5382 .50986 L .54805 .50688 L F
.649 .819 .965 r
.49366 .51726 m .4979 .51012 L .5034 .51423 L F
.49366 .51726 m .48814 .51327 L .4979 .51012 L F
.649 .771 .938 r
.56848 .51408 m .57313 .50598 L .57835 .51116 L F
.56848 .51408 m .56323 .50893 L .57313 .50598 L F
.357 .072 .336 r
.38951 .54765 m .3922 .56523 L .39913 .54286 L F
.38951 .54765 m .3823 .57437 L .3922 .56523 L F
.639 .756 .933 r
.75823 .51453 m .76389 .5064 L .76847 .51184 L F
.75823 .51453 m .75363 .5091 L .76389 .5064 L F
.648 .766 .935 r
.59343 .5135 m .59821 .50531 L .60335 .51059 L F
.59343 .5135 m .58826 .50823 L .59821 .50531 L F
.614 .751 .943 r
.87324 .51878 m .87958 .51132 L .88375 .51661 L F
.87324 .51878 m .86904 .51348 L .87958 .51132 L F
.648 .763 .933 r
.61839 .51302 m .6233 .50479 L .62836 .51014 L F
.61839 .51302 m .61331 .50769 L .6233 .50479 L F
.576 .74 .954 r
.93834 .52477 m .94515 .51823 L .94907 .52332 L F
.93834 .52477 m .93438 .51964 L .94515 .51823 L F
.636 .756 .935 r
.78326 .51459 m .78906 .50655 L .79355 .51197 L F
.78326 .51459 m .77874 .50917 L .78906 .50655 L F
.647 .761 .933 r
.64336 .51264 m .6484 .50437 L .65338 .50977 L F
.64336 .51264 m .63836 .50725 L .6484 .50437 L F
.42 .811 .988 r
.21277 .47187 m .21505 .46843 L .22174 .47169 L F
.21277 .47187 m .20596 .4697 L .21505 .46843 L F
.646 .76 .932 r
.66835 .51232 m .67352 .50406 L .67841 .50948 L F
.66835 .51232 m .66343 .50691 L .67352 .50406 L F
.632 .755 .936 r
.80832 .51479 m .81427 .50685 L .81867 .51225 L F
.80832 .51479 m .80389 .50939 L .81427 .50685 L F
.602 .748 .947 r
.89842 .51981 m .90494 .51264 L .90902 .51787 L F
.89842 .51981 m .89431 .51455 L .90494 .51264 L F
.644 .759 .932 r
.69335 .51208 m .69866 .50383 L .70347 .50927 L F
.69335 .51208 m .68852 .50665 L .69866 .50383 L F
.626 .753 .939 r
.83342 .51515 m .83951 .50737 L .84383 .51274 L F
.83342 .51515 m .82907 .50978 L .83951 .50737 L F
.333 .033 .297 r
.39913 .54286 m .40208 .55684 L .40877 .53822 L F
.39913 .54286 m .3922 .56523 L .40208 .55684 L F
.44 .876 .822 r
.44368 .52387 m .44755 .52093 L .45335 .52042 L F
.44368 .52387 m .43782 .52509 L .44755 .52093 L F
.643 .758 .932 r
.71837 .51191 m .72382 .50369 L .72854 .50914 L F
.71837 .51191 m .71362 .50647 L .72382 .50369 L F
.64 .757 .933 r
.74341 .51182 m .74899 .50365 L .75363 .5091 L F
.74341 .51182 m .73874 .50638 L .74899 .50365 L F
.65 .791 .95 r
.52838 .51284 m .53282 .50511 L .5382 .50986 L F
.52838 .51284 m .52298 .50815 L .53282 .50511 L F
.585 .743 .952 r
.92369 .52127 m .9304 .51449 L .93438 .51964 L F
.92369 .52127 m .91967 .51609 L .9304 .51449 L F
.649 .778 .942 r
.55336 .51188 m .55794 .5039 L .56323 .50893 L F
.55336 .51188 m .54805 .50688 L .55794 .5039 L F
.618 .752 .941 r
.85855 .51574 m .86481 .50815 L .86904 .51348 L F
.85855 .51574 m .8543 .5104 L .86481 .50815 L F
.649 .815 .963 r
.5034 .51423 m .5077 .50698 L .51317 .51119 L F
.5034 .51423 m .4979 .51012 L .5077 .50698 L F
.895 .926 .541 r
.38099 .47168 m .38486 .45859 L .39167 .44233 L F
0 0 0 r
.39167 .44233 m .38486 .45859 L .39514 .43983 L F
.648 .771 .938 r
.57835 .51116 m .58306 .50303 L .58826 .50823 L F
.57835 .51116 m .57313 .50598 L .58306 .50303 L F
.728 .886 .953 r
.18735 .47745 m .18988 .47004 L .19672 .47273 L F
.18735 .47745 m .18046 .47496 L .18988 .47004 L F
.637 .756 .934 r
.76847 .51184 m .77419 .50373 L .77874 .50917 L F
.76847 .51184 m .76389 .5064 L .77419 .50373 L F
.648 .766 .935 r
.60335 .51059 m .60819 .50238 L .61331 .50769 L F
.60335 .51059 m .59821 .50531 L .60819 .50238 L F
.647 .763 .934 r
.62836 .51014 m .63333 .50188 L .63836 .50725 L F
.62836 .51014 m .6233 .50479 L .63333 .50188 L F
.633 .755 .936 r
.79355 .51197 m .79943 .50396 L .80389 .50939 L F
.79355 .51197 m .78906 .50655 L .79943 .50396 L F
.607 .749 .945 r
.88375 .51661 m .89018 .50928 L .89431 .51455 L F
.88375 .51661 m .87958 .51132 L .89018 .50928 L F
.646 .761 .933 r
.65338 .50977 m .65848 .5015 L .66343 .50691 L F
.65338 .50977 m .6484 .50437 L .65848 .5015 L F
.302 0 .25 r
.40877 .53822 m .41194 .54909 L .41843 .53372 L F
.40877 .53822 m .40208 .55684 L .41194 .54909 L F
0 .417 .806 r
.23714 .47748 m .23935 .47687 L .24572 .48289 L F
.23714 .47748 m .23059 .47347 L .23935 .47687 L F
.645 .76 .933 r
.67841 .50948 m .68366 .50121 L .68852 .50665 L F
.67841 .50948 m .67352 .50406 L .68366 .50121 L F
.628 .754 .938 r
.81867 .51225 m .82469 .50438 L .82907 .50978 L F
.81867 .51225 m .81427 .50685 L .82469 .50438 L F
.643 .759 .933 r
.70347 .50927 m .70884 .50102 L .71362 .50647 L F
.70347 .50927 m .69866 .50383 L .70884 .50102 L F
.502 .908 .887 r
.45335 .52042 m .4573 .51686 L .46305 .517 L F
.45335 .52042 m .44755 .52093 L .4573 .51686 L F
.446 0 .026 r
.44054 .40123 m .44412 .40823 L .45 .40737 L F
.44054 .40123 m .4345 .40721 L .44412 .40823 L F
.593 .745 .949 r
.90902 .51787 m .91563 .51088 L .91967 .51609 L F
.90902 .51787 m .90494 .51264 L .91563 .51088 L F
.641 .758 .933 r
.72854 .50914 m .73405 .50093 L .73874 .50638 L F
.72854 .50914 m .72382 .50369 L .73405 .50093 L F
.621 .753 .94 r
.84383 .51274 m .85001 .50503 L .8543 .5104 L F
.84383 .51274 m .83951 .50737 L .85001 .50503 L F
.655 .871 .98 r
.19672 .47273 m .19919 .46649 L .20596 .4697 L F
.19672 .47273 m .18988 .47004 L .19919 .46649 L F
.273 .696 .968 r
.22174 .47169 m .22404 .46888 L .23059 .47347 L F
.22174 .47169 m .21505 .46843 L .22404 .46888 L F
.649 .789 .949 r
.5382 .50986 m .5427 .50207 L .54805 .50688 L F
.5382 .50986 m .53282 .50511 L .5427 .50207 L F
.638 .757 .934 r
.75363 .5091 m .75928 .50095 L .76389 .5064 L F
.75363 .5091 m .74899 .50365 L .75928 .50095 L F
.649 .777 .942 r
.56323 .50893 m .56786 .50091 L .57313 .50598 L F
.56323 .50893 m .55794 .5039 L .56786 .50091 L F
.65 .811 .961 r
.51317 .51119 m .51754 .50384 L .52298 .50815 L F
.51317 .51119 m .5077 .50698 L .51754 .50384 L F
.648 .77 .938 r
.58826 .50823 m .59303 .50008 L .59821 .50531 L F
.58826 .50823 m .58306 .50303 L .59303 .50008 L F
.612 .751 .943 r
.86904 .51348 m .87538 .506 L .87958 .51132 L F
.86904 .51348 m .86481 .50815 L .87538 .506 L F
.647 .766 .935 r
.61331 .50769 m .61821 .49946 L .6233 .50479 L F
.61331 .50769 m .60819 .50238 L .61821 .49946 L F
.644 .859 .981 r
.48814 .51327 m .49235 .50684 L .4979 .51012 L F
.635 .756 .935 r
.77874 .50917 m .78454 .50111 L .78906 .50655 L F
.77874 .50917 m .77419 .50373 L .78454 .50111 L F
.573 .739 .955 r
.93438 .51964 m .9412 .51311 L .94515 .51823 L F
.93438 .51964 m .9304 .51449 L .9412 .51311 L F
.263 0 .189 r
.41843 .53372 m .42179 .5419 L .42811 .52935 L F
.41843 .53372 m .41194 .54909 L .42179 .5419 L F
.646 .763 .934 r
.63836 .50725 m .6434 .49899 L .6484 .50437 L F
.63836 .50725 m .63333 .50188 L .6434 .49899 L F
.645 .761 .933 r
.66343 .50691 m .6686 .49863 L .67352 .50406 L F
.66343 .50691 m .65848 .5015 L .6686 .49863 L F
.63 .755 .937 r
.80389 .50939 m .80983 .50143 L .81427 .50685 L F
.80389 .50939 m .79943 .50396 L .80983 .50143 L F
.6 .747 .947 r
.89431 .51455 m .90084 .50738 L .90494 .51264 L F
.89431 .51455 m .89018 .50928 L .90084 .50738 L F
.644 .76 .933 r
.68852 .50665 m .69382 .49838 L .69866 .50383 L F
.68852 .50665 m .68366 .50121 L .69382 .49838 L F
.549 .923 .931 r
.46305 .517 m .4573 .51686 L .46708 .51288 L F
.625 .754 .939 r
.82907 .50978 m .83517 .50197 L .83951 .50737 L F
.82907 .50978 m .82469 .50438 L .83517 .50197 L F
.642 .759 .933 r
.71362 .50647 m .71906 .49823 L .72382 .50369 L F
.71362 .50647 m .70884 .50102 L .71906 .49823 L F
.554 .825 .996 r
.20596 .4697 m .20838 .46444 L .21505 .46843 L F
.20596 .4697 m .19919 .46649 L .20838 .46444 L F
.64 .758 .934 r
.73874 .50638 m .74433 .49819 L .74899 .50365 L F
.73874 .50638 m .73405 .50093 L .74433 .49819 L F
.582 .742 .952 r
.91967 .51609 m .92639 .50931 L .9304 .51449 L F
.91967 .51609 m .91563 .51088 L .92639 .50931 L F
.617 .752 .942 r
.8543 .5104 m .86056 .50279 L .86481 .50815 L F
.8543 .5104 m .85001 .50503 L .86056 .50279 L F
.649 .787 .948 r
.54805 .50688 m .55261 .49903 L .55794 .5039 L F
.54805 .50688 m .5427 .50207 L .55261 .49903 L F
.213 0 .112 r
.42811 .52935 m .43164 .5352 L .43782 .52509 L F
.42811 .52935 m .42179 .5419 L .43164 .5352 L F
.65 .808 .959 r
.52298 .50815 m .52741 .5007 L .53282 .50511 L F
.52298 .50815 m .51754 .50384 L .52741 .5007 L F
.648 .776 .941 r
.57313 .50598 m .57782 .49792 L .58306 .50303 L F
.57313 .50598 m .56786 .50091 L .57782 .49792 L F
.636 .757 .935 r
.76389 .5064 m .76961 .49828 L .77419 .50373 L F
.76389 .5064 m .75928 .50095 L .76961 .49828 L F
.648 .77 .938 r
.59821 .50531 m .60304 .49713 L .60819 .50238 L F
.59821 .50531 m .59303 .50008 L .60304 .49713 L F
.647 .851 .978 r
.4979 .51012 m .50218 .50349 L .5077 .50698 L F
.4979 .51012 m .49235 .50684 L .50218 .50349 L F
.647 .766 .936 r
.6233 .50479 m .62826 .49654 L .63333 .50188 L F
.6233 .50479 m .61821 .49946 L .62826 .49654 L F
.632 .756 .937 r
.78906 .50655 m .79493 .49852 L .79943 .50396 L F
.78906 .50655 m .78454 .50111 L .79493 .49852 L F
.606 .749 .946 r
.87958 .51132 m .88601 .50398 L .89018 .50928 L F
.87958 .51132 m .87538 .506 L .88601 .50398 L F
.646 .763 .934 r
.6484 .50437 m .6535 .4961 L .65848 .5015 L F
.6484 .50437 m .6434 .49899 L .6535 .4961 L F
.644 .761 .934 r
.67352 .50406 m .67876 .49577 L .68366 .50121 L F
.67352 .50406 m .6686 .49863 L .67876 .49577 L F
.627 .754 .938 r
.81427 .50685 m .82029 .49896 L .82469 .50438 L F
.81427 .50685 m .80983 .50143 L .82029 .49896 L F
.735 .853 .936 r
.18046 .47496 m .18305 .46653 L .18988 .47004 L F
.18046 .47496 m .17359 .47158 L .18305 .46653 L F
.643 .76 .934 r
.69866 .50383 m .70403 .49556 L .70884 .50102 L F
.69866 .50383 m .69382 .49838 L .70403 .49556 L F
.168 .581 .936 r
.23059 .47347 m .23293 .47086 L .23935 .47687 L F
.23059 .47347 m .22404 .46888 L .23293 .47086 L F
.591 .745 .95 r
.90494 .51264 m .91156 .50565 L .91563 .51088 L F
.90494 .51264 m .90084 .50738 L .91156 .50565 L F
.64 .759 .934 r
.72382 .50369 m .72933 .49546 L .73405 .50093 L F
.72382 .50369 m .71906 .49823 L .72933 .49546 L F
.62 .753 .941 r
.83951 .50737 m .84569 .49965 L .85001 .50503 L F
.83951 .50737 m .83517 .50197 L .84569 .49965 L F
.147 0 .014 r
.43782 .52509 m .44149 .52893 L .44755 .52093 L F
.43782 .52509 m .43164 .5352 L .44149 .52893 L F
.638 .758 .935 r
.74899 .50365 m .75464 .49548 L .75928 .50095 L F
.74899 .50365 m .74433 .49819 L .75464 .49548 L F
0 0 0 r
.41509 .41524 m .41872 .41335 L .42484 .40934 L F
.40521 .42533 m .40884 .42144 L .41509 .41524 L F
.41509 .41524 m .40884 .42144 L .41872 .41335 L F
0 .372 .827 r
.24572 .48289 m .24809 .48144 L .2543 .48936 L F
.649 .786 .947 r
.55794 .5039 m .56256 .49599 L .56786 .50091 L F
.55794 .5039 m .55261 .49903 L .56256 .49599 L F
.65 .804 .957 r
.53282 .50511 m .53731 .49756 L .5427 .50207 L F
.53282 .50511 m .52741 .5007 L .53731 .49756 L F
.648 .775 .941 r
.58306 .50303 m .58782 .49493 L .59303 .50008 L F
.58306 .50303 m .57782 .49792 L .58782 .49493 L F
.611 .75 .944 r
.86481 .50815 m .87116 .50066 L .87538 .506 L F
.86481 .50815 m .86056 .50279 L .87116 .50066 L F
.73 .913 .551 r
.39514 .43983 m .39884 .43274 L .40521 .42533 L F
0 0 0 r
.40521 .42533 m .39884 .43274 L .40884 .42144 L F
.647 .769 .938 r
.60819 .50238 m .61308 .49418 L .61821 .49946 L F
.60819 .50238 m .60304 .49713 L .61308 .49418 L F
.634 .756 .936 r
.77419 .50373 m .77999 .49565 L .78454 .50111 L F
.77419 .50373 m .76961 .49828 L .77999 .49565 L F
0 .14 .686 r
.26633 .50882 m .26887 .50729 L .27456 .52144 L F
.648 .844 .975 r
.5077 .50698 m .51205 .50015 L .51754 .50384 L F
.5077 .50698 m .50218 .50349 L .51205 .50015 L F
.438 .75 .994 r
.21505 .46843 m .21747 .46393 L .22404 .46888 L F
.21505 .46843 m .20838 .46444 L .21747 .46393 L F
.57 .738 .956 r
.9304 .51449 m .93723 .50797 L .9412 .51311 L F
.9304 .51449 m .92639 .50931 L .93723 .50797 L F
.646 .766 .936 r
.63333 .50188 m .63836 .49362 L .6434 .49899 L F
.63333 .50188 m .62826 .49654 L .63836 .49362 L F
.685 .845 .959 r
.18988 .47004 m .19242 .4626 L .19919 .46649 L F
.18988 .47004 m .18305 .46653 L .19242 .4626 L F
.455 0 0 r
.45 .40737 m .45375 .41166 L .4595 .41544 L F
.45 .40737 m .44412 .40823 L .45375 .41166 L F
.645 .763 .935 r
.65848 .5015 m .66365 .49321 L .6686 .49863 L F
.65848 .5015 m .6535 .4961 L .66365 .49321 L F
.629 .755 .938 r
.79943 .50396 m .80537 .49599 L .80983 .50143 L F
.79943 .50396 m .79493 .49852 L .80537 .49599 L F
.598 .747 .948 r
.89018 .50928 m .89671 .5021 L .90084 .50738 L F
.89018 .50928 m .88601 .50398 L .89671 .5021 L F
0 0 0 r
.42484 .40934 m .42852 .40844 L .4345 .40721 L F
.42484 .40934 m .41872 .41335 L .42852 .40844 L F
.643 .761 .934 r
.68366 .50121 m .68896 .49293 L .69382 .49838 L F
.68366 .50121 m .67876 .49577 L .68896 .49293 L F
.623 .754 .94 r
.82469 .50438 m .83079 .49656 L .83517 .50197 L F
.82469 .50438 m .82029 .49896 L .83079 .49656 L F
.063 0 0 r
.44755 .52093 m .45135 .52303 L .4573 .51686 L F
.44755 .52093 m .44149 .52893 L .45135 .52303 L F
.641 .76 .934 r
.70884 .50102 m .71428 .49276 L .71906 .49823 L F
.70884 .50102 m .70403 .49556 L .71428 .49276 L F
.639 .758 .935 r
.73405 .50093 m .73963 .49271 L .74433 .49819 L F
.73405 .50093 m .72933 .49546 L .73963 .49271 L F
.615 .752 .943 r
.85001 .50503 m .85627 .49742 L .86056 .50279 L F
.85001 .50503 m .84569 .49965 L .85627 .49742 L F
.58 .742 .953 r
.91563 .51088 m .92236 .50411 L .92639 .50931 L F
.91563 .51088 m .91156 .50565 L .92236 .50411 L F
.228 .124 .521 r
.27898 .61037 m .27681 .5478 L .28381 .57911 L F
.636 .757 .936 r
.75928 .50095 m .765 .4928 L .76961 .49828 L F
.75928 .50095 m .75464 .49548 L .765 .4928 L F
.649 .784 .946 r
.56786 .50091 m .57255 .49294 L .57782 .49792 L F
.56786 .50091 m .56256 .49599 L .57255 .49294 L F
.65 .801 .955 r
.5427 .50207 m .54725 .49443 L .55261 .49903 L F
.5427 .50207 m .53731 .49756 L .54725 .49443 L F
.73 .913 .551 r
.39514 .43983 m .3887 .44707 L .39884 .43274 L F
.909 .97 .667 r
.38486 .45859 m .3887 .44707 L .39514 .43983 L F
.648 .775 .941 r
.59303 .50008 m .59785 .49194 L .60304 .49713 L F
.59303 .50008 m .58782 .49493 L .59785 .49194 L F
.434 .224 .493 r
.36836 .63498 m .37235 .58435 L .36236 .59533 L F
.36836 .63498 m .36236 .59533 L .36114 .63735 L F
.36114 .63735 m .36236 .59533 L .35911 .63834 L F
.543 .322 .53 r
.36147 .61705 m .3764 .50137 L .37137 .61408 L F
.36147 .61705 m .36199 .60612 L .3764 .50137 L F
.745 .524 .595 r
.36199 .60612 m .36984 .5085 L .3764 .50137 L F
.65 .836 .972 r
.51754 .50384 m .52195 .49683 L .52741 .5007 L F
.51754 .50384 m .51205 .50015 L .52195 .49683 L F
.647 .769 .938 r
.61821 .49946 m .62317 .49123 L .62826 .49654 L F
.61821 .49946 m .61308 .49418 L .62317 .49123 L F
0 .26 .77 r
.2604 .49821 m .26294 .49614 L .26887 .50729 L F
.614 .816 .978 r
.19919 .46649 m .20169 .45998 L .20838 .46444 L F
.19919 .46649 m .19242 .4626 L .20169 .45998 L F
.632 .756 .937 r
.78454 .50111 m .79041 .49306 L .79493 .49852 L F
.78454 .50111 m .77999 .49565 L .79041 .49306 L F
.604 .749 .946 r
.87538 .506 m .88182 .49865 L .88601 .50398 L F
.87538 .506 m .87116 .50066 L .88182 .49865 L F
.645 .765 .936 r
.6434 .49899 m .64849 .49071 L .6535 .4961 L F
.6434 .49899 m .63836 .49362 L .64849 .49071 L F
.644 .763 .935 r
.6686 .49863 m .67383 .49034 L .67876 .49577 L F
.6686 .49863 m .66365 .49321 L .67383 .49034 L F
0 0 0 r
.4573 .51686 m .46123 .51746 L .46708 .51288 L F
.4573 .51686 m .45135 .52303 L .46123 .51746 L F
.626 .755 .939 r
.80983 .50143 m .81586 .49352 L .82029 .49896 L F
.80983 .50143 m .80537 .49599 L .81586 .49352 L F
.624 .91 .982 r
.49235 .50684 m .49661 .50136 L .50218 .50349 L F
.49235 .50684 m .48674 .50514 L .49661 .50136 L F
.642 .761 .935 r
.69382 .49838 m .69919 .49009 L .70403 .49556 L F
.69382 .49838 m .68896 .49293 L .69919 .49009 L F
.588 .744 .951 r
.90084 .50738 m .90746 .50039 L .91156 .50565 L F
.90084 .50738 m .89671 .5021 L .90746 .50039 L F
0 0 0 r
.4345 .40721 m .43826 .40646 L .44412 .40823 L F
.4345 .40721 m .42852 .40844 L .43826 .40646 L F
.64 .759 .935 r
.71906 .49823 m .72457 .48997 L .72933 .49546 L F
.71906 .49823 m .71428 .49276 L .72457 .48997 L F
.619 .753 .942 r
.83517 .50197 m .84135 .49424 L .84569 .49965 L F
.83517 .50197 m .83079 .49656 L .84135 .49424 L F
.33 .658 .972 r
.22404 .46888 m .22647 .46484 L .23293 .47086 L F
.22404 .46888 m .21747 .46393 L .22647 .46484 L F
.126 .496 .905 r
.23935 .47687 m .24179 .47404 L .24809 .48144 L F
.23935 .47687 m .23293 .47086 L .24179 .47404 L F
.637 .758 .936 r
.74433 .49819 m .74998 .48999 L .75464 .49548 L F
.74433 .49819 m .73963 .49271 L .74998 .48999 L F
.737 .831 .923 r
.17359 .47158 m .17623 .46245 L .18305 .46653 L F
.17359 .47158 m .16673 .46759 L .17623 .46245 L F
.649 .783 .945 r
.57782 .49792 m .58257 .4899 L .58782 .49493 L F
.57782 .49792 m .57255 .49294 L .58257 .4899 L F
.65 .798 .954 r
.55261 .49903 m .55723 .49129 L .56256 .49599 L F
.55261 .49903 m .54725 .49443 L .55723 .49129 L F
.609 .75 .945 r
.86056 .50279 m .86691 .4953 L .87116 .50066 L F
.86056 .50279 m .85627 .49742 L .86691 .4953 L F
.633 .757 .937 r
.76961 .49828 m .77541 .49016 L .77999 .49565 L F
.76961 .49828 m .765 .4928 L .77541 .49016 L F
.647 .774 .941 r
.60304 .49713 m .60792 .48895 L .61308 .49418 L F
.60304 .49713 m .59785 .49194 L .60792 .48895 L F
.651 .83 .969 r
.52741 .5007 m .53188 .49353 L .53731 .49756 L F
.52741 .5007 m .52195 .49683 L .53188 .49353 L F
.567 .738 .956 r
.92639 .50931 m .93323 .5028 L .93723 .50797 L F
.92639 .50931 m .92236 .50411 L .93323 .5028 L F
.646 .768 .938 r
.62826 .49654 m .63329 .48828 L .63836 .49362 L F
.62826 .49654 m .62317 .49123 L .63329 .48828 L F
0 0 0 r
.46708 .51288 m .46123 .51746 L .47111 .51217 L F
.629 .756 .938 r
.79493 .49852 m .80088 .49052 L .80537 .49599 L F
.79493 .49852 m .79041 .49306 L .80088 .49052 L F
.645 .765 .936 r
.6535 .4961 m .65866 .4878 L .66365 .49321 L F
.6535 .4961 m .64849 .49071 L .65866 .4878 L F
.524 .765 .985 r
.20838 .46444 m .21087 .45872 L .21747 .46393 L F
.20838 .46444 m .20169 .45998 L .21087 .45872 L F
.635 .898 .985 r
.50218 .50349 m .50651 .49764 L .51205 .50015 L F
.50218 .50349 m .49661 .50136 L .50651 .49764 L F
.643 .763 .935 r
.67876 .49577 m .68405 .48747 L .68896 .49293 L F
.67876 .49577 m .67383 .49034 L .68405 .48747 L F
.596 .747 .949 r
.88601 .50398 m .89255 .49679 L .89671 .5021 L F
.88601 .50398 m .88182 .49865 L .89255 .49679 L F
.622 .754 .941 r
.82029 .49896 m .82639 .49112 L .83079 .49656 L F
.82029 .49896 m .81586 .49352 L .82639 .49112 L F
.7 .826 .943 r
.18305 .46653 m .18565 .45825 L .19242 .4626 L F
.18305 .46653 m .17623 .46245 L .18565 .45825 L F
.041 .367 .836 r
.2543 .48936 m .25685 .48659 L .26294 .49614 L F
.2543 .48936 m .24809 .48144 L .25685 .48659 L F
.641 .761 .935 r
.70403 .49556 m .70947 .48728 L .71428 .49276 L F
.70403 .49556 m .69919 .49009 L .70947 .48728 L F
.909 .97 .667 r
.38486 .45859 m .37841 .46397 L .3887 .44707 L F
.96 .912 .723 r
.37436 .48109 m .37841 .46397 L .38486 .45859 L F
.638 .759 .936 r
.72933 .49546 m .7349 .48722 L .73963 .49271 L F
.72933 .49546 m .72457 .48997 L .7349 .48722 L F
.614 .752 .944 r
.84569 .49965 m .85196 .49201 L .85627 .49742 L F
.84569 .49965 m .84135 .49424 L .85196 .49201 L F
.577 .741 .954 r
.91156 .50565 m .91829 .49888 L .92236 .50411 L F
.91156 .50565 m .90746 .50039 L .91829 .49888 L F
.635 .758 .937 r
.75464 .49548 m .76036 .48731 L .765 .4928 L F
.75464 .49548 m .74998 .48999 L .76036 .48731 L F
.65 .795 .952 r
.56256 .49599 m .56724 .48816 L .57255 .49294 L F
.56256 .49599 m .55723 .49129 L .56724 .48816 L F
.648 .781 .945 r
.58782 .49493 m .59263 .48686 L .59785 .49194 L F
.58782 .49493 m .58257 .4899 L .59263 .48686 L F
.647 .773 .94 r
.61308 .49418 m .61803 .48597 L .62317 .49123 L F
.61308 .49418 m .60792 .48895 L .61803 .48597 L F
.651 .824 .966 r
.53731 .49756 m .54185 .49024 L .54725 .49443 L F
.53731 .49756 m .53188 .49353 L .54185 .49024 L F
.631 .756 .938 r
.77999 .49565 m .78586 .48757 L .79041 .49306 L F
.77999 .49565 m .77541 .49016 L .78586 .48757 L F
.602 .748 .947 r
.87116 .50066 m .8776 .4933 L .88182 .49865 L F
.87116 .50066 m .86691 .4953 L .8776 .4933 L F
.645 .768 .938 r
.63836 .49362 m .64344 .48534 L .64849 .49071 L F
.63836 .49362 m .63329 .48828 L .64344 .48534 L F
.42 .202 .474 r
.39538 .62398 m .3922 .56523 L .39219 .62506 L F
.39538 .62398 m .40208 .55684 L .3922 .56523 L F
.39219 .62506 m .3922 .56523 L .38652 .62784 L F
.426 .211 .482 r
.38652 .62784 m .3922 .56523 L .3823 .57437 L F
.38652 .62784 m .3823 .57437 L .38166 .62946 L F
.38166 .62946 m .3823 .57437 L .3775 .63149 L F
0 .29 .706 r
.4595 .41544 m .46343 .41674 L .4691 .42432 L F
.4595 .41544 m .45375 .41166 L .46343 .41674 L F
.644 .765 .936 r
.66365 .49321 m .66887 .4849 L .67383 .49034 L F
.66365 .49321 m .65866 .4878 L .66887 .4849 L F
.643 .886 .985 r
.51205 .50015 m .51645 .49397 L .52195 .49683 L F
.51205 .50015 m .50651 .49764 L .51645 .49397 L F
.413 .19 .464 r
.40404 .61987 m .40208 .55684 L .40296 .62024 L F
.40404 .61987 m .41194 .54909 L .40208 .55684 L F
.40296 .62024 m .40208 .55684 L .39538 .62398 L F
.625 .755 .94 r
.80537 .49599 m .81139 .48805 L .81586 .49352 L F
.80537 .49599 m .80088 .49052 L .81139 .48805 L F
.125 .65 .879 r
.44412 .40823 m .44798 .40702 L .45375 .41166 L F
.44412 .40823 m .43826 .40646 L .44798 .40702 L F
.646 .806 .96 r
.19242 .4626 m .19499 .45517 L .20169 .45998 L F
.19242 .4626 m .18565 .45825 L .19499 .45517 L F
.642 .762 .936 r
.68896 .49293 m .69432 .48462 L .69919 .49009 L F
.68896 .49293 m .68405 .48747 L .69432 .48462 L F
.404 .176 .452 r
.41194 .54909 m .41372 .60536 L .42179 .5419 L F
.40793 .61794 m .41194 .54909 L .40404 .61987 L F
.40793 .61794 m .41372 .60536 L .41194 .54909 L F
.639 .76 .936 r
.71428 .49276 m .71978 .48448 L .72457 .48997 L F
.71428 .49276 m .70947 .48728 L .71978 .48448 L F
.586 .744 .951 r
.89671 .5021 m .90334 .49511 L .90746 .50039 L F
.89671 .5021 m .89255 .49679 L .90334 .49511 L F
.254 .573 .941 r
.23293 .47086 m .23543 .46697 L .24179 .47404 L F
.23293 .47086 m .22647 .46484 L .23543 .46697 L F
.618 .753 .942 r
.83079 .49656 m .83698 .4888 L .84135 .49424 L F
.83079 .49656 m .82639 .49112 L .83698 .4888 L F
.437 .228 .497 r
.35911 .63834 m .36236 .59533 L .35229 .60744 L F
.223 .242 .67 r
.27977 .54199 m .27456 .52144 L .28307 .53174 L F
.158 .279 .739 r
.27456 .52144 m .27754 .5152 L .28307 .53174 L F
.27456 .52144 m .26887 .50729 L .27754 .5152 L F
.636 .759 .937 r
.73963 .49271 m .74528 .48449 L .74998 .48999 L F
.73963 .49271 m .7349 .48722 L .74528 .48449 L F
.428 .696 .976 r
.21747 .46393 m .21996 .4588 L .22647 .46484 L F
.21747 .46393 m .21087 .45872 L .21996 .4588 L F
.393 .158 .436 r
.42179 .5419 m .42418 .58579 L .43164 .5352 L F
.42179 .5419 m .41372 .60536 L .42418 .58579 L F
.79 .999 .812 r
.40884 .42144 m .41263 .41424 L .41872 .41335 L F
.40884 .42144 m .40265 .42365 L .41263 .41424 L F
.863 .996 .774 r
.39884 .43274 m .40265 .42365 L .40884 .42144 L F
.608 .75 .945 r
.85627 .49742 m .86263 .4899 L .86691 .4953 L F
.85627 .49742 m .85196 .49201 L .86263 .4899 L F
.633 .757 .938 r
.765 .4928 m .7708 .48466 L .77541 .49016 L F
.765 .4928 m .76036 .48731 L .7708 .48466 L F
.406 .848 .741 r
.48674 .50514 m .49095 .5023 L .49661 .50136 L F
.48674 .50514 m .48102 .50713 L .49095 .5023 L F
.65 .793 .951 r
.57255 .49294 m .57729 .48504 L .58257 .4899 L F
.57255 .49294 m .56724 .48816 L .57729 .48504 L F
.648 .78 .944 r
.59785 .49194 m .60273 .48382 L .60792 .48895 L F
.59785 .49194 m .59263 .48686 L .60273 .48382 L F
.737 .817 .914 r
.16673 .46759 m .16939 .45797 L .17623 .46245 L F
.16673 .46759 m .15986 .46318 L .16939 .45797 L F
.704 .983 .885 r
.41872 .41335 m .42253 .40752 L .42852 .40844 L F
.41872 .41335 m .41263 .41424 L .42253 .40752 L F
.139 .45 .882 r
.24809 .48144 m .25065 .47798 L .25685 .48659 L F
.24809 .48144 m .24179 .47404 L .25065 .47798 L F
.652 .818 .963 r
.54725 .49443 m .55186 .48696 L .55723 .49129 L F
.54725 .49443 m .54185 .49024 L .55186 .48696 L F
.646 .772 .94 r
.62317 .49123 m .62818 .48299 L .63329 .48828 L F
.62317 .49123 m .61803 .48597 L .62818 .48299 L F
.564 .737 .957 r
.92236 .50411 m .9292 .4976 L .93323 .5028 L F
.92236 .50411 m .91829 .49888 L .9292 .4976 L F
.437 .228 .497 r
.35911 .63834 m .35229 .60744 L .3511 .64095 L F
.3511 .64095 m .35229 .60744 L .3498 .64158 L F
.44 .232 .5 r
.3498 .64158 m .35229 .60744 L .34214 .62086 L F
.628 .756 .939 r
.79041 .49306 m .79635 .48504 L .80088 .49052 L F
.79041 .49306 m .78586 .48757 L .79635 .48504 L F
.142 .333 .794 r
.26887 .50729 m .27171 .50243 L .27754 .5152 L F
.26887 .50729 m .26294 .49614 L .27171 .50243 L F
.644 .767 .938 r
.64849 .49071 m .65364 .48241 L .65866 .4878 L F
.64849 .49071 m .64344 .48534 L .65364 .48241 L F
.863 .996 .774 r
.39884 .43274 m .39256 .43556 L .40265 .42365 L F
.917 .977 .763 r
.3887 .44707 m .39256 .43556 L .39884 .43274 L F
.378 .136 .415 r
.43164 .5352 m .4345 .56909 L .44149 .52893 L F
.43164 .5352 m .42418 .58579 L .4345 .56909 L F
.329 .238 .598 r
.28381 .57911 m .27977 .54199 L .28806 .55613 L F
.223 .242 .67 r
.27977 .54199 m .28307 .53174 L .28806 .55613 L F
.648 .874 .983 r
.52195 .49683 m .52641 .49035 L .53188 .49353 L F
.52195 .49683 m .51645 .49397 L .52641 .49035 L F
.643 .764 .937 r
.67383 .49034 m .67912 .48202 L .68405 .48747 L F
.67383 .49034 m .66887 .4849 L .67912 .48202 L F
.594 .746 .949 r
.88182 .49865 m .88836 .49146 L .89255 .49679 L F
.88182 .49865 m .8776 .4933 L .88836 .49146 L F
.621 .754 .941 r
.81586 .49352 m .82196 .48565 L .82639 .49112 L F
.81586 .49352 m .81139 .48805 L .82196 .48565 L F
.64 .762 .936 r
.69919 .49009 m .70462 .48179 L .70947 .48728 L F
.69919 .49009 m .69432 .48462 L .70462 .48179 L F
.574 .77 .971 r
.20169 .45998 m .20424 .45332 L .21087 .45872 L F
.20169 .45998 m .19499 .45517 L .20424 .45332 L F
.638 .76 .937 r
.72457 .48997 m .73014 .48171 L .7349 .48722 L F
.72457 .48997 m .71978 .48448 L .73014 .48171 L F
.708 .813 .93 r
.17623 .46245 m .17886 .45355 L .18565 .45825 L F
.17623 .46245 m .16939 .45797 L .17886 .45355 L F
.36 .106 .388 r
.44149 .52893 m .44472 .55473 L .45135 .52303 L F
.44149 .52893 m .4345 .56909 L .44472 .55473 L F
.612 .752 .944 r
.84135 .49424 m .84762 .48658 L .85196 .49201 L F
.84135 .49424 m .83698 .4888 L .84762 .48658 L F
.601 .927 .965 r
.42852 .40844 m .43237 .40348 L .43826 .40646 L F
.42852 .40844 m .42253 .40752 L .43237 .40348 L F
.575 .74 .954 r
.90746 .50039 m .9142 .49362 L .91829 .49888 L F
.90746 .50039 m .90334 .49511 L .9142 .49362 L F
.634 .758 .937 r
.74998 .48999 m .75569 .48179 L .76036 .48731 L F
.74998 .48999 m .74528 .48449 L .75569 .48179 L F
.499 .908 .849 r
.49661 .50136 m .50091 .49767 L .50651 .49764 L F
.49661 .50136 m .49095 .5023 L .50091 .49767 L F
.44 .232 .5 r
.3498 .64158 m .34214 .62086 L .34116 .64438 L F
.34116 .64438 m .34214 .62086 L .34043 .64473 L F
.442 .235 .503 r
.34043 .64473 m .34214 .62086 L .33188 .63581 L F
.257 0 .238 r
.47111 .51217 m .46498 .53139 L .47505 .52178 L F
.124 .001 .427 r
.47393 .59829 m .47505 .52178 L .4739 .59832 L F
.113 0 .422 r
.4739 .59832 m .47505 .52178 L .46498 .53139 L F
.543 .323 .53 r
.47662 .59005 m .47471 .43328 L .47286 .58424 L F
.54 .322 .532 r
.47286 .58424 m .47471 .43328 L .48436 .44702 L F
0 .21 .736 r
.47471 .43328 m .4788 .43304 L .48436 .44702 L F
.943 .807 .68 r
.36984 .5085 m .36364 .50636 L .37436 .48109 L F
.96 .912 .723 r
.37436 .48109 m .368 .48269 L .37841 .46397 L F
.911 .795 .719 r
.36364 .50636 m .368 .48269 L .37436 .48109 L F
.649 .79 .949 r
.58257 .4899 m .58738 .48192 L .59263 .48686 L F
.58257 .4899 m .57729 .48504 L .58738 .48192 L F
.63 .757 .939 r
.77541 .49016 m .78127 .48206 L .78586 .48757 L F
.77541 .49016 m .7708 .48466 L .78127 .48206 L F
.647 .778 .943 r
.60792 .48895 m .61287 .48078 L .61803 .48597 L F
.60792 .48895 m .60273 .48382 L .61287 .48078 L F
.652 .813 .96 r
.55723 .49129 m .5619 .48369 L .56724 .48816 L F
.55723 .49129 m .55186 .48696 L .5619 .48369 L F
.601 .748 .948 r
.86691 .4953 m .87335 .48792 L .8776 .4933 L F
.86691 .4953 m .86263 .4899 L .87335 .48792 L F
.645 .771 .94 r
.63329 .48828 m .63836 .48001 L .64344 .48534 L F
.63329 .48828 m .62818 .48299 L .63836 .48001 L F
.745 .524 .595 r
.36199 .60612 m .35823 .5515 L .36984 .5085 L F
.817 .63 .649 r
.35823 .5515 m .36364 .50636 L .36984 .5085 L F
.917 .977 .763 r
.3887 .44707 m .38237 .44957 L .39256 .43556 L F
.941 .935 .763 r
.37841 .46397 m .38237 .44957 L .3887 .44707 L F
.159 .389 .836 r
.26294 .49614 m .2657 .49169 L .27171 .50243 L F
.26294 .49614 m .25685 .48659 L .2657 .49169 L F
.644 .767 .938 r
.65866 .4878 m .66388 .47949 L .66887 .4849 L F
.65866 .4878 m .65364 .48241 L .66388 .47949 L F
.335 .068 .352 r
.45135 .52303 m .45487 .54228 L .46123 .51746 L F
.45135 .52303 m .44472 .55473 L .45487 .54228 L F
.652 .862 .979 r
.53188 .49353 m .53642 .48677 L .54185 .49024 L F
.53188 .49353 m .52641 .49035 L .53642 .48677 L F
.624 .755 .94 r
.80088 .49052 m .8069 .48256 L .81139 .48805 L F
.80088 .49052 m .79635 .48504 L .8069 .48256 L F
.642 .764 .937 r
.68405 .48747 m .68941 .47915 L .69432 .48462 L F
.68405 .48747 m .67912 .48202 L .68941 .47915 L F
.345 .623 .955 r
.22647 .46484 m .229 .46008 L .23543 .46697 L F
.22647 .46484 m .21996 .4588 L .229 .46008 L F
.149 .558 .928 r
.45375 .41166 m .45772 .40959 L .46343 .41674 L F
.45375 .41166 m .44798 .40702 L .45772 .40959 L F
.639 .762 .937 r
.70947 .48728 m .71496 .47898 L .71978 .48448 L F
.70947 .48728 m .70462 .48179 L .71496 .47898 L F
.665 .799 .946 r
.18565 .45825 m .18826 .4501 L .19499 .45517 L F
.18565 .45825 m .17886 .45355 L .18826 .4501 L F
.584 .743 .952 r
.89255 .49679 m .89918 .48978 L .90334 .49511 L F
.89255 .49679 m .88836 .49146 L .89918 .48978 L F
.617 .753 .943 r
.82639 .49112 m .83257 .48334 L .83698 .4888 L F
.82639 .49112 m .82196 .48565 L .83257 .48334 L F
.222 .513 .911 r
.24179 .47404 m .24437 .46996 L .25065 .47798 L F
.24179 .47404 m .23543 .46697 L .24437 .46996 L F
.636 .76 .937 r
.7349 .48722 m .74054 .47897 L .74528 .48449 L F
.7349 .48722 m .73014 .48171 L .74054 .47897 L F
.564 .933 .918 r
.50651 .49764 m .51089 .49321 L .51645 .49397 L F
.50651 .49764 m .50091 .49767 L .51089 .49321 L F
.492 .717 .971 r
.21087 .45872 m .21341 .45273 L .21996 .4588 L F
.21087 .45872 m .20424 .45332 L .21341 .45273 L F
.442 .235 .503 r
.34043 .64473 m .33188 .63581 L .33133 .64766 L F
.33133 .64766 m .33188 .63581 L .33103 .6478 L F
.529 .307 .522 r
.33103 .6478 m .33188 .63581 L .32279 .65044 L F
.302 .018 .304 r
.46123 .51746 m .46498 .53139 L .47111 .51217 L F
.46123 .51746 m .45487 .54228 L .46498 .53139 L F
.632 .758 .938 r
.76036 .48731 m .76615 .47914 L .7708 .48466 L F
.76036 .48731 m .75569 .48179 L .76615 .47914 L F
.606 .75 .946 r
.85196 .49201 m .85831 .48447 L .86263 .4899 L F
.85196 .49201 m .84762 .48658 L .85831 .48447 L F
.484 .813 1 r
.43826 .40646 m .44217 .40196 L .44798 .40702 L F
.43826 .40646 m .43237 .40348 L .44217 .40196 L F
.649 .787 .948 r
.59263 .48686 m .5975 .47881 L .60273 .48382 L F
.59263 .48686 m .58738 .48192 L .5975 .47881 L F
.652 .808 .958 r
.56724 .48816 m .57198 .48044 L .57729 .48504 L F
.56724 .48816 m .5619 .48369 L .57198 .48044 L F
.647 .777 .943 r
.61803 .48597 m .62304 .47775 L .62818 .48299 L F
.61803 .48597 m .61287 .48078 L .62304 .47775 L F
.562 .736 .957 r
.91829 .49888 m .92515 .49236 L .9292 .4976 L F
.91829 .49888 m .9142 .49362 L .92515 .49236 L F
.627 .756 .94 r
.78586 .48757 m .7918 .47952 L .79635 .48504 L F
.78586 .48757 m .78127 .48206 L .7918 .47952 L F
.645 .77 .94 r
.64344 .48534 m .64859 .47704 L .65364 .48241 L F
.64344 .48534 m .63836 .48001 L .64859 .47704 L F
.736 .807 .908 r
.15986 .46318 m .16253 .45319 L .16939 .45797 L F
.15986 .46318 m .15297 .45844 L .16253 .45319 L F
.654 .851 .975 r
.54185 .49024 m .54645 .48323 L .55186 .48696 L F
.54185 .49024 m .53642 .48677 L .54645 .48323 L F
.643 .766 .938 r
.66887 .4849 m .67415 .47657 L .67912 .48202 L F
.66887 .4849 m .66388 .47949 L .67415 .47657 L F
.592 .746 .95 r
.8776 .4933 m .88414 .48608 L .88836 .49146 L F
.8776 .4933 m .87335 .48792 L .88414 .48608 L F
.62 .754 .942 r
.81139 .48805 m .81749 .48016 L .82196 .48565 L F
.81139 .48805 m .8069 .48256 L .81749 .48016 L F
.64 .763 .937 r
.69432 .48462 m .69974 .47629 L .70462 .48179 L F
.69432 .48462 m .68941 .47915 L .69974 .47629 L F
.192 .44 .868 r
.25685 .48659 m .25957 .48216 L .2657 .49169 L F
.25685 .48659 m .25065 .47798 L .25957 .48216 L F
.941 .935 .763 r
.37841 .46397 m .37208 .46508 L .38237 .44957 L F
.928 .87 .76 r
.368 .48269 m .37208 .46508 L .37841 .46397 L F
.607 .771 .959 r
.19499 .45517 m .19757 .44778 L .20424 .45332 L F
.19499 .45517 m .18826 .4501 L .19757 .44778 L F
.637 .761 .937 r
.71978 .48448 m .72535 .47619 L .73014 .48171 L F
.71978 .48448 m .71496 .47898 L .72535 .47619 L F
.606 .935 .956 r
.51645 .49397 m .5209 .4889 L .52641 .49035 L F
.51645 .49397 m .51089 .49321 L .5209 .4889 L F
.611 .752 .945 r
.83698 .4888 m .84324 .48112 L .84762 .48658 L F
.83698 .4888 m .83257 .48334 L .84324 .48112 L F
.634 .759 .938 r
.74528 .48449 m .75099 .47626 L .75569 .48179 L F
.74528 .48449 m .74054 .47897 L .75099 .47626 L F
.573 .74 .955 r
.90334 .49511 m .91008 .48832 L .9142 .49362 L F
.90334 .49511 m .89918 .48978 L .91008 .48832 L F
.714 .804 .921 r
.16939 .45797 m .17204 .44859 L .17886 .45355 L F
.16939 .45797 m .16253 .45319 L .17204 .44859 L F
.397 .334 .67 r
.28806 .55613 m .28307 .53174 L .29193 .53868 L F
.341 .363 .738 r
.28307 .53174 m .28644 .52107 L .29193 .53868 L F
.28307 .53174 m .27754 .5152 L .28644 .52107 L F
.629 .757 .939 r
.7708 .48466 m .77666 .47653 L .78127 .48206 L F
.7708 .48466 m .76615 .47914 L .77666 .47653 L F
.299 .396 .794 r
.27754 .5152 m .28065 .50746 L .28644 .52107 L F
.27754 .5152 m .27171 .50243 L .28065 .50746 L F
.649 .785 .947 r
.60273 .48382 m .60766 .4757 L .61287 .48078 L F
.60273 .48382 m .5975 .47881 L .60766 .4757 L F
.599 .748 .948 r
.86263 .4899 m .86907 .4825 L .87335 .48792 L F
.86263 .4899 m .85831 .48447 L .86907 .4825 L F
.652 .803 .956 r
.57729 .48504 m .58209 .4772 L .58738 .48192 L F
.57729 .48504 m .57198 .48044 L .58209 .4772 L F
.646 .775 .942 r
.62818 .48299 m .63325 .47473 L .63836 .48001 L F
.62818 .48299 m .62304 .47775 L .63325 .47473 L F
.819 .96 .903 r
.41263 .41424 m .41653 .40541 L .42253 .40752 L F
.41263 .41424 m .40654 .41345 L .41653 .40541 L F
.873 .968 .852 r
.40265 .42365 m .40654 .41345 L .41263 .41424 L F
.195 0 .147 r
.48102 .50713 m .48511 .51323 L .49095 .5023 L F
.873 .968 .852 r
.40265 .42365 m .39647 .42376 L .40654 .41345 L F
.906 .956 .816 r
.39256 .43556 m .39647 .42376 L .40265 .42365 L F
.644 .769 .94 r
.65364 .48241 m .65885 .47408 L .66388 .47949 L F
.65364 .48241 m .64859 .47704 L .65885 .47408 L F
.655 .841 .971 r
.55186 .48696 m .55652 .47973 L .5619 .48369 L F
.55186 .48696 m .54645 .48323 L .55652 .47973 L F
.623 .755 .941 r
.79635 .48504 m .80237 .47704 L .8069 .48256 L F
.79635 .48504 m .7918 .47952 L .80237 .47704 L F
.642 .766 .938 r
.67912 .48202 m .68447 .47368 L .68941 .47915 L F
.67912 .48202 m .67415 .47657 L .68447 .47368 L F
.41 .655 .959 r
.21996 .4588 m .22252 .45332 L .229 .46008 L F
.21996 .4588 m .21341 .45273 L .22252 .45332 L F
.289 .561 .93 r
.23543 .46697 m .23802 .4623 L .24437 .46996 L F
.23543 .46697 m .229 .46008 L .23802 .4623 L F
.639 .763 .938 r
.70462 .48179 m .71011 .47346 L .71496 .47898 L F
.70462 .48179 m .69974 .47629 L .71011 .47346 L F
.616 .753 .943 r
.82196 .48565 m .82814 .47784 L .83257 .48334 L F
.82196 .48565 m .81749 .48016 L .82814 .47784 L F
.583 .743 .952 r
.88836 .49146 m .895 .48443 L .89918 .48978 L F
.88836 .49146 m .88414 .48608 L .895 .48443 L F
.739 .92 .953 r
.42253 .40752 m .42644 .39981 L .43237 .40348 L F
.42253 .40752 m .41653 .40541 L .42644 .39981 L F
.436 .264 .548 r
.28377 .62945 m .28381 .57911 L .29172 .60048 L F
.228 .124 .521 r
.28065 .63395 m .28381 .57911 L .28377 .62945 L F
.28065 .63395 m .27898 .61037 L .28381 .57911 L F
.329 .238 .598 r
.28381 .57911 m .28806 .55613 L .29172 .60048 L F
.632 .924 .975 r
.52641 .49035 m .53093 .48472 L .53642 .48677 L F
.52641 .49035 m .5209 .4889 L .53093 .48472 L F
.817 .63 .649 r
.35823 .5515 m .35276 .53295 L .36364 .50636 L F
.911 .795 .719 r
.36364 .50636 m .35748 .50223 L .368 .48269 L F
.834 .682 .694 r
.35276 .53295 m .35748 .50223 L .36364 .50636 L F
.679 .793 .935 r
.17886 .45355 m .18149 .44484 L .18826 .4501 L F
.17886 .45355 m .17204 .44859 L .18149 .44484 L F
.636 .761 .938 r
.73014 .48171 m .73578 .47343 L .74054 .47897 L F
.73014 .48171 m .72535 .47619 L .73578 .47343 L F
.906 .956 .816 r
.39256 .43556 m .38631 .43599 L .39647 .42376 L F
.922 .931 .795 r
.38237 .44957 m .38631 .43599 L .39256 .43556 L F
.381 .675 .975 r
.44798 .40702 m .45196 .40263 L .45772 .40959 L F
.44798 .40702 m .44217 .40196 L .45196 .40263 L F
.277 .428 .833 r
.27171 .50243 m .27468 .49606 L .28065 .50746 L F
.27171 .50243 m .2657 .49169 L .27468 .49606 L F
.536 .73 .964 r
.20424 .45332 m .20681 .44663 L .21341 .45273 L F
.20424 .45332 m .19757 .44778 L .20681 .44663 L F
.632 .759 .939 r
.75569 .48179 m .76148 .47359 L .76615 .47914 L F
.75569 .48179 m .75099 .47626 L .76148 .47359 L F
.605 .75 .946 r
.84762 .48658 m .85397 .47901 L .85831 .48447 L F
.84762 .48658 m .84324 .48112 L .85397 .47901 L F
.107 0 .02 r
.49095 .5023 m .49517 .50555 L .50091 .49767 L F
.49095 .5023 m .48511 .51323 L .49517 .50555 L F
.231 .484 .891 r
.25065 .47798 m .25335 .47338 L .25957 .48216 L F
.25065 .47798 m .24437 .46996 L .25335 .47338 L F
.185 .477 .894 r
.46343 .41674 m .4675 .4136 L .47318 .4227 L F
.46343 .41674 m .45772 .40959 L .4675 .4136 L F
.928 .87 .76 r
.368 .48269 m .36171 .48132 L .37208 .46508 L F
.887 .792 .749 r
.35748 .50223 m .36171 .48132 L .368 .48269 L F
.56 .735 .957 r
.9142 .49362 m .92106 .48709 L .92515 .49236 L F
.9142 .49362 m .91008 .48832 L .92106 .48709 L F
.626 .757 .94 r
.78127 .48206 m .78721 .47398 L .7918 .47952 L F
.78127 .48206 m .77666 .47653 L .78721 .47398 L F
.648 .783 .946 r
.61287 .48078 m .61786 .4726 L .62304 .47775 L F
.61287 .48078 m .60766 .4757 L .61786 .4726 L F
.651 .799 .953 r
.58738 .48192 m .59224 .47398 L .5975 .47881 L F
.58738 .48192 m .58209 .4772 L .59224 .47398 L F
.456 .317 .603 r
.29172 .60048 m .28806 .55613 L .29687 .56452 L F
.397 .334 .67 r
.28806 .55613 m .29193 .53868 L .29687 .56452 L F
.645 .774 .942 r
.63836 .48001 m .6435 .47171 L .64859 .47704 L F
.63836 .48001 m .63325 .47473 L .6435 .47171 L F
.656 .832 .968 r
.5619 .48369 m .56663 .47626 L .57198 .48044 L F
.5619 .48369 m .55652 .47973 L .56663 .47626 L F
.643 .769 .939 r
.66388 .47949 m .66915 .47114 L .67415 .47657 L F
.66388 .47949 m .65885 .47408 L .66915 .47114 L F
.736 .799 .903 r
.15297 .45844 m .15564 .44818 L .16253 .45319 L F
.15297 .45844 m .14605 .45346 L .15564 .44818 L F
.591 .745 .95 r
.87335 .48792 m .87989 .48068 L .88414 .48608 L F
.87335 .48792 m .86907 .4825 L .87989 .48068 L F
.619 .754 .942 r
.8069 .48256 m .813 .47463 L .81749 .48016 L F
.8069 .48256 m .80237 .47704 L .813 .47463 L F
.456 .258 .522 r
.27766 .63536 m .27898 .61037 L .28065 .63395 L F
.967 .707 .277 r
.27601 .64268 m .27898 .61037 L .27766 .63536 L F
.64 .765 .938 r
.68941 .47915 m .69483 .47079 L .69974 .47629 L F
.68941 .47915 m .68447 .47368 L .69483 .47079 L F
.633 .839 .98 r
.43237 .40348 m .43632 .39664 L .44217 .40196 L F
.43237 .40348 m .42644 .39981 L .43632 .39664 L F
.922 .931 .795 r
.38237 .44957 m .37608 .44964 L .38631 .43599 L F
.922 .895 .785 r
.37208 .46508 m .37608 .44964 L .38237 .44957 L F
.648 .908 .981 r
.53642 .48677 m .541 .48065 L .54645 .48323 L F
.53642 .48677 m .53093 .48472 L .541 .48065 L F
.637 .762 .938 r
.71496 .47898 m .72053 .47065 L .72535 .47619 L F
.71496 .47898 m .71011 .47346 L .72053 .47065 L F
.63 .772 .948 r
.18826 .4501 m .19087 .44211 L .19757 .44778 L F
.18826 .4501 m .18149 .44484 L .19087 .44211 L F
0 0 0 r
.50091 .49767 m .50523 .49859 L .51089 .49321 L F
.50091 .49767 m .49517 .50555 L .50523 .49859 L F
.61 .751 .945 r
.83257 .48334 m .83884 .47562 L .84324 .48112 L F
.83257 .48334 m .82814 .47784 L .83884 .47562 L F
.634 .76 .939 r
.74054 .47897 m .74625 .4707 L .75099 .47626 L F
.74054 .47897 m .73578 .47343 L .74625 .4707 L F
.571 .739 .955 r
.89918 .48978 m .90593 .48298 L .91008 .48832 L F
.89918 .48978 m .895 .48443 L .90593 .48298 L F
.138 .012 .433 r
.49429 .59213 m .48511 .51323 L .48422 .59513 L F
.49429 .59213 m .49517 .50555 L .48511 .51323 L F
.48422 .59513 m .48511 .51323 L .4841 .59526 L F
.541 .322 .532 r
.48311 .58108 m .48436 .44702 L .49418 .45741 L F
.54 .322 .532 r
.48239 .58132 m .48436 .44702 L .48311 .58108 L F
.47286 .58424 m .48436 .44702 L .48239 .58132 L F
.228 .326 .757 r
.48436 .44702 m .48863 .44088 L .49418 .45741 L F
.48436 .44702 m .4788 .43304 L .48863 .44088 L F
.27 .458 .861 r
.2657 .49169 m .26859 .48599 L .27468 .49606 L F
.2657 .49169 m .25957 .48216 L .26859 .48599 L F
.718 .797 .914 r
.16253 .45319 m .16519 .44342 L .17204 .44859 L F
.16253 .45319 m .15564 .44818 L .16519 .44342 L F
.629 .758 .94 r
.76615 .47914 m .77201 .47097 L .77666 .47653 L F
.76615 .47914 m .76148 .47359 L .77201 .47097 L F
.598 .748 .948 r
.85831 .48447 m .86476 .47704 L .86907 .4825 L F
.85831 .48447 m .85397 .47901 L .86476 .47704 L F
.651 .795 .951 r
.5975 .47881 m .60243 .47076 L .60766 .4757 L F
.5975 .47881 m .59224 .47398 L .60243 .47076 L F
.344 .596 .94 r
.229 .46008 m .2316 .4549 L .23802 .4623 L F
.229 .46008 m .22252 .45332 L .2316 .4549 L F
.647 .781 .945 r
.62304 .47775 m .6281 .46951 L .63325 .47473 L F
.62304 .47775 m .61786 .4726 L .6281 .46951 L F
.645 .773 .941 r
.64859 .47704 m .65379 .46871 L .65885 .47408 L F
.64859 .47704 m .6435 .47171 L .65379 .46871 L F
.623 .756 .941 r
.7918 .47952 m .79782 .47149 L .80237 .47704 L F
.7918 .47952 m .78721 .47398 L .79782 .47149 L F
.656 .823 .964 r
.57198 .48044 m .57677 .47282 L .58209 .4772 L F
.57198 .48044 m .56663 .47626 L .57677 .47282 L F
.459 .678 .959 r
.21341 .45273 m .21599 .44664 L .22252 .45332 L F
.21341 .45273 m .20681 .44663 L .21599 .44664 L F
.642 .768 .939 r
.67415 .47657 m .6795 .4682 L .68447 .47368 L F
.67415 .47657 m .66915 .47114 L .6795 .4682 L F
.188 .377 .819 r
.4788 .43304 m .48301 .42886 L .48863 .44088 L F
.4788 .43304 m .47318 .4227 L .48301 .42886 L F
0 0 0 r
.51089 .49321 m .51531 .49223 L .5209 .4889 L F
.51089 .49321 m .50523 .49859 L .51531 .49223 L F
.269 .521 .909 r
.24437 .46996 m .24705 .46511 L .25335 .47338 L F
.24437 .46996 m .23802 .4623 L .24705 .46511 L F
.639 .764 .939 r
.69974 .47629 m .70523 .46793 L .71011 .47346 L F
.69974 .47629 m .69483 .47079 L .70523 .46793 L F
.656 .891 .982 r
.54645 .48323 m .55111 .47669 L .55652 .47973 L F
.54645 .48323 m .541 .48065 L .55111 .47669 L F
.615 .753 .944 r
.81749 .48016 m .82367 .47231 L .82814 .47784 L F
.81749 .48016 m .813 .47463 L .82367 .47231 L F
.581 .742 .953 r
.88414 .48608 m .89078 .47903 L .895 .48443 L F
.88414 .48608 m .87989 .48068 L .89078 .47903 L F
.46 .427 .735 r
.29193 .53868 m .28644 .52107 L .29561 .52418 L F
.42 .454 .79 r
.28644 .52107 m .28981 .51058 L .29561 .52418 L F
.28644 .52107 m .28065 .50746 L .28981 .51058 L F
.922 .895 .785 r
.37208 .46508 m .36577 .46406 L .37608 .44964 L F
.903 .847 .779 r
.36171 .48132 m .36577 .46406 L .37208 .46508 L F
.498 .397 .67 r
.29687 .56452 m .29193 .53868 L .30114 .54158 L F
.46 .427 .735 r
.29193 .53868 m .29561 .52418 L .30114 .54158 L F
.635 .761 .939 r
.72535 .47619 m .73098 .46787 L .73578 .47343 L F
.72535 .47619 m .72053 .47065 L .73098 .46787 L F
.314 .562 .925 r
.45772 .40959 m .46179 .40507 L .4675 .4136 L F
.45772 .40959 m .45196 .40263 L .46179 .40507 L F
.689 .789 .927 r
.17204 .44859 m .17469 .43942 L .18149 .44484 L F
.17204 .44859 m .16519 .44342 L .17469 .43942 L F
.516 .73 .97 r
.44217 .40196 m .44617 .39576 L .45196 .40263 L F
.44217 .40196 m .43632 .39664 L .44617 .39576 L F
.568 .738 .956 r
.19757 .44778 m .20017 .4405 L .20681 .44663 L F
.19757 .44778 m .19087 .44211 L .20017 .4405 L F
.834 .682 .694 r
.35276 .53295 m .34693 .52138 L .35748 .50223 L F
.887 .792 .749 r
.35748 .50223 m .35132 .49737 L .36171 .48132 L F
.831 .711 .733 r
.34693 .52138 m .35132 .49737 L .35748 .50223 L F
.631 .759 .939 r
.75099 .47626 m .75677 .46802 L .76148 .47359 L F
.75099 .47626 m .74625 .4707 L .75677 .46802 L F
.604 .75 .947 r
.84324 .48112 m .8496 .47352 L .85397 .47901 L F
.84324 .48112 m .83884 .47562 L .8496 .47352 L F
.849 .921 .879 r
.40654 .41345 m .41049 .40257 L .41653 .40541 L F
.40654 .41345 m .40042 .41163 L .41049 .40257 L F
.885 .926 .843 r
.39647 .42376 m .40042 .41163 L .40654 .41345 L F
.626 .757 .941 r
.77666 .47653 m .7826 .4684 L .78721 .47398 L F
.77666 .47653 m .77201 .47097 L .7826 .4684 L F
.558 .734 .958 r
.91008 .48832 m .91694 .48177 L .92106 .48709 L F
.91008 .48832 m .90593 .48298 L .91694 .48177 L F
.386 .477 .831 r
.28065 .50746 m .28384 .4991 L .28981 .51058 L F
.28065 .50746 m .27468 .49606 L .28384 .4991 L F
.274 .485 .882 r
.25957 .48216 m .2624 .47675 L .26859 .48599 L F
.25957 .48216 m .25335 .47338 L .2624 .47675 L F
.65 .791 .95 r
.60766 .4757 m .61266 .46756 L .61786 .4726 L F
.60766 .4757 m .60243 .47076 L .61266 .46756 L F
.885 .926 .843 r
.39647 .42376 m .39028 .42259 L .40042 .41163 L F
.905 .917 .817 r
.38631 .43599 m .39028 .42259 L .39647 .42376 L F
.79 .895 .918 r
.41653 .40541 m .42049 .3957 L .42644 .39981 L F
.41653 .40541 m .41049 .40257 L .42049 .3957 L F
.647 .779 .944 r
.63325 .47473 m .63838 .46643 L .6435 .47171 L F
.63325 .47473 m .6281 .46951 L .63838 .46643 L F
.656 .816 .96 r
.58209 .4772 m .58695 .46942 L .59224 .47398 L F
.58209 .4772 m .57677 .47282 L .58695 .46942 L F
.644 .771 .941 r
.65885 .47408 m .66412 .46571 L .66915 .47114 L F
.65885 .47408 m .65379 .46871 L .66412 .46571 L F
0 0 0 r
.5209 .4889 m .5254 .48637 L .53093 .48472 L F
.5209 .4889 m .51531 .49223 L .5254 .48637 L F
.59 .745 .951 r
.86907 .4825 m .87561 .47523 L .87989 .48068 L F
.86907 .4825 m .86476 .47704 L .87561 .47523 L F
.619 .754 .943 r
.80237 .47704 m .80847 .46907 L .813 .47463 L F
.80237 .47704 m .79782 .47149 L .80847 .46907 L F
.735 .794 .9 r
.14605 .45346 m .14871 .44297 L .15564 .44818 L F
.14605 .45346 m .13909 .44829 L .14871 .44297 L F
.641 .767 .939 r
.68447 .47368 m .68988 .46529 L .69483 .47079 L F
.68447 .47368 m .6795 .4682 L .68988 .46529 L F
.661 .874 .979 r
.55652 .47973 m .56124 .47282 L .56663 .47626 L F
.55652 .47973 m .55111 .47669 L .56124 .47282 L F
.637 .763 .939 r
.71011 .47346 m .71567 .4651 L .72053 .47065 L F
.71011 .47346 m .70523 .46793 L .71567 .4651 L F
.727 .524 .617 r
.34623 .59824 m .35276 .53295 L .35823 .5515 L F
.34623 .59824 m .34182 .55898 L .35276 .53295 L F
.76 .591 .668 r
.34182 .55898 m .34693 .52138 L .35276 .53295 L F
.224 .435 .857 r
.47318 .4227 m .47736 .41844 L .48301 .42886 L F
.47318 .4227 m .4675 .4136 L .47736 .41844 L F
.647 .772 .939 r
.18149 .44484 m .18412 .43635 L .19087 .44211 L F
.18149 .44484 m .17469 .43942 L .18412 .43635 L F
.61 .751 .945 r
.82814 .47784 m .83441 .47009 L .83884 .47562 L F
.82814 .47784 m .82367 .47231 L .83441 .47009 L F
.905 .917 .817 r
.38631 .43599 m .38006 .435 L .39028 .42259 L F
.91 .898 .802 r
.37608 .44964 m .38006 .435 L .38631 .43599 L F
.633 .761 .939 r
.73578 .47343 m .74148 .46512 L .74625 .4707 L F
.73578 .47343 m .73098 .46787 L .74148 .46512 L F
.652 .428 .567 r
.35403 .61435 m .35823 .5515 L .36199 .60612 L F
.34613 .61511 m .35823 .5515 L .35403 .61435 L F
.34613 .61511 m .34623 .59824 L .35823 .5515 L F
.903 .847 .779 r
.36171 .48132 m .35544 .47849 L .36577 .46406 L F
.867 .791 .773 r
.35132 .49737 m .35544 .47849 L .36171 .48132 L F
.706 .839 .946 r
.42644 .39981 m .43043 .39115 L .43632 .39664 L F
.42644 .39981 m .42049 .3957 L .43043 .39115 L F
.57 .738 .955 r
.895 .48443 m .90175 .47759 L .90593 .48298 L F
.895 .48443 m .89078 .47903 L .90175 .47759 L F
.389 .624 .946 r
.22252 .45332 m .22512 .44767 L .2316 .4549 L F
.22252 .45332 m .21599 .44664 L .22512 .44767 L F
.629 .758 .94 r
.76148 .47359 m .76733 .46538 L .77201 .47097 L F
.76148 .47359 m .75677 .46802 L .76733 .46538 L F
.528 .368 .608 r
.30051 .61081 m .29687 .56452 L .30618 .56663 L F
.456 .317 .603 r
.29172 .60048 m .29687 .56452 L .30051 .61081 L F
.498 .397 .67 r
.29687 .56452 m .30114 .54158 L .30618 .56663 L F
.72 .792 .909 r
.15564 .44818 m .1583 .4381 L .16519 .44342 L F
.15564 .44818 m .14871 .44297 L .1583 .4381 L F
.597 .747 .949 r
.85397 .47901 m .86042 .47155 L .86476 .47704 L F
.85397 .47901 m .8496 .47352 L .86042 .47155 L F
.305 .552 .921 r
.23802 .4623 m .24067 .45718 L .24705 .46511 L F
.23802 .4623 m .2316 .4549 L .24067 .45718 L F
.492 .898 .787 r
.53093 .48472 m .53552 .48092 L .541 .48065 L F
.53093 .48472 m .5254 .48637 L .53552 .48092 L F
.359 .495 .859 r
.27468 .49606 m .27775 .4889 L .28384 .4991 L F
.27468 .49606 m .26859 .48599 L .27775 .4889 L F
.497 .695 .957 r
.20681 .44663 m .2094 .44 L .21599 .44664 L F
.20681 .44663 m .20017 .4405 L .2094 .44 L F
.65 .788 .948 r
.61786 .4726 m .62292 .46438 L .6281 .46951 L F
.61786 .4726 m .61266 .46756 L .62292 .46438 L F
.622 .756 .942 r
.78721 .47398 m .79323 .4659 L .79782 .47149 L F
.78721 .47398 m .7826 .4684 L .79323 .4659 L F
.646 .777 .943 r
.6435 .47171 m .64869 .46336 L .65379 .46871 L F
.6435 .47171 m .63838 .46643 L .64869 .46336 L F
.655 .809 .957 r
.59224 .47398 m .59716 .46604 L .60243 .47076 L F
.59224 .47398 m .58695 .46942 L .59716 .46604 L F
.643 .77 .941 r
.66915 .47114 m .67449 .46274 L .6795 .4682 L F
.66915 .47114 m .66412 .46571 L .67449 .46274 L F
.663 .858 .974 r
.56663 .47626 m .57141 .46902 L .57677 .47282 L F
.56663 .47626 m .56124 .47282 L .57141 .46902 L F
.91 .898 .802 r
.37608 .44964 m .36978 .44829 L .38006 .435 L F
.903 .87 .796 r
.36577 .46406 m .36978 .44829 L .37608 .44964 L F
.639 .766 .939 r
.69483 .47079 m .70031 .46239 L .70523 .46793 L F
.69483 .47079 m .68988 .46529 L .70031 .46239 L F
.415 .621 .937 r
.45196 .40263 m .45603 .39686 L .46179 .40507 L F
.45196 .40263 m .44617 .39576 L .45603 .39686 L F
.614 .753 .944 r
.813 .47463 m .81918 .46674 L .82367 .47231 L F
.813 .47463 m .80847 .46907 L .81918 .46674 L F
.76 .591 .668 r
.34182 .55898 m .33642 .53874 L .34693 .52138 L F
.831 .711 .733 r
.34693 .52138 m .34095 .51222 L .35132 .49737 L F
.768 .636 .715 r
.33642 .53874 m .34095 .51222 L .34693 .52138 L F
.58 .741 .953 r
.87989 .48068 m .88654 .47359 L .89078 .47903 L F
.87989 .48068 m .87561 .47523 L .88654 .47359 L F
.284 .509 .896 r
.25335 .47338 m .25613 .46808 L .2624 .47675 L F
.25335 .47338 m .24705 .46511 L .25613 .46808 L F
.55 .485 .736 r
.30114 .54158 m .29561 .52418 L .30507 .52409 L F
.519 .512 .788 r
.29561 .52418 m .2992 .51126 L .30507 .52409 L F
.29561 .52418 m .28981 .51058 L .2992 .51126 L F
.574 .452 .676 r
.30618 .56663 m .30114 .54158 L .3107 .54013 L F
.55 .485 .736 r
.30114 .54158 m .30507 .52409 L .3107 .54013 L F
.636 .762 .939 r
.72053 .47065 m .72615 .46229 L .73098 .46787 L F
.72053 .47065 m .71567 .4651 L .72615 .46229 L F
.593 .744 .949 r
.19087 .44211 m .19348 .43432 L .20017 .4405 L F
.19087 .44211 m .18412 .43635 L .19348 .43432 L F
.696 .785 .92 r
.16519 .44342 m .16785 .43388 L .17469 .43942 L F
.16519 .44342 m .1583 .4381 L .16785 .43388 L F
.631 .76 .94 r
.74625 .4707 m .75203 .46242 L .75677 .46802 L F
.74625 .4707 m .74148 .46512 L .75203 .46242 L F
.602 .757 .953 r
.43632 .39664 m .44034 .38892 L .44617 .39576 L F
.43632 .39664 m .43043 .39115 L .44034 .38892 L F
.603 .749 .947 r
.83884 .47562 m .84519 .46798 L .8496 .47352 L F
.83884 .47562 m .83441 .47009 L .84519 .46798 L F
.867 .791 .773 r
.35132 .49737 m .34512 .49213 L .35544 .47849 L F
.819 .729 .766 r
.34095 .51222 m .34512 .49213 L .35132 .49737 L F
.281 .489 .882 r
.4675 .4136 m .47166 .40879 L .47736 .41844 L F
.4675 .4136 m .46179 .40507 L .47166 .40879 L F
.588 .945 .901 r
.541 .48065 m .54566 .47582 L .55111 .47669 L F
.541 .48065 m .53552 .48092 L .54566 .47582 L F
.626 .757 .941 r
.77201 .47097 m .77795 .4628 L .7826 .4684 L F
.77201 .47097 m .76733 .46538 L .77795 .4628 L F
.556 .733 .958 r
.90593 .48298 m .9128 .4764 L .91694 .48177 L F
.90593 .48298 m .90175 .47759 L .9128 .4764 L F
.156 .025 .439 r
.50435 .58883 m .49517 .50555 L .49466 .59173 L F
.50435 .58883 m .50523 .49859 L .49517 .50555 L F
.49466 .59173 m .49517 .50555 L .49429 .59213 L F
.54 .323 .534 r
.49374 .57826 m .49418 .45741 L .50414 .4644 L F
.541 .322 .532 r
.49278 .57813 m .49418 .45741 L .49374 .57826 L F
.48311 .58108 m .49418 .45741 L .49278 .57813 L F
.353 .372 .741 r
.49418 .45741 m .49857 .44732 L .50414 .4644 L F
.49418 .45741 m .48863 .44088 L .49857 .44732 L F
.485 .531 .829 r
.28981 .51058 m .2932 .50026 L .2992 .51126 L F
.28981 .51058 m .28384 .4991 L .2932 .50026 L F
.649 .784 .946 r
.6281 .46951 m .63322 .46121 L .63838 .46643 L F
.6281 .46951 m .62292 .46438 L .63322 .46121 L F
.655 .803 .954 r
.60243 .47076 m .60741 .46269 L .61266 .46756 L F
.60243 .47076 m .59716 .46604 L .60741 .46269 L F
.645 .775 .942 r
.65379 .46871 m .65905 .46031 L .66412 .46571 L F
.65379 .46871 m .64869 .46336 L .65905 .46031 L F
.589 .744 .951 r
.86476 .47704 m .8713 .46973 L .87561 .47523 L F
.86476 .47704 m .86042 .47155 L .8713 .46973 L F
.281 .397 .803 r
.48863 .44088 m .49295 .43462 L .49857 .44732 L F
.48863 .44088 m .48301 .42886 L .49295 .43462 L F
.903 .87 .796 r
.36577 .46406 m .35947 .46181 L .36978 .44829 L F
.882 .834 .794 r
.35544 .47849 m .35947 .46181 L .36577 .46406 L F
.618 .754 .943 r
.79782 .47149 m .80391 .46347 L .80847 .46907 L F
.79782 .47149 m .79323 .4659 L .80391 .46347 L F
.341 .51 .879 r
.26859 .48599 m .27157 .47953 L .27775 .4889 L F
.26859 .48599 m .2624 .47675 L .27157 .47953 L F
.641 .769 .94 r
.6795 .4682 m .6849 .45978 L .68988 .46529 L F
.6795 .4682 m .67449 .46274 L .6849 .45978 L F
.663 .844 .969 r
.57677 .47282 m .58162 .46531 L .58695 .46942 L F
.57677 .47282 m .57141 .46902 L .58162 .46531 L F
.734 .79 .897 r
.13909 .44829 m .14175 .43761 L .14871 .44297 L F
.13909 .44829 m .1321 .44295 L .14175 .43761 L F
.638 .765 .94 r
.70523 .46793 m .71078 .45952 L .71567 .4651 L F
.70523 .46793 m .70031 .46239 L .71078 .45952 L F
.504 .314 .555 r
.29151 .62485 m .29172 .60048 L .30051 .61081 L F
.436 .264 .548 r
.28901 .62656 m .29172 .60048 L .29151 .62485 L F
.28377 .62945 m .29172 .60048 L .28901 .62656 L F
.113 0 .422 r
.4739 .59832 m .46498 .53139 L .46373 .60135 L F
.46373 .60135 m .46498 .53139 L .46372 .60136 L F
.103 0 .418 r
.46372 .60136 m .46498 .53139 L .45487 .54228 L F
.861 .894 .858 r
.40042 .41163 m .40442 .39922 L .41049 .40257 L F
.40042 .41163 m .39427 .40912 L .40442 .39922 L F
.887 .897 .832 r
.39028 .42259 m .39427 .40912 L .40042 .41163 L F
.609 .751 .946 r
.82367 .47231 m .82994 .46451 L .83441 .47009 L F
.82367 .47231 m .81918 .46674 L .82994 .46451 L F
.816 .875 .889 r
.41049 .40257 m .41449 .39128 L .42049 .3957 L F
.41049 .40257 m .40442 .39922 L .41449 .39128 L F
.66 .772 .932 r
.17469 .43942 m .17733 .4305 L .18412 .43635 L F
.17469 .43942 m .16785 .43388 L .17733 .4305 L F
.634 .761 .94 r
.73098 .46787 m .73668 .45952 L .74148 .46512 L F
.73098 .46787 m .72615 .46229 L .73668 .45952 L F
.427 .645 .949 r
.21599 .44664 m .21859 .44055 L .22512 .44767 L F
.21599 .44664 m .2094 .44 L .21859 .44055 L F
.338 .578 .93 r
.2316 .4549 m .23424 .44949 L .24067 .45718 L F
.2316 .4549 m .22512 .44767 L .23424 .44949 L F
.568 .737 .955 r
.89078 .47903 m .89754 .47216 L .90175 .47759 L F
.89078 .47903 m .88654 .47359 L .89754 .47216 L F
.103 0 .418 r
.46372 .60136 m .45487 .54228 L .45358 .60437 L F
.45358 .60437 m .45487 .54228 L .45358 .60438 L F
.094 0 .414 r
.45358 .60438 m .45487 .54228 L .44472 .55473 L F
.695 .52 .646 r
.33094 .58217 m .33642 .53874 L .34182 .55898 L F
.33094 .58217 m .32606 .5529 L .33642 .53874 L F
.768 .636 .715 r
.33642 .53874 m .33067 .52487 L .34095 .51222 L F
.704 .568 .699 r
.32606 .5529 m .33067 .52487 L .33642 .53874 L F
.819 .729 .766 r
.34095 .51222 m .33486 .50415 L .34512 .49213 L F
.761 .666 .757 r
.33067 .52487 m .33486 .50415 L .34095 .51222 L F
.64 .945 .954 r
.55111 .47669 m .55583 .47102 L .56124 .47282 L F
.55111 .47669 m .54566 .47582 L .55583 .47102 L F
.585 .414 .617 r
.31009 .61027 m .30618 .56663 L .31594 .56255 L F
.528 .368 .608 r
.30051 .61081 m .30618 .56663 L .31009 .61027 L F
.574 .452 .676 r
.30618 .56663 m .3107 .54013 L .31594 .56255 L F
.64 .507 .685 r
.31594 .56255 m .3107 .54013 L .32057 .53442 L F
.627 .544 .74 r
.3107 .54013 m .31478 .5206 L .32057 .53442 L F
.3107 .54013 m .30507 .52409 L .31478 .5206 L F
.629 .759 .941 r
.75677 .46802 m .76262 .45976 L .76733 .46538 L F
.75677 .46802 m .75203 .46242 L .76262 .45976 L F
.887 .897 .832 r
.39028 .42259 m .38406 .42058 L .39427 .40912 L F
.898 .891 .814 r
.38006 .435 m .38406 .42058 L .39028 .42259 L F
.596 .747 .949 r
.8496 .47352 m .85605 .46601 L .86042 .47155 L F
.8496 .47352 m .84519 .46798 L .85605 .46601 L F
.528 .707 .953 r
.20017 .4405 m .20277 .43339 L .2094 .44 L F
.20017 .4405 m .19348 .43432 L .20277 .43339 L F
.75 .835 .917 r
.42049 .3957 m .4245 .38553 L .43043 .39115 L F
.42049 .3957 m .41449 .39128 L .4245 .38553 L F
.723 .789 .904 r
.14871 .44297 m .15137 .43263 L .1583 .4381 L F
.14871 .44297 m .14175 .43761 L .15137 .43263 L F
.604 .57 .789 r
.30507 .52409 m .30883 .50919 L .31478 .5206 L F
.30507 .52409 m .2992 .51126 L .30883 .50919 L F
.298 .53 .908 r
.24705 .46511 m .24979 .45979 L .25613 .46808 L F
.24705 .46511 m .24067 .45718 L .24979 .45979 L F
.622 .756 .942 r
.7826 .4684 m .78861 .46028 L .79323 .4659 L F
.7826 .4684 m .77795 .4628 L .78861 .46028 L F
.452 .543 .859 r
.28384 .4991 m .28709 .49037 L .2932 .50026 L F
.28384 .4991 m .27775 .4889 L .28709 .49037 L F
.263 .424 .835 r
.48301 .42886 m .48729 .42354 L .49295 .43462 L F
.48301 .42886 m .47736 .41844 L .48729 .42354 L F
.882 .834 .794 r
.35544 .47849 m .34915 .47483 L .35947 .46181 L F
.849 .79 .794 r
.34512 .49213 m .34915 .47483 L .35544 .47849 L F
.177 .04 .444 r
.51402 .58509 m .50523 .49859 L .50548 .58766 L F
.51402 .58509 m .51531 .49223 L .50523 .49859 L F
.50548 .58766 m .50523 .49859 L .50435 .58883 L F
.648 .781 .945 r
.63838 .46643 m .64357 .45806 L .64869 .46336 L F
.63838 .46643 m .63322 .46121 L .64357 .45806 L F
.654 .797 .951 r
.61266 .46756 m .6177 .45937 L .62292 .46438 L F
.61266 .46756 m .60741 .46269 L .6177 .45937 L F
.494 .663 .937 r
.44617 .39576 m .45024 .38883 L .45603 .39686 L F
.44617 .39576 m .44034 .38892 L .45024 .38883 L F
.666 .459 .595 r
.33679 .61441 m .34182 .55898 L .34623 .59824 L F
.33254 .61475 m .34182 .55898 L .33679 .61441 L F
.33254 .61475 m .33094 .58217 L .34182 .55898 L F
.644 .773 .942 r
.66412 .46571 m .66945 .45727 L .67449 .46274 L F
.66412 .46571 m .65905 .46031 L .66945 .45727 L F
.094 0 .414 r
.45358 .60438 m .44472 .55473 L .44347 .60738 L F
.44347 .60738 m .44472 .55473 L .44347 .60738 L F
.087 0 .41 r
.44347 .60738 m .44472 .55473 L .4345 .56909 L F
.663 .832 .965 r
.58695 .46942 m .59186 .46166 L .59716 .46604 L F
.58695 .46942 m .58162 .46531 L .59186 .46166 L F
.704 .568 .699 r
.32606 .5529 m .32057 .53442 L .33067 .52487 L F
.761 .666 .757 r
.33067 .52487 m .32473 .51384 L .33486 .50415 L F
.697 .604 .748 r
.32057 .53442 m .32473 .51384 L .33067 .52487 L F
.64 .767 .94 r
.68988 .46529 m .69535 .45684 L .70031 .46239 L F
.68988 .46529 m .6849 .45978 L .69535 .45684 L F
.64 .507 .685 r
.31594 .56255 m .32057 .53442 L .32606 .5529 L F
.697 .604 .748 r
.32057 .53442 m .31478 .5206 L .32473 .51384 L F
.898 .891 .814 r
.38006 .435 m .37379 .43309 L .38406 .42058 L F
.899 .876 .805 r
.36978 .44829 m .37379 .43309 L .38006 .435 L F
.614 .753 .944 r
.80847 .46907 m .81465 .46113 L .81918 .46674 L F
.80847 .46907 m .80391 .46347 L .81465 .46113 L F
.341 .536 .899 r
.46179 .40507 m .46593 .39957 L .47166 .40879 L F
.46179 .40507 m .45603 .39686 L .46593 .39957 L F
.579 .741 .953 r
.87561 .47523 m .88226 .4681 L .88654 .47359 L F
.87561 .47523 m .8713 .46973 L .88226 .4681 L F
.636 .763 .94 r
.71567 .4651 m .72129 .45668 L .72615 .46229 L F
.71567 .4651 m .71078 .45952 L .72129 .45668 L F
.638 .463 .629 r
.3203 .60006 m .32606 .5529 L .33094 .58217 L F
.3203 .60006 m .31594 .56255 L .32606 .5529 L F
.329 .522 .893 r
.2624 .47675 m .26531 .47072 L .27157 .47953 L F
.2624 .47675 m .25613 .46808 L .26531 .47072 L F
.585 .414 .617 r
.31009 .61027 m .31594 .56255 L .3203 .60006 L F
.199 .053 .446 r
.52276 .58033 m .51531 .49223 L .51714 .58206 L F
.52276 .58033 m .5254 .48637 L .51531 .49223 L F
.51714 .58206 m .51531 .49223 L .51402 .58509 L F
.612 .749 .942 r
.18412 .43635 m .18674 .42811 L .19348 .43432 L F
.18412 .43635 m .17733 .4305 L .18674 .42811 L F
.664 .925 .974 r
.56124 .47282 m .56603 .46645 L .57141 .46902 L F
.56124 .47282 m .55583 .47102 L .56603 .46645 L F
.631 .76 .94 r
.74148 .46512 m .74725 .45678 L .75203 .46242 L F
.74148 .46512 m .73668 .45952 L .74725 .45678 L F
.603 .749 .947 r
.83441 .47009 m .84076 .4624 L .84519 .46798 L F
.83441 .47009 m .82994 .46451 L .84076 .4624 L F
.702 .783 .914 r
.1583 .4381 m .16096 .42822 L .16785 .43388 L F
.1583 .4381 m .15137 .43263 L .16096 .42822 L F
.575 .587 .828 r
.2992 .51126 m .30277 .49915 L .30883 .50919 L F
.2992 .51126 m .2932 .50026 L .30277 .49915 L F
.661 .773 .933 r
.43043 .39115 m .43446 .38209 L .44034 .38892 L F
.43043 .39115 m .4245 .38553 L .43446 .38209 L F
.849 .79 .794 r
.34512 .49213 m .33889 .48666 L .34915 .47483 L F
.803 .74 .794 r
.33486 .50415 m .33889 .48666 L .34512 .49213 L F
.626 .757 .941 r
.76733 .46538 m .77326 .45715 L .77795 .4628 L F
.76733 .46538 m .76262 .45976 L .77326 .45715 L F
.679 .628 .791 r
.31478 .5206 m .31868 .50427 L .32473 .51384 L F
.31478 .5206 m .30883 .50919 L .31868 .50427 L F
.555 .732 .958 r
.90175 .47759 m .90862 .47098 L .9128 .4764 L F
.90175 .47759 m .89754 .47216 L .90862 .47098 L F
.899 .876 .805 r
.36978 .44829 m .36347 .44604 L .37379 .43309 L F
.888 .855 .804 r
.35947 .46181 m .36347 .44604 L .36978 .44829 L F
.087 0 .41 r
.44347 .60738 m .4345 .56909 L .4334 .61037 L F
.4334 .61037 m .4345 .56909 L .4334 .61037 L F
.079 0 .406 r
.4334 .61037 m .4345 .56909 L .42418 .58579 L F
.588 .744 .951 r
.86042 .47155 m .86696 .46419 L .8713 .46973 L F
.86042 .47155 m .85605 .46601 L .86696 .46419 L F
.653 .792 .949 r
.62292 .46438 m .62803 .45607 L .63322 .46121 L F
.62292 .46438 m .6177 .45937 L .62803 .45607 L F
.215 .056 .437 r
.5254 .48637 m .5301 .56666 L .53552 .48092 L F
.52865 .57502 m .5254 .48637 L .52276 .58033 L F
.52935 .57143 m .5254 .48637 L .52865 .57502 L F
.52948 .57427 m .5301 .56666 L .5254 .48637 L F
.215 .033 .406 r
.53552 .48092 m .5321 .53501 L .54034 .51419 L F
.5321 .53501 m .5301 .56666 L .54012 .51532 L F
.5321 .53501 m .54012 .51532 L .54034 .51419 L F
.53552 .48092 m .54034 .51419 L .54566 .47582 L F
.176 0 .326 r
.54566 .47582 m .54216 .50105 L .55051 .48885 L F
.54216 .50105 m .54034 .51419 L .55031 .48935 L F
.54216 .50105 m .55031 .48935 L .55051 .48885 L F
.54566 .47582 m .55051 .48885 L .55583 .47102 L F
.058 0 .145 r
.55583 .47102 m .55224 .48304 L .56071 .47433 L F
.55224 .48304 m .55051 .48885 L .56057 .47452 L F
.55224 .48304 m .56057 .47452 L .56071 .47433 L F
.55583 .47102 m .56071 .47433 L .56603 .46645 L F
.673 .899 .977 r
.57141 .46902 m .56603 .46645 L .57626 .4621 L F
0 0 0 r
.56603 .46645 m .56237 .47187 L .57094 .46465 L F
.56237 .47187 m .56071 .47433 L .57085 .46473 L F
.56237 .47187 m .57085 .46473 L .57094 .46465 L F
.56603 .46645 m .57094 .46465 L .57626 .4621 L F
.542 .906 .716 r
.57626 .4621 m .57094 .46465 L .58121 .4574 L F
.706 .731 .87 r
.57095 .46464 m .56542 .45731 L .57576 .45236 L F
.57094 .46469 m .57092 .46467 L .57095 .46464 L F
.57092 .46467 m .56542 .45731 L .57095 .46464 L F
.664 .606 .78 r
.56074 .47435 m .55511 .46187 L .56542 .45731 L F
.56071 .47446 m .56068 .47441 L .56074 .47435 L F
.56068 .47441 m .55511 .46187 L .56074 .47435 L F
.612 .485 .684 r
.55056 .48899 m .54483 .4657 L .55511 .46187 L F
.55052 .48927 m .55048 .48911 L .55056 .48899 L F
.55048 .48911 m .54483 .4657 L .55056 .48899 L F
.573 .403 .613 r
.5404 .51463 m .53458 .46838 L .54483 .4657 L F
.54034 .51526 m .54029 .51488 L .5404 .51463 L F
.54029 .51488 m .53458 .46838 L .5404 .51463 L F
.552 .357 .571 r
.53014 .56734 m .52437 .46941 L .53458 .46838 L F
.5301 .56818 m .53008 .56768 L .53014 .56734 L F
.53008 .56768 m .52437 .46941 L .53014 .56734 L F
.215 .056 .437 r
.52948 .57427 m .52935 .57143 L .52865 .57502 L F
.647 .779 .944 r
.64869 .46336 m .65395 .45493 L .65905 .46031 L F
.64869 .46336 m .64357 .45806 L .65395 .45493 L F
.618 .754 .943 r
.79323 .4659 m .79932 .45783 L .80391 .46347 L F
.79323 .4659 m .78861 .46028 L .79932 .45783 L F
.662 .821 .96 r
.59716 .46604 m .60214 .45807 L .60741 .46269 L F
.59716 .46604 m .59186 .46166 L .60214 .45807 L F
.423 .551 .88 r
.27775 .4889 m .28089 .48121 L .28709 .49037 L F
.27775 .4889 m .27157 .47953 L .28089 .48121 L F
.273 .452 .855 r
.47736 .41844 m .48161 .41326 L .48729 .42354 L F
.47736 .41844 m .47166 .40879 L .48161 .41326 L F
.643 .771 .941 r
.67449 .46274 m .67989 .45426 L .6849 .45978 L F
.67449 .46274 m .66945 .45727 L .67989 .45426 L F
.803 .74 .794 r
.33486 .50415 m .32871 .49665 L .33889 .48666 L F
.746 .685 .793 r
.32473 .51384 m .32871 .49665 L .33486 .50415 L F
.32473 .51384 m .31868 .50427 L .32871 .49665 L F
.368 .599 .936 r
.22512 .44767 m .22775 .44196 L .23424 .44949 L F
.22512 .44767 m .21859 .44055 L .22775 .44196 L F
.733 .787 .895 r
.1321 .44295 m .13474 .43212 L .14175 .43761 L F
.1321 .44295 m .12507 .43748 L .13474 .43212 L F
.639 .766 .94 r
.70031 .46239 m .70585 .45393 L .71078 .45952 L F
.70031 .46239 m .69535 .45684 L .70585 .45393 L F
.459 .662 .95 r
.2094 .44 m .212 .43351 L .21859 .44055 L F
.2094 .44 m .20277 .43339 L .212 .43351 L F
.609 .751 .946 r
.81918 .46674 m .82544 .45889 L .82994 .46451 L F
.81918 .46674 m .81465 .46113 L .82544 .45889 L F
.673 .899 .977 r
.57141 .46902 m .57626 .4621 L .58162 .46531 L F
.634 .762 .94 r
.72615 .46229 m .73184 .45388 L .73668 .45952 L F
.72615 .46229 m .72129 .45668 L .73184 .45388 L F
.671 .771 .925 r
.16785 .43388 m .17049 .42457 L .17733 .4305 L F
.16785 .43388 m .16096 .42822 L .17049 .42457 L F
.314 .549 .917 r
.24067 .45718 m .24339 .45177 L .24979 .45979 L F
.24067 .45718 m .23424 .44949 L .24339 .45177 L F
.567 .736 .955 r
.88654 .47359 m .89329 .46668 L .89754 .47216 L F
.88654 .47359 m .88226 .4681 L .89329 .46668 L F
.888 .855 .804 r
.35947 .46181 m .35314 .45877 L .36347 .44604 L F
.865 .826 .807 r
.34915 .47483 m .35314 .45877 L .35947 .46181 L F
.541 .326 .538 r
.5048 .57582 m .50414 .4644 L .51421 .46826 L F
.54 .323 .534 r
.50296 .57542 m .50414 .4644 L .5048 .57582 L F
.49374 .57826 m .50414 .4644 L .50296 .57542 L F
.422 .41 .741 r
.50414 .4644 m .50861 .45204 L .51421 .46826 L F
.50414 .4644 m .49857 .44732 L .50861 .45204 L F
.629 .759 .941 r
.75203 .46242 m .75788 .4541 L .76262 .45976 L F
.75203 .46242 m .74725 .45678 L .75788 .4541 L F
.543 .597 .858 r
.2932 .50026 m .29661 .48997 L .30277 .49915 L F
.2932 .50026 m .28709 .49037 L .29661 .48997 L F
.347 .426 .8 r
.49857 .44732 m .50298 .43951 L .50861 .45204 L F
.49857 .44732 m .49295 .43462 L .50298 .43951 L F
.553 .716 .949 r
.19348 .43432 m .19608 .42679 L .20277 .43339 L F
.19348 .43432 m .18674 .42811 L .19608 .42679 L F
.596 .746 .949 r
.84519 .46798 m .85164 .46042 L .85605 .46601 L F
.84519 .46798 m .84076 .4624 L .85164 .46042 L F
.655 .643 .826 r
.30883 .50919 m .31254 .49556 L .31868 .50427 L F
.30883 .50919 m .30277 .49915 L .31254 .49556 L F
.399 .575 .909 r
.45603 .39686 m .46016 .3906 L .46593 .39957 L F
.45603 .39686 m .45024 .38883 L .46016 .3906 L F
.833 .86 .866 r
.40442 .39922 m .40845 .38663 L .41449 .39128 L F
.40442 .39922 m .3983 .39553 L .40845 .38663 L F
.867 .875 .841 r
.39427 .40912 m .3983 .39553 L .40442 .39922 L F
.557 .693 .931 r
.44034 .38892 m .44441 .38091 L .45024 .38883 L F
.44034 .38892 m .43446 .38209 L .44441 .38091 L F
.724 .786 .901 r
.14175 .43761 m .1444 .42704 L .15137 .43263 L F
.14175 .43761 m .13474 .43212 L .1444 .42704 L F
.622 .756 .942 r
.77795 .4628 m .78395 .45461 L .78861 .46028 L F
.77795 .4628 m .77326 .45715 L .78395 .45461 L F
.323 .533 .903 r
.25613 .46808 m .25898 .46229 L .26531 .47072 L F
.25613 .46808 m .24979 .45979 L .25898 .46229 L F
.867 .875 .841 r
.39427 .40912 m .38809 .40614 L .3983 .39553 L F
.886 .878 .822 r
.38406 .42058 m .38809 .40614 L .39427 .40912 L F
.779 .831 .892 r
.41449 .39128 m .41853 .37981 L .4245 .38553 L F
.41449 .39128 m .40845 .38663 L .41853 .37981 L F
.652 .788 .947 r
.63322 .46121 m .6384 .45281 L .64357 .45806 L F
.63322 .46121 m .62803 .45607 L .6384 .45281 L F
.646 .776 .943 r
.65905 .46031 m .66437 .45182 L .66945 .45727 L F
.65905 .46031 m .65395 .45493 L .66437 .45182 L F
.66 .811 .956 r
.60741 .46269 m .61245 .45453 L .6177 .45937 L F
.60741 .46269 m .60214 .45807 L .61245 .45453 L F
.079 0 .406 r
.4334 .61037 m .42418 .58579 L .42336 .61336 L F
.42336 .61336 m .42418 .58579 L .42336 .61336 L F
.073 0 .402 r
.42336 .61336 m .42418 .58579 L .41372 .60536 L F
.641 .769 .941 r
.6849 .45978 m .69037 .45127 L .69535 .45684 L F
.6849 .45978 m .67989 .45426 L .69037 .45127 L F
.614 .753 .944 r
.80391 .46347 m .81008 .45547 L .81465 .46113 L F
.80391 .46347 m .79932 .45783 L .81008 .45547 L F
.865 .826 .807 r
.34915 .47483 m .34284 .47064 L .35314 .45877 L F
.831 .79 .813 r
.33889 .48666 m .34284 .47064 L .34915 .47483 L F
.578 .74 .953 r
.8713 .46973 m .87795 .46256 L .88226 .4681 L F
.8713 .46973 m .86696 .46419 L .87795 .46256 L F
.886 .878 .822 r
.38406 .42058 m .37781 .418 L .38809 .40614 L F
.893 .873 .811 r
.37379 .43309 m .37781 .418 L .38406 .42058 L F
.62 .413 .58 r
.32814 .61453 m .33094 .58217 L .33254 .61475 L F
.32059 .61584 m .33094 .58217 L .32814 .61453 L F
.32059 .61584 m .3203 .60006 L .33094 .58217 L F
.637 .764 .94 r
.71078 .45952 m .71639 .45104 L .72129 .45668 L F
.71078 .45952 m .70585 .45393 L .71639 .45104 L F
.676 .875 .973 r
.58162 .46531 m .58653 .45792 L .59186 .46166 L F
.58162 .46531 m .57626 .4621 L .58653 .45792 L F
.628 .752 .936 r
.17733 .4305 m .17995 .42186 L .18674 .42811 L F
.17733 .4305 m .17049 .42457 L .17995 .42186 L F
.297 .48 .87 r
.47166 .40879 m .47589 .40342 L .48161 .41326 L F
.47166 .40879 m .46593 .39957 L .47589 .40342 L F
.546 .347 .562 r
.30044 .62123 m .30051 .61081 L .31009 .61027 L F
.504 .314 .555 r
.29951 .62161 m .30051 .61081 L .30044 .62123 L F
.29151 .62485 m .30051 .61081 L .29951 .62161 L F
.397 .555 .894 r
.27157 .47953 m .27462 .47254 L .28089 .48121 L F
.27157 .47953 m .26531 .47072 L .27462 .47254 L F
.304 .434 .828 r
.49295 .43462 m .49732 .42838 L .50298 .43951 L F
.49295 .43462 m .48729 .42354 L .49732 .42838 L F
.725 .697 .823 r
.31868 .50427 m .3225 .48947 L .32871 .49665 L F
.31868 .50427 m .31254 .49556 L .3225 .48947 L F
.632 .761 .94 r
.73668 .45952 m .74245 .45111 L .74725 .45678 L F
.73668 .45952 m .73184 .45388 L .74245 .45111 L F
.602 .749 .947 r
.82994 .46451 m .83629 .45676 L .84076 .4624 L F
.82994 .46451 m .82544 .45889 L .83629 .45676 L F
.707 .781 .91 r
.15137 .43263 m .15403 .42246 L .16096 .42822 L F
.15137 .43263 m .1444 .42704 L .15403 .42246 L F
.703 .782 .913 r
.4245 .38553 m .42855 .37526 L .43446 .38209 L F
.4245 .38553 m .41853 .37981 L .42855 .37526 L F
.831 .79 .813 r
.33889 .48666 m .33261 .48104 L .34284 .47064 L F
.784 .746 .819 r
.32871 .49665 m .33261 .48104 L .33889 .48666 L F
.626 .758 .941 r
.76262 .45976 m .76854 .45146 L .77326 .45715 L F
.76262 .45976 m .75788 .4541 L .76854 .45146 L F
.784 .746 .819 r
.32871 .49665 m .3225 .48947 L .33261 .48104 L F
.893 .873 .811 r
.37379 .43309 m .36748 .43054 L .37781 .418 L F
.889 .862 .808 r
.36347 .44604 m .36748 .43054 L .37379 .43309 L F
.554 .731 .957 r
.89754 .47216 m .9044 .4655 L .90862 .47098 L F
.89754 .47216 m .89329 .46668 L .9044 .4655 L F
.51 .601 .88 r
.28709 .49037 m .29038 .48134 L .29661 .48997 L F
.28709 .49037 m .28089 .48121 L .29038 .48134 L F
.395 .617 .94 r
.21859 .44055 m .22121 .43454 L .22775 .44196 L F
.21859 .44055 m .212 .43351 L .22121 .43454 L F
.587 .743 .951 r
.85605 .46601 m .86259 .45859 L .86696 .46419 L F
.85605 .46601 m .85164 .46042 L .86259 .45859 L F
.627 .651 .855 r
.30277 .49915 m .30633 .48738 L .31254 .49556 L F
.30277 .49915 m .29661 .48997 L .30633 .48738 L F
.618 .754 .943 r
.78861 .46028 m .79469 .45214 L .79932 .45783 L F
.78861 .46028 m .78395 .45461 L .79469 .45214 L F
.65 .783 .945 r
.64357 .45806 m .64881 .44957 L .65395 .45493 L F
.64357 .45806 m .6384 .45281 L .64881 .44957 L F
.331 .565 .924 r
.23424 .44949 m .23692 .44395 L .24339 .45177 L F
.23424 .44949 m .22775 .44196 L .23692 .44395 L F
.659 .803 .952 r
.6177 .45937 m .62281 .45105 L .62803 .45607 L F
.6177 .45937 m .61245 .45453 L .62281 .45105 L F
.486 .676 .949 r
.20277 .43339 m .20536 .42652 L .212 .43351 L F
.20277 .43339 m .19608 .42679 L .20536 .42652 L F
.645 .773 .942 r
.66945 .45727 m .67484 .44873 L .67989 .45426 L F
.66945 .45727 m .66437 .45182 L .67484 .44873 L F
.733 .784 .894 r
.12507 .43748 m .1277 .42652 L .13474 .43212 L F
.12507 .43748 m .118 .4319 L .1277 .42652 L F
.64 .767 .94 r
.69535 .45684 m .70089 .4483 L .70585 .45393 L F
.69535 .45684 m .69037 .45127 L .70089 .4483 L F
.675 .853 .968 r
.59186 .46166 m .59683 .45389 L .60214 .45807 L F
.59186 .46166 m .58653 .45792 L .59683 .45389 L F
.608 .751 .945 r
.81465 .46113 m .8209 .45321 L .82544 .45889 L F
.81465 .46113 m .81008 .45547 L .8209 .45321 L F
.453 .608 .913 r
.45024 .38883 m .45436 .38178 L .46016 .3906 L F
.45024 .38883 m .44441 .38091 L .45436 .38178 L F
.635 .763 .94 r
.72129 .45668 m .72697 .4482 L .73184 .45388 L F
.72129 .45668 m .71639 .45104 L .72697 .4482 L F
.68 .771 .92 r
.16096 .42822 m .16361 .41858 L .17049 .42457 L F
.16096 .42822 m .15403 .42246 L .16361 .41858 L F
.321 .542 .91 r
.24979 .45979 m .25259 .45413 L .25898 .46229 L F
.24979 .45979 m .24339 .45177 L .25259 .45413 L F
.889 .862 .808 r
.36347 .44604 m .35713 .44315 L .36748 .43054 L F
.875 .845 .811 r
.35314 .45877 m .35713 .44315 L .36347 .44604 L F
.567 .735 .955 r
.88226 .4681 m .88901 .46114 L .89329 .46668 L F
.88226 .4681 m .87795 .46256 L .88901 .46114 L F
.543 .322 .53 r
.36064 .6173 m .36199 .60612 L .36147 .61705 L F
.652 .428 .567 r
.35403 .61435 m .36199 .60612 L .36064 .6173 L F
.283 .442 .843 r
.48729 .42354 m .49163 .41794 L .49732 .42838 L F
.48729 .42354 m .48161 .41326 L .49163 .41794 L F
.61 .387 .553 r
.34518 .61493 m .34623 .59824 L .34613 .61511 L F
.34171 .61555 m .34623 .59824 L .34518 .61493 L F
.666 .459 .595 r
.33679 .61441 m .34623 .59824 L .34171 .61555 L F
.573 .724 .945 r
.18674 .42811 m .18935 .42018 L .19608 .42679 L F
.18674 .42811 m .17995 .42186 L .18935 .42018 L F
.629 .759 .941 r
.74725 .45678 m .75309 .44839 L .75788 .4541 L F
.74725 .45678 m .74245 .45111 L .75309 .44839 L F
.608 .715 .92 r
.43446 .38209 m .43854 .37303 L .44441 .38091 L F
.43446 .38209 m .42855 .37526 L .43854 .37303 L F
.582 .378 .57 r
.31893 .616 m .3203 .60006 L .32059 .61584 L F
.31011 .6182 m .3203 .60006 L .31893 .616 L F
.31011 .6182 m .31009 .61027 L .3203 .60006 L F
.595 .746 .949 r
.84076 .4624 m .8472 .45477 L .85164 .46042 L F
.84076 .4624 m .83629 .45676 L .8472 .45477 L F
.073 0 .402 r
.42336 .61336 m .41372 .60536 L .41336 .61633 L F
.41336 .61633 m .41372 .60536 L .41336 .61633 L F
.545 .326 .533 r
.41336 .61633 m .41372 .60536 L .40793 .61794 L F
.543 .335 .548 r
.51674 .57423 m .51421 .46826 L .52437 .46941 L F
.541 .326 .538 r
.51286 .57332 m .51421 .46826 L .51674 .57423 L F
.5048 .57582 m .51421 .46826 L .51286 .57332 L F
.472 .452 .754 r
.51421 .46826 m .51875 .45493 L .52437 .46941 L F
.51421 .46826 m .50861 .45204 L .51875 .45493 L F
.328 .506 .881 r
.46593 .39957 m .47013 .39383 L .47589 .40342 L F
.46593 .39957 m .46016 .3906 L .47013 .39383 L F
.546 .347 .562 r
.30938 .61837 m .31009 .61027 L .31011 .6182 L F
.30044 .62123 m .31009 .61027 L .30938 .61837 L F
.622 .756 .942 r
.77326 .45715 m .77926 .4489 L .78395 .45461 L F
.77326 .45715 m .76854 .45146 L .77926 .4489 L F
.726 .784 .899 r
.13474 .43212 m .13739 .42135 L .1444 .42704 L F
.13474 .43212 m .1277 .42652 L .13739 .42135 L F
.376 .557 .904 r
.26531 .47072 m .26829 .46421 L .27462 .47254 L F
.26531 .47072 m .25898 .46229 L .26829 .46421 L F
.701 .703 .849 r
.31254 .49556 m .31623 .48248 L .3225 .48947 L F
.31254 .49556 m .30633 .48738 L .31623 .48248 L F
.875 .845 .811 r
.35314 .45877 m .34679 .4552 L .35713 .44315 L F
.85 .82 .819 r
.34284 .47064 m .34679 .4552 L .35314 .45877 L F
.402 .462 .808 r
.50861 .45204 m .51311 .44319 L .51875 .45493 L F
.50861 .45204 m .50298 .43951 L .51311 .44319 L F
.649 .779 .943 r
.65395 .45493 m .65926 .44636 L .66437 .45182 L F
.65395 .45493 m .64881 .44957 L .65926 .44636 L F
.657 .796 .949 r
.62803 .45607 m .6332 .44762 L .6384 .45281 L F
.62803 .45607 m .62281 .45105 L .6332 .44762 L F
.844 .85 .848 r
.3983 .39553 m .40236 .38182 L .40845 .38663 L F
.3983 .39553 m .39215 .39156 L .40236 .38182 L F
.871 .862 .828 r
.38809 .40614 m .39215 .39156 L .3983 .39553 L F
.614 .752 .944 r
.79932 .45783 m .80549 .44976 L .81008 .45547 L F
.79932 .45783 m .79469 .45214 L .80549 .44976 L F
.643 .771 .941 r
.67989 .45426 m .68534 .44567 L .69037 .45127 L F
.67989 .45426 m .67484 .44873 L .68534 .44567 L F
.801 .827 .872 r
.40845 .38663 m .41251 .374 L .41853 .37981 L F
.40845 .38663 m .40236 .38182 L .41251 .374 L F
.578 .739 .952 r
.86696 .46419 m .87361 .45695 L .87795 .46256 L F
.86696 .46419 m .86259 .45859 L .87361 .45695 L F
.672 .835 .961 r
.60214 .45807 m .60717 .44999 L .61245 .45453 L F
.60214 .45807 m .59683 .45389 L .60717 .44999 L F
.479 .601 .896 r
.28089 .48121 m .28409 .47308 L .29038 .48134 L F
.28089 .48121 m .27462 .47254 L .28409 .47308 L F
.638 .765 .94 r
.70585 .45393 m .71145 .44537 L .71639 .45104 L F
.70585 .45393 m .70089 .4483 L .71145 .44537 L F
.596 .654 .877 r
.29661 .48997 m .30006 .47954 L .30633 .48738 L F
.29661 .48997 m .29038 .48134 L .30006 .47954 L F
.871 .862 .828 r
.38809 .40614 m .38186 .4028 L .39215 .39156 L F
.885 .865 .815 r
.37781 .418 m .38186 .4028 L .38809 .40614 L F
.641 .755 .931 r
.17049 .42457 m .17312 .41557 L .17995 .42186 L F
.17049 .42457 m .16361 .41858 L .17312 .41557 L F
.85 .82 .819 r
.34284 .47064 m .3365 .46609 L .34679 .4552 L F
.813 .789 .83 r
.33261 .48104 m .3365 .46609 L .34284 .47064 L F
.763 .749 .84 r
.3225 .48947 m .3263 .47531 L .33261 .48104 L F
.3225 .48947 m .31623 .48248 L .3263 .47531 L F
.633 .761 .94 r
.73184 .45388 m .7376 .44539 L .74245 .45111 L F
.73184 .45388 m .72697 .4482 L .7376 .44539 L F
.602 .748 .947 r
.82544 .45889 m .83178 .45107 L .83629 .45676 L F
.82544 .45889 m .8209 .45321 L .83178 .45107 L F
.711 .78 .906 r
.1444 .42704 m .14706 .41662 L .15403 .42246 L F
.1444 .42704 m .13739 .42135 L .14706 .41662 L F
.813 .789 .83 r
.33261 .48104 m .3263 .47531 L .3365 .46609 L F
.736 .787 .894 r
.41853 .37981 m .4226 .3684 L .42855 .37526 L F
.41853 .37981 m .41251 .374 L .4226 .3684 L F
.419 .633 .943 r
.212 .43351 m .21461 .42721 L .22121 .43454 L F
.212 .43351 m .20536 .42652 L .21461 .42721 L F
.626 .758 .941 r
.75788 .4541 m .76379 .44573 L .76854 .45146 L F
.75788 .4541 m .75309 .44839 L .76379 .44573 L F
.542 .906 .716 r
.57626 .4621 m .58121 .4574 L .58653 .45792 L F
.348 .58 .929 r
.22775 .44196 m .23041 .43626 L .23692 .44395 L F
.22775 .44196 m .22121 .43454 L .23041 .43626 L F
.278 .451 .853 r
.48161 .41326 m .48591 .40789 L .49163 .41794 L F
.48161 .41326 m .47589 .40342 L .48591 .40789 L F
.885 .865 .815 r
.37781 .418 m .37152 .41499 L .38186 .4028 L F
.888 .861 .809 r
.36748 .43054 m .37152 .41499 L .37781 .418 L F
.553 .729 .957 r
.89329 .46668 m .90016 .45996 L .9044 .4655 L F
.89329 .46668 m .88901 .46114 L .90016 .45996 L F
.347 .459 .832 r
.50298 .43951 m .50745 .43251 L .51311 .44319 L F
.50298 .43951 m .49732 .42838 L .50745 .43251 L F
.509 .687 .948 r
.19608 .42679 m .19868 .41956 L .20536 .42652 L F
.19608 .42679 m .18935 .42018 L .19868 .41956 L F
.587 .742 .95 r
.85164 .46042 m .85818 .45294 L .86259 .45859 L F
.85164 .46042 m .8472 .45477 L .85818 .45294 L F
.619 .754 .943 r
.78395 .45461 m .79003 .4464 L .79469 .45214 L F
.78395 .45461 m .77926 .4489 L .79003 .4464 L F
.322 .551 .916 r
.24339 .45177 m .24614 .44617 L .25259 .45413 L F
.24339 .45177 m .23692 .44395 L .24614 .44617 L F
.502 .635 .913 r
.44441 .38091 m .44853 .37304 L .45436 .38178 L F
.44441 .38091 m .43854 .37303 L .44853 .37304 L F
.655 .789 .946 r
.6384 .45281 m .64363 .44423 L .64881 .44957 L F
.6384 .45281 m .6332 .44762 L .64363 .44423 L F
.647 .776 .942 r
.66437 .45182 m .66975 .44318 L .67484 .44873 L F
.66437 .45182 m .65926 .44636 L .66975 .44318 L F
.669 .82 .956 r
.61245 .45453 m .61755 .44621 L .62281 .45105 L F
.61245 .45453 m .60717 .44999 L .61755 .44621 L F
.732 .782 .893 r
.118 .4319 m .12061 .42081 L .1277 .42652 L F
.118 .4319 m .11088 .42621 L .12061 .42081 L F
.642 .768 .94 r
.69037 .45127 m .69589 .44264 L .70089 .4483 L F
.69037 .45127 m .68534 .44567 L .69589 .44264 L F
.362 .532 .889 r
.46016 .3906 m .46435 .3844 L .47013 .39383 L F
.46016 .3906 m .45436 .38178 L .46435 .3844 L F
.609 .75 .945 r
.81008 .45547 m .81634 .44748 L .8209 .45321 L F
.81008 .45547 m .80549 .44976 L .81634 .44748 L F
.888 .861 .809 r
.36748 .43054 m .36114 .42754 L .37152 .41499 L F
.881 .852 .811 r
.35713 .44315 m .36114 .42754 L .36748 .43054 L F
.636 .763 .94 r
.71639 .45104 m .72207 .44247 L .72697 .4482 L F
.71639 .45104 m .71145 .44537 L .72207 .44247 L F
.359 .559 .911 r
.25898 .46229 m .26189 .45611 L .26829 .46421 L F
.25898 .46229 m .25259 .45413 L .26189 .45611 L F
.687 .771 .915 r
.15403 .42246 m .15668 .41252 L .16361 .41858 L F
.15403 .42246 m .14706 .41662 L .15668 .41252 L F
.65 .73 .908 r
.42855 .37526 m .43264 .36518 L .43854 .37303 L F
.42855 .37526 m .4226 .3684 L .43264 .36518 L F
.675 .705 .87 r
.30633 .48738 m .30992 .47561 L .31623 .48248 L F
.30633 .48738 m .30006 .47954 L .30992 .47561 L F
.591 .73 .94 r
.17995 .42186 m .18256 .41356 L .18935 .42018 L F
.17995 .42186 m .17312 .41557 L .18256 .41356 L F
.566 .734 .954 r
.87795 .46256 m .8847 .45553 L .88901 .46114 L F
.87795 .46256 m .87361 .45695 L .8847 .45553 L F
.543 .335 .548 r
.52209 .57254 m .52437 .46941 L .5301 .56818 L F
.51674 .57423 m .52437 .46941 L .52209 .57254 L F
.518 .5 .776 r
.52437 .46941 m .52896 .45604 L .53458 .46838 L F
.52437 .46941 m .51875 .45493 L .52896 .45604 L F
.685 .967 .931 r
.58653 .45792 m .59152 .45149 L .59683 .45389 L F
.58653 .45792 m .58121 .4574 L .59152 .45149 L F
.63 .759 .94 r
.74245 .45111 m .74828 .44263 L .75309 .44839 L F
.74245 .45111 m .7376 .44539 L .74828 .44263 L F
.595 .745 .948 r
.83629 .45676 m .84273 .44906 L .8472 .45477 L F
.83629 .45676 m .83178 .45107 L .84273 .44906 L F
.449 .598 .907 r
.27462 .47254 m .27773 .46508 L .28409 .47308 L F
.27462 .47254 m .26829 .46421 L .27773 .46508 L F
.623 .756 .942 r
.76854 .45146 m .77454 .44313 L .77926 .4489 L F
.76854 .45146 m .76379 .44573 L .77454 .44313 L F
.565 .653 .895 r
.29038 .48134 m .29373 .47193 L .30006 .47954 L F
.29038 .48134 m .28409 .47308 L .29373 .47193 L F
.727 .782 .896 r
.1277 .42652 m .13033 .41557 L .13739 .42135 L F
.1277 .42652 m .12061 .42081 L .13033 .41557 L F
.881 .852 .811 r
.35713 .44315 m .35075 .43982 L .36114 .42754 L F
.864 .838 .818 r
.34679 .4552 m .35075 .43982 L .35713 .44315 L F
.307 .453 .844 r
.49732 .42838 m .50175 .42236 L .50745 .43251 L F
.49732 .42838 m .49163 .41794 L .50175 .42236 L F
.282 .462 .861 r
.47589 .40342 m .48016 .39805 L .48591 .40789 L F
.47589 .40342 m .47013 .39383 L .48016 .39805 L F
.452 .507 .825 r
.51875 .45493 m .52332 .44548 L .52896 .45604 L F
.51875 .45493 m .51311 .44319 L .52332 .44548 L F
.653 .784 .943 r
.64881 .44957 m .65411 .44089 L .65926 .44636 L F
.64881 .44957 m .64363 .44423 L .65411 .44089 L F
.614 .752 .944 r
.79469 .45214 m .80085 .44399 L .80549 .44976 L F
.79469 .45214 m .79003 .4464 L .80085 .44399 L F
.646 .773 .941 r
.67484 .44873 m .68028 .44004 L .68534 .44567 L F
.67484 .44873 m .66975 .44318 L .68028 .44004 L F
.666 .807 .95 r
.62281 .45105 m .62797 .44252 L .6332 .44762 L F
.62281 .45105 m .61755 .44621 L .62797 .44252 L F
.742 .75 .859 r
.31623 .48248 m .31995 .46949 L .3263 .47531 L F
.31623 .48248 m .30992 .47561 L .31995 .46949 L F
.577 .738 .952 r
.86259 .45859 m .86923 .45129 L .87361 .45695 L F
.86259 .45859 m .85818 .45294 L .86923 .45129 L F
.64 .766 .94 r
.70089 .4483 m .70648 .43965 L .71145 .44537 L F
.70089 .4483 m .69589 .44264 L .70648 .43965 L F
.653 .757 .926 r
.16361 .41858 m .16624 .40924 L .17312 .41557 L F
.16361 .41858 m .15668 .41252 L .16624 .40924 L F
.864 .838 .818 r
.34679 .4552 m .3404 .45124 L .35075 .43982 L F
.836 .816 .831 r
.3365 .46609 m .3404 .45124 L .34679 .4552 L F
.817 .823 .854 r
.40236 .38182 m .40645 .36812 L .41251 .374 L F
.40236 .38182 m .39624 .37687 L .40645 .36812 L F
.853 .842 .833 r
.39215 .39156 m .39624 .37687 L .40236 .38182 L F
.364 .593 .933 r
.22121 .43454 m .22384 .42867 L .23041 .43626 L F
.22121 .43454 m .21461 .42721 L .22384 .42867 L F
.853 .842 .833 r
.39215 .39156 m .38594 .3874 L .39624 .37687 L F
.874 .852 .817 r
.38186 .4028 m .38594 .3874 L .39215 .39156 L F
.441 .646 .945 r
.20536 .42652 m .20796 .41993 L .21461 .42721 L F
.20536 .42652 m .19868 .41956 L .20796 .41993 L F
.704 .917 .967 r
.59683 .45389 m .60187 .44639 L .60717 .44999 L F
.59683 .45389 m .59152 .45149 L .60187 .44639 L F
.634 .761 .94 r
.72697 .4482 m .73272 .43962 L .7376 .44539 L F
.72697 .4482 m .72207 .44247 L .73272 .43962 L F
.603 .748 .946 r
.8209 .45321 m .82725 .44532 L .83178 .45107 L F
.8209 .45321 m .81634 .44748 L .82725 .44532 L F
.795 .787 .845 r
.3263 .47531 m .33012 .46127 L .3365 .46609 L F
.3263 .47531 m .31995 .46949 L .33012 .46127 L F
.715 .779 .902 r
.13739 .42135 m .14004 .41069 L .14706 .41662 L F
.13739 .42135 m .13033 .41557 L .14004 .41069 L F
.836 .816 .831 r
.3365 .46609 m .33012 .46127 L .3404 .45124 L F
.326 .559 .921 r
.23692 .44395 m .23964 .43834 L .24614 .44617 L F
.23692 .44395 m .23041 .43626 L .23964 .43834 L F
.762 .791 .876 r
.41251 .374 m .4166 .36152 L .4226 .3684 L F
.41251 .374 m .40645 .36812 L .4166 .36152 L F
.546 .658 .909 r
.43854 .37303 m .44266 .36433 L .44853 .37304 L F
.43854 .37303 m .43264 .36518 L .44266 .36433 L F
.627 .758 .941 r
.75309 .44839 m .759 .43993 L .76379 .44573 L F
.75309 .44839 m .74828 .44263 L .759 .43993 L F
.398 .556 .894 r
.45436 .38178 m .45853 .37503 L .46435 .3844 L F
.45436 .38178 m .44853 .37304 L .45853 .37503 L F
.874 .852 .817 r
.38186 .4028 m .37559 .39919 L .38594 .3874 L F
.884 .855 .809 r
.37152 .41499 m .37559 .39919 L .38186 .4028 L F
.529 .697 .946 r
.18935 .42018 m .19194 .41261 L .19868 .41956 L F
.18935 .42018 m .18256 .41356 L .19194 .41261 L F
.553 .728 .956 r
.88901 .46114 m .89588 .45435 L .90016 .45996 L F
.88901 .46114 m .8847 .45553 L .89588 .45435 L F
.552 .357 .571 r
.5301 .56818 m .53458 .46838 L .54034 .51526 L F
.561 .557 .806 r
.53458 .46838 m .53922 .45552 L .54483 .4657 L F
.53458 .46838 m .52896 .45604 L .53922 .45552 L F
.587 .742 .95 r
.8472 .45477 m .85373 .44721 L .85818 .45294 L F
.8472 .45477 m .84273 .44906 L .85373 .44721 L F
.345 .56 .916 r
.25259 .45413 m .25545 .44819 L .26189 .45611 L F
.25259 .45413 m .24614 .44617 L .25545 .44819 L F
.619 .754 .942 r
.77926 .4489 m .78533 .4406 L .79003 .4464 L F
.77926 .4489 m .77454 .44313 L .78533 .4406 L F
.393 .497 .846 r
.51311 .44319 m .51765 .43562 L .52332 .44548 L F
.51311 .44319 m .50745 .43251 L .51765 .43562 L F
.647 .704 .888 r
.30006 .47954 m .30355 .46882 L .30992 .47561 L F
.30006 .47954 m .29373 .47193 L .30355 .46882 L F
.278 .447 .849 r
.49163 .41794 m .49603 .41248 L .50175 .42236 L F
.49163 .41794 m .48591 .40789 L .49603 .41248 L F
.652 .779 .941 r
.65926 .44636 m .66462 .4376 L .66975 .44318 L F
.65926 .44636 m .65411 .44089 L .66462 .4376 L F
.663 .797 .946 r
.6332 .44762 m .63842 .43892 L .64363 .44423 L F
.6332 .44762 m .62797 .44252 L .63842 .43892 L F
.731 .78 .892 r
.11088 .42621 m .11347 .41502 L .12061 .42081 L F
.11088 .42621 m .10372 .42043 L .11347 .41502 L F
.644 .77 .939 r
.68534 .44567 m .69086 .43693 L .69589 .44264 L F
.68534 .44567 m .68028 .44004 L .69086 .43693 L F
.884 .855 .809 r
.37152 .41499 m .36518 .41165 L .37559 .39919 L F
.883 .853 .808 r
.36114 .42754 m .36518 .41165 L .37152 .41499 L F
.422 .594 .915 r
.26829 .46421 m .27133 .45726 L .27773 .46508 L F
.26829 .46421 m .26189 .45611 L .27133 .45726 L F
.685 .742 .894 r
.4226 .3684 m .4267 .35732 L .43264 .36518 L F
.4226 .3684 m .4166 .36152 L .4267 .35732 L F
.609 .75 .945 r
.80549 .44976 m .81173 .44169 L .81634 .44748 L F
.80549 .44976 m .80085 .44399 L .81173 .44169 L F
.638 .764 .939 r
.71145 .44537 m .71712 .43669 L .72207 .44247 L F
.71145 .44537 m .70648 .43965 L .71712 .43669 L F
.694 .771 .911 r
.14706 .41662 m .1497 .40639 L .15668 .41252 L F
.14706 .41662 m .14004 .41069 L .1497 .40639 L F
.697 .867 .962 r
.60717 .44999 m .61226 .4418 L .61755 .44621 L F
.60717 .44999 m .60187 .44639 L .61226 .4418 L F
.533 .648 .908 r
.28409 .47308 m .28735 .46447 L .29373 .47193 L F
.28409 .47308 m .27773 .46508 L .28735 .46447 L F
.606 .735 .936 r
.17312 .41557 m .17573 .40693 L .18256 .41356 L F
.17312 .41557 m .16624 .40924 L .17573 .40693 L F
.292 .474 .867 r
.47013 .39383 m .47438 .38833 L .48016 .39805 L F
.47013 .39383 m .46435 .3844 L .47438 .38833 L F
.566 .733 .954 r
.87361 .45695 m .88035 .44985 L .8847 .45553 L F
.87361 .45695 m .86923 .45129 L .88035 .44985 L F
.631 .759 .94 r
.7376 .44539 m .74343 .43681 L .74828 .44263 L F
.7376 .44539 m .73272 .43962 L .74343 .43681 L F
.596 .744 .948 r
.83178 .45107 m .83822 .44329 L .84273 .44906 L F
.83178 .45107 m .82725 .44532 L .83822 .44329 L F
.883 .853 .808 r
.36114 .42754 m .35476 .42418 L .36518 .41165 L F
.873 .846 .814 r
.35075 .43982 m .35476 .42418 L .36114 .42754 L F
.624 .756 .941 r
.76379 .44573 m .76978 .43729 L .77454 .44313 L F
.76379 .44573 m .759 .43993 L .76978 .43729 L F
.502 .56 .847 r
.52896 .45604 m .5336 .44632 L .53922 .45552 L F
.52896 .45604 m .52332 .44548 L .5336 .44632 L F
.728 .78 .894 r
.12061 .42081 m .12323 .40971 L .13033 .41557 L F
.12061 .42081 m .11347 .41502 L .12323 .40971 L F
.719 .749 .876 r
.30992 .47561 m .31355 .46359 L .31995 .46949 L F
.30992 .47561 m .30355 .46882 L .31355 .46359 L F
.573 .403 .613 r
.54034 .51526 m .54483 .4657 L .55052 .48927 L F
.604 .62 .84 r
.54483 .4657 m .54954 .45362 L .55511 .46187 L F
.54483 .4657 m .53922 .45552 L .54954 .45362 L F
.706 .731 .87 r
.57094 .46469 m .57576 .45236 L .58121 .45741 L F
.664 .606 .78 r
.56071 .47446 m .56542 .45731 L .57094 .46469 L F
.615 .752 .943 r
.79003 .4464 m .79619 .43816 L .80085 .44399 L F
.79003 .4464 m .78533 .4406 L .79619 .43816 L F
.612 .485 .684 r
.55052 .48927 m .55511 .46187 L .56071 .47446 L F
.38 .605 .937 r
.21461 .42721 m .21722 .42115 L .22384 .42867 L F
.21461 .42721 m .20796 .41993 L .21722 .42115 L F
.66 .788 .943 r
.64363 .44423 m .64892 .4354 L .65411 .44089 L F
.64363 .44423 m .63842 .43892 L .64892 .4354 L F
.649 .774 .94 r
.66975 .44318 m .67518 .43435 L .68028 .44004 L F
.66975 .44318 m .66462 .4376 L .67518 .43435 L F
.341 .481 .855 r
.50745 .43251 m .51196 .4261 L .51765 .43562 L F
.50745 .43251 m .50175 .42236 L .51196 .4261 L F
.578 .737 .951 r
.85818 .45294 m .86481 .44555 L .86923 .45129 L F
.85818 .45294 m .85373 .44721 L .86481 .44555 L F
.462 .657 .945 r
.19868 .41956 m .20126 .41269 L .20796 .41993 L F
.19868 .41956 m .19194 .41261 L .20126 .41269 L F
.663 .759 .921 r
.15668 .41252 m .15931 .40286 L .16624 .40924 L F
.15668 .41252 m .1497 .40639 L .15931 .40286 L F
.873 .846 .814 r
.35075 .43982 m .34434 .43615 L .35476 .42418 L F
.853 .833 .826 r
.3404 .45124 m .34434 .43615 L .35075 .43982 L F
.434 .577 .897 r
.44853 .37304 m .45268 .36569 L .45853 .37503 L F
.44853 .37304 m .44266 .36433 L .45268 .36569 L F
.642 .767 .939 r
.69589 .44264 m .70148 .43386 L .70648 .43965 L F
.69589 .44264 m .69086 .43693 L .70148 .43386 L F
.33 .567 .925 r
.23041 .43626 m .23309 .43062 L .23964 .43834 L F
.23041 .43626 m .22384 .42867 L .23309 .43062 L F
.687 .832 .953 r
.61755 .44621 m .6227 .43756 L .62797 .44252 L F
.61755 .44621 m .61226 .4418 L .6227 .43756 L F
.586 .676 .903 r
.43264 .36518 m .43675 .35562 L .44266 .36433 L F
.43264 .36518 m .4267 .35732 L .43675 .35562 L F
.259 .442 .852 r
.48591 .40789 m .49028 .40276 L .49603 .41248 L F
.48591 .40789 m .48016 .39805 L .49028 .40276 L F
.722 .814 .922 r
.58121 .45741 m .58612 .44728 L .59152 .45149 L F
.58121 .45741 m .57576 .45236 L .58612 .44728 L F
.635 .762 .939 r
.72207 .44247 m .7278 .43378 L .73272 .43962 L F
.72207 .44247 m .71712 .43669 L .7278 .43378 L F
.603 .747 .946 r
.81634 .44748 m .82267 .4395 L .82725 .44532 L F
.81634 .44748 m .81173 .44169 L .82267 .4395 L F
.777 .785 .859 r
.31995 .46949 m .3237 .45625 L .33012 .46127 L F
.31995 .46949 m .31355 .46359 L .3237 .45625 L F
.831 .82 .838 r
.39624 .37687 m .40035 .36217 L .40645 .36812 L F
.39624 .37687 m .39006 .37182 L .40035 .36217 L F
.861 .836 .82 r
.38594 .3874 m .39006 .37182 L .39624 .37687 L F
.335 .56 .919 r
.24614 .44617 m .24895 .44039 L .25545 .44819 L F
.24614 .44617 m .23964 .43834 L .24895 .44039 L F
.718 .778 .9 r
.13033 .41557 m .13297 .4047 L .14004 .41069 L F
.13033 .41557 m .12323 .40971 L .13297 .4047 L F
.853 .833 .826 r
.3404 .45124 m .33398 .447 L .34434 .43615 L F
.822 .813 .842 r
.33012 .46127 m .33398 .447 L .3404 .45124 L F
.548 .705 .943 r
.18256 .41356 m .18515 .40567 L .19194 .41261 L F
.18256 .41356 m .17573 .40693 L .18515 .40567 L F
.784 .793 .86 r
.40645 .36812 m .41057 .3546 L .4166 .36152 L F
.40645 .36812 m .40035 .36217 L .41057 .3546 L F
.628 .757 .94 r
.74828 .44263 m .75418 .43407 L .759 .43993 L F
.74828 .44263 m .74343 .43681 L .75418 .43407 L F
.822 .813 .842 r
.33012 .46127 m .3237 .45625 L .33398 .447 L F
.861 .836 .82 r
.38594 .3874 m .3797 .38307 L .39006 .37182 L F
.877 .845 .809 r
.37559 .39919 m .3797 .38307 L .38594 .3874 L F
.618 .7 .903 r
.29373 .47193 m .29714 .46206 L .30355 .46882 L F
.29373 .47193 m .28735 .46447 L .29714 .46206 L F
.308 .487 .872 r
.46435 .3844 m .46857 .37865 L .47438 .38833 L F
.46435 .3844 m .45853 .37503 L .46857 .37865 L F
.553 .727 .956 r
.8847 .45553 m .89156 .44866 L .89588 .45435 L F
.8847 .45553 m .88035 .44985 L .89156 .44866 L F
.397 .589 .92 r
.26189 .45611 m .26487 .44957 L .27133 .45726 L F
.26189 .45611 m .25545 .44819 L .26487 .44957 L F
.588 .741 .949 r
.84273 .44906 m .84925 .44142 L .85373 .44721 L F
.84273 .44906 m .83822 .44329 L .84925 .44142 L F
.62 .753 .941 r
.77454 .44313 m .7806 .43473 L .78533 .4406 L F
.77454 .44313 m .76978 .43729 L .7806 .43473 L F
.502 .642 .918 r
.27773 .46508 m .28092 .45712 L .28735 .46447 L F
.27773 .46508 m .27133 .45726 L .28092 .45712 L F
.643 .684 .874 r
.55511 .46187 m .55989 .45059 L .56542 .45731 L F
.55511 .46187 m .54954 .45362 L .55989 .45059 L F
.443 .546 .866 r
.52332 .44548 m .52794 .4375 L .5336 .44632 L F
.52332 .44548 m .51765 .43562 L .52794 .4375 L F
.72 .848 .942 r
.59152 .45149 m .59651 .44224 L .60187 .44639 L F
.59152 .45149 m .58612 .44728 L .59651 .44224 L F
.715 .751 .881 r
.4166 .36152 m .42072 .34945 L .4267 .35732 L F
.4166 .36152 m .41057 .3546 L .42072 .34945 L F
.877 .845 .809 r
.37559 .39919 m .36927 .39537 L .3797 .38307 L F
.883 .848 .804 r
.36518 .41165 m .36927 .39537 L .37559 .39919 L F
.657 .781 .94 r
.65411 .44089 m .65946 .43195 L .66462 .4376 L F
.65411 .44089 m .64892 .4354 L .65946 .43195 L F
.73 .779 .892 r
.10372 .42043 m .10628 .40914 L .11347 .41502 L F
.10372 .42043 m .09651 .41456 L .10628 .40914 L F
.647 .77 .938 r
.68028 .44004 m .68578 .43115 L .69086 .43693 L F
.68028 .44004 m .67518 .43435 L .68578 .43115 L F
.678 .809 .945 r
.62797 .44252 m .63317 .43357 L .63842 .43892 L F
.62797 .44252 m .6227 .43756 L .63317 .43357 L F
.61 .749 .944 r
.80085 .44399 m .80709 .43582 L .81173 .44169 L F
.80085 .44399 m .79619 .43816 L .80709 .43582 L F
.551 .618 .873 r
.53922 .45552 m .54393 .44576 L .54954 .45362 L F
.53922 .45552 m .5336 .44632 L .54393 .44576 L F
.619 .739 .932 r
.16624 .40924 m .16885 .40027 L .17573 .40693 L F
.16624 .40924 m .15931 .40286 L .16885 .40027 L F
.7 .771 .907 r
.14004 .41069 m .14268 .40021 L .1497 .40639 L F
.14004 .41069 m .13297 .4047 L .14268 .40021 L F
.64 .764 .938 r
.70648 .43965 m .71214 .43084 L .71712 .43669 L F
.70648 .43965 m .70148 .43386 L .71214 .43084 L F
.297 .463 .857 r
.50175 .42236 m .50623 .41673 L .51196 .4261 L F
.50175 .42236 m .49603 .41248 L .50623 .41673 L F
.566 .732 .953 r
.86923 .45129 m .87597 .4441 L .88035 .44985 L F
.86923 .45129 m .86481 .44555 L .87597 .4441 L F
.633 .759 .939 r
.73272 .43962 m .73854 .43092 L .74343 .43681 L F
.73272 .43962 m .7278 .43378 L .73854 .43092 L F
.883 .848 .804 r
.36518 .41165 m .3588 .40808 L .36927 .39537 L F
.88 .847 .807 r
.35476 .42418 m .3588 .40808 L .36518 .41165 L F
.596 .744 .947 r
.82725 .44532 m .83367 .43744 L .83822 .44329 L F
.82725 .44532 m .82267 .4395 L .83367 .43744 L F
.713 .85 .948 r
.60187 .44639 m .60693 .43735 L .61226 .4418 L F
.60187 .44639 m .59651 .44224 L .60693 .43735 L F
.246 .439 .853 r
.48016 .39805 m .4845 .39309 L .49028 .40276 L F
.48016 .39805 m .47438 .38833 L .4845 .39309 L F
.674 .742 .902 r
.56542 .45731 m .57026 .44674 L .57576 .45236 L F
.56542 .45731 m .55989 .45059 L .57026 .44674 L F
.695 .746 .89 r
.30355 .46882 m .30711 .45762 L .31355 .46359 L F
.30355 .46882 m .29714 .46206 L .30711 .45762 L F
.625 .755 .94 r
.759 .43993 m .76498 .43138 L .76978 .43729 L F
.759 .43993 m .75418 .43407 L .76498 .43138 L F
.47 .597 .897 r
.44266 .36433 m .4468 .35634 L .45268 .36569 L F
.44266 .36433 m .43675 .35562 L .4468 .35634 L F
.729 .779 .893 r
.11347 .41502 m .11607 .40376 L .12323 .40971 L F
.11347 .41502 m .10628 .40914 L .11607 .40376 L F
.396 .616 .939 r
.20796 .41993 m .21055 .41368 L .21722 .42115 L F
.20796 .41993 m .20126 .41269 L .21055 .41368 L F
.336 .574 .928 r
.22384 .42867 m .22648 .42296 L .23309 .43062 L F
.22384 .42867 m .21722 .42115 L .22648 .42296 L F
.621 .692 .894 r
.4267 .35732 m .43081 .34689 L .43675 .35562 L F
.4267 .35732 m .42072 .34945 L .43081 .34689 L F
.48 .667 .945 r
.19194 .41261 m .19451 .40546 L .20126 .41269 L F
.19194 .41261 m .18515 .40567 L .19451 .40546 L F
.616 .751 .942 r
.78533 .4406 m .79148 .43225 L .79619 .43816 L F
.78533 .4406 m .7806 .43473 L .79148 .43225 L F
.88 .847 .807 r
.35476 .42418 m .34833 .42056 L .3588 .40808 L F
.867 .841 .817 r
.34434 .43615 m .34833 .42056 L .35476 .42418 L F
.578 .736 .95 r
.85373 .44721 m .86036 .43973 L .86481 .44555 L F
.85373 .44721 m .84925 .44142 L .86036 .43973 L F
.654 .775 .937 r
.66462 .4376 m .67004 .42857 L .67518 .43435 L F
.66462 .4376 m .65946 .43195 L .67004 .42857 L F
.671 .76 .917 r
.1497 .40639 m .15233 .39644 L .15931 .40286 L F
.1497 .40639 m .14268 .40021 L .15233 .39644 L F
.326 .561 .922 r
.23964 .43834 m .2424 .43268 L .24895 .44039 L F
.23964 .43834 m .23309 .43062 L .2424 .43268 L F
.328 .5 .876 r
.45853 .37503 m .46273 .36896 L .46857 .37865 L F
.45853 .37503 m .45268 .36569 L .46273 .36896 L F
.671 .792 .939 r
.63842 .43892 m .64369 .42978 L .64892 .4354 L F
.63842 .43892 m .63317 .43357 L .64369 .42978 L F
.645 .767 .937 r
.69086 .43693 m .69643 .42799 L .70148 .43386 L F
.69086 .43693 m .68578 .43115 L .69643 .42799 L F
.385 .524 .873 r
.51765 .43562 m .52225 .42883 L .52794 .4375 L F
.51765 .43562 m .51196 .4261 L .52225 .42883 L F
.588 .693 .915 r
.28735 .46447 m .29068 .45532 L .29714 .46206 L F
.28735 .46447 m .28092 .45712 L .29068 .45532 L F
.637 .761 .938 r
.71712 .43669 m .72285 .42787 L .7278 .43378 L F
.71712 .43669 m .71214 .43084 L .72285 .42787 L F
.604 .746 .945 r
.81173 .44169 m .81806 .4336 L .82267 .4395 L F
.81173 .44169 m .80709 .43582 L .81806 .4336 L F
.375 .583 .923 r
.25545 .44819 m .25836 .44196 L .26487 .44957 L F
.25545 .44819 m .24895 .44039 L .25836 .44196 L F
.759 .783 .873 r
.31355 .46359 m .31724 .45107 L .3237 .45625 L F
.31355 .46359 m .30711 .45762 L .31724 .45107 L F
.564 .712 .941 r
.17573 .40693 m .17831 .39872 L .18515 .40567 L F
.17573 .40693 m .16885 .40027 L .17831 .39872 L F
.696 .788 .922 r
.57576 .45236 m .58067 .44233 L .58612 .44728 L F
.57576 .45236 m .57026 .44674 L .58067 .44233 L F
.704 .837 .946 r
.61226 .4418 m .61739 .43269 L .6227 .43756 L F
.61226 .4418 m .60693 .43735 L .61739 .43269 L F
.597 .677 .897 r
.54954 .45362 m .55431 .44392 L .55989 .45059 L F
.54954 .45362 m .54393 .44576 L .55431 .44392 L F
.721 .777 .897 r
.12323 .40971 m .12586 .39863 L .13297 .4047 L F
.12323 .40971 m .11607 .40376 L .12586 .39863 L F
.472 .634 .925 r
.27133 .45726 m .27444 .44983 L .28092 .45712 L F
.27133 .45726 m .26487 .44957 L .27444 .44983 L F
.867 .841 .817 r
.34434 .43615 m .33789 .43221 L .34833 .42056 L F
.844 .829 .833 r
.33398 .447 m .33789 .43221 L .34434 .43615 L F
.63 .757 .939 r
.74343 .43681 m .74931 .42813 L .75418 .43407 L F
.74343 .43681 m .73854 .43092 L .74931 .42813 L F
.801 .793 .845 r
.40035 .36217 m .40449 .34764 L .41057 .3546 L F
.40035 .36217 m .39421 .35617 L .40449 .34764 L F
.842 .817 .825 r
.39006 .37182 m .39421 .35617 L .40035 .36217 L F
.39006 .37182 m .38384 .36667 L .39421 .35617 L F
.867 .831 .81 r
.3797 .38307 m .38384 .36667 L .39006 .37182 L F
.495 .602 .889 r
.5336 .44632 m .53829 .43803 L .54393 .44576 L F
.5336 .44632 m .52794 .4375 L .53829 .43803 L F
.258 .445 .855 r
.49603 .41248 m .50048 .40744 L .50623 .41673 L F
.49603 .41248 m .49028 .40276 L .50048 .40744 L F
.808 .81 .852 r
.3237 .45625 m .32751 .44252 L .33398 .447 L F
.3237 .45625 m .31724 .45107 L .32751 .44252 L F
.553 .726 .955 r
.88035 .44985 m .88721 .44289 L .89156 .44866 L F
.88035 .44985 m .87597 .4441 L .88721 .44289 L F
.844 .829 .833 r
.33398 .447 m .32751 .44252 L .33789 .43221 L F
.621 .753 .94 r
.76978 .43729 m .77583 .42878 L .7806 .43473 L F
.76978 .43729 m .76498 .43138 L .77583 .42878 L F
.588 .74 .948 r
.83822 .44329 m .84474 .43555 L .84925 .44142 L F
.83822 .44329 m .83367 .43744 L .84474 .43555 L F
.74 .757 .866 r
.41057 .3546 m .4147 .34153 L .42072 .34945 L F
.41057 .3546 m .40449 .34764 L .4147 .34153 L F
.867 .831 .81 r
.3797 .38307 m .3734 .37862 L .38384 .36667 L F
.88 .84 .801 r
.36927 .39537 m .3734 .37862 L .3797 .38307 L F
.239 .437 .854 r
.47438 .38833 m .47868 .38342 L .4845 .39309 L F
.47438 .38833 m .46857 .37865 L .47868 .38342 L F
.73 .778 .891 r
.09651 .41456 m .09905 .40319 L .10628 .40914 L F
.09651 .41456 m .08925 .40862 L .09905 .40319 L F
.631 .743 .928 r
.15931 .40286 m .16191 .39358 L .16885 .40027 L F
.15931 .40286 m .15233 .39644 L .16191 .39358 L F
.665 .78 .935 r
.64892 .4354 m .65425 .42612 L .65946 .43195 L F
.64892 .4354 m .64369 .42978 L .65425 .42612 L F
.651 .77 .936 r
.67518 .43435 m .68067 .42526 L .68578 .43115 L F
.67518 .43435 m .67004 .42857 L .68067 .42526 L F
.708 .817 .933 r
.58612 .44728 m .5911 .43759 L .59651 .44224 L F
.58612 .44728 m .58067 .44233 L .5911 .43759 L F
.611 .748 .943 r
.79619 .43816 m .80242 .42988 L .80709 .43582 L F
.79619 .43816 m .79148 .43225 L .80242 .42988 L F
.705 .772 .904 r
.13297 .4047 m .13561 .39397 L .14268 .40021 L F
.13297 .4047 m .12586 .39863 L .13561 .39397 L F
.505 .615 .895 r
.43675 .35562 m .44088 .34694 L .4468 .35634 L F
.43675 .35562 m .43081 .34689 L .44088 .34694 L F
.642 .763 .936 r
.70148 .43386 m .70712 .42489 L .71214 .43084 L F
.70148 .43386 m .69643 .42799 L .70712 .42489 L F
.695 .818 .941 r
.6227 .43756 m .62788 .42827 L .63317 .43357 L F
.6227 .43756 m .61739 .43269 L .62788 .42827 L F
.88 .84 .801 r
.36927 .39537 m .3629 .39139 L .3734 .37862 L F
.883 .843 .801 r
.3588 .40808 m .3629 .39139 L .36927 .39537 L F
.567 .731 .952 r
.86481 .44555 m .87155 .43826 L .87597 .4441 L F
.86481 .44555 m .86036 .43973 L .87155 .43826 L F
.635 .759 .937 r
.7278 .43378 m .73361 .42495 L .73854 .43092 L F
.7278 .43378 m .72285 .42787 L .73361 .42495 L F
.67 .741 .904 r
.29714 .46206 m .30062 .45158 L .30711 .45762 L F
.29714 .46206 m .29068 .45532 L .30062 .45158 L F
.637 .732 .917 r
.55989 .45059 m .56472 .44101 L .57026 .44674 L F
.55989 .45059 m .55431 .44392 L .56472 .44101 L F
.35 .514 .879 r
.45268 .36569 m .45686 .35924 L .46273 .36896 L F
.45268 .36569 m .4468 .35634 L .45686 .35924 L F
.411 .626 .941 r
.20126 .41269 m .20382 .40623 L .21055 .41368 L F
.20126 .41269 m .19451 .40546 L .20382 .40623 L F
.33 .498 .874 r
.51196 .4261 m .51653 .42023 L .52225 .42883 L F
.51196 .4261 m .50623 .41673 L .51653 .42023 L F
.597 .743 .946 r
.82267 .4395 m .82909 .43152 L .83367 .43744 L F
.82267 .4395 m .81806 .4336 L .82909 .43152 L F
.343 .581 .931 r
.21722 .42115 m .21983 .41536 L .22648 .42296 L F
.21722 .42115 m .21055 .41368 L .21983 .41536 L F
.653 .704 .884 r
.42072 .34945 m .42484 .33811 L .43081 .34689 L F
.42072 .34945 m .4147 .34153 L .42484 .33811 L F
.627 .754 .939 r
.75418 .43407 m .76014 .42539 L .76498 .43138 L F
.75418 .43407 m .74931 .42813 L .76014 .42539 L F
.497 .676 .945 r
.18515 .40567 m .18771 .39824 L .19451 .40546 L F
.18515 .40567 m .17831 .39872 L .18771 .39824 L F
.73 .778 .892 r
.10628 .40914 m .10887 .39775 L .11607 .40376 L F
.10628 .40914 m .09905 .40319 L .10887 .39775 L F
.319 .561 .924 r
.23309 .43062 m .23579 .42502 L .2424 .43268 L F
.23309 .43062 m .22648 .42296 L .23579 .42502 L F
.712 .831 .938 r
.59651 .44224 m .60155 .43272 L .60693 .43735 L F
.59651 .44224 m .5911 .43759 L .60155 .43272 L F
.883 .843 .801 r
.3588 .40808 m .35238 .4043 L .3629 .39139 L F
.877 .843 .808 r
.34833 .42056 m .35238 .4043 L .3588 .40808 L F
.617 .75 .941 r
.7806 .43473 m .78674 .42626 L .79148 .43225 L F
.7806 .43473 m .77583 .42878 L .78674 .42626 L F
.224 .428 .85 r
.49028 .40276 m .49469 .39814 L .50048 .40744 L F
.49028 .40276 m .4845 .39309 L .49469 .39814 L F
.354 .577 .925 r
.24895 .44039 m .2518 .43442 L .25836 .44196 L F
.24895 .44039 m .2424 .43268 L .2518 .43442 L F
.558 .685 .925 r
.28092 .45712 m .28417 .44859 L .29068 .45532 L F
.28092 .45712 m .27444 .44983 L .28417 .44859 L F
.679 .762 .913 r
.14268 .40021 m .1453 .38998 L .15233 .39644 L F
.14268 .40021 m .13561 .39397 L .1453 .38998 L F
.547 .661 .911 r
.54393 .44576 m .5487 .43724 L .55431 .44392 L F
.54393 .44576 m .53829 .43803 L .5487 .43724 L F
.437 .578 .896 r
.52794 .4375 m .53262 .43034 L .53829 .43803 L F
.52794 .4375 m .52225 .42883 L .53262 .43034 L F
.579 .735 .949 r
.84925 .44142 m .85588 .43384 L .86036 .43973 L F
.84925 .44142 m .84474 .43555 L .85588 .43384 L F
.66 .772 .932 r
.65946 .43195 m .66486 .42259 L .67004 .42857 L F
.65946 .43195 m .65425 .42612 L .66486 .42259 L F
.442 .624 .93 r
.26487 .44957 m .26791 .44259 L .27444 .44983 L F
.26487 .44957 m .25836 .44196 L .26791 .44259 L F
.648 .765 .934 r
.68578 .43115 m .69134 .42201 L .69643 .42799 L F
.68578 .43115 m .68067 .42526 L .69134 .42201 L F
.686 .8 .936 r
.63317 .43357 m .63842 .42409 L .64369 .42978 L F
.63317 .43357 m .62788 .42827 L .63842 .42409 L F
.578 .717 .938 r
.16885 .40027 m .17142 .39175 L .17831 .39872 L F
.16885 .40027 m .16191 .39358 L .17142 .39175 L F
.64 .76 .936 r
.71214 .43084 m .71785 .42185 L .72285 .42787 L F
.71214 .43084 m .70712 .42489 L .71785 .42185 L F
.74 .779 .885 r
.30711 .45762 m .31074 .44576 L .31724 .45107 L F
.30711 .45762 m .30062 .45158 L .31074 .44576 L F
.605 .745 .944 r
.80709 .43582 m .81341 .42762 L .81806 .4336 L F
.80709 .43582 m .80242 .42988 L .81341 .42762 L F
.237 .437 .854 r
.46857 .37865 m .47284 .37371 L .47868 .38342 L F
.46857 .37865 m .46273 .36896 L .47284 .37371 L F
.67 .778 .93 r
.57026 .44674 m .57517 .43725 L .58067 .44233 L F
.57026 .44674 m .56472 .44101 L .57517 .43725 L F
.877 .843 .808 r
.34833 .42056 m .34186 .41672 L .35238 .4043 L F
.861 .837 .821 r
.33789 .43221 m .34186 .41672 L .34833 .42056 L F
.723 .776 .895 r
.11607 .40376 m .11869 .3925 L .12586 .39863 L F
.11607 .40376 m .10887 .39775 L .11869 .3925 L F
.632 .756 .937 r
.73854 .43092 m .74441 .42209 L .74931 .42813 L F
.73854 .43092 m .73361 .42495 L .74441 .42209 L F
.817 .794 .83 r
.39421 .35617 m .39837 .34064 L .40449 .34764 L F
.39421 .35617 m .38802 .35011 L .39837 .34064 L F
.852 .814 .812 r
.38384 .36667 m .38802 .35011 L .39421 .35617 L F
.711 .832 .94 r
.60693 .43735 m .61204 .42786 L .61739 .43269 L F
.60693 .43735 m .60155 .43272 L .61204 .42786 L F
.762 .762 .852 r
.40449 .34764 m .40864 .33357 L .4147 .34153 L F
.40449 .34764 m .39837 .34064 L .40864 .33357 L F
.554 .725 .954 r
.87597 .4441 m .88282 .43704 L .88721 .44289 L F
.87597 .4441 m .87155 .43826 L .88282 .43704 L F
.852 .814 .812 r
.38384 .36667 m .37757 .36146 L .38802 .35011 L F
.873 .827 .8 r
.3734 .37862 m .37757 .36146 L .38384 .36667 L F
.538 .631 .892 r
.43081 .34689 m .43494 .33747 L .44088 .34694 L F
.43081 .34689 m .42484 .33811 L .43494 .33747 L F
.623 .752 .939 r
.76498 .43138 m .77102 .42274 L .77583 .42878 L F
.76498 .43138 m .76014 .42539 L .77102 .42274 L F
.589 .739 .947 r
.83367 .43744 m .84019 .42959 L .84474 .43555 L F
.83367 .43744 m .82909 .43152 L .84019 .42959 L F
.794 .808 .863 r
.31724 .45107 m .321 .43786 L .32751 .44252 L F
.31724 .45107 m .31074 .44576 L .321 .43786 L F
.861 .837 .821 r
.33789 .43221 m .33139 .42807 L .34186 .41672 L F
.834 .826 .84 r
.32751 .44252 m .33139 .42807 L .33789 .43221 L F
.32751 .44252 m .321 .43786 L .33139 .42807 L F
.277 .47 .869 r
.50623 .41673 m .51078 .41162 L .51653 .42023 L F
.50623 .41673 m .50048 .40744 L .51078 .41162 L F
.374 .528 .881 r
.4468 .35634 m .45096 .34943 L .45686 .35924 L F
.4468 .35634 m .44088 .34694 L .45096 .34943 L F
.642 .746 .924 r
.15233 .39644 m .15493 .38686 L .16191 .39358 L F
.15233 .39644 m .1453 .38998 L .15493 .38686 L F
.729 .777 .891 r
.08925 .40862 m .09177 .39716 L .09905 .40319 L F
.08925 .40862 m .08195 .40261 L .09177 .39716 L F
.612 .747 .941 r
.79148 .43225 m .7977 .42385 L .80242 .42988 L F
.79148 .43225 m .78674 .42626 L .7977 .42385 L F
.656 .766 .93 r
.67004 .42857 m .67551 .41916 L .68067 .42526 L F
.67004 .42857 m .66486 .42259 L .67551 .41916 L F
.677 .783 .93 r
.64369 .42978 m .649 .42013 L .65425 .42612 L F
.64369 .42978 m .63842 .42409 L .649 .42013 L F
.873 .827 .8 r
.3734 .37862 m .36705 .37407 L .37757 .36146 L F
.882 .835 .795 r
.3629 .39139 m .36705 .37407 L .3734 .37862 L F
.709 .772 .901 r
.12586 .39863 m .12848 .38767 L .13561 .39397 L F
.12586 .39863 m .11869 .3925 L .12848 .38767 L F
.645 .762 .933 r
.69643 .42799 m .70206 .41882 L .70712 .42489 L F
.69643 .42799 m .69134 .42201 L .70206 .41882 L F
.693 .81 .937 r
.58067 .44233 m .58564 .43287 L .5911 .43759 L F
.58067 .44233 m .57517 .43725 L .58564 .43287 L F
.681 .714 .873 r
.4147 .34153 m .41883 .32926 L .42484 .33811 L F
.4147 .34153 m .40864 .33357 L .41883 .32926 L F
.351 .588 .933 r
.21055 .41368 m .21312 .40777 L .21983 .41536 L F
.21055 .41368 m .20382 .40623 L .21312 .40777 L F
.644 .735 .915 r
.29068 .45532 m .29409 .44549 L .30062 .45158 L F
.29068 .45532 m .28417 .44859 L .29409 .44549 L F
.426 .635 .942 r
.19451 .40546 m .19705 .39879 L .20382 .40623 L F
.19451 .40546 m .18771 .39824 L .19705 .39879 L F
.597 .718 .929 r
.55431 .44392 m .55914 .43521 L .56472 .44101 L F
.55431 .44392 m .5487 .43724 L .55914 .43521 L F
.568 .73 .951 r
.86036 .43973 m .86709 .43234 L .87155 .43826 L F
.86036 .43973 m .85588 .43384 L .86709 .43234 L F
.195 .411 .845 r
.4845 .39309 m .48888 .38881 L .49469 .39814 L F
.4845 .39309 m .47868 .38342 L .48888 .38881 L F
.637 .757 .935 r
.72285 .42787 m .72864 .41887 L .73361 .42495 L F
.72285 .42787 m .71785 .42185 L .72864 .41887 L F
.706 .825 .938 r
.61739 .43269 m .62256 .42313 L .62788 .42827 L F
.61739 .43269 m .61204 .42786 L .62256 .42313 L F
.314 .562 .925 r
.22648 .42296 m .22914 .4174 L .23579 .42502 L F
.22648 .42296 m .21983 .41536 L .22914 .4174 L F
.598 .742 .945 r
.81806 .4336 m .82447 .4255 L .82909 .43152 L F
.81806 .4336 m .81341 .42762 L .82447 .4255 L F
.513 .684 .944 r
.17831 .39872 m .18086 .39102 L .18771 .39824 L F
.17831 .39872 m .17142 .39175 L .18086 .39102 L F
.377 .549 .897 r
.52225 .42883 m .52691 .42264 L .53262 .43034 L F
.52225 .42883 m .51653 .42023 L .52691 .42264 L F
.628 .753 .937 r
.74931 .42813 m .75527 .41931 L .76014 .42539 L F
.74931 .42813 m .74441 .42209 L .75527 .41931 L F
.335 .571 .926 r
.2424 .43268 m .24519 .42691 L .2518 .43442 L F
.2424 .43268 m .23579 .42502 L .24519 .42691 L F
.882 .835 .795 r
.3629 .39139 m .35649 .38727 L .36705 .37407 L F
.883 .839 .798 r
.35238 .4043 m .35649 .38727 L .3629 .39139 L F
.239 .438 .855 r
.46273 .36896 m .46697 .36392 L .47284 .37371 L F
.46273 .36896 m .45686 .35924 L .46697 .36392 L F
.494 .638 .919 r
.53829 .43803 m .54304 .43052 L .5487 .43724 L F
.53829 .43803 m .53262 .43034 L .54304 .43052 L F
.73 .778 .891 r
.09905 .40319 m .10162 .39166 L .10887 .39775 L F
.09905 .40319 m .09177 .39716 L .10162 .39166 L F
.527 .675 .932 r
.27444 .44983 m .27762 .44184 L .28417 .44859 L F
.27444 .44983 m .26791 .44259 L .27762 .44184 L F
.413 .614 .932 r
.25836 .44196 m .26133 .43537 L .26791 .44259 L F
.25836 .44196 m .2518 .43442 L .26133 .43537 L F
.618 .749 .939 r
.77583 .42878 m .78196 .42018 L .78674 .42626 L F
.77583 .42878 m .77102 .42274 L .78196 .42018 L F
.686 .763 .91 r
.13561 .39397 m .13823 .38347 L .1453 .38998 L F
.13561 .39397 m .12848 .38767 L .13823 .38347 L F
.708 .829 .94 r
.5911 .43759 m .59613 .4281 L .60155 .43272 L F
.5911 .43759 m .58564 .43287 L .59613 .4281 L F
.58 .734 .948 r
.84474 .43555 m .85135 .42785 L .85588 .43384 L F
.84474 .43555 m .84019 .42959 L .85135 .42785 L F
.669 .77 .926 r
.65425 .42612 m .65963 .41637 L .66486 .42259 L F
.65425 .42612 m .649 .42013 L .65963 .41637 L F
.592 .723 .935 r
.16191 .39358 m .16448 .38477 L .17142 .39175 L F
.16191 .39358 m .15493 .38686 L .16448 .38477 L F
.652 .761 .929 r
.68067 .42526 m .68621 .41582 L .69134 .42201 L F
.68067 .42526 m .67551 .41916 L .68621 .41582 L F
.719 .776 .897 r
.30062 .45158 m .30419 .44033 L .31074 .44576 L F
.30062 .45158 m .29409 .44549 L .30419 .44033 L F
.698 .812 .935 r
.62788 .42827 m .63312 .4186 L .63842 .42409 L F
.62788 .42827 m .62256 .42313 L .63312 .4186 L F
.883 .839 .798 r
.35238 .4043 m .3459 .40037 L .35649 .38727 L F
.874 .839 .808 r
.34186 .41672 m .3459 .40037 L .35238 .4043 L F
.642 .758 .933 r
.70712 .42489 m .71282 .41571 L .71785 .42185 L F
.70712 .42489 m .70206 .41882 L .71282 .41571 L F
.606 .744 .942 r
.80242 .42988 m .80873 .42155 L .81341 .42762 L F
.80242 .42988 m .7977 .42385 L .80873 .42155 L F
.57 .646 .886 r
.42484 .33811 m .42897 .32791 L .43494 .33747 L F
.42484 .33811 m .41883 .32926 L .42897 .32791 L F
.226 .441 .86 r
.50048 .40744 m .50499 .40297 L .51078 .41162 L F
.50048 .40744 m .49469 .39814 L .50499 .40297 L F
.4 .542 .882 r
.44088 .34694 m .44503 .33953 L .45096 .34943 L F
.44088 .34694 m .43494 .33747 L .44503 .33953 L F
.641 .767 .94 r
.56472 .44101 m .56963 .43211 L .57517 .43725 L F
.56472 .44101 m .55914 .43521 L .56963 .43211 L F
.725 .776 .893 r
.10887 .39775 m .11148 .38631 L .11869 .3925 L F
.10887 .39775 m .10162 .39166 L .11148 .38631 L F
.634 .754 .935 r
.73361 .42495 m .73947 .41595 L .74441 .42209 L F
.73361 .42495 m .72864 .41887 L .73947 .41595 L F
.83 .793 .817 r
.38802 .35011 m .39221 .33359 L .39837 .34064 L F
.38802 .35011 m .38178 .344 L .39221 .33359 L F
.86 .812 .801 r
.37757 .36146 m .38178 .344 L .38802 .35011 L F
.781 .765 .839 r
.39837 .34064 m .40255 .32555 L .40864 .33357 L F
.39837 .34064 m .39221 .33359 L .40255 .32555 L F
.555 .723 .952 r
.87155 .43826 m .87839 .43109 L .88282 .43704 L F
.87155 .43826 m .86709 .43234 L .87839 .43109 L F
.169 .395 .839 r
.47868 .38342 m .48303 .3794 L .48888 .38881 L F
.47868 .38342 m .47284 .37371 L .48303 .3794 L F
.624 .751 .937 r
.76014 .42539 m .76618 .41661 L .77102 .42274 L F
.76014 .42539 m .75527 .41931 L .76618 .41661 L F
.59 .738 .946 r
.82909 .43152 m .8356 .42354 L .84019 .42959 L F
.82909 .43152 m .82447 .4255 L .8356 .42354 L F
.874 .839 .808 r
.34186 .41672 m .33534 .41272 L .3459 .40037 L F
.855 .835 .825 r
.33139 .42807 m .33534 .41272 L .34186 .41672 L F
.714 .835 .939 r
.60155 .43272 m .60665 .42313 L .61204 .42786 L F
.60155 .43272 m .59613 .4281 L .60665 .42313 L F
.78 .805 .873 r
.31074 .44576 m .31444 .43305 L .321 .43786 L F
.31074 .44576 m .30419 .44033 L .31444 .43305 L F
.86 .812 .801 r
.37757 .36146 m .37125 .35618 L .38178 .344 L F
.878 .824 .791 r
.36705 .37407 m .37125 .35618 L .37757 .36146 L F
.652 .749 .921 r
.1453 .38998 m .1479 .38011 L .15493 .38686 L F
.1453 .38998 m .13823 .38347 L .1479 .38011 L F
.707 .722 .862 r
.40864 .33357 m .41279 .32033 L .41883 .32926 L F
.40864 .33357 m .40255 .32555 L .41279 .32033 L F
.359 .594 .935 r
.20382 .40623 m .20637 .4002 L .21312 .40777 L F
.20382 .40623 m .19705 .39879 L .20637 .4002 L F
.729 .776 .891 r
.08195 .40261 m .08443 .39107 L .09177 .39716 L F
.08195 .40261 m .07459 .39653 L .08443 .39107 L F
.244 .441 .855 r
.45686 .35924 m .46107 .35403 L .46697 .36392 L F
.45686 .35924 m .45096 .34943 L .46107 .35403 L F
.855 .835 .825 r
.33139 .42807 m .32484 .42375 L .33534 .41272 L F
.825 .824 .848 r
.321 .43786 m .32484 .42375 L .33139 .42807 L F
.613 .746 .94 r
.78674 .42626 m .79295 .41772 L .7977 .42385 L F
.78674 .42626 m .78196 .42018 L .79295 .41772 L F
.44 .643 .943 r
.18771 .39824 m .19023 .39136 L .19705 .39879 L F
.18771 .39824 m .18086 .39102 L .19023 .39136 L F
.662 .76 .923 r
.66486 .42259 m .6703 .41278 L .67551 .41916 L F
.66486 .42259 m .65963 .41637 L .6703 .41278 L F
.316 .515 .892 r
.51653 .42023 m .52116 .4149 L .52691 .42264 L F
.51653 .42023 m .51078 .41162 L .52116 .4149 L F
.825 .824 .848 r
.321 .43786 m .31444 .43305 L .32484 .42375 L F
.616 .727 .925 r
.28417 .44859 m .28751 .43934 L .29409 .44549 L F
.28417 .44859 m .27762 .44184 L .28751 .43934 L F
.713 .772 .898 r
.11869 .3925 m .12131 .38132 L .12848 .38767 L F
.11869 .3925 m .11148 .38631 L .12131 .38132 L F
.689 .796 .931 r
.63842 .42409 m .64372 .41429 L .649 .42013 L F
.63842 .42409 m .63312 .4186 L .64372 .41429 L F
.311 .563 .927 r
.21983 .41536 m .22245 .40981 L .22914 .4174 L F
.21983 .41536 m .21312 .40777 L .22245 .40981 L F
.552 .7 .938 r
.5487 .43724 m .55352 .42937 L .55914 .43521 L F
.5487 .43724 m .54304 .43052 L .55352 .42937 L F
.648 .757 .929 r
.69134 .42201 m .69695 .41256 L .70206 .41882 L F
.69134 .42201 m .68621 .41582 L .69695 .41256 L F
.569 .729 .95 r
.85588 .43384 m .8626 .42632 L .86709 .43234 L F
.85588 .43384 m .85135 .42785 L .8626 .42632 L F
.639 .755 .932 r
.71785 .42185 m .72363 .41266 L .72864 .41887 L F
.71785 .42185 m .71282 .41571 L .72363 .41266 L F
.675 .804 .944 r
.57517 .43725 m .58014 .42815 L .58564 .43287 L F
.57517 .43725 m .56963 .43211 L .58014 .42815 L F
.318 .564 .926 r
.23579 .42502 m .23853 .41942 L .24519 .42691 L F
.23579 .42502 m .22914 .4174 L .23853 .41942 L F
.878 .824 .791 r
.36705 .37407 m .36066 .36944 L .37125 .35618 L F
.885 .832 .79 r
.35649 .38727 m .36066 .36944 L .36705 .37407 L F
.528 .691 .942 r
.17142 .39175 m .17396 .38378 L .18086 .39102 L F
.17142 .39175 m .16448 .38477 L .17396 .38378 L F
.436 .61 .922 r
.53262 .43034 m .53735 .42376 L .54304 .43052 L F
.53262 .43034 m .52691 .42264 L .53735 .42376 L F
.6 .74 .943 r
.81341 .42762 m .81981 .41939 L .82447 .4255 L F
.81341 .42762 m .80873 .42155 L .81981 .41939 L F
.495 .664 .937 r
.26791 .44259 m .27102 .43508 L .27762 .44184 L F
.26791 .44259 m .26133 .43537 L .27102 .43508 L F
.385 .603 .934 r
.2518 .43442 m .2547 .42817 L .26133 .43537 L F
.2518 .43442 m .24519 .42691 L .2547 .42817 L F
.715 .832 .937 r
.61204 .42786 m .6172 .41814 L .62256 .42313 L F
.61204 .42786 m .60665 .42313 L .6172 .41814 L F
.63 .752 .935 r
.74441 .42209 m .75035 .41312 L .75527 .41931 L F
.74441 .42209 m .73947 .41595 L .75035 .41312 L F
.731 .777 .89 r
.09177 .39716 m .09432 .38552 L .10162 .39166 L F
.09177 .39716 m .08443 .39107 L .09432 .38552 L F
.177 .41 .849 r
.49469 .39814 m .49917 .39425 L .50499 .40297 L F
.49469 .39814 m .48888 .38881 L .49917 .39425 L F
.427 .555 .882 r
.43494 .33747 m .43907 .3295 L .44503 .33953 L F
.43494 .33747 m .42897 .32791 L .43907 .3295 L F
.6 .658 .879 r
.41883 .32926 m .42296 .31823 L .42897 .32791 L F
.41883 .32926 m .41279 .32033 L .42296 .31823 L F
.62 .748 .938 r
.77102 .42274 m .77714 .414 L .78196 .42018 L F
.77102 .42274 m .76618 .41661 L .77714 .414 L F
.693 .764 .906 r
.12848 .38767 m .1311 .37691 L .13823 .38347 L F
.12848 .38767 m .12131 .38132 L .1311 .37691 L F
.604 .727 .932 r
.15493 .38686 m .1575 .37776 L .16448 .38477 L F
.15493 .38686 m .1479 .38011 L .1575 .37776 L F
.885 .832 .79 r
.35649 .38727 m .35002 .38305 L .36066 .36944 L F
.883 .836 .796 r
.3459 .40037 m .35002 .38305 L .35649 .38727 L F
.581 .733 .947 r
.84019 .42959 m .84679 .42177 L .85135 .42785 L F
.84019 .42959 m .8356 .42354 L .84679 .42177 L F
.68 .781 .927 r
.649 .42013 m .65437 .41022 L .65963 .41637 L F
.649 .42013 m .64372 .41429 L .65437 .41022 L F
.655 .753 .922 r
.67551 .41916 m .68102 .40934 L .68621 .41582 L F
.67551 .41916 m .6703 .41278 L .68102 .40934 L F
.147 .38 .832 r
.47284 .37371 m .47715 .36988 L .48303 .3794 L F
.47284 .37371 m .46697 .36392 L .47715 .36988 L F
.698 .771 .908 r
.29409 .44549 m .29759 .43481 L .30419 .44033 L F
.29409 .44549 m .28751 .43934 L .29759 .43481 L F
.7 .828 .944 r
.58564 .43287 m .59067 .42354 L .59613 .4281 L F
.58564 .43287 m .58014 .42815 L .59067 .42354 L F
.644 .754 .928 r
.70206 .41882 m .70774 .40939 L .71282 .41571 L F
.70206 .41882 m .69695 .41256 L .70774 .40939 L F
.608 .743 .941 r
.7977 .42385 m .804 .41538 L .80873 .42155 L F
.7977 .42385 m .79295 .41772 L .804 .41538 L F
.711 .822 .934 r
.62256 .42313 m .62779 .41326 L .63312 .4186 L F
.62256 .42313 m .6172 .41814 L .62779 .41326 L F
.728 .776 .891 r
.10162 .39166 m .10421 .38006 L .11148 .38631 L F
.10162 .39166 m .09432 .38552 L .10421 .38006 L F
.798 .767 .825 r
.39221 .33359 m .39642 .31746 L .40255 .32555 L F
.39221 .33359 m .38601 .32649 L .39642 .31746 L F
.842 .793 .804 r
.38178 .344 m .38601 .32649 L .39221 .33359 L F
.607 .755 .949 r
.55914 .43521 m .56404 .42696 L .56963 .43211 L F
.55914 .43521 m .55352 .42937 L .56404 .42696 L F
.636 .752 .932 r
.72864 .41887 m .73449 .40969 L .73947 .41595 L F
.72864 .41887 m .72363 .41266 L .73449 .40969 L F
.252 .444 .856 r
.45096 .34943 m .45514 .34401 L .46107 .35403 L F
.45096 .34943 m .44503 .33953 L .45514 .34401 L F
.842 .793 .804 r
.38178 .344 m .3755 .33784 L .38601 .32649 L F
.868 .81 .79 r
.37125 .35618 m .3755 .33784 L .38178 .344 L F
.883 .836 .796 r
.3459 .40037 m .33937 .39631 L .35002 .38305 L F
.871 .837 .809 r
.33534 .41272 m .33937 .39631 L .3459 .40037 L F
.73 .729 .849 r
.40255 .32555 m .40672 .31131 L .41279 .32033 L F
.40255 .32555 m .39642 .31746 L .40672 .31131 L F
.252 .477 .881 r
.51078 .41162 m .51538 .40709 L .52116 .4149 L F
.51078 .41162 m .50499 .40297 L .51538 .40709 L F
.556 .722 .951 r
.86709 .43234 m .87393 .42504 L .87839 .43109 L F
.86709 .43234 m .8626 .42632 L .87393 .42504 L F
.626 .749 .935 r
.75527 .41931 m .76129 .41036 L .76618 .41661 L F
.75527 .41931 m .75035 .41312 L .76129 .41036 L F
.592 .736 .944 r
.82447 .4255 m .83097 .4174 L .8356 .42354 L F
.82447 .4255 m .81981 .41939 L .83097 .4174 L F
.367 .6 .937 r
.19705 .39879 m .19957 .39264 L .20637 .4002 L F
.19705 .39879 m .19023 .39136 L .19957 .39264 L F
.661 .751 .917 r
.13823 .38347 m .14082 .37332 L .1479 .38011 L F
.13823 .38347 m .1311 .37691 L .14082 .37332 L F
.453 .65 .944 r
.18086 .39102 m .18336 .38391 L .19023 .39136 L F
.18086 .39102 m .17396 .38378 L .18336 .38391 L F
.308 .564 .928 r
.21312 .40777 m .2157 .40221 L .22245 .40981 L F
.21312 .40777 m .20637 .4002 L .2157 .40221 L F
.765 .802 .883 r
.30419 .44033 m .30784 .42811 L .31444 .43305 L F
.30419 .44033 m .29759 .43481 L .30784 .42811 L F
.587 .718 .934 r
.27762 .44184 m .28089 .43313 L .28751 .43934 L F
.27762 .44184 m .27102 .43508 L .28089 .43313 L F
.868 .81 .79 r
.37125 .35618 m .36489 .35085 L .3755 .33784 L F
.882 .821 .783 r
.36066 .36944 m .36489 .35085 L .37125 .35618 L F
.715 .839 .941 r
.59613 .4281 m .60122 .41852 L .60665 .42313 L F
.59613 .4281 m .59067 .42354 L .60122 .41852 L F
.728 .775 .891 r
.07459 .39653 m .07705 .38491 L .08443 .39107 L F
.07459 .39653 m .06718 .39038 L .07705 .38491 L F
.501 .676 .943 r
.54304 .43052 m .54786 .42348 L .55352 .42937 L F
.54304 .43052 m .53735 .42376 L .54786 .42348 L F
.67 .768 .923 r
.65963 .41637 m .66506 .40638 L .6703 .41278 L F
.65963 .41637 m .65437 .41022 L .66506 .40638 L F
.615 .745 .938 r
.78196 .42018 m .78816 .41149 L .79295 .41772 L F
.78196 .42018 m .77714 .414 L .78816 .41149 L F
.871 .837 .809 r
.33534 .41272 m .32877 .40857 L .33937 .39631 L F
.85 .833 .83 r
.32484 .42375 m .32877 .40857 L .33534 .41272 L F
.302 .558 .925 r
.22914 .4174 m .23182 .41194 L .23853 .41942 L F
.22914 .4174 m .22245 .40981 L .23182 .41194 L F
.717 .772 .896 r
.11148 .38631 m .11409 .37491 L .12131 .38132 L F
.11148 .38631 m .10421 .38006 L .11409 .37491 L F
.372 .576 .919 r
.52691 .42264 m .53162 .41695 L .53735 .42376 L F
.52691 .42264 m .52116 .4149 L .53162 .41695 L F
.65 .749 .922 r
.68621 .41582 m .69179 .40603 L .69695 .41256 L F
.68621 .41582 m .68102 .40934 L .69179 .40603 L F
.703 .807 .93 r
.63312 .4186 m .63841 .40856 L .64372 .41429 L F
.63312 .4186 m .62779 .41326 L .63841 .40856 L F
.542 .697 .94 r
.16448 .38477 m .16701 .37653 L .17396 .38378 L F
.16448 .38477 m .1575 .37776 L .16701 .37653 L F
.129 .378 .835 r
.48888 .38881 m .49332 .38544 L .49917 .39425 L F
.48888 .38881 m .48303 .3794 L .49332 .38544 L F
.455 .568 .88 r
.42897 .32791 m .43309 .31933 L .43907 .3295 L F
.42897 .32791 m .42296 .31823 L .43309 .31933 L F
.358 .591 .933 r
.24519 .42691 m .24803 .42095 L .2547 .42817 L F
.24519 .42691 m .23853 .41942 L .24803 .42095 L F
.463 .652 .941 r
.26133 .43537 m .26437 .4283 L .27102 .43508 L F
.26133 .43537 m .2547 .42817 L .26437 .4283 L F
.815 .822 .856 r
.31444 .43305 m .31824 .4193 L .32484 .42375 L F
.31444 .43305 m .30784 .42811 L .31824 .4193 L F
.641 .751 .929 r
.71282 .41571 m .71858 .40629 L .72363 .41266 L F
.71282 .41571 m .70774 .40939 L .71858 .40629 L F
.571 .727 .948 r
.85135 .42785 m .85806 .42021 L .8626 .42632 L F
.85135 .42785 m .84679 .42177 L .85806 .42021 L F
.85 .833 .83 r
.32484 .42375 m .31824 .4193 L .32877 .40857 L F
.628 .669 .87 r
.41279 .32033 m .41693 .30843 L .42296 .31823 L F
.41279 .32033 m .40672 .31131 L .41693 .30843 L F
.601 .739 .941 r
.80873 .42155 m .81512 .41319 L .81981 .41939 L F
.80873 .42155 m .804 .41538 L .81512 .41319 L F
.653 .798 .952 r
.56963 .43211 m .57459 .42346 L .58014 .42815 L F
.56963 .43211 m .56404 .42696 L .57459 .42346 L F
.128 .366 .825 r
.46697 .36392 m .47125 .36024 L .47715 .36988 L F
.46697 .36392 m .46107 .35403 L .47125 .36024 L F
.632 .749 .932 r
.73947 .41595 m .7454 .4068 L .75035 .41312 L F
.73947 .41595 m .73449 .40969 L .7454 .4068 L F
.882 .821 .783 r
.36066 .36944 m .35421 .36474 L .36489 .35085 L F
.887 .83 .785 r
.35002 .38305 m .35421 .36474 L .36066 .36944 L F
.731 .776 .889 r
.08443 .39107 m .08696 .37931 L .09432 .38552 L F
.08443 .39107 m .07705 .38491 L .08696 .37931 L F
.722 .84 .937 r
.60665 .42313 m .61181 .4133 L .6172 .41814 L F
.60665 .42313 m .60122 .41852 L .61181 .4133 L F
.263 .449 .856 r
.44503 .33953 m .44919 .33383 L .45514 .34401 L F
.44503 .33953 m .43907 .3295 L .44919 .33383 L F
.621 .746 .936 r
.76618 .41661 m .77228 .40771 L .77714 .414 L F
.76618 .41661 m .76129 .41036 L .77228 .40771 L F
.615 .731 .928 r
.1479 .38011 m .15046 .37072 L .1575 .37776 L F
.1479 .38011 m .14082 .37332 L .15046 .37072 L F
.698 .765 .903 r
.12131 .38132 m .12392 .37031 L .1311 .37691 L F
.12131 .38132 m .11409 .37491 L .12392 .37031 L F
.583 .731 .945 r
.8356 .42354 m .84219 .41559 L .84679 .42177 L F
.8356 .42354 m .83097 .4174 L .84219 .41559 L F
.662 .757 .92 r
.6703 .41278 m .6758 .40276 L .68102 .40934 L F
.6703 .41278 m .66506 .40638 L .6758 .40276 L F
.693 .791 .926 r
.64372 .41429 m .64907 .40412 L .65437 .41022 L F
.64372 .41429 m .63841 .40856 L .64907 .40412 L F
.675 .765 .918 r
.28751 .43934 m .29095 .4292 L .29759 .43481 L F
.28751 .43934 m .28089 .43313 L .29095 .4292 L F
.645 .746 .922 r
.69695 .41256 m .70261 .40282 L .70774 .40939 L F
.69695 .41256 m .69179 .40603 L .70261 .40282 L F
.187 .436 .866 r
.50499 .40297 m .50956 .3992 L .51538 .40709 L F
.50499 .40297 m .49917 .39425 L .50956 .3992 L F
.609 .741 .939 r
.79295 .41772 m .79924 .40911 L .804 .41538 L F
.79295 .41772 m .78816 .41149 L .79924 .40911 L F
.813 .769 .812 r
.38601 .32649 m .39025 .30929 L .39642 .31746 L F
.38601 .32649 m .37976 .31933 L .39025 .30929 L F
.852 .792 .792 r
.3755 .33784 m .37976 .31933 L .38601 .32649 L F
.887 .83 .785 r
.35002 .38305 m .3435 .37875 L .35421 .36474 L F
.883 .834 .794 r
.33937 .39631 m .3435 .37875 L .35002 .38305 L F
.751 .734 .836 r
.39642 .31746 m .40061 .30218 L .40672 .31131 L F
.39642 .31746 m .39025 .30929 L .40061 .30218 L F
.73 .775 .889 r
.09432 .38552 m .09689 .37375 L .10421 .38006 L F
.09432 .38552 m .08696 .37931 L .09689 .37375 L F
.637 .748 .929 r
.72363 .41266 m .72946 .40327 L .73449 .40969 L F
.72363 .41266 m .71858 .40629 L .72946 .40327 L F
.689 .828 .95 r
.58014 .42815 m .58516 .41908 L .59067 .42354 L F
.58014 .42815 m .57459 .42346 L .58516 .41908 L F
.567 .739 .957 r
.55352 .42937 m .55841 .42181 L .56404 .42696 L F
.55352 .42937 m .54786 .42348 L .55841 .42181 L F
.723 .832 .933 r
.6172 .41814 m .62241 .40806 L .62779 .41326 L F
.6172 .41814 m .61181 .4133 L .62241 .40806 L F
.375 .606 .939 r
.19023 .39136 m .19272 .38506 L .19957 .39264 L F
.19023 .39136 m .18336 .38391 L .19272 .38506 L F
.852 .792 .792 r
.3755 .33784 m .36916 .33165 L .37976 .31933 L F
.875 .808 .78 r
.36489 .35085 m .36916 .33165 L .3755 .33784 L F
.307 .565 .929 r
.20637 .4002 m .2089 .39462 L .2157 .40221 L F
.20637 .4002 m .19957 .39264 L .2089 .39462 L F
.543 .335 .548 r
.52209 .57254 m .5301 .56818 L .52958 .57424 L F
.558 .721 .949 r
.8626 .42632 m .86942 .4189 L .87393 .42504 L F
.8626 .42632 m .85806 .42021 L .86942 .4189 L F
.627 .746 .933 r
.75035 .41312 m .75636 .404 L .76129 .41036 L F
.75035 .41312 m .7454 .4068 L .75636 .404 L F
.466 .657 .944 r
.17396 .38378 m .17644 .37645 L .18336 .38391 L F
.17396 .38378 m .16701 .37653 L .17644 .37645 L F
.482 .581 .877 r
.42296 .31823 m .42708 .30899 L .43309 .31933 L F
.42296 .31823 m .41693 .30843 L .42708 .30899 L F
.083 .346 .819 r
.48303 .3794 m .48743 .37651 L .49332 .38544 L F
.48303 .3794 m .47715 .36988 L .48743 .37651 L F
.593 .735 .942 r
.81981 .41939 m .8263 .41115 L .83097 .4174 L F
.81981 .41939 m .81512 .41319 L .8263 .41115 L F
.669 .753 .913 r
.1311 .37691 m .13369 .36649 L .14082 .37332 L F
.1311 .37691 m .12392 .37031 L .13369 .36649 L F
.302 .536 .911 r
.52116 .4149 m .52585 .41008 L .53162 .41695 L F
.52116 .4149 m .51538 .40709 L .52585 .41008 L F
.288 .552 .925 r
.22245 .40981 m .22507 .40446 L .23182 .41194 L F
.22245 .40981 m .2157 .40221 L .22507 .40446 L F
.557 .707 .941 r
.27102 .43508 m .27421 .42688 L .28089 .43313 L F
.27102 .43508 m .26437 .4283 L .27421 .42688 L F
.112 .353 .819 r
.46107 .35403 m .46531 .35044 L .47125 .36024 L F
.46107 .35403 m .45514 .34401 L .46531 .35044 L F
.442 .647 .945 r
.53735 .42376 m .54216 .41757 L .54786 .42348 L F
.53735 .42376 m .53162 .41695 L .54216 .41757 L F
.655 .678 .86 r
.40672 .31131 m .41087 .29848 L .41693 .30843 L F
.40672 .31131 m .40061 .30218 L .41087 .29848 L F
.883 .834 .794 r
.33937 .39631 m .33279 .39216 L .3435 .37875 L F
.869 .836 .811 r
.32877 .40857 m .33279 .39216 L .33937 .39631 L F
.749 .799 .893 r
.29759 .43481 m .30119 .42307 L .30784 .42811 L F
.29759 .43481 m .29095 .4292 L .30119 .42307 L F
.727 .775 .891 r
.06718 .39038 m .06961 .37869 L .07705 .38491 L F
.06718 .39038 m .05972 .38417 L .06961 .37869 L F
.682 .775 .921 r
.65437 .41022 m .65978 .39995 L .66506 .40638 L F
.65437 .41022 m .64907 .40412 L .65978 .39995 L F
.616 .743 .936 r
.77714 .414 m .78333 .40516 L .78816 .41149 L F
.77714 .414 m .77228 .40771 L .78333 .40516 L F
.331 .579 .932 r
.23853 .41942 m .24131 .41373 L .24803 .42095 L F
.23853 .41942 m .23182 .41194 L .24131 .41373 L F
.654 .748 .919 r
.68102 .40934 m .68659 .39932 L .69179 .40603 L F
.68102 .40934 m .6758 .40276 L .68659 .39932 L F
.721 .772 .893 r
.10421 .38006 m .10681 .36846 L .11409 .37491 L F
.10421 .38006 m .09689 .37375 L .10681 .36846 L F
.43 .638 .943 r
.2547 .42817 m .25767 .4215 L .26437 .4283 L F
.2547 .42817 m .24803 .42095 L .25767 .4215 L F
.555 .702 .938 r
.1575 .37776 m .16001 .36925 L .16701 .37653 L F
.1575 .37776 m .15046 .37072 L .16001 .36925 L F
.875 .808 .78 r
.36489 .35085 m .35847 .34547 L .36916 .33165 L F
.887 .819 .776 r
.35421 .36474 m .35847 .34547 L .36489 .35085 L F
.277 .455 .856 r
.43907 .3295 m .44321 .32348 L .44919 .33383 L F
.43907 .3295 m .43309 .31933 L .44321 .32348 L F
.714 .844 .944 r
.59067 .42354 m .59576 .41405 L .60122 .41852 L F
.59067 .42354 m .58516 .41908 L .59576 .41405 L F
.641 .744 .923 r
.70774 .40939 m .71348 .3997 L .71857 .40629 L F
.70774 .40939 m .70261 .40282 L .71348 .3997 L F
.572 .726 .946 r
.84679 .42177 m .85349 .41399 L .85806 .42021 L F
.84679 .42177 m .84219 .41559 L .85349 .41399 L F
.717 .818 .928 r
.62779 .41326 m .63306 .40295 L .63841 .40856 L F
.62779 .41326 m .62241 .40806 L .63306 .40295 L F
.869 .836 .811 r
.32877 .40857 m .32215 .40432 L .33279 .39216 L F
.844 .832 .835 r
.31824 .4193 m .32215 .40432 L .32877 .40857 L F
.602 .737 .94 r
.804 .41538 m .81038 .40688 L .81512 .41319 L F
.804 .41538 m .79924 .40911 L .81038 .40688 L F
.805 .821 .863 r
.30784 .42811 m .3116 .41473 L .31824 .4193 L F
.30784 .42811 m .30119 .42307 L .3116 .41473 L F
.633 .746 .93 r
.73449 .40969 m .7404 .40034 L .7454 .4068 L F
.73449 .40969 m .72946 .40327 L .7404 .40034 L F
.844 .832 .835 r
.31824 .4193 m .3116 .41473 L .32215 .40432 L F
.626 .791 .961 r
.56404 .42696 m .569 .41883 L .57459 .42346 L F
.56404 .42696 m .55841 .42181 L .569 .41883 L F
.732 .776 .888 r
.07705 .38491 m .07956 .37304 L .08696 .37931 L F
.07705 .38491 m .06961 .37869 L .07956 .37304 L F
.626 .735 .925 r
.14082 .37332 m .14337 .36364 L .15046 .37072 L F
.14082 .37332 m .13369 .36649 L .14337 .36364 L F
.119 .391 .846 r
.49917 .39425 m .5037 .39122 L .50956 .3992 L F
.49917 .39425 m .49332 .38544 L .5037 .39122 L F
.623 .744 .933 r
.76129 .41036 m .76738 .4013 L .77228 .40771 L F
.76129 .41036 m .75636 .404 L .76738 .4013 L F
.704 .766 .9 r
.11409 .37491 m .11669 .36367 L .12392 .37031 L F
.11409 .37491 m .10681 .36846 L .11669 .36367 L F
.887 .819 .776 r
.35421 .36474 m .34771 .35999 L .35847 .34547 L F
.889 .827 .78 r
.3435 .37875 m .34771 .35999 L .35421 .36474 L F
.671 .76 .918 r
.66506 .40638 m .67054 .39606 L .6758 .40276 L F
.66506 .40638 m .65978 .39995 L .67054 .39606 L F
.584 .73 .944 r
.83097 .4174 m .83755 .4093 L .84219 .41559 L F
.83097 .4174 m .8263 .41115 L .83755 .4093 L F
.729 .848 .937 r
.60122 .41852 m .60637 .40862 L .61181 .4133 L F
.60122 .41852 m .59576 .41405 L .60637 .40862 L F
.77 .737 .823 r
.39025 .30929 m .39448 .29293 L .40061 .30218 L F
.39025 .30929 m .38404 .30104 L .39448 .29293 L F
.826 .769 .798 r
.37976 .31933 m .38404 .30104 L .39025 .30929 L F
.51 .593 .873 r
.41693 .30843 m .42104 .29846 L .42708 .30899 L F
.41693 .30843 m .41087 .29848 L .42104 .29846 L F
.651 .758 .928 r
.28089 .43313 m .28425 .42351 L .29095 .4292 L F
.28089 .43313 m .27421 .42688 L .28425 .42351 L F
.647 .742 .918 r
.69179 .40603 m .69744 .39604 L .70261 .40282 L F
.69179 .40603 m .68659 .39932 L .69744 .39604 L F
.826 .769 .798 r
.37976 .31933 m .37348 .31212 L .38404 .30104 L F
.861 .791 .781 r
.36916 .33165 m .37348 .31212 L .37976 .31933 L F
.038 .314 .801 r
.47715 .36988 m .48151 .36744 L .48743 .37651 L F
.47715 .36988 m .47125 .36024 L .48151 .36744 L F
.708 .801 .923 r
.63841 .40856 m .64374 .39807 L .64907 .40412 L F
.63841 .40856 m .63306 .40295 L .64374 .39807 L F
.61 .739 .937 r
.78816 .41149 m .79443 .40274 L .79924 .40911 L F
.78816 .41149 m .78333 .40516 L .79443 .40274 L F
.098 .341 .812 r
.45514 .34401 m .45934 .34047 L .46531 .35044 L F
.45514 .34401 m .44919 .33383 L .45934 .34047 L F
.384 .612 .94 r
.18336 .38391 m .18582 .37747 L .19272 .38506 L F
.18336 .38391 m .17644 .37645 L .18582 .37747 L F
.637 .742 .925 r
.71857 .40629 m .72439 .39668 L .72946 .40327 L F
.71857 .40629 m .71348 .3997 L .72439 .39668 L F
.307 .566 .929 r
.19957 .39264 m .20206 .38701 L .2089 .39462 L F
.19957 .39264 m .19272 .38506 L .20206 .38701 L F
.731 .775 .888 r
.08696 .37931 m .08952 .36738 L .09689 .37375 L F
.08696 .37931 m .07956 .37304 L .08952 .36738 L F
.519 .719 .964 r
.54786 .42348 m .55274 .41668 L .55841 .42181 L F
.54786 .42348 m .54216 .41757 L .55274 .41668 L F
.679 .686 .85 r
.40061 .30218 m .40478 .28836 L .41087 .29848 L F
.40061 .30218 m .39448 .29293 L .40478 .28836 L F
.479 .664 .943 r
.16701 .37653 m .16948 .36897 L .17644 .37645 L F
.16701 .37653 m .16001 .36925 L .16948 .36897 L F
.226 .489 .896 r
.51538 .40709 m .52004 .40315 L .52585 .41008 L F
.51538 .40709 m .50956 .3992 L .52004 .40315 L F
.293 .461 .856 r
.43309 .31933 m .4372 .31293 L .44321 .32348 L F
.43309 .31933 m .42708 .30899 L .4372 .31293 L F
.274 .546 .923 r
.2157 .40221 m .21827 .39696 L .22507 .40446 L F
.2157 .40221 m .2089 .39462 L .21827 .39696 L F
.861 .791 .781 r
.36916 .33165 m .36279 .32541 L .37348 .31212 L F
.881 .806 .771 r
.35847 .34547 m .36279 .32541 L .36916 .33165 L F
.628 .744 .93 r
.7454 .4068 m .75139 .39751 L .75636 .404 L F
.7454 .4068 m .7404 .40034 L .75139 .39751 L F
.675 .828 .957 r
.57459 .42346 m .57961 .41474 L .58516 .41908 L F
.57459 .42346 m .569 .41883 L .57961 .41474 L F
.889 .827 .78 r
.3435 .37875 m .33692 .37438 L .34771 .35999 L F
.883 .833 .793 r
.33279 .39216 m .33692 .37438 L .3435 .37875 L F
.559 .719 .948 r
.85806 .42021 m .86488 .41265 L .86942 .4189 L F
.85806 .42021 m .85349 .41399 L .86488 .41265 L F
.677 .755 .91 r
.12392 .37031 m .1265 .35962 L .13369 .36649 L F
.12392 .37031 m .11669 .36367 L .1265 .35962 L F
.595 .733 .941 r
.81512 .41319 m .82159 .4048 L .8263 .41115 L F
.81512 .41319 m .81038 .40688 L .82159 .4048 L F
.525 .695 .947 r
.26437 .4283 m .26749 .42057 L .27421 .42688 L F
.26437 .4283 m .25767 .4215 L .26749 .42057 L F
.735 .843 .931 r
.61181 .4133 m .61701 .40302 L .62241 .40806 L F
.61181 .4133 m .60637 .40862 L .61701 .40302 L F
.374 .611 .942 r
.53162 .41695 m .53641 .41164 L .54216 .41757 L F
.53162 .41695 m .52585 .41008 L .53641 .41164 L F
.305 .566 .93 r
.23182 .41194 m .23454 .40648 L .24131 .41373 L F
.23182 .41194 m .22507 .40446 L .23454 .40648 L F
.397 .623 .943 r
.24803 .42095 m .25093 .41465 L .25767 .4215 L F
.24803 .42095 m .24131 .41373 L .25093 .41465 L F
.567 .707 .936 r
.15046 .37072 m .15296 .36194 L .16001 .36925 L F
.15046 .37072 m .14337 .36364 L .15296 .36194 L F
.66 .748 .915 r
.6758 .40276 m .68135 .39244 L .68659 .39932 L F
.6758 .40276 m .67054 .39606 L .68135 .39244 L F
.617 .741 .934 r
.77228 .40771 m .77845 .39871 L .78333 .40516 L F
.77228 .40771 m .76738 .4013 L .77845 .39871 L F
.727 .774 .891 r
.05972 .38417 m .06212 .37241 L .06961 .37869 L F
.05972 .38417 m .0522 .3779 L .06212 .37241 L F
.696 .783 .918 r
.64907 .40412 m .65446 .3935 L .65978 .39995 L F
.64907 .40412 m .64374 .39807 L .65446 .3935 L F
.732 .796 .903 r
.29095 .4292 m .29449 .41794 L .30119 .42307 L F
.29095 .4292 m .28425 .42351 L .29449 .41794 L F
.724 .772 .891 r
.09689 .37375 m .09948 .36195 L .10681 .36846 L F
.09689 .37375 m .08952 .36738 L .09948 .36195 L F
.641 .738 .919 r
.70261 .40282 m .70833 .3929 L .71348 .3997 L F
.70261 .40282 m .69744 .39604 L .70833 .3929 L F
.573 .724 .945 r
.84219 .41559 m .84888 .40767 L .85349 .41399 L F
.84219 .41559 m .83755 .4093 L .84888 .40767 L F
.883 .833 .793 r
.33279 .39216 m .32616 .38792 L .33692 .37438 L F
.867 .835 .813 r
.32215 .40432 m .32616 .38792 L .33279 .39216 L F
.881 .806 .771 r
.35847 .34547 m .352 .34006 L .36279 .32541 L F
.891 .817 .769 r
.34771 .35999 m .352 .34006 L .35847 .34547 L F
.05 .343 .821 r
.49332 .38544 m .49781 .38313 L .5037 .39122 L F
.49332 .38544 m .48743 .37651 L .49781 .38313 L F
.604 .736 .938 r
.79924 .40911 m .8056 .40046 L .81038 .40688 L F
.79924 .40911 m .79443 .40274 L .8056 .40046 L F
.633 .741 .926 r
.72946 .40327 m .73536 .39374 L .7404 .40034 L F
.72946 .40327 m .72439 .39668 L .73536 .39374 L F
.733 .83 .925 r
.62241 .40806 m .62767 .39745 L .63306 .40295 L F
.62241 .40806 m .61701 .40302 L .62767 .39745 L F
.538 .603 .867 r
.41087 .29848 m .41498 .28773 L .42104 .29846 L F
.41087 .29848 m .40478 .28836 L .41498 .28773 L F
.711 .85 .948 r
.58516 .41908 m .59025 .40975 L .59576 .41405 L F
.58516 .41908 m .57961 .41474 L .59025 .40975 L F
0 .281 .782 r
.47125 .36024 m .47556 .35821 L .48151 .36744 L F
.47125 .36024 m .46531 .35044 L .47556 .35821 L F
.087 .33 .806 r
.44919 .33383 m .45335 .33031 L .45934 .34047 L F
.44919 .33383 m .44321 .32348 L .45335 .33031 L F
.795 .82 .872 r
.30119 .42307 m .3049 .41006 L .3116 .41473 L F
.30119 .42307 m .29449 .41794 L .3049 .41006 L F
.636 .738 .922 r
.13369 .36649 m .13623 .35653 L .14337 .36364 L F
.13369 .36649 m .1265 .35962 L .13623 .35653 L F
.732 .776 .887 r
.06961 .37869 m .0721 .36671 L .07956 .37304 L F
.06961 .37869 m .06212 .37241 L .0721 .36671 L F
.867 .835 .813 r
.32215 .40432 m .31547 .39996 L .32616 .38792 L F
.838 .831 .84 r
.3116 .41473 m .31547 .39996 L .32215 .40432 L F
.787 .74 .81 r
.38404 .30104 m .38831 .28354 L .39448 .29293 L F
.38404 .30104 m .3778 .2927 L .38831 .28354 L F
.838 .769 .786 r
.37348 .31212 m .3778 .2927 L .38404 .30104 L F
.592 .781 .97 r
.55841 .42181 m .56337 .41429 L .569 .41883 L F
.55841 .42181 m .55274 .41668 L .56337 .41429 L F
.624 .741 .931 r
.75636 .404 m .76244 .39478 L .76738 .4013 L F
.75636 .404 m .75139 .39751 L .76244 .39478 L F
.709 .766 .897 r
.10681 .36846 m .10941 .35697 L .11669 .36367 L F
.10681 .36846 m .09948 .36195 L .10941 .35697 L F
.838 .831 .84 r
.3116 .41473 m .3049 .41006 L .31547 .39996 L F
.311 .468 .855 r
.42708 .30899 m .43117 .30216 L .4372 .31293 L F
.42708 .30899 m .42104 .29846 L .43117 .30216 L F
.682 .765 .914 r
.65978 .39995 m .66524 .38927 L .67054 .39606 L F
.65978 .39995 m .65446 .3935 L .66524 .38927 L F
.585 .728 .942 r
.8263 .41115 m .83287 .40292 L .83755 .4093 L F
.8263 .41115 m .82159 .4048 L .83287 .40292 L F
.838 .769 .786 r
.37348 .31212 m .36714 .30485 L .3778 .2927 L F
.869 .789 .769 r
.36279 .32541 m .36714 .30485 L .37348 .31212 L F
.702 .693 .838 r
.39448 .29293 m .39867 .27807 L .40478 .28836 L F
.39448 .29293 m .38831 .28354 L .39867 .27807 L F
.651 .739 .914 r
.68659 .39932 m .69222 .38905 L .69744 .39604 L F
.68659 .39932 m .68135 .39244 L .69222 .38905 L F
.625 .75 .937 r
.27421 .42688 m .27751 .41775 L .28425 .42351 L F
.27421 .42688 m .26749 .42057 L .27751 .41775 L F
.393 .617 .941 r
.17644 .37645 m .17887 .36985 L .18582 .37747 L F
.17644 .37645 m .16948 .36897 L .17887 .36985 L F
.307 .567 .93 r
.19272 .38506 m .19517 .37938 L .20206 .38701 L F
.19272 .38506 m .18582 .37747 L .19517 .37938 L F
.891 .817 .769 r
.34771 .35999 m .34115 .3552 L .352 .34006 L F
.891 .826 .776 r
.33692 .37438 m .34115 .3552 L .34771 .35999 L F
.611 .737 .935 r
.78333 .40516 m .78959 .39625 L .79443 .40274 L F
.78333 .40516 m .77845 .39871 L .78959 .39625 L F
.725 .812 .919 r
.63306 .40295 m .63837 .39208 L .64374 .39807 L F
.63306 .40295 m .62767 .39745 L .63837 .39208 L F
.144 .436 .873 r
.50956 .3992 m .51419 .39615 L .52004 .40315 L F
.50956 .3992 m .5037 .39122 L .51419 .39615 L F
.636 .736 .92 r
.71348 .3997 m .71928 .38988 L .72439 .39668 L F
.71348 .3997 m .70833 .3929 L .71928 .38988 L F
.735 .857 .938 r
.59576 .41405 m .60089 .40413 L .60637 .40862 L F
.59576 .41405 m .59025 .40975 L .60089 .40413 L F
.491 .67 .943 r
.16001 .36925 m .16246 .36146 L .16948 .36897 L F
.16001 .36925 m .15296 .36194 L .16246 .36146 L F
.262 .54 .922 r
.2089 .39462 m .21142 .38944 L .21827 .39696 L F
.2089 .39462 m .20206 .38701 L .21142 .38944 L F
.733 .775 .887 r
.07956 .37304 m .0821 .36096 L .08952 .36738 L F
.07956 .37304 m .0721 .36671 L .0821 .36096 L F
.461 .693 .967 r
.54216 .41757 m .54702 .41158 L .55274 .41668 L F
.54216 .41757 m .53641 .41164 L .54702 .41158 L F
.279 .553 .927 r
.22507 .40446 m .22772 .39921 L .23454 .40648 L F
.22507 .40446 m .21827 .39696 L .22772 .39921 L F
.491 .681 .951 r
.25767 .4215 m .26072 .41421 L .26749 .42057 L F
.25767 .4215 m .25093 .41465 L .26072 .41421 L F
.628 .74 .928 r
.7404 .40034 m .74638 .3909 L .75139 .39751 L F
.7404 .40034 m .73536 .39374 L .74638 .3909 L F
.684 .756 .907 r
.11669 .36367 m .11927 .3527 L .1265 .35962 L F
.11669 .36367 m .10941 .35697 L .11927 .3527 L F
.561 .718 .946 r
.85349 .41399 m .86029 .40629 L .86488 .41265 L F
.85349 .41399 m .84888 .40767 L .86029 .40629 L F
.869 .789 .769 r
.36279 .32541 m .35636 .31914 L .36714 .30485 L F
.887 .804 .762 r
.352 .34006 m .35636 .31914 L .36279 .32541 L F
.296 .566 .932 r
.52585 .41008 m .53062 .40569 L .53641 .41164 L F
.52585 .41008 m .52004 .40315 L .53062 .40569 L F
.596 .732 .939 r
.81038 .40688 m .81684 .39835 L .82159 .4048 L F
.81038 .40688 m .8056 .40046 L .81684 .39835 L F
.363 .606 .942 r
.24131 .41373 m .24413 .40778 L .25093 .41465 L F
.24131 .41373 m .23454 .40648 L .24413 .40778 L F
.579 .712 .934 r
.14337 .36364 m .14586 .35459 L .15296 .36194 L F
.14337 .36364 m .13623 .35653 L .14586 .35459 L F
0 .293 .791 r
.48743 .37651 m .49188 .37492 L .49781 .38313 L F
.48743 .37651 m .48151 .36744 L .49188 .37492 L F
.656 .828 .966 r
.569 .41883 m .57402 .41053 L .57961 .41474 L F
.569 .41883 m .56337 .41429 L .57402 .41053 L F
.564 .613 .86 r
.40478 .28836 m .4089 .27677 L .41498 .28773 L F
.40478 .28836 m .39867 .27807 L .4089 .27677 L F
.669 .75 .911 r
.67054 .39606 m .67607 .38538 L .68135 .39244 L F
.67054 .39606 m .66524 .38927 L .67607 .38538 L F
.078 .32 .8 r
.44321 .32348 m .44733 .31994 L .45335 .33031 L F
.44321 .32348 m .4372 .31293 L .44733 .31994 L F
.618 .739 .932 r
.76738 .4013 m .77354 .39216 L .77845 .39871 L F
.76738 .4013 m .76244 .39478 L .77354 .39216 L F
.891 .826 .776 r
.33692 .37438 m .33029 .36996 L .34115 .3552 L F
.883 .832 .792 r
.32616 .38792 m .33029 .36996 L .33692 .37438 L F
0 .249 .761 r
.46531 .35044 m .46958 .34882 L .47556 .35821 L F
.46531 .35044 m .45934 .34047 L .46958 .34882 L F
.747 .854 .929 r
.60637 .40862 m .61156 .39816 L .61701 .40302 L F
.60637 .40862 m .60089 .40413 L .61156 .39816 L F
.726 .774 .891 r
.0522 .3779 m .05458 .36607 L .06212 .37241 L F
.0522 .3779 m .04463 .37158 L .05458 .36607 L F
.712 .791 .914 r
.64374 .39807 m .64911 .38702 L .65446 .3935 L F
.64374 .39807 m .63837 .39208 L .64911 .38702 L F
.727 .772 .889 r
.08952 .36738 m .0921 .35539 L .09948 .36195 L F
.08952 .36738 m .0821 .36096 L .0921 .35539 L F
.643 .733 .914 r
.69744 .39604 m .70314 .38586 L .70833 .3929 L F
.69744 .39604 m .69222 .38905 L .70314 .38586 L F
.714 .792 .913 r
.28425 .42351 m .28773 .41272 L .29449 .41794 L F
.28425 .42351 m .27751 .41775 L .28773 .41272 L F
.33 .476 .854 r
.42104 .29846 m .42511 .29115 L .43117 .30216 L F
.42104 .29846 m .41498 .28773 L .42511 .29115 L F
.575 .723 .943 r
.83755 .4093 m .84423 .40125 L .84888 .40767 L F
.83755 .4093 m .83287 .40292 L .84423 .40125 L F
.605 .734 .936 r
.79443 .40274 m .80079 .39394 L .8056 .40046 L F
.79443 .40274 m .78959 .39625 L .80079 .39394 L F
.631 .735 .923 r
.72439 .39668 m .73027 .38697 L .73536 .39374 L F
.72439 .39668 m .71928 .38988 L .73027 .38697 L F
.802 .742 .796 r
.3778 .2927 m .38211 .27401 L .38831 .28354 L F
.3778 .2927 m .37152 .28426 L .38211 .27401 L F
.849 .769 .773 r
.36714 .30485 m .37152 .28426 L .3778 .2927 L F
.887 .804 .762 r
.352 .34006 m .34548 .33462 L .35636 .31914 L F
.894 .816 .763 r
.34115 .3552 m .34548 .33462 L .352 .34006 L F
.723 .698 .826 r
.38831 .28354 m .39253 .26757 L .39867 .27807 L F
.38831 .28354 m .38211 .27401 L .39253 .26757 L F
.645 .741 .919 r
.1265 .35962 m .12904 .34938 L .13623 .35653 L F
.1265 .35962 m .11927 .3527 L .12904 .34938 L F
.883 .832 .792 r
.32616 .38792 m .31947 .38361 L .33029 .36996 L F
.864 .834 .815 r
.31547 .39996 m .31947 .38361 L .32616 .38792 L F
.749 .841 .921 r
.61701 .40302 m .62225 .39209 L .62767 .39745 L F
.61701 .40302 m .61156 .39816 L .62225 .39209 L F
.733 .775 .887 r
.06212 .37241 m .06458 .36032 L .0721 .36671 L F
.06212 .37241 m .05458 .36607 L .06458 .36032 L F
.623 .739 .93 r
.75139 .39751 m .75746 .38816 L .76244 .39478 L F
.75139 .39751 m .74638 .3909 L .75746 .38816 L F
.714 .767 .894 r
.09948 .36195 m .10207 .35023 L .10941 .35697 L F
.09948 .36195 m .0921 .35539 L .10207 .35023 L F
.783 .818 .88 r
.29449 .41794 m .29815 .40531 L .3049 .41006 L F
.29449 .41794 m .28773 .41272 L .29815 .40531 L F
.705 .856 .954 r
.57961 .41474 m .58469 .40563 L .59025 .40975 L F
.57961 .41474 m .57402 .41053 L .58469 .40563 L F
.849 .769 .773 r
.36714 .30485 m .36077 .29752 L .37152 .28426 L F
.877 .788 .759 r
.35636 .31914 m .36077 .29752 L .36714 .30485 L F
.697 .771 .909 r
.65446 .3935 m .6599 .38236 L .66524 .38927 L F
.65446 .3935 m .64911 .38702 L .6599 .38236 L F
.656 .737 .909 r
.68135 .39244 m .68695 .38182 L .69222 .38905 L F
.68135 .39244 m .67607 .38538 L .68695 .38182 L F
.402 .622 .942 r
.16948 .36897 m .17188 .3622 L .17887 .36985 L F
.16948 .36897 m .16246 .36146 L .17188 .3622 L F
.308 .569 .931 r
.18582 .37747 m .18823 .37172 L .19517 .37938 L F
.18582 .37747 m .17887 .36985 L .18823 .37172 L F
.587 .727 .94 r
.82159 .4048 m .82815 .39643 L .83287 .40292 L F
.82159 .4048 m .81684 .39835 L .82815 .39643 L F
.056 .376 .841 r
.5037 .39122 m .5083 .38908 L .51419 .39615 L F
.5037 .39122 m .49781 .38313 L .5083 .38908 L F
.551 .768 .979 r
.55274 .41668 m .55769 .40984 L .56337 .41429 L F
.55274 .41668 m .54702 .41158 L .55769 .40984 L F
.864 .834 .815 r
.31547 .39996 m .30874 .39554 L .31947 .38361 L F
.832 .831 .846 r
.3049 .41006 m .30874 .39554 L .31547 .39996 L F
.596 .741 .945 r
.26749 .42057 m .27072 .41193 L .27751 .41775 L F
.26749 .42057 m .26072 .41421 L .27072 .41193 L F
.832 .831 .846 r
.3049 .41006 m .29815 .40531 L .30874 .39554 L F
.25 .535 .92 r
.20206 .38701 m .20452 .38189 L .21142 .38944 L F
.20206 .38701 m .19517 .37938 L .20452 .38189 L F
.612 .736 .933 r
.77845 .39871 m .78471 .38967 L .78959 .39625 L F
.77845 .39871 m .77354 .39216 L .78471 .38967 L F
.503 .676 .942 r
.15296 .36194 m .15539 .35392 L .16246 .36146 L F
.15296 .36194 m .14586 .35459 L .15539 .35392 L F
.636 .729 .916 r
.70833 .3929 m .71411 .38284 L .71928 .38988 L F
.70833 .3929 m .70314 .38586 L .71411 .38284 L F
.072 .312 .794 r
.4372 .31293 m .44129 .30933 L .44733 .31994 L F
.4372 .31293 m .43117 .30216 L .44129 .30933 L F
.591 .623 .852 r
.39867 .27807 m .4028 .26557 L .4089 .27677 L F
.39867 .27807 m .39253 .26757 L .4028 .26557 L F
.254 .54 .923 r
.21827 .39696 m .22085 .39191 L .22772 .39921 L F
.21827 .39696 m .21142 .38944 L .22085 .39191 L F
.743 .822 .914 r
.62767 .39745 m .63296 .38615 L .63837 .39208 L F
.62767 .39745 m .62225 .39209 L .63296 .38615 L F
0 .216 .74 r
.45934 .34047 m .46356 .33923 L .46958 .34882 L F
.45934 .34047 m .45335 .33031 L .46356 .33923 L F
.735 .775 .885 r
.0721 .36671 m .07462 .35449 L .0821 .36096 L F
.0721 .36671 m .06458 .36032 L .07462 .35449 L F
0 .24 .757 r
.48151 .36744 m .48592 .36658 L .49188 .37492 L F
.48151 .36744 m .47556 .35821 L .48592 .36658 L F
.894 .816 .763 r
.34115 .3552 m .33454 .35037 L .34548 .33462 L F
.893 .825 .772 r
.33029 .36996 m .33454 .35037 L .34115 .3552 L F
.351 .484 .853 r
.41498 .28773 m .41904 .27988 L .42511 .29115 L F
.41498 .28773 m .4089 .27677 L .41904 .27988 L F
.455 .666 .953 r
.25093 .41465 m .2539 .4078 L .26072 .41421 L F
.25093 .41465 m .24413 .40778 L .2539 .4078 L F
.207 .512 .912 r
.52004 .40315 m .52478 .39973 L .53062 .40569 L F
.52004 .40315 m .51419 .39615 L .52478 .39973 L F
.391 .658 .965 r
.53641 .41164 m .54126 .40653 L .54702 .41158 L F
.53641 .41164 m .53062 .40569 L .54126 .40653 L F
.328 .589 .939 r
.23454 .40648 m .23729 .40086 L .24413 .40778 L F
.23454 .40648 m .22772 .39921 L .23729 .40086 L F
.627 .735 .925 r
.73536 .39374 m .74133 .38415 L .74638 .3909 L F
.73536 .39374 m .73027 .38697 L .74133 .38415 L F
.69 .758 .903 r
.10941 .35697 m .11198 .34574 L .11927 .3527 L F
.10941 .35697 m .10207 .35023 L .11198 .34574 L F
.739 .867 .94 r
.59025 .40975 m .59538 .39985 L .60089 .40413 L F
.59025 .40975 m .58469 .40563 L .59538 .39985 L F
.562 .716 .944 r
.84888 .40767 m .85567 .39984 L .86029 .40629 L F
.84888 .40767 m .84423 .40125 L .85567 .39984 L F
.597 .73 .937 r
.8056 .40046 m .81205 .3918 L .81684 .39835 L F
.8056 .40046 m .80079 .39394 L .81205 .3918 L F
.877 .788 .759 r
.35636 .31914 m .34988 .31282 L .36077 .29752 L F
.892 .802 .753 r
.34548 .33462 m .34988 .31282 L .35636 .31914 L F
.59 .716 .931 r
.13623 .35653 m .13871 .34721 L .14586 .35459 L F
.13623 .35653 m .12904 .34938 L .13871 .34721 L F
.68 .752 .905 r
.66524 .38927 m .67074 .37813 L .67607 .38538 L F
.66524 .38927 m .6599 .38236 L .67074 .37813 L F
.618 .737 .931 r
.76244 .39478 m .76859 .38553 L .77354 .39216 L F
.76244 .39478 m .75746 .38816 L .76859 .38553 L F
.645 .728 .909 r
.69222 .38905 m .6979 .37855 L .70314 .38586 L F
.69222 .38905 m .68695 .38182 L .6979 .37855 L F
.743 .702 .813 r
.38211 .27401 m .38637 .25686 L .39253 .26757 L F
.38211 .27401 m .37588 .26431 L .38637 .25686 L F
.816 .743 .783 r
.37152 .28426 m .37588 .26431 L .38211 .27401 L F
.73 .773 .887 r
.0821 .36096 m .08467 .34878 L .0921 .35539 L F
.0821 .36096 m .07462 .35449 L .08467 .34878 L F
.73 .8 .907 r
.63837 .39208 m .64371 .38051 L .64911 .38702 L F
.63837 .39208 m .63296 .38615 L .64371 .38051 L F
.816 .743 .783 r
.37152 .28426 m .3652 .27571 L .37588 .26431 L F
.859 .768 .761 r
.36077 .29752 m .3652 .27571 L .37152 .28426 L F
.632 .826 .975 r
.56337 .41429 m .56838 .4065 L .57402 .41053 L F
.56337 .41429 m .55769 .40984 L .56838 .4065 L F
.694 .788 .923 r
.27751 .41775 m .28093 .40744 L .28773 .41272 L F
.27751 .41775 m .27072 .41193 L .28093 .40744 L F
.576 .721 .942 r
.83287 .40292 m .83954 .39473 L .84423 .40125 L F
.83287 .40292 m .82815 .39643 L .83954 .39473 L F
.759 .865 .927 r
.60089 .40413 m .60607 .3935 L .61156 .39816 L F
.60089 .40413 m .59538 .39985 L .60607 .3935 L F
.893 .825 .772 r
.33029 .36996 m .3236 .3655 L .33454 .35037 L F
.883 .831 .791 r
.31947 .38361 m .3236 .3655 L .33029 .36996 L F
.629 .728 .918 r
.71928 .38988 m .72514 .37997 L .73027 .38697 L F
.71928 .38988 m .71411 .38284 L .72514 .37997 L F
.605 .732 .935 r
.78959 .39625 m .79593 .38734 L .80079 .39394 L F
.78959 .39625 m .78471 .38967 L .79593 .38734 L F
.654 .743 .915 r
.11927 .3527 m .1218 .34219 L .12904 .34938 L F
.11927 .3527 m .11198 .34574 L .1218 .34219 L F
.068 .304 .788 r
.43117 .30216 m .43522 .29846 L .44129 .30933 L F
.43117 .30216 m .42511 .29115 L .43522 .29846 L F
.616 .631 .843 r
.39253 .26757 m .39668 .25409 L .4028 .26557 L F
.39253 .26757 m .38637 .25686 L .39668 .25409 L F
0 .31 .801 r
.49781 .38313 m .50237 .38194 L .5083 .38908 L F
.49781 .38313 m .49188 .37492 L .50237 .38194 L F
.892 .802 .753 r
.34548 .33462 m .3389 .32916 L .34988 .31282 L F
.898 .814 .756 r
.33454 .35037 m .3389 .32916 L .34548 .33462 L F
.622 .734 .927 r
.74638 .3909 m .75244 .38144 L .75746 .38816 L F
.74638 .3909 m .74133 .38415 L .75244 .38144 L F
.309 .57 .931 r
.17887 .36985 m .18124 .36403 L .18823 .37172 L F
.17887 .36985 m .17188 .3622 L .18124 .36403 L F
.374 .492 .85 r
.4089 .27677 m .41294 .26833 L .41904 .27988 L F
.4089 .27677 m .4028 .26557 L .41294 .26833 L F
.411 .627 .942 r
.16246 .36146 m .16483 .35452 L .17188 .3622 L F
.16246 .36146 m .15539 .35392 L .16483 .35452 L F
0 .184 .718 r
.45335 .33031 m .45752 .32944 L .46356 .33923 L F
.45335 .33031 m .44733 .31994 L .45752 .32944 L F
.718 .768 .891 r
.0921 .35539 m .09468 .34344 L .10207 .35023 L F
.0921 .35539 m .08467 .34878 L .09468 .34344 L F
.859 .768 .761 r
.36077 .29752 m .35435 .29012 L .3652 .27571 L F
.884 .786 .748 r
.34988 .31282 m .35435 .29012 L .36077 .29752 L F
.664 .735 .903 r
.67607 .38538 m .68164 .37433 L .68695 .38182 L F
.67607 .38538 m .67074 .37813 L .68164 .37433 L F
.713 .777 .902 r
.64911 .38702 m .65451 .37532 L .6599 .38236 L F
.64911 .38702 m .64371 .38051 L .65451 .37532 L F
.239 .529 .919 r
.19517 .37938 m .19758 .3743 L .20452 .38189 L F
.19517 .37938 m .18823 .37172 L .19758 .3743 L F
.588 .725 .939 r
.81684 .39835 m .82339 .38985 L .82815 .39643 L F
.81684 .39835 m .81205 .3918 L .82339 .38985 L F
.766 .853 .916 r
.61156 .39816 m .61678 .38688 L .62225 .39209 L F
.61156 .39816 m .60607 .3935 L .61678 .38688 L F
0 .186 .718 r
.47556 .35821 m .47992 .35809 L .48592 .36658 L F
.47556 .35821 m .46958 .34882 L .47992 .35809 L F
.883 .831 .791 r
.31947 .38361 m .31273 .37926 L .3236 .3655 L F
.862 .834 .818 r
.30874 .39554 m .31273 .37926 L .31947 .38361 L F
.771 .817 .889 r
.28773 .41272 m .29135 .40049 L .29815 .40531 L F
.28773 .41272 m .28093 .40744 L .29135 .40049 L F
.515 .681 .941 r
.14586 .35459 m .14828 .34633 L .15539 .35392 L F
.14586 .35459 m .13871 .34721 L .14828 .34633 L F
.565 .729 .952 r
.26072 .41421 m .26388 .40605 L .27072 .41193 L F
.26072 .41421 m .2539 .4078 L .26388 .40605 L F
.635 .722 .91 r
.70314 .38586 m .7089 .37553 L .71411 .38284 L F
.70314 .38586 m .6979 .37855 L .7089 .37553 L F
.612 .735 .933 r
.77354 .39216 m .77978 .38303 L .78471 .38967 L F
.77354 .39216 m .76859 .38553 L .77978 .38303 L F
.498 .749 .985 r
.54702 .41158 m .55196 .40552 L .55769 .40984 L F
.54702 .41158 m .54126 .40653 L .55196 .40552 L F
.229 .526 .918 r
.21142 .38944 m .21394 .38457 L .22085 .39191 L F
.21142 .38944 m .20452 .38189 L .21394 .38457 L F
.697 .862 .961 r
.57402 .41053 m .57909 .40173 L .58469 .40563 L F
.57402 .41053 m .56838 .4065 L .57909 .40173 L F
.862 .834 .818 r
.30874 .39554 m .30196 .39104 L .31273 .37926 L F
.826 .831 .852 r
.29815 .40531 m .30196 .39104 L .30874 .39554 L F
.29815 .40531 m .29135 .40049 L .30196 .39104 L F
.292 .57 .935 r
.22772 .39921 m .2304 .3939 L .23729 .40086 L F
.22772 .39921 m .22085 .39191 L .2304 .3939 L F
.417 .648 .953 r
.24413 .40778 m .24703 .40134 L .2539 .4078 L F
.24413 .40778 m .23729 .40086 L .24703 .40134 L F
.106 .447 .881 r
.51419 .39615 m .5189 .39375 L .52478 .39973 L F
.51419 .39615 m .5083 .38908 L .5189 .39375 L F
.624 .728 .921 r
.73027 .38697 m .73623 .37722 L .74133 .38415 L F
.73027 .38697 m .72514 .37997 L .73623 .37722 L F
.762 .833 .907 r
.62225 .39209 m .62752 .3803 L .63296 .38615 L F
.62225 .39209 m .61678 .38688 L .62752 .3803 L F
.697 .759 .9 r
.10207 .35023 m .10464 .33874 L .11198 .34574 L F
.10207 .35023 m .09468 .34344 L .10464 .33874 L F
.761 .705 .8 r
.37588 .26431 m .38019 .24592 L .38637 .25686 L F
.37588 .26431 m .36962 .25445 L .38019 .24592 L F
.828 .743 .77 r
.3652 .27571 m .36962 .25445 L .37588 .26431 L F
.306 .613 .955 r
.53062 .40569 m .53545 .40154 L .54126 .40653 L F
.53062 .40569 m .52478 .39973 L .53545 .40154 L F
.601 .72 .929 r
.12904 .34938 m .13152 .33979 L .13871 .34721 L F
.12904 .34938 m .1218 .34219 L .13152 .33979 L F
.564 .715 .943 r
.84423 .40125 m .85101 .39329 L .85567 .39984 L F
.84423 .40125 m .83954 .39473 L .85101 .39329 L F
.597 .729 .936 r
.80079 .39394 m .80723 .38517 L .81205 .3918 L F
.80079 .39394 m .79593 .38734 L .80723 .38517 L F
.898 .814 .756 r
.33454 .35037 m .32787 .34553 L .3389 .32916 L F
.895 .824 .769 r
.3236 .3655 m .32787 .34553 L .33454 .35037 L F
.694 .754 .898 r
.6599 .38236 m .66537 .37066 L .67074 .37813 L F
.6599 .38236 m .65451 .37532 L .66537 .37066 L F
.884 .786 .748 r
.34988 .31282 m .34336 .30648 L .35435 .29012 L F
.897 .801 .745 r
.3389 .32916 m .34336 .30648 L .34988 .31282 L F
.066 .297 .783 r
.42511 .29115 m .42913 .28732 L .43522 .29846 L F
.42511 .29115 m .41904 .27988 L .42913 .28732 L F
.828 .743 .77 r
.3652 .27571 m .35885 .26705 L .36962 .25445 L F
.867 .767 .749 r
.35435 .29012 m .35885 .26705 L .3652 .27571 L F
.649 .723 .903 r
.68695 .38182 m .69261 .37093 L .6979 .37855 L F
.68695 .38182 m .68164 .37433 L .69261 .37093 L F
.616 .734 .93 r
.75746 .38816 m .7636 .37883 L .76859 .38553 L F
.75746 .38816 m .75244 .38144 L .7636 .37883 L F
.64 .638 .832 r
.38637 .25686 m .39054 .24233 L .39668 .25409 L F
.38637 .25686 m .38019 .24592 L .39054 .24233 L F
.397 .5 .847 r
.4028 .26557 m .40683 .25647 L .41294 .26833 L F
.4028 .26557 m .39668 .25409 L .40683 .25647 L F
.743 .877 .942 r
.58469 .40563 m .58982 .39581 L .59538 .39985 L F
.58469 .40563 m .57909 .40173 L .58982 .39581 L F
0 .152 .695 r
.44733 .31994 m .45145 .31943 L .45752 .32944 L F
.44733 .31994 m .44129 .30933 L .45145 .31943 L F
.75 .809 .899 r
.63296 .38615 m .63828 .37399 L .64371 .38051 L F
.63296 .38615 m .62752 .3803 L .63828 .37399 L F
.627 .719 .913 r
.71411 .38284 m .71996 .37271 L .72514 .37997 L F
.71411 .38284 m .7089 .37553 L .71996 .37271 L F
.577 .72 .94 r
.82815 .39643 m .83481 .38812 L .83954 .39473 L F
.82815 .39643 m .82339 .38985 L .83481 .38812 L F
.672 .782 .932 r
.27072 .41193 m .27407 .40209 L .28093 .40744 L F
.27072 .41193 m .26388 .40605 L .27407 .40209 L F
.605 .732 .934 r
.78471 .38967 m .79104 .38067 L .79593 .38734 L F
.78471 .38967 m .77978 .38303 L .79104 .38067 L F
0 .238 .753 r
.49188 .37492 m .4964 .37471 L .50237 .38194 L F
.49188 .37492 m .48592 .36658 L .4964 .37471 L F
.662 .745 .912 r
.11198 .34574 m .11451 .33495 L .1218 .34219 L F
.11198 .34574 m .10464 .33874 L .11451 .33495 L F
0 .131 .677 r
.46958 .34882 m .47388 .34945 L .47992 .35809 L F
.46958 .34882 m .46356 .33923 L .47388 .34945 L F
.6 .821 .984 r
.55769 .40984 m .56269 .40266 L .56838 .4065 L F
.55769 .40984 m .55196 .40552 L .56269 .40266 L F
.311 .572 .932 r
.17188 .3622 m .17421 .35629 L .18124 .36403 L F
.17188 .3622 m .16483 .35452 L .17421 .35629 L F
.421 .632 .943 r
.15539 .35392 m .15774 .34679 L .16483 .35452 L F
.15539 .35392 m .14828 .34633 L .15774 .34679 L F
.618 .728 .925 r
.74133 .38415 m .74737 .37457 L .75244 .38144 L F
.74133 .38415 m .73623 .37722 L .74737 .37457 L F
.771 .877 .924 r
.59538 .39985 m .60054 .38906 L .60607 .3935 L F
.59538 .39985 m .58982 .39581 L .60054 .38906 L F
.895 .824 .769 r
.3236 .3655 m .31686 .36102 L .32787 .34553 L F
.884 .831 .79 r
.31273 .37926 m .31686 .36102 L .3236 .3655 L F
.867 .767 .749 r
.35435 .29012 m .34789 .28266 L .35885 .26705 L F
.89 .785 .738 r
.34336 .30648 m .34789 .28266 L .35435 .29012 L F
.674 .734 .895 r
.67074 .37813 m .67628 .36654 L .68164 .37433 L F
.67074 .37813 m .66537 .37066 L .67628 .36654 L F
.229 .524 .917 r
.18823 .37172 m .19059 .36668 L .19758 .3743 L F
.18823 .37172 m .18124 .36403 L .19059 .36668 L F
.732 .783 .894 r
.64371 .38051 m .64909 .36816 L .65451 .37532 L F
.64371 .38051 m .63828 .37399 L .64909 .36816 L F
.897 .801 .745 r
.3389 .32916 m .33227 .32368 L .34336 .30648 L F
.902 .813 .751 r
.32787 .34553 m .33227 .32368 L .3389 .32916 L F
.588 .724 .938 r
.81205 .3918 m .8186 .38319 L .82339 .38985 L F
.81205 .3918 m .80723 .38517 L .8186 .38319 L F
.526 .686 .939 r
.13871 .34721 m .14111 .33871 L .14828 .34633 L F
.13871 .34721 m .13152 .33979 L .14111 .33871 L F
.635 .714 .904 r
.6979 .37855 m .70363 .36789 L .7089 .37553 L F
.6979 .37855 m .69261 .37093 L .70363 .36789 L F
.205 .512 .913 r
.20452 .38189 m .20698 .37719 L .21394 .38457 L F
.20452 .38189 m .19758 .3743 L .20698 .37719 L F
.066 .291 .778 r
.41904 .27988 m .42302 .27587 L .42913 .28732 L F
.41904 .27988 m .41294 .26833 L .42302 .27587 L F
.777 .707 .786 r
.36962 .25445 m .37398 .23472 L .38019 .24592 L F
.36962 .25445 m .36334 .2444 L .37398 .23472 L F
.84 .743 .757 r
.35885 .26705 m .36334 .2444 L .36962 .25445 L F
.532 .716 .957 r
.2539 .4078 m .25698 .40011 L .26388 .40605 L F
.2539 .4078 m .24703 .40134 L .25698 .40011 L F
.611 .733 .932 r
.76859 .38553 m .77483 .37634 L .77978 .38303 L F
.76859 .38553 m .7636 .37883 L .77483 .37634 L F
.758 .816 .898 r
.28093 .40744 m .28449 .39561 L .29135 .40049 L F
.28093 .40744 m .27407 .40209 L .28449 .39561 L F
.422 .509 .843 r
.39668 .25409 m .40071 .24427 L .40683 .25647 L F
.39668 .25409 m .39054 .24233 L .40071 .24427 L F
.783 .865 .91 r
.60607 .3935 m .61128 .38185 L .61678 .38688 L F
.60607 .3935 m .60054 .38906 L .61128 .38185 L F
.256 .55 .928 r
.22085 .39191 m .22346 .3869 L .2304 .3939 L F
.22085 .39191 m .21394 .38457 L .22346 .3869 L F
.662 .644 .821 r
.38019 .24592 m .38439 .23025 L .39054 .24233 L F
.38019 .24592 m .37398 .23472 L .38439 .23025 L F
.377 .628 .952 r
.23729 .40086 m .24011 .39483 L .24703 .40134 L F
.23729 .40086 m .2304 .3939 L .24011 .39483 L F
0 .37 .837 r
.5083 .38908 m .51297 .38778 L .5189 .39375 L F
.5083 .38908 m .50237 .38194 L .51297 .38778 L F
.884 .831 .79 r
.31273 .37926 m .30592 .37486 L .31686 .36102 L F
.86 .835 .821 r
.30196 .39104 m .30592 .37486 L .31273 .37926 L F
.431 .721 .986 r
.54126 .40653 m .54618 .40134 L .55196 .40552 L F
.54126 .40653 m .53545 .40154 L .54618 .40134 L F
.619 .719 .917 r
.72514 .37997 m .73108 .37006 L .73623 .37722 L F
.72514 .37997 m .71996 .37271 L .73108 .37006 L F
0 .12 .671 r
.44129 .30933 m .44535 .30917 L .45145 .31943 L F
.44129 .30933 m .43522 .29846 L .44535 .30917 L F
.611 .724 .926 r
.1218 .34219 m .12427 .33232 L .13152 .33979 L F
.1218 .34219 m .11451 .33495 L .12427 .33232 L F
.84 .743 .757 r
.35885 .26705 m .35246 .25826 L .36334 .2444 L F
.875 .766 .738 r
.34789 .28266 m .35246 .25826 L .35885 .26705 L F
.684 .867 .968 r
.56838 .4065 m .57345 .39807 L .57909 .40173 L F
.56838 .4065 m .56269 .40266 L .57345 .39807 L F
.597 .728 .936 r
.79593 .38734 m .80237 .37848 L .80723 .38517 L F
.79593 .38734 m .79104 .38067 L .80237 .37848 L F
.564 .714 .942 r
.83954 .39473 m .84631 .38665 L .85101 .39329 L F
.83954 .39473 m .83481 .38812 L .84631 .38665 L F
.82 .831 .858 r
.29135 .40049 m .29512 .3865 L .30196 .39104 L F
.29135 .40049 m .28449 .39561 L .29512 .3865 L F
.709 .757 .889 r
.65451 .37532 m .65995 .36295 L .66537 .37066 L F
.65451 .37532 m .64909 .36816 L .65995 .36295 L F
.205 .554 .933 r
.52478 .39973 m .52959 .39663 L .53545 .40154 L F
.52478 .39973 m .5189 .39375 L .52959 .39663 L F
.654 .717 .895 r
.68164 .37433 m .68726 .36297 L .69261 .37093 L F
.68164 .37433 m .67628 .36654 L .68726 .36297 L F
.86 .835 .821 r
.30196 .39104 m .29512 .3865 L .30592 .37486 L F
.783 .844 .898 r
.61678 .38688 m .62203 .37454 L .62752 .3803 L F
.61678 .38688 m .61128 .38185 L .62203 .37454 L F
.89 .785 .738 r
.34336 .30648 m .33678 .3001 L .34789 .28266 L F
.902 .799 .737 r
.33227 .32368 m .33678 .3001 L .34336 .30648 L F
.613 .729 .928 r
.75244 .38144 m .75857 .37203 L .7636 .37883 L F
.75244 .38144 m .74737 .37457 L .75857 .37203 L F
0 .076 .632 r
.46356 .33923 m .46781 .34064 L .47388 .34945 L F
.46356 .33923 m .45752 .32944 L .46781 .34064 L F
.902 .813 .751 r
.32787 .34553 m .32114 .34068 L .33227 .32368 L F
.898 .823 .766 r
.31686 .36102 m .32114 .34068 L .32787 .34553 L F
0 .164 .696 r
.48592 .36658 m .49038 .36741 L .4964 .37471 L F
.48592 .36658 m .47992 .35809 L .49038 .36741 L F
.623 .709 .907 r
.7089 .37553 m .71473 .36515 L .71996 .37271 L F
.7089 .37553 m .70363 .36789 L .71473 .36515 L F
.068 .287 .774 r
.41294 .26833 m .41689 .2641 L .42302 .27587 L F
.41294 .26833 m .40683 .25647 L .41689 .2641 L F
.577 .719 .939 r
.82339 .38985 m .83004 .38144 L .83481 .38812 L F
.82339 .38985 m .8186 .38319 L .83004 .38144 L F
.772 .818 .89 r
.62752 .3803 m .63281 .36745 L .63828 .37399 L F
.62752 .3803 m .62203 .37454 L .63281 .36745 L F
.604 .731 .935 r
.77978 .38303 m .78612 .37398 L .79104 .38067 L F
.77978 .38303 m .77483 .37634 L .78612 .37398 L F
.447 .517 .837 r
.39054 .24233 m .39457 .23171 L .40071 .24427 L F
.39054 .24233 m .38439 .23025 L .39457 .23171 L F
.314 .573 .933 r
.16483 .35452 m .16712 .34851 L .17421 .35629 L F
.16483 .35452 m .15774 .34679 L .16712 .34851 L F
.648 .775 .941 r
.26388 .40605 m .26716 .39668 L .27407 .40209 L F
.26388 .40605 m .25698 .40011 L .26716 .39668 L F
.745 .888 .945 r
.57909 .40173 m .58421 .39203 L .58982 .39581 L F
.57909 .40173 m .57345 .39807 L .58421 .39203 L F
.43 .637 .943 r
.14828 .34633 m .1506 .33902 L .15774 .34679 L F
.14828 .34633 m .14111 .33871 L .1506 .33902 L F
.792 .709 .773 r
.36334 .2444 m .36776 .22326 L .37398 .23472 L F
.36334 .2444 m .35703 .23415 L .36776 .22326 L F
.85 .742 .744 r
.35246 .25826 m .35703 .23415 L .36334 .2444 L F
.684 .649 .809 r
.37398 .23472 m .37822 .21783 L .38439 .23025 L F
.37398 .23472 m .36776 .22326 L .37822 .21783 L F
.685 .733 .886 r
.66537 .37066 m .67088 .35842 L .67628 .36654 L F
.66537 .37066 m .65995 .36295 L .67088 .35842 L F
.219 .519 .915 r
.18124 .36403 m .18355 .35901 L .19059 .36668 L F
.18124 .36403 m .17421 .35629 L .18355 .35901 L F
.875 .766 .738 r
.34789 .28266 m .34138 .27513 L .35246 .25826 L F
.896 .783 .729 r
.33678 .3001 m .34138 .27513 L .34789 .28266 L F
.613 .72 .922 r
.73623 .37722 m .74226 .36754 L .74737 .37457 L F
.73623 .37722 m .73108 .37006 L .74226 .36754 L F
0 .089 .647 r
.43522 .29846 m .43922 .29865 L .44535 .30917 L F
.43522 .29846 m .42913 .28732 L .43922 .29865 L F
.636 .705 .896 r
.69261 .37093 m .69832 .35989 L .70363 .36789 L F
.69261 .37093 m .68726 .36297 L .69832 .35989 L F
.538 .691 .938 r
.13152 .33979 m .1339 .33103 L .14111 .33871 L F
.13152 .33979 m .12427 .33232 L .1339 .33103 L F
.18 .498 .907 r
.19758 .3743 m .19997 .36976 L .20698 .37719 L F
.19758 .3743 m .19059 .36668 L .19997 .36976 L F
.559 .813 .993 r
.55196 .40552 m .55696 .39903 L .56269 .40266 L F
.55196 .40552 m .54618 .40134 L .55696 .39903 L F
.588 .724 .938 r
.80723 .38517 m .81377 .37648 L .8186 .38319 L F
.80723 .38517 m .80237 .37848 L .81377 .37648 L F
.752 .789 .883 r
.63828 .37399 m .64362 .36085 L .64909 .36816 L F
.63828 .37399 m .63281 .36745 L .64362 .36085 L F
.898 .823 .766 r
.31686 .36102 m .31005 .35652 L .32114 .34068 L F
.884 .831 .79 r
.30592 .37486 m .31005 .35652 L .31686 .36102 L F
.495 .701 .961 r
.24703 .40134 m .25003 .39412 L .25698 .40011 L F
.24703 .40134 m .24011 .39483 L .25003 .39412 L F
.608 .73 .932 r
.7636 .37883 m .76984 .36959 L .77483 .37634 L F
.7636 .37883 m .75857 .37203 L .76984 .36959 L F
.783 .89 .921 r
.58982 .39581 m .59498 .38488 L .60054 .38906 L F
.58982 .39581 m .58421 .39203 L .59498 .38488 L F
.219 .529 .921 r
.21394 .38457 m .21647 .37985 L .22346 .3869 L F
.21394 .38457 m .20698 .37719 L .21647 .37985 L F
.902 .799 .737 r
.33227 .32368 m .32558 .3182 L .33678 .3001 L F
.905 .812 .745 r
.32114 .34068 m .32558 .3182 L .33227 .32368 L F
.85 .742 .744 r
.35246 .25826 m .34604 .24935 L .35703 .23415 L F
.883 .764 .727 r
.34138 .27513 m .34604 .24935 L .35246 .25826 L F
0 .284 .778 r
.50237 .38194 m .507 .3818 L .51297 .38778 L F
.50237 .38194 m .4964 .37471 L .507 .3818 L F
.334 .607 .948 r
.2304 .3939 m .23314 .38828 L .24011 .39483 L F
.2304 .3939 m .22346 .3869 L .23314 .38828 L F
.614 .708 .912 r
.71996 .37271 m .72589 .36264 L .73108 .37006 L F
.71996 .37271 m .71473 .36515 L .72589 .36264 L F
.072 .283 .77 r
.40683 .25647 m .41074 .25198 L .41689 .2641 L F
.40683 .25647 m .40071 .24427 L .41074 .25198 L F
.744 .814 .907 r
.27407 .40209 m .27757 .39068 L .28449 .39561 L F
.27407 .40209 m .26716 .39668 L .27757 .39068 L F
.472 .525 .831 r
.38439 .23025 m .38843 .21876 L .39457 .23171 L F
.38439 .23025 m .37822 .21783 L .38843 .21876 L F
0 .021 .586 r
.45752 .32944 m .4617 .33165 L .46781 .34064 L F
.45752 .32944 m .45145 .31943 L .4617 .33165 L F
.661 .712 .886 r
.67628 .36654 m .68187 .3546 L .68726 .36297 L F
.67628 .36654 m .67088 .35842 L .68187 .3546 L F
.727 .76 .878 r
.64909 .36816 m .65449 .35497 L .65995 .36295 L F
.64909 .36816 m .64362 .36085 L .65449 .35497 L F
.596 .729 .937 r
.79104 .38067 m .79747 .37178 L .80237 .37848 L F
.79104 .38067 m .78612 .37398 L .79747 .37178 L F
.801 .877 .902 r
.60054 .38906 m .60574 .37702 L .61128 .38185 L F
.60054 .38906 m .59498 .38488 L .60574 .37702 L F
.565 .713 .941 r
.83481 .38812 m .84157 .37994 L .84631 .38665 L F
.83481 .38812 m .83004 .38144 L .84157 .37994 L F
.347 .681 .979 r
.53545 .40154 m .54035 .39733 L .54618 .40134 L F
.53545 .40154 m .52959 .39663 L .54035 .39733 L F
.884 .831 .79 r
.30592 .37486 m .29905 .37044 L .31005 .35652 L F
.857 .836 .824 r
.29512 .3865 m .29905 .37044 L .30592 .37486 L F
.704 .653 .797 r
.36776 .22326 m .37205 .20505 L .37822 .21783 L F
.36776 .22326 m .36153 .2115 L .37205 .20505 L F
.805 .71 .759 r
.35703 .23415 m .36153 .2115 L .36776 .22326 L F
0 .088 .633 r
.47992 .35809 m .48432 .36001 L .49038 .36741 L F
.47992 .35809 m .47388 .34945 L .48432 .36001 L F
.088 .479 .894 r
.5189 .39375 m .52368 .3918 L .52959 .39663 L F
.5189 .39375 m .51297 .38778 L .52368 .3918 L F
.608 .723 .927 r
.74737 .37457 m .7535 .36512 L .75857 .37203 L F
.74737 .37457 m .74226 .36754 L .7535 .36512 L F
.896 .783 .729 r
.33678 .3001 m .33015 .2937 L .34138 .27513 L F
.906 .797 .729 r
.32558 .3182 m .33015 .2937 L .33678 .3001 L F
.62 .698 .9 r
.70363 .36789 m .70944 .35722 L .71473 .36515 L F
.70363 .36789 m .69832 .35989 L .70944 .35722 L F
.813 .832 .865 r
.28449 .39561 m .28821 .38192 L .29512 .3865 L F
.28449 .39561 m .27757 .39068 L .28821 .38192 L F
.805 .71 .759 r
.35703 .23415 m .3507 .22369 L .36153 .2115 L F
.859 .741 .732 r
.34604 .24935 m .3507 .22369 L .35703 .23415 L F
0 .058 .623 r
.42913 .28732 m .43307 .28784 L .43922 .29865 L F
.42913 .28732 m .42302 .27587 L .43307 .28784 L F
.804 .855 .888 r
.61128 .38185 m .61651 .36888 L .62203 .37454 L F
.61128 .38185 m .60574 .37702 L .61651 .36888 L F
.667 .873 .976 r
.56269 .40266 m .56776 .3947 L .57345 .39807 L F
.56269 .40266 m .55696 .39903 L .56776 .3947 L F
.857 .836 .824 r
.29512 .3865 m .28821 .38192 L .29905 .37044 L F
.317 .575 .933 r
.15774 .34679 m .15999 .34069 L .16712 .34851 L F
.15774 .34679 m .1506 .33902 L .15999 .34069 L F
.577 .719 .939 r
.8186 .38319 m .82524 .3747 L .83004 .38144 L F
.8186 .38319 m .81377 .37648 L .82524 .3747 L F
.44 .642 .943 r
.14111 .33871 m .14341 .3312 L .1506 .33902 L F
.14111 .33871 m .1339 .33103 L .14341 .3312 L F
.601 .73 .935 r
.77483 .37634 m .78116 .36727 L .78612 .37398 L F
.77483 .37634 m .76984 .36959 L .78116 .36727 L F
.699 .731 .876 r
.65995 .36295 m .66542 .34992 L .67088 .35842 L F
.65995 .36295 m .65449 .35497 L .66542 .34992 L F
.21 .514 .913 r
.17421 .35629 m .17646 .35129 L .18355 .35901 L F
.17421 .35629 m .16712 .34851 L .17646 .35129 L F
.905 .812 .745 r
.32114 .34068 m .31435 .33582 L .32558 .3182 L F
.9 .823 .762 r
.31005 .35652 m .31435 .33582 L .32114 .34068 L F
.079 .28 .766 r
.40071 .24427 m .40459 .23947 L .41074 .25198 L F
.40071 .24427 m .39457 .23171 L .40459 .23947 L F
.794 .827 .877 r
.62203 .37454 m .6273 .36089 L .63281 .36745 L F
.62203 .37454 m .61651 .36888 L .6273 .36089 L F
.883 .764 .727 r
.34138 .27513 m .33483 .26752 L .34604 .24935 L F
.901 .781 .719 r
.33015 .2937 m .33483 .26752 L .34138 .27513 L F
.62 .767 .95 r
.25698 .40011 m .26019 .39123 L .26716 .39668 L F
.25698 .40011 m .25003 .39412 L .26019 .39123 L F
.606 .71 .918 r
.73108 .37006 m .73711 .36029 L .74226 .36754 L F
.73108 .37006 m .72589 .36264 L .73711 .36029 L F
.497 .533 .824 r
.37822 .21783 m .38228 .2054 L .38843 .21876 L F
.37822 .21783 m .37205 .20505 L .38228 .2054 L F
.637 .696 .887 r
.68726 .36297 m .69295 .35144 L .69832 .35989 L F
.68726 .36297 m .68187 .3546 L .69295 .35144 L F
.156 .484 .9 r
.19059 .36668 m .19291 .36228 L .19997 .36976 L F
.19059 .36668 m .18355 .35901 L .19291 .36228 L F
.587 .725 .939 r
.80237 .37848 m .8089 .36976 L .81377 .37648 L F
.80237 .37848 m .79747 .37178 L .8089 .36976 L F
.859 .741 .732 r
.34604 .24935 m .33958 .24029 L .3507 .22369 L F
.889 .762 .716 r
.33483 .26752 m .33958 .24029 L .34604 .24935 L F
.774 .796 .87 r
.63281 .36745 m .63812 .35339 L .64362 .36085 L F
.63281 .36745 m .6273 .36089 L .63812 .35339 L F
0 0 .489 r
.45518 .32197 m .44939 .31307 L .45556 .32247 L F
.44535 .30917 m .44939 .31307 L .45518 .32197 L F
0 0 .441 r
.44902 .31255 m .44318 .30345 L .44939 .31307 L F
.43922 .29865 m .44318 .30345 L .44902 .31255 L F
0 0 .393 r
.44283 .30291 m .43695 .29358 L .44318 .30345 L F
.43307 .28784 m .43695 .29358 L .44283 .30291 L F
0 .028 .599 r
.42302 .27587 m .4269 .27672 L .43307 .28784 L F
0 0 .393 r
.43307 .28784 m .4269 .27672 L .43529 .29081 L F
.43656 .293 m .43529 .29081 L .43695 .29358 L F
.43307 .28784 m .43529 .29081 L .43656 .293 L F
0 .028 .599 r
.42302 .27587 m .41689 .2641 L .4269 .27672 L F
0 0 .575 r
.42645 .27615 m .42071 .26527 L .4269 .27672 L F
.41689 .2641 m .42071 .26527 L .42645 .27615 L F
0 0 .551 r
.42027 .26468 m .4145 .25345 L .42071 .26527 L F
.41074 .25198 m .4145 .25345 L .42027 .26468 L F
0 0 .528 r
.41407 .25284 m .40827 .24125 L .4145 .25345 L F
.40459 .23947 m .40827 .24125 L .41407 .25284 L F
0 0 .504 r
.40785 .24062 m .40204 .22864 L .40827 .24125 L F
.39842 .22656 m .40204 .22864 L .40785 .24062 L F
0 0 .482 r
.40162 .22798 m .39579 .21557 L .40204 .22864 L F
.39225 .2132 m .39579 .21557 L .40162 .22798 L F
0 0 .459 r
.39539 .21489 m .38954 .20202 L .39579 .21557 L F
.38608 .19936 m .38954 .20202 L .39539 .21489 L F
0 0 .438 r
.38914 .20132 m .38329 .18794 L .38954 .20202 L F
.37991 .18502 m .38329 .18794 L .38914 .20132 L F
0 0 .417 r
.37375 .17012 m .37705 .17331 L .38329 .18794 L F
.817 .458 0 r
.38329 .18794 m .37705 .17331 L .37742 .17452 L F
.111 .278 .754 r
.38228 .2054 m .38608 .19936 L .39225 .2132 L F
.38228 .2054 m .37613 .19158 L .38608 .19936 L F
.126 .279 .751 r
.37613 .19158 m .37991 .18502 L .38608 .19936 L F
0 0 .459 r
.38608 .19936 m .37991 .18502 L .38954 .20202 L F
0 0 .438 r
.37991 .18502 m .37375 .17012 L .38329 .18794 L F
.817 .458 0 r
.38329 .18794 m .37742 .17452 L .38618 .20329 L F
.796 .432 0 r
.38954 .20202 m .38329 .18794 L .38367 .18909 L F
.098 .277 .758 r
.38843 .21876 m .39225 .2132 L .39842 .22656 L F
.38843 .21876 m .38228 .2054 L .39225 .2132 L F
0 0 .482 r
.39225 .2132 m .38608 .19936 L .39579 .21557 L F
.796 .432 0 r
.38954 .20202 m .38367 .18909 L .39259 .21592 L F
.774 .404 0 r
.39579 .21557 m .38954 .20202 L .38993 .2031 L F
.088 .278 .762 r
.39457 .23171 m .39842 .22656 L .40459 .23947 L F
0 0 .528 r
.40459 .23947 m .39842 .22656 L .40827 .24125 L F
0 0 .504 r
.39842 .22656 m .39225 .2132 L .40204 .22864 L F
.774 .404 0 r
.39579 .21557 m .38993 .2031 L .39899 .22811 L F
.748 .374 0 r
.40204 .22864 m .39579 .21557 L .3962 .2166 L F
.40204 .22864 m .3962 .2166 L .40537 .23989 L F
.72 .341 0 r
.40827 .24125 m .40204 .22864 L .40245 .22961 L F
0 0 .551 r
.41074 .25198 m .40459 .23947 L .4145 .25345 L F
.72 .341 0 r
.40827 .24125 m .40245 .22961 L .41173 .25128 L F
.688 .305 0 r
.4145 .25345 m .40827 .24125 L .4087 .24218 L F
0 0 .575 r
.41689 .2641 m .41074 .25198 L .42071 .26527 L F
.688 .305 0 r
.4145 .25345 m .4087 .24218 L .41807 .26233 L F
.652 .266 0 r
.42071 .26527 m .4145 .25345 L .41494 .25433 L F
.42071 .26527 m .41494 .25433 L .42439 .27304 L F
0 0 .346 r
.4269 .27672 m .43068 .28346 L .43695 .29358 L F
.4269 .27672 m .42071 .26527 L .43068 .28346 L F
.652 .266 0 r
.42274 .26897 m .42439 .27304 L .43068 .28346 L F
.42071 .26527 m .42117 .26623 L .42274 .26897 L F
.42117 .26623 m .42439 .27304 L .42274 .26897 L F
.765 .351 0 r
.43695 .29358 m .43068 .28346 L .43103 .2842 L F
0 0 .441 r
.43922 .29865 m .43307 .28784 L .44318 .30345 L F
.765 .351 0 r
.43695 .29358 m .43103 .2842 L .44075 .30534 L F
.725 .304 0 r
.44318 .30345 m .43695 .29358 L .43731 .29429 L F
0 0 .538 r
.45145 .31943 m .44535 .30917 L .45556 .32247 L F
0 0 .489 r
.44535 .30917 m .43922 .29865 L .44939 .31307 L F
.725 .304 0 r
.44318 .30345 m .43731 .29429 L .4471 .3135 L F
.677 .252 0 r
.44939 .31307 m .44318 .30345 L .44356 .30412 L F
0 0 .538 r
.45145 .31943 m .45556 .32247 L .4613 .33117 L F
.677 .252 0 r
.44939 .31307 m .44356 .30412 L .45341 .32154 L F
.621 .194 0 r
.45556 .32247 m .44939 .31307 L .44979 .31371 L F
.45556 .32247 m .44979 .31371 L .45968 .32945 L F
0 0 .538 r
.4613 .33117 m .45556 .32247 L .4617 .33165 L F
.745 .9 .947 r
.57345 .39807 m .57856 .38856 L .58421 .39203 L F
.57345 .39807 m .56776 .3947 L .57856 .38856 L F
.722 .656 .784 r
.36153 .2115 m .36588 .19188 L .37205 .20505 L F
.36153 .2115 m .35528 .19943 L .36588 .19188 L F
.818 .71 .746 r
.3507 .22369 m .35528 .19943 L .36153 .2115 L F
.181 .507 .911 r
.20698 .37719 m .20943 .37275 L .21647 .37985 L F
.20698 .37719 m .19997 .36976 L .20943 .37275 L F
.602 .725 .931 r
.75857 .37203 m .76481 .36279 L .76984 .36959 L F
.75857 .37203 m .7535 .36512 L .76481 .36279 L F
.455 .683 .963 r
.24011 .39483 m .24303 .38809 L .25003 .39412 L F
.24011 .39483 m .23314 .38828 L .24303 .38809 L F
0 .191 .706 r
.4964 .37471 m .50098 .37584 L .507 .3818 L F
.4964 .37471 m .49038 .36741 L .50098 .37584 L F
.606 .695 .906 r
.71473 .36515 m .72064 .35489 L .72589 .36264 L F
.71473 .36515 m .70944 .35722 L .72064 .35489 L F
.29 .582 .942 r
.22346 .3869 m .22612 .38167 L .23314 .38828 L F
.22346 .3869 m .21647 .37985 L .22612 .38167 L F
.669 .706 .875 r
.67088 .35842 m .67642 .34577 L .68187 .3546 L F
.67088 .35842 m .66542 .34992 L .67642 .34577 L F
.504 .798 .998 r
.54618 .40134 m .55117 .39566 L .55696 .39903 L F
.54618 .40134 m .54035 .39733 L .55117 .39566 L F
.818 .71 .746 r
.3507 .22369 m .34434 .21299 L .35528 .19943 L F
.867 .74 .72 r
.33958 .24029 m .34434 .21299 L .3507 .22369 L F
.906 .797 .729 r
.32558 .3182 m .31883 .3127 L .33015 .2937 L F
.908 .81 .739 r
.31435 .33582 m .31883 .3127 L .32558 .3182 L F
.9 .823 .762 r
.31005 .35652 m .30318 .35201 L .31435 .33582 L F
.884 .832 .79 r
.29905 .37044 m .30318 .35201 L .31005 .35652 L F
0 0 .496 r
.47804 .35231 m .47209 .34494 L .47823 .35252 L F
.46781 .34064 m .47209 .34494 L .47804 .35231 L F
.46781 .34064 m .4617 .33165 L .47171 .34445 L F
.472 .34486 m .47171 .34445 L .47209 .34494 L F
.46781 .34064 m .47171 .34445 L .472 .34486 L F
0 0 .425 r
.4617 .33165 m .4659 .33725 L .47209 .34494 L F
.4617 .33165 m .45556 .32247 L .4659 .33725 L F
.621 .194 0 r
.45652 .32384 m .45968 .32945 L .4659 .33725 L F
.45556 .32247 m .45577 .32281 L .45652 .32384 L F
.45577 .32281 m .45968 .32945 L .45652 .32384 L F
.634 .171 0 r
.47209 .34494 m .4659 .33725 L .46609 .33751 L F
0 .012 .566 r
.47388 .34945 m .47823 .35252 L .48413 .35981 L F
.47388 .34945 m .46781 .34064 L .47823 .35252 L F
.634 .171 0 r
.47209 .34494 m .46609 .33751 L .47641 .35216 L F
.554 .089 0 r
.47823 .35252 m .47209 .34494 L .47228 .34518 L F
.47823 .35252 m .47228 .34518 L .48263 .35804 L F
0 .012 .566 r
.48413 .35981 m .47823 .35252 L .48432 .36001 L F
.747 .763 .866 r
.64362 .36085 m .64898 .34669 L .65449 .35497 L F
.64362 .36085 m .63812 .35339 L .64898 .34669 L F
.088 .278 .762 r
.39457 .23171 m .38843 .21876 L .39842 .22656 L F
.522 .54 .816 r
.37205 .20505 m .37613 .19158 L .38228 .2054 L F
.37205 .20505 m .36588 .19188 L .37613 .19158 L F
.794 .903 .918 r
.58421 .39203 m .58936 .38098 L .59498 .38488 L F
.58421 .39203 m .57856 .38856 L .58936 .38098 L F
.728 .811 .917 r
.26716 .39668 m .2706 .38571 L .27757 .39068 L F
.26716 .39668 m .26019 .39123 L .2706 .38571 L F
.594 .729 .938 r
.78612 .37398 m .79255 .36508 L .79747 .37178 L F
.78612 .37398 m .78116 .36727 L .79255 .36508 L F
.565 .713 .941 r
.83004 .38144 m .8368 .37319 L .84157 .37994 L F
.83004 .38144 m .82524 .3747 L .8368 .37319 L F
.616 .685 .892 r
.69832 .35989 m .7041 .34887 L .70944 .35722 L F
.69832 .35989 m .69295 .35144 L .7041 .34887 L F
.599 .713 .924 r
.74226 .36754 m .74839 .35807 L .7535 .36512 L F
.74226 .36754 m .73711 .36029 L .74839 .35807 L F
0 .388 .836 r
.51297 .38778 m .51772 .38708 L .52368 .3918 L F
.51297 .38778 m .507 .3818 L .51772 .38708 L F
.241 .625 .958 r
.52959 .39663 m .53448 .3935 L .54035 .39733 L F
.52959 .39663 m .52368 .3918 L .53448 .3935 L F
.82 .889 .893 r
.59498 .38488 m .60016 .37241 L .60574 .37702 L F
.59498 .38488 m .58936 .38098 L .60016 .37241 L F
.901 .781 .719 r
.33015 .2937 m .32347 .28726 L .33483 .26752 L F
.91 .796 .722 r
.31883 .3127 m .32347 .28726 L .33015 .2937 L F
.32 .577 .934 r
.1506 .33902 m .15281 .3328 L .15999 .34069 L F
.1506 .33902 m .14341 .3312 L .15281 .3328 L F
.74 .659 .77 r
.35528 .19943 m .3597 .17829 L .36588 .19188 L F
.35528 .19943 m .34902 .18702 L .3597 .17829 L F
.829 .709 .733 r
.34434 .21299 m .34902 .18702 L .35528 .19943 L F
.884 .832 .79 r
.29905 .37044 m .29213 .36601 L .30318 .35201 L F
.855 .837 .827 r
.28821 .38192 m .29213 .36601 L .29905 .37044 L F
.714 .73 .863 r
.65449 .35497 m .65991 .341 L .66542 .34992 L F
.65449 .35497 m .64898 .34669 L .65991 .341 L F
.202 .509 .911 r
.16712 .34851 m .16932 .34352 L .17646 .35129 L F
.16712 .34851 m .15999 .34069 L .16932 .34352 L F
.577 .72 .94 r
.81377 .37648 m .82041 .36796 L .82524 .3747 L F
.81377 .37648 m .8089 .36976 L .82041 .36796 L F
.805 .832 .872 r
.27757 .39068 m .28125 .37731 L .28821 .38192 L F
.27757 .39068 m .2706 .38571 L .28125 .37731 L F
.64 .686 .877 r
.68187 .3546 m .68752 .3425 L .69295 .35144 L F
.68187 .3546 m .67642 .34577 L .68752 .3425 L F
.596 .728 .936 r
.76984 .36959 m .77617 .36055 L .78116 .36727 L F
.76984 .36959 m .76481 .36279 L .77617 .36055 L F
.826 .865 .875 r
.60574 .37702 m .61095 .36336 L .61651 .36888 L F
.60574 .37702 m .60016 .37241 L .61095 .36336 L F
.595 .696 .913 r
.72589 .36264 m .7319 .3528 L .73711 .36029 L F
.72589 .36264 m .72064 .35489 L .7319 .3528 L F
.889 .762 .716 r
.33483 .26752 m .32824 .25984 L .33958 .24029 L F
.906 .779 .71 r
.32347 .28726 m .32824 .25984 L .33483 .26752 L F
.855 .837 .827 r
.28821 .38192 m .28125 .37731 L .29213 .36601 L F
.547 .547 .806 r
.36588 .19188 m .36998 .17728 L .37613 .19158 L F
.36588 .19188 m .3597 .17829 L .36998 .17728 L F
.133 .469 .893 r
.18355 .35901 m .1858 .35475 L .19291 .36228 L F
.18355 .35901 m .17646 .35129 L .1858 .35475 L F
.643 .877 .984 r
.55696 .39903 m .56201 .39164 L .56776 .3947 L F
.55696 .39903 m .55117 .39566 L .56201 .39164 L F
.867 .74 .72 r
.33958 .24029 m .33309 .23109 L .34434 .21299 L F
.895 .76 .705 r
.32824 .25984 m .33309 .23109 L .33958 .24029 L F
.59 .757 .958 r
.25003 .39412 m .25317 .38573 L .26019 .39123 L F
.25003 .39412 m .24303 .38809 L .25317 .38573 L F
.817 .835 .863 r
.61651 .36888 m .62175 .35431 L .6273 .36089 L F
.61651 .36888 m .61095 .36336 L .62175 .35431 L F
.908 .81 .739 r
.31435 .33582 m .3075 .33097 L .31883 .3127 L F
.902 .823 .759 r
.30318 .35201 m .3075 .33097 L .31435 .33582 L F
.829 .709 .733 r
.34434 .21299 m .33796 .20205 L .34902 .18702 L F
.875 .738 .708 r
.33309 .23109 m .33796 .20205 L .34434 .21299 L F
.143 .483 .9 r
.19997 .36976 m .20234 .3656 L .20943 .37275 L F
.19997 .36976 m .19291 .36228 L .20234 .3656 L F
.586 .726 .94 r
.79747 .37178 m .80401 .36306 L .8089 .36976 L F
.79747 .37178 m .79255 .36508 L .80401 .36306 L F
.598 .68 .898 r
.70944 .35722 m .71533 .34677 L .72064 .35489 L F
.70944 .35722 m .7041 .34887 L .71533 .34677 L F
.797 .801 .855 r
.6273 .36089 m .63257 .34576 L .63812 .35339 L F
.6273 .36089 m .62175 .35431 L .63257 .34576 L F
.679 .7 .863 r
.66542 .34992 m .67092 .33642 L .67642 .34577 L F
.66542 .34992 m .65991 .341 L .67092 .33642 L F
.593 .718 .931 r
.7535 .36512 m .75974 .35593 L .76481 .36279 L F
.7535 .36512 m .74839 .35807 L .75974 .35593 L F
0 .095 .623 r
.49038 .36741 m .49491 .36988 L .50098 .37584 L F
.49038 .36741 m .48432 .36001 L .49491 .36988 L F
.411 .663 .963 r
.23314 .38828 m .23598 .382 L .24303 .38809 L F
.23314 .38828 m .22612 .38167 L .23598 .382 L F
.242 .556 .933 r
.21647 .37985 m .21905 .37501 L .22612 .38167 L F
.21647 .37985 m .20943 .37275 L .21905 .37501 L F
.755 .661 .757 r
.34902 .18702 m .35352 .16424 L .3597 .17829 L F
.34902 .18702 m .34276 .17425 L .35352 .16424 L F
.839 .709 .72 r
.33796 .20205 m .34276 .17425 L .34902 .18702 L F
.767 .765 .85 r
.63812 .35339 m .64343 .33808 L .64898 .34669 L F
.63812 .35339 m .63257 .34576 L .64343 .33808 L F
.57 .553 .796 r
.3597 .17829 m .36385 .16246 L .36998 .17728 L F
.3597 .17829 m .35352 .16424 L .36385 .16246 L F
.612 .67 .882 r
.69295 .35144 m .6987 .34002 L .7041 .34887 L F
.69295 .35144 m .68752 .3425 L .6987 .34002 L F
.744 .912 .95 r
.56776 .3947 m .57287 .38543 L .57856 .38856 L F
.56776 .3947 m .56201 .39164 L .57287 .38543 L F
.565 .714 .942 r
.82524 .3747 m .832 .36641 L .8368 .37319 L F
.82524 .3747 m .82041 .36796 L .832 .36641 L F
.59 .729 .94 r
.78116 .36727 m .7876 .35842 L .79255 .36508 L F
.78116 .36727 m .77617 .36055 L .7876 .35842 L F
.91 .796 .722 r
.31883 .3127 m .31202 .30721 L .32347 .28726 L F
.911 .81 .734 r
.3075 .33097 m .31202 .30721 L .31883 .3127 L F
.587 .701 .922 r
.73711 .36029 m .74324 .35087 L .74839 .35807 L F
.73711 .36029 m .7319 .3528 L .74324 .35087 L F
.431 .773 .997 r
.54035 .39733 m .54533 .39258 L .55117 .39566 L F
.54035 .39733 m .53448 .3935 L .54533 .39258 L F
.71 .809 .927 r
.26019 .39123 m .26356 .3807 L .2706 .38571 L F
.26019 .39123 m .25317 .38573 L .26356 .3807 L F
.902 .823 .759 r
.30318 .35201 m .29625 .3475 L .3075 .33097 L F
.885 .833 .79 r
.29213 .36601 m .29625 .3475 L .30318 .35201 L F
.731 .729 .848 r
.64898 .34669 m .65435 .33159 L .65991 .341 L F
.64898 .34669 m .64343 .33808 L .65435 .33159 L F
.643 .675 .865 r
.67642 .34577 m .68203 .33298 L .68752 .3425 L F
.67642 .34577 m .67092 .33642 L .68203 .33298 L F
.194 .504 .909 r
.15999 .34069 m .16214 .33569 L .16932 .34352 L F
.15999 .34069 m .15281 .3328 L .16214 .33569 L F
0 .282 .756 r
.507 .3818 m .51171 .38248 L .51772 .38708 L F
.507 .3818 m .50098 .37584 L .51171 .38248 L F
.806 .916 .913 r
.57856 .38856 m .58371 .37742 L .58936 .38098 L F
.57856 .38856 m .57287 .38543 L .58371 .37742 L F
.875 .738 .708 r
.33309 .23109 m .32657 .22173 L .33796 .20205 L F
.839 .709 .72 r
.33796 .20205 m .33157 .19085 L .34276 .17425 L F
.882 .736 .696 r
.32657 .22173 m .33157 .19085 L .33796 .20205 L F
.906 .779 .71 r
.32347 .28726 m .31673 .2808 L .32824 .25984 L F
.914 .794 .714 r
.31202 .30721 m .31673 .2808 L .32347 .28726 L F
.593 .559 .785 r
.35352 .16424 m .35772 .14708 L .36385 .16246 L F
.35352 .16424 m .34736 .14971 L .35772 .14708 L F
.77 .662 .743 r
.34276 .17425 m .34736 .14971 L .35352 .16424 L F
.34276 .17425 m .33649 .16109 L .34736 .14971 L F
.848 .708 .707 r
.33157 .19085 m .33649 .16109 L .34276 .17425 L F
.576 .722 .942 r
.8089 .36976 m .81555 .36124 L .82041 .36796 L F
.8089 .36976 m .80401 .36306 L .81555 .36124 L F
.126 .279 .751 r
.37613 .19158 m .36998 .17728 L .37991 .18502 L F
.582 .68 .908 r
.72064 .35489 m .72665 .34501 L .7319 .3528 L F
.72064 .35489 m .71533 .34677 L .72665 .34501 L F
.895 .76 .705 r
.32824 .25984 m .3216 .25208 L .33309 .23109 L F
.901 .758 .695 r
.3216 .25208 m .32657 .22173 L .33309 .23109 L F
.112 .547 .916 r
.52368 .3918 m .52854 .3899 L .53448 .3935 L F
.52368 .3918 m .51772 .38708 L .52854 .3899 L F
.911 .777 .701 r
.31673 .2808 m .3216 .25208 L .32824 .25984 L F
.588 .724 .937 r
.76481 .36279 m .77114 .35386 L .77617 .36055 L F
.76481 .36279 m .75974 .35593 L .77114 .35386 L F
.109 .454 .885 r
.17646 .35129 m .17864 .34717 L .1858 .35475 L F
.17646 .35129 m .16932 .34352 L .17864 .34717 L F
.838 .901 .882 r
.58936 .38098 m .59454 .36807 L .60016 .37241 L F
.58936 .38098 m .58371 .37742 L .59454 .36807 L F
.796 .833 .88 r
.2706 .38571 m .27423 .37268 L .28125 .37731 L F
.2706 .38571 m .26356 .3807 L .27423 .37268 L F
.885 .833 .79 r
.29213 .36601 m .28513 .36156 L .29625 .3475 L F
.852 .838 .831 r
.28125 .37731 m .28513 .36156 L .29213 .36601 L F
.691 .695 .849 r
.65991 .341 m .66536 .32647 L .67092 .33642 L F
.65991 .341 m .65435 .33159 L .66536 .32647 L F
.587 .662 .89 r
.7041 .34887 m .70997 .3382 L .71533 .34677 L F
.7041 .34887 m .6987 .34002 L .70997 .3382 L F
.848 .875 .86 r
.60016 .37241 m .60535 .35798 L .61095 .36336 L F
.60016 .37241 m .59454 .36807 L .60535 .35798 L F
.556 .745 .965 r
.24303 .38809 m .24608 .38019 L .25317 .38573 L F
.24303 .38809 m .23598 .382 L .24608 .38019 L F
.103 .458 .887 r
.19291 .36228 m .1952 .35839 L .20234 .3656 L F
.19291 .36228 m .1858 .35475 L .1952 .35839 L F
.852 .838 .831 r
.28125 .37731 m .27423 .37268 L .28513 .36156 L F
.841 .842 .846 r
.61095 .36336 m .61615 .34774 L .62175 .35431 L F
.61095 .36336 m .60535 .35798 L .61615 .34774 L F
.583 .728 .943 r
.79255 .36508 m .79909 .35643 L .80401 .36306 L F
.79255 .36508 m .7876 .35842 L .79909 .35643 L F
0 0 .533 r
.48432 .36001 m .4888 .36395 L .49491 .36988 L F
.48432 .36001 m .47823 .35252 L .4888 .36395 L F
.58 .709 .931 r
.74839 .35807 m .75463 .34901 L .75974 .35593 L F
.74839 .35807 m .74324 .35087 L .75463 .34901 L F
.142 .281 .747 r
.36998 .17728 m .37375 .17012 L .37991 .18502 L F
.36998 .17728 m .36385 .16246 L .37375 .17012 L F
.82 .805 .837 r
.62175 .35431 m .62697 .33794 L .63257 .34576 L F
.62175 .35431 m .61615 .34774 L .62697 .33794 L F
.192 .526 .92 r
.20943 .37275 m .21192 .36831 L .21905 .37501 L F
.20943 .37275 m .20234 .3656 L .21192 .36831 L F
.608 .655 .871 r
.68752 .3425 m .69324 .33059 L .6987 .34002 L F
.68752 .3425 m .68203 .33298 L .69324 .33059 L F
.911 .81 .734 r
.3075 .33097 m .30059 .32613 L .31202 .30721 L F
.904 .823 .757 r
.29625 .3475 m .30059 .32613 L .3075 .33097 L F
.362 .638 .96 r
.22612 .38167 m .22887 .37587 L .23598 .382 L F
.22612 .38167 m .21905 .37501 L .22887 .37587 L F
.609 .878 .991 r
.55117 .39566 m .55622 .38893 L .56201 .39164 L F
.55117 .39566 m .54533 .39258 L .55622 .38893 L F
.848 .708 .707 r
.33157 .19085 m .32515 .17936 L .33649 .16109 L F
.789 .767 .833 r
.63257 .34576 m .63783 .3291 L .64343 .33808 L F
.63257 .34576 m .62697 .33794 L .63783 .3291 L F
.882 .736 .696 r
.32657 .22173 m .32001 .21219 L .33157 .19085 L F
.888 .734 .685 r
.32001 .21219 m .32515 .17936 L .33157 .19085 L F
.648 .664 .852 r
.67092 .33642 m .67648 .32278 L .68203 .33298 L F
.67092 .33642 m .66536 .32647 L .67648 .32278 L F
.57 .685 .918 r
.7319 .3528 m .73803 .34347 L .74324 .35087 L F
.7319 .3528 m .72665 .34501 L .73803 .34347 L F
.564 .717 .944 r
.82041 .36796 m .82717 .35966 L .832 .36641 L F
.82041 .36796 m .81555 .36124 L .82717 .35966 L F
.749 .727 .832 r
.64343 .33808 m .64874 .32164 L .65435 .33159 L F
.64343 .33808 m .63783 .3291 L .64874 .32164 L F
.583 .728 .943 r
.77617 .36055 m .78261 .35184 L .7876 .35842 L F
.77617 .36055 m .77114 .35386 L .78261 .35184 L F
.16 .283 .743 r
.36385 .16246 m .3676 .15463 L .37375 .17012 L F
.36385 .16246 m .35772 .14708 L .3676 .15463 L F
.901 .758 .695 r
.3216 .25208 m .31491 .24424 L .32657 .22173 L F
.906 .756 .685 r
.31491 .24424 m .32001 .21219 L .32657 .22173 L F
.914 .794 .714 r
.31202 .30721 m .30516 .30173 L .31673 .2808 L F
.914 .809 .728 r
.30059 .32613 m .30516 .30173 L .31202 .30721 L F
.689 .805 .937 r
.25317 .38573 m .25647 .37567 L .26356 .3807 L F
.25317 .38573 m .24608 .38019 L .25647 .37567 L F
.565 .66 .901 r
.71533 .34677 m .72134 .33687 L .72665 .34501 L F
.71533 .34677 m .70997 .3382 L .72134 .33687 L F
.739 .925 .953 r
.56201 .39164 m .56712 .3827 L .57287 .38543 L F
.56201 .39164 m .55622 .38893 L .56712 .3827 L F
0 .168 .658 r
.50098 .37584 m .50564 .37802 L .51171 .38248 L F
.50098 .37584 m .49491 .36988 L .50564 .37802 L F
.704 .689 .833 r
.65435 .33159 m .65975 .31583 L .66536 .32647 L F
.65435 .33159 m .64874 .32164 L .65975 .31583 L F
.085 .439 .877 r
.16932 .34352 m .17143 .33953 L .17864 .34717 L F
.16932 .34352 m .16214 .33569 L .17143 .33953 L F
.335 .731 .983 r
.53448 .3935 m .53944 .38982 L .54533 .39258 L F
.53448 .3935 m .52854 .3899 L .53944 .38982 L F
.911 .777 .701 r
.31673 .2808 m .30994 .27432 L .3216 .25208 L F
.915 .775 .692 r
.30994 .27432 m .31491 .24424 L .3216 .25208 L F
.904 .823 .757 r
.29625 .3475 m .28925 .34301 L .30059 .32613 L F
.885 .834 .791 r
.28513 .36156 m .28925 .34301 L .29625 .3475 L F
.574 .726 .946 r
.80401 .36306 m .81066 .3546 L .81555 .36124 L F
.80401 .36306 m .79909 .35643 L .81066 .3546 L F
.918 .793 .707 r
.30516 .30173 m .30994 .27432 L .31673 .2808 L F
.575 .717 .939 r
.75974 .35593 m .76609 .3472 L .77114 .35386 L F
.75974 .35593 m .75463 .34901 L .76609 .3472 L F
.575 .642 .879 r
.6987 .34002 m .70455 .3291 L .70997 .3382 L F
.6987 .34002 m .69324 .33059 L .70455 .3291 L F
0 .447 .847 r
.51772 .38708 m .52255 .38654 L .52854 .3899 L F
.51772 .38708 m .51171 .38248 L .52255 .38654 L F
.604 .638 .858 r
.68203 .33298 m .68771 .32048 L .69324 .33059 L F
.68203 .33298 m .67648 .32278 L .68771 .32048 L F
.063 .432 .872 r
.1858 .35475 m .18801 .35113 L .1952 .35839 L F
.1858 .35475 m .17864 .34717 L .18801 .35113 L F
.888 .734 .685 r
.32001 .21219 m .31342 .20249 L .32515 .17936 L F
.817 .93 .907 r
.57287 .38543 m .57801 .37422 L .58371 .37742 L F
.57287 .38543 m .56712 .3827 L .57801 .37422 L F
.787 .834 .888 r
.26356 .3807 m .26714 .36804 L .27423 .37268 L F
.26356 .3807 m .25647 .37567 L .26714 .36804 L F
.518 .73 .97 r
.23598 .382 m .23894 .37462 L .24608 .38019 L F
.23598 .382 m .22887 .37587 L .23894 .37462 L F
.554 .089 0 r
.47823 .35252 m .48263 .35804 L .4888 .36395 L F
.561 .695 .93 r
.74324 .35087 m .74949 .34204 L .75463 .34901 L F
.74324 .35087 m .73803 .34347 L .74949 .34204 L F
.885 .834 .791 r
.28513 .36156 m .27808 .35712 L .28925 .34301 L F
.849 .84 .836 r
.27423 .37268 m .27808 .35712 L .28513 .36156 L F
.577 .73 .947 r
.7876 .35842 m .79415 .34992 L .79909 .35643 L F
.7876 .35842 m .78261 .35184 L .79415 .34992 L F
.14 .494 .905 r
.20234 .3656 m .20474 .36155 L .21192 .36831 L F
.20234 .3656 m .1952 .35839 L .20474 .36155 L F
.654 .653 .837 r
.66536 .32647 m .67087 .31182 L .67648 .32278 L F
.66536 .32647 m .65975 .31583 L .67087 .31182 L F
.857 .913 .87 r
.58371 .37742 m .58887 .36403 L .59454 .36807 L F
.58371 .37742 m .57801 .37422 L .58887 .36403 L F
.843 .809 .817 r
.61615 .34774 m .62134 .32991 L .62697 .33794 L F
.61615 .34774 m .61052 .34116 L .62134 .32991 L F
.863 .848 .826 r
.60535 .35798 m .61052 .34116 L .61615 .34774 L F
.81 .767 .813 r
.62697 .33794 m .63218 .3197 L .63783 .3291 L F
.62697 .33794 m .62134 .32991 L .63218 .3197 L F
.863 .848 .826 r
.60535 .35798 m .5997 .35277 L .61052 .34116 L F
.87 .883 .843 r
.59454 .36807 m .5997 .35277 L .60535 .35798 L F
.309 .61 .954 r
.21905 .37501 m .2217 .3697 L .22887 .37587 L F
.21905 .37501 m .21192 .36831 L .2217 .3697 L F
.87 .883 .843 r
.59454 .36807 m .58887 .36403 L .5997 .35277 L F
.849 .84 .836 r
.27423 .37268 m .26714 .36804 L .27808 .35712 L F
.768 .725 .813 r
.63783 .3291 m .64308 .31106 L .64874 .32164 L F
.63783 .3291 m .63218 .3197 L .64308 .31106 L F
.548 .665 .914 r
.72665 .34501 m .73278 .33586 L .73803 .34347 L F
.72665 .34501 m .72134 .33687 L .73278 .33586 L F
.914 .809 .728 r
.30059 .32613 m .29361 .32132 L .30516 .30173 L F
.906 .823 .754 r
.28925 .34301 m .29361 .32132 L .30059 .32613 L F
.906 .756 .685 r
.31491 .24424 m .30818 .23632 L .32001 .21219 L F
.91 .754 .675 r
.30818 .23632 m .31342 .20249 L .32001 .21219 L F
.563 .721 .947 r
.81555 .36124 m .82231 .35298 L .82717 .35966 L F
.81555 .36124 m .81066 .3546 L .82231 .35298 L F
.571 .725 .947 r
.77114 .35386 m .77761 .34539 L .78261 .35184 L F
.77114 .35386 m .76609 .3472 L .77761 .34539 L F
.717 .683 .815 r
.64874 .32164 m .65407 .30441 L .65975 .31583 L F
.64874 .32164 m .64308 .31106 L .65407 .30441 L F
.562 .873 .994 r
.54533 .39258 m .55037 .38664 L .55622 .38893 L F
.54533 .39258 m .53944 .38982 L .55037 .38664 L F
.545 .636 .892 r
.70997 .3382 m .71597 .32832 L .72134 .33687 L F
.70997 .3382 m .70455 .3291 L .71597 .32832 L F
.561 .619 .868 r
.69324 .33059 m .69906 .31939 L .70455 .3291 L F
.69324 .33059 m .68771 .32048 L .69906 .31939 L F
.677 .252 0 r
.44939 .31307 m .45341 .32154 L .45968 .32945 L F
.601 .621 .843 r
.67648 .32278 m .68212 .30958 L .68771 .32048 L F
.67648 .32278 m .67087 .31182 L .68212 .30958 L F
.915 .775 .692 r
.30994 .27432 m .30309 .26782 L .31491 .24424 L F
.919 .773 .684 r
.30309 .26782 m .30818 .23632 L .31491 .24424 L F
.918 .793 .707 r
.30516 .30173 m .29823 .29626 L .30994 .27432 L F
.917 .808 .723 r
.29361 .32132 m .29823 .29626 L .30516 .30173 L F
.666 .8 .947 r
.24608 .38019 m .24931 .37062 L .25647 .37567 L F
.24608 .38019 m .23894 .37462 L .24931 .37062 L F
.57 .73 .95 r
.79909 .35643 m .80575 .3481 L .81066 .3546 L F
.79909 .35643 m .79415 .34992 L .80575 .3481 L F
.556 .708 .942 r
.75463 .34901 m .76101 .3406 L .76609 .3472 L F
.75463 .34901 m .74949 .34204 L .76101 .3406 L F
0 .052 .547 r
.49491 .36988 m .49952 .37372 L .50564 .37802 L F
.49491 .36988 m .4888 .36395 L .49952 .37372 L F
.921 .791 .7 r
.29823 .29626 m .30309 .26782 L .30994 .27432 L F
.66 .641 .82 r
.65975 .31583 m .66519 .29997 L .67087 .31182 L F
.65975 .31583 m .65407 .30441 L .66519 .29997 L F
.023 .405 .856 r
.17864 .34717 m .18076 .34382 L .18801 .35113 L F
.17864 .34717 m .17143 .33953 L .18076 .34382 L F
.906 .823 .754 r
.28925 .34301 m .28218 .33855 L .29361 .32132 L F
.885 .835 .791 r
.27808 .35712 m .28218 .33855 L .28925 .34301 L F
.634 .171 0 r
.47209 .34494 m .47641 .35216 L .48263 .35804 L F
.211 .666 .947 r
.52854 .3899 m .53348 .38743 L .53944 .38982 L F
.52854 .3899 m .52255 .38654 L .53348 .38743 L F
.73 .938 .955 r
.55622 .38893 m .56132 .38041 L .56712 .3827 L F
.55622 .38893 m .55037 .38664 L .56132 .38041 L F
.688 .305 0 r
.4145 .25345 m .41807 .26233 L .42439 .27304 L F
.786 .722 .793 r
.63218 .3197 m .63737 .29978 L .64308 .31106 L F
.63218 .3197 m .62649 .30982 L .63737 .29978 L F
.831 .767 .792 r
.62134 .32991 m .62649 .30982 L .63218 .3197 L F
.535 .677 .929 r
.73803 .34347 m .74431 .33499 L .74949 .34204 L F
.73803 .34347 m .73278 .33586 L .74431 .33499 L F
0 0 .417 r
.37375 .17012 m .3676 .15463 L .37705 .17331 L F
.831 .767 .792 r
.62134 .32991 m .61566 .32166 L .62649 .30982 L F
.864 .81 .795 r
.61052 .34116 m .61566 .32166 L .62134 .32991 L F
.086 .459 .886 r
.1952 .35839 m .1975 .35475 L .20474 .36155 L F
.1952 .35839 m .18801 .35113 L .1975 .35475 L F
.474 .712 .974 r
.22887 .37587 m .23174 .36901 L .23894 .37462 L F
.22887 .37587 m .2217 .3697 L .23174 .36901 L F
0 .325 .748 r
.51171 .38248 m .51651 .38346 L .52255 .38654 L F
.51171 .38248 m .50564 .37802 L .51651 .38346 L F
.567 .732 .953 r
.78261 .35184 m .78919 .34359 L .79415 .34992 L F
.78261 .35184 m .77761 .34539 L .78919 .34359 L F
.732 .676 .796 r
.64308 .31106 m .64834 .29209 L .65407 .30441 L F
.64308 .31106 m .63737 .29978 L .64834 .29209 L F
.91 .754 .675 r
.30818 .23632 m .3014 .22831 L .31342 .20249 L F
.864 .81 .795 r
.61052 .34116 m .60485 .33458 L .61566 .32166 L F
.885 .852 .805 r
.5997 .35277 m .60485 .33458 L .61052 .34116 L F
.776 .834 .897 r
.25647 .37567 m .25998 .3634 L .26714 .36804 L F
.25647 .37567 m .24931 .37062 L .25998 .3634 L F
.252 .578 .943 r
.21192 .36831 m .21447 .36348 L .2217 .3697 L F
.21192 .36831 m .20474 .36155 L .21447 .36348 L F
.52 .64 .908 r
.72134 .33687 m .72748 .32799 L .73278 .33586 L F
.72134 .33687 m .71597 .32832 L .72748 .32799 L F
.885 .835 .791 r
.27808 .35712 m .27095 .3527 L .28218 .33855 L F
.846 .842 .84 r
.26714 .36804 m .27095 .3527 L .27808 .35712 L F
.52 .609 .881 r
.70455 .3291 m .71054 .31927 L .71597 .32832 L F
.70455 .3291 m .69906 .31939 L .71054 .31927 L F
.885 .852 .805 r
.5997 .35277 m .59402 .34776 L .60485 .33458 L F
.89 .89 .823 r
.58887 .36403 m .59402 .34776 L .5997 .35277 L F
.546 .595 .854 r
.68771 .32048 m .69351 .30895 L .69906 .31939 L F
.68771 .32048 m .68212 .30958 L .69351 .30895 L F
.827 .945 .9 r
.56712 .3827 m .57225 .37146 L .57801 .37422 L F
.56712 .3827 m .56132 .38041 L .57225 .37146 L F
.598 .603 .828 r
.67087 .31182 m .67645 .29777 L .68212 .30958 L F
.67087 .31182 m .66519 .29997 L .67645 .29777 L F
.846 .842 .84 r
.26714 .36804 m .25998 .3634 L .27095 .3527 L F
.725 .304 0 r
.44318 .30345 m .4471 .3135 L .45341 .32154 L F
.89 .89 .823 r
.58887 .36403 m .58316 .36033 L .59402 .34776 L F
.875 .923 .855 r
.57801 .37422 m .58316 .36033 L .58887 .36403 L F
.668 .63 .802 r
.65407 .30441 m .65944 .2871 L .66519 .29997 L F
.65407 .30441 m .64834 .29209 L .65944 .2871 L F
.875 .923 .855 r
.57801 .37422 m .57225 .37146 L .58316 .36033 L F
.561 .727 .952 r
.81066 .3546 m .81743 .34645 L .82231 .35298 L F
.81066 .3546 m .80575 .3481 L .81743 .34645 L F
.553 .721 .952 r
.76609 .3472 m .77258 .33911 L .77761 .34539 L F
.76609 .3472 m .76101 .3406 L .77258 .33911 L F
.74 .559 .649 r
.61172 .12898 m .60655 .16857 L .61073 .12898 L F
.61073 .12898 m .60037 .14334 L .60929 .12882 L F
.61073 .12898 m .60655 .16857 L .60037 .14334 L F
.604 .462 .662 r
.62132 .12587 m .61732 .15385 L .61172 .12898 L F
.74 .559 .649 r
.61172 .12898 m .61732 .15385 L .60655 .16857 L F
.917 .808 .723 r
.29361 .32132 m .28656 .31654 L .29823 .29626 L F
.908 .823 .751 r
.28218 .33855 m .28656 .31654 L .29361 .32132 L F
.749 .554 .632 r
.60929 .12882 m .60037 .14334 L .60169 .12867 L F
.60169 .12867 m .60037 .14334 L .59694 .12799 L F
.72 .341 0 r
.40827 .24125 m .41173 .25128 L .41807 .26233 L F
.919 .773 .684 r
.30309 .26782 m .29619 .2613 L .30818 .23632 L F
.923 .771 .675 r
.29619 .2613 m .3014 .22831 L .30818 .23632 L F
.838 .624 .614 r
.59694 .12799 m .58985 .17068 L .59326 .127 L F
.59694 .12799 m .60037 .14334 L .58985 .17068 L F
.527 .693 .944 r
.74949 .34204 m .75589 .3341 L .76101 .3406 L F
.74949 .34204 m .74431 .33499 L .75589 .3341 L F
.838 .624 .614 r
.59326 .127 m .58373 .14744 L .59078 .12585 L F
.59326 .127 m .58985 .17068 L .58373 .14744 L F
.746 .67 .776 r
.63737 .29978 m .64254 .27876 L .64834 .29209 L F
.63737 .29978 m .6316 .28771 L .64254 .27876 L F
.804 .719 .771 r
.62649 .30982 m .6316 .28771 L .63737 .29978 L F
.563 .736 .957 r
.79415 .34992 m .80083 .34183 L .80575 .3481 L F
.79415 .34992 m .78919 .34359 L .80083 .34183 L F
.804 .719 .771 r
.62649 .30982 m .62075 .29942 L .6316 .28771 L F
.85 .765 .768 r
.61566 .32166 m .62075 .29942 L .62649 .30982 L F
.496 .858 .989 r
.53944 .38982 m .54447 .3848 L .55037 .38664 L F
.53944 .38982 m .53348 .38743 L .54447 .3848 L F
.639 .794 .956 r
.23894 .37462 m .24209 .36556 L .24931 .37062 L F
.23894 .37462 m .23174 .36901 L .24209 .36556 L F
.921 .791 .7 r
.29823 .29626 m .29123 .29081 L .30309 .26782 L F
.92 .807 .718 r
.28656 .31654 m .29123 .29081 L .29823 .29626 L F
.563 .057 0 r
.4888 .36395 m .49334 .3696 L .49952 .37372 L F
.4888 .36395 m .48263 .35804 L .49334 .3696 L F
.925 .79 .693 r
.29123 .29081 m .29619 .2613 L .30309 .26782 L F
.604 .462 .662 r
.62307 .12523 m .61732 .15385 L .62132 .12587 L F
.595 .584 .811 r
.66519 .29997 m .67072 .28491 L .67645 .29777 L F
.66519 .29997 m .65944 .2871 L .67072 .28491 L F
.845 .62 .597 r
.59078 .12585 m .58373 .14744 L .58527 .12426 L F
.702 .244 0 r
.4659 .33725 m .47014 .34633 L .47641 .35216 L F
.4659 .33725 m .45968 .32945 L .47014 .34633 L F
.85 .765 .768 r
.61566 .32166 m .60994 .31315 L .62075 .29942 L F
.884 .81 .771 r
.60485 .33458 m .60994 .31315 L .61566 .32166 L F
.5 .652 .927 r
.73278 .33586 m .73908 .32788 L .74431 .33499 L F
.73278 .33586 m .72748 .32799 L .73908 .32788 L F
.53 .568 .838 r
.68212 .30958 m .68788 .29768 L .69351 .30895 L F
.68212 .30958 m .67645 .29777 L .68788 .29768 L F
.676 .619 .784 r
.64834 .29209 m .65363 .27307 L .65944 .2871 L F
.64834 .29209 m .64254 .27876 L .65363 .27307 L F
.385 .314 .654 r
.62517 .12288 m .62841 .14946 L .62307 .12523 L F
.604 .462 .662 r
.62307 .12523 m .62841 .14946 L .61732 .15385 L F
.029 .422 .864 r
.18801 .35113 m .19021 .3479 L .1975 .35475 L F
.18801 .35113 m .18076 .34382 L .19021 .3479 L F
.491 .576 .868 r
.69906 .31939 m .70505 .30965 L .71054 .31927 L F
.69906 .31939 m .69351 .30895 L .70505 .30965 L F
.483 .608 .9 r
.71597 .32832 m .72213 .31982 L .72748 .32799 L F
.71597 .32832 m .71054 .31927 L .72213 .31982 L F
.83 .629 .631 r
.59594 .19193 m .60037 .14334 L .60655 .16857 L F
.59594 .19193 m .58985 .17068 L .60037 .14334 L F
.845 .62 .597 r
.58527 .12426 m .57758 .12198 L .57793 .12072 L F
.58527 .12426 m .58373 .14744 L .57758 .12198 L F
.765 .351 0 r
.43695 .29358 m .44075 .30534 L .4471 .3135 L F
.748 .374 0 r
.40204 .22864 m .40537 .23989 L .41173 .25128 L F
.425 .69 .974 r
.2217 .3697 m .22448 .36338 L .23174 .36901 L F
.2217 .3697 m .21447 .36348 L .22448 .36338 L F
.908 .823 .751 r
.28218 .33855 m .27504 .33411 L .28656 .31654 L F
.886 .837 .792 r
.27095 .3527 m .27504 .33411 L .28218 .33855 L F
.551 .733 .96 r
.77761 .34539 m .78421 .33754 L .78919 .34359 L F
.77761 .34539 m .77258 .33911 L .78421 .33754 L F
.19 .542 .928 r
.20474 .36155 m .20719 .35723 L .21447 .36348 L F
.20474 .36155 m .1975 .35475 L .20719 .35723 L F
.884 .81 .771 r
.60485 .33458 m .59913 .32801 L .60994 .31315 L F
.905 .854 .781 r
.59402 .34776 m .59913 .32801 L .60485 .33458 L F
.6 .473 .679 r
.62353 .17901 m .61732 .15385 L .62841 .14946 L F
.732 .565 .666 r
.61268 .19147 m .61732 .15385 L .62353 .17901 L F
.61268 .19147 m .60655 .16857 L .61732 .15385 L F
.058 .572 .879 r
.52255 .38654 m .52747 .38544 L .53348 .38743 L F
.52255 .38654 m .51651 .38346 L .52747 .38544 L F
.385 .314 .654 r
.62517 .12288 m .63362 .12889 L .62841 .14946 L F
.395 .313 .645 r
.63107 .11676 m .63362 .12889 L .62517 .12288 L F
0 .191 .625 r
.50564 .37802 m .5104 .3807 L .51651 .38346 L F
.50564 .37802 m .49952 .37372 L .5104 .3807 L F
.764 .835 .906 r
.24931 .37062 m .25276 .35876 L .25998 .3634 L F
.24931 .37062 m .24209 .36556 L .25276 .35876 L F
.76 .663 .755 r
.6316 .28771 m .63669 .26427 L .64254 .27876 L F
.6316 .28771 m .62578 .27474 L .63669 .26427 L F
.821 .715 .748 r
.62075 .29942 m .62578 .27474 L .6316 .28771 L F
.714 .949 .954 r
.55037 .38664 m .55547 .37862 L .56132 .38041 L F
.55037 .38664 m .54447 .3848 L .55547 .37862 L F
.593 .566 .792 r
.65944 .2871 m .66491 .27084 L .67072 .28491 L F
.65944 .2871 m .65363 .27307 L .66491 .27084 L F
.685 .608 .764 r
.64254 .27876 m .64775 .2577 L .65363 .27307 L F
.64254 .27876 m .63669 .26427 L .64775 .2577 L F
.905 .854 .781 r
.59402 .34776 m .58829 .34298 L .59913 .32801 L F
.91 .895 .801 r
.58316 .36033 m .58829 .34298 L .59402 .34776 L F
.557 .736 .959 r
.80575 .3481 m .81255 .34015 L .81743 .34645 L F
.80575 .3481 m .80083 .34183 L .81255 .34015 L F
.524 .713 .958 r
.76101 .3406 m .76754 .33308 L .77258 .33911 L F
.76101 .3406 m .75589 .3341 L .76754 .33308 L F
.886 .837 .792 r
.27095 .3527 m .26375 .3483 L .27504 .33411 L F
.842 .844 .845 r
.25998 .3634 m .26375 .3483 L .27095 .3527 L F
.821 .715 .748 r
.62075 .29942 m .61496 .28842 L .62578 .27474 L F
.868 .763 .744 r
.60994 .31315 m .61496 .28842 L .62075 .29942 L F
.842 .844 .845 r
.25998 .3634 m .25276 .35876 L .26375 .3483 L F
.923 .771 .675 r
.29619 .2613 m .28923 .25477 L .3014 .22831 L F
.852 .617 .582 r
.57793 .12072 m .57758 .12198 L .57766 .12063 L F
.512 .539 .821 r
.67645 .29777 m .68218 .28542 L .68788 .29768 L F
.67645 .29777 m .67072 .28491 L .68218 .28542 L F
.852 .617 .582 r
.57766 .12063 m .57758 .12198 L .57724 .12042 L F
.909 .669 .563 r
.57724 .12042 m .56718 .16836 L .57013 .11673 L F
.57724 .12042 m .57758 .12198 L .56718 .16836 L F
.774 .404 0 r
.39579 .21557 m .39899 .22811 L .40537 .23989 L F
.904 .673 .579 r
.57327 .18753 m .57758 .12198 L .58373 .14744 L F
.57327 .18753 m .56718 .16836 L .57758 .12198 L F
.82 .634 .65 r
.602 .21138 m .60655 .16857 L .61268 .19147 L F
.602 .21138 m .59594 .19193 L .60655 .16857 L F
.91 .895 .801 r
.58316 .36033 m .5774 .35702 L .58829 .34298 L F
.892 .933 .837 r
.57225 .37146 m .5774 .35702 L .58316 .36033 L F
.836 .959 .891 r
.56132 .38041 m .56645 .36917 L .57225 .37146 L F
.56132 .38041 m .55547 .37862 L .56645 .36917 L F
.92 .807 .718 r
.28656 .31654 m .27944 .31179 L .29123 .29081 L F
.91 .824 .748 r
.27504 .33411 m .27944 .31179 L .28656 .31654 L F
.396 .338 .674 r
.63469 .17532 m .62841 .14946 L .63999 .15644 L F
.6 .473 .679 r
.62353 .17901 m .62841 .14946 L .63469 .17532 L F
.385 .314 .654 r
.62841 .14946 m .63362 .12889 L .63999 .15644 L F
.487 .672 .946 r
.74431 .33499 m .75075 .32774 L .75589 .3341 L F
.74431 .33499 m .73908 .32788 L .75075 .32774 L F
.458 .539 .852 r
.69351 .30895 m .69949 .29936 L .70505 .30965 L F
.69351 .30895 m .68788 .29768 L .69949 .29936 L F
.892 .933 .837 r
.57225 .37146 m .56645 .36917 L .5774 .35702 L F
.597 .485 .697 r
.62969 .20171 m .62353 .17901 L .63469 .17532 L F
.722 .572 .685 r
.61877 .21227 m .62353 .17901 L .62969 .20171 L F
.61877 .21227 m .61268 .19147 L .62353 .17901 L F
.694 .598 .744 r
.63669 .26427 m .6418 .24083 L .64775 .2577 L F
.63669 .26427 m .63077 .24848 L .6418 .24083 L F
.774 .657 .734 r
.62578 .27474 m .63077 .24848 L .63669 .26427 L F
.592 .547 .774 r
.65363 .27307 m .65902 .25539 L .66491 .27084 L F
.65363 .27307 m .64775 .2577 L .65902 .25539 L F
.868 .763 .744 r
.60994 .31315 m .60417 .30437 L .61496 .28842 L F
.902 .809 .746 r
.59913 .32801 m .60417 .30437 L .60994 .31315 L F
.551 .742 .965 r
.78919 .34359 m .7959 .33588 L .80083 .34183 L F
.78919 .34359 m .78421 .33754 L .7959 .33588 L F
.756 .306 0 r
.45968 .32945 m .46381 .34054 L .47014 .34633 L F
.45968 .32945 m .45341 .32154 L .46381 .34054 L F
.774 .657 .734 r
.62578 .27474 m .61991 .26075 L .63077 .24848 L F
.836 .71 .725 r
.61496 .28842 m .61991 .26075 L .62578 .27474 L F
.8 .392 0 r
.43068 .28346 m .43436 .29704 L .44075 .30534 L F
.43068 .28346 m .42439 .27304 L .43436 .29704 L F
.452 .618 .921 r
.72748 .32799 m .73382 .32069 L .73908 .32788 L F
.72748 .32799 m .72213 .31982 L .73382 .32069 L F
.438 .568 .888 r
.71054 .31927 m .71672 .31129 L .72213 .31982 L F
.71054 .31927 m .70505 .30965 L .71672 .31129 L F
.608 .785 .966 r
.23174 .36901 m .2348 .36048 L .24209 .36556 L F
.23174 .36901 m .22448 .36338 L .2348 .36048 L F
.925 .79 .693 r
.29123 .29081 m .28417 .28538 L .29619 .2613 L F
.928 .788 .686 r
.28417 .28538 m .28923 .25477 L .29619 .2613 L F
.655 .155 0 r
.48263 .35804 m .4871 .36569 L .49334 .3696 L F
.48263 .35804 m .47641 .35216 L .4871 .36569 L F
.923 .807 .713 r
.27944 .31179 m .28417 .28538 L .29123 .29081 L F
.81 .639 .67 r
.60802 .22922 m .61268 .19147 L .61877 .21227 L F
.60802 .22922 m .602 .21138 L .61268 .19147 L F
0 .037 .549 r
.63274 .11008 m .63362 .12889 L .63107 .11676 L F
.909 .669 .563 r
.57013 .11673 m .56107 .14757 L .56744 .11464 L F
.57013 .11673 m .56718 .16836 L .56107 .14757 L F
.704 .588 .724 r
.63077 .24848 m .63578 .22224 L .6418 .24083 L F
.63077 .24848 m .6248 .23121 L .63578 .22224 L F
.787 .651 .712 r
.61991 .26075 m .6248 .23121 L .63077 .24848 L F
.495 .51 .802 r
.67072 .28491 m .67641 .27203 L .68218 .28542 L F
.67072 .28491 m .66491 .27084 L .67641 .27203 L F
.796 .432 0 r
.38954 .20202 m .39259 .21592 L .39899 .22811 L F
.592 .53 .754 r
.64775 .2577 m .65306 .23834 L .65902 .25539 L F
.64775 .2577 m .6418 .24083 L .65306 .23834 L F
.594 .499 .716 r
.63578 .22224 m .62969 .20171 L .64089 .19856 L F
.713 .58 .704 r
.6248 .23121 m .62969 .20171 L .63578 .22224 L F
.6248 .23121 m .61877 .21227 L .62969 .20171 L F
.597 .485 .697 r
.62969 .20171 m .63469 .17532 L .64089 .19856 L F
.405 .826 .967 r
.53348 .38743 m .5385 .38347 L .54447 .3848 L F
.53348 .38743 m .52747 .38544 L .5385 .38347 L F
.836 .71 .725 r
.61496 .28842 m .60913 .27675 L .61991 .26075 L F
.884 .759 .719 r
.60417 .30437 m .60913 .27675 L .61496 .28842 L F
.369 .663 .971 r
.21447 .36348 m .21715 .35773 L .22448 .36338 L F
.21447 .36348 m .20719 .35723 L .21715 .35773 L F
.123 .5 .907 r
.1975 .35475 m .19985 .35094 L .20719 .35723 L F
.1975 .35475 m .19021 .3479 L .19985 .35094 L F
.526 .732 .969 r
.77258 .33911 m .77923 .33185 L .78421 .33754 L F
.77258 .33911 m .76754 .33308 L .77923 .33185 L F
.799 .645 .69 r
.61399 .24563 m .61877 .21227 L .6248 .23121 L F
.61399 .24563 m .60802 .22922 L .61877 .21227 L F
.787 .651 .712 r
.61991 .26075 m .61399 .24563 L .6248 .23121 L F
.902 .809 .746 r
.59913 .32801 m .59337 .32146 L .60417 .30437 L F
.923 .854 .755 r
.58829 .34298 m .59337 .32146 L .59913 .32801 L F
.898 .678 .596 r
.57933 .20524 m .58373 .14744 L .58985 .17068 L F
.57933 .20524 m .57327 .18753 L .58373 .14744 L F
.85 .705 .701 r
.60913 .27675 m .61399 .24563 L .61991 .26075 L F
.592 .514 .735 r
.6418 .24083 m .64701 .21948 L .65306 .23834 L F
.6418 .24083 m .63578 .22224 L .64701 .21948 L F
.594 .499 .716 r
.63578 .22224 m .64089 .19856 L .64701 .21948 L F
.913 .665 .549 r
.56744 .11464 m .56107 .14757 L .56283 .11218 L F
.91 .824 .748 r
.27504 .33411 m .26783 .32972 L .27944 .31179 L F
.886 .839 .793 r
.26375 .3483 m .26783 .32972 L .27504 .33411 L F
.41 .363 .695 r
.64089 .19856 m .63469 .17532 L .64628 .18114 L F
.396 .338 .674 r
.63469 .17532 m .63999 .15644 L .64628 .18114 L F
.419 .498 .833 r
.68788 .29768 m .69386 .28827 L .69949 .29936 L F
.68788 .29768 m .68218 .28542 L .69386 .28827 L F
.751 .835 .916 r
.24209 .36556 m .24547 .35414 L .25276 .35876 L F
.24209 .36556 m .2348 .36048 L .24547 .35414 L F
.476 .48 .782 r
.66491 .27084 m .67055 .25733 L .67641 .27203 L F
.66491 .27084 m .65902 .25539 L .67055 .25733 L F
.034 .084 .583 r
.63999 .15644 m .63362 .12889 L .64589 .15116 L F
0 .037 .549 r
.63362 .12889 m .63949 .12452 L .64589 .15116 L F
.63274 .11008 m .63949 .12452 L .63362 .12889 L F
.494 0 0 r
.49952 .37372 m .50422 .37829 L .5104 .3807 L F
.49952 .37372 m .49334 .3696 L .50422 .37829 L F
.817 .458 0 r
.38329 .18794 m .38618 .20329 L .39259 .21592 L F
.482 .698 .964 r
.75589 .3341 m .76248 .32738 L .76754 .33308 L F
.75589 .3341 m .75075 .32774 L .76248 .32738 L F
.549 .747 .968 r
.80083 .34183 m .80765 .3342 L .81255 .34015 L F
.80083 .34183 m .7959 .33588 L .80765 .3342 L F
0 .446 .773 r
.51651 .38346 m .52139 .38393 L .52747 .38544 L F
.51651 .38346 m .5104 .3807 L .52139 .38393 L F
.829 .428 0 r
.42439 .27304 m .42793 .28859 L .43436 .29704 L F
.42439 .27304 m .41807 .26233 L .42793 .28859 L F
.85 .705 .701 r
.60913 .27675 m .60325 .26434 L .61399 .24563 L F
.863 .699 .678 r
.60325 .26434 m .60802 .22922 L .61399 .24563 L F
.891 .683 .615 r
.58537 .22165 m .58985 .17068 L .59594 .19193 L F
.58537 .22165 m .57933 .20524 L .58985 .17068 L F
.913 .665 .549 r
.56283 .11218 m .55494 .12501 L .55776 .10819 L F
.56283 .11218 m .56107 .14757 L .55494 .12501 L F
.923 .854 .755 r
.58829 .34298 m .58251 .33847 L .59337 .32146 L F
.928 .898 .777 r
.5774 .35702 m .58251 .33847 L .58829 .34298 L F
.884 .759 .719 r
.60417 .30437 m .59836 .29528 L .60913 .27675 L F
.918 .805 .719 r
.59337 .32146 m .59836 .29528 L .60417 .30437 L F
.382 .519 .871 r
.70505 .30965 m .71125 .30235 L .71672 .31129 L F
.70505 .30965 m .69949 .29936 L .71125 .30235 L F
.886 .839 .793 r
.26375 .3483 m .25649 .34393 L .26783 .32972 L F
.838 .847 .851 r
.25276 .35876 m .25649 .34393 L .26375 .3483 L F
.428 .639 .945 r
.73908 .32788 m .74559 .32155 L .75075 .32774 L F
.73908 .32788 m .73382 .32069 L .74559 .32155 L F
.838 .847 .851 r
.25276 .35876 m .24547 .35414 L .25649 .34393 L F
.8 .36 0 r
.45341 .32154 m .45743 .33482 L .46381 .34054 L F
.45341 .32154 m .4471 .3135 L .45743 .33482 L F
.425 .39 .717 r
.64701 .21948 m .64089 .19856 L .65248 .20329 L F
.41 .363 .695 r
.64089 .19856 m .64628 .18114 L .65248 .20329 L F
.458 .449 .76 r
.65902 .25539 m .66461 .24113 L .67055 .25733 L F
.65902 .25539 m .65306 .23834 L .66461 .24113 L F
.69 .957 .948 r
.54447 .3848 m .54955 .37739 L .55547 .37862 L F
.54447 .3848 m .5385 .38347 L .54955 .37739 L F
.898 .754 .694 r
.59836 .29528 m .60325 .26434 L .60913 .27675 L F
.388 .572 .911 r
.72213 .31982 m .72851 .31343 L .73382 .32069 L F
.72213 .31982 m .71672 .31129 L .72851 .31343 L F
.863 .699 .678 r
.60325 .26434 m .59733 .25108 L .60802 .22922 L F
.874 .694 .656 r
.59733 .25108 m .602 .21138 L .60802 .22922 L F
.883 .688 .635 r
.59137 .23689 m .59594 .19193 L .602 .21138 L F
.59137 .23689 m .58537 .22165 L .59594 .19193 L F
.874 .694 .656 r
.59733 .25108 m .59137 .23689 L .602 .21138 L F
0 .024 .546 r
.63452 .1017 m .63949 .12452 L .63274 .11008 L F
.923 .807 .713 r
.27944 .31179 m .27225 .3071 L .28417 .28538 L F
.913 .824 .746 r
.26783 .32972 m .27225 .3071 L .27944 .31179 L F
.53 .749 .976 r
.78421 .33754 m .79098 .33038 L .7959 .33588 L F
.78421 .33754 m .77923 .33185 L .79098 .33038 L F
.441 .419 .739 r
.65306 .23834 m .65859 .22319 L .66461 .24113 L F
.65306 .23834 m .64701 .21948 L .65859 .22319 L F
.425 .39 .717 r
.64701 .21948 m .65248 .20329 L .65859 .22319 L F
.928 .788 .686 r
.28417 .28538 m .27705 .27999 L .28923 .25477 L F
.928 .898 .777 r
.5774 .35702 m .57159 .35416 L .58251 .33847 L F
.908 .941 .817 r
.56645 .36917 m .57159 .35416 L .5774 .35702 L F
.377 .452 .811 r
.68218 .28542 m .68815 .27626 L .69386 .28827 L F
.68218 .28542 m .67641 .27203 L .68815 .27626 L F
.728 .238 0 r
.47641 .35216 m .4808 .36201 L .4871 .36569 L F
.47641 .35216 m .47014 .34633 L .4808 .36201 L F
.572 .774 .974 r
.22448 .36338 m .22744 .35541 L .2348 .36048 L F
.22448 .36338 m .21715 .35773 L .22744 .35541 L F
.843 .972 .878 r
.55547 .37862 m .56059 .36743 L .56645 .36917 L F
.55547 .37862 m .54955 .37739 L .56059 .36743 L F
.926 .806 .708 r
.27225 .3071 m .27705 .27999 L .28417 .28538 L F
.917 .661 .536 r
.55776 .10819 m .55494 .12501 L .55573 .10708 L F
.908 .941 .817 r
.56645 .36917 m .56059 .36743 L .57159 .35416 L F
.305 .63 .962 r
.20719 .35723 m .20976 .35207 L .21715 .35773 L F
.20719 .35723 m .19985 .35094 L .20976 .35207 L F
.081 .134 .619 r
.64628 .18114 m .63999 .15644 L .65219 .17503 L F
.034 .084 .583 r
.63999 .15644 m .64589 .15116 L .65219 .17503 L F
.918 .805 .719 r
.59337 .32146 m .58756 .31494 L .59836 .29528 L F
.94 .852 .728 r
.58251 .33847 m .58756 .31494 L .59337 .32146 L F
.485 .727 .978 r
.76754 .33308 m .77426 .32665 L .77923 .33185 L F
.76754 .33308 m .76248 .32738 L .77426 .32665 L F
.917 .661 .536 r
.55573 .10708 m .55494 .12501 L .54916 .10185 L F
.853 .46 0 r
.41807 .26233 m .42145 .27998 L .42793 .28859 L F
.41807 .26233 m .41173 .25128 L .42145 .27998 L F
.898 .754 .694 r
.59836 .29528 m .59251 .28584 L .60325 .26434 L F
.91 .749 .669 r
.59251 .28584 m .59733 .25108 L .60325 .26434 L F
.315 .46 .847 r
.69949 .29936 m .70573 .29291 L .71125 .30235 L F
.69949 .29936 m .69386 .28827 L .70573 .29291 L F
.331 .402 .785 r
.67641 .27203 m .68237 .26319 L .68815 .27626 L F
.67641 .27203 m .67055 .25733 L .68237 .26319 L F
.932 .801 .693 r
.58756 .31494 m .59251 .28584 L .59836 .29528 L F
.282 .766 .919 r
.52747 .38544 m .53247 .38273 L .5385 .38347 L F
.52747 .38544 m .52139 .38393 L .53247 .38273 L F
.417 .672 .967 r
.75075 .32774 m .75742 .3221 L .76248 .32738 L F
.75075 .32774 m .74559 .32155 L .75742 .3221 L F
.913 .824 .746 r
.26783 .32972 m .26055 .32539 L .27225 .3071 L F
.887 .841 .794 r
.25649 .34393 m .26055 .32539 L .26783 .32972 L F
.536 .761 .98 r
.7959 .33588 m .80277 .32872 L .80765 .3342 L F
.7959 .33588 m .79098 .33038 L .80277 .32872 L F
.735 .835 .927 r
.2348 .36048 m .2381 .34954 L .24547 .35414 L F
.2348 .36048 m .22744 .35541 L .2381 .34954 L F
.835 .406 0 r
.4471 .3135 m .45099 .32917 L .45743 .33482 L F
.4471 .3135 m .44075 .30534 L .45099 .32917 L F
.305 .511 .892 r
.71672 .31129 m .72317 .30608 L .72851 .31343 L F
.71672 .31129 m .71125 .30235 L .72317 .30608 L F
.609 .065 0 r
.49334 .3696 m .49798 .37629 L .50422 .37829 L F
.49334 .3696 m .4871 .36569 L .49798 .37629 L F
.346 .591 .936 r
.73382 .32069 m .7404 .3156 L .74559 .32155 L F
.73382 .32069 m .72851 .31343 L .7404 .3156 L F
.13 .186 .654 r
.65248 .20329 m .64628 .18114 L .6584 .19646 L F
.081 .134 .619 r
.64628 .18114 m .65219 .17503 L .6584 .19646 L F
.282 .35 .756 r
.67055 .25733 m .67651 .24887 L .68237 .26319 L F
.67055 .25733 m .66461 .24113 L .67651 .24887 L F
.91 .749 .669 r
.59251 .28584 m .58662 .27603 L .59733 .25108 L F
.92 .743 .646 r
.58662 .27603 m .59137 .23689 L .59733 .25108 L F
.94 .852 .728 r
.58251 .33847 m .57669 .33426 L .58756 .31494 L F
.944 .9 .751 r
.57159 .35416 m .57669 .33426 L .58251 .33847 L F
.05 0 0 r
.51525 .38293 m .50903 .38253 L .51169 .38271 L F
.289 0 0 r
.51875 .38315 m .51525 .38293 L .52139 .38393 L F
.5104 .3807 m .51525 .38293 L .51875 .38315 L F
.127 .67 .832 r
.52139 .38393 m .51525 .38293 L .52637 .38264 L F
.05 0 0 r
.51525 .38293 m .51169 .38271 L .52019 .38329 L F
.289 0 0 r
.5104 .3807 m .50422 .37829 L .51525 .38293 L F
.887 .841 .794 r
.25649 .34393 m .24915 .3396 L .26055 .32539 L F
.834 .849 .857 r
.24547 .35414 m .24915 .3396 L .25649 .34393 L F
.24547 .35414 m .2381 .34954 L .24915 .3396 L F
.954 .703 .519 r
.54916 .10185 m .54428 .19244 L .54877 .10154 L F
.54916 .10185 m .55494 .12501 L .54428 .19244 L F
0 0 .273 r
.63424 .09945 m .63949 .12452 L .63452 .1017 L F
.874 .488 .015 r
.41173 .25128 m .41494 .27122 L .42145 .27998 L F
.41173 .25128 m .40537 .23989 L .41494 .27122 L F
.954 .703 .519 r
.54877 .10154 m .53811 .17758 L .54868 .10145 L F
.54877 .10154 m .54428 .19244 L .53811 .17758 L F
.956 .698 .507 r
.54868 .10145 m .53811 .17758 L .54172 .0961 L F
.496 .754 .987 r
.77923 .33185 m .78606 .32549 L .79098 .33038 L F
.77923 .33185 m .77426 .32665 L .78606 .32549 L F
.231 .295 .724 r
.66461 .24113 m .67056 .23313 L .67651 .24887 L F
.66461 .24113 m .65859 .22319 L .67056 .23313 L F
.18 .241 .69 r
.65859 .22319 m .65248 .20329 L .66453 .21573 L F
.13 .186 .654 r
.65248 .20329 m .6584 .19646 L .66453 .21573 L F
.236 .391 .816 r
.69386 .28827 m .70014 .28291 L .70573 .29291 L F
.69386 .28827 m .68815 .27626 L .70014 .28291 L F
.784 .309 0 r
.47014 .34633 m .47443 .3586 L .4808 .36201 L F
.47014 .34633 m .46381 .34054 L .47443 .3586 L F
.926 .806 .708 r
.27225 .3071 m .26499 .30247 L .27705 .27999 L F
.915 .825 .743 r
.26055 .32539 m .26499 .30247 L .27225 .3071 L F
.53 .76 .981 r
.21715 .35773 m .22001 .35035 L .22744 .35541 L F
.21715 .35773 m .20976 .35207 L .22001 .35035 L F
.18 .241 .69 r
.65859 .22319 m .66453 .21573 L .67056 .23313 L F
.652 .959 .934 r
.5385 .38347 m .54358 .37681 L .54955 .37739 L F
.5385 .38347 m .53247 .38273 L .54358 .37681 L F
0 0 .273 r
.63424 .09945 m .64653 .14618 L .63949 .12452 L F
0 0 .222 r
.63391 .09827 m .64455 .13868 L .63424 .09945 L F
.64455 .13868 m .64466 .13906 L .63424 .09945 L F
.64568 .14295 m .64016 .12239 L .64653 .14618 L F
.63391 .09827 m .64016 .12239 L .64568 .14295 L F
.63282 .08983 m .64016 .12239 L .63391 .09827 L F
.888 .583 .076 r
.64016 .12239 m .63372 .09596 L .63432 .09986 L F
.64016 .12239 m .63432 .09986 L .63461 .10168 L F
0 0 .329 r
.64589 .15116 m .63949 .12452 L .65281 .16761 L F
0 0 .273 r
.65091 .16148 m .64653 .14618 L .65281 .16761 L F
.63949 .12452 m .64614 .14499 L .65091 .16148 L F
.64614 .14499 m .64653 .14618 L .65091 .16148 L F
.888 .583 .076 r
.64016 .12239 m .63461 .10168 L .63576 .1091 L F
.64059 .12578 m .63576 .1091 L .64953 .19766 L F
.64016 .12239 m .63576 .1091 L .64059 .12578 L F
.903 .602 .106 r
.62781 .07114 m .62923 .08164 L .63372 .09596 L F
.62923 .08164 m .64352 .18762 L .63414 .09993 L F
.62923 .08164 m .63414 .09993 L .63372 .09596 L F
0 0 .222 r
.64455 .13868 m .64653 .14618 L .64466 .13906 L F
.92 .743 .646 r
.58662 .27603 m .58069 .26579 L .59137 .23689 L F
.928 .736 .623 r
.58069 .26579 m .58537 .22165 L .59137 .23689 L F
.932 .801 .693 r
.58756 .31494 m .58171 .30845 L .59251 .28584 L F
.944 .795 .667 r
.58171 .30845 m .58662 .27603 L .59251 .28584 L F
.953 .848 .701 r
.57669 .33426 m .58171 .30845 L .58756 .31494 L F
.944 .9 .751 r
.57159 .35416 m .56572 .35181 L .57669 .33426 L F
.922 .948 .794 r
.56059 .36743 m .56572 .35181 L .57159 .35416 L F
.419 .711 .984 r
.76248 .32738 m .76928 .32209 L .77426 .32665 L F
.76248 .32738 m .75742 .3221 L .76928 .32209 L F
.952 .707 .532 r
.55043 .20641 m .55494 .12501 L .56107 .14757 L F
.55043 .20641 m .54428 .19244 L .55494 .12501 L F
.199 .431 .86 r
.71125 .30235 m .71778 .29864 L .72317 .30608 L F
.71125 .30235 m .70573 .29291 L .71778 .29864 L F
.928 .736 .623 r
.58069 .26579 m .57471 .25508 L .58537 .22165 L F
.935 .73 .602 r
.57471 .25508 m .57933 .20524 L .58537 .22165 L F
.846 .985 .862 r
.54955 .37739 m .55468 .36631 L .56059 .36743 L F
.54955 .37739 m .54358 .37681 L .55468 .36631 L F
.922 .948 .794 r
.56059 .36743 m .55468 .36631 L .56572 .35181 L F
.863 .445 0 r
.44075 .30534 m .4445 .3236 L .45099 .32917 L F
.44075 .30534 m .43436 .29704 L .4445 .3236 L F
.891 .512 .051 r
.40537 .23989 m .40838 .26227 L .41494 .27122 L F
.40537 .23989 m .39899 .22811 L .40838 .26227 L F
.318 .626 .96 r
.74559 .32155 m .75235 .31736 L .75742 .3221 L F
.74559 .32155 m .7404 .3156 L .75235 .31736 L F
.956 .698 .507 r
.54172 .0961 m .53191 .16174 L .54017 .09443 L F
.54172 .0961 m .53811 .17758 L .53191 .16174 L F
.147 .312 .775 r
.68815 .27626 m .69449 .27224 L .70014 .28291 L F
.68815 .27626 m .68237 .26319 L .69449 .27224 L F
.231 .519 .913 r
.72851 .31343 m .73519 .30993 L .7404 .3156 L F
.72851 .31343 m .72317 .30608 L .73519 .30993 L F
.949 .713 .547 r
.55655 .21959 m .56107 .14757 L .56718 .16836 L F
.55655 .21959 m .55043 .20641 L .56107 .14757 L F
.513 .776 .992 r
.79098 .33038 m .7979 .32389 L .80277 .32872 L F
.79098 .33038 m .78606 .32549 L .7979 .32389 L F
.716 .834 .938 r
.22744 .35541 m .23066 .34497 L .2381 .34954 L F
.22744 .35541 m .22001 .35035 L .23066 .34497 L F
.935 .73 .602 r
.57471 .25508 m .56869 .24385 L .57933 .20524 L F
.941 .724 .582 r
.56869 .24385 m .57327 .18753 L .57933 .20524 L F
.915 .825 .743 r
.26055 .32539 m .25319 .32111 L .26499 .30247 L F
.887 .843 .796 r
.24915 .3396 m .25319 .32111 L .26055 .32539 L F
.957 .694 .496 r
.54017 .09443 m .53191 .16174 L .53478 .09026 L F
.945 .718 .564 r
.56264 .23204 m .56718 .16836 L .57327 .18753 L F
.56264 .23204 m .55655 .21959 L .56718 .16836 L F
.941 .724 .582 r
.56869 .24385 m .56264 .23204 L .57327 .18753 L F
.697 .169 0 r
.4871 .36569 m .49167 .37473 L .49798 .37629 L F
.4871 .36569 m .4808 .36201 L .49167 .37473 L F
.127 .67 .832 r
.52139 .38393 m .52637 .38264 L .53247 .38273 L F
.953 .848 .701 r
.57669 .33426 m .57081 .33041 L .58171 .30845 L F
.958 .899 .723 r
.56572 .35181 m .57081 .33041 L .57669 .33426 L F
.944 .795 .667 r
.58171 .30845 m .57582 .30201 L .58662 .27603 L F
.953 .789 .641 r
.57582 .30201 m .58069 .26579 L .58662 .27603 L F
.829 .853 .864 r
.2381 .34954 m .24173 .33532 L .24915 .3396 L F
.2381 .34954 m .23066 .34497 L .24173 .33532 L F
.887 .843 .796 r
.24915 .3396 m .24173 .33532 L .25319 .32111 L F
.438 .752 .994 r
.77426 .32665 m .78117 .32138 L .78606 .32549 L F
.77426 .32665 m .76928 .32209 L .78117 .32138 L F
.05 .225 .724 r
.68237 .26319 m .68876 .26079 L .69449 .27224 L F
.68237 .26319 m .67651 .24887 L .68876 .26079 L F
.826 .366 0 r
.46381 .34054 m .46799 .35549 L .47443 .3586 L F
.46381 .34054 m .45743 .33482 L .46799 .35549 L F
.905 .534 .084 r
.39899 .22811 m .40179 .25313 L .40838 .26227 L F
.39899 .22811 m .39259 .21592 L .40179 .25313 L F
.446 0 0 r
.50422 .37829 m .50903 .38253 L .51525 .38293 L F
.50422 .37829 m .49798 .37629 L .50903 .38253 L F
.07 .33 .808 r
.70573 .29291 m .71235 .2911 L .71778 .29864 L F
.70573 .29291 m .70014 .28291 L .71235 .2911 L F
.965 .844 .673 r
.57081 .33041 m .57582 .30201 L .58171 .30845 L F
0 0 .391 r
.65219 .17503 m .64589 .15116 L .65901 .18698 L F
.869 .559 .04 r
.64653 .14618 m .64016 .12239 L .64222 .13378 L F
0 0 .329 r
.64589 .15116 m .65242 .16668 L .65708 .18172 L F
.869 .559 .04 r
.64695 .14904 m .64222 .13378 L .65549 .20734 L F
.64653 .14618 m .64222 .13378 L .64695 .14904 L F
0 0 .329 r
.65708 .18172 m .65281 .16761 L .65901 .18698 L F
.65242 .16668 m .65281 .16761 L .65708 .18172 L F
.957 .694 .496 r
.53478 .09026 m .5257 .14481 L .53198 .08722 L F
.53478 .09026 m .53191 .16174 L .5257 .14481 L F
0 0 .178 r
.63114 .0838 m .64016 .12239 L .63282 .08983 L F
.885 .477 .047 r
.43436 .29704 m .43794 .31813 L .4445 .3236 L F
.43436 .29704 m .42793 .28859 L .43794 .31813 L F
.314 .674 .976 r
.75742 .3221 m .76433 .31834 L .76928 .32209 L F
.75742 .3221 m .75235 .31736 L .76433 .31834 L F
0 .133 .664 r
.67651 .24887 m .68297 .24845 L .68876 .26079 L F
.67651 .24887 m .67056 .23313 L .68297 .24845 L F
.078 .414 .863 r
.72317 .30608 m .72997 .30464 L .73519 .30993 L F
.72317 .30608 m .71778 .29864 L .72997 .30464 L F
.958 .899 .723 r
.56572 .35181 m .55981 .35003 L .57081 .33041 L F
.935 .952 .768 r
.55468 .36631 m .55981 .35003 L .56572 .35181 L F
.596 .947 .907 r
.53247 .38273 m .53754 .37695 L .54358 .37681 L F
.53247 .38273 m .52637 .38264 L .53754 .37695 L F
.173 .546 .928 r
.7404 .3156 m .74729 .3133 L .75235 .31736 L F
.7404 .3156 m .73519 .30993 L .74729 .3133 L F
.958 .691 .486 r
.53198 .08722 m .5257 .14481 L .52794 .08406 L F
0 0 .458 r
.6584 .19646 m .65219 .17503 L .66512 .20453 L F
.843 .528 0 r
.65281 .16761 m .64653 .14618 L .6486 .15598 L F
0 0 .391 r
.65219 .17503 m .65861 .18628 L .66316 .20006 L F
.843 .528 0 r
.65323 .17 m .6486 .15598 L .66139 .21669 L F
.65281 .16761 m .6486 .15598 L .65323 .17 L F
0 0 .391 r
.66316 .20006 m .65901 .18698 L .66512 .20453 L F
.65861 .18628 m .65901 .18698 L .66316 .20006 L F
.917 .553 .113 r
.39259 .21592 m .39515 .2438 L .40179 .25313 L F
.39259 .21592 m .38618 .20329 L .39515 .2438 L F
.953 .789 .641 r
.57582 .30201 m .56988 .29563 L .58069 .26579 L F
.961 .782 .617 r
.56988 .29563 m .57471 .25508 L .58069 .26579 L F
0 .039 .598 r
.67056 .23313 m .67709 .23507 L .68297 .24845 L F
.67056 .23313 m .66453 .21573 L .67709 .23507 L F
.47 .789 .999 r
.78606 .32549 m .79307 .31993 L .7979 .32389 L F
.78606 .32549 m .78117 .32138 L .79307 .31993 L F
0 0 .528 r
.66453 .21573 m .6584 .19646 L .67115 .22049 L F
.763 .437 0 r
.66512 .20453 m .65901 .18698 L .65995 .19017 L F
0 0 .458 r
.6584 .19646 m .66512 .20453 L .67027 .21883 L F
0 0 .528 r
.67619 .23368 m .67115 .22049 L .67709 .23507 L F
.66453 .21573 m .67115 .22049 L .67619 .23368 L F
0 0 .458 r
.67027 .21883 m .66512 .20453 L .67115 .22049 L F
.701 .37 0 r
.67115 .22049 m .66512 .20453 L .66608 .20724 L F
.67115 .22049 m .66608 .20724 L .67881 .24315 L F
.763 .437 0 r
.66512 .20453 m .65995 .19017 L .67305 .23457 L F
.935 .952 .768 r
.55468 .36631 m .5487 .36589 L .55981 .35003 L F
.846 .994 .841 r
.54358 .37681 m .5487 .36589 L .55468 .36631 L F
.54358 .37681 m .53754 .37695 L .5487 .36589 L F
0 .209 .734 r
.70014 .28291 m .70687 .28345 L .71235 .2911 L F
.70014 .28291 m .69449 .27224 L .70687 .28345 L F
.958 .691 .486 r
.52794 .08406 m .51948 .12668 L .52404 .07983 L F
.52794 .08406 m .5257 .14481 L .51948 .12668 L F
0 0 .178 r
.63114 .0838 m .63372 .09596 L .64016 .12239 L F
.63068 .08039 m .63372 .09596 L .63114 .0838 L F
.762 .255 0 r
.4808 .36201 m .48528 .37369 L .49167 .37473 L F
.4808 .36201 m .47443 .3586 L .48528 .37369 L F
.858 .414 .01 r
.45743 .33482 m .46148 .35271 L .46799 .35549 L F
.45743 .33482 m .45099 .32917 L .46148 .35271 L F
.965 .844 .673 r
.57081 .33041 m .56489 .32696 L .57582 .30201 L F
.97 .896 .695 r
.55981 .35003 m .56489 .32696 L .57081 .33041 L F
.338 .73 .984 r
.76928 .32209 m .77632 .3183 L .78117 .32138 L F
.76928 .32209 m .76433 .31834 L .77632 .3183 L F
.902 .505 .089 r
.42793 .28859 m .43132 .31277 L .43794 .31813 L F
.42793 .28859 m .42145 .27998 L .43132 .31277 L F
.974 .837 .646 r
.56489 .32696 m .56988 .29563 L .57582 .30201 L F
.228 0 0 r
.51823 .38316 m .51394 .38478 L .52019 .38329 L F
.50903 .38253 m .51394 .38478 L .51823 .38316 L F
.383 0 0 r
.50273 .38279 m .5076 .38722 L .51394 .38478 L F
.267 .755 .666 r
.51394 .38478 m .5076 .38722 L .50959 .38643 L F
.405 .853 .778 r
.52019 .38329 m .51394 .38478 L .51593 .3839 L F
.05 0 0 r
.51525 .38293 m .52019 .38329 L .5244 .38269 L F
.405 .853 .778 r
.52019 .38329 m .51593 .3839 L .52524 .37979 L F
.228 0 0 r
.50903 .38253 m .50273 .38279 L .51394 .38478 L F
.267 .755 .666 r
.5237 .38047 m .51896 .38273 L .52524 .37979 L F
.51394 .38478 m .51896 .38273 L .5237 .38047 L F
.51394 .38478 m .50959 .38643 L .51896 .38273 L F
0 0 0 r
.51744 .38333 m .51259 .38685 L .51896 .38273 L F
.5076 .38722 m .51259 .38685 L .51744 .38333 L F
.044 0 0 r
.51108 .38736 m .50612 .39232 L .51259 .38685 L F
.50116 .39071 m .50612 .39232 L .51108 .38736 L F
.183 0 0 r
.50423 .39434 m .50612 .39232 L .49462 .39542 L F
.648 .879 .523 r
.5045 .39394 m .50612 .39232 L .50423 .39434 L F
0 0 0 r
.5076 .38722 m .50116 .39071 L .51259 .38685 L F
.044 0 0 r
.50116 .39071 m .49462 .39542 L .50612 .39232 L F
.648 .879 .523 r
.51032 .38562 m .50612 .39232 L .5045 .39394 L F
.713 .93 .603 r
.51259 .38685 m .50612 .39232 L .50767 .39043 L F
.51259 .38685 m .50767 .39043 L .5177 .37815 L F
.764 .966 .673 r
.51896 .38273 m .51259 .38685 L .51415 .38502 L F
.51896 .38273 m .51415 .38502 L .52407 .37334 L F
.05 0 0 r
.5244 .38269 m .52019 .38329 L .52637 .38264 L F
.961 .782 .617 r
.56988 .29563 m .56389 .28933 L .57471 .25508 L F
.967 .775 .594 r
.56389 .28933 m .56869 .24385 L .57471 .25508 L F
.77 .498 0 r
.62866 .07315 m .63372 .09596 L .63068 .08039 L F
0 .272 .773 r
.71778 .29864 m .72473 .29981 L .72997 .30464 L F
.71778 .29864 m .71235 .2911 L .72473 .29981 L F
.572 0 0 r
.49798 .37629 m .50273 .38279 L .50903 .38253 L F
.49798 .37629 m .49167 .37473 L .50273 .38279 L F
.147 .593 .93 r
.75235 .31736 m .75941 .31563 L .76433 .31834 L F
.75235 .31736 m .74729 .3133 L .75941 .31563 L F
0 0 .527 r
.70126 .27558 m .69579 .26779 L .70135 .27568 L F
.68876 .26079 m .69579 .26779 L .70126 .27558 L F
.68876 .26079 m .68297 .24845 L .69542 .26723 L F
.6955 .26737 m .69542 .26723 L .69555 .26742 L F
.68876 .26079 m .69542 .26723 L .6955 .26737 L F
.68876 .26079 m .69555 .26742 L .69571 .26771 L F
0 0 .412 r
.68297 .24845 m .69018 .25974 L .69579 .26779 L F
.68297 .24845 m .67709 .23507 L .69018 .25974 L F
0 0 .304 r
.67709 .23507 m .67785 .23674 L .67948 .23958 L F
.67785 .23674 m .68452 .25154 L .67948 .23958 L F
.67709 .23507 m .67115 .22049 L .68452 .25154 L F
.701 .37 0 r
.67467 .22867 m .67881 .24315 L .68452 .25154 L F
.67115 .22049 m .67263 .22489 L .67467 .22867 L F
.67263 .22489 m .67881 .24315 L .67467 .22867 L F
0 0 .527 r
.69571 .26771 m .69555 .26742 L .69579 .26779 L F
0 0 .304 r
.67948 .23958 m .68452 .25154 L .69018 .25974 L F
.762 .337 0 r
.69579 .26779 m .69018 .25974 L .69027 .25993 L F
0 .076 .638 r
.69449 .27224 m .70135 .27568 L .70678 .28337 L F
.69449 .27224 m .68876 .26079 L .70135 .27568 L F
.762 .337 0 r
.69579 .26779 m .69027 .25993 L .7037 .28748 L F
.657 .22 0 r
.70135 .27568 m .69579 .26779 L .69588 .26794 L F
.70135 .27568 m .69588 .26794 L .70896 .28921 L F
0 .076 .638 r
.70678 .28337 m .70135 .27568 L .70687 .28345 L F
0 .415 .847 r
.73519 .30993 m .74224 .31009 L .74729 .3133 L F
.73519 .30993 m .72997 .30464 L .74224 .31009 L F
.97 .896 .695 r
.55981 .35003 m .55383 .34891 L .56489 .32696 L F
.945 .954 .739 r
.5487 .36589 m .55383 .34891 L .55981 .35003 L F
.392 .789 .987 r
.78117 .32138 m .78828 .31709 L .79307 .31993 L F
.78117 .32138 m .77632 .3183 L .78828 .31709 L F
.967 .775 .594 r
.56389 .28933 m .55785 .28311 L .56869 .24385 L F
.971 .768 .572 r
.55785 .28311 m .56264 .23204 L .56869 .24385 L F
.916 .529 .125 r
.42145 .27998 m .42463 .30754 L .43132 .31277 L F
.42145 .27998 m .41494 .27122 L .42463 .30754 L F
.515 .915 .858 r
.52637 .38264 m .53143 .37791 L .53754 .37695 L F
.52637 .38264 m .52019 .38329 L .53143 .37791 L F
.882 .453 .067 r
.45099 .32917 m .45489 .35031 L .46148 .35271 L F
.45099 .32917 m .4445 .3236 L .45489 .35031 L F
.903 .602 .106 r
.62781 .07114 m .63372 .09596 L .62866 .07315 L F
.974 .837 .646 r
.56489 .32696 m .55891 .32397 L .56988 .29563 L F
.981 .83 .619 r
.55891 .32397 m .56389 .28933 L .56988 .29563 L F
.81 .324 0 r
.47443 .3586 m .47881 .37321 L .48528 .37369 L F
.47443 .3586 m .46799 .35549 L .47881 .37321 L F
.945 .954 .739 r
.5487 .36589 m .54266 .36627 L .55383 .34891 L F
.839 .999 .813 r
.53754 .37695 m .54266 .36627 L .5487 .36589 L F
0 .103 .64 r
.71235 .2911 m .71948 .29554 L .72473 .29981 L F
.71235 .2911 m .70687 .28345 L .71948 .29554 L F
.979 .892 .665 r
.55383 .34891 m .55891 .32397 L .56489 .32696 L F
.839 .999 .813 r
.53754 .37695 m .53143 .37791 L .54266 .36627 L F
.171 .661 .921 r
.76433 .31834 m .77152 .31651 L .77632 .3183 L F
.76433 .31834 m .75941 .31563 L .77152 .31651 L F
.915 .617 .131 r
.62759 .0708 m .64352 .18762 L .62781 .07114 L F
.62759 .0708 m .63745 .17716 L .64352 .18762 L F
.62393 .06219 m .63745 .17716 L .62759 .0708 L F
.971 .768 .572 r
.55785 .28311 m .55177 .277 L .56264 .23204 L F
.975 .761 .553 r
.55177 .277 m .55655 .21959 L .56264 .23204 L F
.357 0 0 r
.74224 .31009 m .73721 .30793 L .74478 .31184 L F
0 .443 .806 r
.74729 .3133 m .74959 .31359 L .75049 .31391 L F
.74729 .3133 m .74224 .31009 L .75454 .3142 L F
.357 0 0 r
.74615 .31234 m .74478 .31184 L .74972 .31439 L F
.74224 .31009 m .74478 .31184 L .74615 .31234 L F
0 .443 .806 r
.75049 .31391 m .75454 .3142 L .75941 .31563 L F
.74959 .31359 m .75454 .3142 L .75049 .31391 L F
0 .23 .696 r
.72997 .30464 m .73721 .30793 L .74224 .31009 L F
.72997 .30464 m .72473 .29981 L .73721 .30793 L F
.666 .113 0 r
.49167 .37473 m .49635 .3838 L .50273 .38279 L F
.49167 .37473 m .48528 .37369 L .49635 .3838 L F
.927 .549 .158 r
.41494 .27122 m .41788 .30246 L .42463 .30754 L F
.41494 .27122 m .40838 .26227 L .41788 .30246 L F
.903 .602 .106 r
.63372 .09596 m .64352 .18762 L .64953 .19766 L F
.975 .761 .553 r
.55177 .277 m .54563 .27102 L .55655 .21959 L F
.977 .754 .535 r
.54563 .27102 m .55043 .20641 L .55655 .21959 L F
.252 .743 .917 r
.77632 .3183 m .78357 .31568 L .78828 .31709 L F
.77632 .3183 m .77152 .31651 L .78357 .31568 L F
.9 .485 .115 r
.4445 .3236 m .44822 .34832 L .45489 .35031 L F
.4445 .3236 m .43794 .31813 L .44822 .34832 L F
.981 .83 .619 r
.55891 .32397 m .55288 .32151 L .56389 .28933 L F
.987 .823 .594 r
.55288 .32151 m .55785 .28311 L .56389 .28933 L F
0 0 .479 r
.70687 .28345 m .71422 .29196 L .71948 .29554 L F
.70687 .28345 m .70135 .27568 L .71422 .29196 L F
.979 .892 .665 r
.55383 .34891 m .54779 .34855 L .55891 .32397 L F
.952 .953 .708 r
.54266 .36627 m .54779 .34855 L .55383 .34891 L F
.924 .63 .152 r
.62275 .06043 m .63745 .17716 L .62393 .06219 L F
.888 .583 .076 r
.64016 .12239 m .64953 .19766 L .65549 .20734 L F
.844 .379 .038 r
.46799 .35549 m .47225 .37337 L .47881 .37321 L F
.46799 .35549 m .46148 .35271 L .47225 .37337 L F
.405 .853 .778 r
.52019 .38329 m .52524 .37979 L .53143 .37791 L F
.977 .754 .535 r
.54563 .27102 m .53944 .26519 L .55043 .20641 L F
.979 .748 .518 r
.53944 .26519 m .54428 .19244 L .55043 .20641 L F
.986 .885 .635 r
.54779 .34855 m .55288 .32151 L .55891 .32397 L F
.924 .63 .152 r
.62275 .06043 m .63134 .16623 L .63745 .17716 L F
.61969 .05328 m .63134 .16623 L .62275 .06043 L F
.936 .566 .186 r
.40838 .26227 m .41105 .29754 L .41788 .30246 L F
.40838 .26227 m .40179 .25313 L .41105 .29754 L F
0 .506 .758 r
.75941 .31563 m .76679 .31635 L .77152 .31651 L F
.75941 .31563 m .75454 .3142 L .76679 .31635 L F
.952 .953 .708 r
.54266 .36627 m .53654 .36755 L .54779 .34855 L F
.825 .998 .777 r
.53143 .37791 m .53654 .36755 L .54266 .36627 L F
.869 .559 .04 r
.64653 .14618 m .65549 .20734 L .66139 .21669 L F
.505 0 0 r
.72473 .29981 m .73222 .30706 L .73721 .30793 L F
.72473 .29981 m .71948 .29554 L .73222 .30706 L F
.763 .437 0 r
.66512 .20453 m .67305 .23457 L .67881 .24315 L F
.825 .998 .777 r
.53143 .37791 m .52524 .37979 L .53654 .36755 L F
.357 0 0 r
.74224 .31009 m .74972 .31439 L .75454 .3142 L F
.809 .488 0 r
.65901 .18698 m .65281 .16761 L .66725 .22576 L F
.843 .528 0 r
.65281 .16761 m .66139 .21669 L .66725 .22576 L F
.809 .488 0 r
.65901 .18698 m .66725 .22576 L .67305 .23457 L F
.979 .748 .518 r
.53944 .26519 m .53319 .25953 L .54428 .19244 L F
.98 .742 .503 r
.53319 .25953 m .53811 .17758 L .54428 .19244 L F
.657 .22 0 r
.70135 .27568 m .70896 .28921 L .71422 .29196 L F
.733 .208 0 r
.48528 .37369 m .48988 .38565 L .49635 .3838 L F
.48528 .37369 m .47881 .37321 L .48988 .38565 L F
.383 0 0 r
.50273 .38279 m .49635 .3838 L .5076 .38722 L F
.987 .823 .594 r
.55288 .32151 m .54678 .31965 L .55785 .28311 L F
.991 .815 .57 r
.54678 .31965 m .55177 .277 L .55785 .28311 L F
.913 .511 .155 r
.43794 .31813 m .44146 .34682 L .44822 .34832 L F
.43794 .31813 m .43132 .31277 L .44146 .34682 L F
.98 .742 .503 r
.53319 .25953 m .52689 .25409 L .53811 .17758 L F
.981 .736 .49 r
.52689 .25409 m .53191 .16174 L .53811 .17758 L F
.932 .639 .169 r
.61771 .05033 m .63134 .16623 L .61969 .05328 L F
.943 .581 .211 r
.40179 .25313 m .40415 .29282 L .41105 .29754 L F
.40179 .25313 m .39515 .2438 L .40415 .29282 L F
.037 .607 .736 r
.77152 .31651 m .77895 .31611 L .78357 .31568 L F
.77152 .31651 m .76679 .31635 L .77895 .31611 L F
.981 .736 .49 r
.52689 .25409 m .52053 .24888 L .53191 .16174 L F
.982 .731 .478 r
.52053 .24888 m .5257 .14481 L .53191 .16174 L F
.986 .885 .635 r
.54779 .34855 m .54168 .34903 L .55288 .32151 L F
.956 .95 .674 r
.53654 .36755 m .54168 .34903 L .54779 .34855 L F
.868 .423 .099 r
.46148 .35271 m .46559 .37426 L .47225 .37337 L F
.46148 .35271 m .45489 .35031 L .46559 .37426 L F
.932 .639 .169 r
.61771 .05033 m .62516 .15478 L .63134 .16623 L F
.61515 .04441 m .62516 .15478 L .61771 .05033 L F
.982 .731 .478 r
.52053 .24888 m .5141 .24396 L .5257 .14481 L F
.982 .726 .468 r
.5141 .24396 m .51948 .12668 L .5257 .14481 L F
.992 .878 .606 r
.54168 .34903 m .54678 .31965 L .55288 .32151 L F
.982 .726 .468 r
.5141 .24396 m .50761 .23935 L .51948 .12668 L F
.678 .161 0 r
.71948 .29554 m .72726 .30778 L .73222 .30706 L F
.71948 .29554 m .71422 .29196 L .72726 .30778 L F
.33 0 0 r
.75454 .3142 m .76216 .31825 L .76679 .31635 L F
.75454 .3142 m .74972 .31439 L .76216 .31825 L F
.762 .337 0 r
.69579 .26779 m .7037 .28748 L .70896 .28921 L F
.574 0 0 r
.73721 .30793 m .74498 .31656 L .74972 .31439 L F
.73721 .30793 m .73222 .30706 L .74498 .31656 L F
.991 .815 .57 r
.54678 .31965 m .54062 .31848 L .55177 .277 L F
.994 .807 .547 r
.54062 .31848 m .54563 .27102 L .55177 .277 L F
.924 .533 .19 r
.43132 .31277 m .4346 .34584 L .44146 .34682 L F
.43132 .31277 m .42463 .30754 L .4346 .34584 L F
.956 .95 .674 r
.53654 .36755 m .53035 .36987 L .54168 .34903 L F
.801 .988 .731 r
.52524 .37979 m .53035 .36987 L .53654 .36755 L F
.52524 .37979 m .51896 .38273 L .53035 .36987 L F
.78 .283 .018 r
.47881 .37321 m .4833 .38845 L .48988 .38565 L F
.47881 .37321 m .47225 .37337 L .4833 .38845 L F
.505 0 0 r
.49635 .3838 m .50116 .39071 L .5076 .38722 L F
.49635 .3838 m .48988 .38565 L .50116 .39071 L F
.831 .423 0 r
.69018 .25974 m .69845 .28697 L .7037 .28748 L F
.69018 .25974 m .68452 .25154 L .69845 .28697 L F
.201 0 0 r
.76679 .31635 m .77446 .31886 L .77895 .31611 L F
.76679 .31635 m .76216 .31825 L .77446 .31886 L F
.886 .459 .15 r
.45489 .35031 m .45883 .37595 L .46559 .37426 L F
.45489 .35031 m .44822 .34832 L .45883 .37595 L F
.992 .878 .606 r
.54168 .34903 m .5355 .35049 L .54678 .31965 L F
.956 .943 .637 r
.53035 .36987 m .5355 .35049 L .54168 .34903 L F
.786 .298 0 r
.71422 .29196 m .72237 .31042 L .72726 .30778 L F
.71422 .29196 m .70896 .28921 L .72237 .31042 L F
.995 .87 .577 r
.5355 .35049 m .54062 .31848 L .54678 .31965 L F
.994 .807 .547 r
.54062 .31848 m .53439 .3181 L .54563 .27102 L F
.995 .799 .526 r
.53439 .3181 m .53944 .26519 L .54563 .27102 L F
.932 .551 .22 r
.42463 .30754 m .42765 .34547 L .4346 .34584 L F
.42463 .30754 m .41788 .30246 L .42765 .34547 L F
.525 0 0 r
.74972 .31439 m .75766 .32271 L .76216 .31825 L F
.74972 .31439 m .74498 .31656 L .75766 .32271 L F
.71 .174 0 r
.73222 .30706 m .74035 .32119 L .74498 .31656 L F
.73222 .30706 m .72726 .30778 L .74035 .32119 L F
.876 .484 .021 r
.68452 .25154 m .69322 .28792 L .69845 .28697 L F
.68452 .25154 m .67881 .24315 L .69322 .28792 L F
.956 .943 .637 r
.53035 .36987 m .52407 .37334 L .5355 .35049 L F
.764 .966 .673 r
.51896 .38273 m .52407 .37334 L .53035 .36987 L F
.814 .342 .092 r
.47225 .37337 m .47662 .39232 L .4833 .38845 L F
.47225 .37337 m .46559 .37426 L .47662 .39232 L F
.596 .053 0 r
.48988 .38565 m .49462 .39542 L .50116 .39071 L F
.48988 .38565 m .4833 .38845 L .49462 .39542 L F
.899 .487 .192 r
.44822 .34832 m .45196 .37854 L .45883 .37595 L F
.44822 .34832 m .44146 .34682 L .45196 .37854 L F
.995 .799 .526 r
.53439 .3181 m .52808 .31863 L .53944 .26519 L F
.997 .791 .507 r
.52808 .31863 m .53319 .25953 L .53944 .26519 L F
.85 .393 .018 r
.70896 .28921 m .71754 .31541 L .72237 .31042 L F
.70896 .28921 m .7037 .28748 L .71754 .31541 L F
.938 .567 .246 r
.41788 .30246 m .42059 .34576 L .42765 .34547 L F
.41788 .30246 m .41105 .29754 L .42059 .34576 L F
.384 0 0 r
.76216 .31825 m .77012 .32451 L .77446 .31886 L F
.76216 .31825 m .75766 .32271 L .77012 .32451 L F
.995 .87 .577 r
.5355 .35049 m .52923 .35306 L .54062 .31848 L F
.997 .861 .55 r
.52923 .35306 m .53439 .3181 L .54062 .31848 L F
.906 .529 .087 r
.67881 .24315 m .688 .29063 L .69322 .28792 L F
.67881 .24315 m .67305 .23457 L .688 .29063 L F
.954 .934 .599 r
.52407 .37334 m .52923 .35306 L .5355 .35049 L F
.64 .12 0 r
.74498 .31656 m .75331 .33036 L .75766 .32271 L F
.74498 .31656 m .74035 .32119 L .75331 .33036 L F
.786 .295 .04 r
.72726 .30778 m .73583 .32884 L .74035 .32119 L F
.72726 .30778 m .72237 .31042 L .73583 .32884 L F
.997 .791 .507 r
.52808 .31863 m .52168 .32017 L .53319 .25953 L F
.997 .784 .49 r
.52168 .32017 m .52689 .25409 L .53319 .25953 L F
.925 .561 .138 r
.67305 .23457 m .68281 .29544 L .688 .29063 L F
.67305 .23457 m .66725 .22576 L .68281 .29544 L F
.838 .389 .152 r
.4741 .3942 m .46559 .37426 L .46887 .39215 L F
.4741 .3942 m .47662 .39232 L .46559 .37426 L F
.46887 .39215 m .46559 .37426 L .45883 .37595 L F
.943 .58 .268 r
.41105 .29754 m .41341 .3468 L .42059 .34576 L F
.41105 .29754 m .40415 .29282 L .41341 .3468 L F
.909 .511 .227 r
.44703 .3811 m .44146 .34682 L .44473 .37971 L F
.44703 .3811 m .45196 .37854 L .44146 .34682 L F
.44473 .37971 m .44146 .34682 L .4346 .34584 L F
.954 .934 .599 r
.52407 .37334 m .5177 .37815 L .52923 .35306 L F
.713 .93 .603 r
.51259 .38685 m .5177 .37815 L .52407 .37334 L F
.887 .458 .11 r
.7037 .28748 m .7128 .32325 L .71754 .31541 L F
.7037 .28748 m .69845 .28697 L .7128 .32325 L F
.661 .15 .017 r
.4922 .39762 m .4833 .38845 L .48633 .3969 L F
.4922 .39762 m .49462 .39542 L .4833 .38845 L F
.48633 .3969 m .4833 .38845 L .47662 .39232 L F
.997 .861 .55 r
.52923 .35306 m .52288 .35689 L .53439 .3181 L F
.997 .851 .523 r
.52288 .35689 m .52808 .31863 L .53439 .3181 L F
.939 .585 .177 r
.66725 .22576 m .67766 .30278 L .68281 .29544 L F
.66725 .22576 m .66139 .21669 L .67766 .30278 L F
.497 .009 .027 r
.75766 .32271 m .76599 .33381 L .77012 .32451 L F
.75766 .32271 m .75331 .33036 L .76599 .33381 L F
.948 .922 .56 r
.5177 .37815 m .52288 .35689 L .52923 .35306 L F
.997 .784 .49 r
.52168 .32017 m .5152 .3229 L .52689 .25409 L F
.997 .777 .474 r
.5152 .3229 m .52053 .24888 L .52689 .25409 L F
.829 .376 .148 r
.72237 .31042 m .73147 .34021 L .73583 .32884 L F
.72237 .31042 m .71754 .31541 L .73147 .34021 L F
.705 .234 .129 r
.74035 .32119 m .74915 .34198 L .75331 .33036 L F
.74035 .32119 m .73583 .32884 L .74915 .34198 L F
.909 .511 .227 r
.44473 .37971 m .4346 .34584 L .44414 .37926 L F
.917 .53 .257 r
.44414 .37926 m .4346 .34584 L .43689 .37485 L F
.43689 .37485 m .4346 .34584 L .42765 .34547 L F
.838 .389 .152 r
.46887 .39215 m .45883 .37595 L .46647 .39083 L F
.855 .426 .201 r
.46647 .39083 m .45883 .37595 L .46066 .38848 L F
.46066 .38848 m .45883 .37595 L .45196 .37854 L F
.948 .603 .207 r
.66139 .21669 m .67255 .31316 L .67766 .30278 L F
.66139 .21669 m .65549 .20734 L .67255 .31316 L F
.183 0 0 r
.50423 .39434 m .49462 .39542 L .4962 .39668 L F
.4962 .39668 m .49462 .39542 L .4922 .39762 L F
.909 .503 .177 r
.69845 .28697 m .70817 .33457 L .7128 .32325 L F
.69845 .28697 m .69322 .28792 L .70817 .33457 L F
.948 .922 .56 r
.5177 .37815 m .51122 .38447 L .52288 .35689 L F
.648 .879 .523 r
.50612 .39232 m .51122 .38447 L .5177 .37815 L F
.997 .851 .523 r
.52288 .35689 m .51643 .36216 L .52808 .31863 L F
.996 .842 .498 r
.51643 .36216 m .52168 .32017 L .52808 .31863 L F
.997 .777 .474 r
.5152 .3229 m .50861 .32696 L .52053 .24888 L F
.997 .77 .459 r
.50861 .32696 m .5141 .24396 L .52053 .24888 L F
.661 .15 .017 r
.48633 .3969 m .47662 .39232 L .48061 .39554 L F
.708 .226 .1 r
.48061 .39554 m .47662 .39232 L .47737 .39506 L F
.47737 .39506 m .47662 .39232 L .4741 .3942 L F
.648 .879 .523 r
.51032 .38562 m .51122 .38447 L .50612 .39232 L F
.955 .617 .231 r
.67062 .31851 m .65549 .20734 L .66626 .31486 L F
.67062 .31851 m .67255 .31316 L .65549 .20734 L F
.66626 .31486 m .65549 .20734 L .64953 .19766 L F
.939 .907 .52 r
.51122 .38447 m .51643 .36216 L .52288 .35689 L F
.565 .125 .163 r
.75331 .33036 m .7621 .34769 L .76599 .33381 L F
.75331 .33036 m .74915 .34198 L .7621 .34769 L F
.917 .53 .257 r
.43689 .37485 m .42765 .34547 L .43439 .3729 L F
.922 .547 .282 r
.43439 .3729 m .42765 .34547 L .42914 .36967 L F
.42914 .36967 m .42765 .34547 L .42059 .34576 L F
.854 .431 .222 r
.72809 .35316 m .71754 .31541 L .72647 .35271 L F
.72809 .35316 m .73147 .34021 L .71754 .31541 L F
.72647 .35271 m .71754 .31541 L .7128 .32325 L F
.997 .77 .459 r
.50861 .32696 m .50191 .33256 L .5141 .24396 L F
.996 .764 .447 r
.50191 .33256 m .50761 .23935 L .5141 .24396 L F
.855 .426 .201 r
.46066 .38848 m .45196 .37854 L .45485 .38523 L F
.868 .456 .24 r
.45485 .38523 m .45196 .37854 L .45263 .3843 L F
.45263 .3843 m .45196 .37854 L .44703 .3811 L F
.955 .617 .231 r
.66626 .31486 m .64953 .19766 L .66568 .31408 L F
.96 .627 .25 r
.66568 .31408 m .64953 .19766 L .65927 .30867 L F
.65927 .30867 m .64953 .19766 L .64352 .18762 L F
.923 .535 .225 r
.70553 .34372 m .69322 .28792 L .70232 .34207 L F
.70553 .34372 m .70817 .33457 L .69322 .28792 L F
.70232 .34207 m .69322 .28792 L .688 .29063 L F
.744 .311 .223 r
.74576 .35628 m .73583 .32884 L .7445 .35617 L F
.74576 .35628 m .74915 .34198 L .73583 .32884 L F
.7445 .35617 m .73583 .32884 L .73147 .34021 L F
.996 .842 .498 r
.5105 .36645 m .52168 .32017 L .51643 .36216 L F
.995 .832 .475 r
.51023 .36587 m .52168 .32017 L .5105 .36645 L F
.51023 .36587 m .5152 .3229 L .52168 .32017 L F
.939 .907 .52 r
.5111 .37585 m .51122 .38447 L .51085 .38491 L F
.5111 .37585 m .51643 .36216 L .51122 .38447 L F
.579 .829 .459 r
.51085 .38491 m .51122 .38447 L .51032 .38562 L F
.96 .627 .25 r
.65927 .30867 m .64352 .18762 L .65784 .30676 L F
.963 .636 .265 r
.65784 .30676 m .64352 .18762 L .65238 .30212 L F
.65238 .30212 m .64352 .18762 L .63745 .17716 L F
.996 .764 .447 r
.49607 .33199 m .50761 .23935 L .50191 .33256 L F
.922 .547 .282 r
.42914 .36967 m .42059 .34576 L .42494 .36636 L F
.927 .56 .303 r
.42494 .36636 m .42059 .34576 L .42144 .3642 L F
.42144 .3642 m .42059 .34576 L .41341 .3468 L F
.996 .842 .498 r
.5105 .36645 m .51643 .36216 L .51097 .36791 L F
.954 .91 .539 r
.51097 .36791 m .51643 .36216 L .5111 .37585 L F
.963 .636 .265 r
.65238 .30212 m .63745 .17716 L .65025 .29928 L F
.966 .642 .277 r
.65025 .29928 m .63745 .17716 L .64558 .29528 L F
.64558 .29528 m .63745 .17716 L .63134 .16623 L F
.923 .535 .225 r
.70232 .34207 m .688 .29063 L .70132 .34119 L F
.932 .558 .261 r
.70132 .34119 m .688 .29063 L .69465 .33768 L F
.69465 .33768 m .688 .29063 L .68281 .29544 L F
.608 .205 .254 r
.76064 .3557 m .74915 .34198 L .75444 .35625 L F
.76064 .3557 m .7621 .34769 L .74915 .34198 L F
.75444 .35625 m .74915 .34198 L .74576 .35628 L F
.854 .431 .222 r
.72647 .35271 m .7128 .32325 L .72557 .35223 L F
.869 .469 .274 r
.72557 .35223 m .7128 .32325 L .71798 .35001 L F
.71798 .35001 m .7128 .32325 L .70817 .33457 L F
.995 .832 .475 r
.50758 .35774 m .5152 .3229 L .51023 .36587 L F
.993 .823 .453 r
.50575 .35374 m .5152 .3229 L .50758 .35774 L F
.50575 .35374 m .50861 .32696 L .5152 .3229 L F
.966 .642 .277 r
.64558 .29528 m .63134 .16623 L .64285 .29165 L F
.968 .648 .287 r
.64285 .29165 m .63134 .16623 L .63884 .28819 L F
.63884 .28819 m .63134 .16623 L .62516 .15478 L F
.744 .311 .223 r
.7445 .35617 m .73147 .34021 L .74324 .35586 L F
.768 .364 .287 r
.74324 .35586 m .73147 .34021 L .73515 .35505 L F
.73515 .35505 m .73147 .34021 L .72809 .35316 L F
.927 .56 .303 r
.42144 .3642 m .41341 .3468 L .41574 .35968 L F
.968 .648 .287 r
.63884 .28819 m .62516 .15478 L .6356 .2839 L F
.932 .558 .261 r
.69465 .33768 m .68281 .29544 L .69144 .33484 L F
.938 .576 .287 r
.69144 .33484 m .68281 .29544 L .6873 .33261 L F
.6873 .33261 m .68281 .29544 L .67766 .30278 L F
.993 .823 .453 r
.50423 .34908 m .50861 .32696 L .50575 .35374 L F
.991 .814 .433 r
.50098 .34196 m .50861 .32696 L .50423 .34908 L F
.50098 .34196 m .50191 .33256 L .50861 .32696 L F
.869 .469 .274 r
.71798 .35001 m .70817 .33457 L .71255 .34703 L F
.88 .498 .311 r
.71255 .34703 m .70817 .33457 L .71005 .34626 L F
.71005 .34626 m .70817 .33457 L .70553 .34372 L F
.938 .576 .287 r
.6873 .33261 m .67766 .30278 L .68233 .32816 L F
.943 .589 .307 r
.68233 .32816 m .67766 .30278 L .68019 .32698 L F
.68019 .32698 m .67766 .30278 L .67255 .31316 L F
.991 .814 .433 r
.50049 .34046 m .50191 .33256 L .50098 .34196 L F
.996 .764 .447 r
.49607 .33199 m .50191 .33256 L .49855 .33619 L F
.999 .803 .47 r
.49855 .33619 m .50191 .33256 L .50049 .34046 L F
.943 .589 .307 r
.68019 .32698 m .67255 .31316 L .67381 .32122 L F
.946 .599 .323 r
.67381 .32122 m .67255 .31316 L .67326 .32091 L F
.67326 .32091 m .67255 .31316 L .67062 .31851 L F
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14467 .21304 m
.1493 .21769 L
s
gsave
.13542 .20373 -77.9542 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -70.3694 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.55745 .05141 m
.56132 .05671 L
s
gsave
.54972 .04081 -69.7574 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.19287 .19417 m
.1956 .197 L
s
.24198 .17493 m
.24466 .17782 L
s
.29204 .15533 m
.29467 .15827 L
s
.39509 .11498 m
.3976 .11801 L
s
.44814 .09421 m
.45059 .09729 L
s
.50225 .07302 m
.50464 .07615 L
s
.09737 .23156 m
.10019 .23431 L
s
.05093 .24975 m
.05379 .25245 L
s
.61378 .02935 m
.61603 .03258 L
s
.67126 .00684 m
.67344 .01012 L
s
gsave
.29165 .07573 -69.9038 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.562 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.00912e-16 1.04977 -0.0679587 1.04977 [
[.13542 .20373 -16.9542 -11.1875 ]
[.13542 .20373 .04582 0 ]
[.3345 .12542 -9.36936 -11.1875 ]
[.3345 .12542 .69314 0 ]
[.54972 .04081 -8.75741 -11.1875 ]
[.54972 .04081 1.36759 0 ]
[.29165 .07573 -8.90381 -11.1875 ]
[.29165 .07573 .65869 0 ]
[.76189 .08851 0 -7.66985 ]
[.76189 .08851 17 3.51765 ]
[.8565 .23339 0 -7.4972 ]
[.8565 .23339 10.0625 3.6903 ]
[.93905 .3598 0 -7.35106 ]
[.93905 .3598 10.125 3.83644 ]
[.91861 .21225 0 -7.4972 ]
[.91861 .21225 9.6875 3.6903 ]
[.02494 .25992 -22.4375 -3.40341 ]
[.02494 .25992 0 7.78409 ]
[.01611 .31527 -17.0625 -3.46156 ]
[.01611 .31527 0 7.72594 ]
[.00696 .37264 -10.0625 -3.52206 ]
[.00696 .37264 0 7.66544 ]
[-0.00254 .43215 -10.1875 -3.58506 ]
[-0.00254 .43215 0 7.60244 ]
[-0.0124 .49393 -15.5625 -3.65071 ]
[-0.0124 .49393 0 7.53679 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.14467 .21304 m
.1493 .21769 L
s
gsave
.13542 .20373 -77.9542 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -70.3694 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.55745 .05141 m
.56132 .05671 L
s
gsave
.54972 .04081 -69.7574 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.19287 .19417 m
.1956 .197 L
s
.24198 .17493 m
.24466 .17782 L
s
.29204 .15533 m
.29467 .15827 L
s
.39509 .11498 m
.3976 .11801 L
s
.44814 .09421 m
.45059 .09729 L
s
.50225 .07302 m
.50464 .07615 L
s
.09737 .23156 m
.10019 .23431 L
s
.05093 .24975 m
.05379 .25245 L
s
.61378 .02935 m
.61603 .03258 L
s
.67126 .00684 m
.67344 .01012 L
s
gsave
.29165 .07573 -69.9038 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.562 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74959 .09308 m
.74344 .09536 L
s
gsave
.76189 .08851 -61 -11.6699 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.4972 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.92653 .36374 m
.92027 .3657 L
s
gsave
.93905 .3598 -61 -11.3511 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.77448 .13116 m
.77078 .1325 L
s
.79849 .16789 m
.79478 .16921 L
s
.82168 .20336 m
.81796 .20465 L
s
.86572 .27073 m
.86199 .27197 L
s
.88666 .30275 m
.88291 .30397 L
s
.90691 .33374 m
.90316 .33494 L
s
.72377 .05359 m
.72009 .05499 L
s
.69697 .0126 m
.69331 .01403 L
s
.94552 .3928 m
.94176 .39396 L
s
.96393 .42096 m
.96017 .4221 L
s
gsave
.91861 .21225 -61 -11.4972 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
68.688 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -83.4375 -7.40341 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -78.0625 -7.46156 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -71.0625 -7.52206 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -71.1875 -7.58506 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -76.5625 -7.65071 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.40678 .69174 m .41017 .68474 L .41534 .68932 L F
.40678 .69174 m .40159 .68718 L .41017 .68474 L F
.41534 .68932 m .41878 .68229 L .42393 .68688 L F
.41534 .68932 m .41017 .68474 L .41878 .68229 L F
.40159 .68718 m .40498 .68013 L .41017 .68474 L F
.40159 .68718 m .39638 .68259 L .40498 .68013 L F
.42393 .68688 m .42741 .67983 L .43254 .68444 L F
.42393 .68688 m .41878 .68229 L .42741 .67983 L F
.41017 .68474 m .4136 .67766 L .41878 .68229 L F
.41017 .68474 m .40498 .68013 L .4136 .67766 L F
.43254 .68444 m .43608 .67736 L .44119 .68199 L F
.43254 .68444 m .42741 .67983 L .43608 .67736 L F
.39638 .68259 m .39975 .67549 L .40498 .68013 L F
.39638 .68259 m .39114 .67797 L .39975 .67549 L F
.41878 .68229 m .42225 .67519 L .42741 .67983 L F
.41878 .68229 m .4136 .67766 L .42225 .67519 L F
.44119 .68199 m .44476 .67489 L .44986 .67953 L F
.44119 .68199 m .43608 .67736 L .44476 .67489 L F
.40498 .68013 m .40839 .67301 L .4136 .67766 L F
.40498 .68013 m .39975 .67549 L .40839 .67301 L F
.42741 .67983 m .43093 .67271 L .43608 .67736 L F
.42741 .67983 m .42225 .67519 L .43093 .67271 L F
.44986 .67953 m .45348 .67241 L .45856 .67706 L F
.44986 .67953 m .44476 .67489 L .45348 .67241 L F
.39114 .67797 m .3945 .67083 L .39975 .67549 L F
.39114 .67797 m .38586 .67332 L .3945 .67083 L F
.4136 .67766 m .41706 .67053 L .42225 .67519 L F
.4136 .67766 m .40839 .67301 L .41706 .67053 L F
.43608 .67736 m .43964 .67022 L .44476 .67489 L F
.43608 .67736 m .43093 .67271 L .43964 .67022 L F
.45856 .67706 m .46223 .66992 L .46728 .67459 L F
.45856 .67706 m .45348 .67241 L .46223 .66992 L F
.39975 .67549 m .40315 .66834 L .40839 .67301 L F
.39975 .67549 m .3945 .67083 L .40315 .66834 L F
.42225 .67519 m .42576 .66803 L .43093 .67271 L F
.42225 .67519 m .41706 .67053 L .42576 .66803 L F
.44476 .67489 m .44838 .66773 L .45348 .67241 L F
.44476 .67489 m .43964 .67022 L .44838 .66773 L F
.46728 .67459 m .471 .66742 L .47604 .6721 L F
.46728 .67459 m .46223 .66992 L .471 .66742 L F
.38586 .67332 m .38921 .66614 L .3945 .67083 L F
.38586 .67332 m .38056 .66864 L .38921 .66614 L F
.40839 .67301 m .41184 .66583 L .41706 .67053 L F
.40839 .67301 m .40315 .66834 L .41184 .66583 L F
.43093 .67271 m .43449 .66553 L .43964 .67022 L F
.43093 .67271 m .42576 .66803 L .43449 .66553 L F
.45348 .67241 m .45714 .66522 L .46223 .66992 L F
.45348 .67241 m .44838 .66773 L .45714 .66522 L F
.47604 .6721 m .4798 .66492 L .48482 .66961 L F
.47604 .6721 m .471 .66742 L .4798 .66492 L F
.3945 .67083 m .39788 .66363 L .40315 .66834 L F
.3945 .67083 m .38921 .66614 L .39788 .66363 L F
.41706 .67053 m .42056 .66332 L .42576 .66803 L F
.41706 .67053 m .41184 .66583 L .42056 .66332 L F
.43964 .67022 m .44324 .66302 L .44838 .66773 L F
.43964 .67022 m .43449 .66553 L .44324 .66302 L F
.46223 .66992 m .46593 .66271 L .471 .66742 L F
.46223 .66992 m .45714 .66522 L .46593 .66271 L F
.48482 .66961 m .48863 .6624 L .49363 .66712 L F
.48482 .66961 m .4798 .66492 L .48863 .6624 L F
.38056 .66864 m .38388 .66142 L .38921 .66614 L F
.38056 .66864 m .37522 .66394 L .38388 .66142 L F
.40315 .66834 m .40659 .66111 L .41184 .66583 L F
.40315 .66834 m .39788 .66363 L .40659 .66111 L F
.42576 .66803 m .4293 .6608 L .43449 .66553 L F
.42576 .66803 m .42056 .66332 L .4293 .6608 L F
.44838 .66773 m .45202 .6605 L .45714 .66522 L F
.44838 .66773 m .44324 .66302 L .45202 .6605 L F
.471 .66742 m .47475 .66019 L .4798 .66492 L F
.471 .66742 m .46593 .66271 L .47475 .66019 L F
.49363 .66712 m .49749 .65988 L .50247 .66461 L F
.49363 .66712 m .48863 .6624 L .49749 .65988 L F
.38921 .66614 m .39258 .65889 L .39788 .66363 L F
.38921 .66614 m .38388 .66142 L .39258 .65889 L F
.41184 .66583 m .41532 .65859 L .42056 .66332 L F
.41184 .66583 m .40659 .66111 L .41532 .65859 L F
.43449 .66553 m .43807 .65828 L .44324 .66302 L F
.43449 .66553 m .4293 .6608 L .43807 .65828 L F
.45714 .66522 m .46083 .65797 L .46593 .66271 L F
.45714 .66522 m .45202 .6605 L .46083 .65797 L F
.4798 .66492 m .4836 .65766 L .48863 .6624 L F
.4798 .66492 m .47475 .66019 L .4836 .65766 L F
.50247 .66461 m .50638 .65735 L .51134 .66209 L F
.50247 .66461 m .49749 .65988 L .50638 .65735 L F
.37522 .66394 m .37853 .65667 L .38388 .66142 L F
.37522 .66394 m .36985 .6592 L .37853 .65667 L F
.39788 .66363 m .4013 .65636 L .40659 .66111 L F
.39788 .66363 m .39258 .65889 L .4013 .65636 L F
.42056 .66332 m .42408 .65605 L .4293 .6608 L F
.42056 .66332 m .41532 .65859 L .42408 .65605 L F
.44324 .66302 m .44687 .65574 L .45202 .6605 L F
.44324 .66302 m .43807 .65828 L .44687 .65574 L F
.46593 .66271 m .46967 .65543 L .47475 .66019 L F
.46593 .66271 m .46083 .65797 L .46967 .65543 L F
.48863 .6624 m .49248 .65512 L .49749 .65988 L F
.48863 .6624 m .4836 .65766 L .49248 .65512 L F
.51134 .66209 m .5153 .65481 L .52024 .65957 L F
.51134 .66209 m .50638 .65735 L .5153 .65481 L F
.38388 .66142 m .38724 .65413 L .39258 .65889 L F
.38388 .66142 m .37853 .65667 L .38724 .65413 L F
.40659 .66111 m .41005 .65382 L .41532 .65859 L F
.40659 .66111 m .4013 .65636 L .41005 .65382 L F
.4293 .6608 m .43287 .65351 L .43807 .65828 L F
.4293 .6608 m .42408 .65605 L .43287 .65351 L F
.45202 .6605 m .4557 .6532 L .46083 .65797 L F
.45202 .6605 m .44687 .65574 L .4557 .6532 L F
.47475 .66019 m .47854 .65289 L .4836 .65766 L F
.47475 .66019 m .46967 .65543 L .47854 .65289 L F
.49749 .65988 m .50139 .65258 L .50638 .65735 L F
.49749 .65988 m .49248 .65512 L .50139 .65258 L F
.52024 .65957 m .52424 .65226 L .52917 .65704 L F
.52024 .65957 m .5153 .65481 L .52424 .65226 L F
.36985 .6592 m .37314 .65189 L .37853 .65667 L F
.36985 .6592 m .36444 .65444 L .37314 .65189 L F
.39258 .65889 m .39598 .65158 L .4013 .65636 L F
.39258 .65889 m .38724 .65413 L .39598 .65158 L F
.41532 .65859 m .41883 .65127 L .42408 .65605 L F
.41532 .65859 m .41005 .65382 L .41883 .65127 L F
.43807 .65828 m .44169 .65096 L .44687 .65574 L F
.43807 .65828 m .43287 .65351 L .44169 .65096 L F
.46083 .65797 m .46456 .65065 L .46967 .65543 L F
.46083 .65797 m .4557 .6532 L .46456 .65065 L F
.4836 .65766 m .48744 .65033 L .49248 .65512 L F
.4836 .65766 m .47854 .65289 L .48744 .65033 L F
.50638 .65735 m .51032 .65002 L .5153 .65481 L F
.50638 .65735 m .50139 .65258 L .51032 .65002 L F
.52917 .65704 m .53322 .64971 L .53812 .6545 L F
.52917 .65704 m .52424 .65226 L .53322 .64971 L F
.37853 .65667 m .38187 .64934 L .38724 .65413 L F
.37853 .65667 m .37314 .65189 L .38187 .64934 L F
.4013 .65636 m .40475 .64902 L .41005 .65382 L F
.4013 .65636 m .39598 .65158 L .40475 .64902 L F
.42408 .65605 m .42764 .64871 L .43287 .65351 L F
.42408 .65605 m .41883 .65127 L .42764 .64871 L F
.44687 .65574 m .45054 .6484 L .4557 .6532 L F
.44687 .65574 m .44169 .65096 L .45054 .6484 L F
.46967 .65543 m .47345 .64809 L .47854 .65289 L F
.46967 .65543 m .46456 .65065 L .47345 .64809 L F
.49248 .65512 m .49636 .64777 L .50139 .65258 L F
.49248 .65512 m .48744 .65033 L .49636 .64777 L F
.5153 .65481 m .51929 .64746 L .52424 .65226 L F
.5153 .65481 m .51032 .65002 L .51929 .64746 L F
.53812 .6545 m .54222 .64715 L .54711 .65195 L F
.53812 .6545 m .53322 .64971 L .54222 .64715 L F
.36444 .65444 m .36772 .64708 L .37314 .65189 L F
.36444 .65444 m .359 .64965 L .36772 .64708 L F
.38724 .65413 m .39063 .64677 L .39598 .65158 L F
.38724 .65413 m .38187 .64934 L .39063 .64677 L F
.41005 .65382 m .41355 .64646 L .41883 .65127 L F
.41005 .65382 m .40475 .64902 L .41355 .64646 L F
.43287 .65351 m .43648 .64614 L .44169 .65096 L F
.43287 .65351 m .42764 .64871 L .43648 .64614 L F
.4557 .6532 m .45942 .64583 L .46456 .65065 L F
.4557 .6532 m .45054 .6484 L .45942 .64583 L F
.47854 .65289 m .48236 .64552 L .48744 .65033 L F
.47854 .65289 m .47345 .64809 L .48236 .64552 L F
.50139 .65258 m .50532 .6452 L .51032 .65002 L F
.50139 .65258 m .49636 .64777 L .50532 .6452 L F
.52424 .65226 m .52828 .64489 L .53322 .64971 L F
.52424 .65226 m .51929 .64746 L .52828 .64489 L F
.54711 .65195 m .55126 .64457 L .55612 .6494 L F
.54711 .65195 m .54222 .64715 L .55126 .64457 L F
.37314 .65189 m .37647 .64451 L .38187 .64934 L F
.37314 .65189 m .36772 .64708 L .37647 .64451 L F
.39598 .65158 m .39942 .6442 L .40475 .64902 L F
.39598 .65158 m .39063 .64677 L .39942 .6442 L F
.41883 .65127 m .42238 .64388 L .42764 .64871 L F
.41883 .65127 m .41355 .64646 L .42238 .64388 L F
.44169 .65096 m .44535 .64357 L .45054 .6484 L F
.44169 .65096 m .43648 .64614 L .44535 .64357 L F
.46456 .65065 m .46832 .64325 L .47345 .64809 L F
.46456 .65065 m .45942 .64583 L .46832 .64325 L F
.48744 .65033 m .49131 .64294 L .49636 .64777 L F
.48744 .65033 m .48236 .64552 L .49131 .64294 L F
.51032 .65002 m .5143 .64262 L .51929 .64746 L F
.51032 .65002 m .50532 .6452 L .5143 .64262 L F
.53322 .64971 m .53731 .64231 L .54222 .64715 L F
.53322 .64971 m .52828 .64489 L .53731 .64231 L F
.359 .64965 m .36227 .64225 L .36772 .64708 L F
.359 .64965 m .35353 .64483 L .36227 .64225 L F
.55612 .6494 m .56032 .64199 L .56517 .64683 L F
.55612 .6494 m .55126 .64457 L .56032 .64199 L F
.38187 .64934 m .38525 .64193 L .39063 .64677 L F
.38187 .64934 m .37647 .64451 L .38525 .64193 L F
.40475 .64902 m .40824 .64162 L .41355 .64646 L F
.40475 .64902 m .39942 .6442 L .40824 .64162 L F
.42764 .64871 m .43123 .6413 L .43648 .64614 L F
.42764 .64871 m .42238 .64388 L .43123 .6413 L F
.45054 .6484 m .45424 .64099 L .45942 .64583 L F
.45054 .6484 m .44535 .64357 L .45424 .64099 L F
.47345 .64809 m .47726 .64067 L .48236 .64552 L F
.47345 .64809 m .46832 .64325 L .47726 .64067 L F
.49636 .64777 m .50028 .64035 L .50532 .6452 L F
.49636 .64777 m .49131 .64294 L .50028 .64035 L F
.51929 .64746 m .52332 .64004 L .52828 .64489 L F
.51929 .64746 m .5143 .64262 L .52332 .64004 L F
.54222 .64715 m .54636 .63972 L .55126 .64457 L F
.54222 .64715 m .53731 .64231 L .54636 .63972 L F
.36772 .64708 m .37104 .63966 L .37647 .64451 L F
.36772 .64708 m .36227 .64225 L .37104 .63966 L F
.56517 .64683 m .56941 .63941 L .57424 .64426 L F
.56517 .64683 m .56032 .64199 L .56941 .63941 L F
.39063 .64677 m .39405 .63934 L .39942 .6442 L F
.39063 .64677 m .38525 .64193 L .39405 .63934 L F
.41355 .64646 m .41708 .63903 L .42238 .64388 L F
.41355 .64646 m .40824 .64162 L .41708 .63903 L F
.43648 .64614 m .44012 .63871 L .44535 .64357 L F
.43648 .64614 m .43123 .6413 L .44012 .63871 L F
.45942 .64583 m .46317 .63839 L .46832 .64325 L F
.45942 .64583 m .45424 .64099 L .46317 .63839 L F
.48236 .64552 m .48622 .63808 L .49131 .64294 L F
.48236 .64552 m .47726 .64067 L .48622 .63808 L F
.50532 .6452 m .50929 .63776 L .5143 .64262 L F
.50532 .6452 m .50028 .64035 L .50929 .63776 L F
.52828 .64489 m .53236 .63744 L .53731 .64231 L F
.52828 .64489 m .52332 .64004 L .53236 .63744 L F
.35353 .64483 m .35678 .63738 L .36227 .64225 L F
.35353 .64483 m .34803 .63998 L .35678 .63738 L F
.55126 .64457 m .55544 .63713 L .56032 .64199 L F
.55126 .64457 m .54636 .63972 L .55544 .63713 L F
.37647 .64451 m .37983 .63706 L .38525 .64193 L F
.37647 .64451 m .37104 .63966 L .37983 .63706 L F
.57424 .64426 m .57854 .63681 L .58334 .64168 L F
.57424 .64426 m .56941 .63941 L .57854 .63681 L F
.39942 .6442 m .40289 .63675 L .40824 .64162 L F
.39942 .6442 m .39405 .63934 L .40289 .63675 L F
.42238 .64388 m .42596 .63643 L .43123 .6413 L F
.42238 .64388 m .41708 .63903 L .42596 .63643 L F
.44535 .64357 m .44903 .63611 L .45424 .64099 L F
.44535 .64357 m .44012 .63871 L .44903 .63611 L F
.46832 .64325 m .47212 .63579 L .47726 .64067 L F
.46832 .64325 m .46317 .63839 L .47212 .63579 L F
.49131 .64294 m .49522 .63548 L .50028 .64035 L F
.49131 .64294 m .48622 .63808 L .49522 .63548 L F
.5143 .64262 m .51832 .63516 L .52332 .64004 L F
.5143 .64262 m .50929 .63776 L .51832 .63516 L F
.53731 .64231 m .54143 .63484 L .54636 .63972 L F
.53731 .64231 m .53236 .63744 L .54143 .63484 L F
.36227 .64225 m .36557 .63478 L .37104 .63966 L F
.36227 .64225 m .35678 .63738 L .36557 .63478 L F
.56032 .64199 m .56456 .63452 L .56941 .63941 L F
.56032 .64199 m .55544 .63713 L .56456 .63452 L F
.38525 .64193 m .38866 .63446 L .39405 .63934 L F
.38525 .64193 m .37983 .63706 L .38866 .63446 L F
.58334 .64168 m .58769 .6342 L .59248 .63909 L F
.58334 .64168 m .57854 .63681 L .58769 .6342 L F
.40824 .64162 m .41175 .63414 L .41708 .63903 L F
.40824 .64162 m .40289 .63675 L .41175 .63414 L F
.43123 .6413 m .43486 .63382 L .44012 .63871 L F
.43123 .6413 m .42596 .63643 L .43486 .63382 L F
.45424 .64099 m .45798 .6335 L .46317 .63839 L F
.45424 .64099 m .44903 .63611 L .45798 .6335 L F
.47726 .64067 m .4811 .63318 L .48622 .63808 L F
.47726 .64067 m .47212 .63579 L .4811 .63318 L F
.50028 .64035 m .50424 .63287 L .50929 .63776 L F
.50028 .64035 m .49522 .63548 L .50424 .63287 L F
.52332 .64004 m .52738 .63255 L .53236 .63744 L F
.52332 .64004 m .51832 .63516 L .52738 .63255 L F
.34803 .63998 m .35126 .63248 L .35678 .63738 L F
.34803 .63998 m .34249 .6351 L .35126 .63248 L F
.54636 .63972 m .55054 .63223 L .55544 .63713 L F
.54636 .63972 m .54143 .63484 L .55054 .63223 L F
.37104 .63966 m .37438 .63216 L .37983 .63706 L F
.37104 .63966 m .36557 .63478 L .37438 .63216 L F
.56941 .63941 m .5737 .63191 L .57854 .63681 L F
.56941 .63941 m .56456 .63452 L .5737 .63191 L F
.39405 .63934 m .39751 .63185 L .40289 .63675 L F
.39405 .63934 m .38866 .63446 L .39751 .63185 L F
.59248 .63909 m .59687 .63159 L .60164 .63649 L F
.59248 .63909 m .58769 .6342 L .59687 .63159 L F
.41708 .63903 m .42065 .63153 L .42596 .63643 L F
.41708 .63903 m .41175 .63414 L .42065 .63153 L F
.44012 .63871 m .44379 .63121 L .44903 .63611 L F
.44012 .63871 m .43486 .63382 L .44379 .63121 L F
.46317 .63839 m .46695 .63089 L .47212 .63579 L F
.46317 .63839 m .45798 .6335 L .46695 .63089 L F
.48622 .63808 m .49012 .63057 L .49522 .63548 L F
.48622 .63808 m .4811 .63318 L .49012 .63057 L F
.50929 .63776 m .51329 .63025 L .51832 .63516 L F
.50929 .63776 m .50424 .63287 L .51329 .63025 L F
.53236 .63744 m .53648 .62993 L .54143 .63484 L F
.53236 .63744 m .52738 .63255 L .53648 .62993 L F
.35678 .63738 m .36006 .62986 L .36557 .63478 L F
.35678 .63738 m .35126 .63248 L .36006 .62986 L F
.55544 .63713 m .55967 .62961 L .56456 .63452 L F
.55544 .63713 m .55054 .63223 L .55967 .62961 L F
.37983 .63706 m .38322 .62954 L .38866 .63446 L F
.37983 .63706 m .37438 .63216 L .38322 .62954 L F
.57854 .63681 m .58287 .62929 L .58769 .6342 L F
.57854 .63681 m .5737 .63191 L .58287 .62929 L F
.40289 .63675 m .40639 .62922 L .41175 .63414 L F
.40289 .63675 m .39751 .63185 L .40639 .62922 L F
.60164 .63649 m .60609 .62897 L .61083 .63388 L F
.60164 .63649 m .59687 .63159 L .60609 .62897 L F
.42596 .63643 m .42957 .6289 L .43486 .63382 L F
.42596 .63643 m .42065 .63153 L .42957 .6289 L F
.44903 .63611 m .45276 .62858 L .45798 .6335 L F
.44903 .63611 m .44379 .63121 L .45276 .62858 L F
.47212 .63579 m .47595 .62826 L .4811 .63318 L F
.47212 .63579 m .46695 .63089 L .47595 .62826 L F
.49522 .63548 m .49916 .62794 L .50424 .63287 L F
.49522 .63548 m .49012 .63057 L .49916 .62794 L F
.51832 .63516 m .52238 .62762 L .52738 .63255 L F
.51832 .63516 m .51329 .63025 L .52238 .62762 L F
.34249 .6351 m .34571 .62756 L .35126 .63248 L F
.34249 .6351 m .33691 .63018 L .34571 .62756 L F
.54143 .63484 m .5456 .6273 L .55054 .63223 L F
.54143 .63484 m .53648 .62993 L .5456 .6273 L F
.36557 .63478 m .3689 .62724 L .37438 .63216 L F
.36557 .63478 m .36006 .62986 L .3689 .62724 L F
.56456 .63452 m .56884 .62698 L .5737 .63191 L F
.56456 .63452 m .55967 .62961 L .56884 .62698 L F
.38866 .63446 m .3921 .62691 L .39751 .63185 L F
.38866 .63446 m .38322 .62954 L .3921 .62691 L F
.58769 .6342 m .59208 .62666 L .59687 .63159 L F
.58769 .6342 m .58287 .62929 L .59208 .62666 L F
.41175 .63414 m .4153 .62659 L .42065 .63153 L F
.41175 .63414 m .40639 .62922 L .4153 .62659 L F
.61083 .63388 m .61533 .62633 L .62006 .63127 L F
.61083 .63388 m .60609 .62897 L .61533 .62633 L F
.43486 .63382 m .43852 .62627 L .44379 .63121 L F
.43486 .63382 m .42957 .6289 L .43852 .62627 L F
.45798 .6335 m .46175 .62595 L .46695 .63089 L F
.45798 .6335 m .45276 .62858 L .46175 .62595 L F
.4811 .63318 m .48499 .62563 L .49012 .63057 L F
.4811 .63318 m .47595 .62826 L .48499 .62563 L F
.50424 .63287 m .50823 .62531 L .51329 .63025 L F
.50424 .63287 m .49916 .62794 L .50823 .62531 L F
.52738 .63255 m .53149 .62498 L .53648 .62993 L F
.52738 .63255 m .52238 .62762 L .53149 .62498 L F
.35126 .63248 m .35453 .62492 L .36006 .62986 L F
.35126 .63248 m .34571 .62756 L .35453 .62492 L F
.55054 .63223 m .55475 .62466 L .55967 .62961 L F
.55054 .63223 m .5456 .6273 L .55475 .62466 L F
.37438 .63216 m .37776 .6246 L .38322 .62954 L F
.37438 .63216 m .3689 .62724 L .37776 .6246 L F
.5737 .63191 m .57803 .62434 L .58287 .62929 L F
.5737 .63191 m .56884 .62698 L .57803 .62434 L F
.39751 .63185 m .401 .62428 L .40639 .62922 L F
.39751 .63185 m .3921 .62691 L .401 .62428 L F
.59687 .63159 m .60131 .62402 L .60609 .62897 L F
.59687 .63159 m .59208 .62666 L .60131 .62402 L F
.42065 .63153 m .42425 .62395 L .42957 .6289 L F
.42065 .63153 m .4153 .62659 L .42425 .62395 L F
.62006 .63127 m .62461 .62369 L .62931 .62864 L F
.62006 .63127 m .61533 .62633 L .62461 .62369 L F
.44379 .63121 m .4475 .62363 L .45276 .62858 L F
.44379 .63121 m .43852 .62627 L .4475 .62363 L F
.46695 .63089 m .47077 .62331 L .47595 .62826 L F
.46695 .63089 m .46175 .62595 L .47077 .62331 L F
.49012 .63057 m .49405 .62298 L .49916 .62794 L F
.49012 .63057 m .48499 .62563 L .49405 .62298 L F
.51329 .63025 m .51734 .62266 L .52238 .62762 L F
.51329 .63025 m .50823 .62531 L .51734 .62266 L F
.33691 .63018 m .34012 .6226 L .34571 .62756 L F
.33691 .63018 m .33131 .62524 L .34012 .6226 L F
.53648 .62993 m .54063 .62234 L .5456 .6273 L F
.53648 .62993 m .53149 .62498 L .54063 .62234 L F
.36006 .62986 m .36338 .62228 L .3689 .62724 L F
.36006 .62986 m .35453 .62492 L .36338 .62228 L F
.55967 .62961 m .56394 .62202 L .56884 .62698 L F
.55967 .62961 m .55475 .62466 L .56394 .62202 L F
.38322 .62954 m .38665 .62195 L .3921 .62691 L F
.38322 .62954 m .37776 .6246 L .38665 .62195 L F
.58287 .62929 m .58725 .62169 L .59208 .62666 L F
.58287 .62929 m .57803 .62434 L .58725 .62169 L F
.40639 .62922 m .40993 .62163 L .4153 .62659 L F
.40639 .62922 m .401 .62428 L .40993 .62163 L F
.60609 .62897 m .61058 .62137 L .61533 .62633 L F
.60609 .62897 m .60131 .62402 L .61058 .62137 L F
.42957 .6289 m .43322 .6213 L .43852 .62627 L F
.42957 .6289 m .42425 .62395 L .43322 .6213 L F
.62931 .62864 m .63391 .62104 L .63859 .62601 L F
.62931 .62864 m .62461 .62369 L .63391 .62104 L F
.45276 .62858 m .45652 .62098 L .46175 .62595 L F
.45276 .62858 m .4475 .62363 L .45652 .62098 L F
.47595 .62826 m .47982 .62066 L .48499 .62563 L F
.47595 .62826 m .47077 .62331 L .47982 .62066 L F
.49916 .62794 m .50314 .62033 L .50823 .62531 L F
.49916 .62794 m .49405 .62298 L .50314 .62033 L F
.52238 .62762 m .52647 .62001 L .53149 .62498 L F
.52238 .62762 m .51734 .62266 L .52647 .62001 L F
.34571 .62756 m .34895 .61995 L .35453 .62492 L F
.34571 .62756 m .34012 .6226 L .34895 .61995 L F
.5456 .6273 m .54981 .61968 L .55475 .62466 L F
.5456 .6273 m .54063 .62234 L .54981 .61968 L F
.3689 .62724 m .37226 .61962 L .37776 .6246 L F
.3689 .62724 m .36338 .62228 L .37226 .61962 L F
.56884 .62698 m .57315 .61936 L .57803 .62434 L F
.56884 .62698 m .56394 .62202 L .57315 .61936 L F
.3921 .62691 m .39557 .6193 L .401 .62428 L F
.3921 .62691 m .38665 .62195 L .39557 .6193 L F
.59208 .62666 m .59651 .61904 L .60131 .62402 L F
.59208 .62666 m .58725 .62169 L .59651 .61904 L F
.4153 .62659 m .41889 .61897 L .42425 .62395 L F
.4153 .62659 m .40993 .62163 L .41889 .61897 L F
.61533 .62633 m .61987 .61871 L .62461 .62369 L F
.61533 .62633 m .61058 .62137 L .61987 .61871 L F
.43852 .62627 m .44222 .61865 L .4475 .62363 L F
.43852 .62627 m .43322 .6213 L .44222 .61865 L F
.63859 .62601 m .64325 .61839 L .64791 .62337 L F
.63859 .62601 m .63391 .62104 L .64325 .61839 L F
.46175 .62595 m .46556 .61832 L .47077 .62331 L F
.46175 .62595 m .45652 .62098 L .46556 .61832 L F
.48499 .62563 m .48891 .618 L .49405 .62298 L F
.48499 .62563 m .47982 .62066 L .48891 .618 L F
.50823 .62531 m .51227 .61767 L .51734 .62266 L F
.50823 .62531 m .50314 .62033 L .51227 .61767 L F
.33131 .62524 m .33449 .61761 L .34012 .6226 L F
.33131 .62524 m .32566 .62027 L .33449 .61761 L F
.53149 .62498 m .53563 .61735 L .54063 .62234 L F
.53149 .62498 m .52647 .62001 L .53563 .61735 L F
.35453 .62492 m .35782 .61728 L .36338 .62228 L F
.35453 .62492 m .34895 .61995 L .35782 .61728 L F
.55475 .62466 m .55901 .61702 L .56394 .62202 L F
.55475 .62466 m .54981 .61968 L .55901 .61702 L F
.37776 .6246 m .38117 .61696 L .38665 .62195 L F
.37776 .6246 m .37226 .61962 L .38117 .61696 L F
.57803 .62434 m .5824 .6167 L .58725 .62169 L F
.57803 .62434 m .57315 .61936 L .5824 .6167 L F
.401 .62428 m .40452 .61663 L .40993 .62163 L F
.401 .62428 m .39557 .6193 L .40452 .61663 L F
.60131 .62402 m .6058 .61637 L .61058 .62137 L F
.60131 .62402 m .59651 .61904 L .6058 .61637 L F
.42425 .62395 m .42788 .61631 L .43322 .6213 L F
.42425 .62395 m .41889 .61897 L .42788 .61631 L F
.62461 .62369 m .6292 .61605 L .63391 .62104 L F
.62461 .62369 m .61987 .61871 L .6292 .61605 L F
.4475 .62363 m .45125 .61598 L .45652 .62098 L F
.4475 .62363 m .44222 .61865 L .45125 .61598 L F
.64791 .62337 m .65262 .61572 L .65726 .62072 L F
.64791 .62337 m .64325 .61839 L .65262 .61572 L F
.47077 .62331 m .47463 .61566 L .47982 .62066 L F
.47077 .62331 m .46556 .61832 L .47463 .61566 L F
.49405 .62298 m .49802 .61533 L .50314 .62033 L F
.49405 .62298 m .48891 .618 L .49802 .61533 L F
.51734 .62266 m .52142 .615 L .52647 .62001 L F
.51734 .62266 m .51227 .61767 L .52142 .615 L F
.34012 .6226 m .34335 .61494 L .34895 .61995 L F
.34012 .6226 m .33449 .61761 L .34335 .61494 L F
.54063 .62234 m .54483 .61468 L .54981 .61968 L F
.54063 .62234 m .53563 .61735 L .54483 .61468 L F
.36338 .62228 m .36672 .61461 L .37226 .61962 L F
.36338 .62228 m .35782 .61728 L .36672 .61461 L F
.56394 .62202 m .56825 .61435 L .57315 .61936 L F
.56394 .62202 m .55901 .61702 L .56825 .61435 L F
.38665 .62195 m .3901 .61429 L .39557 .6193 L F
.38665 .62195 m .38117 .61696 L .3901 .61429 L F
.58725 .62169 m .59168 .61402 L .59651 .61904 L F
.58725 .62169 m .5824 .6167 L .59168 .61402 L F
.40993 .62163 m .4135 .61396 L .41889 .61897 L F
.40993 .62163 m .40452 .61663 L .4135 .61396 L F
.61058 .62137 m .61511 .6137 L .61987 .61871 L F
.61058 .62137 m .6058 .61637 L .61511 .6137 L F
.43322 .6213 m .4369 .61363 L .44222 .61865 L F
.43322 .6213 m .42788 .61631 L .4369 .61363 L F
.63391 .62104 m .63856 .61337 L .64325 .61839 L F
.63391 .62104 m .6292 .61605 L .63856 .61337 L F
.45652 .62098 m .46031 .61331 L .46556 .61832 L F
.45652 .62098 m .45125 .61598 L .46031 .61331 L F
.65726 .62072 m .66202 .61304 L .66663 .61806 L F
.65726 .62072 m .65262 .61572 L .66202 .61304 L F
.47982 .62066 m .48373 .61298 L .48891 .618 L F
.47982 .62066 m .47463 .61566 L .48373 .61298 L F
.50314 .62033 m .50716 .61265 L .51227 .61767 L F
.50314 .62033 m .49802 .61533 L .50716 .61265 L F
.32566 .62027 m .32883 .61259 L .33449 .61761 L F
.32566 .62027 m .31998 .61527 L .32883 .61259 L F
.52647 .62001 m .5306 .61233 L .53563 .61735 L F
.52647 .62001 m .52142 .615 L .5306 .61233 L F
.34895 .61995 m .35223 .61226 L .35782 .61728 L F
.34895 .61995 m .34335 .61494 L .35223 .61226 L F
.54981 .61968 m .55405 .612 L .55901 .61702 L F
.54981 .61968 m .54483 .61468 L .55405 .612 L F
.37226 .61962 m .37565 .61193 L .38117 .61696 L F
.37226 .61962 m .36672 .61461 L .37565 .61193 L F
.57315 .61936 m .57751 .61167 L .5824 .6167 L F
.57315 .61936 m .56825 .61435 L .57751 .61167 L F
.39557 .6193 m .39907 .61161 L .40452 .61663 L F
.39557 .6193 m .3901 .61429 L .39907 .61161 L F
.59651 .61904 m .60098 .61134 L .6058 .61637 L F
.59651 .61904 m .59168 .61402 L .60098 .61134 L F
.41889 .61897 m .42251 .61128 L .42788 .61631 L F
.41889 .61897 m .4135 .61396 L .42251 .61128 L F
.61987 .61871 m .62446 .61102 L .6292 .61605 L F
.61987 .61871 m .61511 .6137 L .62446 .61102 L F
.44222 .61865 m .44595 .61095 L .45125 .61598 L F
.44222 .61865 m .4369 .61363 L .44595 .61095 L F
.64325 .61839 m .64795 .61069 L .65262 .61572 L F
.64325 .61839 m .63856 .61337 L .64795 .61069 L F
.46556 .61832 m .4694 .61062 L .47463 .61566 L F
.46556 .61832 m .46031 .61331 L .4694 .61062 L F
.66663 .61806 m .67145 .61036 L .67604 .61539 L F
.66663 .61806 m .66202 .61304 L .67145 .61036 L F
.48891 .618 m .49287 .6103 L .49802 .61533 L F
.48891 .618 m .48373 .61298 L .49287 .6103 L F
.51227 .61767 m .51634 .60997 L .52142 .615 L F
.51227 .61767 m .50716 .61265 L .51634 .60997 L F
.33449 .61761 m .33771 .6099 L .34335 .61494 L F
.33449 .61761 m .32883 .61259 L .33771 .6099 L F
.53563 .61735 m .53982 .60964 L .54483 .61468 L F
.53563 .61735 m .5306 .61233 L .53982 .60964 L F
.35782 .61728 m .36115 .60957 L .36672 .61461 L F
.35782 .61728 m .35223 .61226 L .36115 .60957 L F
.55901 .61702 m .56331 .60931 L .56825 .61435 L F
.55901 .61702 m .55405 .612 L .56331 .60931 L F
.38117 .61696 m .38461 .60925 L .3901 .61429 L F
.38117 .61696 m .37565 .61193 L .38461 .60925 L F
.5824 .6167 m .58681 .60898 L .59168 .61402 L F
.5824 .6167 m .57751 .61167 L .58681 .60898 L F
.40452 .61663 m .40807 .60892 L .4135 .61396 L F
.40452 .61663 m .39907 .61161 L .40807 .60892 L F
.6058 .61637 m .61032 .60865 L .61511 .6137 L F
.6058 .61637 m .60098 .61134 L .61032 .60865 L F
.42788 .61631 m .43155 .60859 L .4369 .61363 L F
.42788 .61631 m .42251 .61128 L .43155 .60859 L F
.6292 .61605 m .63384 .60832 L .63856 .61337 L F
.6292 .61605 m .62446 .61102 L .63384 .60832 L F
.45125 .61598 m .45503 .60826 L .46031 .61331 L F
.45125 .61598 m .44595 .61095 L .45503 .60826 L F
.65262 .61572 m .65737 .60799 L .66202 .61304 L F
.65262 .61572 m .64795 .61069 L .65737 .60799 L F
.47463 .61566 m .47853 .60793 L .48373 .61298 L F
.47463 .61566 m .4694 .61062 L .47853 .60793 L F
.67604 .61539 m .68091 .60767 L .68548 .61272 L F
.67604 .61539 m .67145 .61036 L .68091 .60767 L F
.49802 .61533 m .50203 .6076 L .50716 .61265 L F
.49802 .61533 m .49287 .6103 L .50203 .6076 L F
.31998 .61527 m .32313 .60754 L .32883 .61259 L F
.31998 .61527 m .31427 .61023 L .32313 .60754 L F
.52142 .615 m .52554 .60727 L .5306 .61233 L F
.52142 .615 m .51634 .60997 L .52554 .60727 L F
.34335 .61494 m .34661 .60721 L .35223 .61226 L F
.34335 .61494 m .33771 .6099 L .34661 .60721 L F
.54483 .61468 m .54907 .60694 L .55405 .612 L F
.54483 .61468 m .53982 .60964 L .54907 .60694 L F
.36672 .61461 m .3701 .60688 L .37565 .61193 L F
.36672 .61461 m .36115 .60957 L .3701 .60688 L F
.56825 .61435 m .5726 .60661 L .57751 .61167 L F
.56825 .61435 m .56331 .60931 L .5726 .60661 L F
.3901 .61429 m .3936 .60655 L .39907 .61161 L F
.3901 .61429 m .38461 .60925 L .3936 .60655 L F
.59168 .61402 m .59614 .60628 L .60098 .61134 L F
.59168 .61402 m .58681 .60898 L .59614 .60628 L F
.4135 .61396 m .4171 .60622 L .42251 .61128 L F
.4135 .61396 m .40807 .60892 L .4171 .60622 L F
.61511 .6137 m .61969 .60595 L .62446 .61102 L F
.61511 .6137 m .61032 .60865 L .61969 .60595 L F
.4369 .61363 m .44062 .60589 L .44595 .61095 L F
.4369 .61363 m .43155 .60859 L .44062 .60589 L F
.63856 .61337 m .64325 .60562 L .64795 .61069 L F
.63856 .61337 m .63384 .60832 L .64325 .60562 L F
.46031 .61331 m .46414 .60556 L .4694 .61062 L F
.46031 .61331 m .45503 .60826 L .46414 .60556 L F
.66202 .61304 m .66682 .60529 L .67145 .61036 L F
.66202 .61304 m .65737 .60799 L .66682 .60529 L F
.48373 .61298 m .48768 .60523 L .49287 .6103 L F
.48373 .61298 m .47853 .60793 L .48768 .60523 L F
.68548 .61272 m .6904 .60496 L .69496 .61003 L F
.68548 .61272 m .68091 .60767 L .6904 .60496 L F
.50716 .61265 m .51122 .6049 L .51634 .60997 L F
.50716 .61265 m .50203 .6076 L .51122 .6049 L F
.32883 .61259 m .33203 .60483 L .33771 .6099 L F
.32883 .61259 m .32313 .60754 L .33203 .60483 L F
.5306 .61233 m .53478 .60457 L .53982 .60964 L F
.5306 .61233 m .52554 .60727 L .53478 .60457 L F
.35223 .61226 m .35555 .6045 L .36115 .60957 L F
.35223 .61226 m .34661 .60721 L .35555 .6045 L F
.55405 .612 m .55834 .60424 L .56331 .60931 L F
.55405 .612 m .54907 .60694 L .55834 .60424 L F
.37565 .61193 m .37908 .60417 L .38461 .60925 L F
.37565 .61193 m .3701 .60688 L .37908 .60417 L F
.57751 .61167 m .58192 .60391 L .58681 .60898 L F
.57751 .61167 m .5726 .60661 L .58192 .60391 L F
.39907 .61161 m .40261 .60384 L .40807 .60892 L F
.39907 .61161 m .3936 .60655 L .40261 .60384 L F
.60098 .61134 m .6055 .60358 L .61032 .60865 L F
.60098 .61134 m .59614 .60628 L .6055 .60358 L F
.42251 .61128 m .42616 .60351 L .43155 .60859 L F
.42251 .61128 m .4171 .60622 L .42616 .60351 L F
.62446 .61102 m .62909 .60324 L .63384 .60832 L F
.62446 .61102 m .61969 .60595 L .62909 .60324 L F
.44595 .61095 m .44972 .60318 L .45503 .60826 L F
.44595 .61095 m .44062 .60589 L .44972 .60318 L F
.64795 .61069 m .6527 .60291 L .65737 .60799 L F
.64795 .61069 m .64325 .60562 L .6527 .60291 L F
.4694 .61062 m .47329 .60285 L .47853 .60793 L F
.4694 .61062 m .46414 .60556 L .47329 .60285 L F
.67145 .61036 m .67631 .60258 L .68091 .60767 L F
.67145 .61036 m .66682 .60529 L .67631 .60258 L F
.49287 .6103 m .49686 .60252 L .50203 .6076 L F
.49287 .6103 m .48768 .60523 L .49686 .60252 L F
.31427 .61023 m .3174 .60245 L .32313 .60754 L F
.31427 .61023 m .30852 .60516 L .3174 .60245 L F
.69496 .61003 m .69993 .60225 L .70446 .60734 L F
.69496 .61003 m .6904 .60496 L .69993 .60225 L F
.51634 .60997 m .52045 .60219 L .52554 .60727 L F
.51634 .60997 m .51122 .6049 L .52045 .60219 L F
.33771 .6099 m .34095 .60212 L .34661 .60721 L F
.33771 .6099 m .33203 .60483 L .34095 .60212 L F
.53982 .60964 m .54404 .60185 L .54907 .60694 L F
.53982 .60964 m .53478 .60457 L .54404 .60185 L F
.36115 .60957 m .36451 .60179 L .3701 .60688 L F
.36115 .60957 m .35555 .6045 L .36451 .60179 L F
.56331 .60931 m .56765 .60152 L .5726 .60661 L F
.56331 .60931 m .55834 .60424 L .56765 .60152 L F
.38461 .60925 m .38808 .60146 L .3936 .60655 L F
.38461 .60925 m .37908 .60417 L .38808 .60146 L F
.58681 .60898 m .59127 .60119 L .59614 .60628 L F
.58681 .60898 m .58192 .60391 L .59127 .60119 L F
.40807 .60892 m .41166 .60113 L .4171 .60622 L F
.40807 .60892 m .40261 .60384 L .41166 .60113 L F
.61032 .60865 m .61489 .60086 L .61969 .60595 L F
.61032 .60865 m .6055 .60358 L .61489 .60086 L F
.43155 .60859 m .43525 .60079 L .44062 .60589 L F
.43155 .60859 m .42616 .60351 L .43525 .60079 L F
.63384 .60832 m .63853 .60053 L .64325 .60562 L F
.63384 .60832 m .62909 .60324 L .63853 .60053 L F
.45503 .60826 m .45885 .60046 L .46414 .60556 L F
.45503 .60826 m .44972 .60318 L .45885 .60046 L F
.65737 .60799 m .66217 .60019 L .66682 .60529 L F
.65737 .60799 m .6527 .60291 L .66217 .60019 L F
.47853 .60793 m .48246 .60013 L .48768 .60523 L F
.47853 .60793 m .47329 .60285 L .48246 .60013 L F
.68091 .60767 m .68582 .59986 L .6904 .60496 L F
.68091 .60767 m .67631 .60258 L .68582 .59986 L F
.50203 .6076 m .50608 .5998 L .51122 .6049 L F
.50203 .6076 m .49686 .60252 L .50608 .5998 L F
.32313 .60754 m .32631 .59973 L .33203 .60483 L F
.32313 .60754 m .3174 .60245 L .32631 .59973 L F
.70446 .60734 m .70949 .59953 L .71399 .60463 L F
.70446 .60734 m .69993 .60225 L .70949 .59953 L F
.52554 .60727 m .52971 .59946 L .53478 .60457 L F
.52554 .60727 m .52045 .60219 L .52971 .59946 L F
.34661 .60721 m .34991 .5994 L .35555 .6045 L F
.34661 .60721 m .34095 .60212 L .34991 .5994 L F
.54907 .60694 m .55334 .59913 L .55834 .60424 L F
.54907 .60694 m .54404 .60185 L .55334 .59913 L F
.3701 .60688 m .37351 .59907 L .37908 .60417 L F
.3701 .60688 m .36451 .60179 L .37351 .59907 L F
.5726 .60661 m .57699 .5988 L .58192 .60391 L F
.5726 .60661 m .56765 .60152 L .57699 .5988 L F
.3936 .60655 m .39712 .59873 L .40261 .60384 L F
.3936 .60655 m .38808 .60146 L .39712 .59873 L F
.59614 .60628 m .60065 .59847 L .6055 .60358 L F
.59614 .60628 m .59127 .60119 L .60065 .59847 L F
.4171 .60622 m .42074 .5984 L .42616 .60351 L F
.4171 .60622 m .41166 .60113 L .42074 .5984 L F
.61969 .60595 m .62431 .59813 L .62909 .60324 L F
.61969 .60595 m .61489 .60086 L .62431 .59813 L F
.44062 .60589 m .44437 .59807 L .44972 .60318 L F
.44062 .60589 m .43525 .60079 L .44437 .59807 L F
.64325 .60562 m .64799 .5978 L .6527 .60291 L F
.64325 .60562 m .63853 .60053 L .64799 .5978 L F
.46414 .60556 m .46801 .59774 L .47329 .60285 L F
.46414 .60556 m .45885 .60046 L .46801 .59774 L F
.66682 .60529 m .67168 .59747 L .67631 .60258 L F
.66682 .60529 m .66217 .60019 L .67168 .59747 L F
.48768 .60523 m .49166 .5974 L .49686 .60252 L F
.48768 .60523 m .48246 .60013 L .49166 .5974 L F
.30852 .60516 m .31163 .59734 L .3174 .60245 L F
.30852 .60516 m .30273 .60006 L .31163 .59734 L F
.6904 .60496 m .69537 .59713 L .69993 .60225 L F
.6904 .60496 m .68582 .59986 L .69537 .59713 L F
.51122 .6049 m .51532 .59707 L .52045 .60219 L F
.51122 .6049 m .50608 .5998 L .51532 .59707 L F
.33203 .60483 m .33526 .597 L .34095 .60212 L F
.33203 .60483 m .32631 .59973 L .33526 .597 L F
.71399 .60463 m .71908 .5968 L .72356 .60192 L F
.71399 .60463 m .70949 .59953 L .71908 .5968 L F
.53478 .60457 m .53899 .59673 L .54404 .60185 L F
.53478 .60457 m .52971 .59946 L .53899 .59673 L F
.35555 .6045 m .35889 .59667 L .36451 .60179 L F
.35555 .6045 m .34991 .5994 L .35889 .59667 L F
.55834 .60424 m .56267 .5964 L .56765 .60152 L F
.55834 .60424 m .55334 .59913 L .56267 .5964 L F
.37908 .60417 m .38253 .59634 L .38808 .60146 L F
.37908 .60417 m .37351 .59907 L .38253 .59634 L F
.58192 .60391 m .58636 .59607 L .59127 .60119 L F
.58192 .60391 m .57699 .5988 L .58636 .59607 L F
.40261 .60384 m .40619 .596 L .41166 .60113 L F
.40261 .60384 m .39712 .59873 L .40619 .596 L F
.6055 .60358 m .61006 .59573 L .61489 .60086 L F
.6055 .60358 m .60065 .59847 L .61006 .59573 L F
.42616 .60351 m .42985 .59567 L .43525 .60079 L F
.42616 .60351 m .42074 .5984 L .42985 .59567 L F
.62909 .60324 m .63377 .5954 L .63853 .60053 L F
.62909 .60324 m .62431 .59813 L .63377 .5954 L F
.44972 .60318 m .45352 .59533 L .45885 .60046 L F
.44972 .60318 m .44437 .59807 L .45352 .59533 L F
.6527 .60291 m .65749 .59506 L .66217 .60019 L F
.6527 .60291 m .64799 .5978 L .65749 .59506 L F
.47329 .60285 m .47721 .595 L .48246 .60013 L F
.47329 .60285 m .46801 .59774 L .47721 .595 L F
.67631 .60258 m .68122 .59473 L .68582 .59986 L F
.67631 .60258 m .67168 .59747 L .68122 .59473 L F
.49686 .60252 m .5009 .59466 L .50608 .5998 L F
.49686 .60252 m .49166 .5974 L .5009 .59466 L F
.3174 .60245 m .32057 .5946 L .32631 .59973 L F
.3174 .60245 m .31163 .59734 L .32057 .5946 L F
.69993 .60225 m .70495 .5944 L .70949 .59953 L F
.69993 .60225 m .69537 .59713 L .70495 .5944 L F
.52045 .60219 m .5246 .59433 L .52971 .59946 L F
.52045 .60219 m .51532 .59707 L .5246 .59433 L F
.34095 .60212 m .34423 .59426 L .34991 .5994 L F
.34095 .60212 m .33526 .597 L .34423 .59426 L F
.72356 .60192 m .7287 .59406 L .73316 .5992 L F
.72356 .60192 m .71908 .5968 L .7287 .59406 L F
.54404 .60185 m .54831 .594 L .55334 .59913 L F
.54404 .60185 m .53899 .59673 L .54831 .594 L F
.36451 .60179 m .36791 .59393 L .37351 .59907 L F
.36451 .60179 m .35889 .59667 L .36791 .59393 L F
.56765 .60152 m .57203 .59366 L .57699 .5988 L F
.56765 .60152 m .56267 .5964 L .57203 .59366 L F
.38808 .60146 m .39159 .59359 L .39712 .59873 L F
.38808 .60146 m .38253 .59634 L .39159 .59359 L F
.59127 .60119 m .59576 .59333 L .60065 .59847 L F
.59127 .60119 m .58636 .59607 L .59576 .59333 L F
.41166 .60113 m .41529 .59326 L .42074 .5984 L F
.41166 .60113 m .40619 .596 L .41529 .59326 L F
.61489 .60086 m .61951 .59299 L .62431 .59813 L F
.61489 .60086 m .61006 .59573 L .61951 .59299 L F
.24896 .55268 m .24279 .54724 L .24284 .54723 L F
.24897 .55263 m .24284 .54723 L .25188 .54433 L F
.24896 .55268 m .24284 .54723 L .24897 .55263 L F
.937 .687 .533 r
.2369 .542 m .2423 .5531 L .23607 .54764 L F
.25184 .43914 m .2423 .5531 L .25216 .43815 L F
.25216 .43815 m .2428 .5472 L .2369 .542 L F
.2428 .5472 m .2423 .5531 L .2369 .542 L F
.656 .751 .92 r
.43525 .60079 m .43899 .59292 L .44437 .59807 L F
.43525 .60079 m .42985 .59567 L .43899 .59292 L F
.63853 .60053 m .64326 .59265 L .64799 .5978 L F
.63853 .60053 m .63377 .5954 L .64326 .59265 L F
.45885 .60046 m .46271 .59259 L .46801 .59774 L F
.45885 .60046 m .45352 .59533 L .46271 .59259 L F
.66217 .60019 m .66702 .59232 L .67168 .59747 L F
.66217 .60019 m .65749 .59506 L .66702 .59232 L F
.48246 .60013 m .48643 .59225 L .49166 .5974 L F
.48246 .60013 m .47721 .595 L .48643 .59225 L F
.30273 .60006 m .30583 .59219 L .31163 .59734 L F
.30273 .60006 m .29691 .59493 L .30583 .59219 L F
.937 .687 .533 r
.25216 .43815 m .23607 .54764 L .24687 .43316 L F
.656 .751 .92 r
.68582 .59986 m .69079 .59198 L .69537 .59713 L F
.68582 .59986 m .68122 .59473 L .69079 .59198 L F
.50608 .5998 m .51016 .59192 L .51532 .59707 L F
.50608 .5998 m .5009 .59466 L .51016 .59192 L F
.32631 .59973 m .32953 .59185 L .33526 .597 L F
.32631 .59973 m .32057 .5946 L .32953 .59185 L F
.70949 .59953 m .71457 .59165 L .71908 .5968 L F
.70949 .59953 m .70495 .5944 L .71457 .59165 L F
.52971 .59946 m .53391 .59158 L .53899 .59673 L F
.52971 .59946 m .5246 .59433 L .53391 .59158 L F
.34991 .5994 m .35323 .59152 L .35889 .59667 L F
.34991 .5994 m .34423 .59426 L .35323 .59152 L F
.73316 .5992 m .73836 .59131 L .7428 .59647 L F
.73316 .5992 m .7287 .59406 L .73836 .59131 L F
.55334 .59913 m .55766 .59125 L .56267 .5964 L F
.55334 .59913 m .54831 .594 L .55766 .59125 L F
.37351 .59907 m .37695 .59118 L .38253 .59634 L F
.37351 .59907 m .36791 .59393 L .37695 .59118 L F
.57699 .5988 m .58143 .59091 L .58636 .59607 L F
.57699 .5988 m .57203 .59366 L .58143 .59091 L F
.39712 .59873 m .40068 .59084 L .40619 .596 L F
.39712 .59873 m .39159 .59359 L .40068 .59084 L F
.60065 .59847 m .6052 .59057 L .61006 .59573 L F
.60065 .59847 m .59576 .59333 L .6052 .59057 L F
.42074 .5984 m .42442 .59051 L .42985 .59567 L F
.42074 .5984 m .41529 .59326 L .42442 .59051 L F
.62431 .59813 m .62898 .59024 L .63377 .5954 L F
.62431 .59813 m .61951 .59299 L .62898 .59024 L F
.44437 .59807 m .44816 .59017 L .45352 .59533 L F
.44437 .59807 m .43899 .59292 L .44816 .59017 L F
.64799 .5978 m .65278 .5899 L .65749 .59506 L F
.64799 .5978 m .64326 .59265 L .65278 .5899 L F
.46801 .59774 m .47192 .58984 L .47721 .595 L F
.46801 .59774 m .46271 .59259 L .47192 .58984 L F
.67168 .59747 m .67658 .58956 L .68122 .59473 L F
.67168 .59747 m .66702 .59232 L .67658 .58956 L F
.49166 .5974 m .49569 .5895 L .5009 .59466 L F
.49166 .5974 m .48643 .59225 L .49569 .5895 L F
.31163 .59734 m .31478 .58943 L .32057 .5946 L F
.31163 .59734 m .30583 .59219 L .31478 .58943 L F
.69537 .59713 m .70039 .58923 L .70495 .5944 L F
.69537 .59713 m .69079 .59198 L .70039 .58923 L F
.51532 .59707 m .51946 .58916 L .5246 .59433 L F
.51532 .59707 m .51016 .59192 L .51946 .58916 L F
.33526 .597 m .33852 .5891 L .34423 .59426 L F
.33526 .597 m .32953 .59185 L .33852 .5891 L F
.71908 .5968 m .72421 .58889 L .7287 .59406 L F
.71908 .5968 m .71457 .59165 L .72421 .58889 L F
.53899 .59673 m .54325 .58883 L .54831 .594 L F
.53899 .59673 m .53391 .59158 L .54325 .58883 L F
.35889 .59667 m .36227 .58876 L .36791 .59393 L F
.35889 .59667 m .35323 .59152 L .36227 .58876 L F
.7428 .59647 m .74805 .58855 L .75246 .59373 L F
.7428 .59647 m .73836 .59131 L .74805 .58855 L F
.56267 .5964 m .56704 .58849 L .57203 .59366 L F
.56267 .5964 m .55766 .59125 L .56704 .58849 L F
.38253 .59634 m .38603 .58842 L .39159 .59359 L F
.38253 .59634 m .37695 .59118 L .38603 .58842 L F
.58636 .59607 m .59085 .58815 L .59576 .59333 L F
.58636 .59607 m .58143 .59091 L .59085 .58815 L F
.40619 .596 m .4098 .58808 L .41529 .59326 L F
.40619 .596 m .40068 .59084 L .4098 .58808 L F
.61006 .59573 m .61467 .58781 L .61951 .59299 L F
.61006 .59573 m .6052 .59057 L .61467 .58781 L F
.42985 .59567 m .43358 .58775 L .43899 .59292 L F
.42985 .59567 m .42442 .59051 L .43358 .58775 L F
.63377 .5954 m .63849 .58748 L .64326 .59265 L F
.63377 .5954 m .62898 .59024 L .63849 .58748 L F
.934 .697 .557 r
.24686 .43327 m .24516 .45131 L .24715 .4349 L F
.24516 .45131 m .23607 .54764 L .24543 .45234 L F
.24516 .45131 m .24543 .45234 L .24715 .4349 L F
.24687 .43316 m .24686 .43327 L .2479 .4272 L F
.24686 .43327 m .24715 .4349 L .2479 .4272 L F
.2479 .4272 m .22981 .54214 L .24624 .42563 L F
.2479 .4272 m .23607 .54764 L .22981 .54214 L F
0 0 0 r
.24035 .4695 m .24263 .46785 L .24688 .45779 L F
.24663 .45685 m .24688 .45779 L .25099 .44807 L F
.24035 .4695 m .24688 .45779 L .24663 .45685 L F
.924 .714 .6 r
.24624 .42563 m .24034 .46748 L .23778 .47486 L F
.958 .947 .688 r
.22905 .49766 m .23232 .48411 L .23424 .48061 L F
.924 .714 .6 r
.24034 .46748 m .23759 .48695 L .23778 .47486 L F
.23759 .48695 m .23658 .48503 L .23778 .47486 L F
.909 .733 .651 r
.2235 .5366 m .22905 .49766 L .23778 .47486 L F
0 0 0 r
.23778 .47486 m .22905 .49766 L .23518 .48238 L F
.924 .714 .6 r
.22981 .54214 m .2235 .5366 L .23778 .47486 L F
0 0 0 r
.23778 .47486 m .23518 .48238 L .24035 .4695 L F
.23934 .46926 m .24035 .4695 L .24783 .4388 L F
.23778 .47486 m .24035 .4695 L .23934 .46926 L F
.23778 .47486 m .24783 .4388 L .24771 .43813 L F
.924 .714 .6 r
.24624 .42563 m .23778 .47486 L .24607 .42231 L F
.205 .008 .378 r
.24607 .42231 m .23778 .47486 L .25056 .42761 L F
.958 .947 .688 r
.23518 .48238 m .23424 .48061 L .24035 .4695 L F
.22905 .49766 m .23424 .48061 L .23518 .48238 L F
0 0 0 r
.24035 .4695 m .23232 .48411 L .24142 .46976 L F
.24035 .4695 m .24142 .46976 L .24263 .46785 L F
.924 .714 .6 r
.23759 .48695 m .22981 .54214 L .23658 .48503 L F
0 0 0 r
.24771 .43813 m .24783 .4388 L .25056 .42761 L F
.656 .751 .92 r
.45352 .59533 m .45737 .58741 L .46271 .59259 L F
.45352 .59533 m .44816 .59017 L .45737 .58741 L F
.65749 .59506 m .66233 .58714 L .66702 .59232 L F
.65749 .59506 m .65278 .5899 L .66233 .58714 L F
.47721 .595 m .48116 .58707 L .48643 .59225 L F
.47721 .595 m .47192 .58984 L .48116 .58707 L F
.29691 .59493 m .29999 .58701 L .30583 .59219 L F
.29691 .59493 m .29105 .58977 L .29999 .58701 L F
.68122 .59473 m .68617 .5868 L .69079 .59198 L F
.68122 .59473 m .67658 .58956 L .68617 .5868 L F
.5009 .59466 m .50497 .58673 L .51016 .59192 L F
.5009 .59466 m .49569 .5895 L .50497 .58673 L F
.32057 .5946 m .32376 .58667 L .32953 .59185 L F
.32057 .5946 m .31478 .58943 L .32376 .58667 L F
.70495 .5944 m .71003 .58646 L .71457 .59165 L F
.70495 .5944 m .70039 .58923 L .71003 .58646 L F
.5246 .59433 m .52879 .5864 L .53391 .59158 L F
.5246 .59433 m .51946 .58916 L .52879 .5864 L F
.34423 .59426 m .34754 .58633 L .35323 .59152 L F
.34423 .59426 m .33852 .5891 L .34754 .58633 L F
.7287 .59406 m .73389 .58612 L .73836 .59131 L F
.7287 .59406 m .72421 .58889 L .73389 .58612 L F
.54831 .594 m .55262 .58606 L .55766 .59125 L F
.54831 .594 m .54325 .58883 L .55262 .58606 L F
.36791 .59393 m .37133 .58599 L .37695 .59118 L F
.36791 .59393 m .36227 .58876 L .37133 .58599 L F
.75246 .59373 m .75777 .58579 L .76216 .59098 L F
.75246 .59373 m .74805 .58855 L .75777 .58579 L F
.57203 .59366 m .57646 .58572 L .58143 .59091 L F
.57203 .59366 m .56704 .58849 L .57646 .58572 L F
.39159 .59359 m .39513 .58565 L .40068 .59084 L F
.39159 .59359 m .38603 .58842 L .39513 .58565 L F
.59576 .59333 m .60031 .58538 L .6052 .59057 L F
.59576 .59333 m .59085 .58815 L .60031 .58538 L F
.41529 .59326 m .41895 .58532 L .42442 .59051 L F
.41529 .59326 m .4098 .58808 L .41895 .58532 L F
.61951 .59299 m .62416 .58504 L .62898 .59024 L F
.61951 .59299 m .61467 .58781 L .62416 .58504 L F
.43899 .59292 m .44277 .58498 L .44816 .59017 L F
.43899 .59292 m .43358 .58775 L .44277 .58498 L F
.64326 .59265 m .64803 .58471 L .65278 .5899 L F
.64326 .59265 m .63849 .58748 L .64803 .58471 L F
.46271 .59259 m .4666 .58464 L .47192 .58984 L F
.46271 .59259 m .45737 .58741 L .4666 .58464 L F
.66702 .59232 m .67191 .58437 L .67658 .58956 L F
.66702 .59232 m .66233 .58714 L .67191 .58437 L F
.48643 .59225 m .49044 .5843 L .49569 .5895 L F
.48643 .59225 m .48116 .58707 L .49044 .5843 L F
.30583 .59219 m .30896 .58423 L .31478 .58943 L F
.30583 .59219 m .29999 .58701 L .30896 .58423 L F
.69079 .59198 m .6958 .58403 L .70039 .58923 L F
.69079 .59198 m .68617 .5868 L .6958 .58403 L F
.51016 .59192 m .51429 .58396 L .51946 .58916 L F
.51016 .59192 m .50497 .58673 L .51429 .58396 L F
.32953 .59185 m .33277 .58389 L .33852 .5891 L F
.32953 .59185 m .32376 .58667 L .33277 .58389 L F
.71457 .59165 m .7197 .58369 L .72421 .58889 L F
.71457 .59165 m .71003 .58646 L .7197 .58369 L F
.53391 .59158 m .53815 .58362 L .54325 .58883 L F
.53391 .59158 m .52879 .5864 L .53815 .58362 L F
.35323 .59152 m .35659 .58356 L .36227 .58876 L F
.35323 .59152 m .34754 .58633 L .35659 .58356 L F
.73836 .59131 m .7436 .58335 L .74805 .58855 L F
.73836 .59131 m .73389 .58612 L .7436 .58335 L F
.55766 .59125 m .56202 .58328 L .56704 .58849 L F
.55766 .59125 m .55262 .58606 L .56202 .58328 L F
.37695 .59118 m .38043 .58322 L .38603 .58842 L F
.37695 .59118 m .37133 .58599 L .38043 .58322 L F
.76216 .59098 m .76752 .58301 L .77189 .58822 L F
.76216 .59098 m .75777 .58579 L .76752 .58301 L F
.58143 .59091 m .5859 .58294 L .59085 .58815 L F
.58143 .59091 m .57646 .58572 L .5859 .58294 L F
.40068 .59084 m .40427 .58288 L .4098 .58808 L F
.40068 .59084 m .39513 .58565 L .40427 .58288 L F
.6052 .59057 m .6098 .5826 L .61467 .58781 L F
.6052 .59057 m .60031 .58538 L .6098 .5826 L F
.42442 .59051 m .42813 .58254 L .43358 .58775 L F
.42442 .59051 m .41895 .58532 L .42813 .58254 L F
.62898 .59024 m .6337 .58226 L .63849 .58748 L F
.62898 .59024 m .62416 .58504 L .6337 .58226 L F
.44816 .59017 m .45199 .5822 L .45737 .58741 L F
.44816 .59017 m .44277 .58498 L .45199 .5822 L F
.65278 .5899 m .65761 .58192 L .66233 .58714 L F
.65278 .5899 m .64803 .58471 L .65761 .58192 L F
.47192 .58984 m .47586 .58186 L .48116 .58707 L F
.47192 .58984 m .4666 .58464 L .47586 .58186 L F
.29105 .58977 m .29411 .58179 L .29999 .58701 L F
.29105 .58977 m .28515 .58457 L .29411 .58179 L F
.67658 .58956 m .68153 .58158 L .68617 .5868 L F
.67658 .58956 m .67191 .58437 L .68153 .58158 L F
.49569 .5895 m .49975 .58152 L .50497 .58673 L F
.49569 .5895 m .49044 .5843 L .49975 .58152 L F
.31478 .58943 m .31795 .58145 L .32376 .58667 L F
.31478 .58943 m .30896 .58423 L .31795 .58145 L F
.70039 .58923 m .70546 .58124 L .71003 .58646 L F
.70039 .58923 m .6958 .58403 L .70546 .58124 L F
.51946 .58916 m .52364 .58118 L .52879 .5864 L F
.51946 .58916 m .51429 .58396 L .52364 .58118 L F
.33852 .5891 m .34181 .58111 L .34754 .58633 L F
.33852 .5891 m .33277 .58389 L .34181 .58111 L F
.72421 .58889 m .7294 .5809 L .73389 .58612 L F
.72421 .58889 m .7197 .58369 L .7294 .5809 L F
.54325 .58883 m .54755 .58084 L .55262 .58606 L F
.54325 .58883 m .53815 .58362 L .54755 .58084 L F
.36227 .58876 m .36568 .58077 L .37133 .58599 L F
.36227 .58876 m .35659 .58356 L .36568 .58077 L F
.74805 .58855 m .75335 .58056 L .75777 .58579 L F
.74805 .58855 m .7436 .58335 L .75335 .58056 L F
.56704 .58849 m .57146 .5805 L .57646 .58572 L F
.56704 .58849 m .56202 .58328 L .57146 .5805 L F
.38603 .58842 m .38955 .58043 L .39513 .58565 L F
.38603 .58842 m .38043 .58322 L .38955 .58043 L F
.77189 .58822 m .77731 .58022 L .78165 .58545 L F
.77189 .58822 m .76752 .58301 L .77731 .58022 L F
.59085 .58815 m .59538 .58016 L .60031 .58538 L F
.59085 .58815 m .5859 .58294 L .59538 .58016 L F
.4098 .58808 m .41344 .58009 L .41895 .58532 L F
.4098 .58808 m .40427 .58288 L .41344 .58009 L F
.61467 .58781 m .61932 .57982 L .62416 .58504 L F
.61467 .58781 m .6098 .5826 L .61932 .57982 L F
.43358 .58775 m .43734 .57975 L .44277 .58498 L F
.43358 .58775 m .42813 .58254 L .43734 .57975 L F
.63849 .58748 m .64326 .57948 L .64803 .58471 L F
.63849 .58748 m .6337 .58226 L .64326 .57948 L F
.45737 .58741 m .46124 .57941 L .4666 .58464 L F
.45737 .58741 m .45199 .5822 L .46124 .57941 L F
.66233 .58714 m .66721 .57913 L .67191 .58437 L F
.66233 .58714 m .65761 .58192 L .66721 .57913 L F
.48116 .58707 m .48516 .57907 L .49044 .5843 L F
.48116 .58707 m .47586 .58186 L .48516 .57907 L F
.29999 .58701 m .30309 .579 L .30896 .58423 L F
.29999 .58701 m .29411 .58179 L .30309 .579 L F
.68617 .5868 m .69118 .57879 L .6958 .58403 L F
.68617 .5868 m .68153 .58158 L .69118 .57879 L F
.50497 .58673 m .50909 .57873 L .51429 .58396 L F
.50497 .58673 m .49975 .58152 L .50909 .57873 L F
.32376 .58667 m .32698 .57866 L .33277 .58389 L F
.32376 .58667 m .31795 .58145 L .32698 .57866 L F
.71003 .58646 m .71515 .57845 L .7197 .58369 L F
.71003 .58646 m .70546 .58124 L .71515 .57845 L F
.52879 .5864 m .53302 .57839 L .53815 .58362 L F
.52879 .5864 m .52364 .58118 L .53302 .57839 L F
.34754 .58633 m .35088 .57832 L .35659 .58356 L F
.34754 .58633 m .34181 .58111 L .35088 .57832 L F
.73389 .58612 m .73913 .57811 L .7436 .58335 L F
.73389 .58612 m .7294 .5809 L .73913 .57811 L F
.55262 .58606 m .55697 .57804 L .56202 .58328 L F
.55262 .58606 m .54755 .58084 L .55697 .57804 L F
.37133 .58599 m .37479 .57798 L .38043 .58322 L F
.37133 .58599 m .36568 .58077 L .37479 .57798 L F
.75777 .58579 m .76313 .57777 L .76752 .58301 L F
.75777 .58579 m .75335 .58056 L .76313 .57777 L F
.57646 .58572 m .58093 .5777 L .5859 .58294 L F
.57646 .58572 m .57146 .5805 L .58093 .5777 L F
.39513 .58565 m .39871 .57764 L .40427 .58288 L F
.39513 .58565 m .38955 .58043 L .39871 .57764 L F
.205 .008 .378 r
.24607 .42231 m .25056 .42761 L .25092 .4179 L F
.656 .751 .92 r
.78165 .58545 m .78713 .57743 L .79145 .58267 L F
.78165 .58545 m .77731 .58022 L .78713 .57743 L F
.60031 .58538 m .60489 .57736 L .6098 .5826 L F
.60031 .58538 m .59538 .58016 L .60489 .57736 L F
.41895 .58532 m .42264 .57729 L .42813 .58254 L F
.41895 .58532 m .41344 .58009 L .42264 .57729 L F
.62416 .58504 m .62887 .57702 L .6337 .58226 L F
.62416 .58504 m .61932 .57982 L .62887 .57702 L F
.44277 .58498 m .44658 .57695 L .45199 .5822 L F
.44277 .58498 m .43734 .57975 L .44658 .57695 L F
.64803 .58471 m .65286 .57668 L .65761 .58192 L F
.64803 .58471 m .64326 .57948 L .65286 .57668 L F
.4666 .58464 m .47053 .57661 L .47586 .58186 L F
.4666 .58464 m .46124 .57941 L .47053 .57661 L F
.28515 .58457 m .28819 .57654 L .29411 .58179 L F
.28515 .58457 m .27922 .57934 L .28819 .57654 L F
.67191 .58437 m .67685 .57634 L .68153 .58158 L F
.67191 .58437 m .66721 .57913 L .67685 .57634 L F
.49044 .5843 m .49449 .57627 L .49975 .58152 L F
.49044 .5843 m .48516 .57907 L .49449 .57627 L F
.30896 .58423 m .31211 .5762 L .31795 .58145 L F
.30896 .58423 m .30309 .579 L .31211 .5762 L F
.6958 .58403 m .70086 .57599 L .70546 .58124 L F
.6958 .58403 m .69118 .57879 L .70086 .57599 L F
.51429 .58396 m .51846 .57593 L .52364 .58118 L F
.51429 .58396 m .50909 .57873 L .51846 .57593 L F
.33277 .58389 m .33604 .57586 L .34181 .58111 L F
.33277 .58389 m .32698 .57866 L .33604 .57586 L F
.7197 .58369 m .72487 .57565 L .7294 .5809 L F
.7197 .58369 m .71515 .57845 L .72487 .57565 L F
.53815 .58362 m .54244 .57558 L .54755 .58084 L F
.53815 .58362 m .53302 .57839 L .54244 .57558 L F
.35659 .58356 m .35999 .57552 L .36568 .58077 L F
.35659 .58356 m .35088 .57832 L .35999 .57552 L F
.7436 .58335 m .7489 .57531 L .75335 .58056 L F
.7436 .58335 m .73913 .57811 L .7489 .57531 L F
.56202 .58328 m .56643 .57524 L .57146 .5805 L F
.56202 .58328 m .55697 .57804 L .56643 .57524 L F
.38043 .58322 m .38394 .57517 L .38955 .58043 L F
.38043 .58322 m .37479 .57798 L .38394 .57517 L F
.76752 .58301 m .77294 .57497 L .77731 .58022 L F
.76752 .58301 m .76313 .57777 L .77294 .57497 L F
.5859 .58294 m .59043 .5749 L .59538 .58016 L F
.5859 .58294 m .58093 .5777 L .59043 .5749 L F
.40427 .58288 m .4079 .57483 L .41344 .58009 L F
.40427 .58288 m .39871 .57764 L .4079 .57483 L F
.79145 .58267 m .79698 .57462 L .80128 .57988 L F
.79145 .58267 m .78713 .57743 L .79698 .57462 L F
.6098 .5826 m .61444 .57456 L .61932 .57982 L F
.6098 .5826 m .60489 .57736 L .61444 .57456 L F
.42813 .58254 m .43187 .57449 L .43734 .57975 L F
.42813 .58254 m .42264 .57729 L .43187 .57449 L F
.6337 .58226 m .63846 .57421 L .64326 .57948 L F
.6337 .58226 m .62887 .57702 L .63846 .57421 L F
.45199 .5822 m .45586 .57415 L .46124 .57941 L F
.45199 .5822 m .44658 .57695 L .45586 .57415 L F
.65761 .58192 m .66249 .57387 L .66721 .57913 L F
.65761 .58192 m .65286 .57668 L .66249 .57387 L F
.47586 .58186 m .47985 .5738 L .48516 .57907 L F
.47586 .58186 m .47053 .57661 L .47985 .5738 L F
.29411 .58179 m .2972 .57374 L .30309 .579 L F
.29411 .58179 m .28819 .57654 L .2972 .57374 L F
.68153 .58158 m .68652 .57353 L .69118 .57879 L F
.68153 .58158 m .67685 .57634 L .68652 .57353 L F
.205 .008 .378 r
.25092 .4179 m .25056 .42761 L .25197 .41641 L F
.656 .751 .92 r
.49975 .58152 m .50385 .57346 L .50909 .57873 L F
.49975 .58152 m .49449 .57627 L .50385 .57346 L F
.31795 .58145 m .32116 .57339 L .32698 .57866 L F
.31795 .58145 m .31211 .5762 L .32116 .57339 L F
.70546 .58124 m .71057 .57318 L .71515 .57845 L F
.70546 .58124 m .70086 .57599 L .71057 .57318 L F
.52364 .58118 m .52786 .57312 L .53302 .57839 L F
.52364 .58118 m .51846 .57593 L .52786 .57312 L F
.34181 .58111 m .34514 .57305 L .35088 .57832 L F
.34181 .58111 m .33604 .57586 L .34514 .57305 L F
.7294 .5809 m .73463 .57284 L .73913 .57811 L F
.7294 .5809 m .72487 .57565 L .73463 .57284 L F
.54755 .58084 m .55189 .57277 L .55697 .57804 L F
.54755 .58084 m .54244 .57558 L .55189 .57277 L F
.36568 .58077 m .36912 .5727 L .37479 .57798 L F
.36568 .58077 m .35999 .57552 L .36912 .5727 L F
.75335 .58056 m .7587 .5725 L .76313 .57777 L F
.75335 .58056 m .7489 .57531 L .7587 .5725 L F
.57146 .5805 m .57592 .57243 L .58093 .5777 L F
.57146 .5805 m .56643 .57524 L .57592 .57243 L F
.38955 .58043 m .39312 .57236 L .39871 .57764 L F
.38955 .58043 m .38394 .57517 L .39312 .57236 L F
.77731 .58022 m .78278 .57215 L .78713 .57743 L F
.77731 .58022 m .77294 .57497 L .78278 .57215 L F
.434 .212 .476 r
.25197 .41641 m .25056 .42761 L .25513 .41475 L F
.656 .751 .92 r
.59538 .58016 m .59996 .57208 L .60489 .57736 L F
.59538 .58016 m .59043 .5749 L .59996 .57208 L F
.41344 .58009 m .41712 .57202 L .42264 .57729 L F
.41344 .58009 m .4079 .57483 L .41712 .57202 L F
.80128 .57988 m .80687 .57181 L .81114 .57709 L F
.80128 .57988 m .79698 .57462 L .80687 .57181 L F
.61932 .57982 m .62401 .57174 L .62887 .57702 L F
.61932 .57982 m .61444 .57456 L .62401 .57174 L F
.43734 .57975 m .44114 .57167 L .44658 .57695 L F
.43734 .57975 m .43187 .57449 L .44114 .57167 L F
.64326 .57948 m .64807 .5714 L .65286 .57668 L F
.64326 .57948 m .63846 .57421 L .64807 .5714 L F
.46124 .57941 m .46516 .57133 L .47053 .57661 L F
.46124 .57941 m .45586 .57415 L .46516 .57133 L F
.27922 .57934 m .28224 .57126 L .28819 .57654 L F
.27922 .57934 m .27324 .57408 L .28224 .57126 L F
.66721 .57913 m .67215 .57105 L .67685 .57634 L F
.66721 .57913 m .66249 .57387 L .67215 .57105 L F
.48516 .57907 m .4892 .57098 L .49449 .57627 L F
.48516 .57907 m .47985 .5738 L .4892 .57098 L F
.30309 .579 m .30623 .57092 L .31211 .5762 L F
.30309 .579 m .2972 .57374 L .30623 .57092 L F
.69118 .57879 m .69623 .57071 L .70086 .57599 L F
.69118 .57879 m .68652 .57353 L .69623 .57071 L F
.50909 .57873 m .51324 .57064 L .51846 .57593 L F
.50909 .57873 m .50385 .57346 L .51324 .57064 L F
.198 0 .311 r
.25513 .41475 m .25099 .44807 L .25867 .41119 L F
.25513 .41475 m .25056 .42761 L .25099 .44807 L F
.656 .751 .92 r
.32698 .57866 m .33024 .57057 L .33604 .57586 L F
.32698 .57866 m .32116 .57339 L .33024 .57057 L F
.71515 .57845 m .72032 .57036 L .72487 .57565 L F
.71515 .57845 m .71057 .57318 L .72032 .57036 L F
.53302 .57839 m .5373 .5703 L .54244 .57558 L F
.53302 .57839 m .52786 .57312 L .5373 .5703 L F
.35088 .57832 m .35426 .57023 L .35999 .57552 L F
.35088 .57832 m .34514 .57305 L .35426 .57023 L F
.73913 .57811 m .74443 .57002 L .7489 .57531 L F
.73913 .57811 m .73463 .57284 L .74443 .57002 L F
.55697 .57804 m .56136 .56995 L .56643 .57524 L F
.55697 .57804 m .55189 .57277 L .56136 .56995 L F
.37479 .57798 m .37829 .56988 L .38394 .57517 L F
.37479 .57798 m .36912 .5727 L .37829 .56988 L F
.76313 .57777 m .76854 .56967 L .77294 .57497 L F
.76313 .57777 m .7587 .5725 L .76854 .56967 L F
.58093 .5777 m .58544 .56961 L .59043 .5749 L F
.58093 .5777 m .57592 .57243 L .58544 .56961 L F
.39871 .57764 m .40233 .56954 L .4079 .57483 L F
.39871 .57764 m .39312 .57236 L .40233 .56954 L F
.78713 .57743 m .79266 .56933 L .79698 .57462 L F
.78713 .57743 m .78278 .57215 L .79266 .56933 L F
.60489 .57736 m .60953 .56926 L .61444 .57456 L F
.60489 .57736 m .59996 .57208 L .60953 .56926 L F
.42264 .57729 m .42637 .56919 L .43187 .57449 L F
.42264 .57729 m .41712 .57202 L .42637 .56919 L F
.81114 .57709 m .81679 .56898 L .82104 .57428 L F
.81114 .57709 m .80687 .57181 L .81679 .56898 L F
.62887 .57702 m .63362 .56892 L .63846 .57421 L F
.62887 .57702 m .62401 .57174 L .63362 .56892 L F
.44658 .57695 m .45043 .56885 L .45586 .57415 L F
.44658 .57695 m .44114 .57167 L .45043 .56885 L F
.65286 .57668 m .65773 .56857 L .66249 .57387 L F
.65286 .57668 m .64807 .5714 L .65773 .56857 L F
.47053 .57661 m .4745 .5685 L .47985 .5738 L F
.47053 .57661 m .46516 .57133 L .4745 .5685 L F
.28819 .57654 m .29126 .56844 L .2972 .57374 L F
.28819 .57654 m .28224 .57126 L .29126 .56844 L F
.67685 .57634 m .68184 .56822 L .68652 .57353 L F
.67685 .57634 m .67215 .57105 L .68184 .56822 L F
.49449 .57627 m .49858 .56816 L .50385 .57346 L F
.49449 .57627 m .4892 .57098 L .49858 .56816 L F
.31211 .5762 m .3153 .56809 L .32116 .57339 L F
.31211 .5762 m .30623 .57092 L .3153 .56809 L F
.70086 .57599 m .70597 .56788 L .71057 .57318 L F
.70086 .57599 m .69623 .57071 L .70597 .56788 L F
.51846 .57593 m .52267 .56781 L .52786 .57312 L F
.51846 .57593 m .51324 .57064 L .52267 .56781 L F
.33604 .57586 m .33935 .56774 L .34514 .57305 L F
.33604 .57586 m .33024 .57057 L .33935 .56774 L F
.72487 .57565 m .7301 .56753 L .73463 .57284 L F
.72487 .57565 m .72032 .57036 L .7301 .56753 L F
.54244 .57558 m .54677 .56747 L .55189 .57277 L F
.54244 .57558 m .5373 .5703 L .54677 .56747 L F
.35999 .57552 m .36341 .5674 L .36912 .5727 L F
.35999 .57552 m .35426 .57023 L .36341 .5674 L F
.391 .14 .41 r
.25867 .41119 m .26095 .43415 L .26153 .40967 L F
.25867 .41119 m .25099 .44807 L .26095 .43415 L F
.656 .751 .92 r
.7489 .57531 m .75425 .56719 L .7587 .5725 L F
.7489 .57531 m .74443 .57002 L .75425 .56719 L F
.56643 .57524 m .57088 .56712 L .57592 .57243 L F
.56643 .57524 m .56136 .56995 L .57088 .56712 L F
.38394 .57517 m .38749 .56705 L .39312 .57236 L F
.38394 .57517 m .37829 .56988 L .38749 .56705 L F
.77294 .57497 m .77841 .56684 L .78278 .57215 L F
.77294 .57497 m .76854 .56967 L .77841 .56684 L F
.59043 .5749 m .59499 .56677 L .59996 .57208 L F
.59043 .5749 m .58544 .56961 L .59499 .56677 L F
.4079 .57483 m .41157 .56671 L .41712 .57202 L F
.4079 .57483 m .40233 .56954 L .41157 .56671 L F
.79698 .57462 m .80257 .5665 L .80687 .57181 L F
.79698 .57462 m .79266 .56933 L .80257 .5665 L F
.61444 .57456 m .61912 .56643 L .62401 .57174 L F
.61444 .57456 m .60953 .56926 L .61912 .56643 L F
.43187 .57449 m .43566 .56636 L .44114 .57167 L F
.43187 .57449 m .42637 .56919 L .43566 .56636 L F
.82104 .57428 m .82675 .56615 L .83097 .57146 L F
.82104 .57428 m .81679 .56898 L .82675 .56615 L F
.63846 .57421 m .64326 .56608 L .64807 .5714 L F
.63846 .57421 m .63362 .56892 L .64326 .56608 L F
.45586 .57415 m .45976 .56601 L .46516 .57133 L F
.45586 .57415 m .45043 .56885 L .45976 .56601 L F
.27324 .57408 m .27624 .56595 L .28224 .57126 L F
.27324 .57408 m .26723 .56878 L .27624 .56595 L F
.391 .14 .41 r
.26153 .40967 m .26095 .43415 L .26637 .40688 L F
.198 0 .311 r
.25056 .42761 m .24035 .4695 L .25099 .44807 L F
.656 .751 .92 r
.66249 .57387 m .66741 .56573 L .67215 .57105 L F
.66249 .57387 m .65773 .56857 L .66741 .56573 L F
.47985 .5738 m .48387 .56567 L .4892 .57098 L F
.47985 .5738 m .4745 .5685 L .48387 .56567 L F
.2972 .57374 m .30032 .5656 L .30623 .57092 L F
.2972 .57374 m .29126 .56844 L .30032 .5656 L F
.68652 .57353 m .69157 .56539 L .69623 .57071 L F
.68652 .57353 m .68184 .56822 L .69157 .56539 L F
.50385 .57346 m .50799 .56532 L .51324 .57064 L F
.50385 .57346 m .49858 .56816 L .50799 .56532 L F
.32116 .57339 m .3244 .56525 L .33024 .57057 L F
.32116 .57339 m .3153 .56809 L .3244 .56525 L F
.33024 .57057 m .33353 .56241 L .33935 .56774 L F
.33024 .57057 m .3244 .56525 L .33353 .56241 L F
.3244 .56525 m .32767 .55703 L .33353 .56241 L F
.33353 .56241 m .32767 .55703 L .33685 .55416 L F
.32767 .55703 m .33098 .54873 L .33685 .55416 L F
.32767 .55703 m .32177 .55162 L .33098 .54873 L F
.33685 .55416 m .33098 .54873 L .34021 .54582 L F
.32177 .55162 m .32506 .54327 L .33098 .54873 L F
.33098 .54873 m .33431 .54034 L .34021 .54582 L F
.33098 .54873 m .32506 .54327 L .33431 .54034 L F
.32506 .54327 m .32838 .53483 L .33431 .54034 L F
.33431 .54034 m .32838 .53483 L .33768 .53187 L F
.32838 .53483 m .33173 .5263 L .33768 .53187 L F
.32838 .53483 m .3224 .52927 L .33173 .5263 L F
.33768 .53187 m .33173 .5263 L .34016 .52361 L F
.34073 .52421 m .34016 .52361 L .34109 .52332 L F
.33768 .53187 m .34016 .52361 L .34073 .52421 L F
.543 .322 .53 r
.33188 .51493 m .34086 .40885 L .33551 .40286 L F
.656 .751 .92 r
.3224 .52927 m .32574 .52069 L .33173 .5263 L F
.33173 .5263 m .33511 .51768 L .34109 .52332 L F
.33173 .5263 m .32574 .52069 L .33352 .5182 L F
.33447 .51932 m .33352 .5182 L .33511 .51768 L F
.33173 .5263 m .33352 .5182 L .33447 .51932 L F
.674 .418 .526 r
.32801 .40157 m .32815 .51186 L .33042 .4046 L F
.32815 .51186 m .32817 .52795 L .32845 .51222 L F
.32815 .51186 m .32845 .51222 L .33042 .4046 L F
.543 .322 .53 r
.32801 .63442 m .33465 .51783 L .33188 .51493 L F
.33465 .51783 m .34086 .40885 L .33188 .51493 L F
.656 .751 .92 r
.71057 .57318 m .71574 .56504 L .72032 .57036 L F
.71057 .57318 m .70597 .56788 L .71574 .56504 L F
.52786 .57312 m .53213 .56497 L .5373 .5703 L F
.52786 .57312 m .52267 .56781 L .53213 .56497 L F
.34514 .57305 m .34849 .56491 L .35426 .57023 L F
.34514 .57305 m .33935 .56774 L .34849 .56491 L F
.73463 .57284 m .73992 .56469 L .74443 .57002 L F
.73463 .57284 m .7301 .56753 L .73992 .56469 L F
.55189 .57277 m .55627 .56463 L .56136 .56995 L F
.55189 .57277 m .54677 .56747 L .55627 .56463 L F
.36912 .5727 m .3726 .56456 L .37829 .56988 L F
.36912 .5727 m .36341 .5674 L .3726 .56456 L F
.7587 .5725 m .76411 .56435 L .76854 .56967 L F
.7587 .5725 m .75425 .56719 L .76411 .56435 L F
.57592 .57243 m .58042 .56428 L .58544 .56961 L F
.57592 .57243 m .57088 .56712 L .58042 .56428 L F
.39312 .57236 m .39671 .56421 L .40233 .56954 L F
.39312 .57236 m .38749 .56705 L .39671 .56421 L F
.78278 .57215 m .78831 .564 L .79266 .56933 L F
.78278 .57215 m .77841 .56684 L .78831 .564 L F
.59996 .57208 m .60458 .56393 L .60953 .56926 L F
.59996 .57208 m .59499 .56677 L .60458 .56393 L F
.41712 .57202 m .42084 .56386 L .42637 .56919 L F
.41712 .57202 m .41157 .56671 L .42084 .56386 L F
.80687 .57181 m .81252 .56365 L .81679 .56898 L F
.80687 .57181 m .80257 .5665 L .81252 .56365 L F
.62401 .57174 m .62876 .56358 L .63362 .56892 L F
.62401 .57174 m .61912 .56643 L .62876 .56358 L F
.44114 .57167 m .44497 .56352 L .45043 .56885 L F
.44114 .57167 m .43566 .56636 L .44497 .56352 L F
.476 .219 .444 r
.26637 .40688 m .27029 .42787 L .27101 .40505 L F
.26637 .40688 m .26095 .43415 L .27029 .42787 L F
.656 .751 .92 r
.83097 .57146 m .83674 .56331 L .84094 .56864 L F
.83097 .57146 m .82675 .56615 L .83674 .56331 L F
.64807 .5714 m .65294 .56324 L .65773 .56857 L F
.64807 .5714 m .64326 .56608 L .65294 .56324 L F
.46516 .57133 m .46912 .56317 L .4745 .5685 L F
.46516 .57133 m .45976 .56601 L .46912 .56317 L F
.28224 .57126 m .28529 .5631 L .29126 .56844 L F
.28224 .57126 m .27624 .56595 L .28529 .5631 L F
.67215 .57105 m .67713 .56289 L .68184 .56822 L F
.67215 .57105 m .66741 .56573 L .67713 .56289 L F
.4892 .57098 m .49327 .56282 L .49858 .56816 L F
.4892 .57098 m .48387 .56567 L .49327 .56282 L F
.30623 .57092 m .3094 .56275 L .3153 .56809 L F
.30623 .57092 m .30032 .5656 L .3094 .56275 L F
.69623 .57071 m .70133 .56254 L .70597 .56788 L F
.69623 .57071 m .69157 .56539 L .70133 .56254 L F
.51324 .57064 m .51744 .56247 L .52267 .56781 L F
.51324 .57064 m .50799 .56532 L .51744 .56247 L F
.72032 .57036 m .72555 .56219 L .7301 .56753 L F
.72032 .57036 m .71574 .56504 L .72555 .56219 L F
.5373 .5703 m .54162 .56213 L .54677 .56747 L F
.5373 .5703 m .53213 .56497 L .54162 .56213 L F
.35426 .57023 m .35767 .56206 L .36341 .5674 L F
.35426 .57023 m .34849 .56491 L .35767 .56206 L F
.74443 .57002 m .74977 .56185 L .75425 .56719 L F
.74443 .57002 m .73992 .56469 L .74977 .56185 L F
.56136 .56995 m .5658 .56178 L .57088 .56712 L F
.56136 .56995 m .55627 .56463 L .5658 .56178 L F
.37829 .56988 m .38182 .56171 L .38749 .56705 L F
.37829 .56988 m .3726 .56456 L .38182 .56171 L F
.476 .219 .444 r
.27101 .40505 m .27029 .42787 L .27522 .40363 L F
.656 .751 .92 r
.76854 .56967 m .774 .5615 L .77841 .56684 L F
.76854 .56967 m .76411 .56435 L .774 .5615 L F
.58544 .56961 m .59 .56143 L .59499 .56677 L F
.58544 .56961 m .58042 .56428 L .59 .56143 L F
.40233 .56954 m .40598 .56136 L .41157 .56671 L F
.40233 .56954 m .39671 .56421 L .40598 .56136 L F
.543 .322 .53 r
.33042 .4046 m .32817 .52795 L .33551 .40286 L F
.656 .751 .92 r
.79266 .56933 m .79825 .56115 L .80257 .5665 L F
.79266 .56933 m .78831 .564 L .79825 .56115 L F
.60953 .56926 m .6142 .56108 L .61912 .56643 L F
.60953 .56926 m .60458 .56393 L .6142 .56108 L F
.42637 .56919 m .43014 .56101 L .43566 .56636 L F
.42637 .56919 m .42084 .56386 L .43014 .56101 L F
.81679 .56898 m .8225 .5608 L .82675 .56615 L F
.81679 .56898 m .81252 .56365 L .8225 .5608 L F
.63362 .56892 m .63842 .56073 L .64326 .56608 L F
.63362 .56892 m .62876 .56358 L .63842 .56073 L F
.45043 .56885 m .45432 .56066 L .45976 .56601 L F
.45043 .56885 m .44497 .56352 L .45432 .56066 L F
.26723 .56878 m .27021 .5606 L .27624 .56595 L F
.26723 .56878 m .26118 .56345 L .27021 .5606 L F
.84094 .56864 m .84677 .56045 L .85094 .5658 L F
.84094 .56864 m .83674 .56331 L .84677 .56045 L F
.65773 .56857 m .66265 .56038 L .66741 .56573 L F
.65773 .56857 m .65294 .56324 L .66265 .56038 L F
.534 .267 .457 r
.27522 .40363 m .27909 .42875 L .27991 .40229 L F
.27522 .40363 m .27029 .42787 L .27909 .42875 L F
.656 .751 .92 r
.4745 .5685 m .47851 .56031 L .48387 .56567 L F
.4745 .5685 m .46912 .56317 L .47851 .56031 L F
.29126 .56844 m .29436 .56025 L .30032 .5656 L F
.29126 .56844 m .28529 .5631 L .29436 .56025 L F
.68184 .56822 m .68688 .56003 L .69157 .56539 L F
.68184 .56822 m .67713 .56289 L .68688 .56003 L F
.49858 .56816 m .50271 .55997 L .50799 .56532 L F
.49858 .56816 m .49327 .56282 L .50271 .55997 L F
.3153 .56809 m .31852 .5599 L .3244 .56525 L F
.3153 .56809 m .3094 .56275 L .31852 .5599 L F
.70597 .56788 m .71113 .55968 L .71574 .56504 L F
.70597 .56788 m .70133 .56254 L .71113 .55968 L F
.32506 .54327 m .3191 .53777 L .32838 .53483 L F
.3191 .53777 m .3224 .52927 L .32838 .53483 L F
.844 .589 .046 r
.32817 .52795 m .3235 .49881 L .32381 .50133 L F
.543 .322 .53 r
.32815 .5362 m .33091 .54474 L .32817 .52795 L F
.32801 .63442 m .33056 .55554 L .32815 .5362 L F
.33056 .55554 m .33091 .54474 L .32815 .5362 L F
.656 .751 .92 r
.3244 .56525 m .31852 .5599 L .32767 .55703 L F
.31852 .5599 m .32177 .55162 L .32767 .55703 L F
.543 .322 .53 r
.32801 .63442 m .32817 .52795 L .32224 .62882 L F
.32224 .62882 m .32817 .52795 L .32811 .62706 L F
.844 .589 .046 r
.32811 .62706 m .32814 .56911 L .32977 .55058 L F
.32814 .56911 m .32817 .52795 L .32977 .55058 L F
.912 .536 .104 r
.32673 .52548 m .32537 .51523 L .32977 .55058 L F
.774 .462 .459 r
.31816 .43784 m .31773 .48818 L .3235 .49881 L F
.912 .536 .104 r
.3235 .49881 m .31773 .48818 L .32537 .51523 L F
.826 .387 0 r
.32264 .50557 m .31996 .49753 L .32537 .51523 L F
.31773 .48818 m .31996 .49753 L .32264 .50557 L F
.31773 .48818 m .31174 .48047 L .31621 .48976 L F
.31921 .49441 m .31621 .48976 L .31996 .49753 L F
.31773 .48818 m .31621 .48976 L .31921 .49441 L F
.784 .3 .071 r
.31138 .47971 m .30566 .47364 L .31174 .48047 L F
.30368 .46337 m .30566 .47364 L .31138 .47971 L F
.612 .048 0 r
.30531 .47319 m .29952 .46716 L .30566 .47364 L F
.29719 .46273 m .29952 .46716 L .30531 .47319 L F
.6 .055 0 r
.28869 .4538 m .2908 .45994 L .29719 .46273 L F
.612 .048 0 r
.29719 .46273 m .2908 .45994 L .29952 .46716 L F
0 .24 .731 r
.29952 .46716 m .29332 .46083 L .29368 .46109 L F
.784 .3 .071 r
.30368 .46337 m .29719 .46273 L .30566 .47364 L F
0 .24 .731 r
.29952 .46716 m .29368 .46109 L .3022 .46705 L F
0 .037 .548 r
.30566 .47364 m .29952 .46716 L .2999 .46753 L F
.30566 .47364 m .2999 .46753 L .30825 .47563 L F
.668 .187 0 r
.31757 .49258 m .31419 .4854 L .31996 .49753 L F
.31174 .48047 m .31419 .4854 L .31757 .49258 L F
.816 .428 .319 r
.31044 .45891 m .31174 .48047 L .31773 .48818 L F
.31044 .45891 m .30368 .46337 L .31174 .48047 L F
.668 .187 0 r
.31174 .48047 m .30566 .47364 L .31419 .4854 L F
0 .155 .697 r
.31419 .4854 m .30825 .47563 L .31078 .47817 L F
.774 .462 .459 r
.31816 .43784 m .31044 .45891 L .31773 .48818 L F
0 .155 .697 r
.31419 .4854 m .31078 .47817 L .31706 .48445 L F
0 .037 .548 r
.30715 .4757 m .30825 .47563 L .31419 .4854 L F
.30566 .47364 m .30599 .4739 L .30715 .4757 L F
.30599 .4739 m .30825 .47563 L .30715 .4757 L F
0 .062 .626 r
.31996 .49753 m .31419 .4854 L .31725 .48943 L F
.31996 .49753 m .31725 .48943 L .32285 .49681 L F
.31996 .49753 m .32285 .49681 L .32293 .49702 L F
.912 .536 .104 r
.32381 .50133 m .3252 .51369 L .32615 .52068 L F
.3235 .49881 m .3236 .49965 L .32381 .50133 L F
.3236 .49965 m .32537 .51523 L .32381 .50133 L F
.844 .589 .046 r
.32817 .52795 m .32381 .50133 L .32977 .55058 L F
.674 .418 .526 r
.3222 .40177 m .3235 .49881 L .32801 .40157 L F
.3222 .40177 m .31816 .43784 L .3235 .49881 L F
.32801 .40157 m .3235 .49881 L .32817 .52795 L F
0 .062 .626 r
.324 .50491 m .32293 .49702 L .32841 .51295 L F
.31996 .49753 m .32293 .49702 L .324 .50491 L F
.912 .536 .104 r
.32615 .52068 m .32537 .51523 L .32673 .52548 L F
.3252 .51369 m .32537 .51523 L .32615 .52068 L F
0 .019 .575 r
.32537 .51523 m .31996 .49753 L .324 .50491 L F
.32537 .51523 m .324 .50491 L .32841 .51295 L F
.543 .322 .53 r
.33091 .54474 m .33551 .40286 L .32817 .52795 L F
.115 .09 .549 r
.32977 .55058 m .32537 .51523 L .33139 .532 L F
.32977 .55058 m .33139 .532 L .33347 .53777 L F
.656 .751 .92 r
.52267 .56781 m .52692 .55962 L .53213 .56497 L F
.52267 .56781 m .51744 .56247 L .52692 .55962 L F
.33935 .56774 m .34269 .55955 L .34849 .56491 L F
.33935 .56774 m .33353 .56241 L .34269 .55955 L F
.7301 .56753 m .73539 .55934 L .73992 .56469 L F
.7301 .56753 m .72555 .56219 L .73539 .55934 L F
.54677 .56747 m .55114 .55927 L .55627 .56463 L F
.54677 .56747 m .54162 .56213 L .55114 .55927 L F
.36341 .5674 m .36687 .5592 L .3726 .56456 L F
.36341 .5674 m .35767 .56206 L .36687 .5592 L F
.534 .267 .457 r
.27991 .40229 m .27909 .42875 L .28525 .40149 L F
.656 .751 .92 r
.75425 .56719 m .75965 .55899 L .76411 .56435 L F
.75425 .56719 m .74977 .56185 L .75965 .55899 L F
.57088 .56712 m .57537 .55892 L .58042 .56428 L F
.57088 .56712 m .5658 .56178 L .57537 .55892 L F
.38749 .56705 m .39107 .55885 L .39671 .56421 L F
.38749 .56705 m .38182 .56171 L .39107 .55885 L F
.608 .37 .531 r
.31556 .40184 m .31816 .43784 L .32026 .40094 L F
.674 .401 .5 r
.3125 .40031 m .31816 .43784 L .31556 .40184 L F
.608 .37 .531 r
.32026 .40094 m .31816 .43784 L .3222 .40177 L F
.656 .751 .92 r
.77841 .56684 m .78393 .55864 L .78831 .564 L F
.77841 .56684 m .774 .5615 L .78393 .55864 L F
.59499 .56677 m .59961 .55857 L .60458 .56393 L F
.59499 .56677 m .59 .56143 L .59961 .55857 L F
.41157 .56671 m .41527 .5585 L .42084 .56386 L F
.41157 .56671 m .40598 .56136 L .41527 .5585 L F
.585 .306 .459 r
.28525 .40149 m .2875 .43588 L .28835 .40091 L F
.28525 .40149 m .27909 .42875 L .2875 .43588 L F
.656 .751 .92 r
.80257 .5665 m .80822 .55829 L .81252 .56365 L F
.80257 .5665 m .79825 .56115 L .80822 .55829 L F
.61912 .56643 m .62386 .55822 L .62876 .56358 L F
.61912 .56643 m .6142 .56108 L .62386 .55822 L F
.43566 .56636 m .43948 .55815 L .44497 .56352 L F
.43566 .56636 m .43014 .56101 L .43948 .55815 L F
.587 .342 .512 r
.29467 .40113 m .29616 .40489 L .29639 .40074 L F
.585 .306 .459 r
.28835 .40091 m .29616 .40489 L .29467 .40113 L F
.656 .751 .92 r
.82675 .56615 m .83252 .55794 L .83674 .56331 L F
.82675 .56615 m .8225 .5608 L .83252 .55794 L F
.64326 .56608 m .64812 .55787 L .65294 .56324 L F
.64326 .56608 m .63842 .56073 L .64812 .55787 L F
.585 .306 .459 r
.28835 .40091 m .2875 .43588 L .29616 .40489 L F
.656 .751 .92 r
.45976 .56601 m .4637 .5578 L .46912 .56317 L F
.45976 .56601 m .45432 .56066 L .4637 .5578 L F
.27624 .56595 m .27927 .55773 L .28529 .5631 L F
.27624 .56595 m .27021 .5606 L .27927 .55773 L F
.622 .367 .51 r
.29672 .40075 m .30332 .43015 L .30477 .3996 L F
.29672 .40075 m .29616 .40489 L .30332 .43015 L F
.587 .342 .512 r
.29639 .40074 m .29616 .40489 L .29672 .40075 L F
.656 .751 .92 r
.85094 .5658 m .85683 .55759 L .86097 .56296 L F
.85094 .5658 m .84677 .56045 L .85683 .55759 L F
.66741 .56573 m .67239 .55752 L .67713 .56289 L F
.66741 .56573 m .66265 .56038 L .67239 .55752 L F
.48387 .56567 m .48793 .55745 L .49327 .56282 L F
.48387 .56567 m .47851 .56031 L .48793 .55745 L F
.674 .401 .5 r
.30859 .4004 m .31044 .45891 L .3125 .40031 L F
.30859 .4004 m .30332 .43015 L .31044 .45891 L F
.622 .367 .51 r
.30477 .3996 m .30332 .43015 L .30859 .4004 L F
.656 .751 .92 r
.30032 .5656 m .30347 .55738 L .3094 .56275 L F
.30032 .5656 m .29436 .56025 L .30347 .55738 L F
.674 .401 .5 r
.3125 .40031 m .31044 .45891 L .31816 .43784 L F
.656 .751 .92 r
.69157 .56539 m .69667 .55717 L .70133 .56254 L F
.69157 .56539 m .68688 .56003 L .69667 .55717 L F
.50799 .56532 m .51218 .5571 L .51744 .56247 L F
.50799 .56532 m .50271 .55997 L .51218 .5571 L F
.71574 .56504 m .72096 .55682 L .72555 .56219 L F
.71574 .56504 m .71113 .55968 L .72096 .55682 L F
.53213 .56497 m .53643 .55675 L .54162 .56213 L F
.53213 .56497 m .52692 .55962 L .53643 .55675 L F
.34849 .56491 m .35189 .55668 L .35767 .56206 L F
.34849 .56491 m .34269 .55955 L .35189 .55668 L F
.73992 .56469 m .74526 .55647 L .74977 .56185 L F
.73992 .56469 m .73539 .55934 L .74526 .55647 L F
.55627 .56463 m .56069 .5564 L .5658 .56178 L F
.55627 .56463 m .55114 .55927 L .56069 .5564 L F
.3726 .56456 m .37611 .55633 L .38182 .56171 L F
.3726 .56456 m .36687 .5592 L .37611 .55633 L F
.76411 .56435 m .76957 .55612 L .774 .5615 L F
.76411 .56435 m .75965 .55899 L .76957 .55612 L F
.58042 .56428 m .58497 .55605 L .59 .56143 L F
.58042 .56428 m .57537 .55892 L .58497 .55605 L F
.39671 .56421 m .40035 .55598 L .40598 .56136 L F
.39671 .56421 m .39107 .55885 L .40035 .55598 L F
.78831 .564 m .79389 .55577 L .79825 .56115 L F
.78831 .564 m .78393 .55864 L .79389 .55577 L F
.60458 .56393 m .60925 .5557 L .6142 .56108 L F
.60458 .56393 m .59961 .55857 L .60925 .5557 L F
.42084 .56386 m .42459 .55563 L .43014 .56101 L F
.42084 .56386 m .41527 .5585 L .42459 .55563 L F
.81252 .56365 m .81823 .55542 L .8225 .5608 L F
.81252 .56365 m .80822 .55829 L .81823 .55542 L F
.62876 .56358 m .63355 .55535 L .63842 .56073 L F
.62876 .56358 m .62386 .55822 L .63355 .55535 L F
.44497 .56352 m .44885 .55528 L .45432 .56066 L F
.44497 .56352 m .43948 .55815 L .44885 .55528 L F
.64 .342 .45 r
.29616 .40489 m .29564 .44794 L .30332 .43015 L F
.29616 .40489 m .2875 .43588 L .29564 .44794 L F
.656 .751 .92 r
.26118 .56345 m .26414 .55521 L .27021 .5606 L F
.26118 .56345 m .25509 .55808 L .26414 .55521 L F
.83674 .56331 m .84257 .55507 L .84677 .56045 L F
.83674 .56331 m .83252 .55794 L .84257 .55507 L F
.65294 .56324 m .65785 .555 L .66265 .56038 L F
.65294 .56324 m .64812 .55787 L .65785 .555 L F
.46912 .56317 m .47312 .55493 L .47851 .56031 L F
.46912 .56317 m .4637 .5578 L .47312 .55493 L F
.28529 .5631 m .28837 .55486 L .29436 .56025 L F
.28529 .5631 m .27927 .55773 L .28837 .55486 L F
.86097 .56296 m .86692 .55471 L .87104 .5601 L F
.86097 .56296 m .85683 .55759 L .86692 .55471 L F
.67713 .56289 m .68216 .55465 L .68688 .56003 L F
.67713 .56289 m .67239 .55752 L .68216 .55465 L F
.49327 .56282 m .49739 .55458 L .50271 .55997 L F
.49327 .56282 m .48793 .55745 L .49739 .55458 L F
.3094 .56275 m .3126 .55451 L .31852 .5599 L F
.3094 .56275 m .30347 .55738 L .3126 .55451 L F
.70133 .56254 m .70649 .55429 L .71113 .55968 L F
.70133 .56254 m .69667 .55717 L .70649 .55429 L F
.51744 .56247 m .52168 .55423 L .52692 .55962 L F
.51744 .56247 m .51218 .5571 L .52168 .55423 L F
.33353 .56241 m .33685 .55416 L .34269 .55955 L F
.72555 .56219 m .73082 .55394 L .73539 .55934 L F
.72555 .56219 m .72096 .55682 L .73082 .55394 L F
.54162 .56213 m .54598 .55387 L .55114 .55927 L F
.54162 .56213 m .53643 .55675 L .54598 .55387 L F
.35767 .56206 m .36111 .5538 L .36687 .5592 L F
.35767 .56206 m .35189 .55668 L .36111 .5538 L F
.74977 .56185 m .75517 .55359 L .75965 .55899 L F
.74977 .56185 m .74526 .55647 L .75517 .55359 L F
.5658 .56178 m .57028 .55352 L .57537 .55892 L F
.5658 .56178 m .56069 .5564 L .57028 .55352 L F
.38182 .56171 m .38538 .55345 L .39107 .55885 L F
.38182 .56171 m .37611 .55633 L .38538 .55345 L F
.774 .5615 m .77952 .55324 L .78393 .55864 L F
.774 .5615 m .76957 .55612 L .77952 .55324 L F
.59 .56143 m .5946 .55317 L .59961 .55857 L F
.59 .56143 m .58497 .55605 L .5946 .55317 L F
.40598 .56136 m .40966 .5531 L .41527 .5585 L F
.40598 .56136 m .40035 .55598 L .40966 .5531 L F
.79825 .56115 m .80389 .55289 L .80822 .55829 L F
.79825 .56115 m .79389 .55577 L .80389 .55289 L F
.6142 .56108 m .61893 .55282 L .62386 .55822 L F
.6142 .56108 m .60925 .5557 L .61893 .55282 L F
.43014 .56101 m .43395 .55275 L .43948 .55815 L F
.43014 .56101 m .42459 .55563 L .43395 .55275 L F
.8225 .5608 m .82827 .55253 L .83252 .55794 L F
.8225 .5608 m .81823 .55542 L .82827 .55253 L F
.63842 .56073 m .64327 .55247 L .64812 .55787 L F
.63842 .56073 m .63355 .55535 L .64327 .55247 L F
.45432 .56066 m .45825 .5524 L .4637 .5578 L F
.45432 .56066 m .44885 .55528 L .45825 .5524 L F
.27021 .5606 m .27322 .55233 L .27927 .55773 L F
.27021 .5606 m .26414 .55521 L .27322 .55233 L F
.84677 .56045 m .85265 .55218 L .85683 .55759 L F
.84677 .56045 m .84257 .55507 L .85265 .55218 L F
.66265 .56038 m .66761 .55211 L .67239 .55752 L F
.66265 .56038 m .65785 .555 L .66761 .55211 L F
.47851 .56031 m .48256 .55204 L .48793 .55745 L F
.47851 .56031 m .47312 .55493 L .48256 .55204 L F
.29436 .56025 m .29749 .55198 L .30347 .55738 L F
.29436 .56025 m .28837 .55486 L .29749 .55198 L F
.87104 .5601 m .87705 .55183 L .88114 .55724 L F
.87104 .5601 m .86692 .55471 L .87705 .55183 L F
.68688 .56003 m .69197 .55176 L .69667 .55717 L F
.68688 .56003 m .68216 .55465 L .69197 .55176 L F
.50271 .55997 m .50688 .55169 L .51218 .5571 L F
.50271 .55997 m .49739 .55458 L .50688 .55169 L F
.31852 .5599 m .3126 .55451 L .32177 .55162 L F
.71113 .55968 m .71634 .55141 L .72096 .55682 L F
.71113 .55968 m .70649 .55429 L .71634 .55141 L F
.52692 .55962 m .53121 .55134 L .53643 .55675 L F
.52692 .55962 m .52168 .55423 L .53121 .55134 L F
.34269 .55955 m .34607 .55127 L .35189 .55668 L F
.34269 .55955 m .33685 .55416 L .34607 .55127 L F
.73539 .55934 m .74072 .55106 L .74526 .55647 L F
.73539 .55934 m .73082 .55394 L .74072 .55106 L F
.55114 .55927 m .55555 .55099 L .56069 .5564 L F
.55114 .55927 m .54598 .55387 L .55555 .55099 L F
.36687 .5592 m .37037 .55092 L .37611 .55633 L F
.36687 .5592 m .36111 .5538 L .37037 .55092 L F
.75965 .55899 m .76511 .5507 L .76957 .55612 L F
.75965 .55899 m .75517 .55359 L .76511 .5507 L F
.57537 .55892 m .5799 .55063 L .58497 .55605 L F
.57537 .55892 m .57028 .55352 L .5799 .55063 L F
.39107 .55885 m .39468 .55057 L .40035 .55598 L F
.39107 .55885 m .38538 .55345 L .39468 .55057 L F
.78393 .55864 m .78951 .55035 L .79389 .55577 L F
.78393 .55864 m .77952 .55324 L .78951 .55035 L F
.59961 .55857 m .60427 .55028 L .60925 .5557 L F
.59961 .55857 m .5946 .55317 L .60427 .55028 L F
.41527 .5585 m .41901 .55021 L .42459 .55563 L F
.41527 .5585 m .40966 .5531 L .41901 .55021 L F
.80822 .55829 m .81392 .55 L .81823 .55542 L F
.80822 .55829 m .80389 .55289 L .81392 .55 L F
.62386 .55822 m .62864 .54993 L .63355 .55535 L F
.62386 .55822 m .61893 .55282 L .62864 .54993 L F
.43948 .55815 m .44334 .54986 L .44885 .55528 L F
.43948 .55815 m .43395 .55275 L .44334 .54986 L F
.25509 .55808 m .25803 .54979 L .26414 .55521 L F
.25509 .55808 m .24896 .55268 L .25803 .54979 L F
.83252 .55794 m .83834 .54964 L .84257 .55507 L F
.83252 .55794 m .82827 .55253 L .83834 .54964 L F
.64812 .55787 m .65302 .54957 L .65785 .555 L F
.64812 .55787 m .64327 .55247 L .65302 .54957 L F
.4637 .5578 m .46768 .54951 L .47312 .55493 L F
.4637 .5578 m .45825 .5524 L .46768 .54951 L F
.27927 .55773 m .28233 .54944 L .28837 .55486 L F
.27927 .55773 m .27322 .55233 L .28233 .54944 L F
.85683 .55759 m .86277 .54929 L .86692 .55471 L F
.85683 .55759 m .85265 .55218 L .86277 .54929 L F
.67239 .55752 m .67741 .54922 L .68216 .55465 L F
.67239 .55752 m .66761 .55211 L .67741 .54922 L F
.48793 .55745 m .49204 .54915 L .49739 .55458 L F
.48793 .55745 m .48256 .55204 L .49204 .54915 L F
.30347 .55738 m .30665 .54908 L .3126 .55451 L F
.30347 .55738 m .29749 .55198 L .30665 .54908 L F
.88114 .55724 m .88721 .54894 L .89128 .55436 L F
.88114 .55724 m .87705 .55183 L .88721 .54894 L F
.69667 .55717 m .70182 .54887 L .70649 .55429 L F
.69667 .55717 m .69197 .55176 L .70182 .54887 L F
.51218 .5571 m .5164 .5488 L .52168 .55423 L F
.51218 .5571 m .50688 .55169 L .5164 .5488 L F
.72096 .55682 m .72623 .54851 L .73082 .55394 L F
.72096 .55682 m .71634 .55141 L .72623 .54851 L F
.53643 .55675 m .54078 .54844 L .54598 .55387 L F
.53643 .55675 m .53121 .55134 L .54078 .54844 L F
.35189 .55668 m .35531 .54838 L .36111 .5538 L F
.35189 .55668 m .34607 .55127 L .35531 .54838 L F
.74526 .55647 m .75065 .54816 L .75517 .55359 L F
.74526 .55647 m .74072 .55106 L .75065 .54816 L F
.56069 .5564 m .56516 .54809 L .57028 .55352 L F
.56069 .5564 m .55555 .55099 L .56516 .54809 L F
.37611 .55633 m .37966 .54802 L .38538 .55345 L F
.37611 .55633 m .37037 .55092 L .37966 .54802 L F
.76957 .55612 m .77509 .54781 L .77952 .55324 L F
.76957 .55612 m .76511 .5507 L .77509 .54781 L F
.58497 .55605 m .58956 .54774 L .5946 .55317 L F
.58497 .55605 m .5799 .55063 L .58956 .54774 L F
.40035 .55598 m .40402 .54767 L .40966 .5531 L F
.40035 .55598 m .39468 .55057 L .40402 .54767 L F
.79389 .55577 m .79953 .54745 L .80389 .55289 L F
.79389 .55577 m .78951 .55035 L .79953 .54745 L F
.60925 .5557 m .61397 .54738 L .61893 .55282 L F
.60925 .5557 m .60427 .55028 L .61397 .54738 L F
.42459 .55563 m .42838 .54731 L .43395 .55275 L F
.42459 .55563 m .41901 .55021 L .42838 .54731 L F
.81823 .55542 m .82399 .5471 L .82827 .55253 L F
.81823 .55542 m .81392 .55 L .82399 .5471 L F
.63355 .55535 m .63838 .54703 L .64327 .55247 L F
.63355 .55535 m .62864 .54993 L .63838 .54703 L F
.44885 .55528 m .45276 .54696 L .45825 .5524 L F
.44885 .55528 m .44334 .54986 L .45276 .54696 L F
.26414 .55521 m .26713 .54689 L .27322 .55233 L F
.26414 .55521 m .25803 .54979 L .26713 .54689 L F
.84257 .55507 m .84845 .54674 L .85265 .55218 L F
.84257 .55507 m .83834 .54964 L .84845 .54674 L F
.65785 .555 m .66281 .54667 L .66761 .55211 L F
.65785 .555 m .65302 .54957 L .66281 .54667 L F
.47312 .55493 m .47715 .5466 L .48256 .55204 L F
.47312 .55493 m .46768 .54951 L .47715 .5466 L F
.28837 .55486 m .29148 .54653 L .29749 .55198 L F
.28837 .55486 m .28233 .54944 L .29148 .54653 L F
.86692 .55471 m .87293 .54639 L .87705 .55183 L F
.86692 .55471 m .86277 .54929 L .87293 .54639 L F
.68216 .55465 m .68725 .54632 L .69197 .55176 L F
.68216 .55465 m .67741 .54922 L .68725 .54632 L F
.49739 .55458 m .50155 .54625 L .50688 .55169 L F
.49739 .55458 m .49204 .54915 L .50155 .54625 L F
.3126 .55451 m .31584 .54618 L .32177 .55162 L F
.3126 .55451 m .30665 .54908 L .31584 .54618 L F
.89128 .55436 m .89741 .54603 L .90146 .55148 L F
.89128 .55436 m .88721 .54894 L .89741 .54603 L F
.70649 .55429 m .71169 .54596 L .71634 .55141 L F
.70649 .55429 m .70182 .54887 L .71169 .54596 L F
.52168 .55423 m .52596 .54589 L .53121 .55134 L F
.52168 .55423 m .5164 .5488 L .52596 .54589 L F
.33685 .55416 m .34021 .54582 L .34607 .55127 L F
.73082 .55394 m .73615 .54561 L .74072 .55106 L F
.73082 .55394 m .72623 .54851 L .73615 .54561 L F
.54598 .55387 m .55038 .54554 L .55555 .55099 L F
.54598 .55387 m .54078 .54844 L .55038 .54554 L F
.36111 .5538 m .36459 .54547 L .37037 .55092 L F
.36111 .5538 m .35531 .54838 L .36459 .54547 L F
.75517 .55359 m .76062 .54525 L .76511 .5507 L F
.75517 .55359 m .75065 .54816 L .76062 .54525 L F
.57028 .55352 m .57481 .54518 L .5799 .55063 L F
.57028 .55352 m .56516 .54809 L .57481 .54518 L F
.321 .008 .268 r
.26095 .43415 m .26206 .44849 L .27029 .42787 L F
.26095 .43415 m .25254 .45581 L .26206 .44849 L F
.093 0 .135 r
.25099 .44807 m .25254 .45581 L .26095 .43415 L F
.656 .751 .92 r
.38538 .55345 m .38898 .54511 L .39468 .55057 L F
.38538 .55345 m .37966 .54802 L .38898 .54511 L F
.77952 .55324 m .7851 .5449 L .78951 .55035 L F
.77952 .55324 m .77509 .54781 L .7851 .5449 L F
.5946 .55317 m .59925 .54483 L .60427 .55028 L F
.5946 .55317 m .58956 .54774 L .59925 .54483 L F
.40966 .5531 m .41338 .54476 L .41901 .55021 L F
.40966 .5531 m .40402 .54767 L .41338 .54476 L F
.80389 .55289 m .80959 .54454 L .81392 .55 L F
.80389 .55289 m .79953 .54745 L .80959 .54454 L F
.61893 .55282 m .6237 .54447 L .62864 .54993 L F
.61893 .55282 m .61397 .54738 L .6237 .54447 L F
.43395 .55275 m .4378 .5444 L .44334 .54986 L F
.43395 .55275 m .42838 .54731 L .4378 .5444 L F
.24896 .55268 m .25188 .54433 L .25803 .54979 L F
.82827 .55253 m .83409 .54419 L .83834 .54964 L F
.82827 .55253 m .82399 .5471 L .83409 .54419 L F
.64327 .55247 m .64816 .54412 L .65302 .54957 L F
.64327 .55247 m .63838 .54703 L .64816 .54412 L F
.45825 .5524 m .46222 .54405 L .46768 .54951 L F
.45825 .5524 m .45276 .54696 L .46222 .54405 L F
.27322 .55233 m .27626 .54398 L .28233 .54944 L F
.27322 .55233 m .26713 .54689 L .27626 .54398 L F
.446 .121 .319 r
.27029 .42787 m .27121 .44595 L .27909 .42875 L F
.27029 .42787 m .26206 .44849 L .27121 .44595 L F
.656 .751 .92 r
.85265 .55218 m .8586 .54383 L .86277 .54929 L F
.85265 .55218 m .84845 .54674 L .8586 .54383 L F
.66761 .55211 m .67263 .54376 L .67741 .54922 L F
.66761 .55211 m .66281 .54667 L .67263 .54376 L F
.48256 .55204 m .48665 .54369 L .49204 .54915 L F
.48256 .55204 m .47715 .5466 L .48665 .54369 L F
.29749 .55198 m .30065 .54362 L .30665 .54908 L F
.29749 .55198 m .29148 .54653 L .30065 .54362 L F
.87705 .55183 m .88312 .54348 L .88721 .54894 L F
.87705 .55183 m .87293 .54639 L .88312 .54348 L F
.69197 .55176 m .69711 .54341 L .70182 .54887 L F
.69197 .55176 m .68725 .54632 L .69711 .54341 L F
.50688 .55169 m .51109 .54334 L .5164 .5488 L F
.50688 .55169 m .50155 .54625 L .51109 .54334 L F
.32177 .55162 m .31584 .54618 L .32506 .54327 L F
.90146 .55148 m .90765 .54312 L .91167 .54858 L F
.90146 .55148 m .89741 .54603 L .90765 .54312 L F
.71634 .55141 m .72161 .54305 L .72623 .54851 L F
.71634 .55141 m .71169 .54596 L .72161 .54305 L F
.53121 .55134 m .53555 .54298 L .54078 .54844 L F
.53121 .55134 m .52596 .54589 L .53555 .54298 L F
.34607 .55127 m .34947 .54291 L .35531 .54838 L F
.34607 .55127 m .34021 .54582 L .34947 .54291 L F
.74072 .55106 m .74611 .54269 L .75065 .54816 L F
.74072 .55106 m .73615 .54561 L .74611 .54269 L F
.55555 .55099 m .56001 .54262 L .56516 .54809 L F
.55555 .55099 m .55038 .54554 L .56001 .54262 L F
.37037 .55092 m .3739 .54255 L .37966 .54802 L F
.37037 .55092 m .36459 .54547 L .3739 .54255 L F
.093 0 .135 r
.25099 .44807 m .24263 .46785 L .25254 .45581 L F
.656 .751 .92 r
.76511 .5507 m .77062 .54234 L .77509 .54781 L F
.76511 .5507 m .76062 .54525 L .77062 .54234 L F
.5799 .55063 m .58449 .54227 L .58956 .54774 L F
.5799 .55063 m .57481 .54518 L .58449 .54227 L F
.39468 .55057 m .39834 .5422 L .40402 .54767 L F
.39468 .55057 m .38898 .54511 L .39834 .5422 L F
.78951 .55035 m .79515 .54198 L .79953 .54745 L F
.78951 .55035 m .7851 .5449 L .79515 .54198 L F
.60427 .55028 m .60897 .54191 L .61397 .54738 L F
.60427 .55028 m .59925 .54483 L .60897 .54191 L F
.41901 .55021 m .42278 .54184 L .42838 .54731 L F
.41901 .55021 m .41338 .54476 L .42278 .54184 L F
.81392 .55 m .81968 .54162 L .82399 .5471 L F
.81392 .55 m .80959 .54454 L .81968 .54162 L F
.62864 .54993 m .63347 .54155 L .63838 .54703 L F
.62864 .54993 m .6237 .54447 L .63347 .54155 L F
.44334 .54986 m .44724 .54148 L .45276 .54696 L F
.44334 .54986 m .4378 .5444 L .44724 .54148 L F
.25803 .54979 m .261 .54141 L .26713 .54689 L F
.25803 .54979 m .25188 .54433 L .261 .54141 L F
.83834 .54964 m .84423 .54127 L .84845 .54674 L F
.83834 .54964 m .83409 .54419 L .84423 .54127 L F
.65302 .54957 m .65797 .5412 L .66281 .54667 L F
.65302 .54957 m .64816 .54412 L .65797 .5412 L F
.46768 .54951 m .47171 .54113 L .47715 .5466 L F
.46768 .54951 m .46222 .54405 L .47171 .54113 L F
.28233 .54944 m .28542 .54106 L .29148 .54653 L F
.28233 .54944 m .27626 .54398 L .28542 .54106 L F
.86277 .54929 m .86878 .54091 L .87293 .54639 L F
.86277 .54929 m .8586 .54383 L .86878 .54091 L F
.67741 .54922 m .68249 .54084 L .68725 .54632 L F
.67741 .54922 m .67263 .54376 L .68249 .54084 L F
.49204 .54915 m .49618 .54077 L .50155 .54625 L F
.49204 .54915 m .48665 .54369 L .49618 .54077 L F
.30665 .54908 m .30986 .5407 L .31584 .54618 L F
.30665 .54908 m .30065 .54362 L .30986 .5407 L F
.88721 .54894 m .89335 .54055 L .89741 .54603 L F
.88721 .54894 m .88312 .54348 L .89335 .54055 L F
.70182 .54887 m .70702 .54048 L .71169 .54596 L F
.70182 .54887 m .69711 .54341 L .70702 .54048 L F
.5164 .5488 m .52067 .54041 L .52596 .54589 L F
.5164 .5488 m .51109 .54334 L .52067 .54041 L F
.91167 .54858 m .91792 .5402 L .92191 .54568 L F
.91167 .54858 m .90765 .54312 L .91792 .5402 L F
.72623 .54851 m .73155 .54013 L .73615 .54561 L F
.72623 .54851 m .72161 .54305 L .73155 .54013 L F
.54078 .54844 m .54517 .54006 L .55038 .54554 L F
.54078 .54844 m .53555 .54298 L .54517 .54006 L F
.35531 .54838 m .35877 .53999 L .36459 .54547 L F
.35531 .54838 m .34947 .54291 L .35877 .53999 L F
.75065 .54816 m .7561 .53977 L .76062 .54525 L F
.75065 .54816 m .74611 .54269 L .7561 .53977 L F
.56516 .54809 m .56968 .5397 L .57481 .54518 L F
.56516 .54809 m .56001 .54262 L .56968 .5397 L F
.37966 .54802 m .38324 .53963 L .38898 .54511 L F
.37966 .54802 m .3739 .54255 L .38324 .53963 L F
.77509 .54781 m .78066 .53941 L .7851 .5449 L F
.77509 .54781 m .77062 .54234 L .78066 .53941 L F
.58956 .54774 m .5942 .53934 L .59925 .54483 L F
.58956 .54774 m .58449 .54227 L .5942 .53934 L F
.40402 .54767 m .40772 .53927 L .41338 .54476 L F
.40402 .54767 m .39834 .5422 L .40772 .53927 L F
.79953 .54745 m .80523 .53905 L .80959 .54454 L F
.79953 .54745 m .79515 .54198 L .80523 .53905 L F
.61397 .54738 m .61873 .53898 L .6237 .54447 L F
.61397 .54738 m .60897 .54191 L .61873 .53898 L F
.42838 .54731 m .43221 .53891 L .4378 .5444 L F
.42838 .54731 m .42278 .54184 L .43221 .53891 L F
.538 .194 .332 r
.27909 .42875 m .28006 .44793 L .2875 .43588 L F
.27909 .42875 m .27121 .44595 L .28006 .44793 L F
.656 .751 .92 r
.82399 .5471 m .82981 .53869 L .83409 .54419 L F
.82399 .5471 m .81968 .54162 L .82981 .53869 L F
.63838 .54703 m .64327 .53862 L .64816 .54412 L F
.63838 .54703 m .63347 .54155 L .64327 .53862 L F
.45276 .54696 m .45672 .53855 L .46222 .54405 L F
.45276 .54696 m .44724 .54148 L .45672 .53855 L F
.26713 .54689 m .27015 .53848 L .27626 .54398 L F
.26713 .54689 m .261 .54141 L .27015 .53848 L F
.84845 .54674 m .8544 .53834 L .8586 .54383 L F
.84845 .54674 m .84423 .54127 L .8544 .53834 L F
.66281 .54667 m .66782 .53827 L .67263 .54376 L F
.66281 .54667 m .65797 .5412 L .66782 .53827 L F
.47715 .5466 m .48123 .5382 L .48665 .54369 L F
.47715 .5466 m .47171 .54113 L .48123 .5382 L F
.29148 .54653 m .29462 .53813 L .30065 .54362 L F
.29148 .54653 m .28542 .54106 L .29462 .53813 L F
.87293 .54639 m .879 .53798 L .88312 .54348 L F
.87293 .54639 m .86878 .54091 L .879 .53798 L F
.68725 .54632 m .69238 .53791 L .69711 .54341 L F
.68725 .54632 m .68249 .54084 L .69238 .53791 L F
.50155 .54625 m .50575 .53784 L .51109 .54334 L F
.50155 .54625 m .49618 .54077 L .50575 .53784 L F
.31584 .54618 m .3191 .53777 L .32506 .54327 L F
.31584 .54618 m .30986 .5407 L .3191 .53777 L F
.89741 .54603 m .90361 .53762 L .90765 .54312 L F
.89741 .54603 m .89335 .54055 L .90361 .53762 L F
.712 .382 .418 r
.30332 .43015 m .30368 .46337 L .31044 .45891 L F
.30332 .43015 m .29564 .44794 L .30368 .46337 L F
.656 .751 .92 r
.71169 .54596 m .71695 .53755 L .72161 .54305 L F
.71169 .54596 m .70702 .54048 L .71695 .53755 L F
.52596 .54589 m .53028 .53748 L .53555 .54298 L F
.52596 .54589 m .52067 .54041 L .53028 .53748 L F
.34021 .54582 m .3436 .53741 L .34947 .54291 L F
.34021 .54582 m .33431 .54034 L .3436 .53741 L F
.92191 .54568 m .92823 .53726 L .93219 .54276 L F
.92191 .54568 m .91792 .5402 L .92823 .53726 L F
.73615 .54561 m .74154 .53719 L .74611 .54269 L F
.73615 .54561 m .73155 .54013 L .74154 .53719 L F
.55038 .54554 m .55483 .53712 L .56001 .54262 L F
.55038 .54554 m .54517 .54006 L .55483 .53712 L F
.36459 .54547 m .3681 .53705 L .3739 .54255 L F
.36459 .54547 m .35877 .53999 L .3681 .53705 L F
.76062 .54525 m .76613 .53683 L .77062 .54234 L F
.76062 .54525 m .7561 .53977 L .76613 .53683 L F
.57481 .54518 m .57938 .53676 L .58449 .54227 L F
.57481 .54518 m .56968 .5397 L .57938 .53676 L F
.38898 .54511 m .39262 .53669 L .39834 .5422 L F
.38898 .54511 m .38324 .53963 L .39262 .53669 L F
.7851 .5449 m .79073 .53647 L .79515 .54198 L F
.7851 .5449 m .78066 .53941 L .79073 .53647 L F
.42278 .54184 m .4266 .53339 L .43221 .53891 L F
.42278 .54184 m .41714 .53633 L .4266 .53339 L F
.43221 .53891 m .4266 .53339 L .43608 .53043 L F
.41714 .53633 m .42094 .52782 L .4266 .53339 L F
.4266 .53339 m .43045 .52484 L .43608 .53043 L F
.4266 .53339 m .42094 .52782 L .43045 .52484 L F
.42094 .52782 m .42478 .51922 L .43045 .52484 L F
.43045 .52484 m .42478 .51922 L .43434 .51622 L F
.42478 .51922 m .42865 .51054 L .43434 .51622 L F
.42478 .51922 m .41907 .51357 L .42865 .51054 L F
.43434 .51622 m .42865 .51054 L .43827 .5075 L F
.41907 .51357 m .42293 .50482 L .42865 .51054 L F
.42865 .51054 m .43257 .50176 L .43827 .5075 L F
.42865 .51054 m .42293 .50482 L .43257 .50176 L F
.42293 .50482 m .42683 .49599 L .43257 .50176 L F
.42293 .50482 m .41717 .49907 L .42683 .49599 L F
.43257 .50176 m .42683 .49599 L .4342 .49364 L F
.43544 .49532 m .4342 .49364 L .43653 .4929 L F
.43257 .50176 m .4342 .49364 L .43544 .49532 L F
.41717 .49907 m .42105 .49017 L .42683 .49599 L F
.42683 .49599 m .43077 .48706 L .43653 .4929 L F
.42683 .49599 m .42105 .49017 L .4296 .48743 L F
.43023 .48828 m .4296 .48743 L .43077 .48706 L F
.42683 .49599 m .4296 .48743 L .43023 .48828 L F
.543 .322 .53 r
.42729 .48432 m .4283 .37115 L .43276 .37758 L F
.656 .751 .92 r
.42094 .52782 m .41525 .52222 L .42478 .51922 L F
.41525 .52222 m .41907 .51357 L .42478 .51922 L F
.41332 .50787 m .41717 .49907 L .42293 .50482 L F
.969 .859 .675 r
.4243 .50323 m .41822 .50378 L .41949 .50082 L F
.543 .322 .53 r
.42627 .50421 m .42497 .48119 L .42729 .48432 L F
.42431 .50323 m .42497 .48119 L .42627 .50421 L F
.42497 .48119 m .4283 .37115 L .42729 .48432 L F
.42141 .59907 m .42729 .48432 L .42621 .6051 L F
.42729 .48432 m .43276 .37758 L .4296 .48743 L F
.42729 .48432 m .4296 .48743 L .42621 .6051 L F
.42141 .59907 m .4243 .50323 L .42436 .50144 L F
.42436 .50144 m .42436 .50144 L .4283 .37115 L F
.42141 .59907 m .42436 .50144 L .42436 .50144 L F
.4283 .37115 m .42436 .50144 L .4351 .46507 L F
.42436 .50144 m .4243 .50323 L .42569 .49832 L F
.42436 .50144 m .42569 .49832 L .4351 .46507 L F
.92 .817 .727 r
.41949 .50082 m .42261 .48148 L .42873 .47927 L F
.41822 .50378 m .41882 .50074 L .41949 .50082 L F
.656 .751 .92 r
.41717 .49907 m .41136 .49327 L .42105 .49017 L F
.92 .817 .727 r
.41882 .50074 m .42261 .48148 L .41949 .50082 L F
.969 .859 .675 r
.4243 .50323 m .41949 .50082 L .42873 .47927 L F
.543 .322 .53 r
.42141 .59907 m .42431 .50323 L .42627 .50421 L F
.656 .751 .92 r
.59925 .54483 m .60395 .5364 L .60897 .54191 L F
.59925 .54483 m .5942 .53934 L .60395 .5364 L F
.41338 .54476 m .41714 .53633 L .42278 .54184 L F
.41338 .54476 m .40772 .53927 L .41714 .53633 L F
.80959 .54454 m .81535 .53611 L .81968 .54162 L F
.80959 .54454 m .80523 .53905 L .81535 .53611 L F
.6237 .54447 m .62852 .53604 L .63347 .54155 L F
.6237 .54447 m .61873 .53898 L .62852 .53604 L F
.4378 .5444 m .44168 .53597 L .44724 .54148 L F
.4378 .5444 m .43221 .53891 L .44168 .53597 L F
.83409 .54419 m .83997 .53576 L .84423 .54127 L F
.83409 .54419 m .82981 .53869 L .83997 .53576 L F
.64816 .54412 m .65311 .53568 L .65797 .5412 L F
.64816 .54412 m .64327 .53862 L .65311 .53568 L F
.46222 .54405 m .46623 .53561 L .47171 .54113 L F
.46222 .54405 m .45672 .53855 L .46623 .53561 L F
.27626 .54398 m .27933 .53554 L .28542 .54106 L F
.27626 .54398 m .27015 .53848 L .27933 .53554 L F
.8586 .54383 m .8646 .5354 L .86878 .54091 L F
.8586 .54383 m .8544 .53834 L .8646 .5354 L F
.67263 .54376 m .6777 .53533 L .68249 .54084 L F
.67263 .54376 m .66782 .53827 L .6777 .53533 L F
.48665 .54369 m .49078 .53526 L .49618 .54077 L F
.48665 .54369 m .48123 .5382 L .49078 .53526 L F
.30065 .54362 m .30385 .53518 L .30986 .5407 L F
.30065 .54362 m .29462 .53813 L .30385 .53518 L F
.88312 .54348 m .88925 .53504 L .89335 .54055 L F
.88312 .54348 m .879 .53798 L .88925 .53504 L F
.69711 .54341 m .70231 .53497 L .70702 .54048 L F
.69711 .54341 m .69238 .53791 L .70231 .53497 L F
.51109 .54334 m .51535 .5349 L .52067 .54041 L F
.51109 .54334 m .50575 .53784 L .51535 .5349 L F
.90765 .54312 m .91391 .53468 L .91792 .5402 L F
.90765 .54312 m .90361 .53762 L .91391 .53468 L F
.72161 .54305 m .72693 .53461 L .73155 .54013 L F
.72161 .54305 m .71695 .53755 L .72693 .53461 L F
.53555 .54298 m .53993 .53454 L .54517 .54006 L F
.53555 .54298 m .53028 .53748 L .53993 .53454 L F
.34947 .54291 m .35292 .53447 L .35877 .53999 L F
.34947 .54291 m .3436 .53741 L .35292 .53447 L F
.93219 .54276 m .93857 .53432 L .94251 .53984 L F
.93219 .54276 m .92823 .53726 L .93857 .53432 L F
.74611 .54269 m .75155 .53425 L .7561 .53977 L F
.74611 .54269 m .74154 .53719 L .75155 .53425 L F
.56001 .54262 m .56452 .53418 L .56968 .5397 L F
.56001 .54262 m .55483 .53712 L .56452 .53418 L F
.3739 .54255 m .37747 .53411 L .38324 .53963 L F
.3739 .54255 m .3681 .53705 L .37747 .53411 L F
.77062 .54234 m .77619 .53389 L .78066 .53941 L F
.77062 .54234 m .76613 .53683 L .77619 .53389 L F
.58449 .54227 m .58912 .53382 L .5942 .53934 L F
.58449 .54227 m .57938 .53676 L .58912 .53382 L F
.39834 .5422 m .40203 .53375 L .40772 .53927 L F
.39834 .5422 m .39262 .53669 L .40203 .53375 L F
.79515 .54198 m .80084 .53353 L .80523 .53905 L F
.79515 .54198 m .79073 .53647 L .80084 .53353 L F
.60897 .54191 m .61373 .53346 L .61873 .53898 L F
.60897 .54191 m .60395 .5364 L .61373 .53346 L F
.81968 .54162 m .8255 .53317 L .82981 .53869 L F
.81968 .54162 m .81535 .53611 L .8255 .53317 L F
.63347 .54155 m .63835 .5331 L .64327 .53862 L F
.63347 .54155 m .62852 .53604 L .63835 .5331 L F
.44724 .54148 m .45118 .53302 L .45672 .53855 L F
.44724 .54148 m .44168 .53597 L .45118 .53302 L F
.84423 .54127 m .85017 .53281 L .8544 .53834 L F
.84423 .54127 m .83997 .53576 L .85017 .53281 L F
.65797 .5412 m .66298 .53273 L .66782 .53827 L F
.65797 .5412 m .65311 .53568 L .66298 .53273 L F
.47171 .54113 m .47577 .53266 L .48123 .5382 L F
.47171 .54113 m .46623 .53561 L .47577 .53266 L F
.28542 .54106 m .28855 .53259 L .29462 .53813 L F
.28542 .54106 m .27933 .53554 L .28855 .53259 L F
.86878 .54091 m .87485 .53244 L .879 .53798 L F
.86878 .54091 m .8646 .5354 L .87485 .53244 L F
.68249 .54084 m .68762 .53237 L .69238 .53791 L F
.68249 .54084 m .6777 .53533 L .68762 .53237 L F
.49618 .54077 m .50037 .5323 L .50575 .53784 L F
.49618 .54077 m .49078 .53526 L .50037 .5323 L F
.30986 .5407 m .31311 .53223 L .3191 .53777 L F
.30986 .5407 m .30385 .53518 L .31311 .53223 L F
.89335 .54055 m .89954 .53208 L .90361 .53762 L F
.89335 .54055 m .88925 .53504 L .89954 .53208 L F
.70702 .54048 m .71227 .53201 L .71695 .53755 L F
.70702 .54048 m .70231 .53497 L .71227 .53201 L F
.52067 .54041 m .52498 .53194 L .53028 .53748 L F
.52067 .54041 m .51535 .5349 L .52498 .53194 L F
.33431 .54034 m .33768 .53187 L .3436 .53741 L F
.91792 .5402 m .92424 .53172 L .92823 .53726 L F
.91792 .5402 m .91391 .53468 L .92424 .53172 L F
.73155 .54013 m .73693 .53165 L .74154 .53719 L F
.73155 .54013 m .72693 .53461 L .73693 .53165 L F
.54517 .54006 m .54961 .53158 L .55483 .53712 L F
.54517 .54006 m .53993 .53454 L .54961 .53158 L F
.35877 .53999 m .36227 .53151 L .3681 .53705 L F
.35877 .53999 m .35292 .53447 L .36227 .53151 L F
.94251 .53984 m .94895 .53136 L .95286 .5369 L F
.94251 .53984 m .93857 .53432 L .94895 .53136 L F
.7561 .53977 m .7616 .53129 L .76613 .53683 L F
.7561 .53977 m .75155 .53425 L .7616 .53129 L F
.56968 .5397 m .57424 .53122 L .57938 .53676 L F
.56968 .5397 m .56452 .53418 L .57424 .53122 L F
.38324 .53963 m .38686 .53115 L .39262 .53669 L F
.38324 .53963 m .37747 .53411 L .38686 .53115 L F
.78066 .53941 m .78629 .53093 L .79073 .53647 L F
.78066 .53941 m .77619 .53389 L .78629 .53093 L F
.5942 .53934 m .59889 .53086 L .60395 .5364 L F
.5942 .53934 m .58912 .53382 L .59889 .53086 L F
.40772 .53927 m .41147 .53079 L .41714 .53633 L F
.40772 .53927 m .40203 .53375 L .41147 .53079 L F
.622 .248 .313 r
.2875 .43588 m .28869 .4538 L .29564 .44794 L F
.2875 .43588 m .28006 .44793 L .28869 .4538 L F
.656 .751 .92 r
.80523 .53905 m .81098 .53057 L .81535 .53611 L F
.80523 .53905 m .80084 .53353 L .81098 .53057 L F
.543 .322 .53 r
.4283 .37115 m .4351 .46507 L .43776 .36792 L F
.656 .751 .92 r
.61873 .53898 m .62354 .5305 L .62852 .53604 L F
.61873 .53898 m .61373 .53346 L .62354 .5305 L F
.43221 .53891 m .43608 .53043 L .44168 .53597 L F
.82981 .53869 m .83569 .53021 L .83997 .53576 L F
.82981 .53869 m .8255 .53317 L .83569 .53021 L F
.64327 .53862 m .64821 .53014 L .65311 .53568 L F
.64327 .53862 m .63835 .5331 L .64821 .53014 L F
.45672 .53855 m .46071 .53007 L .46623 .53561 L F
.45672 .53855 m .45118 .53302 L .46071 .53007 L F
.8544 .53834 m .8604 .52985 L .8646 .5354 L F
.8544 .53834 m .85017 .53281 L .8604 .52985 L F
.66782 .53827 m .67288 .52977 L .6777 .53533 L F
.66782 .53827 m .66298 .53273 L .67288 .52977 L F
.48123 .5382 m .48535 .5297 L .49078 .53526 L F
.48123 .5382 m .47577 .53266 L .48535 .5297 L F
.29462 .53813 m .29779 .52963 L .30385 .53518 L F
.29462 .53813 m .28855 .53259 L .29779 .52963 L F
.879 .53798 m .88513 .52948 L .88925 .53504 L F
.879 .53798 m .87485 .53244 L .88513 .52948 L F
.69238 .53791 m .69757 .52941 L .70231 .53497 L F
.69238 .53791 m .68762 .53237 L .69757 .52941 L F
.50575 .53784 m .50999 .52934 L .51535 .5349 L F
.50575 .53784 m .50037 .5323 L .50999 .52934 L F
.3191 .53777 m .31311 .53223 L .3224 .52927 L F
.90361 .53762 m .90986 .52912 L .91391 .53468 L F
.90361 .53762 m .89954 .53208 L .90986 .52912 L F
.71695 .53755 m .72227 .52905 L .72693 .53461 L F
.71695 .53755 m .71227 .53201 L .72227 .52905 L F
.53028 .53748 m .53465 .52898 L .53993 .53454 L F
.53028 .53748 m .52498 .53194 L .53465 .52898 L F
.3436 .53741 m .34702 .52891 L .35292 .53447 L F
.3436 .53741 m .33768 .53187 L .34702 .52891 L F
.92823 .53726 m .93461 .52876 L .93857 .53432 L F
.92823 .53726 m .92424 .53172 L .93461 .52876 L F
.74154 .53719 m .74697 .52869 L .75155 .53425 L F
.74154 .53719 m .73693 .53165 L .74697 .52869 L F
.55483 .53712 m .55932 .52862 L .56452 .53418 L F
.55483 .53712 m .54961 .53158 L .55932 .52862 L F
.3681 .53705 m .37165 .52855 L .37747 .53411 L F
.3681 .53705 m .36227 .53151 L .37165 .52855 L F
.95286 .5369 m .95937 .5284 L .96325 .53396 L F
.95286 .5369 m .94895 .53136 L .95937 .5284 L F
.76613 .53683 m .77169 .52833 L .77619 .53389 L F
.76613 .53683 m .7616 .53129 L .77169 .52833 L F
.57938 .53676 m .584 .52825 L .58912 .53382 L F
.57938 .53676 m .57424 .53122 L .584 .52825 L F
.39262 .53669 m .39629 .52818 L .40203 .53375 L F
.39262 .53669 m .38686 .53115 L .39629 .52818 L F
.79073 .53647 m .79642 .52796 L .80084 .53353 L F
.79073 .53647 m .78629 .53093 L .79642 .52796 L F
.60395 .5364 m .60869 .52789 L .61373 .53346 L F
.60395 .5364 m .59889 .53086 L .60869 .52789 L F
.41714 .53633 m .41147 .53079 L .42094 .52782 L F
.81535 .53611 m .82116 .5276 L .8255 .53317 L F
.81535 .53611 m .81098 .53057 L .82116 .5276 L F
.543 .322 .53 r
.43776 .36792 m .4351 .46507 L .43776 .36792 L F
.43776 .36792 m .44548 .43732 L .44725 .36468 L F
.43776 .36792 m .4351 .46507 L .44548 .43732 L F
.656 .751 .92 r
.62852 .53604 m .63339 .52753 L .63835 .5331 L F
.62852 .53604 m .62354 .5305 L .63339 .52753 L F
.44168 .53597 m .4456 .52746 L .45118 .53302 L F
.44168 .53597 m .43608 .53043 L .4456 .52746 L F
.83997 .53576 m .84591 .52724 L .85017 .53281 L F
.83997 .53576 m .83569 .53021 L .84591 .52724 L F
.65311 .53568 m .6581 .52717 L .66298 .53273 L F
.65311 .53568 m .64821 .53014 L .6581 .52717 L F
.46623 .53561 m .47027 .5271 L .47577 .53266 L F
.46623 .53561 m .46071 .53007 L .47027 .5271 L F
.8646 .5354 m .87067 .52687 L .87485 .53244 L F
.8646 .5354 m .8604 .52985 L .87067 .52687 L F
.6777 .53533 m .68282 .5268 L .68762 .53237 L F
.6777 .53533 m .67288 .52977 L .68282 .5268 L F
.49078 .53526 m .49496 .52673 L .50037 .5323 L F
.49078 .53526 m .48535 .5297 L .49496 .52673 L F
.30385 .53518 m .30708 .52666 L .31311 .53223 L F
.30385 .53518 m .29779 .52963 L .30708 .52666 L F
.88925 .53504 m .89544 .52651 L .89954 .53208 L F
.88925 .53504 m .88513 .52948 L .89544 .52651 L F
.70231 .53497 m .70755 .52644 L .71227 .53201 L F
.70231 .53497 m .69757 .52941 L .70755 .52644 L F
.51535 .5349 m .51965 .52637 L .52498 .53194 L F
.51535 .5349 m .50999 .52934 L .51965 .52637 L F
.91391 .53468 m .92023 .52615 L .92424 .53172 L F
.91391 .53468 m .90986 .52912 L .92023 .52615 L F
.72693 .53461 m .7323 .52608 L .73693 .53165 L F
.72693 .53461 m .72227 .52905 L .7323 .52608 L F
.909 .733 .651 r
.2235 .5366 m .21716 .53103 L .22905 .49766 L F
.958 .947 .688 r
.22905 .49766 m .22167 .50372 L .23232 .48411 L F
.889 .748 .7 r
.21716 .53103 m .22167 .50372 L .22905 .49766 L F
.656 .751 .92 r
.53993 .53454 m .54435 .52601 L .54961 .53158 L F
.53993 .53454 m .53465 .52898 L .54435 .52601 L F
.35292 .53447 m .35639 .52593 L .36227 .53151 L F
.35292 .53447 m .34702 .52891 L .35639 .52593 L F
.93857 .53432 m .94502 .52578 L .94895 .53136 L F
.93857 .53432 m .93461 .52876 L .94502 .52578 L F
.75155 .53425 m .75705 .52571 L .7616 .53129 L F
.75155 .53425 m .74697 .52869 L .75705 .52571 L F
.56452 .53418 m .56907 .52564 L .57424 .53122 L F
.56452 .53418 m .55932 .52862 L .56907 .52564 L F
.37747 .53411 m .38107 .52557 L .38686 .53115 L F
.37747 .53411 m .37165 .52855 L .38107 .52557 L F
0 0 0 r
.25254 .45581 m .25465 .45728 L .26206 .44849 L F
.554 .843 .512 r
.24263 .46785 m .24504 .46488 L .25254 .45581 L F
0 0 0 r
.25254 .45581 m .24504 .46488 L .25465 .45728 L F
.656 .751 .92 r
.77619 .53389 m .78181 .52535 L .78629 .53093 L F
.77619 .53389 m .77169 .52833 L .78181 .52535 L F
.58912 .53382 m .59379 .52528 L .59889 .53086 L F
.58912 .53382 m .584 .52825 L .59379 .52528 L F
.40203 .53375 m .40575 .52521 L .41147 .53079 L F
.40203 .53375 m .39629 .52818 L .40575 .52521 L F
.80084 .53353 m .80659 .52499 L .81098 .53057 L F
.80084 .53353 m .79642 .52796 L .80659 .52499 L F
.61373 .53346 m .61853 .52491 L .62354 .5305 L F
.61373 .53346 m .60869 .52789 L .61853 .52491 L F
.8255 .53317 m .83137 .52462 L .83569 .53021 L F
.8255 .53317 m .82116 .5276 L .83137 .52462 L F
.173 0 0 r
.26206 .44849 m .264 .45309 L .27121 .44595 L F
.26206 .44849 m .25465 .45728 L .264 .45309 L F
.543 .322 .53 r
.44725 .36468 m .45554 .41876 L .45677 .36142 L F
.44725 .36468 m .44548 .43732 L .45554 .41876 L F
.44725 .36468 m .44548 .43732 L .44725 .36468 L F
.656 .751 .92 r
.63835 .5331 m .64327 .52455 L .64821 .53014 L F
.63835 .5331 m .63339 .52753 L .64327 .52455 L F
.45118 .53302 m .45516 .52448 L .46071 .53007 L F
.45118 .53302 m .4456 .52746 L .45516 .52448 L F
.85017 .53281 m .85617 .52426 L .8604 .52985 L F
.85017 .53281 m .84591 .52724 L .85617 .52426 L F
.66298 .53273 m .66803 .52419 L .67288 .52977 L F
.66298 .53273 m .6581 .52717 L .66803 .52419 L F
.47577 .53266 m .47987 .52412 L .48535 .5297 L F
.47577 .53266 m .47027 .5271 L .47987 .52412 L F
.87485 .53244 m .88098 .52389 L .88513 .52948 L F
.87485 .53244 m .87067 .52687 L .88098 .52389 L F
.68762 .53237 m .6928 .52382 L .69757 .52941 L F
.68762 .53237 m .68282 .5268 L .6928 .52382 L F
.50037 .5323 m .5046 .52375 L .50999 .52934 L F
.50037 .5323 m .49496 .52673 L .5046 .52375 L F
.554 .843 .512 r
.24263 .46785 m .23517 .47561 L .24504 .46488 L F
.883 .99 .743 r
.23232 .48411 m .23517 .47561 L .24263 .46785 L F
.656 .751 .92 r
.31311 .53223 m .31639 .52368 L .3224 .52927 L F
.31311 .53223 m .30708 .52666 L .31639 .52368 L F
.89954 .53208 m .90579 .52353 L .90986 .52912 L F
.89954 .53208 m .89544 .52651 L .90579 .52353 L F
.71227 .53201 m .71757 .52346 L .72227 .52905 L F
.71227 .53201 m .70755 .52644 L .71757 .52346 L F
.52498 .53194 m .52934 .52339 L .53465 .52898 L F
.52498 .53194 m .51965 .52637 L .52934 .52339 L F
.33768 .53187 m .34109 .52332 L .34702 .52891 L F
.92424 .53172 m .93062 .52316 L .93461 .52876 L F
.92424 .53172 m .92023 .52615 L .93062 .52316 L F
.73693 .53165 m .74236 .52309 L .74697 .52869 L F
.73693 .53165 m .7323 .52608 L .74236 .52309 L F
.54961 .53158 m .55409 .52302 L .55932 .52862 L F
.54961 .53158 m .54435 .52601 L .55409 .52302 L F
.36227 .53151 m .3658 .52295 L .37165 .52855 L F
.36227 .53151 m .35639 .52593 L .3658 .52295 L F
.94895 .53136 m .95546 .5228 L .95937 .5284 L F
.94895 .53136 m .94502 .52578 L .95546 .5228 L F
.7616 .53129 m .76716 .52273 L .77169 .52833 L F
.7616 .53129 m .75705 .52571 L .76716 .52273 L F
.57424 .53122 m .57885 .52266 L .584 .52825 L F
.57424 .53122 m .56907 .52564 L .57885 .52266 L F
.38686 .53115 m .39052 .52259 L .39629 .52818 L F
.38686 .53115 m .38107 .52557 L .39052 .52259 L F
.78629 .53093 m .79197 .52236 L .79642 .52796 L F
.78629 .53093 m .78181 .52535 L .79197 .52236 L F
.59889 .53086 m .60362 .52229 L .60869 .52789 L F
.59889 .53086 m .59379 .52528 L .60362 .52229 L F
.41147 .53079 m .41525 .52222 L .42094 .52782 L F
.41147 .53079 m .40575 .52521 L .41525 .52222 L F
.81098 .53057 m .81679 .522 L .82116 .5276 L F
.81098 .53057 m .80659 .52499 L .81679 .522 L F
.62354 .5305 m .6284 .52193 L .63339 .52753 L F
.62354 .5305 m .61853 .52491 L .6284 .52193 L F
.43608 .53043 m .43999 .52186 L .4456 .52746 L F
.43608 .53043 m .43045 .52484 L .43999 .52186 L F
.83569 .53021 m .84162 .52163 L .84591 .52724 L F
.83569 .53021 m .83137 .52462 L .84162 .52163 L F
.543 .322 .53 r
.45677 .36142 m .46541 .40783 L .46633 .35816 L F
.45677 .36142 m .45554 .41876 L .46541 .40783 L F
.45677 .36142 m .45554 .41876 L .45677 .36142 L F
.656 .751 .92 r
.64821 .53014 m .65319 .52156 L .6581 .52717 L F
.64821 .53014 m .64327 .52455 L .65319 .52156 L F
.46071 .53007 m .46474 .52149 L .47027 .5271 L F
.46071 .53007 m .45516 .52448 L .46474 .52149 L F
.365 0 .016 r
.27121 .44595 m .2731 .45233 L .28006 .44793 L F
.27121 .44595 m .264 .45309 L .2731 .45233 L F
.656 .751 .92 r
.8604 .52985 m .86647 .52127 L .87067 .52687 L F
.8604 .52985 m .85617 .52426 L .86647 .52127 L F
.67288 .52977 m .67799 .5212 L .68282 .5268 L F
.67288 .52977 m .66803 .52419 L .67799 .5212 L F
.48535 .5297 m .48951 .52112 L .49496 .52673 L F
.48535 .5297 m .47987 .52412 L .48951 .52112 L F
.88513 .52948 m .89132 .5209 L .89544 .52651 L F
.88513 .52948 m .88098 .52389 L .89132 .5209 L F
.69757 .52941 m .70281 .52083 L .70755 .52644 L F
.69757 .52941 m .6928 .52382 L .70281 .52083 L F
.50999 .52934 m .51428 .52076 L .51965 .52637 L F
.50999 .52934 m .5046 .52375 L .51428 .52076 L F
.3224 .52927 m .31639 .52368 L .32574 .52069 L F
.90986 .52912 m .91618 .52054 L .92023 .52615 L F
.90986 .52912 m .90579 .52353 L .91618 .52054 L F
.72227 .52905 m .72763 .52046 L .7323 .52608 L F
.72227 .52905 m .71757 .52346 L .72763 .52046 L F
.53465 .52898 m .53906 .52039 L .54435 .52601 L F
.53465 .52898 m .52934 .52339 L .53906 .52039 L F
.34702 .52891 m .35048 .52032 L .35639 .52593 L F
.34702 .52891 m .34109 .52332 L .35048 .52032 L F
.93461 .52876 m .94106 .52017 L .94502 .52578 L F
.93461 .52876 m .93062 .52316 L .94106 .52017 L F
.74697 .52869 m .75247 .5201 L .75705 .52571 L F
.74697 .52869 m .74236 .52309 L .75247 .5201 L F
.55932 .52862 m .56386 .52003 L .56907 .52564 L F
.55932 .52862 m .55409 .52302 L .56386 .52003 L F
.37165 .52855 m .37524 .51996 L .38107 .52557 L F
.37165 .52855 m .3658 .52295 L .37524 .51996 L F
.883 .99 .743 r
.23232 .48411 m .22505 .48889 L .23517 .47561 L F
.926 .89 .776 r
.22167 .50372 m .22505 .48889 L .23232 .48411 L F
.656 .751 .92 r
.77169 .52833 m .77731 .51973 L .78181 .52535 L F
.77169 .52833 m .76716 .52273 L .77731 .51973 L F
.71 .289 .246 r
.29564 .44794 m .29719 .46273 L .30368 .46337 L F
.29564 .44794 m .28869 .4538 L .29719 .46273 L F
.656 .751 .92 r
.584 .52825 m .58866 .51966 L .59379 .52528 L F
.584 .52825 m .57885 .52266 L .58866 .51966 L F
.39629 .52818 m .4 .51959 L .40575 .52521 L F
.39629 .52818 m .39052 .52259 L .4 .51959 L F
.79642 .52796 m .80217 .51937 L .80659 .52499 L F
.79642 .52796 m .79197 .52236 L .80217 .51937 L F
.60869 .52789 m .61348 .51929 L .61853 .52491 L F
.60869 .52789 m .60362 .52229 L .61348 .51929 L F
.82116 .5276 m .82703 .519 L .83137 .52462 L F
.82116 .5276 m .81679 .522 L .82703 .519 L F
.63339 .52753 m .63831 .51893 L .64327 .52455 L F
.63339 .52753 m .6284 .52193 L .63831 .51893 L F
.4456 .52746 m .44957 .51886 L .45516 .52448 L F
.4456 .52746 m .43999 .52186 L .44957 .51886 L F
.84591 .52724 m .85191 .51863 L .85617 .52426 L F
.84591 .52724 m .84162 .52163 L .85191 .51863 L F
.543 .322 .53 r
.46634 .35816 m .47518 .40286 L .47592 .35489 L F
.46634 .35816 m .46541 .40783 L .47518 .40286 L F
.46633 .35816 m .46541 .40783 L .46634 .35816 L F
.656 .751 .92 r
.6581 .52717 m .66315 .51856 L .66803 .52419 L F
.6581 .52717 m .65319 .52156 L .66315 .51856 L F
.47027 .5271 m .47436 .51849 L .47987 .52412 L F
.47027 .5271 m .46474 .52149 L .47436 .51849 L F
.87067 .52687 m .8768 .51827 L .88098 .52389 L F
.87067 .52687 m .86647 .52127 L .8768 .51827 L F
.68282 .5268 m .68799 .5182 L .6928 .52382 L F
.68282 .5268 m .67799 .5212 L .68799 .5182 L F
.49496 .52673 m .49917 .51812 L .5046 .52375 L F
.49496 .52673 m .48951 .52112 L .49917 .51812 L F
.89544 .52651 m .9017 .5179 L .90579 .52353 L F
.89544 .52651 m .89132 .5209 L .9017 .5179 L F
.70755 .52644 m .71285 .51783 L .71757 .52346 L F
.70755 .52644 m .70281 .52083 L .71285 .51783 L F
.51965 .52637 m .52399 .51776 L .52934 .52339 L F
.51965 .52637 m .51428 .52076 L .52399 .51776 L F
.92023 .52615 m .92661 .51753 L .93062 .52316 L F
.92023 .52615 m .91618 .52054 L .92661 .51753 L F
.7323 .52608 m .73772 .51746 L .74236 .52309 L F
.7323 .52608 m .72763 .52046 L .73772 .51746 L F
.54435 .52601 m .54882 .51739 L .55409 .52302 L F
.54435 .52601 m .53906 .52039 L .54882 .51739 L F
.35639 .52593 m .35991 .51732 L .3658 .52295 L F
.35639 .52593 m .35048 .52032 L .35991 .51732 L F
.94502 .52578 m .95153 .51717 L .95546 .5228 L F
.94502 .52578 m .94106 .52017 L .95153 .51717 L F
.75705 .52571 m .7626 .51709 L .76716 .52273 L F
.75705 .52571 m .75247 .5201 L .7626 .51709 L F
.56907 .52564 m .57366 .51702 L .57885 .52266 L F
.56907 .52564 m .56386 .52003 L .57366 .51702 L F
.38107 .52557 m .38471 .51695 L .39052 .52259 L F
.38107 .52557 m .37524 .51996 L .38471 .51695 L F
.78181 .52535 m .7875 .51673 L .79197 .52236 L F
.78181 .52535 m .77731 .51973 L .7875 .51673 L F
.59379 .52528 m .59852 .51665 L .60362 .52229 L F
.59379 .52528 m .58866 .51966 L .59852 .51665 L F
.40575 .52521 m .40952 .51658 L .41525 .52222 L F
.40575 .52521 m .4 .51959 L .40952 .51658 L F
.80659 .52499 m .8124 .51636 L .81679 .522 L F
.80659 .52499 m .80217 .51937 L .8124 .51636 L F
.61853 .52491 m .62338 .51629 L .6284 .52193 L F
.61853 .52491 m .61348 .51929 L .62338 .51629 L F
.43045 .52484 m .43434 .51622 L .43999 .52186 L F
.83137 .52462 m .83731 .51599 L .84162 .52163 L F
.83137 .52462 m .82703 .519 L .83731 .51599 L F
.64327 .52455 m .64825 .51592 L .65319 .52156 L F
.64327 .52455 m .63831 .51893 L .64825 .51592 L F
.45516 .52448 m .45917 .51585 L .46474 .52149 L F
.45516 .52448 m .44957 .51886 L .45917 .51585 L F
.503 .003 .001 r
.28006 .44793 m .28201 .45478 L .28869 .4538 L F
.28006 .44793 m .2731 .45233 L .28201 .45478 L F
.656 .751 .92 r
.85617 .52426 m .86223 .51562 L .86647 .52127 L F
.85617 .52426 m .85191 .51863 L .86223 .51562 L F
.543 .322 .53 r
.47594 .3549 m .48492 .40222 L .48553 .35162 L F
.47594 .3549 m .47518 .40286 L .48492 .40222 L F
.47592 .35489 m .47518 .40286 L .47594 .3549 L F
.656 .751 .92 r
.66803 .52419 m .67313 .51555 L .67799 .5212 L F
.66803 .52419 m .66315 .51856 L .67313 .51555 L F
.47987 .52412 m .48402 .51548 L .48951 .52112 L F
.47987 .52412 m .47436 .51849 L .48402 .51548 L F
.88098 .52389 m .88717 .51526 L .89132 .5209 L F
.88098 .52389 m .8768 .51827 L .88717 .51526 L F
.6928 .52382 m .69803 .51518 L .70281 .52083 L F
.6928 .52382 m .68799 .5182 L .69803 .51518 L F
.5046 .52375 m .50887 .51511 L .51428 .52076 L F
.5046 .52375 m .49917 .51812 L .50887 .51511 L F
.90579 .52353 m .91211 .51489 L .91618 .52054 L F
.90579 .52353 m .9017 .5179 L .91211 .51489 L F
.71757 .52346 m .72293 .51482 L .72763 .52046 L F
.71757 .52346 m .71285 .51783 L .72293 .51482 L F
.52934 .52339 m .53374 .51474 L .53906 .52039 L F
.52934 .52339 m .52399 .51776 L .53374 .51474 L F
.34109 .52332 m .34453 .51467 L .35048 .52032 L F
.34109 .52332 m .33511 .51768 L .34453 .51467 L F
.93062 .52316 m .93707 .51452 L .94106 .52017 L F
.93062 .52316 m .92661 .51753 L .93707 .51452 L F
.74236 .52309 m .74785 .51445 L .75247 .5201 L F
.74236 .52309 m .73772 .51746 L .74785 .51445 L F
.889 .748 .7 r
.21716 .53103 m .21077 .52542 L .22167 .50372 L F
.926 .89 .776 r
.22167 .50372 m .21475 .50395 L .22505 .48889 L F
.866 .758 .741 r
.21077 .52542 m .21475 .50395 L .22167 .50372 L F
.656 .751 .92 r
.55409 .52302 m .55862 .51437 L .56386 .52003 L F
.55409 .52302 m .54882 .51739 L .55862 .51437 L F
.3658 .52295 m .36936 .5143 L .37524 .51996 L F
.3658 .52295 m .35991 .51732 L .36936 .5143 L F
.76716 .52273 m .77278 .51408 L .77731 .51973 L F
.76716 .52273 m .7626 .51709 L .77278 .51408 L F
.57885 .52266 m .5835 .51401 L .58866 .51966 L F
.57885 .52266 m .57366 .51702 L .5835 .51401 L F
.39052 .52259 m .39421 .51393 L .4 .51959 L F
.39052 .52259 m .38471 .51695 L .39421 .51393 L F
.79197 .52236 m .79772 .51371 L .80217 .51937 L F
.79197 .52236 m .7875 .51673 L .79772 .51371 L F
.60362 .52229 m .6084 .51364 L .61348 .51929 L F
.60362 .52229 m .59852 .51665 L .6084 .51364 L F
.41525 .52222 m .40952 .51658 L .41907 .51357 L F
.81679 .522 m .82266 .51334 L .82703 .519 L F
.81679 .522 m .8124 .51636 L .82266 .51334 L F
.6284 .52193 m .63331 .51327 L .63831 .51893 L F
.6284 .52193 m .62338 .51629 L .63331 .51327 L F
.43999 .52186 m .44394 .5132 L .44957 .51886 L F
.43999 .52186 m .43434 .51622 L .44394 .5132 L F
.84162 .52163 m .84762 .51297 L .85191 .51863 L F
.84162 .52163 m .83731 .51599 L .84762 .51297 L F
.65319 .52156 m .65823 .5129 L .66315 .51856 L F
.65319 .52156 m .64825 .51592 L .65823 .5129 L F
.46474 .52149 m .46882 .51283 L .47436 .51849 L F
.46474 .52149 m .45917 .51585 L .46882 .51283 L F
.543 .322 .529 r
.48562 .35167 m .49468 .40448 L .49514 .34843 L F
.48562 .35167 m .48492 .40222 L .49468 .40448 L F
.543 .322 .53 r
.48553 .35162 m .48492 .40222 L .48562 .35167 L F
.656 .751 .92 r
.86647 .52127 m .87259 .5126 L .8768 .51827 L F
.86647 .52127 m .86223 .51562 L .87259 .5126 L F
.67799 .5212 m .68316 .51253 L .68799 .5182 L F
.67799 .5212 m .67313 .51555 L .68316 .51253 L F
.48951 .52112 m .49371 .51246 L .49917 .51812 L F
.48951 .52112 m .48402 .51548 L .49371 .51246 L F
.89132 .5209 m .89758 .51223 L .9017 .5179 L F
.89132 .5209 m .88717 .51526 L .89758 .51223 L F
.70281 .52083 m .7081 .51216 L .71285 .51783 L F
.70281 .52083 m .69803 .51518 L .7081 .51216 L F
.51428 .52076 m .51861 .51209 L .52399 .51776 L F
.51428 .52076 m .50887 .51511 L .51861 .51209 L F
.674 .971 .791 r
.24504 .46488 m .24761 .4605 L .25465 .45728 L F
.24504 .46488 m .23795 .46813 L .24761 .4605 L F
.843 .996 .837 r
.23517 .47561 m .23795 .46813 L .24504 .46488 L F
.656 .751 .92 r
.91618 .52054 m .92257 .51186 L .92661 .51753 L F
.91618 .52054 m .91211 .51489 L .92257 .51186 L F
.72763 .52046 m .73305 .51179 L .73772 .51746 L F
.72763 .52046 m .72293 .51482 L .73305 .51179 L F
.53906 .52039 m .54352 .51172 L .54882 .51739 L F
.53906 .52039 m .53374 .51474 L .54352 .51172 L F
.35048 .52032 m .35397 .51165 L .35991 .51732 L F
.35048 .52032 m .34453 .51467 L .35397 .51165 L F
.94106 .52017 m .94757 .51149 L .95153 .51717 L F
.94106 .52017 m .93707 .51452 L .94757 .51149 L F
.75247 .5201 m .75801 .51142 L .7626 .51709 L F
.75247 .5201 m .74785 .51445 L .75801 .51142 L F
.56386 .52003 m .56844 .51135 L .57366 .51702 L F
.56386 .52003 m .55862 .51437 L .56844 .51135 L F
.401 .836 .695 r
.25465 .45728 m .25707 .45541 L .264 .45309 L F
.25465 .45728 m .24761 .4605 L .25707 .45541 L F
.656 .751 .92 r
.37524 .51996 m .37886 .51128 L .38471 .51695 L F
.37524 .51996 m .36936 .5143 L .37886 .51128 L F
.843 .996 .837 r
.23517 .47561 m .2281 .47792 L .23795 .46813 L F
.896 .936 .832 r
.22505 .48889 m .2281 .47792 L .23517 .47561 L F
.656 .751 .92 r
.77731 .51973 m .78299 .51105 L .7875 .51673 L F
.77731 .51973 m .77278 .51408 L .78299 .51105 L F
.58866 .51966 m .59338 .51098 L .59852 .51665 L F
.58866 .51966 m .5835 .51401 L .59338 .51098 L F
.4 .51959 m .40375 .51091 L .40952 .51658 L F
.4 .51959 m .39421 .51393 L .40375 .51091 L F
.80217 .51937 m .80797 .51068 L .8124 .51636 L F
.80217 .51937 m .79772 .51371 L .80797 .51068 L F
.61348 .51929 m .61832 .51061 L .62338 .51629 L F
.61348 .51929 m .6084 .51364 L .61832 .51061 L F
.82703 .519 m .83297 .51031 L .83731 .51599 L F
.82703 .519 m .82266 .51334 L .83297 .51031 L F
.63831 .51893 m .64328 .51024 L .64825 .51592 L F
.63831 .51893 m .63331 .51327 L .64328 .51024 L F
.44957 .51886 m .45357 .51017 L .45917 .51585 L F
.44957 .51886 m .44394 .5132 L .45357 .51017 L F
.85191 .51863 m .85797 .50994 L .86223 .51562 L F
.85191 .51863 m .84762 .51297 L .85797 .50994 L F
.66315 .51856 m .66824 .50987 L .67313 .51555 L F
.66315 .51856 m .65823 .5129 L .66824 .50987 L F
.544 .32 .527 r
.49552 .34864 m .5045 .40837 L .50462 .34559 L F
.49552 .34864 m .49468 .40448 L .5045 .40837 L F
.543 .322 .529 r
.49514 .34843 m .49468 .40448 L .49552 .34864 L F
.656 .751 .92 r
.47436 .51849 m .4785 .5098 L .48402 .51548 L F
.47436 .51849 m .46882 .51283 L .4785 .5098 L F
.548 .315 .514 r
.51331 .34456 m .51996 .38778 L .51809 .34854 L F
.656 .751 .92 r
.8768 .51827 m .88299 .50957 L .88717 .51526 L F
.8768 .51827 m .87259 .5126 L .88299 .50957 L F
.68799 .5182 m .69322 .5095 L .69803 .51518 L F
.68799 .5182 m .68316 .51253 L .69322 .5095 L F
.49917 .51812 m .50343 .50943 L .50887 .51511 L F
.49917 .51812 m .49371 .51246 L .50343 .50943 L F
.9017 .5179 m .90802 .5092 L .91211 .51489 L F
.9017 .5179 m .89758 .51223 L .90802 .5092 L F
.71285 .51783 m .71821 .50913 L .72293 .51482 L F
.71285 .51783 m .7081 .51216 L .71821 .50913 L F
.52399 .51776 m .52838 .50906 L .53374 .51474 L F
.52399 .51776 m .51861 .51209 L .52838 .50906 L F
0 0 0 r
.264 .45309 m .26634 .45303 L .2731 .45233 L F
.264 .45309 m .25707 .45541 L .26634 .45303 L F
.656 .751 .92 r
.92661 .51753 m .93306 .50883 L .93707 .51452 L F
.92661 .51753 m .92257 .51186 L .93306 .50883 L F
.896 .936 .832 r
.22505 .48889 m .2181 .48932 L .2281 .47792 L F
.883 .849 .805 r
.21475 .50395 m .2181 .48932 L .22505 .48889 L F
.656 .751 .92 r
.73772 .51746 m .74321 .50876 L .74785 .51445 L F
.73772 .51746 m .73305 .51179 L .74321 .50876 L F
.54882 .51739 m .55334 .50868 L .55862 .51437 L F
.54882 .51739 m .54352 .51172 L .55334 .50868 L F
.35991 .51732 m .36345 .50861 L .36936 .5143 L F
.35991 .51732 m .35397 .51165 L .36345 .50861 L F
.7626 .51709 m .76821 .50839 L .77278 .51408 L F
.7626 .51709 m .75801 .51142 L .76821 .50839 L F
.57366 .51702 m .57831 .50831 L .5835 .51401 L F
.57366 .51702 m .56844 .51135 L .57831 .50831 L F
.38471 .51695 m .38838 .50824 L .39421 .51393 L F
.38471 .51695 m .37886 .51128 L .38838 .50824 L F
.548 .315 .514 r
.50642 .34672 m .51439 .41291 L .51331 .34456 L F
.50642 .34672 m .5045 .40837 L .51439 .41291 L F
.544 .32 .527 r
.50462 .34559 m .5045 .40837 L .50642 .34672 L F
.656 .751 .92 r
.7875 .51673 m .79323 .50801 L .79772 .51371 L F
.7875 .51673 m .78299 .51105 L .79323 .50801 L F
.59852 .51665 m .60329 .50794 L .6084 .51364 L F
.59852 .51665 m .59338 .51098 L .60329 .50794 L F
.6 .055 0 r
.28869 .4538 m .28201 .45478 L .2908 .45994 L F
.656 .751 .92 r
.40952 .51658 m .41332 .50787 L .41907 .51357 L F
.40952 .51658 m .40375 .51091 L .41332 .50787 L F
.866 .758 .741 r
.21077 .52542 m .20434 .51978 L .21475 .50395 L F
.656 .751 .92 r
.8124 .51636 m .81827 .50764 L .82266 .51334 L F
.8124 .51636 m .80797 .51068 L .81827 .50764 L F
.62338 .51629 m .62828 .50757 L .63331 .51327 L F
.62338 .51629 m .61832 .51061 L .62828 .50757 L F
.43434 .51622 m .43827 .5075 L .44394 .5132 L F
.83731 .51599 m .84331 .50727 L .84762 .51297 L F
.83731 .51599 m .83297 .51031 L .84331 .50727 L F
.64825 .51592 m .65328 .5072 L .65823 .5129 L F
.64825 .51592 m .64328 .51024 L .65328 .5072 L F
.45917 .51585 m .46323 .50713 L .46882 .51283 L F
.45917 .51585 m .45357 .51017 L .46323 .50713 L F
.86223 .51562 m .86836 .5069 L .87259 .5126 L F
.86223 .51562 m .85797 .50994 L .86836 .5069 L F
.67313 .51555 m .67829 .50683 L .68316 .51253 L F
.67313 .51555 m .66824 .50987 L .67829 .50683 L F
.48402 .51548 m .48821 .50675 L .49371 .51246 L F
.48402 .51548 m .4785 .5098 L .48821 .50675 L F
.88717 .51526 m .89342 .50653 L .89758 .51223 L F
.88717 .51526 m .88299 .50957 L .89342 .50653 L F
.69803 .51518 m .70332 .50646 L .7081 .51216 L F
.69803 .51518 m .69322 .5095 L .70332 .50646 L F
.50887 .51511 m .51319 .50638 L .51861 .51209 L F
.50887 .51511 m .50343 .50943 L .51319 .50638 L F
.91211 .51489 m .9185 .50616 L .92257 .51186 L F
.91211 .51489 m .90802 .5092 L .9185 .50616 L F
.548 .315 .514 r
.51331 .34456 m .51439 .41291 L .51996 .38778 L F
.656 .751 .92 r
.72293 .51482 m .72835 .50608 L .73305 .51179 L F
.72293 .51482 m .71821 .50913 L .72835 .50608 L F
.53374 .51474 m .53818 .50601 L .54352 .51172 L F
.53374 .51474 m .52838 .50906 L .53818 .50601 L F
.93707 .51452 m .94358 .50578 L .94757 .51149 L F
.93707 .51452 m .93306 .50883 L .94358 .50578 L F
.74785 .51445 m .75339 .50571 L .75801 .51142 L F
.74785 .51445 m .74321 .50876 L .75339 .50571 L F
.55862 .51437 m .56319 .50564 L .56844 .51135 L F
.55862 .51437 m .55334 .50868 L .56319 .50564 L F
.883 .849 .805 r
.21475 .50395 m .208 .50164 L .2181 .48932 L F
.844 .764 .774 r
.20434 .51978 m .208 .50164 L .21475 .50395 L F
.656 .751 .92 r
.36936 .5143 m .37297 .50557 L .37886 .51128 L F
.36936 .5143 m .36345 .50861 L .37297 .50557 L F
.77278 .51408 m .77845 .50534 L .78299 .51105 L F
.77278 .51408 m .76821 .50839 L .77845 .50534 L F
.5835 .51401 m .5882 .50527 L .59338 .51098 L F
.5835 .51401 m .57831 .50831 L .5882 .50527 L F
.39421 .51393 m .39794 .50519 L .40375 .51091 L F
.39421 .51393 m .38838 .50824 L .39794 .50519 L F
.79772 .51371 m .80352 .50497 L .80797 .51068 L F
.79772 .51371 m .79323 .50801 L .80352 .50497 L F
.6084 .51364 m .61323 .50489 L .61832 .51061 L F
.6084 .51364 m .60329 .50794 L .61323 .50489 L F
.41907 .51357 m .41332 .50787 L .42293 .50482 L F
.82266 .51334 m .8286 .50459 L .83297 .51031 L F
.82266 .51334 m .81827 .50764 L .8286 .50459 L F
.12 0 0 r
.2731 .45233 m .27545 .45333 L .28201 .45478 L F
.2731 .45233 m .26634 .45303 L .27545 .45333 L F
.656 .751 .92 r
.63331 .51327 m .63827 .50452 L .64328 .51024 L F
.63331 .51327 m .62828 .50757 L .63827 .50452 L F
.44394 .5132 m .44793 .50445 L .45357 .51017 L F
.44394 .5132 m .43827 .5075 L .44793 .50445 L F
.84762 .51297 m .85368 .50422 L .85797 .50994 L F
.84762 .51297 m .84331 .50727 L .85368 .50422 L F
.65823 .5129 m .66332 .50415 L .66824 .50987 L F
.65823 .5129 m .65328 .5072 L .66332 .50415 L F
.46882 .51283 m .47293 .50408 L .4785 .5098 L F
.46882 .51283 m .46323 .50713 L .47293 .50408 L F
.87259 .5126 m .87878 .50385 L .88299 .50957 L F
.87259 .5126 m .86836 .5069 L .87878 .50385 L F
.68316 .51253 m .68838 .50378 L .69322 .5095 L F
.68316 .51253 m .67829 .50683 L .68838 .50378 L F
.49371 .51246 m .49795 .5037 L .50343 .50943 L F
.49371 .51246 m .48821 .50675 L .49795 .5037 L F
.89758 .51223 m .9039 .50348 L .90802 .5092 L F
.89758 .51223 m .89342 .50653 L .9039 .50348 L F
.7081 .51216 m .71345 .5034 L .71821 .50913 L F
.7081 .51216 m .70332 .50646 L .71345 .5034 L F
.51861 .51209 m .52298 .50333 L .52838 .50906 L F
.51861 .51209 m .51319 .50638 L .52298 .50333 L F
.92257 .51186 m .92902 .5031 L .93306 .50883 L F
.92257 .51186 m .9185 .50616 L .92902 .5031 L F
.73305 .51179 m .73853 .50303 L .74321 .50876 L F
.73305 .51179 m .72835 .50608 L .73853 .50303 L F
.54352 .51172 m .54802 .50296 L .55334 .50868 L F
.54352 .51172 m .53818 .50601 L .54802 .50296 L F
.75801 .51142 m .76362 .50266 L .76821 .50839 L F
.75801 .51142 m .75339 .50571 L .76362 .50266 L F
.56844 .51135 m .57308 .50258 L .57831 .50831 L F
.56844 .51135 m .56319 .50564 L .57308 .50258 L F
.37886 .51128 m .38251 .50251 L .38838 .50824 L F
.37886 .51128 m .37297 .50557 L .38251 .50251 L F
.78299 .51105 m .78872 .50228 L .79323 .50801 L F
.78299 .51105 m .77845 .50534 L .78872 .50228 L F
.59338 .51098 m .59814 .50221 L .60329 .50794 L F
.59338 .51098 m .5882 .50527 L .59814 .50221 L F
.40375 .51091 m .40754 .50214 L .41332 .50787 L F
.40375 .51091 m .39794 .50519 L .40754 .50214 L F
.844 .764 .774 r
.20434 .51978 m .19786 .51409 L .208 .50164 L F
.656 .751 .92 r
.80797 .51068 m .81384 .50191 L .81827 .50764 L F
.80797 .51068 m .80352 .50497 L .81384 .50191 L F
.61832 .51061 m .62321 .50183 L .62828 .50757 L F
.61832 .51061 m .61323 .50489 L .62321 .50183 L F
.806 .97 .906 r
.23795 .46813 m .24075 .46075 L .24761 .4605 L F
.23795 .46813 m .23105 .46832 L .24075 .46075 L F
.855 .935 .876 r
.2281 .47792 m .23105 .46832 L .23795 .46813 L F
.656 .751 .92 r
.83297 .51031 m .83896 .50153 L .84331 .50727 L F
.83297 .51031 m .8286 .50459 L .83896 .50153 L F
.64328 .51024 m .6483 .50146 L .65328 .5072 L F
.64328 .51024 m .63827 .50452 L .6483 .50146 L F
.45357 .51017 m .45761 .50139 L .46323 .50713 L F
.45357 .51017 m .44793 .50445 L .45761 .50139 L F
.85797 .50994 m .8641 .50116 L .86836 .5069 L F
.85797 .50994 m .85368 .50422 L .8641 .50116 L F
.855 .935 .876 r
.2281 .47792 m .22121 .47741 L .23105 .46832 L F
.866 .883 .847 r
.2181 .48932 m .22121 .47741 L .2281 .47792 L F
.656 .751 .92 r
.66824 .50987 m .67339 .50109 L .67829 .50683 L F
.66824 .50987 m .66332 .50415 L .67339 .50109 L F
.4785 .5098 m .48267 .50101 L .48821 .50675 L F
.4785 .5098 m .47293 .50408 L .48267 .50101 L F
.701 .968 .933 r
.24761 .4605 m .25029 .45512 L .25707 .45541 L F
.24761 .4605 m .24075 .46075 L .25029 .45512 L F
.656 .751 .92 r
.88299 .50957 m .88925 .50079 L .89342 .50653 L F
.88299 .50957 m .87878 .50385 L .88925 .50079 L F
.69322 .5095 m .6985 .50071 L .70332 .50646 L F
.69322 .5095 m .68838 .50378 L .6985 .50071 L F
.50343 .50943 m .50773 .50064 L .51319 .50638 L F
.50343 .50943 m .49795 .5037 L .50773 .50064 L F
.90802 .5092 m .9144 .50041 L .9185 .50616 L F
.90802 .5092 m .9039 .50348 L .9144 .50041 L F
.71821 .50913 m .72362 .50034 L .72835 .50608 L F
.71821 .50913 m .71345 .5034 L .72362 .50034 L F
.52838 .50906 m .53281 .50026 L .53818 .50601 L F
.52838 .50906 m .52298 .50333 L .53281 .50026 L F
.93306 .50883 m .93957 .50004 L .94358 .50578 L F
.93306 .50883 m .92902 .5031 L .93957 .50004 L F
.74321 .50876 m .74874 .49996 L .75339 .50571 L F
.74321 .50876 m .73853 .50303 L .74874 .49996 L F
.55334 .50868 m .5579 .49989 L .56319 .50564 L F
.55334 .50868 m .54802 .50296 L .5579 .49989 L F
.866 .883 .847 r
.2181 .48932 m .21128 .48752 L .22121 .47741 L F
.851 .825 .822 r
.208 .50164 m .21128 .48752 L .2181 .48932 L F
.656 .751 .92 r
.76821 .50839 m .77388 .49959 L .77845 .50534 L F
.76821 .50839 m .76362 .50266 L .77388 .49959 L F
.57831 .50831 m .583 .49951 L .5882 .50527 L F
.57831 .50831 m .57308 .50258 L .583 .49951 L F
.38838 .50824 m .3921 .49944 L .39794 .50519 L F
.38838 .50824 m .38251 .50251 L .3921 .49944 L F
.79323 .50801 m .79903 .49921 L .80352 .50497 L F
.79323 .50801 m .78872 .50228 L .79903 .49921 L F
.60329 .50794 m .60811 .49914 L .61323 .50489 L F
.60329 .50794 m .59814 .50221 L .60811 .49914 L F
.41332 .50787 m .40754 .50214 L .41717 .49907 L F
.81827 .50764 m .82419 .49884 L .8286 .50459 L F
.81827 .50764 m .81384 .50191 L .82419 .49884 L F
.535 .91 .949 r
.25707 .45541 m .25968 .45168 L .26634 .45303 L F
.25707 .45541 m .25029 .45512 L .25968 .45168 L F
.656 .751 .92 r
.62828 .50757 m .63323 .49876 L .63827 .50452 L F
.62828 .50757 m .62321 .50183 L .63323 .49876 L F
.43827 .5075 m .44225 .49869 L .44793 .50445 L F
.43827 .5075 m .43257 .50176 L .44225 .49869 L F
.261 0 0 r
.28201 .45478 m .28442 .45607 L .2908 .45994 L F
.28201 .45478 m .27545 .45333 L .28442 .45607 L F
.656 .751 .92 r
.84331 .50727 m .84937 .49846 L .85368 .50422 L F
.84331 .50727 m .83896 .50153 L .84937 .49846 L F
.65328 .5072 m .65836 .49839 L .66332 .50415 L F
.65328 .5072 m .6483 .50146 L .65836 .49839 L F
.46323 .50713 m .46734 .49832 L .47293 .50408 L F
.46323 .50713 m .45761 .50139 L .46734 .49832 L F
.851 .825 .822 r
.208 .50164 m .20131 .49805 L .21128 .48752 L F
.823 .768 .8 r
.19786 .51409 m .20131 .49805 L .208 .50164 L F
.656 .751 .92 r
.86836 .5069 m .87455 .49809 L .87878 .50385 L F
.86836 .5069 m .8641 .50116 L .87455 .49809 L F
.67829 .50683 m .6835 .49801 L .68838 .50378 L F
.67829 .50683 m .67339 .50109 L .6835 .49801 L F
.48821 .50675 m .49244 .49794 L .49795 .5037 L F
.48821 .50675 m .48267 .50101 L .49244 .49794 L F
.89342 .50653 m .89974 .49771 L .9039 .50348 L F
.89342 .50653 m .88925 .50079 L .89974 .49771 L F
.70332 .50646 m .70866 .49764 L .71345 .5034 L F
.70332 .50646 m .6985 .50071 L .70866 .49764 L F
.51319 .50638 m .51755 .49756 L .52298 .50333 L F
.51319 .50638 m .50773 .50064 L .51755 .49756 L F
.9185 .50616 m .92495 .49734 L .92902 .5031 L F
.9185 .50616 m .9144 .50041 L .92495 .49734 L F
.72835 .50608 m .73382 .49726 L .73853 .50303 L F
.72835 .50608 m .72362 .50034 L .73382 .49726 L F
.53818 .50601 m .54267 .49719 L .54802 .50296 L F
.53818 .50601 m .53281 .50026 L .54267 .49719 L F
.75339 .50571 m .759 .49689 L .76362 .50266 L F
.75339 .50571 m .74874 .49996 L .759 .49689 L F
.56319 .50564 m .56781 .49681 L .57308 .50258 L F
.56319 .50564 m .5579 .49989 L .56781 .49681 L F
.77845 .50534 m .78418 .49651 L .78872 .50228 L F
.77845 .50534 m .77388 .49959 L .78418 .49651 L F
.5882 .50527 m .59296 .49644 L .59814 .50221 L F
.5882 .50527 m .583 .49951 L .59296 .49644 L F
.39794 .50519 m .40171 .49636 L .40754 .50214 L F
.39794 .50519 m .3921 .49944 L .40171 .49636 L F
.823 .768 .8 r
.19786 .51409 m .19134 .50837 L .20131 .49805 L F
.656 .751 .92 r
.80352 .50497 m .80938 .49613 L .81384 .50191 L F
.80352 .50497 m .79903 .49921 L .80938 .49613 L F
.61323 .50489 m .61811 .49606 L .62321 .50183 L F
.61323 .50489 m .60811 .49914 L .61811 .49606 L F
.8286 .50459 m .83459 .49576 L .83896 .50153 L F
.8286 .50459 m .82419 .49884 L .83459 .49576 L F
.63827 .50452 m .64328 .49568 L .6483 .50146 L F
.63827 .50452 m .63323 .49876 L .64328 .49568 L F
.44793 .50445 m .45196 .49561 L .45761 .50139 L F
.44793 .50445 m .44225 .49869 L .45196 .49561 L F
.85368 .50422 m .85981 .49538 L .8641 .50116 L F
.85368 .50422 m .84937 .49846 L .85981 .49538 L F
.332 .79 .944 r
.26634 .45303 m .26892 .45053 L .27545 .45333 L F
.26634 .45303 m .25968 .45168 L .26892 .45053 L F
.656 .751 .92 r
.66332 .50415 m .66846 .49531 L .67339 .50109 L F
.66332 .50415 m .65836 .49839 L .66846 .49531 L F
.47293 .50408 m .47709 .49523 L .48267 .50101 L F
.47293 .50408 m .46734 .49832 L .47709 .49523 L F
.87878 .50385 m .88504 .495 L .88925 .50079 L F
.87878 .50385 m .87455 .49809 L .88504 .495 L F
.68838 .50378 m .69365 .49493 L .6985 .50071 L F
.68838 .50378 m .6835 .49801 L .69365 .49493 L F
.49795 .5037 m .50224 .49486 L .50773 .50064 L F
.49795 .5037 m .49244 .49794 L .50224 .49486 L F
.9039 .50348 m .91028 .49463 L .9144 .50041 L F
.9039 .50348 m .89974 .49771 L .91028 .49463 L F
.71345 .5034 m .71885 .49455 L .72362 .50034 L F
.71345 .5034 m .70866 .49764 L .71885 .49455 L F
.52298 .50333 m .5274 .49448 L .53281 .50026 L F
.52298 .50333 m .51755 .49756 L .5274 .49448 L F
.92902 .5031 m .93553 .49425 L .93957 .50004 L F
.92902 .5031 m .92495 .49734 L .93553 .49425 L F
.73853 .50303 m .74406 .49418 L .74874 .49996 L F
.73853 .50303 m .73382 .49726 L .74406 .49418 L F
.54802 .50296 m .55257 .4941 L .5579 .49989 L F
.54802 .50296 m .54267 .49719 L .55257 .4941 L F
.76362 .50266 m .76928 .4938 L .77388 .49959 L F
.76362 .50266 m .759 .49689 L .76928 .4938 L F
.57308 .50258 m .57776 .49372 L .583 .49951 L F
.57308 .50258 m .56781 .49681 L .57776 .49372 L F
.78872 .50228 m .79452 .49342 L .79903 .49921 L F
.78872 .50228 m .78418 .49651 L .79452 .49342 L F
.59814 .50221 m .60295 .49335 L .60811 .49914 L F
.59814 .50221 m .59296 .49644 L .60295 .49335 L F
.40754 .50214 m .41136 .49327 L .41717 .49907 L F
.40754 .50214 m .40171 .49636 L .41136 .49327 L F
.81384 .50191 m .81976 .49304 L .82419 .49884 L F
.81384 .50191 m .80938 .49613 L .81976 .49304 L F
.62321 .50183 m .62815 .49297 L .63323 .49876 L F
.62321 .50183 m .61811 .49606 L .62815 .49297 L F
.43257 .50176 m .43653 .4929 L .44225 .49869 L F
.83896 .50153 m .84502 .49267 L .84937 .49846 L F
.83896 .50153 m .83459 .49576 L .84502 .49267 L F
.6483 .50146 m .65337 .49259 L .65836 .49839 L F
.6483 .50146 m .64328 .49568 L .65337 .49259 L F
.815 .914 .906 r
.23105 .46832 m .23397 .45924 L .24075 .46075 L F
.23105 .46832 m .22423 .46671 L .23397 .45924 L F
.838 .887 .876 r
.22121 .47741 m .22423 .46671 L .23105 .46832 L F
.22121 .47741 m .21441 .47528 L .22423 .46671 L F
.84 .85 .852 r
.21128 .48752 m .21441 .47528 L .22121 .47741 L F
.656 .751 .92 r
.45761 .50139 m .4617 .49252 L .46734 .49832 L F
.45761 .50139 m .45196 .49561 L .4617 .49252 L F
.8641 .50116 m .87029 .49229 L .87455 .49809 L F
.8641 .50116 m .85981 .49538 L .87029 .49229 L F
.67339 .50109 m .67859 .49221 L .6835 .49801 L F
.67339 .50109 m .66846 .49531 L .67859 .49221 L F
.48267 .50101 m .48689 .49214 L .49244 .49794 L F
.48267 .50101 m .47709 .49523 L .48689 .49214 L F
.84 .85 .852 r
.21128 .48752 m .20453 .48446 L .21441 .47528 L F
.827 .81 .834 r
.20131 .49805 m .20453 .48446 L .21128 .48752 L F
.262 0 .243 r
.46541 .40783 m .46921 .41809 L .47518 .40286 L F
.46541 .40783 m .45926 .42756 L .46921 .41809 L F
.178 0 .229 r
.45554 .41876 m .45926 .42756 L .46541 .40783 L F
.656 .751 .92 r
.88925 .50079 m .89557 .49191 L .89974 .49771 L F
.88925 .50079 m .88504 .495 L .89557 .49191 L F
.6985 .50071 m .70383 .49184 L .70866 .49764 L F
.6985 .50071 m .69365 .49493 L .70383 .49184 L F
.762 .926 .942 r
.24075 .46075 m .24358 .45326 L .25029 .45512 L F
.24075 .46075 m .23397 .45924 L .24358 .45326 L F
.656 .751 .92 r
.50773 .50064 m .51208 .49176 L .51755 .49756 L F
.50773 .50064 m .50224 .49486 L .51208 .49176 L F
.9144 .50041 m .92085 .49153 L .92495 .49734 L F
.9144 .50041 m .91028 .49463 L .92085 .49153 L F
.72362 .50034 m .72908 .49146 L .73382 .49726 L F
.72362 .50034 m .71885 .49455 L .72908 .49146 L F
.53281 .50026 m .53729 .49138 L .54267 .49719 L F
.53281 .50026 m .5274 .49448 L .53729 .49138 L F
.827 .81 .834 r
.20131 .49805 m .19463 .49374 L .20453 .48446 L F
.805 .77 .821 r
.19134 .50837 m .19463 .49374 L .20131 .49805 L F
0 .264 .671 r
.2908 .45994 m .29332 .46083 L .29952 .46716 L F
.2908 .45994 m .28442 .45607 L .29332 .46083 L F
.656 .751 .92 r
.74874 .49996 m .75434 .49108 L .759 .49689 L F
.74874 .49996 m .74406 .49418 L .75434 .49108 L F
.5579 .49989 m .56251 .491 L .56781 .49681 L F
.5579 .49989 m .55257 .4941 L .56251 .491 L F
.178 0 .229 r
.45554 .41876 m .44922 .44083 L .45926 .42756 L F
0 0 .129 r
.44548 .43732 m .44922 .44083 L .45554 .41876 L F
.656 .751 .92 r
.77388 .49959 m .77961 .4907 L .78418 .49651 L F
.77388 .49959 m .76928 .4938 L .77961 .4907 L F
.583 .49951 m .58774 .49063 L .59296 .49644 L F
.583 .49951 m .57776 .49372 L .58774 .49063 L F
.805 .77 .821 r
.19134 .50837 m .18478 .50261 L .19463 .49374 L F
.145 .634 .917 r
.27545 .45333 m .27804 .45158 L .28442 .45607 L F
.27545 .45333 m .26892 .45053 L .27804 .45158 L F
.656 .751 .92 r
.79903 .49921 m .80489 .49032 L .80938 .49613 L F
.79903 .49921 m .79452 .49342 L .80489 .49032 L F
.60811 .49914 m .61298 .49025 L .61811 .49606 L F
.60811 .49914 m .60295 .49335 L .61298 .49025 L F
.672 .908 .977 r
.25029 .45512 m .25306 .44909 L .25968 .45168 L F
.25029 .45512 m .24358 .45326 L .25306 .44909 L F
.656 .751 .92 r
.82419 .49884 m .83018 .48994 L .83459 .49576 L F
.82419 .49884 m .81976 .49304 L .83018 .48994 L F
.63323 .49876 m .63823 .48987 L .64328 .49568 L F
.63323 .49876 m .62815 .49297 L .63823 .48987 L F
.44225 .49869 m .44626 .48979 L .45196 .49561 L F
.44225 .49869 m .43653 .4929 L .44626 .48979 L F
.303 0 .203 r
.47518 .40286 m .4791 .41202 L .48492 .40222 L F
.47518 .40286 m .46921 .41809 L .4791 .41202 L F
.656 .751 .92 r
.84937 .49846 m .85549 .48956 L .85981 .49538 L F
.84937 .49846 m .84502 .49267 L .85549 .48956 L F
.65836 .49839 m .66349 .48949 L .66846 .49531 L F
.65836 .49839 m .65337 .49259 L .66349 .48949 L F
.46734 .49832 m .47148 .48941 L .47709 .49523 L F
.46734 .49832 m .4617 .49252 L .47148 .48941 L F
.87455 .49809 m .8808 .48918 L .88504 .495 L F
.87455 .49809 m .87029 .49229 L .8808 .48918 L F
.6835 .49801 m .68877 .48911 L .69365 .49493 L F
.6835 .49801 m .67859 .49221 L .68877 .48911 L F
.49244 .49794 m .49671 .48903 L .50224 .49486 L F
.49244 .49794 m .48689 .49214 L .49671 .48903 L F
.89974 .49771 m .90613 .4888 L .91028 .49463 L F
.89974 .49771 m .89557 .49191 L .90613 .4888 L F
.70866 .49764 m .71405 .48873 L .71885 .49455 L F
.70866 .49764 m .70383 .49184 L .71405 .48873 L F
.51755 .49756 m .52196 .48866 L .5274 .49448 L F
.51755 .49756 m .51208 .49176 L .52196 .48866 L F
.92495 .49734 m .93147 .48842 L .93553 .49425 L F
.92495 .49734 m .92085 .49153 L .93147 .48842 L F
.73382 .49726 m .73935 .48835 L .74406 .49418 L F
.73382 .49726 m .72908 .49146 L .73935 .48835 L F
.54267 .49719 m .54721 .48828 L .55257 .4941 L F
.54267 .49719 m .53729 .49138 L .54721 .48828 L F
.759 .49689 m .76465 .48797 L .76928 .4938 L F
.759 .49689 m .75434 .49108 L .76465 .48797 L F
.56781 .49681 m .57248 .4879 L .57776 .49372 L F
.56781 .49681 m .56251 .491 L .57248 .4879 L F
.78418 .49651 m .78997 .48759 L .79452 .49342 L F
.78418 .49651 m .77961 .4907 L .78997 .48759 L F
.574 .26 .398 r
.51996 .38778 m .51439 .41291 L .52438 .41737 L F
.382 .577 .917 r
.52438 .41737 m .51883 .40988 L .52149 .41041 L F
.574 .26 .398 r
.51996 .38778 m .52438 .41737 L .52724 .42428 L F
.382 .577 .917 r
.52438 .41737 m .52149 .41041 L .5289 .4119 L F
.574 .26 .398 r
.52724 .42428 m .52438 .41737 L .5299 .43765 L F
.656 .751 .92 r
.59296 .49644 m .59776 .48752 L .60295 .49335 L F
.59296 .49644 m .58774 .49063 L .59776 .48752 L F
.80938 .49613 m .8153 .48721 L .81976 .49304 L F
.80938 .49613 m .80489 .49032 L .8153 .48721 L F
.61811 .49606 m .62304 .48714 L .62815 .49297 L F
.61811 .49606 m .61298 .49025 L .62304 .48714 L F
.54 .846 .999 r
.25968 .45168 m .2624 .44689 L .26892 .45053 L F
.25968 .45168 m .25306 .44909 L .2624 .44689 L F
.656 .751 .92 r
.83459 .49576 m .84064 .48683 L .84502 .49267 L F
.83459 .49576 m .83018 .48994 L .84064 .48683 L F
.64328 .49568 m .64834 .48675 L .65337 .49259 L F
.64328 .49568 m .63823 .48987 L .64834 .48675 L F
.45196 .49561 m .45603 .48668 L .4617 .49252 L F
.45196 .49561 m .44626 .48979 L .45603 .48668 L F
.85981 .49538 m .86599 .48645 L .87029 .49229 L F
.85981 .49538 m .85549 .48956 L .86599 .48645 L F
.66846 .49531 m .67365 .48637 L .67859 .49221 L F
.66846 .49531 m .66349 .48949 L .67365 .48637 L F
.47709 .49523 m .4813 .4863 L .48689 .49214 L F
.47709 .49523 m .47148 .48941 L .4813 .4863 L F
.88504 .495 m .89136 .48607 L .89557 .49191 L F
.88504 .495 m .8808 .48918 L .89136 .48607 L F
.69365 .49493 m .69898 .48599 L .70383 .49184 L F
.69365 .49493 m .68877 .48911 L .69898 .48599 L F
.50224 .49486 m .50658 .48592 L .51208 .49176 L F
.50224 .49486 m .49671 .48903 L .50658 .48592 L F
0 0 .129 r
.44548 .43732 m .43905 .45811 L .44922 .44083 L F
0 0 0 r
.4351 .46507 m .43905 .45811 L .44548 .43732 L F
.656 .751 .92 r
.91028 .49463 m .91673 .48569 L .92085 .49153 L F
.91028 .49463 m .90613 .4888 L .91673 .48569 L F
.71885 .49455 m .72431 .48561 L .72908 .49146 L F
.71885 .49455 m .71405 .48873 L .72431 .48561 L F
.5274 .49448 m .53187 .48554 L .53729 .49138 L F
.5274 .49448 m .52196 .48866 L .53187 .48554 L F
.74406 .49418 m .74965 .48523 L .75434 .49108 L F
.74406 .49418 m .73935 .48835 L .74965 .48523 L F
.311 0 .088 r
.48492 .40222 m .48899 .40878 L .49468 .40448 L F
.48492 .40222 m .4791 .41202 L .48899 .40878 L F
.656 .751 .92 r
.55257 .4941 m .55717 .48516 L .56251 .491 L F
.55257 .4941 m .54721 .48828 L .55717 .48516 L F
.76928 .4938 m .77501 .48485 L .77961 .4907 L F
.76928 .4938 m .76465 .48797 L .77501 .48485 L F
.57776 .49372 m .58248 .48478 L .58774 .49063 L F
.57776 .49372 m .57248 .4879 L .58248 .48478 L F
.821 .856 .873 r
.21441 .47528 m .21746 .46398 L .22423 .46671 L F
.21441 .47528 m .20764 .47213 L .21746 .46398 L F
.82 .83 .856 r
.20453 .48446 m .20764 .47213 L .21441 .47528 L F
.20453 .48446 m .19779 .4806 L .20764 .47213 L F
.808 .801 .844 r
.19463 .49374 m .19779 .4806 L .20453 .48446 L F
.788 .77 .837 r
.18478 .50261 m .18795 .48897 L .19463 .49374 L F
.18478 .50261 m .17817 .49681 L .18795 .48897 L F
.808 .801 .844 r
.19463 .49374 m .18795 .48897 L .19779 .4806 L F
.808 .876 .896 r
.22423 .46671 m .22722 .45661 L .23397 .45924 L F
.22423 .46671 m .21746 .46398 L .22722 .45661 L F
.656 .751 .92 r
.79452 .49342 m .80037 .48447 L .80489 .49032 L F
.79452 .49342 m .78997 .48759 L .80037 .48447 L F
.60295 .49335 m .60781 .48439 L .61298 .49025 L F
.60295 .49335 m .59776 .48752 L .60781 .48439 L F
.026 .491 .879 r
.28442 .45607 m .28707 .45458 L .29332 .46083 L F
.28442 .45607 m .27804 .45158 L .28707 .45458 L F
.656 .751 .92 r
.81976 .49304 m .82575 .48409 L .83018 .48994 L F
.81976 .49304 m .8153 .48721 L .82575 .48409 L F
.62815 .49297 m .63315 .48401 L .63823 .48987 L F
.62815 .49297 m .62304 .48714 L .63315 .48401 L F
.43653 .4929 m .44052 .48394 L .44626 .48979 L F
.43653 .4929 m .43077 .48706 L .44052 .48394 L F
.84502 .49267 m .85114 .48371 L .85549 .48956 L F
.84502 .49267 m .84064 .48683 L .85114 .48371 L F
.775 .885 .925 r
.23397 .45924 m .23688 .45041 L .24358 .45326 L F
.23397 .45924 m .22722 .45661 L .23688 .45041 L F
.656 .751 .92 r
.65337 .49259 m .65849 .48363 L .66349 .48949 L F
.65337 .49259 m .64834 .48675 L .65849 .48363 L F
.4617 .49252 m .46583 .48356 L .47148 .48941 L F
.4617 .49252 m .45603 .48668 L .46583 .48356 L F
.87029 .49229 m .87654 .48332 L .8808 .48918 L F
.87029 .49229 m .86599 .48645 L .87654 .48332 L F
.67859 .49221 m .68385 .48325 L .68877 .48911 L F
.67859 .49221 m .67365 .48637 L .68385 .48325 L F
.48689 .49214 m .49115 .48317 L .49671 .48903 L F
.48689 .49214 m .4813 .4863 L .49115 .48317 L F
.89557 .49191 m .90195 .48294 L .90613 .4888 L F
.89557 .49191 m .89136 .48607 L .90195 .48294 L F
.384 .74 .991 r
.26892 .45053 m .27164 .44668 L .27804 .45158 L F
.26892 .45053 m .2624 .44689 L .27164 .44668 L F
.656 .751 .92 r
.70383 .49184 m .70922 .48287 L .71405 .48873 L F
.70383 .49184 m .69898 .48599 L .70922 .48287 L F
.51208 .49176 m .51647 .48279 L .52196 .48866 L F
.51208 .49176 m .50658 .48592 L .51647 .48279 L F
.92085 .49153 m .92737 .48256 L .93147 .48842 L F
.92085 .49153 m .91673 .48569 L .92737 .48256 L F
0 .24 .731 r
.29952 .46716 m .3022 .46705 L .30825 .47563 L F
.656 .751 .92 r
.72908 .49146 m .7346 .48248 L .73935 .48835 L F
.72908 .49146 m .72431 .48561 L .7346 .48248 L F
.53729 .49138 m .54181 .48241 L .54721 .48828 L F
.53729 .49138 m .53187 .48554 L .54181 .48241 L F
.75434 .49108 m .75999 .4821 L .76465 .48797 L F
.75434 .49108 m .74965 .48523 L .75999 .4821 L F
.56251 .491 m .56717 .48203 L .57248 .4879 L F
.56251 .491 m .55717 .48516 L .56717 .48203 L F
.716 .877 .956 r
.24358 .45326 m .24644 .44569 L .25306 .44909 L F
.24358 .45326 m .23688 .45041 L .24644 .44569 L F
.656 .751 .92 r
.77961 .4907 m .7854 .48172 L .78997 .48759 L F
.77961 .4907 m .77501 .48485 L .7854 .48172 L F
.58774 .49063 m .59253 .48164 L .59776 .48752 L F
.58774 .49063 m .58248 .48478 L .59253 .48164 L F
.80489 .49032 m .81081 .48134 L .8153 .48721 L F
.80489 .49032 m .80037 .48447 L .81081 .48134 L F
.61298 .49025 m .6179 .48126 L .62304 .48714 L F
.61298 .49025 m .60781 .48439 L .6179 .48126 L F
.83018 .48994 m .83624 .48095 L .84064 .48683 L F
.83018 .48994 m .82575 .48409 L .83624 .48095 L F
.63823 .48987 m .64328 .48088 L .64834 .48675 L F
.63823 .48987 m .63315 .48401 L .64328 .48088 L F
.44626 .48979 m .45031 .4808 L .45603 .48668 L F
.44626 .48979 m .44052 .48394 L .45031 .4808 L F
.85549 .48956 m .86167 .48057 L .86599 .48645 L F
.85549 .48956 m .85114 .48371 L .86167 .48057 L F
.66349 .48949 m .66868 .48049 L .67365 .48637 L F
.66349 .48949 m .65849 .48363 L .66868 .48049 L F
.47148 .48941 m .47567 .48042 L .4813 .4863 L F
.47148 .48941 m .46583 .48356 L .47567 .48042 L F
.8808 .48918 m .88712 .48019 L .89136 .48607 L F
.8808 .48918 m .87654 .48332 L .88712 .48019 L F
.68877 .48911 m .69409 .48011 L .69898 .48599 L F
.68877 .48911 m .68385 .48325 L .69409 .48011 L F
.49671 .48903 m .50103 .48004 L .50658 .48592 L F
.49671 .48903 m .49115 .48317 L .50103 .48004 L F
.90613 .4888 m .91258 .4798 L .91673 .48569 L F
.90613 .4888 m .90195 .48294 L .91258 .4798 L F
.71405 .48873 m .7195 .47973 L .72431 .48561 L F
.71405 .48873 m .70922 .48287 L .7195 .47973 L F
.52196 .48866 m .52641 .47965 L .53187 .48554 L F
.52196 .48866 m .51647 .48279 L .52641 .47965 L F
.626 .841 .982 r
.25306 .44909 m .25588 .44269 L .2624 .44689 L F
.25306 .44909 m .24644 .44569 L .25588 .44269 L F
.656 .751 .92 r
.73935 .48835 m .74493 .47934 L .74965 .48523 L F
.73935 .48835 m .7346 .48248 L .74493 .47934 L F
0 .019 .575 r
.32537 .51523 m .32841 .51295 L .33347 .53777 L F
.656 .751 .92 r
.54721 .48828 m .5518 .47927 L .55717 .48516 L F
.54721 .48828 m .54181 .48241 L .5518 .47927 L F
.254 0 0 r
.49468 .40448 m .49889 .40776 L .5045 .40837 L F
.49468 .40448 m .48899 .40878 L .49889 .40776 L F
.656 .751 .92 r
.76465 .48797 m .77037 .47896 L .77501 .48485 L F
.76465 .48797 m .75999 .4821 L .77037 .47896 L F
.57248 .4879 m .5772 .47889 L .58248 .48478 L F
.57248 .4879 m .56717 .48203 L .5772 .47889 L F
.773 .77 .85 r
.17817 .49681 m .18125 .4839 L .18795 .48897 L F
.17817 .49681 m .17152 .49097 L .18125 .4839 L F
.656 .751 .92 r
.78997 .48759 m .79582 .47858 L .80037 .48447 L F
.78997 .48759 m .7854 .48172 L .79582 .47858 L F
.59776 .48752 m .60261 .4785 L .60781 .48439 L F
.59776 .48752 m .59253 .48164 L .60261 .4785 L F
.8153 .48721 m .82129 .47819 L .82575 .48409 L F
.8153 .48721 m .81081 .48134 L .82129 .47819 L F
.62304 .48714 m .62803 .47812 L .63315 .48401 L F
.62304 .48714 m .6179 .48126 L .62803 .47812 L F
.793 .794 .853 r
.18795 .48897 m .19104 .47623 L .19779 .4806 L F
.18795 .48897 m .18125 .4839 L .19104 .47623 L F
.656 .751 .92 r
.84064 .48683 m .84676 .47781 L .85114 .48371 L F
.84064 .48683 m .83624 .48095 L .84676 .47781 L F
.64834 .48675 m .65346 .47773 L .65849 .48363 L F
.64834 .48675 m .64328 .48088 L .65346 .47773 L F
.805 .816 .86 r
.19779 .4806 m .20087 .4683 L .20764 .47213 L F
.19779 .4806 m .19104 .47623 L .20087 .4683 L F
.656 .751 .92 r
.45603 .48668 m .46014 .47766 L .46583 .48356 L F
.45603 .48668 m .45031 .4808 L .46014 .47766 L F
.241 .612 .955 r
.27804 .45158 m .28078 .44835 L .28707 .45458 L F
.27804 .45158 m .27164 .44668 L .28078 .44835 L F
.656 .751 .92 r
.86599 .48645 m .87225 .47742 L .87654 .48332 L F
.86599 .48645 m .86167 .48057 L .87225 .47742 L F
.808 .836 .871 r
.20764 .47213 m .2107 .4605 L .21746 .46398 L F
.20764 .47213 m .20087 .4683 L .2107 .4605 L F
.656 .751 .92 r
.67365 .48637 m .6789 .47735 L .68385 .48325 L F
.67365 .48637 m .66868 .48049 L .6789 .47735 L F
.4813 .4863 m .48554 .47727 L .49115 .48317 L F
.4813 .4863 m .47567 .48042 L .48554 .47727 L F
0 .155 .697 r
.31419 .4854 m .31706 .48445 L .32285 .49681 L F
.656 .751 .92 r
.89136 .48607 m .89774 .47704 L .90195 .48294 L F
.89136 .48607 m .88712 .48019 L .89774 .47704 L F
.69898 .48599 m .70436 .47696 L .70922 .48287 L F
.69898 .48599 m .69409 .48011 L .70436 .47696 L F
.8 .85 .888 r
.21746 .46398 m .22048 .45323 L .22722 .45661 L F
.21746 .46398 m .2107 .4605 L .22048 .45323 L F
.656 .751 .92 r
.50658 .48592 m .51096 .47689 L .51647 .48279 L F
.50658 .48592 m .50103 .48004 L .51096 .47689 L F
0 .393 .845 r
.29332 .46083 m .29607 .45913 L .3022 .46705 L F
.29332 .46083 m .28707 .45458 L .29607 .45913 L F
.656 .751 .92 r
.91673 .48569 m .92325 .47665 L .92737 .48256 L F
.91673 .48569 m .91258 .4798 L .92325 .47665 L F
.72431 .48561 m .72982 .47658 L .7346 .48248 L F
.72431 .48561 m .7195 .47973 L .72982 .47658 L F
.53187 .48554 m .53638 .4765 L .54181 .48241 L F
.53187 .48554 m .52641 .47965 L .53638 .4765 L F
.74965 .48523 m .7553 .47619 L .75999 .4821 L F
.74965 .48523 m .74493 .47934 L .7553 .47619 L F
.55717 .48516 m .56182 .47612 L .56717 .48203 L F
.55717 .48516 m .5518 .47927 L .56182 .47612 L F
.777 .858 .91 r
.22722 .45661 m .23019 .44686 L .23688 .45041 L F
.22722 .45661 m .22048 .45323 L .23019 .44686 L F
.969 .859 .675 r
.4243 .50323 m .42873 .47927 L .4351 .46507 L F
0 0 0 r
.4351 .46507 m .42873 .47927 L .43905 .45811 L F
.656 .751 .92 r
.77501 .48485 m .78079 .47581 L .7854 .48172 L F
.77501 .48485 m .77037 .47896 L .78079 .47581 L F
.58248 .48478 m .58726 .47573 L .59253 .48164 L F
.58248 .48478 m .5772 .47889 L .58726 .47573 L F
.507 .771 .991 r
.2624 .44689 m .2652 .44151 L .27164 .44668 L F
.2624 .44689 m .25588 .44269 L .2652 .44151 L F
.656 .751 .92 r
.80037 .48447 m .80629 .47542 L .81081 .48134 L F
.80037 .48447 m .79582 .47858 L .80629 .47542 L F
.60781 .48439 m .61272 .47535 L .6179 .48126 L F
.60781 .48439 m .60261 .4785 L .61272 .47535 L F
.82575 .48409 m .8318 .47504 L .83624 .48095 L F
.82575 .48409 m .82129 .47819 L .8318 .47504 L F
.63315 .48401 m .63819 .47496 L .64328 .48088 L F
.63315 .48401 m .62803 .47812 L .63819 .47496 L F
.85114 .48371 m .85732 .47465 L .86167 .48057 L F
.85114 .48371 m .84676 .47781 L .85732 .47465 L F
.65849 .48363 m .66367 .47458 L .66868 .48049 L F
.65849 .48363 m .65346 .47773 L .66367 .47458 L F
.46583 .48356 m .47 .4745 L .47567 .48042 L F
.46583 .48356 m .46014 .47766 L .47 .4745 L F
.735 .853 .936 r
.23688 .45041 m .23981 .44174 L .24644 .44569 L F
.23688 .45041 m .23019 .44686 L .23981 .44174 L F
.656 .751 .92 r
.87654 .48332 m .88286 .47426 L .88712 .48019 L F
.87654 .48332 m .87225 .47742 L .88286 .47426 L F
.68385 .48325 m .68916 .47419 L .69409 .48011 L F
.68385 .48325 m .6789 .47735 L .68916 .47419 L F
.49115 .48317 m .49545 .47411 L .50103 .48004 L F
.49115 .48317 m .48554 .47727 L .49545 .47411 L F
.90195 .48294 m .9084 .47388 L .91258 .4798 L F
.90195 .48294 m .89774 .47704 L .9084 .47388 L F
.70922 .48287 m .71467 .4738 L .7195 .47973 L F
.70922 .48287 m .70436 .47696 L .71467 .4738 L F
.51647 .48279 m .52091 .47373 L .52641 .47965 L F
.51647 .48279 m .51096 .47689 L .52091 .47373 L F
.7346 .48248 m .74018 .47342 L .74493 .47934 L F
.7346 .48248 m .72982 .47658 L .74018 .47342 L F
.54181 .48241 m .54639 .47334 L .5518 .47927 L F
.54181 .48241 m .53638 .4765 L .54639 .47334 L F
0 .256 .767 r
.30825 .47563 m .31111 .47402 L .31706 .48445 L F
.30825 .47563 m .3022 .46705 L .31111 .47402 L F
.656 .751 .92 r
.75999 .4821 m .76571 .47303 L .77037 .47896 L F
.75999 .4821 m .7553 .47619 L .76571 .47303 L F
.56717 .48203 m .57187 .47295 L .5772 .47889 L F
.56717 .48203 m .56182 .47612 L .57187 .47295 L F
.76 .769 .86 r
.17152 .49097 m .17451 .47861 L .18125 .4839 L F
.17152 .49097 m .16482 .48509 L .17451 .47861 L F
.656 .751 .92 r
.7854 .48172 m .79124 .47264 L .79582 .47858 L F
.7854 .48172 m .78079 .47581 L .79124 .47264 L F
.59253 .48164 m .59737 .47257 L .60261 .4785 L F
.59253 .48164 m .58726 .47573 L .59737 .47257 L F
.475 .83 .561 r
.46921 .41809 m .47331 .41446 L .4791 .41202 L F
.46921 .41809 m .46331 .42287 L .47331 .41446 L F
.545 .833 .496 r
.45926 .42756 m .46331 .42287 L .46921 .41809 L F
.656 .751 .92 r
.81081 .48134 m .81679 .47226 L .82129 .47819 L F
.81081 .48134 m .80629 .47542 L .81679 .47226 L F
.6179 .48126 m .62287 .47218 L .62803 .47812 L F
.6179 .48126 m .61272 .47535 L .62287 .47218 L F
.545 .833 .496 r
.45926 .42756 m .45326 .43395 L .46331 .42287 L F
.69 .897 .535 r
.44922 .44083 m .45326 .43395 L .45926 .42756 L F
.669 .829 .961 r
.24644 .44569 m .24933 .43811 L .25588 .44269 L F
.24644 .44569 m .23981 .44174 L .24933 .43811 L F
0 .57 .747 r
.5045 .40837 m .50883 .40832 L .51439 .41291 L F
.5045 .40837 m .49889 .40776 L .50883 .40832 L F
.656 .751 .92 r
.83624 .48095 m .84235 .47187 L .84676 .47781 L F
.83624 .48095 m .8318 .47504 L .84235 .47187 L F
.64328 .48088 m .64839 .47179 L .65346 .47773 L F
.64328 .48088 m .63819 .47496 L .64839 .47179 L F
.78 .789 .86 r
.18125 .4839 m .18428 .47149 L .19104 .47623 L F
.18125 .4839 m .17451 .47861 L .18428 .47149 L F
.656 .751 .92 r
.86167 .48057 m .86792 .47148 L .87225 .47742 L F
.86167 .48057 m .85732 .47465 L .86792 .47148 L F
.66868 .48049 m .67392 .47141 L .6789 .47735 L F
.66868 .48049 m .66367 .47458 L .67392 .47141 L F
.47567 .48042 m .4799 .47133 L .48554 .47727 L F
.47567 .48042 m .47 .4745 L .4799 .47133 L F
.88712 .48019 m .89351 .4711 L .89774 .47704 L F
.88712 .48019 m .88286 .47426 L .89351 .4711 L F
.69409 .48011 m .69946 .47102 L .70436 .47696 L F
.69409 .48011 m .68916 .47419 L .69946 .47102 L F
.144 .498 .907 r
.28707 .45458 m .28987 .45161 L .29607 .45913 L F
.28707 .45458 m .28078 .44835 L .28987 .45161 L F
.793 .807 .863 r
.19104 .47623 m .1941 .46401 L .20087 .4683 L F
.19104 .47623 m .18428 .47149 L .1941 .46401 L F
.377 .674 .974 r
.27164 .44668 m .27444 .44212 L .28078 .44835 L F
.27164 .44668 m .2652 .44151 L .27444 .44212 L F
.656 .751 .92 r
.50103 .48004 m .5054 .47094 L .51096 .47689 L F
.50103 .48004 m .49545 .47411 L .5054 .47094 L F
.91258 .4798 m .9191 .47071 L .92325 .47665 L F
.91258 .4798 m .9084 .47388 L .9191 .47071 L F
.475 .88 .73 r
.4791 .41202 m .48328 .40856 L .48899 .40878 L F
.4791 .41202 m .47331 .41446 L .48328 .40856 L F
.656 .751 .92 r
.7195 .47973 m .72501 .47063 L .72982 .47658 L F
.7195 .47973 m .71467 .4738 L .72501 .47063 L F
.52641 .47965 m .53091 .47056 L .53638 .4765 L F
.52641 .47965 m .52091 .47373 L .53091 .47056 L F
.798 .822 .871 r
.20087 .4683 m .20393 .45649 L .2107 .4605 L F
.20087 .4683 m .1941 .46401 L .20393 .45649 L F
.656 .751 .92 r
.74493 .47934 m .75058 .47024 L .7553 .47619 L F
.74493 .47934 m .74018 .47342 L .75058 .47024 L F
.5518 .47927 m .55643 .47017 L .56182 .47612 L F
.5518 .47927 m .54639 .47334 L .55643 .47017 L F
.69 .897 .535 r
.44922 .44083 m .44314 .44763 L .45326 .43395 L F
.866 .966 .64 r
.43905 .45811 m .44314 .44763 L .44922 .44083 L F
.656 .751 .92 r
.77037 .47896 m .77615 .46986 L .78079 .47581 L F
.77037 .47896 m .76571 .47303 L .77615 .46986 L F
.5772 .47889 m .58196 .46978 L .58726 .47573 L F
.5772 .47889 m .57187 .47295 L .58196 .46978 L F
.408 .233 .53 r
.32892 .62318 m .32977 .55058 L .33708 .58949 L F
.844 .589 .046 r
.32811 .62706 m .32977 .55058 L .32892 .62318 L F
.115 .09 .549 r
.32977 .55058 m .33347 .53777 L .33708 .58949 L F
.793 .833 .883 r
.2107 .4605 m .21374 .44931 L .22048 .45323 L F
.2107 .4605 m .20393 .45649 L .21374 .44931 L F
.656 .751 .92 r
.79582 .47858 m .80174 .46947 L .80629 .47542 L F
.79582 .47858 m .79124 .47264 L .80174 .46947 L F
.60261 .4785 m .60751 .46939 L .61272 .47535 L F
.60261 .4785 m .59737 .47257 L .60751 .46939 L F
.82129 .47819 m .82733 .46908 L .8318 .47504 L F
.82129 .47819 m .81679 .47226 L .82733 .46908 L F
.62803 .47812 m .63306 .469 L .63819 .47496 L F
.62803 .47812 m .62287 .47218 L .63306 .469 L F
.576 .781 .976 r
.25588 .44269 m .25874 .43615 L .2652 .44151 L F
.25588 .44269 m .24933 .43811 L .25874 .43615 L F
.656 .751 .92 r
.84676 .47781 m .85294 .46869 L .85732 .47465 L F
.84676 .47781 m .84235 .47187 L .85294 .46869 L F
.777 .839 .899 r
.22048 .45323 m .22349 .44283 L .23019 .44686 L F
.22048 .45323 m .21374 .44931 L .22349 .44283 L F
.012 .347 .825 r
.3022 .46705 m .30507 .4647 L .31111 .47402 L F
.3022 .46705 m .29607 .45913 L .30507 .4647 L F
.656 .751 .92 r
.65346 .47773 m .65863 .46862 L .66367 .47458 L F
.65346 .47773 m .64839 .47179 L .65863 .46862 L F
.87225 .47742 m .87856 .4683 L .88286 .47426 L F
.87225 .47742 m .86792 .47148 L .87856 .4683 L F
.6789 .47735 m .68421 .46823 L .68916 .47419 L F
.6789 .47735 m .67392 .47141 L .68421 .46823 L F
.48554 .47727 m .48983 .46815 L .49545 .47411 L F
.48554 .47727 m .4799 .47133 L .48983 .46815 L F
.89774 .47704 m .90419 .46791 L .9084 .47388 L F
.89774 .47704 m .89351 .4711 L .90419 .46791 L F
.70436 .47696 m .7098 .46784 L .71467 .4738 L F
.70436 .47696 m .69946 .47102 L .7098 .46784 L F
.51096 .47689 m .51538 .46776 L .52091 .47373 L F
.51096 .47689 m .5054 .47094 L .51538 .46776 L F
.502 .903 .923 r
.48899 .40878 m .49324 .4049 L .49889 .40776 L F
.48899 .40878 m .48328 .40856 L .49324 .4049 L F
.656 .751 .92 r
.72982 .47658 m .7354 .46745 L .74018 .47342 L F
.72982 .47658 m .72501 .47063 L .7354 .46745 L F
.53638 .4765 m .54094 .46737 L .54639 .47334 L F
.53638 .4765 m .53091 .47056 L .54094 .46737 L F
.745 .836 .92 r
.23019 .44686 m .23317 .43738 L .23981 .44174 L F
.23019 .44686 m .22349 .44283 L .23317 .43738 L F
.656 .751 .92 r
.7553 .47619 m .76101 .46706 L .76571 .47303 L F
.7553 .47619 m .75058 .47024 L .76101 .46706 L F
.56182 .47612 m .56651 .46698 L .57187 .47295 L F
.56182 .47612 m .55643 .47017 L .56651 .46698 L F
.749 .768 .869 r
.16482 .48509 m .16774 .47317 L .17451 .47861 L F
.16482 .48509 m .15808 .47917 L .16774 .47317 L F
.241 .225 .64 r
.33347 .53777 m .32841 .51295 L .33717 .52538 L F
.125 .226 .699 r
.32841 .51295 m .33172 .50678 L .33717 .52538 L F
.32841 .51295 m .32285 .49681 L .33172 .50678 L F
.656 .751 .92 r
.78079 .47581 m .78663 .46667 L .79124 .47264 L F
.78079 .47581 m .77615 .46986 L .78663 .46667 L F
.58726 .47573 m .59209 .46659 L .59737 .47257 L F
.58726 .47573 m .58196 .46978 L .59209 .46659 L F
.80629 .47542 m .81227 .46628 L .81679 .47226 L F
.80629 .47542 m .80174 .46947 L .81227 .46628 L F
.61272 .47535 m .61768 .4662 L .62287 .47218 L F
.61272 .47535 m .60751 .46939 L .61768 .4662 L F
.066 .254 .746 r
.32285 .49681 m .326 .49271 L .33172 .50678 L F
.32285 .49681 m .31706 .48445 L .326 .49271 L F
.656 .751 .92 r
.8318 .47504 m .83791 .46589 L .84235 .47187 L F
.8318 .47504 m .82733 .46908 L .83791 .46589 L F
.63819 .47496 m .64329 .46582 L .64839 .47179 L F
.63819 .47496 m .63306 .469 L .64329 .46582 L F
.866 .966 .64 r
.43905 .45811 m .43292 .46365 L .44314 .44763 L F
.957 .939 .721 r
.42873 .47927 m .43292 .46365 L .43905 .45811 L F
.656 .751 .92 r
.85732 .47465 m .86357 .4655 L .86792 .47148 L F
.85732 .47465 m .85294 .46869 L .86357 .4655 L F
.66367 .47458 m .6689 .46543 L .67392 .47141 L F
.66367 .47458 m .65863 .46862 L .6689 .46543 L F
.769 .785 .866 r
.17451 .47861 m .17749 .46649 L .18428 .47149 L F
.17451 .47861 m .16774 .47317 L .17749 .46649 L F
.262 .569 .938 r
.28078 .44835 m .28361 .44434 L .28987 .45161 L F
.28078 .44835 m .27444 .44212 L .28361 .44434 L F
.656 .751 .92 r
.88286 .47426 m .88924 .46511 L .89351 .4711 L F
.88286 .47426 m .87856 .4683 L .88924 .46511 L F
.68916 .47419 m .69453 .46504 L .69946 .47102 L F
.68916 .47419 m .68421 .46823 L .69453 .46504 L F
.694 .819 .942 r
.23981 .44174 m .24275 .43324 L .24933 .43811 L F
.23981 .44174 m .23317 .43738 L .24275 .43324 L F
.656 .751 .92 r
.49545 .47411 m .4998 .46496 L .5054 .47094 L F
.49545 .47411 m .48983 .46815 L .4998 .46496 L F
.9084 .47388 m .91492 .46472 L .9191 .47071 L F
.9084 .47388 m .90419 .46791 L .91492 .46472 L F
.71467 .4738 m .72017 .46465 L .72501 .47063 L F
.71467 .4738 m .7098 .46784 L .72017 .46465 L F
.275 .635 .964 r
.51439 .41291 m .51883 .40988 L .52438 .41737 L F
.51439 .41291 m .50883 .40832 L .51883 .40988 L F
.656 .751 .92 r
.52091 .47373 m .5254 .46457 L .53091 .47056 L F
.52091 .47373 m .51538 .46776 L .5254 .46457 L F
.464 .707 .974 r
.2652 .44151 m .26805 .43588 L .27444 .44212 L F
.2652 .44151 m .25874 .43615 L .26805 .43588 L F
.782 .8 .867 r
.18428 .47149 m .1873 .45937 L .1941 .46401 L F
.18428 .47149 m .17749 .46649 L .1873 .45937 L F
.656 .751 .92 r
.74018 .47342 m .74582 .46425 L .75058 .47024 L F
.74018 .47342 m .7354 .46745 L .74582 .46425 L F
.54639 .47334 m .55101 .46418 L .55643 .47017 L F
.54639 .47334 m .54094 .46737 L .55101 .46418 L F
.76571 .47303 m .77148 .46386 L .77615 .46986 L F
.76571 .47303 m .76101 .46706 L .77148 .46386 L F
.57187 .47295 m .57663 .46379 L .58196 .46978 L F
.57187 .47295 m .56651 .46698 L .57663 .46379 L F
.103 .422 .868 r
.29607 .45913 m .29895 .45606 L .30507 .4647 L F
.29607 .45913 m .28987 .45161 L .29895 .45606 L F
.057 .296 .784 r
.31706 .48445 m .32012 .481 L .326 .49271 L F
.31706 .48445 m .31111 .47402 L .32012 .481 L F
.656 .751 .92 r
.79124 .47264 m .79715 .46347 L .80174 .46947 L F
.79124 .47264 m .78663 .46667 L .79715 .46347 L F
.789 .812 .871 r
.1941 .46401 m .19714 .4521 L .20393 .45649 L F
.1941 .46401 m .1873 .45937 L .19714 .4521 L F
.656 .751 .92 r
.59737 .47257 m .60226 .4634 L .60751 .46939 L F
.59737 .47257 m .59209 .46659 L .60226 .4634 L F
.81679 .47226 m .82284 .46308 L .82733 .46908 L F
.81679 .47226 m .81227 .46628 L .82284 .46308 L F
.5 .826 1 r
.49889 .40776 m .50323 .40311 L .50883 .40832 L F
.49889 .40776 m .49324 .4049 L .50323 .40311 L F
.656 .751 .92 r
.62287 .47218 m .6279 .46301 L .63306 .469 L F
.62287 .47218 m .61768 .4662 L .6279 .46301 L F
.381 .253 .578 r
.33708 .58949 m .33347 .53777 L .34208 .55418 L F
.241 .225 .64 r
.33347 .53777 m .33717 .52538 L .34208 .55418 L F
.656 .751 .92 r
.84235 .47187 m .84853 .46269 L .85294 .46869 L F
.84235 .47187 m .83791 .46589 L .84853 .46269 L F
.64839 .47179 m .65355 .46261 L .65863 .46862 L F
.64839 .47179 m .64329 .46582 L .65355 .46261 L F
.788 .822 .879 r
.20393 .45649 m .20697 .445 L .21374 .44931 L F
.20393 .45649 m .19714 .4521 L .20697 .445 L F
.656 .751 .92 r
.86792 .47148 m .87424 .4623 L .87856 .4683 L F
.86792 .47148 m .86357 .4655 L .87424 .4623 L F
.67392 .47141 m .67922 .46222 L .68421 .46823 L F
.67392 .47141 m .6689 .46543 L .67922 .46222 L F
.62 .784 .96 r
.24933 .43811 m .25223 .43063 L .25874 .43615 L F
.24933 .43811 m .24275 .43324 L .25223 .43063 L F
.656 .751 .92 r
.89351 .4711 m .89996 .46191 L .90419 .46791 L F
.89351 .4711 m .88924 .46511 L .89996 .46191 L F
.69946 .47102 m .70489 .46183 L .7098 .46784 L F
.69946 .47102 m .69453 .46504 L .70489 .46183 L F
.5054 .47094 m .50981 .46176 L .51538 .46776 L F
.5054 .47094 m .4998 .46496 L .50981 .46176 L F
.776 .826 .892 r
.21374 .44931 m .21676 .43843 L .22349 .44283 L F
.21374 .44931 m .20697 .445 L .21676 .43843 L F
.656 .751 .92 r
.72501 .47063 m .73058 .46144 L .7354 .46745 L F
.72501 .47063 m .72017 .46465 L .73058 .46144 L F
.53091 .47056 m .53545 .46136 L .54094 .46737 L F
.53091 .47056 m .5254 .46457 L .53545 .46136 L F
.75058 .47024 m .75628 .46105 L .76101 .46706 L F
.75058 .47024 m .74582 .46425 L .75628 .46105 L F
.55643 .47017 m .56111 .46097 L .56651 .46698 L F
.55643 .47017 m .55101 .46418 L .56111 .46097 L F
.738 .767 .876 r
.15808 .47917 m .16094 .46759 L .16774 .47317 L F
.15808 .47917 m .15129 .47321 L .16094 .46759 L F
.656 .751 .92 r
.77615 .46986 m .78199 .46066 L .78663 .46667 L F
.77615 .46986 m .77148 .46386 L .78199 .46066 L F
.58196 .46978 m .58678 .46058 L .59209 .46659 L F
.58196 .46978 m .57663 .46379 L .58678 .46058 L F
.832 .998 .836 r
.46331 .42287 m .46749 .41429 L .47331 .41446 L F
.46331 .42287 m .45742 .4241 L .46749 .41429 L F
.873 .994 .788 r
.45326 .43395 m .45742 .4241 L .46331 .42287 L F
.543 .322 .53 r
.41132 .6021 m .4243 .50323 L .42141 .59907 L F
.41132 .6021 m .41298 .55226 L .4243 .50323 L F
.802 .61 .642 r
.41298 .55226 m .41822 .50378 L .4243 .50323 L F
.656 .751 .92 r
.80174 .46947 m .80771 .46026 L .81227 .46628 L F
.80174 .46947 m .79715 .46347 L .80771 .46026 L F
.60751 .46939 m .61246 .46019 L .61768 .4662 L F
.60751 .46939 m .60226 .4634 L .61246 .46019 L F
.751 .824 .909 r
.22349 .44283 m .22649 .43271 L .23317 .43738 L F
.22349 .44283 m .21676 .43843 L .22649 .43271 L F
.786 .982 .903 r
.47331 .41446 m .47753 .40666 L .48328 .40856 L F
.47331 .41446 m .46749 .41429 L .47753 .40666 L F
.076 .343 .817 r
.31111 .47402 m .31413 .47066 L .32012 .481 L F
.31111 .47402 m .30507 .4647 L .31413 .47066 L F
.656 .751 .92 r
.82733 .46908 m .83344 .45987 L .83791 .46589 L F
.82733 .46908 m .82284 .46308 L .83344 .45987 L F
.63306 .469 m .63815 .4598 L .64329 .46582 L F
.63306 .469 m .6279 .46301 L .63815 .4598 L F
.85294 .46869 m .85919 .45948 L .86357 .4655 L F
.85294 .46869 m .84853 .46269 L .85919 .45948 L F
.65863 .46862 m .66385 .4594 L .6689 .46543 L F
.65863 .46862 m .65355 .46261 L .66385 .4594 L F
.873 .994 .788 r
.45326 .43395 m .44729 .43599 L .45742 .4241 L F
.913 .979 .769 r
.44314 .44763 m .44729 .43599 L .45326 .43395 L F
.35 .618 .952 r
.27444 .44212 m .2773 .43723 L .28361 .44434 L F
.27444 .44212 m .26805 .43588 L .2773 .43723 L F
.759 .782 .872 r
.16774 .47317 m .17067 .46128 L .17749 .46649 L F
.16774 .47317 m .16094 .46759 L .17067 .46128 L F
.957 .939 .721 r
.42873 .47927 m .42261 .48148 L .43292 .46365 L F
.656 .751 .92 r
.87856 .4683 m .88495 .45909 L .88924 .46511 L F
.87856 .4683 m .87424 .4623 L .88495 .45909 L F
.68421 .46823 m .68957 .45901 L .69453 .46504 L F
.68421 .46823 m .67922 .46222 L .68957 .45901 L F
.90419 .46791 m .91071 .45869 L .91492 .46472 L F
.90419 .46791 m .89996 .46191 L .91071 .45869 L F
.7098 .46784 m .71529 .45862 L .72017 .46465 L F
.7098 .46784 m .70489 .46183 L .71529 .45862 L F
.51538 .46776 m .51985 .45854 L .5254 .46457 L F
.51538 .46776 m .50981 .46176 L .51985 .45854 L F
.184 .484 .898 r
.28987 .45161 m .29276 .44786 L .29895 .45606 L F
.28987 .45161 m .28361 .44434 L .29276 .44786 L F
.656 .751 .92 r
.7354 .46745 m .74103 .45822 L .74582 .46425 L F
.7354 .46745 m .73058 .46144 L .74103 .45822 L F
.726 .931 .957 r
.48328 .40856 m .48755 .40117 L .49324 .4049 L F
.48328 .40856 m .47753 .40666 L .48755 .40117 L F
.656 .751 .92 r
.54094 .46737 m .54555 .45815 L .55101 .46418 L F
.54094 .46737 m .53545 .46136 L .54555 .45815 L F
.524 .727 .966 r
.25874 .43615 m .26163 .42963 L .26805 .43588 L F
.25874 .43615 m .25223 .43063 L .26163 .42963 L F
.711 .812 .928 r
.23317 .43738 m .23614 .42815 L .24275 .43324 L F
.23317 .43738 m .22649 .43271 L .23614 .42815 L F
.656 .751 .92 r
.76101 .46706 m .76678 .45783 L .77148 .46386 L F
.76101 .46706 m .75628 .46105 L .76678 .45783 L F
.773 .795 .87 r
.17749 .46649 m .18048 .45447 L .1873 .45937 L F
.17749 .46649 m .17067 .46128 L .18048 .45447 L F
.656 .751 .92 r
.56651 .46698 m .57125 .45775 L .57663 .46379 L F
.56651 .46698 m .56111 .46097 L .57125 .45775 L F
.477 .715 .974 r
.50883 .40832 m .51326 .40277 L .51883 .40988 L F
.50883 .40832 m .50323 .40311 L .51326 .40277 L F
.656 .751 .92 r
.78663 .46667 m .79254 .45744 L .79715 .46347 L F
.78663 .46667 m .78199 .46066 L .79254 .45744 L F
.59209 .46659 m .59697 .45736 L .60226 .4634 L F
.59209 .46659 m .58678 .46058 L .59697 .45736 L F
.471 .413 .71 r
.5299 .43765 m .52438 .41737 L .53444 .42123 L F
.382 .577 .917 r
.52438 .41737 m .5289 .4119 L .53444 .42123 L F
.656 .751 .92 r
.81227 .46628 m .81831 .45704 L .82284 .46308 L F
.81227 .46628 m .80771 .46026 L .81831 .45704 L F
.61768 .4662 m .6227 .45697 L .6279 .46301 L F
.61768 .4662 m .61246 .46019 L .6227 .45697 L F
.913 .979 .769 r
.44314 .44763 m .4371 .44966 L .44729 .43599 L F
.937 .946 .768 r
.43292 .46365 m .4371 .44966 L .44314 .44763 L F
.782 .805 .871 r
.1873 .45937 m .19032 .44741 L .19714 .4521 L F
.1873 .45937 m .18048 .45447 L .19032 .44741 L F
.656 .751 .92 r
.83791 .46589 m .84409 .45665 L .84853 .46269 L F
.83791 .46589 m .83344 .45987 L .84409 .45665 L F
.64329 .46582 m .64844 .45657 L .65355 .46261 L F
.64329 .46582 m .63815 .4598 L .64844 .45657 L F
.86357 .4655 m .86989 .45626 L .87424 .4623 L F
.86357 .4655 m .85919 .45948 L .86989 .45626 L F
.6689 .46543 m .67419 .45618 L .67922 .46222 L F
.6689 .46543 m .66385 .4594 L .67419 .45618 L F
.312 .322 .71 r
.33717 .52538 m .33172 .50678 L .34083 .51438 L F
.239 .335 .761 r
.33172 .50678 m .33512 .49957 L .34083 .51438 L F
.33172 .50678 m .326 .49271 L .33512 .49957 L F
.656 .751 .92 r
.88924 .46511 m .89569 .45586 L .89996 .46191 L F
.88924 .46511 m .88495 .45909 L .89569 .45586 L F
.69453 .46504 m .69995 .45578 L .70489 .46183 L F
.69453 .46504 m .68957 .45901 L .69995 .45578 L F
.111 .389 .845 r
.30507 .4647 m .30806 .46118 L .31413 .47066 L F
.30507 .4647 m .29895 .45606 L .30806 .46118 L F
.783 .813 .877 r
.19714 .4521 m .20018 .44039 L .20697 .445 L F
.19714 .4521 m .19032 .44741 L .20018 .44039 L F
.471 .413 .71 r
.5299 .43765 m .53444 .42123 L .54003 .44786 L F
.656 .751 .92 r
.72017 .46465 m .72573 .45539 L .73058 .46144 L F
.72017 .46465 m .71529 .45862 L .72573 .45539 L F
.5254 .46457 m .52993 .45531 L .53545 .46136 L F
.5254 .46457 m .51985 .45854 L .52993 .45531 L F
.398 .316 .646 r
.34208 .55418 m .33717 .52538 L .34627 .53383 L F
.312 .322 .71 r
.33717 .52538 m .34083 .51438 L .34627 .53383 L F
.65 .785 .946 r
.24275 .43324 m .24569 .42498 L .25223 .43063 L F
.24275 .43324 m .23614 .42815 L .24569 .42498 L F
.652 .844 .974 r
.49324 .4049 m .49758 .39764 L .50323 .40311 L F
.49324 .4049 m .48755 .40117 L .49758 .39764 L F
.656 .751 .92 r
.74582 .46425 m .75152 .455 L .75628 .46105 L F
.74582 .46425 m .74103 .45822 L .75152 .455 L F
.55101 .46418 m .55568 .45492 L .56111 .46097 L F
.55101 .46418 m .54555 .45815 L .55568 .45492 L F
.729 .766 .882 r
.15129 .47321 m .15409 .46191 L .16094 .46759 L F
.15129 .47321 m .14446 .46721 L .15409 .46191 L F
.656 .751 .92 r
.77148 .46386 m .77731 .4546 L .78199 .46066 L F
.77148 .46386 m .76678 .45783 L .77731 .4546 L F
.57663 .46379 m .58143 .45452 L .58678 .46058 L F
.57663 .46379 m .57125 .45775 L .58143 .45452 L F
.775 .817 .886 r
.20697 .445 m .21001 .43375 L .21676 .43843 L F
.20697 .445 m .20018 .44039 L .21001 .43375 L F
.19 .351 .796 r
.326 .49271 m .32927 .48723 L .33512 .49957 L F
.326 .49271 m .32012 .481 L .32927 .48723 L F
.656 .751 .92 r
.79715 .46347 m .80312 .45421 L .80771 .46026 L F
.79715 .46347 m .79254 .45744 L .80312 .45421 L F
.60226 .4634 m .6072 .45413 L .61246 .46019 L F
.60226 .4634 m .59697 .45736 L .6072 .45413 L F
.82284 .46308 m .82894 .45381 L .83344 .45987 L F
.82284 .46308 m .81831 .45704 L .82894 .45381 L F
.6279 .46301 m .63298 .45373 L .63815 .4598 L F
.6279 .46301 m .6227 .45697 L .63298 .45373 L F
.84853 .46269 m .85478 .45342 L .85919 .45948 L F
.84853 .46269 m .84409 .45665 L .85478 .45342 L F
.65355 .46261 m .65877 .45334 L .66385 .4594 L F
.65355 .46261 m .64844 .45657 L .65877 .45334 L F
.937 .946 .768 r
.43292 .46365 m .42684 .46464 L .4371 .44966 L F
.93 .888 .768 r
.42261 .48148 m .42684 .46464 L .43292 .46365 L F
.417 .652 .956 r
.26805 .43588 m .27094 .43022 L .2773 .43723 L F
.26805 .43588 m .26163 .42963 L .27094 .43022 L F
.756 .815 .9 r
.21676 .43843 m .21978 .42781 L .22649 .43271 L F
.21676 .43843 m .21001 .43375 L .21978 .42781 L F
.254 .533 .918 r
.28361 .44434 m .28651 .43996 L .29276 .44786 L F
.28361 .44434 m .2773 .43723 L .28651 .43996 L F
.656 .751 .92 r
.87424 .4623 m .88062 .45302 L .88495 .45909 L F
.87424 .4623 m .86989 .45626 L .88062 .45302 L F
.67922 .46222 m .68457 .45294 L .68957 .45901 L F
.67922 .46222 m .67419 .45618 L .68457 .45294 L F
.75 .779 .877 r
.16094 .46759 m .16382 .45591 L .17067 .46128 L F
.16094 .46759 m .15409 .46191 L .16382 .45591 L F
.656 .751 .92 r
.89996 .46191 m .90648 .45262 L .91071 .45869 L F
.89996 .46191 m .89569 .45586 L .90648 .45262 L F
.70489 .46183 m .71038 .45255 L .71529 .45862 L F
.70489 .46183 m .69995 .45578 L .71038 .45255 L F
.73058 .46144 m .73621 .45215 L .74103 .45822 L F
.73058 .46144 m .72573 .45539 L .73621 .45215 L F
.53545 .46136 m .54005 .45207 L .54555 .45815 L F
.53545 .46136 m .52993 .45531 L .54005 .45207 L F
.46 .633 .929 r
.51883 .40988 m .52334 .40343 L .5289 .4119 L F
.51883 .40988 m .51326 .40277 L .52334 .40343 L F
.656 .751 .92 r
.75628 .46105 m .76204 .45176 L .76678 .45783 L F
.75628 .46105 m .75152 .455 L .76204 .45176 L F
.568 .74 .957 r
.25223 .43063 m .25515 .42334 L .26163 .42963 L F
.25223 .43063 m .24569 .42498 L .25515 .42334 L F
.656 .751 .92 r
.56111 .46097 m .56584 .45168 L .57125 .45775 L F
.56111 .46097 m .55568 .45492 L .56584 .45168 L F
.78199 .46066 m .78789 .45136 L .79254 .45744 L F
.78199 .46066 m .77731 .4546 L .78789 .45136 L F
.164 .37 .82 r
.32012 .481 m .3233 .47635 L .32927 .48723 L F
.32012 .481 m .31413 .47066 L .3233 .47635 L F
.656 .751 .92 r
.58678 .46058 m .59165 .45128 L .59697 .45736 L F
.58678 .46058 m .58143 .45452 L .59165 .45128 L F
.766 .79 .873 r
.17067 .46128 m .17362 .44936 L .18048 .45447 L F
.17067 .46128 m .16382 .45591 L .17362 .44936 L F
.722 .806 .917 r
.22649 .43271 m .22949 .42288 L .23614 .42815 L F
.22649 .43271 m .21978 .42781 L .22949 .42288 L F
.581 .749 .957 r
.50323 .40311 m .50764 .3958 L .51326 .40277 L F
.50323 .40311 m .49758 .39764 L .50764 .3958 L F
.151 .431 .868 r
.29895 .45606 m .30192 .45227 L .30806 .46118 L F
.29895 .45606 m .29276 .44786 L .30192 .45227 L F
.656 .751 .92 r
.80771 .46026 m .81375 .45096 L .81831 .45704 L F
.80771 .46026 m .80312 .45421 L .81375 .45096 L F
.802 .61 .642 r
.41298 .55226 m .40754 .53058 L .41822 .50378 L F
.92 .817 .727 r
.41822 .50378 m .41221 .50031 L .42261 .48148 L F
.835 .685 .697 r
.40754 .53058 m .41221 .50031 L .41822 .50378 L F
.656 .751 .92 r
.61246 .46019 m .61746 .45089 L .6227 .45697 L F
.61246 .46019 m .6072 .45413 L .61746 .45089 L F
.845 .941 .886 r
.46749 .41429 m .47174 .40391 L .47753 .40666 L F
.46749 .41429 m .46164 .41283 L .47174 .40391 L F
.883 .956 .847 r
.45742 .4241 m .46164 .41283 L .46749 .41429 L F
.656 .751 .92 r
.83344 .45987 m .83962 .45057 L .84409 .45665 L F
.83344 .45987 m .82894 .45381 L .83962 .45057 L F
.63815 .4598 m .64329 .45049 L .64844 .45657 L F
.63815 .4598 m .63298 .45373 L .64329 .45049 L F
.883 .956 .847 r
.45742 .4241 m .45149 .4236 L .46164 .41283 L F
.907 .952 .816 r
.44729 .43599 m .45149 .4236 L .45742 .4241 L F
.656 .751 .92 r
.85919 .45948 m .8655 .45017 L .86989 .45626 L F
.85919 .45948 m .85478 .45342 L .8655 .45017 L F
.66385 .4594 m .66913 .45009 L .67419 .45618 L F
.66385 .4594 m .65877 .45334 L .66913 .45009 L F
.509 .403 .67 r
.54003 .44786 m .53444 .42123 L .54458 .4242 L F
.429 .546 .873 r
.53444 .42123 m .53904 .41395 L .54458 .4242 L F
.53444 .42123 m .5289 .4119 L .53904 .41395 L F
.776 .8 .872 r
.18048 .45447 m .18348 .44248 L .19032 .44741 L F
.18048 .45447 m .17362 .44936 L .18348 .44248 L F
.791 .903 .92 r
.47753 .40666 m .48182 .39697 L .48755 .40117 L F
.47753 .40666 m .47174 .40391 L .48182 .39697 L F
.656 .751 .92 r
.88495 .45909 m .8914 .44977 L .89569 .45586 L F
.88495 .45909 m .88062 .45302 L .8914 .44977 L F
.68957 .45901 m .69498 .4497 L .69995 .45578 L F
.68957 .45901 m .68457 .45294 L .69498 .4497 L F
.71529 .45862 m .72085 .4493 L .72573 .45539 L F
.71529 .45862 m .71038 .45255 L .72085 .4493 L F
.475 .315 .584 r
.34542 .6137 m .34208 .55418 L .3512 .56355 L F
.381 .253 .578 r
.33708 .58949 m .34208 .55418 L .34542 .6137 L F
.398 .316 .646 r
.34208 .55418 m .34627 .53383 L .3512 .56355 L F
.656 .751 .92 r
.74103 .45822 m .74672 .4489 L .75152 .455 L F
.74103 .45822 m .73621 .45215 L .74672 .4489 L F
.907 .952 .816 r
.44729 .43599 m .44129 .43596 L .45149 .4236 L F
.921 .936 .798 r
.4371 .44966 m .44129 .43596 L .44729 .43599 L F
.656 .751 .92 r
.54555 .45815 m .5502 .44882 L .55568 .45492 L F
.54555 .45815 m .54005 .45207 L .5502 .44882 L F
.779 .807 .875 r
.19032 .44741 m .19335 .43554 L .20018 .44039 L F
.19032 .44741 m .18348 .44248 L .19335 .43554 L F
.72 .765 .888 r
.14446 .46721 m .1472 .45613 L .15409 .46191 L F
.14446 .46721 m .13757 .46117 L .1472 .45613 L F
.93 .888 .768 r
.42261 .48148 m .41653 .48028 L .42684 .46464 L F
.892 .807 .758 r
.41221 .50031 m .41653 .48028 L .42261 .48148 L F
.672 .785 .934 r
.23614 .42815 m .2391 .41923 L .24569 .42498 L F
.23614 .42815 m .22949 .42288 L .2391 .41923 L F
.656 .751 .92 r
.76678 .45783 m .77261 .4485 L .77731 .4546 L F
.76678 .45783 m .76204 .45176 L .77261 .4485 L F
.57125 .45775 m .57605 .44843 L .58143 .45452 L F
.57125 .45775 m .56584 .45168 L .57605 .44843 L F
.79254 .45744 m .7985 .44811 L .80312 .45421 L F
.79254 .45744 m .78789 .45136 L .7985 .44811 L F
.59697 .45736 m .6019 .44803 L .6072 .45413 L F
.59697 .45736 m .59165 .45128 L .6019 .44803 L F
.722 .842 .938 r
.48755 .40117 m .4919 .392 L .49758 .39764 L F
.48755 .40117 m .48182 .39697 L .4919 .392 L F
.656 .751 .92 r
.81831 .45704 m .82441 .44771 L .82894 .45381 L F
.81831 .45704 m .81375 .45096 L .82441 .44771 L F
.6227 .45697 m .62777 .44763 L .63298 .45373 L F
.6227 .45697 m .61746 .45089 L .62777 .44763 L F
.774 .81 .882 r
.20018 .44039 m .20322 .42884 L .21001 .43375 L F
.20018 .44039 m .19335 .43554 L .20322 .42884 L F
.156 .391 .839 r
.31413 .47066 m .31725 .46639 L .3233 .47635 L F
.31413 .47066 m .30806 .46118 L .31725 .46639 L F
.314 .572 .931 r
.2773 .43723 m .2802 .43226 L .28651 .43996 L F
.2773 .43723 m .27094 .43022 L .2802 .43226 L F
.656 .751 .92 r
.84409 .45665 m .85034 .44731 L .85478 .45342 L F
.84409 .45665 m .83962 .45057 L .85034 .44731 L F
.64844 .45657 m .65364 .44723 L .65877 .45334 L F
.64844 .45657 m .64329 .45049 L .65364 .44723 L F
.469 .677 .955 r
.26163 .42963 m .26453 .42328 L .27094 .43022 L F
.26163 .42963 m .25515 .42334 L .26453 .42328 L F
.433 .394 .716 r
.34627 .53383 m .34083 .51438 L .35019 .51889 L F
.37 .406 .768 r
.34083 .51438 m .34446 .50431 L .35019 .51889 L F
.34083 .51438 m .33512 .49957 L .34446 .50431 L F
.656 .751 .92 r
.86989 .45626 m .87627 .44691 L .88062 .45302 L F
.86989 .45626 m .8655 .45017 L .87627 .44691 L F
.67419 .45618 m .67953 .44683 L .68457 .45294 L F
.67419 .45618 m .66913 .45009 L .67953 .44683 L F
.742 .777 .881 r
.15409 .46191 m .15692 .4504 L .16382 .45591 L F
.15409 .46191 m .1472 .45613 L .15692 .4504 L F
.656 .751 .92 r
.89569 .45586 m .90221 .44651 L .90648 .45262 L F
.89569 .45586 m .8914 .44977 L .90221 .44651 L F
.921 .936 .798 r
.4371 .44966 m .43105 .44948 L .44129 .43596 L F
.921 .906 .791 r
.42684 .46464 m .43105 .44948 L .4371 .44966 L F
.656 .751 .92 r
.69995 .45578 m .70544 .44644 L .71038 .45255 L F
.69995 .45578 m .69498 .4497 L .70544 .44644 L F
.525 .67 .929 r
.51326 .40277 m .51774 .3953 L .52334 .40343 L F
.51326 .40277 m .50764 .3958 L .51774 .3953 L F
.759 .809 .893 r
.21001 .43375 m .21304 .42271 L .21978 .42781 L F
.21001 .43375 m .20322 .42884 L .21304 .42271 L F
.193 .468 .887 r
.29276 .44786 m .29571 .44374 L .30192 .45227 L F
.29276 .44786 m .28651 .43996 L .29571 .44374 L F
.656 .751 .92 r
.72573 .45539 m .73135 .44604 L .73621 .45215 L F
.72573 .45539 m .72085 .4493 L .73135 .44604 L F
.491 .378 .652 r
.3512 .56355 m .34627 .53383 L .3557 .53772 L F
.433 .394 .716 r
.34627 .53383 m .35019 .51889 L .3557 .53772 L F
.311 .414 .806 r
.33512 .49957 m .33858 .49202 L .34446 .50431 L F
.33512 .49957 m .32927 .48723 L .33858 .49202 L F
.454 .586 .895 r
.5289 .4119 m .53349 .40468 L .53904 .41395 L F
.5289 .4119 m .52334 .40343 L .53349 .40468 L F
.656 .751 .92 r
.75152 .455 m .75727 .44564 L .76204 .45176 L F
.75152 .455 m .74672 .4489 L .75727 .44564 L F
.55568 .45492 m .56039 .44556 L .56584 .45168 L F
.55568 .45492 m .5502 .44882 L .56039 .44556 L F
.601 .749 .948 r
.24569 .42498 m .24863 .41703 L .25515 .42334 L F
.24569 .42498 m .2391 .41923 L .24863 .41703 L F
.656 .751 .92 r
.77731 .4546 m .78321 .44524 L .78789 .45136 L F
.77731 .4546 m .77261 .4485 L .78321 .44524 L F
.58143 .45452 m .58629 .44516 L .59165 .45128 L F
.58143 .45452 m .57605 .44843 L .58629 .44516 L F
.509 .403 .67 r
.54003 .44786 m .54458 .4242 L .55019 .44786 L F
.656 .751 .92 r
.80312 .45421 m .80916 .44484 L .81375 .45096 L F
.80312 .45421 m .7985 .44811 L .80916 .44484 L F
.759 .787 .876 r
.16382 .45591 m .16673 .44408 L .17362 .44936 L F
.16382 .45591 m .15692 .4504 L .16673 .44408 L F
.656 .751 .92 r
.6072 .45413 m .61219 .44476 L .61746 .45089 L F
.6072 .45413 m .6019 .44803 L .61219 .44476 L F
.492 .294 .539 r
.33642 .61819 m .33708 .58949 L .34542 .6137 L F
.408 .233 .53 r
.33451 .61988 m .33708 .58949 L .33642 .61819 L F
.32892 .62318 m .33708 .58949 L .33451 .61988 L F
.647 .768 .937 r
.49758 .39764 m .50199 .38886 L .50764 .3958 L F
.49758 .39764 m .4919 .392 L .50199 .38886 L F
.656 .751 .92 r
.82894 .45381 m .83512 .44444 L .83962 .45057 L F
.82894 .45381 m .82441 .44771 L .83512 .44444 L F
.63298 .45373 m .63811 .44436 L .64329 .45049 L F
.63298 .45373 m .62777 .44763 L .63811 .44436 L F
.732 .802 .907 r
.21978 .42781 m .2228 .41747 L .22949 .42288 L F
.21978 .42781 m .21304 .42271 L .2228 .41747 L F
.656 .751 .92 r
.85478 .45342 m .86109 .44404 L .8655 .45017 L F
.85478 .45342 m .85034 .44731 L .86109 .44404 L F
.65877 .45334 m .66404 .44396 L .66913 .45009 L F
.65877 .45334 m .65364 .44723 L .66404 .44396 L F
.88062 .45302 m .88707 .44364 L .8914 .44977 L F
.88062 .45302 m .87627 .44691 L .88707 .44364 L F
.68457 .45294 m .68998 .44356 L .69498 .4497 L F
.68457 .45294 m .67953 .44683 L .68998 .44356 L F
.835 .685 .697 r
.40754 .53058 m .40175 .51907 L .41221 .50031 L F
.892 .807 .758 r
.41221 .50031 m .40618 .49575 L .41653 .48028 L F
.831 .718 .74 r
.40175 .51907 m .40618 .49575 L .41221 .50031 L F
.522 .426 .687 r
.55019 .44786 m .54458 .4242 L .55479 .42612 L F
.46 .541 .853 r
.54458 .4242 m .54925 .41571 L .55479 .42612 L F
.54458 .4242 m .53904 .41395 L .54925 .41571 L F
.921 .906 .791 r
.42684 .46464 m .42076 .46357 L .43105 .44948 L F
.904 .861 .788 r
.41653 .48028 m .42076 .46357 L .42684 .46464 L F
.77 .796 .874 r
.17362 .44936 m .17659 .43737 L .18348 .44248 L F
.17362 .44936 m .16673 .44408 L .17659 .43737 L F
.16 .413 .854 r
.30806 .46118 m .31113 .45704 L .31725 .46639 L F
.30806 .46118 m .30192 .45227 L .31113 .45704 L F
.656 .751 .92 r
.71038 .45255 m .71593 .44316 L .72085 .4493 L F
.71038 .45255 m .70544 .44644 L .71593 .44316 L F
.264 .419 .83 r
.32927 .48723 m .33261 .48111 L .33858 .49202 L F
.32927 .48723 m .3233 .47635 L .33261 .48111 L F
.656 .751 .92 r
.73621 .45215 m .74189 .44276 L .74672 .4489 L F
.73621 .45215 m .73135 .44604 L .74189 .44276 L F
.713 .764 .892 r
.13757 .46117 m .14026 .45028 L .1472 .45613 L F
.13757 .46117 m .13064 .45509 L .14026 .45028 L F
.656 .751 .92 r
.76204 .45176 m .76787 .44236 L .77261 .4485 L F
.76204 .45176 m .75727 .44564 L .76787 .44236 L F
.56584 .45168 m .57062 .44229 L .57605 .44843 L F
.56584 .45168 m .56039 .44556 L .57062 .44229 L F
.775 .802 .874 r
.18348 .44248 m .18649 .43049 L .19335 .43554 L F
.18348 .44248 m .17659 .43737 L .18649 .43049 L F
.689 .785 .924 r
.22949 .42288 m .23248 .41338 L .2391 .41923 L F
.22949 .42288 m .2228 .41747 L .23248 .41338 L F
.656 .751 .92 r
.78789 .45136 m .79385 .44196 L .7985 .44811 L F
.78789 .45136 m .78321 .44524 L .79385 .44196 L F
.864 .91 .861 r
.46164 .41283 m .46591 .40064 L .47174 .40391 L F
.46164 .41283 m .45574 .4106 L .46591 .40064 L F
.892 .921 .834 r
.45149 .4236 m .45574 .4106 L .46164 .41283 L F
.656 .751 .92 r
.59165 .45128 m .59657 .44189 L .6019 .44803 L F
.59165 .45128 m .58629 .44516 L .59657 .44189 L F
.365 .603 .939 r
.27094 .43022 m .27384 .4247 L .2802 .43226 L F
.27094 .43022 m .26453 .42328 L .27384 .4247 L F
.822 .883 .889 r
.47174 .40391 m .47605 .39249 L .48182 .39697 L F
.47174 .40391 m .46591 .40064 L .47605 .39249 L F
.656 .751 .92 r
.81375 .45096 m .81985 .44156 L .82441 .44771 L F
.81375 .45096 m .80916 .44484 L .81985 .44156 L F
.698 .489 .601 r
.40162 .60437 m .40754 .53058 L .41298 .55226 L F
.40048 .60437 m .40754 .53058 L .40162 .60437 L F
.40048 .60437 m .39674 .55804 L .40754 .53058 L F
.753 .581 .664 r
.39674 .55804 m .40175 .51907 L .40754 .53058 L F
.656 .751 .92 r
.61746 .45089 m .62252 .44148 L .62777 .44763 L F
.61746 .45089 m .61219 .44476 L .62252 .44148 L F
.83962 .45057 m .84586 .44116 L .85034 .44731 L F
.83962 .45057 m .83512 .44444 L .84586 .44116 L F
.511 .696 .952 r
.25515 .42334 m .25807 .41637 L .26453 .42328 L F
.25515 .42334 m .24863 .41703 L .25807 .41637 L F
.656 .751 .92 r
.64329 .45049 m .64849 .44108 L .65364 .44723 L F
.64329 .45049 m .63811 .44436 L .64849 .44108 L F
.892 .921 .834 r
.45149 .4236 m .44553 .4221 L .45574 .4106 L F
.908 .918 .814 r
.44129 .43596 m .44553 .4221 L .45149 .4236 L F
.234 .501 .902 r
.28651 .43996 m .28944 .43548 L .29571 .44374 L F
.28651 .43996 m .2802 .43226 L .28944 .43548 L F
.656 .751 .92 r
.8655 .45017 m .87188 .44076 L .87627 .44691 L F
.8655 .45017 m .86109 .44404 L .87188 .44076 L F
.773 .805 .879 r
.19335 .43554 m .19639 .42375 L .20322 .42884 L F
.19335 .43554 m .18649 .43049 L .19639 .42375 L F
.489 .615 .903 r
.52334 .40343 m .5279 .39579 L .53349 .40468 L F
.52334 .40343 m .51774 .3953 L .5279 .39579 L F
.656 .751 .92 r
.66913 .45009 m .67447 .44068 L .67953 .44683 L F
.66913 .45009 m .66404 .44396 L .67447 .44068 L F
.579 .697 .923 r
.50764 .3958 m .51211 .38732 L .51774 .3953 L F
.50764 .3958 m .50199 .38886 L .51211 .38732 L F
.764 .838 .909 r
.48182 .39697 m .48618 .38626 L .4919 .392 L F
.48182 .39697 m .47605 .39249 L .48618 .38626 L F
.656 .751 .92 r
.8914 .44977 m .89792 .44036 L .90221 .44651 L F
.8914 .44977 m .88707 .44364 L .89792 .44036 L F
.69498 .4497 m .70046 .44028 L .70544 .44644 L F
.69498 .4497 m .68998 .44356 L .70046 .44028 L F
.735 .775 .885 r
.1472 .45613 m .14998 .44478 L .15692 .4504 L F
.1472 .45613 m .14026 .45028 L .14998 .44478 L F
.522 .426 .687 r
.55019 .44786 m .55479 .42612 L .56039 .44535 L F
.904 .861 .788 r
.41653 .48028 m .41044 .47757 L .42076 .46357 L F
.868 .803 .784 r
.40618 .49575 m .41044 .47757 L .41653 .48028 L F
.656 .751 .92 r
.72085 .4493 m .72646 .43988 L .73135 .44604 L F
.72085 .4493 m .71593 .44316 L .72646 .43988 L F
.526 .459 .724 r
.3557 .53772 m .35019 .51889 L .35981 .5199 L F
.477 .475 .776 r
.35019 .51889 m .35401 .50638 L .35981 .5199 L F
.35019 .51889 m .34446 .50431 L .35401 .50638 L F
.656 .751 .92 r
.74672 .4489 m .75247 .43948 L .75727 .44564 L F
.74672 .4489 m .74189 .44276 L .75247 .43948 L F
.229 .423 .845 r
.3233 .47635 m .32656 .47107 L .33261 .48111 L F
.3233 .47635 m .31725 .46639 L .32656 .47107 L F
.532 .359 .592 r
.35393 .61026 m .3512 .56355 L .36077 .56572 L F
.475 .315 .584 r
.34598 .61427 m .3512 .56355 L .35393 .61026 L F
.34598 .61427 m .34542 .6137 L .3512 .56355 L F
.491 .378 .652 r
.3512 .56355 m .3557 .53772 L .36077 .56572 L F
.458 .566 .876 r
.53904 .41395 m .5437 .40613 L .54925 .41571 L F
.53904 .41395 m .53349 .40468 L .5437 .40613 L F
.908 .918 .814 r
.44129 .43596 m .43527 .43476 L .44553 .4221 L F
.912 .905 .803 r
.43105 .44948 m .43527 .43476 L .44129 .43596 L F
.761 .804 .887 r
.20322 .42884 m .20626 .41746 L .21304 .42271 L F
.20322 .42884 m .19639 .42375 L .20626 .41746 L F
.543 .322 .53 r
.41132 .6021 m .41298 .55226 L .41132 .6021 L F
.40239 .60478 m .41298 .55226 L .41132 .6021 L F
.698 .489 .601 r
.40162 .60437 m .41298 .55226 L .40239 .60478 L F
.656 .751 .92 r
.77261 .4485 m .7785 .43908 L .78321 .44524 L F
.77261 .4485 m .76787 .44236 L .7785 .43908 L F
.57605 .44843 m .58089 .439 L .58629 .44516 L F
.57605 .44843 m .57062 .44229 L .58089 .439 L F
.563 .434 .663 r
.36077 .56572 m .3557 .53772 L .36543 .53688 L F
.526 .459 .724 r
.3557 .53772 m .35981 .5199 L .36543 .53688 L F
.627 .755 .939 r
.2391 .41923 m .24206 .41068 L .24863 .41703 L F
.2391 .41923 m .23248 .41338 L .24206 .41068 L F
.656 .751 .92 r
.7985 .44811 m .80454 .43868 L .80916 .44484 L F
.7985 .44811 m .79385 .44196 L .80454 .43868 L F
.171 .434 .868 r
.30192 .45227 m .30495 .44812 L .31113 .45704 L F
.30192 .45227 m .29571 .44374 L .30495 .44812 L F
.656 .751 .92 r
.6019 .44803 m .60688 .4386 L .61219 .44476 L F
.6019 .44803 m .59657 .44189 L .60688 .4386 L F
.753 .581 .664 r
.39674 .55804 m .3913 .53645 L .40175 .51907 L F
.831 .718 .74 r
.40175 .51907 m .39584 .51011 L .40618 .49575 L F
.763 .633 .717 r
.3913 .53645 m .39584 .51011 L .40175 .51907 L F
.752 .785 .879 r
.15692 .4504 m .15979 .43866 L .16673 .44408 L F
.15692 .4504 m .14998 .44478 L .15979 .43866 L F
.656 .751 .92 r
.82441 .44771 m .83058 .43827 L .83512 .44444 L F
.82441 .44771 m .81985 .44156 L .83058 .43827 L F
.62777 .44763 m .63289 .43819 L .63811 .44436 L F
.62777 .44763 m .62252 .44148 L .63289 .43819 L F
.422 .481 .816 r
.34446 .50431 m .34809 .49478 L .35401 .50638 L F
.34446 .50431 m .33858 .49202 L .34809 .49478 L F
.695 .78 .917 r
.4919 .392 m .4963 .38194 L .50199 .38886 L F
.4919 .392 m .48618 .38626 L .4963 .38194 L F
.656 .751 .92 r
.85034 .44731 m .85664 .43787 L .86109 .44404 L F
.85034 .44731 m .84586 .44116 L .85664 .43787 L F
.65364 .44723 m .65891 .43779 L .66404 .44396 L F
.65364 .44723 m .64849 .44108 L .65891 .43779 L F
.739 .798 .9 r
.21304 .42271 m .21607 .41193 L .2228 .41747 L F
.21304 .42271 m .20626 .41746 L .21607 .41193 L F
.656 .751 .92 r
.87627 .44691 m .88272 .43747 L .88707 .44364 L F
.87627 .44691 m .87188 .44076 L .88272 .43747 L F
.67953 .44683 m .68494 .43739 L .68998 .44356 L F
.67953 .44683 m .67447 .44068 L .68494 .43739 L F
.536 .463 .72 r
.56039 .44535 m .55479 .42612 L .56505 .427 L F
.486 .552 .849 r
.55479 .42612 m .55953 .41694 L .56505 .427 L F
.55479 .42612 m .54925 .41571 L .55953 .41694 L F
.912 .905 .803 r
.43105 .44948 m .42497 .44806 L .43527 .43476 L F
.905 .882 .801 r
.42076 .46357 m .42497 .44806 L .43105 .44948 L F
.656 .751 .92 r
.70544 .44644 m .71098 .43699 L .71593 .44316 L F
.70544 .44644 m .70046 .44028 L .71098 .43699 L F
.765 .792 .875 r
.16673 .44408 m .16967 .43209 L .17659 .43737 L F
.16673 .44408 m .15979 .43866 L .16967 .43209 L F
.656 .751 .92 r
.73135 .44604 m .73703 .43658 L .74189 .44276 L F
.73135 .44604 m .72646 .43988 L .73703 .43658 L F
.868 .803 .784 r
.40618 .49575 m .40013 .49069 L .41044 .47757 L F
.816 .735 .775 r
.39584 .51011 m .40013 .49069 L .40618 .49575 L F
.705 .762 .897 r
.13064 .45509 m .13328 .44436 L .14026 .45028 L F
.13064 .45509 m .12367 .44896 L .13328 .44436 L F
.536 .463 .72 r
.56039 .44535 m .56505 .427 L .57062 .44224 L F
.656 .751 .92 r
.75727 .44564 m .76309 .43618 L .76787 .44236 L F
.75727 .44564 m .75247 .43948 L .76309 .43618 L F
.409 .628 .943 r
.26453 .42328 m .26744 .41724 L .27384 .4247 L F
.26453 .42328 m .25807 .41637 L .26744 .41724 L F
.656 .751 .92 r
.78321 .44524 m .78917 .43578 L .79385 .44196 L F
.78321 .44524 m .7785 .43908 L .78917 .43578 L F
.58629 .44516 m .59119 .4357 L .59657 .44189 L F
.58629 .44516 m .58089 .439 L .59119 .4357 L F
.273 .531 .914 r
.2802 .43226 m .28313 .42741 L .28944 .43548 L F
.2802 .43226 m .27384 .4247 L .28313 .42741 L F
.524 .639 .905 r
.51774 .3953 m .52228 .38706 L .5279 .39579 L F
.51774 .3953 m .51211 .38732 L .52228 .38706 L F
.369 .481 .842 r
.33858 .49202 m .34209 .48432 L .34809 .49478 L F
.33858 .49202 m .33261 .48111 L .34209 .48432 L F
.205 .428 .856 r
.31725 .46639 m .32044 .46161 L .32656 .47107 L F
.31725 .46639 m .31113 .45704 L .32044 .46161 L F
.656 .751 .92 r
.80916 .44484 m .81526 .43537 L .81985 .44156 L F
.80916 .44484 m .80454 .43868 L .81526 .43537 L F
.702 .784 .915 r
.2228 .41747 m .2258 .40746 L .23248 .41338 L F
.2228 .41747 m .21607 .41193 L .2258 .40746 L F
.656 .751 .92 r
.61219 .44476 m .61724 .4353 L .62252 .44148 L F
.61219 .44476 m .60688 .4386 L .61724 .4353 L F
.772 .798 .874 r
.17659 .43737 m .17959 .42528 L .18649 .43049 L F
.17659 .43737 m .16967 .43209 L .17959 .42528 L F
.656 .751 .92 r
.83512 .44444 m .84136 .43497 L .84586 .44116 L F
.83512 .44444 m .83058 .43827 L .84136 .43497 L F
.545 .71 .947 r
.24863 .41703 m .25156 .40949 L .25807 .41637 L F
.24863 .41703 m .24206 .41068 L .25156 .40949 L F
.656 .751 .92 r
.63811 .44436 m .6433 .43489 L .64849 .44108 L F
.63811 .44436 m .63289 .43819 L .6433 .43489 L F
.469 .583 .886 r
.53349 .40468 m .53812 .39687 L .5437 .40613 L F
.53349 .40468 m .5279 .39579 L .53812 .39687 L F
.624 .717 .913 r
.50199 .38886 m .50645 .37939 L .51211 .38732 L F
.50199 .38886 m .4963 .38194 L .50645 .37939 L F
.656 .751 .92 r
.86109 .44404 m .86747 .43457 L .87188 .44076 L F
.86109 .44404 m .85664 .43787 L .86747 .43457 L F
.66404 .44396 m .66936 .43449 L .67447 .44068 L F
.66404 .44396 m .65891 .43779 L .66936 .43449 L F
.629 .492 .677 r
.37071 .56119 m .36543 .53688 L .3754 .53157 L F
.563 .434 .663 r
.36077 .56572 m .36543 .53688 L .37071 .56119 L F
.607 .524 .735 r
.36543 .53688 m .36965 .51729 L .3754 .53157 L F
.36543 .53688 m .35981 .5199 L .36965 .51729 L F
.905 .882 .801 r
.42076 .46357 m .41465 .46137 L .42497 .44806 L F
.884 .847 .803 r
.41044 .47757 m .41465 .46137 L .42076 .46357 L F
.571 .543 .785 r
.35981 .5199 m .36377 .50548 L .36965 .51729 L F
.35981 .5199 m .35401 .50638 L .36377 .50548 L F
.656 .751 .92 r
.88707 .44364 m .89359 .43416 L .89792 .44036 L F
.88707 .44364 m .88272 .43747 L .89359 .43416 L F
.68998 .44356 m .69544 .43408 L .70046 .44028 L F
.68998 .44356 m .68494 .43739 L .69544 .43408 L F
.685 .505 .637 r
.3859 .58394 m .3913 .53645 L .39674 .55804 L F
.3859 .58394 m .38092 .55098 L .3913 .53645 L F
.763 .633 .717 r
.3913 .53645 m .38556 .52237 L .39584 .51011 L F
.695 .558 .696 r
.38092 .55098 m .38556 .52237 L .3913 .53645 L F
.772 .801 .877 r
.18649 .43049 m .18952 .41851 L .19639 .42375 L F
.18649 .43049 m .17959 .42528 L .18952 .41851 L F
.728 .773 .889 r
.14026 .45028 m .143 .43906 L .14998 .44478 L F
.14026 .45028 m .13328 .44436 L .143 .43906 L F
.841 .869 .864 r
.46591 .40064 m .47023 .38781 L .47605 .39249 L F
.46591 .40064 m .46004 .39704 L .47023 .38781 L F
.874 .889 .841 r
.45574 .4106 m .46004 .39704 L .46591 .40064 L F
.816 .735 .775 r
.39584 .51011 m .38986 .50216 L .40013 .49069 L F
.752 .663 .763 r
.38556 .52237 m .38986 .50216 L .39584 .51011 L F
.188 .455 .879 r
.29571 .44374 m .29871 .43948 L .30495 .44812 L F
.29571 .44374 m .28944 .43548 L .29871 .43948 L F
.656 .751 .92 r
.71593 .44316 m .72153 .43368 L .72646 .43988 L F
.71593 .44316 m .71098 .43699 L .72153 .43368 L F
.874 .889 .841 r
.45574 .4106 m .4498 .40788 L .46004 .39704 L F
.895 .898 .822 r
.44553 .4221 m .4498 .40788 L .45574 .4106 L F
.581 .4 .602 r
.36377 .60719 m .36077 .56572 L .37071 .56119 L F
.532 .359 .592 r
.35615 .60942 m .36077 .56572 L .36377 .60719 L F
.35393 .61026 m .36077 .56572 L .35615 .60942 L F
.469 .564 .869 r
.54925 .41571 m .55398 .40747 L .55953 .41694 L F
.54925 .41571 m .5437 .40613 L .55398 .40747 L F
.656 .751 .92 r
.74189 .44276 m .74764 .43328 L .75247 .43948 L F
.74189 .44276 m .73703 .43658 L .74764 .43328 L F
.792 .834 .884 r
.47605 .39249 m .48041 .38043 L .48618 .38626 L F
.47605 .39249 m .47023 .38781 L .48041 .38043 L F
.656 .751 .92 r
.76787 .44236 m .77375 .43287 L .7785 .43908 L F
.76787 .44236 m .76309 .43618 L .77375 .43287 L F
.555 .512 .762 r
.57062 .44224 m .57536 .42689 L .58089 .43899 L F
.57062 .44224 m .56505 .427 L .57536 .42689 L F
.763 .801 .883 r
.19639 .42375 m .19943 .41206 L .20626 .41746 L F
.19639 .42375 m .18952 .41851 L .19943 .41206 L F
.656 .751 .92 r
.79385 .44196 m .79988 .43247 L .80454 .43868 L F
.79385 .44196 m .78917 .43578 L .79988 .43247 L F
.648 .759 .931 r
.23248 .41338 m .23545 .4043 L .24206 .41068 L F
.23248 .41338 m .2258 .40746 L .23545 .4043 L F
.656 .751 .92 r
.59657 .44189 m .60154 .43239 L .60688 .4386 L F
.59657 .44189 m .59119 .4357 L .60154 .43239 L F
.695 .558 .696 r
.38092 .55098 m .3754 .53157 L .38556 .52237 L F
.629 .492 .677 r
.37071 .56119 m .3754 .53157 L .38092 .55098 L F
.682 .592 .749 r
.3754 .53157 m .37968 .51123 L .38556 .52237 L F
.3754 .53157 m .36965 .51729 L .37968 .51123 L F
.895 .898 .822 r
.44553 .4221 m .43952 .41996 L .4498 .40788 L F
.904 .896 .81 r
.43527 .43476 m .43952 .41996 L .44553 .4221 L F
.752 .663 .763 r
.38556 .52237 m .37968 .51123 L .38986 .50216 L F
.656 .751 .92 r
.81985 .44156 m .82602 .43206 L .83058 .43827 L F
.81985 .44156 m .81526 .43537 L .82602 .43206 L F
.525 .551 .825 r
.35401 .50638 m .35779 .49506 L .36377 .50548 L F
.35401 .50638 m .34809 .49478 L .35779 .49506 L F
.656 .751 .92 r
.62252 .44148 m .62763 .43198 L .63289 .43819 L F
.62252 .44148 m .61724 .4353 L .62763 .43198 L F
.884 .847 .803 r
.41044 .47757 m .40432 .47404 L .41465 .46137 L F
.847 .801 .806 r
.40013 .49069 m .40432 .47404 L .41044 .47757 L F
.64 .427 .578 r
.39369 .60274 m .39674 .55804 L .40048 .60437 L F
.38645 .60367 m .39674 .55804 L .39369 .60274 L F
.38645 .60367 m .3859 .58394 L .39674 .55804 L F
.321 .476 .859 r
.33261 .48111 m .33601 .4746 L .34209 .48432 L F
.33261 .48111 m .32656 .47107 L .33601 .4746 L F
.747 .782 .882 r
.14998 .44478 m .15281 .43313 L .15979 .43866 L F
.14998 .44478 m .143 .43906 L .15281 .43313 L F
.656 .751 .92 r
.84586 .44116 m .85217 .43166 L .85664 .43787 L F
.84586 .44116 m .84136 .43497 L .85217 .43166 L F
.64849 .44108 m .65374 .43158 L .65891 .43779 L F
.64849 .44108 m .6433 .43489 L .65374 .43158 L F
.512 .575 .856 r
.56505 .427 m .56986 .4175 L .57536 .42689 L F
.56505 .427 m .55953 .41694 L .56986 .4175 L F
.731 .787 .897 r
.48618 .38626 m .49058 .375 L .4963 .38194 L F
.48618 .38626 m .48041 .38043 L .49058 .375 L F
.63 .447 .617 r
.37515 .60547 m .38092 .55098 L .3859 .58394 L F
.37514 .60547 m .38092 .55098 L .37515 .60547 L F
.37514 .60547 m .37071 .56119 L .38092 .55098 L F
.656 .751 .92 r
.87188 .44076 m .87833 .43125 L .88272 .43747 L F
.87188 .44076 m .86747 .43457 L .87833 .43125 L F
.67447 .44068 m .67986 .43117 L .68494 .43739 L F
.67447 .44068 m .66936 .43449 L .67986 .43117 L F
.492 .294 .539 r
.33642 .61819 m .34542 .6137 L .34537 .61448 L F
.189 .433 .863 r
.31113 .45704 m .31426 .45256 L .32044 .46161 L F
.31113 .45704 m .30495 .44812 L .31426 .45256 L F
.745 .796 .893 r
.20626 .41746 m .20929 .40628 L .21607 .41193 L F
.20626 .41746 m .19943 .41206 L .20929 .40628 L F
.581 .4 .602 r
.36602 .60656 m .37071 .56119 L .37514 .60547 L F
.36377 .60719 m .37071 .56119 L .36602 .60656 L F
.656 .751 .92 r
.70046 .44028 m .70599 .43077 L .71098 .43699 L F
.70046 .44028 m .69544 .43408 L .70599 .43077 L F
.655 .612 .794 r
.36965 .51729 m .37372 .50154 L .37968 .51123 L F
.36965 .51729 m .36377 .50548 L .37372 .50154 L F
.904 .896 .81 r
.43527 .43476 m .4292 .43281 L .43952 .41996 L F
.903 .886 .806 r
.42497 .44806 m .4292 .43281 L .43527 .43476 L F
.656 .751 .92 r
.72646 .43988 m .73213 .43036 L .73703 .43658 L F
.72646 .43988 m .72153 .43368 L .73213 .43036 L F
.559 .658 .903 r
.51211 .38732 m .51664 .37839 L .52228 .38706 L F
.51211 .38732 m .50645 .37939 L .51664 .37839 L F
.447 .649 .945 r
.25807 .41637 m .26098 .40984 L .26744 .41724 L F
.25807 .41637 m .25156 .40949 L .26098 .40984 L F
.699 .761 .9 r
.12367 .44896 m .12625 .43837 L .13328 .44436 L F
.12367 .44896 m .11664 .44279 L .12625 .43837 L F
.486 .598 .89 r
.5279 .39579 m .53251 .38773 L .53812 .39687 L F
.5279 .39579 m .52228 .38706 L .53251 .38773 L F
.309 .556 .923 r
.27384 .4247 m .27676 .41947 L .28313 .42741 L F
.27384 .4247 m .26744 .41724 L .27676 .41947 L F
.761 .79 .877 r
.15979 .43866 m .1627 .42669 L .16967 .43209 L F
.15979 .43866 m .15281 .43313 L .1627 .42669 L F
.656 .751 .92 r
.75247 .43948 m .75829 .42996 L .76309 .43618 L F
.75247 .43948 m .74764 .43328 L .75829 .42996 L F
.847 .801 .806 r
.40013 .49069 m .39404 .48536 L .40432 .47404 L F
.795 .744 .806 r
.38986 .50216 m .39404 .48536 L .40013 .49069 L F
.656 .751 .92 r
.7785 .43908 m .78445 .42955 L .78917 .43578 L F
.7785 .43908 m .77375 .43287 L .78445 .42955 L F
.576 .568 .807 r
.58089 .43899 m .58572 .42592 L .59119 .4357 L F
.58089 .43899 m .57536 .42689 L .58572 .42592 L F
.656 .751 .92 r
.80454 .43868 m .81063 .42914 L .81526 .43537 L F
.80454 .43868 m .79988 .43247 L .81063 .42914 L F
.60688 .4386 m .61192 .42906 L .61724 .4353 L F
.60688 .4386 m .60154 .43239 L .61192 .42906 L F
.462 .57 .878 r
.5437 .40613 m .54841 .3982 L .55398 .40747 L F
.5437 .40613 m .53812 .39687 L .54841 .3982 L F
.475 .55 .854 r
.34809 .49478 m .35174 .48548 L .35779 .49506 L F
.34809 .49478 m .34209 .48432 L .35174 .48548 L F
.73 .68 .802 r
.37968 .51123 m .38382 .4947 L .38986 .50216 L F
.37968 .51123 m .37372 .50154 L .38382 .4947 L F
.574 .72 .942 r
.24206 .41068 m .24501 .40261 L .25156 .40949 L F
.24206 .41068 m .23545 .4043 L .24501 .40261 L F
.656 .751 .92 r
.83058 .43827 m .83682 .42874 L .84136 .43497 L F
.83058 .43827 m .82602 .43206 L .83682 .42874 L F
.713 .784 .907 r
.21607 .41193 m .21909 .40146 L .2258 .40746 L F
.21607 .41193 m .20929 .40628 L .21909 .40146 L F
.795 .744 .806 r
.38986 .50216 m .38382 .4947 L .39404 .48536 L F
.662 .731 .901 r
.4963 .38194 m .50075 .37148 L .50645 .37939 L F
.4963 .38194 m .49058 .375 L .50075 .37148 L F
.656 .751 .92 r
.63289 .43819 m .63807 .42866 L .6433 .43489 L F
.63289 .43819 m .62763 .43198 L .63807 .42866 L F
.207 .475 .889 r
.28944 .43548 m .29241 .43106 L .29871 .43948 L F
.28944 .43548 m .28313 .42741 L .29241 .43106 L F
.769 .795 .874 r
.16967 .43209 m .17264 .41994 L .17959 .42528 L F
.16967 .43209 m .1627 .42669 L .17264 .41994 L F
.656 .751 .92 r
.85664 .43787 m .86302 .42833 L .86747 .43457 L F
.85664 .43787 m .85217 .43166 L .86302 .42833 L F
.65891 .43779 m .66422 .42825 L .66936 .43449 L F
.65891 .43779 m .65374 .43158 L .66422 .42825 L F
.903 .886 .806 r
.42497 .44806 m .41886 .44586 L .4292 .43281 L F
.891 .868 .809 r
.41465 .46137 m .41886 .44586 L .42497 .44806 L F
.656 .751 .92 r
.88272 .43747 m .88924 .42792 L .89359 .43416 L F
.88272 .43747 m .87833 .43125 L .88924 .42792 L F
.68494 .43739 m .69039 .42784 L .69544 .43408 L F
.68494 .43739 m .67986 .43117 L .69039 .42784 L F
.278 .469 .868 r
.32656 .47107 m .32988 .46537 L .33601 .4746 L F
.32656 .47107 m .32044 .46161 L .32988 .46537 L F
.721 .771 .892 r
.13328 .44436 m .13597 .43325 L .143 .43906 L F
.13328 .44436 m .12625 .43837 L .13597 .43325 L F
.618 .621 .832 r
.36377 .50548 m .36768 .49265 L .37372 .50154 L F
.36377 .50548 m .35779 .49506 L .36768 .49265 L F
.485 .576 .872 r
.55953 .41694 m .56433 .40844 L .56986 .4175 L F
.55953 .41694 m .55398 .40747 L .56433 .40844 L F
.656 .751 .92 r
.71098 .43699 m .71658 .42744 L .72153 .43368 L F
.71098 .43699 m .70599 .43077 L .71658 .42744 L F
.526 .32 .544 r
.34541 .61446 m .34542 .6137 L .34598 .61427 L F
.492 .294 .539 r
.34537 .61448 m .34542 .6137 L .34541 .61446 L F
.771 .798 .875 r
.17959 .42528 m .18261 .41313 L .18952 .41851 L F
.17959 .42528 m .17264 .41994 L .18261 .41313 L F
.656 .751 .92 r
.73703 .43658 m .74277 .42703 L .74764 .43328 L F
.73703 .43658 m .73213 .43036 L .74277 .42703 L F
.76309 .43618 m .76897 .42662 L .77375 .43287 L F
.76309 .43618 m .75829 .42996 L .76897 .42662 L F
.537 .604 .869 r
.57536 .42689 m .58024 .41734 L .58572 .42592 L F
.57536 .42689 m .56986 .4175 L .58024 .41734 L F
.656 .751 .92 r
.78917 .43578 m .79519 .42622 L .79988 .43247 L F
.78917 .43578 m .78445 .42955 L .79519 .42622 L F
.181 .439 .869 r
.30495 .44812 m .30803 .44379 L .31426 .45256 L F
.30495 .44812 m .29871 .43948 L .30803 .44379 L F
.597 .624 .849 r
.59119 .4357 m .59611 .42423 L .60154 .43239 L F
.59119 .4357 m .58572 .42592 L .59611 .42423 L F
.854 .859 .844 r
.46004 .39704 m .46437 .38299 L .47023 .38781 L F
.46004 .39704 m .45411 .3932 L .46437 .38299 L F
.881 .875 .826 r
.4498 .40788 m .45411 .3932 L .46004 .39704 L F
.891 .868 .809 r
.41465 .46137 m .40851 .45846 L .41886 .44586 L F
.866 .839 .817 r
.40432 .47404 m .40851 .45846 L .41465 .46137 L F
.814 .831 .863 r
.47023 .38781 m .4746 .37454 L .48041 .38043 L F
.47023 .38781 m .46437 .38299 L .4746 .37454 L F
.666 .763 .923 r
.2258 .40746 m .22879 .39787 L .23545 .4043 L F
.2258 .40746 m .21909 .40146 L .22879 .39787 L F
.656 .751 .92 r
.81526 .43537 m .82142 .42581 L .82602 .43206 L F
.81526 .43537 m .81063 .42914 L .82142 .42581 L F
.61724 .4353 m .62234 .42573 L .62763 .43198 L F
.61724 .4353 m .61192 .42906 L .62234 .42573 L F
.765 .798 .879 r
.18952 .41851 m .19256 .40656 L .19943 .41206 L F
.18952 .41851 m .18261 .41313 L .19256 .40656 L F
.656 .751 .92 r
.84136 .43497 m .84766 .4254 L .85217 .43166 L F
.84136 .43497 m .83682 .42874 L .84766 .4254 L F
.6433 .43489 m .64854 .42532 L .65374 .43158 L F
.6433 .43489 m .63807 .42866 L .64854 .42532 L F
.741 .78 .885 r
.143 .43906 m .14579 .42748 L .15281 .43313 L F
.143 .43906 m .13597 .43325 L .14579 .42748 L F
.881 .875 .826 r
.4498 .40788 m .44381 .40482 L .45411 .3932 L F
.896 .883 .813 r
.43952 .41996 m .44381 .40482 L .4498 .40788 L F
.506 .611 .891 r
.52228 .38706 m .52688 .37861 L .53251 .38773 L F
.52228 .38706 m .51664 .37839 L .52688 .37861 L F
.423 .543 .873 r
.34209 .48432 m .34563 .47645 L .35174 .48548 L F
.34209 .48432 m .33601 .4746 L .34563 .47645 L F
.656 .751 .92 r
.86747 .43457 m .87392 .42499 L .87833 .43125 L F
.86747 .43457 m .86302 .42833 L .87392 .42499 L F
.66936 .43449 m .67475 .42491 L .67986 .43117 L F
.66936 .43449 m .66422 .42825 L .67475 .42491 L F
.76 .792 .879 r
.48041 .38043 m .48481 .36803 L .49058 .375 L F
.48041 .38043 m .4746 .37454 L .48481 .36803 L F
.592 .674 .898 r
.50645 .37939 m .51096 .36971 L .51664 .37839 L F
.50645 .37939 m .50075 .37148 L .51096 .36971 L F
.701 .688 .834 r
.37372 .50154 m .37773 .48752 L .38382 .4947 L F
.37372 .50154 m .36768 .49265 L .37773 .48752 L F
.656 .751 .92 r
.69544 .43408 m .70097 .4245 L .70599 .43077 L F
.69544 .43408 m .69039 .42784 L .70097 .4245 L F
.343 .579 .929 r
.26744 .41724 m .27034 .41162 L .27676 .41947 L F
.26744 .41724 m .26098 .40984 L .27034 .41162 L F
.462 .575 .882 r
.53812 .39687 m .54281 .38898 L .54841 .3982 L F
.53812 .39687 m .53251 .38773 L .54281 .38898 L F
.866 .839 .817 r
.40432 .47404 m .39818 .46999 L .40851 .45846 L F
.826 .799 .826 r
.39404 .48536 m .39818 .46999 L .40432 .47404 L F
.48 .666 .944 r
.25156 .40949 m .25448 .40248 L .26098 .40984 L F
.25156 .40949 m .24501 .40261 L .25448 .40248 L F
.656 .751 .92 r
.72153 .43368 m .7272 .4241 L .73213 .43036 L F
.72153 .43368 m .71658 .42744 L .7272 .4241 L F
.75 .794 .888 r
.19943 .41206 m .20247 .40054 L .20929 .40628 L F
.19943 .41206 m .19256 .40656 L .20247 .40054 L F
.692 .76 .904 r
.11664 .44279 m .11917 .43231 L .12625 .43837 L F
.11664 .44279 m .10956 .43658 L .11917 .43231 L F
.896 .883 .813 r
.43952 .41996 m .43347 .41739 L .44381 .40482 L F
.9 .882 .807 r
.4292 .43281 m .43347 .41739 L .43952 .41996 L F
.656 .751 .92 r
.74764 .43328 m .75345 .42369 L .75829 .42996 L F
.74764 .43328 m .74277 .42703 L .75345 .42369 L F
.575 .622 .861 r
.35779 .49506 m .36158 .48427 L .36768 .49265 L F
.35779 .49506 m .35174 .48548 L .36158 .48427 L F
.228 .494 .898 r
.28313 .42741 m .28607 .42279 L .29241 .43106 L F
.28313 .42741 m .27676 .41947 L .28607 .42279 L F
.756 .787 .878 r
.15281 .43313 m .15569 .42116 L .1627 .42669 L F
.15281 .43313 m .14579 .42748 L .15569 .42116 L F
.243 .462 .872 r
.32044 .46161 m .32369 .45649 L .32988 .46537 L F
.32044 .46161 m .31426 .45256 L .32369 .45649 L F
.656 .751 .92 r
.77375 .43287 m .7797 .42328 L .78445 .42955 L F
.77375 .43287 m .76897 .42662 L .7797 .42328 L F
.771 .748 .832 r
.38382 .4947 m .3879 .47985 L .39404 .48536 L F
.38382 .4947 m .37773 .48752 L .3879 .47985 L F
.826 .799 .826 r
.39404 .48536 m .3879 .47985 L .39818 .46999 L F
.602 .388 .564 r
.38466 .60355 m .3859 .58394 L .38645 .60367 L F
.37516 .60547 m .3859 .58394 L .38466 .60355 L F
.63 .447 .617 r
.37515 .60547 m .3859 .58394 L .37516 .60547 L F
.466 .573 .878 r
.55398 .40747 m .55877 .39945 L .56433 .40844 L F
.55398 .40747 m .54841 .3982 L .55877 .39945 L F
.656 .751 .92 r
.79988 .43247 m .80597 .42287 L .81063 .42914 L F
.79988 .43247 m .79519 .42622 L .80597 .42287 L F
.616 .675 .883 r
.60154 .43239 m .60654 .42197 L .61192 .42906 L F
.60154 .43239 m .59611 .42423 L .60654 .42197 L F
.694 .742 .888 r
.49058 .375 m .49502 .36354 L .50075 .37148 L F
.49058 .375 m .48481 .36803 L .49502 .36354 L F
.598 .729 .936 r
.23545 .4043 m .2384 .39573 L .24501 .40261 L F
.23545 .4043 m .22879 .39787 L .2384 .39573 L F
.656 .751 .92 r
.82602 .43206 m .83225 .42246 L .83682 .42874 L F
.82602 .43206 m .82142 .42581 L .83225 .42246 L F
.62763 .43198 m .6328 .42238 L .63807 .42866 L F
.62763 .43198 m .62234 .42573 L .6328 .42238 L F
.723 .784 .901 r
.20929 .40628 m .21232 .39539 L .21909 .40146 L F
.20929 .40628 m .20247 .40054 L .21232 .39539 L F
.656 .751 .92 r
.85217 .43166 m .85855 .42205 L .86302 .42833 L F
.85217 .43166 m .84766 .4254 L .85855 .42205 L F
.65374 .43158 m .65905 .42197 L .66422 .42825 L F
.65374 .43158 m .64854 .42532 L .65905 .42197 L F
.505 .598 .881 r
.56986 .4175 m .57473 .40887 L .58024 .41734 L F
.56986 .4175 m .56433 .40844 L .57473 .40887 L F
.561 .639 .885 r
.58572 .42592 m .59067 .41645 L .59611 .42423 L F
.58572 .42592 m .58024 .41734 L .59067 .41645 L F
.9 .882 .807 r
.4292 .43281 m .4231 .43036 L .43347 .41739 L F
.895 .874 .809 r
.41886 .44586 m .4231 .43036 L .4292 .43281 L F
.766 .793 .874 r
.1627 .42669 m .16566 .41447 L .17264 .41994 L F
.1627 .42669 m .15569 .42116 L .16566 .41447 L F
.656 .751 .92 r
.87833 .43125 m .88485 .42164 L .88924 .42792 L F
.87833 .43125 m .87392 .42499 L .88485 .42164 L F
.67986 .43117 m .68531 .42156 L .69039 .42784 L F
.67986 .43117 m .67475 .42491 L .68531 .42156 L F
.178 .446 .875 r
.29871 .43948 m .30174 .43523 L .30803 .44379 L F
.29871 .43948 m .29241 .43106 L .30174 .43523 L F
.656 .751 .92 r
.70599 .43077 m .71158 .42115 L .71658 .42744 L F
.70599 .43077 m .70097 .4245 L .71158 .42115 L F
.715 .77 .895 r
.12625 .43837 m .1289 .42736 L .13597 .43325 L F
.12625 .43837 m .11917 .43231 L .1289 .42736 L F
.656 .751 .92 r
.73213 .43036 m .73787 .42074 L .74277 .42703 L F
.73213 .43036 m .7272 .4241 L .73787 .42074 L F
.373 .531 .884 r
.33601 .4746 m .33947 .46777 L .34563 .47645 L F
.33601 .4746 m .32988 .46537 L .33947 .46777 L F
.656 .751 .92 r
.75829 .42996 m .76416 .42033 L .76897 .42662 L F
.75829 .42996 m .75345 .42369 L .76416 .42033 L F
.77 .795 .873 r
.17264 .41994 m .17565 .40764 L .18261 .41313 L F
.17264 .41994 m .16566 .41447 L .17565 .40764 L F
.528 .623 .89 r
.51664 .37839 m .52121 .36946 L .52688 .37861 L F
.51664 .37839 m .51096 .36971 L .52121 .36946 L F
.656 .751 .92 r
.78445 .42955 m .79047 .41992 L .79519 .42622 L F
.78445 .42955 m .7797 .42328 L .79047 .41992 L F
.667 .689 .862 r
.36768 .49265 m .37158 .4805 L .37773 .48752 L F
.36768 .49265 m .36158 .48427 L .37158 .4805 L F
.895 .874 .809 r
.41886 .44586 m .41271 .44313 L .4231 .43036 L F
.878 .859 .818 r
.40851 .45846 m .41271 .44313 L .41886 .44586 L F
.68 .766 .916 r
.21909 .40146 m .22209 .39141 L .22879 .39787 L F
.21909 .40146 m .21232 .39539 L .22209 .39141 L F
.656 .751 .92 r
.81063 .42914 m .81679 .41951 L .82142 .42581 L F
.81063 .42914 m .80597 .42287 L .81679 .41951 L F
.466 .579 .884 r
.53251 .38773 m .53718 .37972 L .54281 .38898 L F
.53251 .38773 m .52688 .37861 L .53718 .37972 L F
.63 .714 .907 r
.61192 .42906 m .61701 .41928 L .62234 .42573 L F
.61192 .42906 m .60654 .42197 L .61701 .41928 L F
.622 .688 .891 r
.50075 .37148 m .50525 .361 L .51096 .36971 L F
.50075 .37148 m .49502 .36354 L .50525 .361 L F
.528 .615 .882 r
.35174 .48548 m .35543 .4762 L .36158 .48427 L F
.35174 .48548 m .34563 .47645 L .35543 .4762 L F
.656 .751 .92 r
.83682 .42874 m .84312 .4191 L .84766 .4254 L F
.83682 .42874 m .83225 .42246 L .84312 .4191 L F
.63807 .42866 m .6433 .41902 L .64854 .42532 L F
.63807 .42866 m .6328 .42238 L .6433 .41902 L F
.767 .795 .876 r
.18261 .41313 m .18565 .40094 L .19256 .40656 L F
.18261 .41313 m .17565 .40764 L .18565 .40094 L F
.831 .828 .844 r
.46437 .38299 m .46875 .36858 L .4746 .37454 L F
.46437 .38299 m .45847 .37808 L .46875 .36858 L F
.865 .851 .827 r
.45411 .3932 m .45847 .37808 L .46437 .38299 L F
.375 .599 .934 r
.26098 .40984 m .26388 .40384 L .27034 .41162 L F
.26098 .40984 m .25448 .40248 L .26388 .40384 L F
.736 .779 .887 r
.13597 .43325 m .13872 .42174 L .14579 .42748 L F
.13597 .43325 m .1289 .42736 L .13872 .42174 L F
.656 .751 .92 r
.86302 .42833 m .86947 .41869 L .87392 .42499 L F
.86302 .42833 m .85855 .42205 L .86947 .41869 L F
.66422 .42825 m .6696 .41861 L .67475 .42491 L F
.66422 .42825 m .65905 .42197 L .6696 .41861 L F
.213 .455 .874 r
.31426 .45256 m .31744 .44786 L .32369 .45649 L F
.31426 .45256 m .30803 .44379 L .31744 .44786 L F
.865 .851 .827 r
.45411 .3932 m .44814 .3892 L .45847 .37808 L F
.886 .866 .813 r
.44381 .40482 m .44814 .3892 L .45411 .3932 L F
.784 .795 .861 r
.4746 .37454 m .47901 .36102 L .48481 .36803 L F
.4746 .37454 m .46875 .36858 L .47901 .36102 L F
.452 .568 .881 r
.54841 .3982 m .55318 .39044 L .55877 .39945 L F
.54841 .3982 m .54281 .38898 L .55318 .39044 L F
.51 .68 .942 r
.24501 .40261 m .24792 .39514 L .25448 .40248 L F
.24501 .40261 m .2384 .39573 L .24792 .39514 L F
.656 .751 .92 r
.69039 .42784 m .69591 .4182 L .70097 .4245 L F
.69039 .42784 m .68531 .42156 L .69591 .4182 L F
.25 .512 .906 r
.27676 .41947 m .27968 .41463 L .28607 .42279 L F
.27676 .41947 m .27034 .41162 L .27968 .41463 L F
.878 .859 .818 r
.40851 .45846 m .40233 .45508 L .41271 .44313 L F
.849 .833 .831 r
.39818 .46999 m .40233 .45508 L .40851 .45846 L F
.656 .751 .92 r
.71658 .42744 m .72224 .41778 L .7272 .4241 L F
.71658 .42744 m .71158 .42115 L .72224 .41778 L F
.686 .759 .907 r
.10956 .43658 m .11205 .4262 L .11917 .43231 L F
.10956 .43658 m .10244 .43032 L .11205 .4262 L F
.585 .674 .901 r
.59611 .42423 m .60113 .41491 L .60654 .42197 L F
.59611 .42423 m .59067 .41645 L .60113 .41491 L F
.744 .749 .856 r
.37773 .48752 m .38173 .4742 L .3879 .47985 L F
.37773 .48752 m .37158 .4805 L .38173 .4742 L F
.656 .751 .92 r
.74277 .42703 m .74857 .41737 L .75345 .42369 L F
.74277 .42703 m .73787 .42074 L .74857 .41737 L F
.754 .792 .883 r
.19256 .40656 m .19561 .39471 L .20247 .40054 L F
.19256 .40656 m .18565 .40094 L .19561 .39471 L F
.478 .588 .885 r
.56433 .40844 m .56919 .40038 L .57473 .40887 L F
.56433 .40844 m .55877 .39945 L .56919 .40038 L F
.886 .866 .813 r
.44381 .40482 m .43777 .40152 L .44814 .3892 L F
.896 .872 .805 r
.43347 .41739 m .43777 .40152 L .44381 .40482 L F
.656 .751 .92 r
.76897 .42662 m .77492 .41696 L .7797 .42328 L F
.76897 .42662 m .76416 .42033 L .77492 .41696 L F
.849 .833 .831 r
.39818 .46999 m .39199 .4656 L .40233 .45508 L F
.805 .797 .845 r
.3879 .47985 m .39199 .4656 L .39818 .46999 L F
.529 .628 .893 r
.58024 .41734 m .58519 .40866 L .59067 .41645 L F
.58024 .41734 m .57473 .40887 L .58519 .40866 L F
.753 .786 .88 r
.14579 .42748 m .14864 .41554 L .15569 .42116 L F
.14579 .42748 m .13872 .42174 L .14864 .41554 L F
.723 .751 .875 r
.48481 .36803 m .48925 .35556 L .49502 .36354 L F
.48481 .36803 m .47901 .36102 L .48925 .35556 L F
.805 .797 .845 r
.3879 .47985 m .38173 .4742 L .39199 .4656 L F
.656 .751 .92 r
.79519 .42622 m .80128 .41655 L .80597 .42287 L F
.79519 .42622 m .79047 .41992 L .80128 .41655 L F
.619 .736 .93 r
.22879 .39787 m .23175 .38883 L .2384 .39573 L F
.22879 .39787 m .22209 .39141 L .23175 .38883 L F
.179 .453 .879 r
.29241 .43106 m .29541 .42682 L .30174 .43523 L F
.29241 .43106 m .28607 .42279 L .29541 .42682 L F
.656 .751 .92 r
.82142 .42581 m .82765 .41614 L .83225 .42246 L F
.82142 .42581 m .81679 .41951 L .82765 .41614 L F
.325 .516 .89 r
.32988 .46537 m .33326 .45935 L .33947 .46777 L F
.32988 .46537 m .32369 .45649 L .33326 .45935 L F
.641 .741 .921 r
.62234 .42573 m .6275 .41627 L .6328 .42238 L F
.62234 .42573 m .61701 .41928 L .6275 .41627 L F
.656 .751 .92 r
.84766 .4254 m .85404 .41572 L .85855 .42205 L F
.84766 .4254 m .84312 .4191 L .85404 .41572 L F
.64854 .42532 m .65384 .41564 L .65905 .42197 L F
.64854 .42532 m .6433 .41902 L .65384 .41564 L F
.731 .783 .895 r
.20247 .40054 m .20551 .38926 L .21232 .39539 L F
.20247 .40054 m .19561 .39471 L .20551 .38926 L F
.896 .872 .805 r
.43347 .41739 m .42737 .4145 L .43777 .40152 L F
.897 .873 .805 r
.4231 .43036 m .42737 .4145 L .43347 .41739 L F
.656 .751 .92 r
.87392 .42499 m .88043 .41531 L .88485 .42164 L F
.87392 .42499 m .86947 .41869 L .88043 .41531 L F
.67475 .42491 m .68019 .41523 L .68531 .42156 L F
.67475 .42491 m .6696 .41861 L .68019 .41523 L F
.55 .635 .887 r
.51096 .36971 m .51551 .36023 L .52121 .36946 L F
.51096 .36971 m .50525 .361 L .51551 .36023 L F
.764 .791 .875 r
.15569 .42116 m .15862 .4089 L .16566 .41447 L F
.15569 .42116 m .14864 .41554 L .15862 .4089 L F
.656 .751 .92 r
.70097 .4245 m .70655 .41482 L .71158 .42115 L F
.70097 .4245 m .69591 .4182 L .70655 .41482 L F
.628 .685 .884 r
.36158 .48427 m .3654 .47356 L .37158 .4805 L F
.36158 .48427 m .35543 .4762 L .3654 .47356 L F
.71 .769 .898 r
.11917 .43231 m .12177 .4214 L .1289 .42736 L F
.11917 .43231 m .11205 .4262 L .12177 .4214 L F
.474 .584 .884 r
.52688 .37861 m .53153 .37039 L .53718 .37972 L F
.52688 .37861 m .52121 .36946 L .53153 .37039 L F
.479 .603 .897 r
.34563 .47645 m .34923 .46833 L .35543 .4762 L F
.34563 .47645 m .33947 .46777 L .34923 .46833 L F
.656 .751 .92 r
.7272 .4241 m .73293 .41441 L .73787 .42074 L F
.7272 .4241 m .72224 .41778 L .73293 .41441 L F
.75345 .42369 m .75932 .41399 L .76416 .42033 L F
.75345 .42369 m .74857 .41737 L .75932 .41399 L F
.651 .699 .882 r
.49502 .36354 m .4995 .35222 L .50525 .361 L F
.49502 .36354 m .48925 .35556 L .4995 .35222 L F
.188 .448 .875 r
.30803 .44379 m .31115 .43939 L .31744 .44786 L F
.30803 .44379 m .30174 .43523 L .31115 .43939 L F
.656 .751 .92 r
.7797 .42328 m .78572 .41358 L .79047 .41992 L F
.7797 .42328 m .77492 .41696 L .78572 .41358 L F
.606 .706 .915 r
.60654 .42197 m .61164 .41278 L .61701 .41928 L F
.60654 .42197 m .60113 .41491 L .61164 .41278 L F
.769 .793 .872 r
.16566 .41447 m .16865 .40204 L .17565 .40764 L F
.16566 .41447 m .15862 .4089 L .16865 .40204 L F
.442 .563 .882 r
.54281 .38898 m .54756 .38134 L .55318 .39044 L F
.54281 .38898 m .53718 .37972 L .54756 .38134 L F
.897 .873 .805 r
.4231 .43036 m .41694 .42755 L .42737 .4145 L F
.888 .866 .812 r
.41271 .44313 m .41694 .42755 L .4231 .43036 L F
.656 .751 .92 r
.80597 .42287 m .81213 .41317 L .81679 .41951 L F
.80597 .42287 m .80128 .41655 L .81213 .41317 L F
.405 .616 .937 r
.25448 .40248 m .25737 .3961 L .26388 .40384 L F
.25448 .40248 m .24792 .39514 L .25737 .3961 L F
.693 .768 .909 r
.21232 .39539 m .21533 .38491 L .22209 .39141 L F
.21232 .39539 m .20551 .38926 L .21533 .38491 L F
.656 .751 .92 r
.83225 .42246 m .83855 .41275 L .84312 .4191 L F
.83225 .42246 m .82765 .41614 L .83855 .41275 L F
.649 .757 .928 r
.6328 .42238 m .63804 .41305 L .6433 .41902 L F
.6328 .42238 m .6275 .41627 L .63804 .41305 L F
.273 .528 .912 r
.27034 .41162 m .27324 .40654 L .27968 .41463 L F
.27034 .41162 m .26388 .40384 L .27324 .40654 L F
.656 .751 .92 r
.85855 .42205 m .86499 .41234 L .86947 .41869 L F
.85855 .42205 m .85404 .41572 L .86499 .41234 L F
.454 .575 .887 r
.55877 .39945 m .56362 .3918 L .56919 .40038 L F
.55877 .39945 m .55318 .39044 L .56362 .3918 L F
.656 .751 .92 r
.65905 .42197 m .66442 .41226 L .6696 .41861 L F
.65905 .42197 m .65384 .41564 L .66442 .41226 L F
.731 .777 .89 r
.1289 .42736 m .13161 .41592 L .13872 .42174 L F
.1289 .42736 m .12177 .4214 L .13161 .41592 L F
.536 .692 .94 r
.2384 .39573 m .24132 .38781 L .24792 .39514 L F
.2384 .39573 m .23175 .38883 L .24132 .38781 L F
.768 .794 .874 r
.17565 .40764 m .17868 .39524 L .18565 .40094 L F
.17565 .40764 m .16865 .40204 L .17868 .39524 L F
.554 .661 .907 r
.59067 .41645 m .59569 .40777 L .60113 .41491 L F
.59067 .41645 m .58519 .40866 L .59569 .40777 L F
.656 .751 .92 r
.68531 .42156 m .69082 .41184 L .69591 .4182 L F
.68531 .42156 m .68019 .41523 L .69082 .41184 L F
.714 .746 .877 r
.37158 .4805 m .37552 .46846 L .38173 .4742 L F
.37158 .4805 m .3654 .47356 L .37552 .46846 L F
.804 .796 .845 r
.46875 .36858 m .47316 .35396 L .47901 .36102 L F
.46875 .36858 m .46286 .36258 L .47316 .35396 L F
.846 .826 .828 r
.45847 .37808 m .46286 .36258 L .46875 .36858 L F
.497 .613 .897 r
.57473 .40887 m .57967 .40078 L .58519 .40866 L F
.57473 .40887 m .56919 .40038 L .57967 .40078 L F
.846 .826 .828 r
.45847 .37808 m .45251 .37308 L .46286 .36258 L F
.874 .846 .813 r
.44814 .3892 m .45251 .37308 L .45847 .37808 L F
.888 .866 .812 r
.41271 .44313 m .40651 .44003 L .41694 .42755 L F
.867 .853 .826 r
.40233 .45508 m .40651 .44003 L .41271 .44313 L F
.656 .751 .92 r
.71158 .42115 m .71723 .41143 L .72224 .41778 L F
.71158 .42115 m .70655 .41482 L .71723 .41143 L F
.281 .5 .891 r
.32369 .45649 m .32699 .4511 L .33326 .45935 L F
.32369 .45649 m .31744 .44786 L .32699 .4511 L F
.68 .758 .91 r
.10244 .43032 m .10487 .42003 L .11205 .4262 L F
.10244 .43032 m .09526 .42402 L .10487 .42003 L F
.656 .751 .92 r
.73787 .42074 m .74366 .41101 L .74857 .41737 L F
.73787 .42074 m .73293 .41441 L .74366 .41101 L F
.183 .461 .884 r
.28607 .42279 m .28903 .4185 L .29541 .42682 L F
.28607 .42279 m .27968 .41463 L .28903 .4185 L F
.874 .846 .813 r
.44814 .3892 m .44212 .38508 L .45251 .37308 L F
.891 .859 .803 r
.43777 .40152 m .44212 .38508 L .44814 .3892 L F
.656 .751 .92 r
.76416 .42033 m .7701 .4106 L .77492 .41696 L F
.76416 .42033 m .75932 .41399 L .7701 .4106 L F
.748 .757 .86 r
.47901 .36102 m .48345 .34751 L .48925 .35556 L F
.47901 .36102 m .47316 .35396 L .48345 .34751 L F
.758 .791 .879 r
.18565 .40094 m .18869 .38881 L .19561 .39471 L F
.18565 .40094 m .17868 .39524 L .18869 .38881 L F
.656 .751 .92 r
.79047 .41992 m .79656 .41019 L .80128 .41655 L F
.79047 .41992 m .78572 .41358 L .79656 .41019 L F
.867 .853 .826 r
.40233 .45508 m .39611 .45135 L .40651 .44003 L F
.833 .829 .844 r
.39199 .4656 m .39611 .45135 L .40233 .45508 L F
.749 .784 .882 r
.13872 .42174 m .14154 .40982 L .14864 .41554 L F
.13872 .42174 m .13161 .41592 L .14154 .40982 L F
.574 .645 .883 r
.50525 .361 m .50979 .35088 L .51551 .36023 L F
.50525 .361 m .4995 .35222 L .50979 .35088 L F
.782 .794 .862 r
.38173 .4742 m .38576 .46096 L .39199 .4656 L F
.38173 .4742 m .37552 .46846 L .38576 .46096 L F
.637 .742 .924 r
.22209 .39141 m .22506 .38192 L .23175 .38883 L F
.22209 .39141 m .21533 .38491 L .22506 .38192 L F
.485 .588 .882 r
.52121 .36946 m .52584 .36092 L .53153 .37039 L F
.52121 .36946 m .51551 .36023 L .52584 .36092 L F
.623 .734 .926 r
.61701 .41928 m .62217 .41016 L .6275 .41627 L F
.61701 .41928 m .61164 .41278 L .62217 .41016 L F
.656 .751 .92 r
.81679 .41951 m .82302 .40977 L .82765 .41614 L F
.81679 .41951 m .81213 .41317 L .82302 .40977 L F
.429 .587 .907 r
.33947 .46777 m .34299 .46061 L .34923 .46833 L F
.33947 .46777 m .33326 .45935 L .34299 .46061 L F
.833 .829 .844 r
.39199 .4656 m .38576 .46096 L .39611 .45135 L F
.585 .675 .902 r
.35543 .4762 m .35917 .46668 L .3654 .47356 L F
.35543 .4762 m .34923 .46833 L .35917 .46668 L F
.656 .751 .92 r
.84312 .4191 m .8495 .40936 L .85404 .41572 L F
.84312 .4191 m .83855 .41275 L .8495 .40936 L F
.654 .764 .931 r
.6433 .41902 m .6486 .40968 L .65384 .41564 L F
.6433 .41902 m .63804 .41305 L .6486 .40968 L F
.891 .859 .803 r
.43777 .40152 m .43169 .39805 L .44212 .38508 L F
.897 .865 .8 r
.42737 .4145 m .43169 .39805 L .43777 .40152 L F
.656 .751 .92 r
.86947 .41869 m .87598 .40894 L .88043 .41531 L F
.86947 .41869 m .86499 .41234 L .87598 .40894 L F
.6696 .41861 m .67503 .40886 L .68019 .41523 L F
.6696 .41861 m .66442 .41226 L .67503 .40886 L F
.435 .558 .881 r
.53718 .37972 m .54191 .37211 L .54756 .38134 L F
.53718 .37972 m .53153 .37039 L .54191 .37211 L F
.738 .783 .889 r
.19561 .39471 m .19865 .38307 L .20551 .38926 L F
.19561 .39471 m .18869 .38881 L .19865 .38307 L F
.169 .443 .874 r
.30174 .43523 m .30481 .43105 L .31115 .43939 L F
.30174 .43523 m .29541 .42682 L .30481 .43105 L F
.656 .751 .92 r
.69591 .4182 m .70149 .40844 L .70655 .41482 L F
.69591 .4182 m .69082 .41184 L .70149 .40844 L F
.678 .709 .872 r
.48925 .35556 m .49373 .34334 L .4995 .35222 L F
.48925 .35556 m .48345 .34751 L .49373 .34334 L F
.762 .789 .875 r
.14864 .41554 m .15155 .40323 L .15862 .4089 L F
.14864 .41554 m .14154 .40982 L .15155 .40323 L F
.704 .767 .901 r
.11205 .4262 m .1146 .41537 L .12177 .4214 L F
.11205 .4262 m .10487 .42003 L .1146 .41537 L F
.656 .751 .92 r
.72224 .41778 m .72796 .40803 L .73293 .41441 L F
.72224 .41778 m .71723 .41143 L .72796 .40803 L F
.74857 .41737 m .75444 .40761 L .75932 .41399 L F
.74857 .41737 m .74366 .41101 L .75444 .40761 L F
.579 .694 .92 r
.60113 .41491 m .60623 .40621 L .61164 .41278 L F
.60113 .41491 m .59569 .40777 L .60623 .40621 L F
.431 .562 .886 r
.55318 .39044 m .55801 .3831 L .56362 .3918 L F
.55318 .39044 m .54756 .38134 L .55801 .3831 L F
.656 .751 .92 r
.77492 .41696 m .78093 .40719 L .78572 .41358 L F
.77492 .41696 m .7701 .4106 L .78093 .40719 L F
.432 .631 .938 r
.24792 .39514 m .25081 .38838 L .25737 .3961 L F
.24792 .39514 m .24132 .38781 L .25081 .38838 L F
.897 .865 .8 r
.42737 .4145 m .42122 .41139 L .43169 .39805 L F
.894 .866 .804 r
.41694 .42755 m .42122 .41139 L .42737 .4145 L F
.295 .544 .918 r
.26388 .40384 m .26676 .39849 L .27324 .40654 L F
.26388 .40384 m .25737 .3961 L .26676 .39849 L F
.656 .751 .92 r
.80128 .41655 m .80743 .40678 L .81213 .41317 L F
.80128 .41655 m .79656 .41019 L .80743 .40678 L F
.769 .792 .872 r
.15862 .4089 m .1616 .39636 L .16865 .40204 L F
.15862 .4089 m .15155 .40323 L .1616 .39636 L F
.705 .77 .903 r
.20551 .38926 m .20853 .37836 L .21533 .38491 L F
.20551 .38926 m .19865 .38307 L .20853 .37836 L F
.521 .644 .911 r
.58519 .40866 m .5902 .40054 L .59569 .40777 L F
.58519 .40866 m .57967 .40078 L .5902 .40054 L F
.466 .595 .898 r
.56919 .40038 m .57412 .39279 L .57967 .40078 L F
.56919 .40038 m .56362 .3918 L .57412 .39279 L F
.656 .751 .92 r
.82765 .41614 m .83395 .40636 L .83855 .41275 L F
.82765 .41614 m .82302 .40977 L .83395 .40636 L F
.239 .483 .889 r
.31744 .44786 m .32068 .44297 L .32699 .4511 L F
.31744 .44786 m .31115 .43939 L .32068 .44297 L F
.638 .754 .933 r
.6275 .41627 m .63274 .40717 L .63804 .41305 L F
.6275 .41627 m .62217 .41016 L .63274 .40717 L F
.559 .702 .936 r
.23175 .38883 m .23468 .38047 L .24132 .38781 L F
.23175 .38883 m .22506 .38192 L .23468 .38047 L F
.656 .751 .92 r
.85404 .41572 m .86048 .40594 L .86499 .41234 L F
.85404 .41572 m .8495 .40936 L .86048 .40594 L F
.657 .766 .93 r
.65384 .41564 m .65921 .40623 L .66441 .41226 L F
.65384 .41564 m .6486 .40968 L .65921 .40623 L F
.681 .74 .895 r
.3654 .47356 m .36926 .46262 L .37552 .46846 L F
.3654 .47356 m .35917 .46668 L .36926 .46262 L F
.726 .776 .892 r
.12177 .4214 m .12445 .41001 L .13161 .41592 L F
.12177 .4214 m .1146 .41537 L .12445 .41001 L F
.189 .469 .888 r
.27968 .41463 m .2826 .41026 L .28903 .4185 L F
.27968 .41463 m .27324 .40654 L .2826 .41026 L F
.656 .751 .92 r
.68019 .41523 m .68569 .40545 L .69082 .41184 L F
.68019 .41523 m .67503 .40886 L .68569 .40545 L F
.769 .792 .872 r
.16865 .40204 m .17167 .38945 L .17868 .39524 L F
.16865 .40204 m .1616 .39636 L .17167 .38945 L F
.656 .751 .92 r
.70655 .41482 m .7122 .40503 L .71723 .41143 L F
.70655 .41482 m .70149 .40844 L .7122 .40503 L F
.894 .866 .804 r
.41694 .42755 m .41074 .42447 L .42122 .41139 L F
.881 .861 .816 r
.40651 .44003 m .41074 .42447 L .41694 .42755 L F
.498 .593 .88 r
.51551 .36023 m .52012 .35131 L .52584 .36092 L F
.51551 .36023 m .50979 .35088 L .52012 .35131 L F
.821 .797 .829 r
.46286 .36258 m .46728 .34686 L .47316 .35396 L F
.46286 .36258 m .45692 .35652 L .46728 .34686 L F
.858 .823 .813 r
.45251 .37308 m .45692 .35652 L .46286 .36258 L F
.597 .654 .877 r
.4995 .35222 m .50403 .3414 L .50979 .35088 L F
.4995 .35222 m .49373 .34334 L .50403 .3414 L F
.675 .757 .912 r
.09526 .42402 m .09765 .41381 L .10487 .42003 L F
.09526 .42402 m .08803 .41768 L .09765 .41381 L F
.656 .751 .92 r
.73293 .41441 m .73872 .40461 L .74366 .41101 L F
.73293 .41441 m .72796 .40803 L .73872 .40461 L F
.77 .762 .846 r
.47316 .35396 m .47761 .33939 L .48345 .34751 L F
.47316 .35396 m .46728 .34686 L .47761 .33939 L F
.377 .567 .911 r
.33326 .45935 m .33669 .45297 L .34299 .46061 L F
.33326 .45935 m .32699 .4511 L .33669 .45297 L F
.858 .823 .813 r
.45251 .37308 m .44651 .36803 L .45692 .35652 L F
.882 .841 .8 r
.44212 .38508 m .44651 .36803 L .45251 .37308 L F
.656 .751 .92 r
.75932 .41399 m .76525 .40419 L .7701 .4106 L F
.75932 .41399 m .75444 .40761 L .76525 .40419 L F
.539 .662 .916 r
.34923 .46833 m .35289 .45982 L .35917 .46668 L F
.34923 .46833 m .34299 .46061 L .35289 .45982 L F
.431 .554 .879 r
.53153 .37039 m .53623 .36272 L .54191 .37211 L F
.53153 .37039 m .52584 .36092 L .53623 .36272 L F
.656 .751 .92 r
.78572 .41358 m .7918 .40378 L .79656 .41019 L F
.78572 .41358 m .78093 .40719 L .7918 .40378 L F
.762 .79 .876 r
.17868 .39524 m .18173 .38283 L .18869 .38881 L F
.17868 .39524 m .17167 .38945 L .18173 .38283 L F
.654 .747 .918 r
.21533 .38491 m .21831 .37497 L .22506 .38192 L F
.21533 .38491 m .20853 .37836 L .21831 .37497 L F
.602 .725 .931 r
.61164 .41278 m .6168 .40405 L .62217 .41016 L F
.61164 .41278 m .60623 .40621 L .6168 .40405 L F
.745 .783 .883 r
.13161 .41592 m .13439 .40401 L .14154 .40982 L F
.13161 .41592 m .12445 .41001 L .13439 .40401 L F
.656 .751 .92 r
.81213 .41317 m .81835 .40336 L .82302 .40977 L F
.81213 .41317 m .80743 .40678 L .81835 .40336 L F
.152 .438 .873 r
.29541 .42682 m .29843 .42278 L .30481 .43105 L F
.29541 .42682 m .28903 .4185 L .29843 .42278 L F
.881 .861 .816 r
.40651 .44003 m .40027 .43666 L .41074 .42447 L F
.856 .849 .835 r
.39611 .45135 m .40027 .43666 L .40651 .44003 L F
.758 .79 .879 r
.37552 .46846 m .37949 .45613 L .38576 .46096 L F
.37552 .46846 m .36926 .46262 L .37949 .45613 L F
.656 .751 .92 r
.83855 .41275 m .84492 .40294 L .8495 .40936 L F
.83855 .41275 m .83395 .40636 L .84492 .40294 L F
.882 .841 .8 r
.44212 .38508 m .43605 .38087 L .44651 .36803 L F
.895 .853 .794 r
.43169 .39805 m .43605 .38087 L .44212 .38508 L F
.702 .717 .86 r
.48345 .34751 m .48792 .33434 L .49373 .34334 L F
.48345 .34751 m .47761 .33939 L .48792 .33434 L F
.648 .768 .936 r
.63804 .41305 m .64334 .4039 L .6486 .40968 L F
.63804 .41305 m .63274 .40717 L .64334 .4039 L F
.656 .751 .92 r
.86499 .41234 m .8715 .40252 L .87598 .40894 L F
.86499 .41234 m .86048 .40594 L .8715 .40252 L F
.658 .765 .929 r
.66441 .41226 m .66985 .40273 L .67503 .40886 L F
.66441 .41226 m .65921 .40623 L .66985 .40273 L F
.411 .549 .883 r
.54756 .38134 m .55238 .37424 L .55801 .3831 L F
.54756 .38134 m .54191 .37211 L .55238 .37424 L F
.856 .849 .835 r
.39611 .45135 m .38984 .44737 L .40027 .43666 L F
.816 .826 .857 r
.38576 .46096 m .38984 .44737 L .39611 .45135 L F
.38576 .46096 m .37949 .45613 L .38984 .44737 L F
.656 .751 .92 r
.69082 .41184 m .69639 .40202 L .70149 .40844 L F
.69082 .41184 m .68569 .40545 L .69639 .40202 L F
.745 .783 .884 r
.18869 .38881 m .19175 .37682 L .19865 .38307 L F
.18869 .38881 m .18173 .38283 L .19175 .37682 L F
.699 .766 .904 r
.10487 .42003 m .10738 .40927 L .1146 .41537 L F
.10487 .42003 m .09765 .41381 L .10738 .40927 L F
.656 .751 .92 r
.71723 .41143 m .72295 .4016 L .72796 .40803 L F
.71723 .41143 m .7122 .40503 L .72295 .4016 L F
.549 .679 .924 r
.59569 .40777 m .60078 .39959 L .60623 .40621 L F
.59569 .40777 m .5902 .40054 L .60078 .39959 L F
.759 .788 .876 r
.14154 .40982 m .14442 .39748 L .15155 .40323 L F
.14154 .40982 m .13439 .40401 L .14442 .39748 L F
.317 .559 .923 r
.25737 .3961 m .26023 .39048 L .26676 .39849 L F
.25737 .3961 m .25081 .38838 L .26023 .39048 L F
.458 .645 .938 r
.24132 .38781 m .2442 .38067 L .25081 .38838 L F
.24132 .38781 m .23468 .38047 L .2442 .38067 L F
.434 .576 .896 r
.56362 .3918 m .56854 .38466 L .57412 .39279 L F
.56362 .3918 m .55801 .3831 L .56854 .38466 L F
.656 .751 .92 r
.74366 .41101 m .74952 .40118 L .75444 .40761 L F
.74366 .41101 m .73872 .40461 L .74952 .40118 L F
.201 .466 .884 r
.31115 .43939 m .31432 .43492 L .32068 .44297 L F
.31115 .43939 m .30481 .43105 L .31432 .43492 L F
.895 .853 .794 r
.43169 .39805 m .42555 .39445 L .43605 .38087 L F
.898 .86 .795 r
.42122 .41139 m .42555 .39445 L .43169 .39805 L F
.487 .625 .912 r
.57967 .40078 m .58468 .3932 L .5902 .40054 L F
.57967 .40078 m .57412 .39279 L .58468 .3932 L F
.656 .751 .92 r
.7701 .4106 m .77611 .40076 L .78093 .40719 L F
.7701 .4106 m .76525 .40419 L .77611 .40076 L F
.79656 .41019 m .80271 .40034 L .80743 .40678 L F
.79656 .41019 m .7918 .40378 L .80271 .40034 L F
.513 .599 .877 r
.50979 .35088 m .51437 .34151 L .52012 .35131 L F
.50979 .35088 m .50403 .3414 L .51437 .34151 L F
.197 .478 .893 r
.27324 .40654 m .27613 .40206 L .2826 .41026 L F
.27324 .40654 m .26676 .39849 L .27613 .40206 L F
.656 .751 .92 r
.82302 .40977 m .82932 .39993 L .83395 .40636 L F
.82302 .40977 m .81835 .40336 L .82932 .39993 L F
.715 .771 .897 r
.19865 .38307 m .20168 .37177 L .20853 .37836 L F
.19865 .38307 m .19175 .37682 L .20168 .37177 L F
.581 .711 .932 r
.22506 .38192 m .22798 .37313 L .23468 .38047 L F
.22506 .38192 m .21831 .37497 L .22798 .37313 L F
.768 .79 .871 r
.15155 .40323 m .1545 .39058 L .1616 .39636 L F
.15155 .40323 m .14442 .39748 L .1545 .39058 L F
.621 .663 .87 r
.49373 .34334 m .49824 .33175 L .50403 .3414 L F
.49373 .34334 m .48792 .33434 L .49824 .33175 L F
.644 .731 .912 r
.35917 .46668 m .36296 .45672 L .36926 .46262 L F
.35917 .46668 m .35289 .45982 L .36296 .45672 L F
.623 .75 .938 r
.62217 .41016 m .62741 .40137 L .63274 .40717 L F
.62217 .41016 m .6168 .40405 L .62741 .40137 L F
.656 .751 .92 r
.8495 .40936 m .85594 .39951 L .86048 .40594 L F
.8495 .40936 m .84492 .40294 L .85594 .39951 L F
.655 .775 .937 r
.6486 .40968 m .65398 .40044 L .65921 .40623 L F
.6486 .40968 m .64334 .4039 L .65398 .40044 L F
.43 .55 .876 r
.52584 .36092 m .53052 .35314 L .53623 .36272 L F
.52584 .36092 m .52012 .35131 L .53052 .35314 L F
.326 .545 .911 r
.32699 .4511 m .33035 .44539 L .33669 .45297 L F
.32699 .4511 m .32068 .44297 L .33035 .44539 L F
.659 .763 .927 r
.67503 .40886 m .68054 .39922 L .68569 .40545 L F
.67503 .40886 m .66985 .40273 L .68054 .39922 L F
.722 .774 .894 r
.1146 .41537 m .11723 .40404 L .12445 .41001 L F
.1146 .41537 m .10738 .40927 L .11723 .40404 L F
.898 .86 .795 r
.42122 .41139 m .41502 .40812 L .42555 .39445 L F
.892 .862 .804 r
.41074 .42447 m .41502 .40812 L .42122 .41139 L F
.656 .751 .92 r
.70149 .40844 m .70713 .39858 L .7122 .40503 L F
.70149 .40844 m .69639 .40202 L .70713 .39858 L F
.491 .645 .925 r
.34299 .46061 m .34656 .45297 L .35289 .45982 L F
.34299 .46061 m .33669 .45297 L .34656 .45297 L F
.77 .791 .87 r
.1616 .39636 m .16462 .38358 L .17167 .38945 L F
.1616 .39636 m .1545 .39058 L .16462 .38358 L F
.67 .755 .915 r
.08803 .41768 m .09037 .40753 L .09765 .41381 L F
.08803 .41768 m .08075 .41129 L .09037 .40753 L F
.789 .765 .831 r
.46728 .34686 m .47174 .33118 L .47761 .33939 L F
.46728 .34686 m .46136 .33969 L .47174 .33118 L F
.836 .797 .814 r
.45692 .35652 m .46136 .33969 L .46728 .34686 L F
.45692 .35652 m .45094 .35043 L .46136 .33969 L F
.869 .821 .799 r
.44651 .36803 m .45094 .35043 L .45692 .35652 L F
.656 .751 .92 r
.72796 .40803 m .73374 .39816 L .73872 .40461 L F
.72796 .40803 m .72295 .4016 L .73374 .39816 L F
.14 .434 .872 r
.28903 .4185 m .292 .41457 L .29843 .42278 L F
.28903 .4185 m .2826 .41026 L .292 .41457 L F
.656 .751 .92 r
.75444 .40761 m .76037 .39774 L .76525 .40419 L F
.75444 .40761 m .74952 .40118 L .76037 .39774 L F
.391 .535 .88 r
.54191 .37211 m .54671 .36519 L .55238 .37424 L F
.54191 .37211 m .53623 .36272 L .54671 .36519 L F
.656 .751 .92 r
.78093 .40719 m .787 .39732 L .7918 .40378 L F
.78093 .40719 m .77611 .40076 L .787 .39732 L F
.725 .723 .848 r
.47761 .33939 m .48208 .32521 L .48792 .33434 L F
.47761 .33939 m .47174 .33118 L .48208 .32521 L F
.668 .751 .912 r
.20853 .37836 m .21152 .368 L .21831 .37497 L F
.20853 .37836 m .20168 .37177 L .21152 .368 L F
.577 .713 .936 r
.60623 .40621 m .61139 .39794 L .6168 .40405 L F
.60623 .40621 m .60078 .39959 L .61139 .39794 L F
.869 .821 .799 r
.44651 .36803 m .44046 .36293 L .45094 .35043 L F
.889 .838 .789 r
.43605 .38087 m .44046 .36293 L .44651 .36803 L F
.656 .751 .92 r
.80743 .40678 m .81366 .3969 L .81835 .40336 L F
.80743 .40678 m .80271 .40034 L .81366 .3969 L F
.765 .789 .872 r
.17167 .38945 m .17472 .37678 L .18173 .38283 L F
.17167 .38945 m .16462 .38358 L .17472 .37678 L F
.892 .862 .804 r
.41074 .42447 m .40448 .4212 L .41502 .40812 L F
.875 .858 .82 r
.40027 .43666 m .40448 .4212 L .41074 .42447 L F
.742 .781 .885 r
.12445 .41001 m .12719 .39813 L .13439 .40401 L F
.12445 .41001 m .11723 .40404 L .12719 .39813 L F
.732 .785 .895 r
.36926 .46262 m .37318 .45115 L .37949 .45613 L F
.36926 .46262 m .36296 .45672 L .37318 .45115 L F
.656 .751 .92 r
.83395 .40636 m .84032 .39648 L .84492 .40294 L F
.83395 .40636 m .82932 .39993 L .84032 .39648 L F
.86048 .40594 m .86699 .39606 L .8715 .40252 L F
.86048 .40594 m .85594 .39951 L .86699 .39606 L F
.402 .555 .893 r
.55801 .3831 m .56292 .37637 L .56854 .38466 L F
.55801 .3831 m .55238 .37424 L .56292 .37637 L F
.64 .769 .941 r
.63274 .40717 m .63805 .39826 L .64334 .4039 L F
.63274 .40717 m .62741 .40137 L .63805 .39826 L F
.66 .776 .935 r
.65921 .40623 m .66465 .39685 L .66985 .40273 L F
.65921 .40623 m .65398 .40044 L .66465 .39685 L F
.166 .449 .878 r
.30481 .43105 m .30792 .42692 L .31432 .43492 L F
.30481 .43105 m .29843 .42278 L .30792 .42692 L F
.514 .661 .927 r
.5902 .40054 m .59529 .3929 L .60078 .39959 L F
.5902 .40054 m .58468 .3932 L .59529 .3929 L F
.658 .76 .925 r
.68569 .40545 m .69126 .39569 L .69639 .40202 L F
.68569 .40545 m .68054 .39922 L .69126 .39569 L F
.34 .573 .926 r
.25081 .38838 m .25365 .38247 L .26023 .39048 L F
.25081 .38838 m .2442 .38067 L .25365 .38247 L F
.529 .604 .872 r
.50403 .3414 m .5086 .3315 L .51437 .34151 L F
.50403 .3414 m .49824 .33175 L .5086 .3315 L F
.482 .657 .938 r
.23468 .38047 m .23755 .37295 L .2442 .38067 L F
.23468 .38047 m .22798 .37313 L .23755 .37295 L F
.449 .603 .911 r
.57412 .39279 m .57912 .38575 L .58468 .3932 L F
.57412 .39279 m .56854 .38466 L .57912 .38575 L F
.75 .783 .879 r
.18173 .38283 m .18479 .37052 L .19175 .37682 L F
.18173 .38283 m .17472 .37678 L .18479 .37052 L F
.875 .858 .82 r
.40027 .43666 m .39398 .43307 L .40448 .4212 L F
.846 .846 .844 r
.38984 .44737 m .39398 .43307 L .40027 .43666 L F
.694 .765 .906 r
.09765 .41381 m .10011 .40311 L .10738 .40927 L F
.09765 .41381 m .09037 .40753 L .10011 .40311 L F
.889 .838 .789 r
.43605 .38087 m .42993 .3766 L .44046 .36293 L F
.899 .849 .786 r
.42555 .39445 m .42993 .3766 L .43605 .38087 L F
.656 .751 .92 r
.7122 .40503 m .71791 .39513 L .72295 .4016 L F
.7122 .40503 m .70713 .39858 L .71791 .39513 L F
.799 .823 .87 r
.37949 .45613 m .38353 .44319 L .38984 .44737 L F
.37949 .45613 m .37318 .45115 L .38353 .44319 L F
.656 .751 .92 r
.73872 .40461 m .74457 .39471 L .74952 .40118 L F
.73872 .40461 m .73374 .39816 L .74457 .39471 L F
.757 .786 .877 r
.13439 .40401 m .13724 .39164 L .14442 .39748 L F
.13439 .40401 m .12719 .39813 L .13724 .39164 L F
.643 .67 .861 r
.48792 .33434 m .49243 .32192 L .49824 .33175 L F
.48792 .33434 m .48208 .32521 L .49243 .32192 L F
.846 .846 .844 r
.38984 .44737 m .38353 .44319 L .39398 .43307 L F
.207 .486 .897 r
.26676 .39849 m .26961 .39388 L .27613 .40206 L F
.26676 .39849 m .26023 .39048 L .26961 .39388 L F
.43 .547 .873 r
.52012 .35131 m .52478 .34334 L .53052 .35314 L F
.52012 .35131 m .51437 .34151 L .52478 .34334 L F
.656 .751 .92 r
.76525 .40419 m .77125 .39429 L .77611 .40076 L F
.76525 .40419 m .76037 .39774 L .77125 .39429 L F
.7918 .40378 m .79794 .39387 L .80271 .40034 L F
.7918 .40378 m .787 .39732 L .79794 .39387 L F
.276 .521 .907 r
.32068 .44297 m .32397 .43784 L .33035 .44539 L F
.32068 .44297 m .31432 .43492 L .32397 .43784 L F
.6 .718 .927 r
.21831 .37497 m .22124 .36576 L .22798 .37313 L F
.21831 .37497 m .21152 .368 L .22124 .36576 L F
.604 .719 .925 r
.35289 .45982 m .35661 .45074 L .36296 .45672 L F
.35289 .45982 m .34656 .45297 L .35661 .45074 L F
.656 .751 .92 r
.81835 .40336 m .82465 .39344 L .82932 .39993 L F
.81835 .40336 m .81366 .3969 L .82465 .39344 L F
.724 .772 .891 r
.19175 .37682 m .19478 .36514 L .20168 .37177 L F
.19175 .37682 m .18479 .37052 L .19478 .36514 L F
.656 .751 .92 r
.84492 .40294 m .85136 .39302 L .85594 .39951 L F
.84492 .40294 m .84032 .39648 L .85136 .39302 L F
.767 .789 .871 r
.14442 .39748 m .14736 .38473 L .1545 .39058 L F
.14442 .39748 m .13724 .39164 L .14736 .38473 L F
.604 .744 .943 r
.6168 .40405 m .62204 .39563 L .62741 .40137 L F
.6168 .40405 m .61139 .39794 L .62204 .39563 L F
.899 .849 .786 r
.42555 .39445 m .41936 .39077 L .42993 .3766 L F
.899 .856 .791 r
.41502 .40812 m .41936 .39077 L .42555 .39445 L F
.439 .624 .93 r
.33669 .45297 m .3402 .44612 L .34656 .45297 L F
.33669 .45297 m .33035 .44539 L .3402 .44612 L F
.373 .521 .875 r
.53623 .36272 m .541 .35595 L .54671 .36519 L F
.53623 .36272 m .53052 .35314 L .541 .35595 L F
.129 .431 .871 r
.2826 .41026 m .28552 .40639 L .292 .41457 L F
.2826 .41026 m .27613 .40206 L .28552 .40639 L F
.662 .775 .933 r
.66985 .40273 m .67536 .3932 L .68054 .39922 L F
.66985 .40273 m .66465 .39685 L .67536 .3932 L F
.652 .78 .942 r
.64334 .4039 m .64871 .39482 L .65398 .40044 L F
.64334 .4039 m .63805 .39826 L .64871 .39482 L F
.717 .773 .896 r
.10738 .40927 m .10997 .39799 L .11723 .40404 L F
.10738 .40927 m .10011 .40311 L .10997 .39799 L F
.807 .767 .817 r
.46136 .33969 m .46583 .32287 L .47174 .33118 L F
.46136 .33969 m .4554 .33247 L .46583 .32287 L F
.849 .797 .799 r
.45094 .35043 m .4554 .33247 L .46136 .33969 L F
.658 .757 .923 r
.69639 .40202 m .70202 .39217 L .70713 .39858 L F
.69639 .40202 m .69126 .39569 L .70202 .39217 L F
.664 .754 .917 r
.08075 .41129 m .08305 .40119 L .09037 .40753 L F
.08075 .41129 m .07342 .40486 L .08305 .40119 L F
.656 .751 .92 r
.72295 .4016 m .72873 .39167 L .73374 .39816 L F
.72295 .4016 m .71791 .39513 L .72873 .39167 L F
.746 .728 .835 r
.47174 .33118 m .47622 .31593 L .48208 .32521 L F
.47174 .33118 m .46583 .32287 L .47622 .31593 L F
.771 .79 .868 r
.1545 .39058 m .15751 .37765 L .16462 .38358 L F
.1545 .39058 m .14736 .38473 L .15751 .37765 L F
.849 .797 .799 r
.45094 .35043 m .44491 .3443 L .4554 .33247 L F
.878 .819 .786 r
.44046 .36293 m .44491 .3443 L .45094 .35043 L F
.656 .751 .92 r
.74952 .40118 m .75545 .39124 L .76037 .39774 L F
.74952 .40118 m .74457 .39471 L .75545 .39124 L F
.368 .532 .887 r
.55238 .37424 m .55726 .36791 L .56292 .37637 L F
.55238 .37424 m .54671 .36519 L .55726 .36791 L F
.656 .751 .92 r
.77611 .40076 m .78218 .39082 L .787 .39732 L F
.77611 .40076 m .77125 .39429 L .78218 .39082 L F
.546 .699 .94 r
.60078 .39959 m .60595 .39182 L .61139 .39794 L F
.60078 .39959 m .59529 .3929 L .60595 .39182 L F
.681 .754 .906 r
.20168 .37177 m .20468 .36099 L .21152 .368 L F
.20168 .37177 m .19478 .36514 L .20468 .36099 L F
.546 .609 .867 r
.49824 .33175 m .5028 .32126 L .5086 .3315 L F
.49824 .33175 m .49243 .32192 L .5028 .32126 L F
.899 .856 .791 r
.41502 .40812 m .40876 .40472 L .41936 .39077 L F
.89 .859 .804 r
.40448 .4212 m .40876 .40472 L .41502 .40812 L F
.656 .751 .92 r
.80271 .40034 m .80892 .3904 L .81366 .3969 L F
.80271 .40034 m .79794 .39387 L .80892 .3904 L F
.134 .432 .871 r
.29843 .42278 m .30147 .41895 L .30792 .42692 L F
.29843 .42278 m .292 .41457 L .30147 .41895 L F
.768 .788 .869 r
.16462 .38358 m .16766 .37067 L .17472 .37678 L F
.16462 .38358 m .15751 .37765 L .16766 .37067 L F
.656 .751 .92 r
.82932 .39993 m .83568 .38997 L .84032 .39648 L F
.82932 .39993 m .82465 .39344 L .83568 .38997 L F
.704 .779 .91 r
.36296 .45672 m .36682 .44605 L .37318 .45115 L F
.36296 .45672 m .35661 .45074 L .36682 .44605 L F
.738 .78 .887 r
.11723 .40404 m .11994 .39217 L .12719 .39813 L F
.11723 .40404 m .10997 .39799 L .11994 .39217 L F
.433 .545 .87 r
.51437 .34151 m .51901 .3333 L .52478 .34334 L F
.51437 .34151 m .5086 .3315 L .51901 .3333 L F
.878 .819 .786 r
.44046 .36293 m .43436 .3578 L .44491 .3443 L F
.895 .834 .779 r
.42993 .3766 m .43436 .3578 L .44046 .36293 L F
.361 .586 .929 r
.2442 .38067 m .24703 .37446 L .25365 .38247 L F
.2442 .38067 m .23755 .37295 L .24703 .37446 L F
.408 .577 .907 r
.56854 .38466 m .57353 .37816 L .57912 .38575 L F
.56854 .38466 m .56292 .37637 L .57353 .37816 L F
.475 .639 .928 r
.58468 .3932 m .58977 .38614 L .59529 .3929 L F
.58468 .3932 m .57912 .38575 L .58977 .38614 L F
.656 .751 .92 r
.85594 .39951 m .86245 .38955 L .86699 .39606 L F
.85594 .39951 m .85136 .39302 L .86245 .38955 L F
.666 .677 .851 r
.48208 .32521 m .48659 .31188 L .49243 .32192 L F
.48208 .32521 m .47622 .31593 L .48659 .31188 L F
.505 .668 .936 r
.22798 .37313 m .23085 .36522 L .23755 .37295 L F
.22798 .37313 m .22124 .36576 L .23085 .36522 L F
.627 .768 .947 r
.62741 .40137 m .63271 .39274 L .63805 .39826 L F
.62741 .40137 m .62204 .39563 L .63271 .39274 L F
.663 .771 .93 r
.68054 .39922 m .6861 .38952 L .69126 .39569 L F
.68054 .39922 m .67536 .3932 L .6861 .38952 L F
.661 .785 .94 r
.65398 .40044 m .65941 .39116 L .66465 .39685 L F
.65398 .40044 m .64871 .39482 L .65941 .39116 L F
.219 .495 .901 r
.26023 .39048 m .26305 .38571 L .26961 .39388 L F
.26023 .39048 m .25365 .38247 L .26305 .38571 L F
.657 .755 .922 r
.70713 .39858 m .71283 .38865 L .71791 .39513 L F
.70713 .39858 m .70202 .39217 L .71283 .38865 L F
.689 .763 .908 r
.09037 .40753 m .09279 .39689 L .10011 .40311 L F
.09037 .40753 m .08305 .40119 L .09279 .39689 L F
.89 .859 .804 r
.40448 .4212 m .39818 .41778 L .40876 .40472 L F
.87 .856 .825 r
.39398 .43307 m .39818 .41778 L .40448 .4212 L F
.756 .783 .875 r
.17472 .37678 m .17778 .36415 L .18479 .37052 L F
.17472 .37678 m .16766 .37067 L .17778 .36415 L F
.656 .751 .92 r
.73374 .39816 m .73959 .38819 L .74457 .39471 L F
.73374 .39816 m .72873 .39167 L .73959 .38819 L F
.226 .495 .899 r
.31432 .43492 m .31754 .43031 L .32397 .43784 L F
.31432 .43492 m .30792 .42692 L .31754 .43031 L F
.357 .507 .87 r
.53052 .35314 m .53527 .34647 L .541 .35595 L F
.53052 .35314 m .52478 .34334 L .53527 .34647 L F
.755 .785 .878 r
.12719 .39813 m .13001 .38573 L .13724 .39164 L F
.12719 .39813 m .11994 .39217 L .13001 .38573 L F
.656 .751 .92 r
.76037 .39774 m .76636 .38777 L .77125 .39429 L F
.76037 .39774 m .75545 .39124 L .76636 .38777 L F
.781 .82 .883 r
.37318 .45115 m .37717 .43886 L .38353 .44319 L F
.37318 .45115 m .36682 .44605 L .37717 .43886 L F
.561 .704 .936 r
.34656 .45297 m .35022 .4447 L .35661 .45074 L F
.34656 .45297 m .3402 .44612 L .35022 .4447 L F
.895 .834 .779 r
.42993 .3766 m .42376 .37229 L .43436 .3578 L F
.902 .846 .779 r
.41936 .39077 m .42376 .37229 L .42993 .3766 L F
.656 .751 .92 r
.787 .39732 m .79315 .38734 L .79794 .39387 L F
.787 .39732 m .78218 .39082 L .79315 .38734 L F
.617 .724 .923 r
.21152 .368 m .21445 .35836 L .22124 .36576 L F
.21152 .368 m .20468 .36099 L .21445 .35836 L F
.87 .856 .825 r
.39398 .43307 m .38763 .42933 L .39818 .41778 L F
.835 .844 .853 r
.38353 .44319 m .38763 .42933 L .39398 .43307 L F
.122 .428 .87 r
.27613 .40206 m .279 .39822 L .28552 .40639 L F
.27613 .40206 m .26961 .39388 L .279 .39822 L F
.656 .751 .92 r
.81366 .3969 m .81994 .38691 L .82465 .39344 L F
.81366 .3969 m .80892 .3904 L .81994 .38691 L F
.385 .599 .931 r
.33035 .44539 m .33378 .43924 L .3402 .44612 L F
.33035 .44539 m .32397 .43784 L .33378 .43924 L F
.835 .844 .853 r
.38353 .44319 m .37717 .43886 L .38763 .42933 L F
.732 .773 .886 r
.18479 .37052 m .18783 .35846 L .19478 .36514 L F
.18479 .37052 m .17778 .36415 L .18783 .35846 L F
.656 .751 .92 r
.84032 .39648 m .84676 .38649 L .85136 .39302 L F
.84032 .39648 m .83568 .38997 L .84676 .38649 L F
.579 .736 .95 r
.61139 .39794 m .61663 .38996 L .62204 .39563 L F
.61139 .39794 m .60595 .39182 L .61663 .38996 L F
.767 .788 .871 r
.13724 .39164 m .14016 .37881 L .14736 .38473 L F
.13724 .39164 m .13001 .38573 L .14016 .37881 L F
.766 .732 .822 r
.46583 .32287 m .47032 .30647 L .47622 .31593 L F
.46583 .32287 m .45988 .31445 L .47032 .30647 L F
.822 .769 .802 r
.4554 .33247 m .45988 .31445 L .46583 .32287 L F
.4554 .33247 m .4494 .32518 L .45988 .31445 L F
.861 .796 .785 r
.44491 .3443 m .4494 .32518 L .4554 .33247 L F
.564 .614 .861 r
.49243 .32192 m .49697 .31075 L .5028 .32126 L F
.49243 .32192 m .48659 .31188 L .49697 .31075 L F
.334 .508 .88 r
.54671 .36519 m .55157 .35925 L .55726 .36791 L F
.54671 .36519 m .541 .35595 L .55157 .35925 L F
.713 .772 .899 r
.10011 .40311 m .10266 .39188 L .10997 .39799 L F
.10011 .40311 m .09279 .39689 L .10266 .39188 L F
.667 .785 .937 r
.66465 .39685 m .67015 .38736 L .67536 .3932 L F
.66465 .39685 m .65941 .39116 L .67015 .38736 L F
.663 .766 .927 r
.69126 .39569 m .69689 .38584 L .70202 .39217 L F
.69126 .39569 m .6861 .38952 L .69689 .38584 L F
.647 .785 .948 r
.63805 .39826 m .64342 .38939 L .64871 .39482 L F
.63805 .39826 m .63271 .39274 L .64342 .38939 L F
.659 .753 .919 r
.07342 .40486 m .07567 .39481 L .08305 .40119 L F
.07342 .40486 m .06604 .39837 L .07567 .39481 L F
.657 .753 .921 r
.71791 .39513 m .72368 .38513 L .72873 .39167 L F
.71791 .39513 m .71283 .38865 L .72368 .38513 L F
.438 .543 .866 r
.5086 .3315 m .51321 .32299 L .51901 .3333 L F
.5086 .3315 m .5028 .32126 L .51321 .32299 L F
.656 .751 .92 r
.74457 .39471 m .75049 .3847 L .75545 .39124 L F
.74457 .39471 m .73959 .38819 L .75049 .3847 L F
.902 .846 .779 r
.41936 .39077 m .41311 .38702 L .42376 .37229 L F
.9 .854 .788 r
.40876 .40472 m .41311 .38702 L .41936 .39077 L F
.104 .416 .864 r
.292 .41457 m .29498 .41098 L .30147 .41895 L F
.292 .41457 m .28552 .40639 L .29498 .41098 L F
.861 .796 .785 r
.44491 .3443 m .43884 .33814 L .4494 .32518 L F
.886 .816 .774 r
.43436 .3578 m .43884 .33814 L .44491 .3443 L F
.772 .789 .867 r
.14736 .38473 m .15035 .37164 L .15751 .37765 L F
.14736 .38473 m .14016 .37881 L .15035 .37164 L F
.687 .683 .84 r
.47622 .31593 m .48072 .3016 L .48659 .31188 L F
.47622 .31593 m .47032 .30647 L .48072 .3016 L F
.656 .751 .92 r
.77125 .39429 m .77732 .38427 L .78218 .39082 L F
.77125 .39429 m .76636 .38777 L .77732 .38427 L F
.509 .681 .943 r
.59529 .3929 m .60046 .38571 L .60595 .39182 L F
.59529 .3929 m .58977 .38614 L .60046 .38571 L F
.693 .757 .901 r
.19478 .36514 m .19779 .35395 L .20468 .36099 L F
.19478 .36514 m .18783 .35846 L .19779 .35395 L F
.363 .548 .901 r
.56292 .37637 m .56789 .37044 L .57353 .37816 L F
.56292 .37637 m .55726 .36791 L .56789 .37044 L F
.656 .751 .92 r
.79794 .39387 m .80416 .38385 L .80892 .3904 L F
.79794 .39387 m .79315 .38734 L .80416 .38385 L F
.383 .598 .932 r
.23755 .37295 m .24036 .36644 L .24703 .37446 L F
.23755 .37295 m .23085 .36522 L .24036 .36644 L F
.43 .613 .926 r
.57912 .38575 m .5842 .37931 L .58977 .38614 L F
.57912 .38575 m .57353 .37816 L .5842 .37931 L F
.656 .751 .92 r
.82465 .39344 m .83101 .38342 L .83568 .38997 L F
.82465 .39344 m .81994 .38691 L .83101 .38342 L F
.672 .77 .924 r
.35661 .45074 m .36041 .44085 L .36682 .44605 L F
.35661 .45074 m .35022 .4447 L .36041 .44085 L F
.231 .504 .904 r
.25365 .38247 m .25644 .37753 L .26305 .38571 L F
.25365 .38247 m .24703 .37446 L .25644 .37753 L F
.771 .787 .867 r
.15751 .37765 m .16055 .3645 L .16766 .37067 L F
.15751 .37765 m .15035 .37164 L .16055 .3645 L F
.526 .678 .934 r
.22124 .36576 m .22411 .35747 L .23085 .36522 L F
.22124 .36576 m .21445 .35836 L .22411 .35747 L F
.341 .492 .864 r
.52478 .34334 m .5295 .33674 L .53527 .34647 L F
.52478 .34334 m .51901 .3333 L .5295 .33674 L F
.735 .779 .888 r
.10997 .39799 m .11264 .38615 L .11994 .39217 L F
.10997 .39799 m .10266 .39188 L .11264 .38615 L F
.656 .751 .92 r
.85136 .39302 m .85787 .38299 L .86245 .38955 L F
.85136 .39302 m .84676 .38649 L .85787 .38299 L F
.177 .468 .889 r
.30792 .42692 m .31107 .42277 L .31754 .43031 L F
.30792 .42692 m .30147 .41895 L .31107 .42277 L F
.886 .816 .774 r
.43436 .3578 m .42821 .35266 L .43884 .33814 L F
.901 .832 .769 r
.42376 .37229 m .42821 .35266 L .43436 .3578 L F
.9 .854 .788 r
.40876 .40472 m .40246 .40124 L .41311 .38702 L F
.888 .857 .805 r
.39818 .41778 m .40246 .40124 L .40876 .40472 L F
.669 .782 .933 r
.67536 .3932 m .68092 .38349 L .6861 .38952 L F
.67536 .3932 m .67015 .38736 L .68092 .38349 L F
.611 .766 .954 r
.62204 .39563 m .62735 .38737 L .63271 .39274 L F
.62204 .39563 m .61663 .38996 L .62735 .38737 L F
.662 .761 .924 r
.70202 .39217 m .70772 .38219 L .71283 .38865 L F
.70202 .39217 m .69689 .38584 L .70772 .38219 L F
.684 .762 .911 r
.08305 .40119 m .08542 .39061 L .09279 .39689 L F
.08305 .40119 m .07567 .39481 L .08542 .39061 L F
.661 .794 .945 r
.64871 .39482 m .65415 .38567 L .65941 .39116 L F
.64871 .39482 m .64342 .38939 L .65415 .38567 L F
.656 .752 .92 r
.72873 .39167 m .73457 .38161 L .73959 .38819 L F
.72873 .39167 m .72368 .38513 L .73457 .38161 L F
.761 .783 .871 r
.16766 .37067 m .17073 .35774 L .17778 .36415 L F
.16766 .37067 m .16055 .3645 L .17073 .35774 L F
.116 .427 .87 r
.26961 .39388 m .27244 .39005 L .279 .39822 L F
.26961 .39388 m .26305 .38571 L .27244 .39005 L F
.656 .751 .92 r
.75545 .39124 m .76143 .3812 L .76636 .38777 L F
.75545 .39124 m .75049 .3847 L .76143 .3812 L F
.583 .619 .854 r
.48659 .31188 m .49111 .29996 L .49697 .31075 L F
.48659 .31188 m .48072 .3016 L .49111 .29996 L F
.513 .685 .944 r
.3402 .44612 m .34378 .43861 L .35022 .4447 L F
.3402 .44612 m .33378 .43924 L .34378 .43861 L F
.329 .571 .928 r
.32397 .43784 m .32733 .43235 L .33378 .43924 L F
.32397 .43784 m .31754 .43031 L .32733 .43235 L F
.634 .73 .917 r
.20468 .36099 m .20762 .35094 L .21445 .35836 L F
.20468 .36099 m .19779 .35395 L .20762 .35094 L F
.753 .784 .879 r
.11994 .39217 m .12273 .37975 L .13001 .38573 L F
.11994 .39217 m .11264 .38615 L .12273 .37975 L F
.656 .751 .92 r
.78218 .39082 m .78832 .38077 L .79315 .38734 L F
.78218 .39082 m .77732 .38427 L .78832 .38077 L F
.298 .482 .871 r
.541 .35595 m .54584 .35038 L .55157 .35925 L F
.541 .35595 m .53527 .34647 L .54584 .35038 L F
.444 .541 .861 r
.5028 .32126 m .50739 .31239 L .51321 .32299 L F
.5028 .32126 m .49697 .31075 L .50739 .31239 L F
.76 .816 .897 r
.36682 .44605 m .37076 .43441 L .37717 .43886 L F
.36682 .44605 m .36041 .44085 L .37076 .43441 L F
.656 .751 .92 r
.80892 .3904 m .81521 .38034 L .81994 .38691 L F
.80892 .3904 m .80416 .38385 L .81521 .38034 L F
.783 .735 .808 r
.45988 .31445 m .46439 .29683 L .47032 .30647 L F
.45988 .31445 m .45391 .3059 L .46439 .29683 L F
.836 .769 .788 r
.4494 .32518 m .45391 .3059 L .45988 .31445 L F
.888 .857 .805 r
.39818 .41778 m .39182 .41425 L .40246 .40124 L F
.864 .855 .831 r
.38763 .42933 m .39182 .41425 L .39818 .41778 L F
.656 .751 .92 r
.83568 .38997 m .84211 .37991 L .84676 .38649 L F
.83568 .38997 m .83101 .38342 L .84211 .37991 L F
.74 .774 .881 r
.17778 .36415 m .18084 .35173 L .18783 .35846 L F
.17778 .36415 m .17073 .35774 L .18084 .35173 L F
.836 .769 .788 r
.4494 .32518 m .44335 .31782 L .45391 .3059 L F
.872 .795 .772 r
.43884 .33814 m .44335 .31782 L .4494 .32518 L F
.901 .832 .769 r
.42376 .37229 m .41753 .36796 L .42821 .35266 L F
.906 .844 .773 r
.41311 .38702 m .41753 .36796 L .42376 .37229 L F
.549 .724 .956 r
.60595 .39182 m .61119 .38438 L .61663 .38996 L F
.60595 .39182 m .60046 .38571 L .61119 .38438 L F
.707 .687 .829 r
.47032 .30647 m .47482 .29107 L .48072 .3016 L F
.47032 .30647 m .46439 .29683 L .47482 .29107 L F
.766 .787 .871 r
.13001 .38573 m .13291 .37282 L .14016 .37881 L F
.13001 .38573 m .12273 .37975 L .13291 .37282 L F
.823 .843 .863 r
.37717 .43886 m .38124 .42546 L .38763 .42933 L F
.37717 .43886 m .37076 .43441 L .38124 .42546 L F
.076 .4 .856 r
.28552 .40639 m .28845 .40301 L .29498 .41098 L F
.28552 .40639 m .279 .39822 L .28845 .40301 L F
.864 .855 .831 r
.38763 .42933 m .38124 .42546 L .39182 .41425 L F
.709 .771 .901 r
.09279 .39689 m .09529 .3857 L .10266 .39188 L F
.09279 .39689 m .08542 .39061 L .09529 .3857 L F
.654 .752 .921 r
.06604 .39837 m .06824 .38837 L .07567 .39481 L F
.06604 .39837 m .0586 .39185 L .06824 .38837 L F
.67 .776 .929 r
.6861 .38952 m .69173 .37961 L .69689 .38584 L F
.6861 .38952 m .68092 .38349 L .69173 .37961 L F
.314 .515 .892 r
.55726 .36791 m .56222 .36257 L .56789 .37044 L F
.55726 .36791 m .55157 .35925 L .56222 .36257 L F
.66 .757 .921 r
.71283 .38865 m .71859 .37855 L .72368 .38513 L F
.71283 .38865 m .70772 .38219 L .71859 .37855 L F
.327 .478 .858 r
.51901 .3333 m .52371 .32673 L .5295 .33674 L F
.51901 .3333 m .51321 .32299 L .52371 .32673 L F
.671 .796 .942 r
.65941 .39116 m .66491 .38172 L .67015 .38736 L F
.65941 .39116 m .65415 .38567 L .66491 .38172 L F
.638 .789 .955 r
.63271 .39274 m .63809 .38415 L .64342 .38939 L F
.63271 .39274 m .62735 .38737 L .63809 .38415 L F
.656 .751 .92 r
.73959 .38819 m .7455 .37809 L .75049 .3847 L F
.73959 .38819 m .73457 .38161 L .7455 .37809 L F
.404 .61 .933 r
.23085 .36522 m .23365 .3584 L .24036 .36644 L F
.23085 .36522 m .22411 .35747 L .23365 .3584 L F
.465 .659 .945 r
.58977 .38614 m .59493 .3796 L .60046 .38571 L F
.58977 .38614 m .5842 .37931 L .59493 .3796 L F
.656 .751 .92 r
.76636 .38777 m .77242 .37768 L .77732 .38427 L F
.76636 .38777 m .76143 .3812 L .77242 .37768 L F
.872 .795 .772 r
.43884 .33814 m .43272 .33195 L .44335 .31782 L F
.894 .814 .762 r
.42821 .35266 m .43272 .33195 L .43884 .33814 L F
.773 .788 .866 r
.14016 .37881 m .14314 .36557 L .15035 .37164 L F
.14016 .37881 m .13291 .37282 L .14314 .36557 L F
.704 .76 .895 r
.18783 .35846 m .19085 .34686 L .19779 .35395 L F
.18783 .35846 m .18084 .35173 L .19085 .34686 L F
.377 .581 .921 r
.57353 .37816 m .5786 .37241 L .5842 .37931 L F
.57353 .37816 m .56789 .37044 L .5786 .37241 L F
.244 .513 .908 r
.24703 .37446 m .24979 .36933 L .25644 .37753 L F
.24703 .37446 m .24036 .36644 L .24979 .36933 L F
.656 .751 .92 r
.79315 .38734 m .79936 .37725 L .80416 .38385 L F
.79315 .38734 m .78832 .38077 L .79936 .37725 L F
.546 .687 .931 r
.21445 .35836 m .21732 .34968 L .22411 .35747 L F
.21445 .35836 m .20762 .35094 L .21732 .34968 L F
.656 .751 .92 r
.81994 .38691 m .8263 .37682 L .83101 .38342 L F
.81994 .38691 m .81521 .38034 L .8263 .37682 L F
.129 .441 .877 r
.30147 .41895 m .30455 .41522 L .31107 .42277 L F
.30147 .41895 m .29498 .41098 L .30455 .41522 L F
.602 .623 .845 r
.48072 .3016 m .48523 .28886 L .49111 .29996 L F
.48072 .3016 m .47482 .29107 L .48523 .28886 L F
.906 .844 .773 r
.41311 .38702 m .40681 .38324 L .41753 .36796 L F
.901 .852 .785 r
.40246 .40124 m .40681 .38324 L .41311 .38702 L F
.636 .759 .937 r
.35022 .4447 m .35395 .43556 L .36041 .44085 L F
.35022 .4447 m .34378 .43861 L .35395 .43556 L F
.656 .751 .92 r
.84676 .38649 m .85326 .37639 L .85787 .38299 L F
.84676 .38649 m .84211 .37991 L .85326 .37639 L F
.732 .778 .89 r
.10266 .39188 m .10529 .38005 L .11264 .38615 L F
.10266 .39188 m .09529 .3857 L .10529 .38005 L F
.773 .787 .864 r
.15035 .37164 m .15339 .35827 L .16055 .3645 L F
.15035 .37164 m .14314 .36557 L .15339 .35827 L F
.453 .54 .856 r
.49697 .31075 m .50154 .30146 L .50739 .31239 L F
.49697 .31075 m .49111 .29996 L .50154 .30146 L F
.112 .426 .869 r
.26305 .38571 m .26583 .38186 L .27244 .39005 L F
.26305 .38571 m .25644 .37753 L .26583 .38186 L F
.262 .454 .86 r
.53527 .34647 m .54008 .34128 L .54584 .35038 L F
.53527 .34647 m .5295 .33674 L .54008 .34128 L F
.668 .768 .925 r
.69689 .38584 m .70258 .37575 L .70772 .38219 L F
.69689 .38584 m .69173 .37961 L .70258 .37575 L F
.679 .761 .913 r
.07567 .39481 m .07799 .38428 L .08542 .39061 L F
.07567 .39481 m .06824 .38837 L .07799 .38428 L F
.677 .793 .936 r
.67015 .38736 m .6757 .37762 L .68092 .38349 L F
.67015 .38736 m .66491 .38172 L .6757 .37762 L F
.27 .54 .92 r
.31754 .43031 m .32082 .42542 L .32733 .43235 L F
.31754 .43031 m .31107 .42277 L .32082 .42542 L F
.659 .753 .92 r
.72368 .38513 m .72951 .37495 L .73457 .38161 L F
.72368 .38513 m .71859 .37855 L .72951 .37495 L F
.589 .763 .962 r
.61663 .38996 m .62194 .38216 L .62735 .38737 L F
.61663 .38996 m .61119 .38438 L .62194 .38216 L F
.894 .814 .762 r
.42821 .35266 m .42201 .3475 L .43272 .33195 L F
.906 .83 .76 r
.41753 .36796 m .42201 .3475 L .42821 .35266 L F
.461 .662 .949 r
.33378 .43924 m .33729 .43246 L .34378 .43861 L F
.33378 .43924 m .32733 .43235 L .33729 .43246 L F
.765 .783 .867 r
.16055 .3645 m .16362 .35127 L .17073 .35774 L F
.16055 .3645 m .15339 .35827 L .16362 .35127 L F
.8 .736 .793 r
.45391 .3059 m .45843 .28698 L .46439 .29683 L F
.45391 .3059 m .44789 .29721 L .45843 .28698 L F
.849 .769 .773 r
.44335 .31782 m .44789 .29721 L .45391 .3059 L F
.649 .735 .912 r
.19779 .35395 m .20074 .34348 L .20762 .35094 L F
.19779 .35395 m .19085 .34686 L .20074 .34348 L F
.66 .803 .951 r
.64342 .38939 m .64885 .38041 L .65415 .38567 L F
.64342 .38939 m .63809 .38415 L .64885 .38041 L F
.656 .751 .92 r
.75049 .3847 m .75647 .37456 L .76143 .3812 L F
.75049 .3847 m .7455 .37809 L .75647 .37456 L F
.727 .691 .816 r
.46439 .29683 m .4689 .28026 L .47482 .29107 L F
.46439 .29683 m .45843 .28698 L .4689 .28026 L F
.656 .751 .92 r
.77732 .38427 m .78345 .37415 L .78832 .38077 L F
.77732 .38427 m .77242 .37768 L .78345 .37415 L F
.751 .784 .88 r
.11264 .38615 m .1154 .3737 L .12273 .37975 L F
.11264 .38615 m .10529 .38005 L .1154 .3737 L F
.315 .464 .851 r
.51321 .32299 m .51788 .31642 L .52371 .32673 L F
.51321 .32299 m .50739 .31239 L .51788 .31642 L F
.901 .852 .785 r
.40246 .40124 m .39609 .3977 L .40681 .38324 L F
.887 .857 .807 r
.39182 .41425 m .39609 .3977 L .40246 .40124 L F
.656 .751 .92 r
.80416 .38385 m .81044 .37372 L .81521 .38034 L F
.80416 .38385 m .79936 .37725 L .81044 .37372 L F
.051 .385 .847 r
.279 .39822 m .28187 .39503 L .28845 .40301 L F
.279 .39822 m .27244 .39005 L .28187 .39503 L F
.849 .769 .773 r
.44335 .31782 m .43727 .31038 L .44789 .29721 L F
.881 .793 .758 r
.43272 .33195 m .43727 .31038 L .44335 .31782 L F
.656 .751 .92 r
.83101 .38342 m .83744 .37328 L .84211 .37991 L F
.83101 .38342 m .8263 .37682 L .83744 .37328 L F
.738 .812 .91 r
.36041 .44085 m .3643 .42986 L .37076 .43441 L F
.36041 .44085 m .35395 .43556 L .3643 .42986 L F
.26 .478 .88 r
.55157 .35925 m .55651 .35453 L .56222 .36257 L F
.55157 .35925 m .54584 .35038 L .55651 .35453 L F
.747 .775 .876 r
.17073 .35774 m .17379 .34496 L .18084 .35173 L F
.17073 .35774 m .16362 .35127 L .17379 .34496 L F
.51 .709 .961 r
.60046 .38571 m .6057 .37889 L .61119 .38438 L F
.60046 .38571 m .59493 .3796 L .6057 .37889 L F
.765 .787 .871 r
.12273 .37975 m .12561 .36676 L .13291 .37282 L F
.12273 .37975 m .1154 .3737 L .12561 .36676 L F
.705 .77 .903 r
.08542 .39061 m .08787 .37947 L .09529 .3857 L F
.08542 .39061 m .07799 .38428 L .08787 .37947 L F
.621 .628 .836 r
.47482 .29107 m .47933 .27742 L .48523 .28886 L F
.47482 .29107 m .4689 .28026 L .47933 .27742 L F
.65 .751 .923 r
.0586 .39185 m .06075 .38188 L .06824 .38837 L F
.0586 .39185 m .05111 .38527 L .06075 .38188 L F
.887 .857 .807 r
.39182 .41425 m .3854 .41064 L .39609 .3977 L F
.858 .855 .837 r
.38124 .42546 m .3854 .41064 L .39182 .41425 L F
.424 .621 .934 r
.22411 .35747 m .2269 .35032 L .23365 .3584 L F
.22411 .35747 m .21732 .34968 L .2269 .35032 L F
.463 .539 .85 r
.49111 .29996 m .49566 .29019 L .50154 .30146 L F
.49111 .29996 m .48523 .28886 L .49566 .29019 L F
.666 .761 .921 r
.70772 .38219 m .71347 .37194 L .71859 .37855 L F
.70772 .38219 m .70258 .37575 L .71347 .37194 L F
.679 .786 .931 r
.68092 .38349 m .68653 .37348 L .69173 .37961 L F
.68092 .38349 m .6757 .37762 L .68653 .37348 L F
.258 .522 .911 r
.24036 .36644 m .2431 .36111 L .24979 .36933 L F
.24036 .36644 m .23365 .3584 L .2431 .36111 L F
.317 .543 .912 r
.56789 .37044 m .57296 .36543 L .5786 .37241 L F
.56789 .37044 m .56222 .36257 L .57296 .36543 L F
.906 .83 .76 r
.41753 .36796 m .41125 .36363 L .42201 .3475 L F
.909 .842 .767 r
.40681 .38324 m .41125 .36363 L .41753 .36796 L F
.658 .75 .918 r
.73457 .38161 m .74046 .37136 L .7455 .37809 L F
.73457 .38161 m .72951 .37495 L .74046 .37136 L F
.81 .842 .874 r
.37076 .43441 m .37479 .42149 L .38124 .42546 L F
.37076 .43441 m .3643 .42986 L .37479 .42149 L F
.411 .629 .944 r
.5842 .37931 m .58937 .3735 L .59493 .3796 L F
.5842 .37931 m .5786 .37241 L .58937 .3735 L F
.676 .808 .946 r
.65415 .38567 m .65964 .3763 L .66491 .38172 L F
.65415 .38567 m .64885 .38041 L .65964 .3763 L F
.656 .751 .92 r
.76143 .3812 m .76749 .37102 L .77242 .37768 L F
.76143 .3812 m .75647 .37456 L .76749 .37102 L F
.858 .855 .837 r
.38124 .42546 m .37479 .42149 L .3854 .41064 L F
.715 .762 .889 r
.18084 .35173 m .18386 .33973 L .19085 .34686 L F
.18084 .35173 m .17379 .34496 L .18386 .33973 L F
.083 .412 .863 r
.29498 .41098 m .29799 .40765 L .30455 .41522 L F
.29498 .41098 m .28845 .40301 L .29799 .40765 L F
.626 .793 .962 r
.62735 .38737 m .63272 .37913 L .63809 .38415 L F
.62735 .38737 m .62194 .38216 L .63272 .37913 L F
.224 .424 .848 r
.5295 .33674 m .53429 .33192 L .54008 .34128 L F
.5295 .33674 m .52371 .32673 L .53429 .33192 L F
.565 .695 .928 r
.20762 .35094 m .21049 .34186 L .21732 .34968 L F
.20762 .35094 m .20074 .34348 L .21049 .34186 L F
.881 .793 .758 r
.43272 .33195 m .42656 .32573 L .43727 .31038 L F
.901 .812 .751 r
.42201 .3475 m .42656 .32573 L .43272 .33195 L F
.656 .751 .92 r
.78832 .38077 m .79452 .3706 L .79936 .37725 L F
.78832 .38077 m .78345 .37415 L .79452 .3706 L F
.774 .788 .864 r
.13291 .37282 m .13588 .35943 L .14314 .36557 L F
.13291 .37282 m .12561 .36676 L .13588 .35943 L F
.656 .751 .92 r
.81521 .38034 m .82156 .37017 L .8263 .37682 L F
.81521 .38034 m .81044 .37372 L .82156 .37017 L F
.109 .425 .869 r
.25644 .37753 m .25918 .37365 L .26583 .38186 L F
.25644 .37753 m .24979 .36933 L .25918 .37365 L F
.656 .751 .92 r
.84211 .37991 m .84862 .36974 L .85326 .37639 L F
.84211 .37991 m .83744 .37328 L .84862 .36974 L F
.596 .746 .948 r
.34378 .43861 m .34745 .43019 L .35395 .43556 L F
.34378 .43861 m .33729 .43246 L .34745 .43019 L F
.745 .694 .803 r
.45843 .28698 m .46295 .26915 L .4689 .28026 L F
.45843 .28698 m .45244 .27691 L .46295 .26915 L F
.815 .737 .779 r
.44789 .29721 m .45244 .27691 L .45843 .28698 L F
.303 .451 .843 r
.50739 .31239 m .51203 .30578 L .51788 .31642 L F
.50739 .31239 m .50154 .30146 L .51203 .30578 L F
.729 .777 .892 r
.09529 .3857 m .09789 .3739 L .10529 .38005 L F
.09529 .3857 m .08787 .37947 L .09789 .3739 L F
.776 .787 .862 r
.14314 .36557 m .14617 .35198 L .15339 .35827 L F
.14314 .36557 m .13588 .35943 L .14617 .35198 L F
.815 .737 .779 r
.44789 .29721 m .44185 .28838 L .45244 .27691 L F
.86 .768 .759 r
.43727 .31038 m .44185 .28838 L .44789 .29721 L F
.21 .506 .909 r
.31107 .42277 m .31427 .41845 L .32082 .42542 L F
.31107 .42277 m .30455 .41522 L .31427 .41845 L F
.674 .76 .915 r
.06824 .38837 m .07051 .37789 L .07799 .38428 L F
.06824 .38837 m .06075 .38188 L .07051 .37789 L F
.678 .777 .926 r
.69173 .37961 m .6974 .36935 L .70258 .37575 L F
.69173 .37961 m .68653 .37348 L .6974 .36935 L F
.403 .635 .949 r
.32733 .43235 m .33076 .42626 L .33729 .43246 L F
.32733 .43235 m .32082 .42542 L .33076 .42626 L F
.663 .755 .918 r
.71859 .37855 m .72441 .36819 L .72951 .37495 L F
.71859 .37855 m .71347 .37194 L .72441 .36819 L F
.909 .842 .767 r
.40681 .38324 m .40045 .37944 L .41125 .36363 L F
.902 .851 .783 r
.39609 .3977 m .40045 .37944 L .40681 .38324 L F
.663 .739 .907 r
.19085 .34686 m .19381 .33597 L .20074 .34348 L F
.19085 .34686 m .18386 .33973 L .19381 .33597 L F
.657 .749 .918 r
.7455 .37809 m .75147 .36779 L .75647 .37456 L F
.7455 .37809 m .74046 .37136 L .75147 .36779 L F
.686 .806 .939 r
.66491 .38172 m .67046 .37195 L .6757 .37762 L F
.66491 .38172 m .65964 .3763 L .67046 .37195 L F
.77 .783 .864 r
.15339 .35827 m .15646 .34475 L .16362 .35127 L F
.15339 .35827 m .14617 .35198 L .15646 .34475 L F
.202 .436 .863 r
.54584 .35038 m .55077 .34631 L .55651 .35453 L F
.54584 .35038 m .54008 .34128 L .55077 .34631 L F
.64 .631 .826 r
.4689 .28026 m .47341 .2656 L .47933 .27742 L F
.4689 .28026 m .46295 .26915 L .47341 .2656 L F
.559 .756 .97 r
.61119 .38438 m .6165 .37713 L .62194 .38216 L F
.61119 .38438 m .6057 .37889 L .6165 .37713 L F
.027 .37 .839 r
.27244 .39005 m .27524 .38702 L .28187 .39503 L F
.27244 .39005 m .26583 .38186 L .27524 .38702 L F
.474 .539 .844 r
.48523 .28886 m .48976 .27852 L .49566 .29019 L F
.48523 .28886 m .47933 .27742 L .48976 .27852 L F
.656 .751 .92 r
.77242 .37768 m .77855 .36746 L .78345 .37415 L F
.77242 .37768 m .76749 .37102 L .77855 .36746 L F
.901 .812 .751 r
.42201 .3475 m .41576 .34235 L .42656 .32573 L F
.911 .828 .751 r
.41125 .36363 m .41576 .34235 L .42201 .3475 L F
.657 .812 .958 r
.63809 .38415 m .64352 .37541 L .64885 .38041 L F
.63809 .38415 m .63272 .37913 L .64352 .37541 L F
.749 .783 .881 r
.10529 .38005 m .10802 .36759 L .1154 .3737 L F
.10529 .38005 m .09789 .3739 L .10802 .36759 L F
.656 .751 .92 r
.79936 .37725 m .80563 .36705 L .81044 .37372 L F
.79936 .37725 m .79452 .3706 L .80563 .36705 L F
.86 .768 .759 r
.43727 .31038 m .43115 .30287 L .44185 .28838 L F
.89 .791 .746 r
.42656 .32573 m .43115 .30287 L .43727 .31038 L F
.656 .751 .92 r
.8263 .37682 m .83273 .36661 L .83744 .37328 L F
.8263 .37682 m .82156 .37017 L .83273 .36661 L F
.754 .776 .871 r
.16362 .35127 m .16669 .33814 L .17379 .34496 L F
.16362 .35127 m .15646 .34475 L .16669 .33814 L F
.186 .393 .833 r
.52371 .32673 m .52847 .32229 L .53429 .33192 L F
.52371 .32673 m .51788 .31642 L .52847 .32229 L F
.712 .807 .924 r
.35395 .43556 m .35779 .42523 L .3643 .42986 L F
.35395 .43556 m .34745 .43019 L .35779 .42523 L F
.444 .631 .934 r
.21732 .34968 m .2201 .3422 L .2269 .35032 L F
.21732 .34968 m .21049 .34186 L .2201 .3422 L F
.272 .531 .914 r
.23365 .3584 m .23636 .35285 L .2431 .36111 L F
.23365 .3584 m .2269 .35032 L .23636 .35285 L F
.248 .498 .897 r
.56222 .36257 m .56727 .35836 L .57296 .36543 L F
.56222 .36257 m .55651 .35453 L .56727 .35836 L F
.46 .687 .964 r
.59493 .3796 m .60018 .37351 L .6057 .37889 L F
.59493 .3796 m .58937 .3735 L .60018 .37351 L F
.902 .851 .783 r
.39609 .3977 m .38967 .39413 L .40045 .37944 L F
.885 .857 .809 r
.3854 .41064 m .38967 .39413 L .39609 .3977 L F
.645 .749 .925 r
.05111 .38527 m .05321 .37534 L .06075 .38188 L F
.05111 .38527 m .04357 .37865 L .05321 .37534 L F
.7 .769 .905 r
.07799 .38428 m .0804 .37317 L .08787 .37947 L F
.07799 .38428 m .07051 .37789 L .0804 .37317 L F
.293 .437 .835 r
.50154 .30146 m .50614 .29477 L .51203 .30578 L F
.50154 .30146 m .49566 .29019 L .50614 .29477 L F
.765 .786 .871 r
.1154 .3737 m .11825 .36065 L .12561 .36676 L F
.1154 .3737 m .10802 .36759 L .11825 .36065 L F
.037 .383 .846 r
.28845 .40301 m .29138 .40005 L .29799 .40765 L F
.28845 .40301 m .28187 .39503 L .29138 .40005 L F
.674 .767 .921 r
.70258 .37575 m .70831 .36529 L .71347 .37194 L F
.70258 .37575 m .6974 .36935 L .70831 .36529 L F
.661 .75 .916 r
.72951 .37495 m .73539 .3645 L .74046 .37136 L F
.72951 .37495 m .72441 .36819 L .73539 .3645 L F
.345 .592 .937 r
.5786 .37241 m .58376 .36743 L .58937 .3735 L F
.5786 .37241 m .57296 .36543 L .58376 .36743 L F
.762 .696 .789 r
.45244 .27691 m .45699 .25772 L .46295 .26915 L F
.45244 .27691 m .44643 .26659 L .45699 .25772 L F
.828 .738 .765 r
.44185 .28838 m .44643 .26659 L .45244 .27691 L F
.69 .799 .932 r
.6757 .37762 m .68131 .36748 L .68653 .37348 L F
.6757 .37762 m .67046 .37195 L .68131 .36748 L F
.582 .702 .924 r
.20074 .34348 m .20361 .334 L .21049 .34186 L F
.20074 .34348 m .19381 .33597 L .20361 .334 L F
.656 .748 .918 r
.75647 .37456 m .76251 .36422 L .76749 .37102 L F
.75647 .37456 m .75147 .36779 L .76251 .36422 L F
.724 .763 .884 r
.17379 .34496 m .17682 .33256 L .18386 .33973 L F
.17379 .34496 m .16669 .33814 L .17682 .33256 L F
.109 .425 .869 r
.24979 .36933 m .25249 .36539 L .25918 .37365 L F
.24979 .36933 m .2431 .36111 L .25249 .36539 L F
.656 .751 .92 r
.78345 .37415 m .78965 .3639 L .79452 .3706 L F
.78345 .37415 m .77855 .36746 L .78965 .3639 L F
.68 .821 .951 r
.64885 .38041 m .65434 .37114 L .65964 .3763 L F
.64885 .38041 m .64352 .37541 L .65434 .37114 L F
.89 .791 .746 r
.42656 .32573 m .42034 .31948 L .43115 .30287 L F
.907 .81 .74 r
.41576 .34235 m .42034 .31948 L .42656 .32573 L F
.487 .539 .836 r
.47933 .27742 m .48385 .26644 L .48976 .27852 L F
.47933 .27742 m .47341 .2656 L .48385 .26644 L F
.797 .841 .885 r
.3643 .42986 m .36829 .41745 L .37479 .42149 L F
.3643 .42986 m .35779 .42523 L .36829 .41745 L F
.828 .738 .765 r
.44185 .28838 m .43577 .2794 L .44643 .26659 L F
.871 .767 .745 r
.43115 .30287 m .43577 .2794 L .44185 .28838 L F
.775 .787 .863 r
.12561 .36676 m .12856 .35324 L .13588 .35943 L F
.12561 .36676 m .11825 .36065 L .12856 .35324 L F
.885 .857 .809 r
.3854 .41064 m .37893 .40698 L .38967 .39413 L F
.852 .855 .844 r
.37479 .42149 m .37893 .40698 L .3854 .41064 L F
.659 .635 .815 r
.46295 .26915 m .46747 .25339 L .47341 .2656 L F
.46295 .26915 m .45699 .25772 L .46747 .25339 L F
.656 .751 .92 r
.81044 .37372 m .81679 .36347 L .82156 .37017 L F
.81044 .37372 m .80563 .36705 L .81679 .36347 L F
.911 .828 .751 r
.41125 .36363 m .40491 .3593 L .41576 .34235 L F
.912 .841 .761 r
.40045 .37944 m .40491 .3593 L .41125 .36363 L F
.608 .795 .971 r
.62194 .38216 m .62733 .37436 L .63272 .37913 L F
.62194 .38216 m .6165 .37713 L .62733 .37436 L F
.656 .751 .92 r
.83744 .37328 m .84394 .36304 L .84862 .36974 L F
.83744 .37328 m .83273 .36661 L .84394 .36304 L F
.149 .469 .892 r
.30455 .41522 m .30767 .41145 L .31427 .41845 L F
.30455 .41522 m .29799 .40765 L .30767 .41145 L F
.852 .855 .844 r
.37479 .42149 m .36829 .41745 L .37893 .40698 L F
.551 .729 .957 r
.33729 .43246 m .34089 .42476 L .34745 .43019 L F
.33729 .43246 m .33076 .42626 L .34089 .42476 L F
.725 .777 .894 r
.08787 .37947 m .09043 .36768 L .09789 .3739 L F
.08787 .37947 m .0804 .37317 L .09043 .36768 L F
.139 .389 .841 r
.54008 .34128 m .54498 .33791 L .55077 .34631 L F
.54008 .34128 m .53429 .33192 L .54498 .33791 L F
.778 .786 .86 r
.13588 .35943 m .13891 .34564 L .14617 .35198 L F
.13588 .35943 m .12856 .35324 L .13891 .34564 L F
.341 .603 .945 r
.32082 .42542 m .32417 .42 L .33076 .42626 L F
.32082 .42542 m .31427 .41845 L .32417 .42 L F
.005 .356 .83 r
.26583 .38186 m .26858 .37896 L .27524 .38702 L F
.26583 .38186 m .25918 .37365 L .26858 .37896 L F
.67 .759 .917 r
.06075 .38188 m .06297 .37144 L .07051 .37789 L F
.06075 .38188 m .05321 .37534 L .06297 .37144 L F
.676 .743 .901 r
.18386 .33973 m .18683 .32842 L .19381 .33597 L F
.18386 .33973 m .17682 .33256 L .18683 .32842 L F
.67 .758 .916 r
.71347 .37194 m .71927 .36133 L .72441 .36819 L F
.71347 .37194 m .70831 .36529 L .71927 .36133 L F
.69 .788 .925 r
.68653 .37348 m .69219 .36301 L .6974 .36935 L F
.68653 .37348 m .68131 .36748 L .69219 .36301 L F
.146 .36 .817 r
.51788 .31642 m .52261 .31235 L .52847 .32229 L F
.51788 .31642 m .51203 .30578 L .52261 .31235 L F
.658 .746 .915 r
.74046 .37136 m .74642 .36086 L .75147 .36779 L F
.74046 .37136 m .73539 .3645 L .74642 .36086 L F
.284 .424 .827 r
.49566 .29019 m .50024 .28338 L .50614 .29477 L F
.49566 .29019 m .48976 .27852 L .50024 .28338 L F
.774 .783 .86 r
.14617 .35198 m .14925 .33818 L .15646 .34475 L F
.14617 .35198 m .13891 .34564 L .14925 .33818 L F
.655 .748 .918 r
.76749 .37102 m .7736 .36066 L .77855 .36746 L F
.76749 .37102 m .76251 .36422 L .7736 .36066 L F
.871 .767 .745 r
.43115 .30287 m .42498 .29528 L .43577 .2794 L F
.897 .789 .733 r
.42034 .31948 m .42498 .29528 L .43115 .30287 L F
.696 .821 .942 r
.65964 .3763 m .66518 .36649 L .67046 .37195 L F
.65964 .3763 m .65434 .37114 L .66518 .36649 L F
.656 .751 .92 r
.79452 .3706 m .80079 .36032 L .80563 .36705 L F
.79452 .3706 m .78965 .3639 L .80079 .36032 L F
.52 .745 .977 r
.6057 .37889 m .61102 .3723 L .6165 .37713 L F
.6057 .37889 m .60018 .37351 L .61102 .3723 L F
.747 .782 .882 r
.09789 .3739 m .10058 .36142 L .10802 .36759 L F
.09789 .3739 m .09043 .36768 L .10058 .36142 L F
.778 .698 .775 r
.44643 .26659 m .45101 .24592 L .45699 .25772 L F
.44643 .26659 m .44039 .25601 L .45101 .24592 L F
.84 .737 .75 r
.43577 .2794 m .44039 .25601 L .44643 .26659 L F
.656 .751 .92 r
.82156 .37017 m .82799 .35989 L .83273 .36661 L F
.82156 .37017 m .81679 .36347 L .82799 .35989 L F
.912 .841 .761 r
.40045 .37944 m .39404 .37565 L .40491 .3593 L F
.904 .851 .781 r
.38967 .39413 m .39404 .37565 L .40045 .37944 L F
.5 .54 .829 r
.47341 .2656 m .47791 .25391 L .48385 .26644 L F
.47341 .2656 m .46747 .25339 L .47791 .25391 L F
.287 .54 .917 r
.2269 .35032 m .22958 .34454 L .23636 .35285 L F
.2269 .35032 m .2201 .3422 L .22958 .34454 L F
.464 .641 .933 r
.21049 .34186 m .21325 .33403 L .2201 .3422 L F
.21049 .34186 m .20361 .334 L .21325 .33403 L F
.169 .444 .875 r
.55651 .35453 m .56155 .35121 L .56727 .35836 L F
.55651 .35453 m .55077 .34631 L .56155 .35121 L F
.907 .81 .74 r
.41576 .34235 m .40946 .3372 L .42034 .31948 L F
.916 .826 .743 r
.40491 .3593 m .40946 .3372 L .41576 .34235 L F
.65 .822 .966 r
.63272 .37913 m .63816 .37069 L .64352 .37541 L F
.63272 .37913 m .62733 .37436 L .63816 .37069 L F
.677 .637 .803 r
.45699 .25772 m .46151 .24073 L .46747 .25339 L F
.45699 .25772 m .45101 .24592 L .46151 .24073 L F
.76 .776 .866 r
.15646 .34475 m .15954 .33127 L .16669 .33814 L F
.15646 .34475 m .14925 .33818 L .15954 .33127 L F
0 .354 .828 r
.28187 .39503 m .28473 .3924 L .29138 .40005 L F
.28187 .39503 m .27524 .38702 L .28473 .3924 L F
.683 .8 .937 r
.34745 .43019 m .35122 .42053 L .35779 .42523 L F
.34745 .43019 m .34089 .42476 L .35122 .42053 L F
.397 .657 .963 r
.58937 .3735 m .59461 .36826 L .60018 .37351 L F
.58937 .3735 m .58376 .36743 L .59461 .36826 L F
.696 .768 .907 r
.07051 .37789 m .07287 .36682 L .0804 .37317 L F
.07051 .37789 m .06297 .37144 L .07287 .36682 L F
.109 .426 .87 r
.2431 .36111 m .24575 .3571 L .25249 .36539 L F
.2431 .36111 m .23636 .35285 L .24575 .3571 L F
.266 .545 .924 r
.57296 .36543 m .57811 .36138 L .58376 .36743 L F
.57296 .36543 m .56727 .35836 L .57811 .36138 L F
.599 .708 .92 r
.19381 .33597 m .19668 .32608 L .20361 .334 L F
.19381 .33597 m .18683 .32842 L .19668 .32608 L F
.686 .775 .919 r
.6974 .36935 m .70311 .35861 L .70831 .36529 L F
.6974 .36935 m .69219 .36301 L .70311 .35861 L F
.666 .75 .913 r
.72441 .36819 m .73027 .35747 L .73539 .3645 L F
.72441 .36819 m .71927 .36133 L .73027 .35747 L F
.764 .786 .871 r
.10802 .36759 m .11084 .35447 L .11825 .36065 L F
.10802 .36759 m .10058 .36142 L .11084 .35447 L F
.84 .737 .75 r
.43577 .2794 m .42965 .27024 L .44039 .25601 L F
.88 .765 .732 r
.42498 .29528 m .42965 .27024 L .43577 .2794 L F
.656 .744 .915 r
.75147 .36779 m .75749 .35726 L .76251 .36422 L F
.75147 .36779 m .74642 .36086 L .75749 .35726 L F
.733 .765 .878 r
.16669 .33814 m .16974 .32534 L .17682 .33256 L F
.16669 .33814 m .15954 .33127 L .16974 .32534 L F
.703 .813 .933 r
.67046 .37195 m .67605 .36164 L .68131 .36748 L F
.67046 .37195 m .66518 .36649 L .67605 .36164 L F
.071 .338 .814 r
.53429 .33192 m .53916 .32929 L .54498 .33791 L F
.53429 .33192 m .52847 .32229 L .53916 .32929 L F
.655 .748 .918 r
.77855 .36746 m .78474 .35708 L .78965 .3639 L F
.77855 .36746 m .7736 .36066 L .78474 .35708 L F
.277 .411 .818 r
.48976 .27852 m .49431 .27156 L .50024 .28338 L F
.48976 .27852 m .48385 .26644 L .49431 .27156 L F
.904 .851 .781 r
.38967 .39413 m .38318 .39054 L .39404 .37565 L F
.883 .858 .811 r
.37893 .40698 m .38318 .39054 L .38967 .39413 L F
.106 .326 .798 r
.51203 .30578 m .51672 .30209 L .52261 .31235 L F
.51203 .30578 m .50614 .29477 L .51672 .30209 L F
.086 .43 .872 r
.29799 .40765 m .30103 .4044 L .30767 .41145 L F
.29799 .40765 m .29138 .40005 L .30103 .4044 L F
.656 .751 .92 r
.80563 .36705 m .81198 .35672 L .81679 .36347 L F
.80563 .36705 m .80079 .36032 L .81198 .35672 L F
.897 .789 .733 r
.42034 .31948 m .41408 .31321 L .42498 .29528 L F
.913 .808 .729 r
.40946 .3372 m .41408 .31321 L .42034 .31948 L F
.775 .787 .863 r
.11825 .36065 m .12119 .34699 L .12856 .35324 L F
.11825 .36065 m .11084 .35447 L .12119 .34699 L F
.656 .751 .92 r
.83273 .36661 m .83923 .35629 L .84394 .36304 L F
.83273 .36661 m .82799 .35989 L .83923 .35629 L F
.515 .54 .82 r
.46747 .25339 m .47196 .24089 L .47791 .25391 L F
.46747 .25339 m .46151 .24073 L .47196 .24089 L F
0 .343 .821 r
.25918 .37365 m .26187 .37087 L .26858 .37896 L F
.25918 .37365 m .25249 .36539 L .26187 .37087 L F
.684 .835 .956 r
.64352 .37541 m .64902 .36626 L .65434 .37114 L F
.64352 .37541 m .63816 .37069 L .64902 .36626 L F
.5 .707 .963 r
.33076 .42626 m .33428 .41927 L .34089 .42476 L F
.33076 .42626 m .32417 .42 L .33428 .41927 L F
.781 .84 .897 r
.35779 .42523 m .36173 .41336 L .36829 .41745 L F
.35779 .42523 m .35122 .42053 L .36173 .41336 L F
.583 .795 .98 r
.6165 .37713 m .62189 .36987 L .62733 .37436 L F
.6165 .37713 m .61102 .3723 L .62189 .36987 L F
.722 .776 .895 r
.0804 .37317 m .08291 .36141 L .09043 .36768 L F
.0804 .37317 m .07287 .36682 L .08291 .36141 L F
.694 .64 .79 r
.45101 .24592 m .45555 .2276 L .46151 .24073 L F
.45101 .24592 m .44501 .23374 L .45555 .2276 L F
.792 .698 .761 r
.44039 .25601 m .44501 .23374 L .45101 .24592 L F
.274 .566 .935 r
.31427 .41845 m .31754 .4137 L .32417 .42 L F
.31427 .41845 m .30767 .41145 L .31754 .4137 L F
.916 .826 .743 r
.40491 .3593 m .39851 .355 L .40946 .3372 L F
.915 .84 .756 r
.39404 .37565 m .39851 .355 L .40491 .3593 L F
.792 .698 .761 r
.44039 .25601 m .43433 .24515 L .44501 .23374 L F
.851 .736 .736 r
.42965 .27024 m .43433 .24515 L .44039 .25601 L F
.688 .746 .896 r
.17682 .33256 m .1798 .32082 L .18683 .32842 L F
.17682 .33256 m .16974 .32534 L .1798 .32082 L F
.883 .858 .811 r
.37893 .40698 m .3724 .40328 L .38318 .39054 L F
.845 .856 .852 r
.36829 .41745 m .3724 .40328 L .37893 .40698 L F
.78 .786 .858 r
.12856 .35324 m .13158 .33924 L .13891 .34564 L F
.12856 .35324 m .12119 .34699 L .13158 .33924 L F
.68 .762 .913 r
.70831 .36529 m .71408 .35435 L .71927 .36133 L F
.70831 .36529 m .70311 .35861 L .71408 .35435 L F
.845 .856 .852 r
.36829 .41745 m .36173 .41336 L .3724 .40328 L F
.661 .744 .911 r
.73539 .3645 m .74132 .35372 L .74642 .36086 L F
.73539 .3645 m .73027 .35747 L .74132 .35372 L F
.88 .765 .732 r
.42498 .29528 m .41878 .2876 L .42965 .27024 L F
.904 .787 .721 r
.41408 .31321 m .41878 .2876 L .42498 .29528 L F
.705 .8 .924 r
.68131 .36748 m .68695 .35673 L .69219 .36301 L F
.68131 .36748 m .67605 .36164 L .68695 .35673 L F
.655 .743 .915 r
.76251 .36422 m .76861 .35368 L .7736 .36066 L F
.76251 .36422 m .75749 .35726 L .76861 .35368 L F
.778 .783 .857 r
.13891 .34564 m .14198 .33156 L .14925 .33818 L F
.13891 .34564 m .13158 .33924 L .14198 .33156 L F
.303 .549 .919 r
.2201 .3422 m .22276 .33617 L .22958 .34454 L F
.2201 .3422 m .21325 .33403 L .22276 .33617 L F
.081 .381 .844 r
.55077 .34631 m .55578 .34397 L .56155 .35121 L F
.55077 .34631 m .54498 .33791 L .55578 .34397 L F
.483 .65 .932 r
.20361 .334 m .20637 .32582 L .21325 .33403 L F
.20361 .334 m .19668 .32608 L .20637 .32582 L F
.655 .749 .919 r
.78965 .3639 m .79591 .3535 L .80079 .36032 L F
.78965 .3639 m .78474 .35708 L .79591 .3535 L F
.271 .399 .809 r
.48385 .26644 m .48836 .25927 L .49431 .27156 L F
.48385 .26644 m .47791 .25391 L .48836 .25927 L F
0 .325 .809 r
.27524 .38702 m .27803 .38471 L .28473 .3924 L F
.27524 .38702 m .26858 .37896 L .27803 .38471 L F
.656 .751 .92 r
.81679 .36347 m .82321 .35311 L .82799 .35989 L F
.81679 .36347 m .81198 .35672 L .82321 .35311 L F
.745 .782 .883 r
.09043 .36768 m .09308 .35519 L .10058 .36142 L F
.09043 .36768 m .08291 .36141 L .09308 .35519 L F
.469 .728 .982 r
.60018 .37351 m .60551 .36771 L .61102 .3723 L F
.60018 .37351 m .59461 .36826 L .60551 .36771 L F
.707 .837 .945 r
.65434 .37114 m .65988 .36129 L .66518 .36649 L F
.65434 .37114 m .64902 .36626 L .65988 .36129 L F
.53 .541 .811 r
.46151 .24073 m .466 .22733 L .47196 .24089 L F
.46151 .24073 m .45555 .2276 L .466 .22733 L F
.851 .736 .736 r
.42965 .27024 m .42351 .2609 L .43433 .24515 L F
.888 .763 .718 r
.41878 .2876 m .42351 .2609 L .42965 .27024 L F
.11 .427 .87 r
.23636 .35285 m .23898 .34875 L .24575 .3571 L F
.23636 .35285 m .22958 .34454 L .23898 .34875 L F
.766 .777 .862 r
.14925 .33818 m .15234 .32435 L .15954 .33127 L F
.14925 .33818 m .14198 .33156 L .15234 .32435 L F
.066 .291 .778 r
.50614 .29477 m .5108 .29147 L .51672 .30209 L F
.50614 .29477 m .50024 .28338 L .5108 .29147 L F
0 .282 .782 r
.52847 .32229 m .5333 .32045 L .53916 .32929 L F
.52847 .32229 m .52261 .31235 L .5333 .32045 L F
.913 .808 .729 r
.40946 .3372 m .4031 .33207 L .41408 .31321 L F
.92 .824 .735 r
.39851 .355 m .4031 .33207 L .40946 .3372 L F
.615 .714 .916 r
.18683 .32842 m .18971 .31812 L .19668 .32608 L F
.18683 .32842 m .1798 .32082 L .18971 .31812 L F
.711 .641 .777 r
.44501 .23374 m .44957 .21396 L .45555 .2276 L F
.44501 .23374 m .43899 .22114 L .44957 .21396 L F
.806 .699 .747 r
.43433 .24515 m .43899 .22114 L .44501 .23374 L F
.172 .484 .9 r
.56727 .35836 m .57242 .35536 L .57811 .36138 L F
.56727 .35836 m .56155 .35121 L .57242 .35536 L F
.64 .831 .974 r
.62733 .37436 m .63277 .3663 L .63816 .37069 L F
.62733 .37436 m .62189 .36987 L .63277 .3663 L F
.673 .751 .909 r
.71927 .36133 m .72511 .35025 L .73027 .35747 L F
.71927 .36133 m .71408 .35435 L .72511 .35025 L F
.915 .84 .756 r
.39404 .37565 m .38756 .37187 L .39851 .355 L F
.905 .851 .779 r
.38318 .39054 m .38756 .37187 L .39404 .37565 L F
.318 .615 .955 r
.58376 .36743 m .58901 .36316 L .59461 .36826 L F
.58376 .36743 m .57811 .36138 L .58901 .36316 L F
.649 .791 .95 r
.34089 .42476 m .3446 .41578 L .35122 .42053 L F
.34089 .42476 m .33428 .41927 L .3446 .41578 L F
.701 .784 .916 r
.69219 .36301 m .69788 .35189 L .70311 .35861 L F
.69219 .36301 m .68695 .35673 L .69788 .35189 L F
.657 .739 .91 r
.74642 .36086 m .75243 .35007 L .75749 .35726 L F
.74642 .36086 m .74132 .35372 L .75243 .35007 L F
.763 .785 .871 r
.10058 .36142 m .10338 .34824 L .11084 .35447 L F
.10058 .36142 m .09308 .35519 L .10338 .34824 L F
.741 .766 .873 r
.15954 .33127 m .1626 .31807 L .16974 .32534 L F
.15954 .33127 m .15234 .32435 L .1626 .31807 L F
.806 .699 .747 r
.43433 .24515 m .42825 .23398 L .43899 .22114 L F
.861 .735 .722 r
.42351 .2609 m .42825 .23398 L .43433 .24515 L F
.023 .388 .848 r
.29138 .40005 m .29434 .39731 L .30103 .4044 L F
.29138 .40005 m .28473 .3924 L .29434 .39731 L F
.654 .743 .915 r
.7736 .36066 m .77978 .35012 L .78474 .35708 L F
.7736 .36066 m .76861 .35368 L .77978 .35012 L F
0 .329 .813 r
.25249 .36539 m .25511 .36272 L .26187 .37087 L F
.25249 .36539 m .24575 .3571 L .25511 .36272 L F
.655 .749 .919 r
.80079 .36032 m .80714 .3499 L .81198 .35672 L F
.80079 .36032 m .79591 .3535 L .80714 .3499 L F
.267 .388 .8 r
.47791 .25391 m .4824 .24648 L .48836 .25927 L F
.47791 .25391 m .47196 .24089 L .4824 .24648 L F
.719 .829 .933 r
.66518 .36649 m .67076 .35598 L .67605 .36164 L F
.66518 .36649 m .65988 .36129 L .67076 .35598 L F
.546 .542 .801 r
.45555 .2276 m .46003 .2132 L .466 .22733 L F
.45555 .2276 m .44957 .21396 L .46003 .2132 L F
.656 .751 .92 r
.82799 .35989 m .83449 .34949 L .83923 .35629 L F
.82799 .35989 m .82321 .35311 L .83449 .34949 L F
.904 .787 .721 r
.41408 .31321 m .40777 .30692 L .41878 .2876 L F
.919 .806 .719 r
.4031 .33207 m .40777 .30692 L .41408 .31321 L F
.776 .787 .862 r
.11084 .35447 m .11376 .34069 L .12119 .34699 L F
.11084 .35447 m .10338 .34824 L .11376 .34069 L F
.442 .681 .966 r
.32417 .42 m .32762 .41374 L .33428 .41927 L F
.32417 .42 m .31754 .4137 L .32762 .41374 L F
.203 .524 .919 r
.30767 .41145 m .31086 .40735 L .31754 .4137 L F
.30767 .41145 m .30103 .4044 L .31086 .40735 L F
.699 .749 .89 r
.16974 .32534 m .17273 .31317 L .1798 .32082 L F
.16974 .32534 m .1626 .31807 L .17273 .31317 L F
.905 .851 .779 r
.38318 .39054 m .37664 .38696 L .38756 .37187 L F
.881 .859 .814 r
.3724 .40328 m .37664 .38696 L .38318 .39054 L F
.026 .254 .756 r
.50024 .28338 m .50486 .28047 L .5108 .29147 L F
.50024 .28338 m .49431 .27156 L .50486 .28047 L F
.727 .643 .764 r
.43899 .22114 m .44359 .19976 L .44957 .21396 L F
.43899 .22114 m .43297 .20809 L .44359 .19976 L F
.818 .698 .732 r
.42825 .23398 m .43297 .20809 L .43899 .22114 L F
.686 .85 .961 r
.63816 .37069 m .64366 .36173 L .64902 .36626 L F
.63816 .37069 m .63277 .3663 L .64366 .36173 L F
.693 .767 .909 r
.70311 .35861 m .70886 .34723 L .71408 .35435 L F
.70311 .35861 m .69788 .35189 L .70886 .34723 L F
.782 .786 .856 r
.12119 .34699 m .12421 .33279 L .13158 .33924 L F
.12119 .34699 m .11376 .34069 L .12421 .33279 L F
.666 .741 .906 r
.73027 .35747 m .73618 .34634 L .74132 .35372 L F
.73027 .35747 m .72511 .35025 L .73618 .34634 L F
.763 .839 .909 r
.35122 .42053 m .35512 .40923 L .36173 .41336 L F
.35122 .42053 m .3446 .41578 L .35512 .40923 L F
.888 .763 .718 r
.41878 .2876 m .41253 .27983 L .42351 .2609 L F
.911 .785 .709 r
.40777 .30692 m .41253 .27983 L .41878 .2876 L F
0 .31 .802 r
.54498 .33791 m .54997 .33663 L .55578 .34397 L F
.54498 .33791 m .53916 .32929 L .54997 .33663 L F
.549 .793 .989 r
.61102 .3723 m .61642 .36571 L .62189 .36987 L F
.61102 .3723 m .60551 .36771 L .61642 .36571 L F
.319 .558 .921 r
.21325 .33403 m .2159 .32775 L .22276 .33617 L F
.21325 .33403 m .20637 .32582 L .2159 .32775 L F
.502 .658 .93 r
.19668 .32608 m .19944 .31754 L .20637 .32582 L F
.19668 .32608 m .18971 .31812 L .19944 .31754 L F
.654 .737 .911 r
.75749 .35726 m .76358 .34648 L .76861 .35368 L F
.75749 .35726 m .75243 .35007 L .76358 .34648 L F
0 .295 .788 r
.26858 .37896 m .27129 .37697 L .27803 .38471 L F
.26858 .37896 m .26187 .37087 L .27129 .37697 L F
.861 .735 .722 r
.42351 .2609 m .41733 .25136 L .42825 .23398 L F
.896 .761 .705 r
.41253 .27983 m .41733 .25136 L .42351 .2609 L F
0 .222 .743 r
.52261 .31235 m .52741 .31137 L .5333 .32045 L F
.52261 .31235 m .51672 .30209 L .52741 .31137 L F
.92 .824 .735 r
.39851 .355 m .39206 .35073 L .4031 .33207 L F
.918 .839 .751 r
.38756 .37187 m .39206 .35073 L .39851 .355 L F
.723 .814 .921 r
.67605 .36164 m .68167 .35054 L .68695 .35673 L F
.67605 .36164 m .67076 .35598 L .68167 .35054 L F
.781 .783 .854 r
.13158 .33924 m .13466 .32488 L .14198 .33156 L F
.13158 .33924 m .12421 .33279 L .13466 .32488 L F
.653 .744 .916 r
.78474 .35708 m .79099 .34655 L .79591 .3535 L F
.78474 .35708 m .77978 .35012 L .79099 .34655 L F
.563 .543 .791 r
.44957 .21396 m .45406 .19844 L .46003 .2132 L F
.44957 .21396 m .44359 .19976 L .45406 .19844 L F
.265 .377 .791 r
.47196 .24089 m .47642 .23314 L .4824 .24648 L F
.47196 .24089 m .466 .22733 L .47642 .23314 L F
.881 .859 .814 r
.3724 .40328 m .36581 .39956 L .37664 .38696 L F
.838 .858 .86 r
.36173 .41336 m .36581 .39956 L .3724 .40328 L F
.113 .429 .871 r
.22958 .34454 m .23215 .34034 L .23898 .34875 L F
.22958 .34454 m .22276 .33617 L .23215 .34034 L F
.838 .858 .86 r
.36173 .41336 m .35512 .40923 L .36581 .39956 L F
.818 .698 .732 r
.42825 .23398 m .42215 .22247 L .43297 .20809 L F
.871 .733 .708 r
.41733 .25136 m .42215 .22247 L .42825 .23398 L F
.655 .75 .92 r
.81198 .35672 m .8184 .34628 L .82321 .35311 L F
.81198 .35672 m .80714 .3499 L .8184 .34628 L F
.771 .777 .858 r
.14198 .33156 m .14508 .31738 L .15234 .32435 L F
.14198 .33156 m .13466 .32488 L .14508 .31738 L F
.63 .719 .911 r
.1798 .32082 m .18269 .3101 L .18971 .31812 L F
.1798 .32082 m .17273 .31317 L .18269 .3101 L F
.4 .701 .982 r
.59461 .36826 m .59995 .36339 L .60551 .36771 L F
.59461 .36826 m .58901 .36316 L .59995 .36339 L F
.062 .41 .861 r
.56155 .35121 m .56668 .34939 L .57242 .35536 L F
.56155 .35121 m .55578 .34397 L .56668 .34939 L F
.742 .643 .75 r
.43297 .20809 m .43761 .18497 L .44359 .19976 L F
.43297 .20809 m .42694 .19455 L .43761 .18497 L F
.829 .697 .718 r
.42215 .22247 m .42694 .19455 L .43297 .20809 L F
.719 .854 .946 r
.64902 .36626 m .65455 .3564 L .65988 .36129 L F
.64902 .36626 m .64366 .36173 L .65455 .3564 L F
.683 .752 .903 r
.71408 .35435 m .71989 .34281 L .72511 .35025 L F
.71408 .35435 m .70886 .34723 L .71989 .34281 L F
.659 .734 .905 r
.74132 .35372 m .74731 .34259 L .75243 .35007 L F
.74132 .35372 m .73618 .34634 L .74731 .34259 L F
0 .345 .82 r
.28473 .3924 m .28761 .39016 L .29434 .39731 L F
.28473 .3924 m .27803 .38471 L .28761 .39016 L F
0 .217 .732 r
.49431 .27156 m .49888 .26905 L .50486 .28047 L F
.49431 .27156 m .48836 .25927 L .49888 .26905 L F
0 .317 .804 r
.24575 .3571 m .24832 .35451 L .25511 .36272 L F
.24575 .3571 m .23898 .34875 L .24832 .35451 L F
.218 .558 .935 r
.57811 .36138 m .58336 .35822 L .58901 .36316 L F
.57811 .36138 m .57242 .35536 L .58336 .35822 L F
.579 .544 .78 r
.44359 .19976 m .44809 .183 L .45406 .19844 L F
.44359 .19976 m .43761 .18497 L .44809 .183 L F
.719 .795 .911 r
.68695 .35673 m .69261 .34515 L .69788 .35189 L F
.68695 .35673 m .68167 .35054 L .69261 .34515 L F
.749 .767 .868 r
.15234 .32435 m .15541 .31075 L .1626 .31807 L F
.15234 .32435 m .14508 .31738 L .15541 .31075 L F
.919 .806 .719 r
.4031 .33207 m .39668 .32696 L .40777 .30692 L F
.924 .823 .727 r
.39206 .35073 m .39668 .32696 L .4031 .33207 L F
.652 .737 .912 r
.76861 .35368 m .77478 .34294 L .77978 .35012 L F
.76861 .35368 m .76358 .34648 L .77478 .34294 L F
.61 .779 .961 r
.33428 .41927 m .33792 .41099 L .3446 .41578 L F
.33428 .41927 m .32762 .41374 L .33792 .41099 L F
.264 .366 .781 r
.466 .22733 m .47043 .21922 L .47642 .23314 L F
.466 .22733 m .46003 .2132 L .47043 .21922 L F
.624 .841 .983 r
.62189 .36987 m .62734 .36228 L .63277 .3663 L F
.62189 .36987 m .61642 .36571 L .62734 .36228 L F
.653 .746 .918 r
.79591 .3535 m .80225 .34297 L .80714 .3499 L F
.79591 .3535 m .79099 .34655 L .80225 .34297 L F
.918 .839 .751 r
.38756 .37187 m .38102 .36813 L .39206 .35073 L F
.906 .852 .778 r
.37664 .38696 m .38102 .36813 L .38756 .37187 L F
.655 .751 .92 r
.82321 .35311 m .82971 .34264 L .83449 .34949 L F
.82321 .35311 m .8184 .34628 L .82971 .34264 L F
.127 .477 .897 r
.30103 .4044 m .30413 .40095 L .31086 .40735 L F
.30103 .4044 m .29434 .39731 L .30413 .40095 L F
0 .159 .7 r
.51672 .30209 m .52148 .30203 L .52741 .31137 L F
.51672 .30209 m .5108 .29147 L .52148 .30203 L F
.911 .785 .709 r
.40777 .30692 m .40141 .30061 L .41253 .27983 L F
.924 .804 .709 r
.39668 .32696 m .40141 .30061 L .40777 .30692 L F
.871 .733 .708 r
.41733 .25136 m .41113 .24162 L .42215 .22247 L F
.829 .697 .718 r
.42215 .22247 m .41604 .21061 L .42694 .19455 L F
.879 .731 .695 r
.41113 .24162 m .41604 .21061 L .42215 .22247 L F
0 .23 .749 r
.53916 .32929 m .54413 .3292 L .54997 .33663 L F
.53916 .32929 m .5333 .32045 L .54413 .3292 L F
.737 .846 .931 r
.65988 .36129 m .66545 .35055 L .67076 .35598 L F
.65988 .36129 m .65455 .3564 L .66545 .35055 L F
.756 .644 .736 r
.42694 .19455 m .43164 .16952 L .43761 .18497 L F
.42694 .19455 m .42091 .18049 L .43164 .16952 L F
.839 .696 .704 r
.41604 .21061 m .42091 .18049 L .42694 .19455 L F
.376 .648 .963 r
.31754 .4137 m .32091 .40815 L .32762 .41374 L F
.31754 .4137 m .31086 .40735 L .32091 .40815 L F
.71 .751 .884 r
.1626 .31807 m .16561 .30547 L .17273 .31317 L F
.1626 .31807 m .15541 .31075 L .16561 .30547 L F
.596 .545 .768 r
.43761 .18497 m .44213 .16683 L .44809 .183 L F
.43761 .18497 m .43164 .16952 L .44213 .16683 L F
.336 .566 .923 r
.20637 .32582 m .20899 .31926 L .2159 .32775 L F
.20637 .32582 m .19944 .31754 L .20899 .31926 L F
.896 .761 .705 r
.41253 .27983 m .40624 .27196 L .41733 .25136 L F
.902 .759 .693 r
.40624 .27196 m .41113 .24162 L .41733 .25136 L F
.917 .783 .698 r
.40141 .30061 m .40624 .27196 L .41253 .27983 L F
.673 .738 .899 r
.72511 .35025 m .73098 .33866 L .73618 .34634 L F
.72511 .35025 m .71989 .34281 L .73098 .33866 L F
0 .265 .767 r
.26187 .37087 m .2645 .36917 L .27129 .37697 L F
.26187 .37087 m .25511 .36272 L .2645 .36917 L F
.52 .666 .928 r
.18971 .31812 m .19246 .3092 L .19944 .31754 L F
.18971 .31812 m .18269 .3101 L .19246 .3092 L F
.71 .774 .902 r
.69788 .35189 m .7036 .33996 L .70886 .34723 L F
.69788 .35189 m .69261 .34515 L .7036 .33996 L F
.265 .357 .771 r
.46003 .2132 m .46444 .20464 L .47043 .21922 L F
.46003 .2132 m .45406 .19844 L .46444 .20464 L F
.654 .73 .905 r
.75243 .35007 m .75849 .33899 L .76358 .34648 L F
.75243 .35007 m .74731 .34259 L .75849 .33899 L F
.117 .431 .872 r
.22276 .33617 m .22529 .33186 L .23215 .34034 L F
.22276 .33617 m .2159 .32775 L .22529 .33186 L F
0 .179 .707 r
.48836 .25927 m .49289 .25717 L .49888 .26905 L F
.48836 .25927 m .4824 .24648 L .49289 .25717 L F
.743 .837 .922 r
.3446 .41578 m .34844 .40508 L .35512 .40923 L F
.3446 .41578 m .33792 .41099 L .34844 .40508 L F
.651 .738 .913 r
.77978 .35012 m .78603 .33942 L .79099 .34655 L F
.77978 .35012 m .77478 .34294 L .78603 .33942 L F
.612 .546 .756 r
.43917 .1584 m .43164 .16952 L .43353 .16133 L F
.43917 .1584 m .44213 .16683 L .43164 .16952 L F
.43353 .16133 m .43164 .16952 L .4293 .16319 L F
.77 .644 .723 r
.4293 .16319 m .43164 .16952 L .42091 .18049 L F
.687 .867 .967 r
.63277 .3663 m .63827 .35758 L .64366 .36173 L F
.63277 .3663 m .62734 .36228 L .63827 .35758 L F
.906 .852 .778 r
.37664 .38696 m .37003 .3834 L .38102 .36813 L F
.88 .861 .818 r
.36581 .39956 m .37003 .3834 L .37664 .38696 L F
.501 .784 .996 r
.60551 .36771 m .61091 .36191 L .61642 .36571 L F
.60551 .36771 m .59995 .36339 L .61091 .36191 L F
.77 .644 .723 r
.4293 .16319 m .42091 .18049 L .42407 .1625 L F
.653 .747 .919 r
.80714 .3499 m .81355 .33937 L .8184 .34628 L F
.80714 .3499 m .80225 .34297 L .81355 .33937 L F
.744 .829 .917 r
.67076 .35598 m .67636 .34446 L .68167 .35054 L F
.67076 .35598 m .66545 .35055 L .67636 .34446 L F
.839 .696 .704 r
.41604 .21061 m .40991 .19837 L .42091 .18049 L F
.77 .644 .723 r
.42407 .1625 m .42091 .18049 L .41488 .16586 L F
.849 .694 .691 r
.40991 .19837 m .41488 .16586 L .42091 .18049 L F
.645 .723 .906 r
.17273 .31317 m .17563 .30201 L .18269 .3101 L F
.17273 .31317 m .16561 .30547 L .17563 .30201 L F
.77 .644 .723 r
.42407 .1625 m .41488 .16586 L .41899 .1611 L F
.268 .348 .761 r
.45406 .19844 m .45844 .18937 L .46444 .20464 L F
.45406 .19844 m .44809 .183 L .45844 .18937 L F
.924 .823 .727 r
.39206 .35073 m .38554 .34651 L .39668 .32696 L F
.921 .839 .746 r
.38102 .36813 m .38554 .34651 L .39206 .35073 L F
0 .321 .806 r
.55578 .34397 m .5609 .34347 L .56668 .34939 L F
.55578 .34397 m .54997 .33663 L .5609 .34347 L F
0 .304 .796 r
.23898 .34875 m .24148 .34624 L .24832 .35451 L F
.23898 .34875 m .23215 .34034 L .24148 .34624 L F
.829 .86 .869 r
.35512 .40923 m .35916 .39584 L .36581 .39956 L F
.35512 .40923 m .34844 .40508 L .35916 .39584 L F
0 .3 .789 r
.27803 .38471 m .28082 .38296 L .28761 .39016 L F
.27803 .38471 m .27129 .37697 L .28082 .38296 L F
.879 .731 .695 r
.41113 .24162 m .4049 .23164 L .41604 .21061 L F
.886 .729 .681 r
.4049 .23164 m .40991 .19837 L .41604 .21061 L F
.88 .861 .818 r
.36581 .39956 m .35916 .39584 L .37003 .3834 L F
.697 .753 .895 r
.70886 .34723 m .71463 .33509 L .71989 .34281 L F
.70886 .34723 m .7036 .33996 L .71463 .33509 L F
.663 .727 .897 r
.73618 .34634 m .74213 .33478 L .74731 .34259 L F
.73618 .34634 m .73098 .33866 L .74213 .33478 L F
.782 .643 .709 r
.41899 .1611 m .41488 .16586 L .41575 .16055 L F
0 .094 .652 r
.5108 .29147 m .51552 .29239 L .52148 .30203 L F
.5108 .29147 m .50486 .28047 L .51552 .29239 L F
.309 .659 .972 r
.58901 .36316 m .59435 .35937 L .59995 .36339 L F
.58901 .36316 m .58336 .35822 L .59435 .35937 L F
0 .141 .68 r
.4824 .24648 m .48688 .24479 L .49289 .25717 L F
.4824 .24648 m .47642 .23314 L .48688 .24479 L F
.649 .728 .906 r
.76358 .34648 m .76972 .33549 L .77478 .34294 L F
.76358 .34648 m .75849 .33899 L .76972 .33549 L F
.782 .643 .709 r
.41575 .16055 m .41488 .16586 L .41236 .15948 L F
.272 .34 .751 r
.44809 .183 m .45245 .17334 L .45844 .18937 L F
.44809 .183 m .44213 .16683 L .45245 .17334 L F
.849 .694 .691 r
.40991 .19837 m .40377 .1857 L .41488 .16586 L F
.857 .692 .677 r
.41236 .15948 m .41488 .16586 L .40377 .1857 L F
.74 .806 .904 r
.68167 .35054 m .6873 .33838 L .69261 .34515 L F
.68167 .35054 m .67636 .34446 L .6873 .33838 L F
.095 .481 .896 r
.57242 .35536 m .57766 .35348 L .58336 .35822 L F
.57242 .35536 m .56668 .34939 L .57766 .35348 L F
.731 .874 .947 r
.64366 .36173 m .64918 .35185 L .65455 .3564 L F
.64366 .36173 m .63827 .35758 L .64918 .35185 L F
.902 .759 .693 r
.40624 .27196 m .39991 .26399 L .41113 .24162 L F
.909 .756 .68 r
.39991 .26399 m .4049 .23164 L .41113 .24162 L F
0 .144 .685 r
.5333 .32045 m .53824 .32165 L .54413 .3292 L F
.5333 .32045 m .52741 .31137 L .53824 .32165 L F
.65 .74 .915 r
.79099 .34655 m .79732 .33591 L .80225 .34297 L F
.79099 .34655 m .78603 .33942 L .79732 .33591 L F
.564 .763 .971 r
.32762 .41374 m .33119 .40617 L .33792 .41099 L F
.32762 .41374 m .32091 .40815 L .33119 .40617 L F
.857 .692 .677 r
.41236 .15948 m .40377 .1857 L .40788 .15731 L F
.924 .804 .709 r
.39668 .32696 m .3902 .3219 L .40141 .30061 L F
.928 .822 .719 r
.38554 .34651 m .3902 .3219 L .39668 .32696 L F
.654 .749 .92 r
.8184 .34628 m .82489 .33575 L .82971 .34264 L F
.8184 .34628 m .81355 .33937 L .82489 .33575 L F
.047 .426 .868 r
.29434 .39731 m .29735 .3945 L .30413 .40095 L F
.29434 .39731 m .28761 .39016 L .29735 .3945 L F
.353 .575 .924 r
.19944 .31754 m .20204 .3107 L .20899 .31926 L F
.19944 .31754 m .19246 .3092 L .20204 .3107 L F
.278 .333 .74 r
.44213 .16683 m .44647 .1565 L .45245 .17334 L F
.44074 .15281 m .44213 .16683 L .43917 .1584 L F
.44074 .15281 m .44647 .1565 L .44213 .16683 L F
0 .236 .744 r
.25511 .36272 m .25767 .36131 L .2645 .36917 L F
.25511 .36272 m .24832 .35451 L .25767 .36131 L F
.917 .783 .698 r
.40141 .30061 m .395 .2943 L .40624 .27196 L F
.922 .78 .687 r
.395 .2943 m .39991 .26399 L .40624 .27196 L F
.601 .848 .991 r
.61642 .36571 m .62188 .3587 L .62734 .36228 L F
.61642 .36571 m .61091 .36191 L .62188 .3587 L F
.302 .609 .954 r
.31086 .40735 m .31414 .40253 L .32091 .40815 L F
.31086 .40735 m .30413 .40095 L .31414 .40253 L F
.538 .673 .925 r
.18269 .3101 m .18544 .30078 L .19246 .3092 L F
.18269 .3101 m .17563 .30201 L .18544 .30078 L F
.928 .802 .7 r
.3902 .3219 m .395 .2943 L .40141 .30061 L F
.682 .735 .891 r
.71989 .34281 m .72573 .33061 L .73098 .33866 L F
.71989 .34281 m .71463 .33509 L .72573 .33061 L F
.121 .434 .873 r
.2159 .32775 m .21839 .32331 L .22529 .33186 L F
.2159 .32775 m .20899 .31926 L .21839 .32331 L F
.654 .72 .898 r
.74731 .34259 m .75334 .33114 L .75849 .33899 L F
.74731 .34259 m .74213 .33478 L .75334 .33114 L F
.886 .729 .681 r
.4049 .23164 m .39864 .22143 L .40991 .19837 L F
.893 .726 .669 r
.39864 .22143 m .40377 .1857 L .40991 .19837 L F
.921 .839 .746 r
.38102 .36813 m .37441 .36445 L .38554 .34651 L F
.908 .853 .777 r
.37003 .3834 m .37441 .36445 L .38102 .36813 L F
.729 .781 .894 r
.69261 .34515 m .69829 .33252 L .7036 .33996 L F
.69261 .34515 m .6873 .33838 L .69829 .33252 L F
0 .103 .653 r
.47642 .23314 m .48084 .23187 L .48688 .24479 L F
.47642 .23314 m .47043 .21922 L .48084 .23187 L F
.857 .692 .677 r
.40788 .15731 m .39762 .17259 L .40605 .1561 L F
.40788 .15731 m .40377 .1857 L .39762 .17259 L F
.758 .865 .928 r
.65455 .3564 m .6601 .34539 L .66545 .35055 L F
.65455 .3564 m .64918 .35185 L .6601 .34539 L F
.646 .729 .909 r
.77478 .34294 m .78101 .33207 L .78603 .33942 L F
.77478 .34294 m .76972 .33549 L .78101 .33207 L F
0 .029 .599 r
.50486 .28047 m .50952 .28245 L .51552 .29239 L F
.50486 .28047 m .49888 .26905 L .50952 .28245 L F
.864 .69 .664 r
.40605 .1561 m .39762 .17259 L .40029 .15319 L F
.65 .743 .918 r
.80225 .34297 m .80866 .33237 L .81355 .33937 L F
.80225 .34297 m .79732 .33591 L .80866 .33237 L F
0 .292 .788 r
.23215 .34034 m .2346 .3379 L .24148 .34624 L F
.23215 .34034 m .22529 .33186 L .2346 .3379 L F
.719 .834 .936 r
.33792 .41099 m .34171 .40092 L .34844 .40508 L F
.33792 .41099 m .33119 .40617 L .34171 .40092 L F
0 .219 .731 r
.54997 .33663 m .55507 .33761 L .5609 .34347 L F
.54997 .33663 m .54413 .3292 L .55507 .33761 L F
0 .254 .754 r
.27129 .37697 m .27399 .37571 L .28082 .38296 L F
.27129 .37697 m .2645 .36917 L .27399 .37571 L F
.768 .845 .91 r
.66545 .35055 m .67102 .33852 L .67636 .34446 L F
.66545 .35055 m .6601 .34539 L .67102 .33852 L F
.668 .72 .888 r
.73098 .33866 m .73689 .32654 L .74213 .33478 L F
.73098 .33866 m .72573 .33061 L .73689 .32654 L F
.713 .755 .886 r
.7036 .33996 m .70932 .32707 L .71463 .33509 L F
.7036 .33996 m .69829 .33252 L .70932 .32707 L F
.433 .766 .996 r
.59995 .36339 m .60536 .35854 L .61091 .36191 L F
.59995 .36339 m .59435 .35937 L .60536 .35854 L F
0 .066 .625 r
.47043 .21922 m .4748 .21836 L .48084 .23187 L F
.47043 .21922 m .46444 .20464 L .4748 .21836 L F
.685 .885 .972 r
.62734 .36228 m .63284 .35389 L .63827 .35758 L F
.62734 .36228 m .62188 .3587 L .63284 .35389 L F
.909 .756 .68 r
.39991 .26399 m .39354 .25592 L .4049 .23164 L F
.914 .753 .669 r
.39354 .25592 m .39864 .22143 L .4049 .23164 L F
.908 .853 .777 r
.37003 .3834 m .36336 .37987 L .37441 .36445 L F
.877 .863 .822 r
.35916 .39584 m .36336 .37987 L .37003 .3834 L F
0 0 .533 r
.53213 .31379 m .52633 .30621 L .53231 .31399 L F
.52148 .30203 m .52633 .30621 L .53213 .31379 L F
0 0 .451 r
.52617 .30599 m .52032 .2983 L .52633 .30621 L F
.51552 .29239 m .52032 .2983 L .52617 .30599 L F
.51552 .29239 m .50952 .28245 L .51988 .29765 L F
.52021 .29816 m .51988 .29765 L .52032 .2983 L F
.51552 .29239 m .51988 .29765 L .52021 .29816 L F
0 0 .544 r
.50904 .28184 m .50349 .27217 L .50952 .28245 L F
.49888 .26905 m .50349 .27217 L .50904 .28184 L F
0 0 .487 r
.50303 .27151 m .49744 .26152 L .50349 .27217 L F
.49289 .25717 m .49744 .26152 L .50303 .27151 L F
0 0 .43 r
.49699 .26081 m .49135 .25047 L .49744 .26152 L F
.48688 .24479 m .49135 .25047 L .49699 .26081 L F
0 0 .374 r
.49092 .24971 m .48524 .23898 L .49135 .25047 L F
.48084 .23187 m .48524 .23898 L .49092 .24971 L F
.48084 .23187 m .4748 .21836 L .48311 .23477 L F
.48465 .23803 m .48311 .23477 L .48524 .23898 L F
.48084 .23187 m .48311 .23477 L .48465 .23803 L F
0 .029 .597 r
.47419 .21756 m .46874 .20422 L .4748 .21836 L F
.46444 .20464 m .46874 .20422 L .47419 .21756 L F
0 0 .568 r
.46815 .20337 m .46269 .18938 L .46874 .20422 L F
.45844 .18937 m .46269 .18938 L .46815 .20337 L F
0 0 .54 r
.46211 .18848 m .45663 .17378 L .46269 .18938 L F
.45245 .17334 m .45663 .17378 L .46211 .18848 L F
0 0 .512 r
.45607 .17283 m .45058 .15737 L .45663 .17378 L F
.44647 .1565 m .45058 .15737 L .45607 .17283 L F
0 0 .484 r
.44989 .15596 m .44454 .14007 L .45058 .15737 L F
.44179 .13918 m .44454 .14007 L .44989 .15596 L F
0 0 .474 r
.43944 .12457 m .44454 .14007 L .44085 .13267 L F
.787 .466 0 r
.4389 .12323 m .43904 .12374 L .44454 .14007 L F
0 0 .512 r
.44236 .14219 m .45058 .15737 L .44647 .1565 L F
0 0 .484 r
.44179 .13918 m .45058 .15737 L .44236 .14219 L F
.44085 .13267 m .44454 .14007 L .44179 .13918 L F
.787 .466 0 r
.43904 .12374 m .44822 .15844 L .44454 .14007 L F
.761 .434 0 r
.45058 .15737 m .44454 .14007 L .44507 .14187 L F
0 0 .54 r
.45245 .17334 m .44647 .1565 L .45663 .17378 L F
.761 .434 0 r
.45058 .15737 m .44507 .14187 L .45441 .1735 L F
.73 .399 0 r
.45663 .17378 m .45058 .15737 L .45113 .15904 L F
0 0 .568 r
.45844 .18937 m .45245 .17334 L .46269 .18938 L F
.73 .399 0 r
.45663 .17378 m .45113 .15904 L .4606 .18783 L F
.695 .36 0 r
.46269 .18938 m .45663 .17378 L .4572 .17534 L F
0 .029 .597 r
.46444 .20464 m .45844 .18937 L .46874 .20422 L F
.695 .36 0 r
.46269 .18938 m .4572 .17534 L .46678 .20149 L F
.655 .317 0 r
.46874 .20422 m .46269 .18938 L .46328 .19082 L F
.46874 .20422 m .46328 .19082 L .47295 .21453 L F
0 0 .319 r
.48483 .23816 m .47911 .22701 L .48524 .23898 L F
.4748 .21836 m .47911 .22701 L .48483 .23816 L F
.4748 .21836 m .46874 .20422 L .47911 .22701 L F
.844 .468 0 r
.47911 .22701 m .47295 .21453 L .47335 .2158 L F
.47911 .22701 m .47335 .2158 L .48336 .24754 L F
.655 .317 0 r
.47145 .21017 m .47295 .21453 L .47911 .22701 L F
.46874 .20422 m .46946 .20597 L .47145 .21017 L F
.46946 .20597 m .47295 .21453 L .47145 .21017 L F
.812 .429 0 r
.48524 .23898 m .47911 .22701 L .47952 .22819 L F
0 0 .43 r
.48688 .24479 m .48084 .23187 L .49135 .25047 L F
.812 .429 0 r
.48524 .23898 m .47952 .22819 L .48962 .25645 L F
.773 .383 0 r
.49135 .25047 m .48524 .23898 L .48568 .24006 L F
0 0 .544 r
.49888 .26905 m .49289 .25717 L .50349 .27217 L F
0 0 .487 r
.49289 .25717 m .48688 .24479 L .49744 .26152 L F
.773 .383 0 r
.49135 .25047 m .48568 .24006 L .49585 .26516 L F
.726 .329 0 r
.49744 .26152 m .49135 .25047 L .49181 .25146 L F
.49744 .26152 m .49181 .25146 L .50203 .27369 L F
.668 .267 0 r
.50349 .27217 m .49744 .26152 L .49792 .26244 L F
.50349 .27217 m .49792 .26244 L .50817 .28205 L F
0 0 .369 r
.50952 .28245 m .51426 .29025 L .52032 .2983 L F
.50952 .28245 m .50349 .27217 L .51426 .29025 L F
.668 .267 0 r
.50484 .27443 m .50817 .28205 L .51426 .29025 L F
.50349 .27217 m .50381 .27284 L .50484 .27443 L F
.50381 .27284 m .50817 .28205 L .50484 .27443 L F
.729 .284 0 r
.52032 .2983 m .51426 .29025 L .51443 .29054 L F
0 .056 .612 r
.52741 .31137 m .52148 .30203 L .53231 .31399 L F
0 0 .533 r
.52148 .30203 m .51552 .29239 L .52633 .30621 L F
.729 .284 0 r
.52032 .2983 m .51443 .29054 L .52523 .30975 L F
.655 .202 0 r
.52633 .30621 m .52032 .2983 L .5205 .29857 L F
0 .056 .612 r
.52741 .31137 m .53231 .31399 L .53805 .32147 L F
.655 .202 0 r
.52633 .30621 m .5205 .29857 L .5313 .31507 L F
.562 .107 0 r
.53231 .31399 m .52633 .30621 L .52652 .30645 L F
.53231 .31399 m .52652 .30645 L .53732 .32054 L F
0 .056 .612 r
.53805 .32147 m .53231 .31399 L .53824 .32165 L F
.893 .726 .669 r
.39864 .22143 m .39235 .21095 L .40377 .1857 L F
.898 .724 .657 r
.39235 .21095 m .39762 .17259 L .40377 .1857 L F
.646 .717 .9 r
.75849 .33899 m .76461 .32771 L .76972 .33549 L F
.75849 .33899 m .75334 .33114 L .76461 .32771 L F
.864 .69 .664 r
.40029 .15319 m .39147 .159 L .39565 .15007 L F
.40029 .15319 m .39762 .17259 L .39147 .159 L F
.928 .822 .719 r
.38554 .34651 m .37896 .34235 L .3902 .3219 L F
.925 .839 .741 r
.37441 .36445 m .37896 .34235 L .38554 .34651 L F
.29 .332 .733 r
.44297 .14611 m .44647 .1565 L .44074 .15281 L F
.82 .862 .879 r
.34844 .40508 m .35244 .39214 L .35916 .39584 L F
.34844 .40508 m .34171 .40092 L .35244 .39214 L F
.645 .732 .912 r
.78603 .33942 m .79234 .32866 L .79732 .33591 L F
.78603 .33942 m .78101 .33207 L .79234 .32866 L F
.37 .583 .925 r
.19246 .3092 m .19505 .30207 L .20204 .3107 L F
.19246 .3092 m .18544 .30078 L .19505 .30207 L F
.877 .863 .822 r
.35916 .39584 m .35244 .39214 L .36336 .37987 L F
.765 .818 .895 r
.67636 .34446 m .68196 .33158 L .6873 .33838 L F
.67636 .34446 m .67102 .33852 L .68196 .33158 L F
0 .383 .833 r
.56668 .34939 m .57192 .34897 L .57766 .35348 L F
.56668 .34939 m .5609 .34347 L .57192 .34897 L F
.189 .595 .943 r
.58336 .35822 m .5887 .3557 L .59435 .35937 L F
.58336 .35822 m .57766 .35348 L .5887 .3557 L F
0 .369 .832 r
.28761 .39016 m .29052 .38801 L .29735 .3945 L F
.28761 .39016 m .28082 .38296 L .29052 .38801 L F
0 .206 .721 r
.24832 .35451 m .2508 .35338 L .25767 .36131 L F
.24832 .35451 m .24148 .34624 L .2508 .35338 L F
.651 .747 .92 r
.81355 .33937 m .82004 .3288 L .82489 .33575 L F
.81355 .33937 m .80866 .33237 L .82004 .3288 L F
.511 .742 .978 r
.32091 .40815 m .3244 .40133 L .33119 .40617 L F
.32091 .40815 m .31414 .40253 L .3244 .40133 L F
.127 .437 .875 r
.20899 .31926 m .21144 .31468 L .21839 .32331 L F
.20899 .31926 m .20204 .3107 L .21144 .31468 L F
.922 .78 .687 r
.395 .2943 m .38854 .28797 L .39991 .26399 L F
.927 .777 .676 r
.38854 .28797 m .39354 .25592 L .39991 .26399 L F
.694 .732 .88 r
.71463 .33509 m .72042 .32214 L .72573 .33061 L F
.71463 .33509 m .70932 .32707 L .72042 .32214 L F
.744 .895 .947 r
.63827 .35758 m .64379 .34772 L .64918 .35185 L F
.63827 .35758 m .63284 .35389 L .64379 .34772 L F
.928 .802 .7 r
.3902 .3219 m .38367 .31687 L .395 .2943 L F
.932 .82 .712 r
.37896 .34235 m .38367 .31687 L .3902 .3219 L F
.654 .71 .888 r
.74213 .33478 m .74813 .32285 L .75334 .33114 L F
.74213 .33478 m .73689 .32654 L .74813 .32285 L F
.22 .562 .936 r
.30413 .40095 m .30732 .39688 L .31414 .40253 L F
.30413 .40095 m .29735 .3945 L .30732 .39688 L F
.933 .8 .69 r
.38367 .31687 m .38854 .28797 L .395 .2943 L F
.871 .688 .652 r
.39565 .15007 m .39147 .159 L .39284 .1486 L F
.898 .724 .657 r
.39235 .21095 m .38604 .20019 L .39762 .17259 L F
.904 .721 .645 r
.38604 .20019 m .39147 .159 L .39762 .17259 L F
.752 .788 .882 r
.6873 .33838 m .69293 .32489 L .69829 .33252 L F
.6873 .33838 m .68196 .33158 L .69293 .32489 L F
.641 .717 .903 r
.76972 .33549 m .77594 .32441 L .78101 .33207 L F
.76972 .33549 m .76461 .32771 L .77594 .32441 L F
.566 .853 .997 r
.61091 .36191 m .61638 .35562 L .62188 .3587 L F
.61091 .36191 m .60536 .35854 L .61638 .35562 L F
0 .28 .779 r
.22529 .33186 m .22767 .32947 L .2346 .3379 L F
.22529 .33186 m .21839 .32331 L .22767 .32947 L F
.871 .688 .652 r
.39284 .1486 m .38532 .14489 L .3858 .14377 L F
.39284 .1486 m .39147 .159 L .38532 .14489 L F
.914 .753 .669 r
.39354 .25592 m .38713 .24774 L .39864 .22143 L F
.919 .751 .657 r
.38713 .24774 m .39235 .21095 L .39864 .22143 L F
.645 .737 .916 r
.79732 .33591 m .80373 .32525 L .80866 .33237 L F
.79732 .33591 m .79234 .32866 L .80373 .32525 L F
.78 .885 .922 r
.64918 .35185 m .65472 .34053 L .6601 .34539 L F
.64918 .35185 m .64379 .34772 L .65472 .34053 L F
0 .207 .716 r
.2645 .36917 m .26711 .3684 L .27399 .37571 L F
.2645 .36917 m .25767 .36131 L .26711 .3684 L F
.925 .839 .741 r
.37441 .36445 m .36774 .36083 L .37896 .34235 L F
.909 .855 .776 r
.36336 .37987 m .36774 .36083 L .37441 .36445 L F
.674 .712 .877 r
.72573 .33061 m .73159 .31778 L .73689 .32654 L F
.72573 .33061 m .72042 .32214 L .73159 .31778 L F
0 .109 .64 r
.54413 .3292 m .5492 .33182 L .55507 .33761 L F
.54413 .3292 m .53824 .32165 L .5492 .33182 L F
.732 .758 .873 r
.69829 .33252 m .70396 .31868 L .70932 .32707 L F
.69829 .33252 m .69293 .32489 L .70396 .31868 L F
.642 .704 .891 r
.75334 .33114 m .75943 .31949 L .76461 .32771 L F
.75334 .33114 m .74813 .32285 L .75943 .31949 L F
0 0 .512 r
.44236 .14219 m .44647 .1565 L .44297 .14611 L F
.69 .829 .95 r
.33119 .40617 m .33491 .39676 L .34171 .40092 L F
.33119 .40617 m .3244 .40133 L .33491 .39676 L F
.904 .721 .645 r
.38604 .20019 m .37971 .18914 L .39147 .159 L F
.908 .718 .634 r
.37971 .18914 m .38532 .14489 L .39147 .159 L F
.794 .862 .9 r
.6601 .34539 m .66564 .33274 L .67102 .33852 L F
.6601 .34539 m .65472 .34053 L .66564 .33274 L F
0 .177 .697 r
.24148 .34624 m .24388 .34538 L .2508 .35338 L F
.24148 .34624 m .2346 .3379 L .24388 .34538 L F
.637 .721 .908 r
.78101 .33207 m .78732 .3212 L .79234 .32866 L F
.78101 .33207 m .77594 .32441 L .78732 .3212 L F
.34 .731 .984 r
.59435 .35937 m .59977 .35564 L .60536 .35854 L F
.59435 .35937 m .5887 .3557 L .59977 .35564 L F
.134 .44 .876 r
.20204 .3107 m .20445 .30597 L .21144 .31468 L F
.20204 .3107 m .19505 .30207 L .20445 .30597 L F
0 .309 .789 r
.28082 .38296 m .28363 .38147 L .29052 .38801 L F
.28082 .38296 m .27399 .37571 L .28363 .38147 L F
.678 .903 .976 r
.62188 .3587 m .62739 .35071 L .63284 .35389 L F
.62188 .3587 m .61638 .35562 L .62739 .35071 L F
.927 .777 .676 r
.38854 .28797 m .38202 .28163 L .39354 .25592 L F
.931 .775 .665 r
.38202 .28163 m .38713 .24774 L .39354 .25592 L F
.909 .855 .776 r
.36336 .37987 m .35662 .37641 L .36774 .36083 L F
.875 .867 .827 r
.35244 .39214 m .35662 .37641 L .36336 .37987 L F
.708 .729 .867 r
.70932 .32707 m .71505 .31316 L .72042 .32214 L F
.70932 .32707 m .70396 .31868 L .71505 .31316 L F
.645 .742 .92 r
.80866 .33237 m .81516 .3218 L .82004 .3288 L F
.80866 .33237 m .80373 .32525 L .81516 .3218 L F
.792 .831 .882 r
.67102 .33852 m .67657 .32477 L .68196 .33158 L F
.67102 .33852 m .66564 .33274 L .67657 .32477 L F
0 .263 .742 r
.5609 .34347 m .56613 .34471 L .57192 .34897 L F
.5609 .34347 m .55507 .33761 L .56613 .34471 L F
.655 .697 .877 r
.73689 .32654 m .74285 .314 L .74813 .32285 L F
.73689 .32654 m .73159 .31778 L .74285 .314 L F
.877 .686 .64 r
.3858 .14377 m .38532 .14489 L .38548 .1436 L F
.932 .82 .712 r
.37896 .34235 m .37231 .33827 L .38367 .31687 L F
.928 .839 .736 r
.36774 .36083 m .37231 .33827 L .37896 .34235 L F
.877 .686 .64 r
.38548 .1436 m .38532 .14489 L .38449 .1429 L F
.809 .864 .889 r
.34171 .40092 m .34566 .38847 L .35244 .39214 L F
.34171 .40092 m .33491 .39676 L .34566 .38847 L F
.908 .718 .634 r
.37971 .18914 m .37336 .17776 L .38532 .14489 L F
.913 .715 .623 r
.38449 .1429 m .38532 .14489 L .37336 .17776 L F
.447 .714 .981 r
.31414 .40253 m .31755 .39648 L .3244 .40133 L F
.31414 .40253 m .30732 .39688 L .31755 .39648 L F
.04 .502 .885 r
.57766 .35348 m .58301 .35243 L .5887 .3557 L F
.57766 .35348 m .57192 .34897 L .58301 .35243 L F
.919 .751 .657 r
.38713 .24774 m .38068 .23944 L .39235 .21095 L F
.923 .748 .646 r
.38068 .23944 m .38604 .20019 L .39235 .21095 L F
.913 .715 .623 r
.38449 .1429 m .37336 .17776 L .37819 .13828 L F
.13 .506 .91 r
.29735 .3945 m .30044 .39119 L .30732 .39688 L F
.29735 .3945 m .29052 .38801 L .30044 .39119 L F
.875 .867 .827 r
.35244 .39214 m .34566 .38847 L .35662 .37641 L F
0 .269 .771 r
.21839 .32331 m .22071 .32097 L .22767 .32947 L F
.21839 .32331 m .21144 .31468 L .22071 .32097 L F
.633 .702 .896 r
.76461 .32771 m .7708 .31639 L .77594 .32441 L F
.76461 .32771 m .75943 .31949 L .7708 .31639 L F
.777 .796 .868 r
.68196 .33158 m .68753 .31703 L .69293 .32489 L F
.68196 .33158 m .67657 .32477 L .68753 .31703 L F
.933 .8 .69 r
.38367 .31687 m .37707 .3119 L .38854 .28797 L F
.937 .797 .681 r
.37707 .3119 m .38202 .28163 L .38854 .28797 L F
.936 .819 .704 r
.37231 .33827 m .37707 .3119 L .38367 .31687 L F
.757 .918 .944 r
.63284 .35389 m .63836 .34406 L .64379 .34772 L F
.63284 .35389 m .62739 .35071 L .63836 .34406 L F
.682 .704 .863 r
.72042 .32214 m .72622 .30842 L .73159 .31778 L F
.72042 .32214 m .71505 .31316 L .72622 .30842 L F
0 .16 .677 r
.25767 .36131 m .26018 .36103 L .26711 .3684 L F
.25767 .36131 m .2508 .35338 L .26018 .36103 L F
.636 .727 .914 r
.79234 .32866 m .79875 .31799 L .80373 .32525 L F
.79234 .32866 m .78732 .3212 L .79875 .31799 L F
0 0 .537 r
.53824 .32165 m .54328 .32613 L .5492 .33182 L F
.53824 .32165 m .53231 .31399 L .54328 .32613 L F
.754 .76 .857 r
.69293 .32489 m .69853 .30987 L .70396 .31868 L F
.69293 .32489 m .68753 .31703 L .69853 .30987 L F
.637 .688 .88 r
.74813 .32285 m .75418 .31074 L .75943 .31949 L F
.74813 .32285 m .74285 .314 L .75418 .31074 L F
.513 .85 .996 r
.60536 .35854 m .61085 .35311 L .61638 .35562 L F
.60536 .35854 m .59977 .35564 L .61085 .35311 L F
.804 .906 .912 r
.64379 .34772 m .64931 .33605 L .65472 .34053 L F
.64379 .34772 m .63836 .34406 L .64931 .33605 L F
0 .148 .672 r
.2346 .3379 m .23691 .3373 L .24388 .34538 L F
.2346 .3379 m .22767 .32947 L .23691 .3373 L F
.913 .715 .623 r
.37819 .13828 m .367 .16604 L .37685 .13706 L F
.37819 .13828 m .37336 .17776 L .367 .16604 L F
.928 .839 .736 r
.36774 .36083 m .361 .35729 L .37231 .33827 L F
.911 .857 .776 r
.35662 .37641 m .361 .35729 L .36774 .36083 L F
.626 .706 .903 r
.77594 .32441 m .78224 .31344 L .78732 .3212 L F
.77594 .32441 m .7708 .31639 L .78224 .31344 L F
.923 .748 .646 r
.38068 .23944 m .37418 .23102 L .38604 .20019 L F
.927 .745 .635 r
.37418 .23102 m .37971 .18914 L .38604 .20019 L F
.656 .823 .963 r
.3244 .40133 m .32804 .39262 L .33491 .39676 L F
.3244 .40133 m .31755 .39648 L .32804 .39262 L F
.724 .725 .851 r
.70396 .31868 m .70961 .30357 L .71505 .31316 L F
.70396 .31868 m .69853 .30987 L .70961 .30357 L F
.931 .775 .665 r
.38202 .28163 m .37545 .2753 L .38713 .24774 L F
.935 .772 .655 r
.37545 .2753 m .38068 .23944 L .38713 .24774 L F
.656 .683 .864 r
.73159 .31778 m .73749 .30449 L .74285 .314 L F
.73159 .31778 m .72622 .30842 L .73749 .30449 L F
0 .247 .74 r
.27399 .37571 m .2767 .37489 L .28363 .38147 L F
.27399 .37571 m .26711 .3684 L .2767 .37489 L F
.823 .879 .885 r
.65472 .34053 m .66024 .32717 L .66564 .33274 L F
.65472 .34053 m .64931 .33605 L .66024 .32717 L F
.637 .735 .92 r
.80373 .32525 m .81023 .31474 L .81516 .3218 L F
.80373 .32525 m .79875 .31799 L .81023 .31474 L F
0 .258 .763 r
.21144 .31468 m .2137 .31237 L .22071 .32097 L F
.21144 .31468 m .20445 .30597 L .2137 .31237 L F
.821 .843 .865 r
.66564 .33274 m .67115 .31795 L .67657 .32477 L F
.66564 .33274 m .66024 .32717 L .67115 .31795 L F
0 .132 .625 r
.55507 .33761 m .5603 .34074 L .56613 .34471 L F
.55507 .33761 m .5492 .33182 L .5603 .34074 L F
.623 .684 .887 r
.75943 .31949 m .7656 .30789 L .7708 .31639 L F
.75943 .31949 m .75418 .31074 L .7656 .30789 L F
.212 .668 .946 r
.5887 .3557 m .59414 .3533 L .59977 .35564 L F
.5887 .3557 m .58301 .35243 L .59414 .3533 L F
.033 .442 .872 r
.29052 .38801 m .29351 .38548 L .30044 .39119 L F
.29052 .38801 m .28363 .38147 L .29351 .38548 L F
.372 .678 .977 r
.30732 .39688 m .31063 .39162 L .31755 .39648 L F
.30732 .39688 m .30044 .39119 L .31063 .39162 L F
.692 .694 .847 r
.71505 .31316 m .72078 .29831 L .72622 .30842 L F
.71505 .31316 m .70961 .30357 L .72078 .29831 L F
.911 .857 .776 r
.35662 .37641 m .34981 .37301 L .361 .35729 L F
.873 .87 .832 r
.34566 .38847 m .34981 .37301 L .35662 .37641 L F
.664 .92 .975 r
.61638 .35562 m .6219 .34814 L .62739 .35071 L F
.61638 .35562 m .61085 .35311 L .6219 .34814 L F
.804 .802 .85 r
.67657 .32477 m .68208 .30891 L .68753 .31703 L F
.67657 .32477 m .67115 .31795 L .68208 .30891 L F
.936 .819 .704 r
.37231 .33827 m .3656 .33428 L .37707 .3119 L F
.931 .839 .732 r
.361 .35729 m .3656 .33428 L .37231 .33827 L F
.796 .867 .901 r
.33491 .39676 m .33881 .38485 L .34566 .38847 L F
.33491 .39676 m .32804 .39262 L .33881 .38485 L F
0 .114 .635 r
.2508 .35338 m .2532 .35359 L .26018 .36103 L F
.2508 .35338 m .24388 .34538 L .2532 .35359 L F
0 .379 .789 r
.57192 .34897 m .57727 .34961 L .58301 .35243 L F
.57192 .34897 m .56613 .34471 L .57727 .34961 L F
.937 .797 .681 r
.37707 .3119 m .37042 .30699 L .38202 .28163 L F
.941 .795 .672 r
.37042 .30699 m .37545 .2753 L .38202 .28163 L F
.623 .714 .911 r
.78732 .3212 m .79373 .31056 L .79875 .31799 L F
.78732 .3212 m .78224 .31344 L .79373 .31056 L F
.632 .669 .868 r
.74285 .314 m .74886 .30133 L .75418 .31074 L F
.74285 .314 m .73749 .30449 L .74886 .30133 L F
.562 .107 0 r
.53231 .31399 m .53732 .32054 L .54328 .32613 L F
.873 .87 .832 r
.34566 .38847 m .33881 .38485 L .34981 .37301 L F
.777 .761 .839 r
.68753 .31703 m .69306 .30056 L .69853 .30987 L F
.68753 .31703 m .68208 .30891 L .69306 .30056 L F
.94 .818 .697 r
.3656 .33428 m .37042 .30699 L .37707 .3119 L F
.927 .745 .635 r
.37418 .23102 m .36765 .22246 L .37971 .18914 L F
.931 .742 .625 r
.36765 .22246 m .37336 .17776 L .37971 .18914 L F
0 .119 .647 r
.22767 .32947 m .2299 .32915 L .23691 .3373 L F
.22767 .32947 m .22071 .32097 L .2299 .32915 L F
.659 .668 .848 r
.72622 .30842 m .73206 .29417 L .73749 .30449 L F
.72622 .30842 m .72078 .29831 L .73206 .29417 L F
.769 .941 .937 r
.62739 .35071 m .63291 .34096 L .63836 .34406 L F
.62739 .35071 m .6219 .34814 L .63291 .34096 L F
.742 .721 .832 r
.69853 .30987 m .7041 .29327 L .70961 .30357 L F
.69853 .30987 m .69306 .30056 L .7041 .29327 L F
.612 .687 .896 r
.7708 .31639 m .7771 .30533 L .78224 .31344 L F
.7708 .31639 m .7656 .30789 L .7771 .30533 L F
.935 .772 .655 r
.37545 .2753 m .36883 .26896 L .38068 .23944 L F
.939 .769 .645 r
.36883 .26896 m .37418 .23102 L .38068 .23944 L F
0 .183 .687 r
.26711 .3684 m .26971 .36826 L .2767 .37489 L F
.26711 .3684 m .26018 .36103 L .26971 .36826 L F
.695 .36 0 r
.46269 .18938 m .46678 .20149 L .47295 .21453 L F
.623 .725 .92 r
.79875 .31799 m .80527 .30764 L .81023 .31474 L F
.79875 .31799 m .79373 .31056 L .80527 .30764 L F
.828 .927 .898 r
.63836 .34406 m .64387 .33201 L .64931 .33605 L F
.63836 .34406 m .63291 .34096 L .64387 .33201 L F
.611 .662 .876 r
.75418 .31074 m .76033 .29881 L .7656 .30789 L F
.75418 .31074 m .74886 .30133 L .76033 .29881 L F
.435 .832 .981 r
.59977 .35564 m .60527 .35126 L .61085 .35311 L F
.59977 .35564 m .59414 .3533 L .60527 .35126 L F
.615 .812 .976 r
.31755 .39648 m .32111 .38851 L .32804 .39262 L F
.31755 .39648 m .31063 .39162 L .32111 .38851 L F
.703 .684 .829 r
.70961 .30357 m .71525 .28733 L .72078 .29831 L F
.70961 .30357 m .7041 .29327 L .71525 .28733 L F
.931 .839 .732 r
.361 .35729 m .35419 .35385 L .3656 .33428 L F
.912 .859 .776 r
.34981 .37301 m .35419 .35385 L .361 .35729 L F
.852 .895 .867 r
.64931 .33605 m .65479 .32184 L .66024 .32717 L F
.64931 .33605 m .64387 .33201 L .65479 .32184 L F
.73 .399 0 r
.45663 .17378 m .4606 .18783 L .46678 .20149 L F
.931 .742 .625 r
.36765 .22246 m .36108 .21377 L .37336 .17776 L F
.934 .739 .615 r
.36108 .21377 m .367 .16604 L .37336 .17776 L F
.626 .649 .853 r
.73749 .30449 m .74345 .29112 L .74886 .30133 L F
.73749 .30449 m .73206 .29417 L .74345 .29112 L F
.506 0 0 r
.5492 .33182 m .55441 .3371 L .5603 .34074 L F
.5492 .33182 m .54328 .32613 L .55441 .3371 L F
0 .371 .824 r
.28363 .38147 m .28651 .37975 L .29351 .38548 L F
.28363 .38147 m .2767 .37489 L .28651 .37975 L F
0 .068 .592 r
.24388 .34538 m .24617 .34609 L .2532 .35359 L F
.24388 .34538 m .23691 .3373 L .24617 .34609 L F
.851 .853 .844 r
.66024 .32717 m .66569 .31111 L .67115 .31795 L F
.66024 .32717 m .65479 .32184 L .66569 .31111 L F
.832 .808 .827 r
.67115 .31795 m .67659 .30051 L .68208 .30891 L F
.67115 .31795 m .66569 .31111 L .67659 .30051 L F
.285 .632 .964 r
.30044 .39119 m .30366 .38676 L .31063 .39162 L F
.30044 .39119 m .29351 .38548 L .30366 .38676 L F
.605 .696 .908 r
.78224 .31344 m .78866 .30291 L .79373 .31056 L F
.78224 .31344 m .7771 .30533 L .78866 .30291 L F
.761 .434 0 r
.45058 .15737 m .45441 .1735 L .4606 .18783 L F
.655 .202 0 r
.52633 .30621 m .5313 .31507 L .53732 .32054 L F
.801 .762 .817 r
.68208 .30891 m .68752 .29067 L .69306 .30056 L F
.68208 .30891 m .67659 .30051 L .68752 .29067 L F
.941 .795 .672 r
.37042 .30699 m .36369 .30217 L .37545 .2753 L F
.944 .793 .663 r
.36369 .30217 m .36883 .26896 L .37545 .2753 L F
.662 .652 .83 r
.72078 .29831 m .72653 .28289 L .73206 .29417 L F
.72078 .29831 m .71525 .28733 L .72653 .28289 L F
.047 .569 .869 r
.58301 .35243 m .58846 .35158 L .59414 .3533 L F
.58301 .35243 m .57727 .34961 L .58846 .35158 L F
.787 .466 0 r
.44454 .14007 m .44822 .15844 L .45441 .1735 L F
.4389 .12323 m .44454 .14007 L .43944 .12457 L F
0 .09 .621 r
.22071 .32097 m .22284 .32091 L .2299 .32915 L F
.22071 .32097 m .2137 .31237 L .22284 .32091 L F
.726 .329 0 r
.49744 .26152 m .50203 .27369 L .50817 .28205 L F
.761 .717 .811 r
.69306 .30056 m .69852 .28214 L .7041 .29327 L F
.69306 .30056 m .68752 .29067 L .69852 .28214 L F
.781 .869 .914 r
.32804 .39262 m .33189 .38129 L .33881 .38485 L F
.32804 .39262 m .32111 .38851 L .33189 .38129 L F
.94 .818 .697 r
.3656 .33428 m .35881 .3304 L .37042 .30699 L F
.934 .84 .727 r
.35419 .35385 m .35881 .3304 L .3656 .33428 L F
.912 .859 .776 r
.34981 .37301 m .34293 .3697 L .35419 .35385 L F
.87 .874 .838 r
.33881 .38485 m .34293 .3697 L .34981 .37301 L F
0 .232 .656 r
.56613 .34471 m .57148 .3473 L .57727 .34961 L F
.56613 .34471 m .5603 .34074 L .57148 .3473 L F
.593 .663 .887 r
.7656 .30789 m .77189 .29677 L .7771 .30533 L F
.7656 .30789 m .76033 .29881 L .77189 .29677 L F
.64 .933 .968 r
.61085 .35311 m .61637 .34626 L .6219 .34814 L F
.61085 .35311 m .60527 .35126 L .61637 .34626 L F
.943 .817 .69 r
.35881 .3304 m .36369 .30217 L .37042 .30699 L F
.939 .769 .645 r
.36883 .26896 m .36214 .26264 L .37418 .23102 L F
.942 .767 .635 r
.36214 .26264 m .36765 .22246 L .37418 .23102 L F
.81 .493 0 r
.43869 .1228 m .44822 .15844 L .4389 .12323 L F
.87 .874 .838 r
.33881 .38485 m .33189 .38129 L .34293 .3697 L F
.716 .674 .808 r
.7041 .29327 m .70964 .27531 L .71525 .28733 L F
.7041 .29327 m .69852 .28214 L .70964 .27531 L F
.81 .493 0 r
.43869 .1228 m .44203 .14258 L .44822 .15844 L F
.43534 .11432 m .44203 .14258 L .43869 .1228 L F
.596 .637 .862 r
.74886 .30133 m .75497 .28902 L .76033 .29881 L F
.74886 .30133 m .74345 .29112 L .75497 .28902 L F
0 .119 .629 r
.26018 .36103 m .26266 .36159 L .26971 .36826 L F
.26018 .36103 m .2532 .35359 L .26266 .36159 L F
.934 .739 .615 r
.36108 .21377 m .35447 .20494 L .367 .16604 L F
.718 .529 .634 r
.67663 .12124 m .66742 .1429 L .66923 .12175 L F
.66923 .12175 m .66742 .1429 L .66268 .12147 L F
.811 .602 .62 r
.66268 .12147 m .65706 .16609 L .66034 .12109 L F
.66268 .12147 m .66742 .1429 L .65706 .16609 L F
.62 .626 .835 r
.73206 .29417 m .73795 .27994 L .74345 .29112 L F
.73206 .29417 m .72653 .28289 L .73795 .27994 L F
.603 .71 .92 r
.79373 .31056 m .80028 .30048 L .80527 .30764 L F
.79373 .31056 m .78866 .30291 L .80028 .30048 L F
.587 .435 .642 r
.6791 .12037 m .67813 .1285 L .67663 .12124 L F
.718 .529 .634 r
.67663 .12124 m .67813 .1285 L .66742 .1429 L F
.811 .602 .62 r
.66034 .12109 m .65076 .14124 L .65836 .12038 L F
.66034 .12109 m .65706 .16609 L .65076 .14124 L F
.778 .963 .925 r
.6219 .34814 m .62742 .33851 L .63291 .34096 L F
.6219 .34814 m .61637 .34626 L .62742 .33851 L F
.819 .597 .601 r
.65836 .12038 m .65076 .14124 L .65201 .1192 L F
.587 .435 .642 r
.68786 .11707 m .67813 .1285 L .6791 .12037 L F
.666 .636 .81 r
.71525 .28733 m .72091 .27045 L .72653 .28289 L F
.71525 .28733 m .70964 .27531 L .72091 .27045 L F
0 0 .505 r
.2299 .32915 m .23197 .33088 L .2391 .33852 L F
.552 .062 0 r
.2391 .33852 m .23197 .33088 L .23207 .33099 L F
0 .023 .549 r
.23691 .3373 m .2391 .33852 L .24608 .346 L F
.23691 .3373 m .2299 .32915 L .2391 .33852 L F
.552 .062 0 r
.2391 .33852 m .23207 .33099 L .24119 .34131 L F
0 .023 .549 r
.24608 .346 m .2391 .33852 L .24617 .34609 L F
.564 .797 .987 r
.31063 .39162 m .31412 .38443 L .32111 .38851 L F
.31063 .39162 m .30366 .38676 L .31412 .38443 L F
.773 .383 0 r
.49135 .25047 m .49585 .26516 L .50203 .27369 L F
.819 .597 .601 r
.65201 .1192 m .65076 .14124 L .64508 .11656 L F
.587 .45 .661 r
.68467 .15703 m .67813 .1285 L .68939 .12452 L F
.71 .537 .653 r
.67381 .16902 m .67813 .1285 L .68467 .15703 L F
.67381 .16902 m .66742 .1429 L .67813 .1285 L F
.587 .435 .642 r
.68786 .11707 m .68939 .12452 L .67813 .1285 L F
0 .294 .765 r
.2767 .37489 m .27946 .374 L .28651 .37975 L F
.2767 .37489 m .26971 .36826 L .27946 .374 L F
.58 .672 .902 r
.7771 .30533 m .78353 .29499 L .78866 .30291 L F
.7771 .30533 m .77189 .29677 L .78353 .29499 L F
.825 .761 .792 r
.67659 .30051 m .68192 .28012 L .68752 .29067 L F
.67659 .30051 m .67104 .29178 L .68192 .28012 L F
.859 .811 .801 r
.66569 .31111 m .67104 .29178 L .67659 .30051 L F
.781 .711 .787 r
.68752 .29067 m .69287 .27002 L .69852 .28214 L F
.68752 .29067 m .68192 .28012 L .69287 .27002 L F
.852 .946 .879 r
.63291 .34096 m .6384 .32847 L .64387 .33201 L F
.63291 .34096 m .62742 .33851 L .6384 .32847 L F
.729 .284 0 r
.52032 .2983 m .52523 .30975 L .5313 .31507 L F
.859 .811 .801 r
.66569 .31111 m .66019 .30428 L .67104 .29178 L F
.88 .861 .818 r
.65479 .32184 m .66019 .30428 L .66569 .31111 L F
.625 .121 0 r
.54328 .32613 m .54846 .33384 L .55441 .3371 L F
.54328 .32613 m .53732 .32054 L .54846 .33384 L F
.934 .84 .727 r
.35419 .35385 m .3473 .35053 L .35881 .3304 L F
.914 .862 .776 r
.34293 .3697 m .3473 .35053 L .35419 .35385 L F
.88 .861 .818 r
.65479 .32184 m .64932 .31679 L .66019 .30428 L F
.881 .908 .843 r
.64387 .33201 m .64932 .31679 L .65479 .32184 L F
.186 .575 .938 r
.29351 .38548 m .29661 .38192 L .30366 .38676 L F
.29351 .38548 m .28651 .37975 L .29661 .38192 L F
.881 .908 .843 r
.64387 .33201 m .6384 .32847 L .64932 .31679 L F
.323 .787 .939 r
.59414 .3533 m .59965 .35016 L .60527 .35126 L F
.59414 .3533 m .58846 .35158 L .59965 .35016 L F
.729 .664 .786 r
.69852 .28214 m .70394 .26207 L .70964 .27531 L F
.69852 .28214 m .69287 .27002 L .70394 .26207 L F
.569 .634 .876 r
.76033 .29881 m .76661 .28765 L .77189 .29677 L F
.76033 .29881 m .75497 .28902 L .76661 .28765 L F
.395 .306 .636 r
.69188 .11306 m .68939 .12452 L .68786 .11707 L F
.944 .793 .663 r
.36369 .30217 m .3569 .29743 L .36883 .26896 L F
.948 .791 .654 r
.3569 .29743 m .36214 .26264 L .36883 .26896 L F
.579 .608 .845 r
.74345 .29112 m .74953 .27835 L .75497 .28902 L F
.74345 .29112 m .73795 .27994 L .74953 .27835 L F
.888 .658 .585 r
.64508 .11656 m .64077 .17673 L .64419 .11621 L F
.64508 .11656 m .65076 .14124 L .64077 .17673 L F
.614 .602 .816 r
.72653 .28289 m .73235 .26759 L .73795 .27994 L F
.72653 .28289 m .72091 .27045 L .73235 .26759 L F
.942 .767 .635 r
.36214 .26264 m .3554 .25632 L .36765 .22246 L F
.945 .764 .626 r
.3554 .25632 m .36108 .21377 L .36765 .22246 L F
.888 .658 .585 r
.64419 .11621 m .63461 .15566 L .64377 .11592 L F
.64419 .11621 m .64077 .17673 L .63461 .15566 L F
.801 .609 .641 r
.66327 .18831 m .66742 .1429 L .67381 .16902 L F
.66327 .18831 m .65706 .16609 L .66742 .1429 L F
.895 .653 .566 r
.64377 .11592 m .63461 .15566 L .63649 .11288 L F
.671 .619 .788 r
.70964 .27531 m .71518 .25663 L .72091 .27045 L F
.70964 .27531 m .70394 .26207 L .71518 .25663 L F
.762 .871 .927 r
.32111 .38851 m .32489 .3778 L .33189 .38129 L F
.32111 .38851 m .31412 .38443 L .32489 .3778 L F
0 .057 .569 r
.2532 .35359 m .25556 .35487 L .26266 .36159 L F
.2532 .35359 m .24617 .34609 L .25556 .35487 L F
.411 .333 .658 r
.696 .15358 m .68939 .12452 L .70137 .13189 L F
.587 .45 .661 r
.68467 .15703 m .68939 .12452 L .696 .15358 L F
.395 .306 .636 r
.69638 .10885 m .68939 .12452 L .69188 .11306 L F
.69638 .10885 m .70137 .13189 L .68939 .12452 L F
.943 .817 .69 r
.35881 .3304 m .35195 .32663 L .36369 .30217 L F
.937 .841 .723 r
.3473 .35053 m .35195 .32663 L .35881 .3304 L F
.48 0 0 r
.5603 .34074 m .56564 .34558 L .57148 .3473 L F
.5603 .34074 m .55441 .3371 L .56564 .34558 L F
.812 .429 0 r
.48524 .23898 m .48962 .25645 L .49585 .26516 L F
0 .429 .741 r
.57727 .34961 m .58273 .35058 L .58306 .35063 L F
.57727 .34961 m .57148 .3473 L .58273 .35058 L F
.335 0 0 r
.57148 .3473 m .57695 .35041 L .58273 .35058 L F
0 .566 .711 r
.58273 .35058 m .57695 .35041 L .58239 .35054 L F
0 .429 .741 r
.58306 .35063 m .58273 .35058 L .58846 .35158 L F
.171 .701 .852 r
.58846 .35158 m .58273 .35058 L .59399 .34993 L F
0 .566 .711 r
.59068 .35012 m .58828 .35068 L .59399 .34993 L F
.58273 .35058 m .58828 .35068 L .59068 .35012 L F
.58273 .35058 m .58239 .35054 L .58828 .35068 L F
.203 0 0 r
.57695 .35041 m .58251 .35257 L .58828 .35068 L F
.3 .782 .702 r
.58828 .35068 m .58251 .35257 L .58584 .35125 L F
.58828 .35068 m .58584 .35125 L .59387 .34805 L F
.914 .862 .776 r
.34293 .3697 m .33597 .36649 L .3473 .35053 L F
.866 .879 .845 r
.33189 .38129 m .33597 .36649 L .34293 .3697 L F
.947 .816 .683 r
.35195 .32663 m .3569 .29743 L .36369 .30217 L F
.573 .69 .92 r
.78866 .30291 m .79524 .29327 L .80028 .30048 L F
.78866 .30291 m .78353 .29499 L .79524 .29327 L F
.866 .879 .845 r
.33189 .38129 m .32489 .3778 L .33597 .36649 L F
.742 .653 .762 r
.69287 .27002 m .69814 .24739 L .70394 .26207 L F
.69287 .27002 m .68713 .25677 L .69814 .24739 L F
.799 .705 .761 r
.68192 .28012 m .68713 .25677 L .69287 .27002 L F
.68192 .28012 m .67625 .26879 L .68713 .25677 L F
.847 .758 .764 r
.67104 .29178 m .67625 .26879 L .68192 .28012 L F
.895 .653 .566 r
.63649 .11288 m .62837 .13233 L .63256 .11015 L F
.63649 .11288 m .63461 .15566 L .62837 .13233 L F
0 0 .505 r
.2299 .32915 m .22284 .32091 L .23197 .33088 L F
.598 .937 .947 r
.60527 .35126 m .61081 .34518 L .61637 .34626 L F
.60527 .35126 m .59965 .35016 L .61081 .34518 L F
.588 .466 .682 r
.69105 .18215 m .68467 .15703 L .696 .15358 L F
.703 .547 .674 r
.68007 .19217 m .68467 .15703 L .69105 .18215 L F
.68007 .19217 m .67381 .16902 L .68467 .15703 L F
.547 .641 .895 r
.77189 .29677 m .77835 .28675 L .78353 .29499 L F
.77189 .29677 m .76661 .28765 L .77835 .28675 L F
.608 .578 .794 r
.72091 .27045 m .72664 .25385 L .73235 .26759 L F
.72091 .27045 m .71518 .25663 L .72664 .25385 L F
.847 .758 .764 r
.67104 .29178 m .66544 .28268 L .67625 .26879 L F
.885 .812 .772 r
.66019 .30428 m .66544 .28268 L .67104 .29178 L F
.677 .602 .765 r
.70394 .26207 m .70934 .2412 L .71518 .25663 L F
.70394 .26207 m .69814 .24739 L .70934 .2412 L F
.559 .575 .827 r
.73795 .27994 m .74398 .26663 L .74953 .27835 L F
.73795 .27994 m .73235 .26759 L .74398 .26663 L F
.539 .598 .862 r
.75497 .28902 m .76125 .27786 L .76661 .28765 L F
.75497 .28902 m .74953 .27835 L .76125 .27786 L F
.787 .352 0 r
.51426 .29025 m .51911 .30458 L .52523 .30975 L F
.51426 .29025 m .50817 .28205 L .51911 .30458 L F
0 .214 .697 r
.26971 .36826 m .27234 .36823 L .27946 .374 L F
.26971 .36826 m .26266 .36159 L .27234 .36823 L F
.88 .664 .606 r
.64687 .19581 m .65076 .14124 L .65706 .16609 L F
.64687 .19581 m .64077 .17673 L .65076 .14124 L F
.791 .616 .664 r
.66937 .20821 m .67381 .16902 L .68007 .19217 L F
.66937 .20821 m .66327 .18831 L .67381 .16902 L F
.502 .775 .993 r
.30366 .38676 m .30704 .38041 L .31412 .38443 L F
.30366 .38676 m .29661 .38192 L .30704 .38041 L F
.885 .812 .772 r
.66019 .30428 m .65465 .29746 L .66544 .28268 L F
.907 .866 .787 r
.64932 .31679 m .65465 .29746 L .66019 .30428 L F
.9 .649 .548 r
.63256 .11015 m .62837 .13233 L .62917 .10867 L F
.844 .468 0 r
.47911 .22701 m .48336 .24754 L .48962 .25645 L F
.716 .224 0 r
.53732 .32054 m .54246 .33101 L .54846 .33384 L F
.53732 .32054 m .5313 .31507 L .54246 .33101 L F
.755 .643 .737 r
.68713 .25677 m .69223 .23103 L .69814 .24739 L F
.68713 .25677 m .6813 .2422 L .69223 .23103 L F
.817 .699 .734 r
.67625 .26879 m .6813 .2422 L .68713 .25677 L F
.075 .504 .898 r
.28651 .37975 m .2895 .3771 L .29661 .38192 L F
.28651 .37975 m .27946 .374 L .2895 .3771 L F
.945 .764 .626 r
.3554 .25632 m .3486 .25002 L .36108 .21377 L F
.948 .761 .617 r
.3486 .25002 m .35447 .20494 L .36108 .21377 L F
.783 .982 .904 r
.61637 .34626 m .6219 .33681 L .62742 .33851 L F
.61637 .34626 m .61081 .34518 L .6219 .33681 L F
.103 .116 .587 r
.69748 .10581 m .70137 .13189 L .69638 .10885 L F
.683 .587 .742 r
.69814 .24739 m .70338 .22385 L .70934 .2412 L F
.69814 .24739 m .69223 .23103 L .70338 .22385 L F
.907 .866 .787 r
.64932 .31679 m .64381 .31209 L .65465 .29746 L F
.908 .918 .813 r
.6384 .32847 m .64381 .31209 L .64932 .31679 L F
.9 .649 .548 r
.62917 .10867 m .62206 .10646 L .62246 .1039 L F
.62917 .10867 m .62837 .13233 L .62206 .10646 L F
.602 .553 .772 r
.71518 .25663 m .7208 .23845 L .72664 .25385 L F
.71518 .25663 m .70934 .2412 L .7208 .23845 L F
.948 .791 .654 r
.3569 .29743 m .35004 .29279 L .36214 .26264 L F
.951 .789 .645 r
.35004 .29279 m .3554 .25632 L .36214 .26264 L F
.817 .699 .734 r
.67625 .26879 m .67052 .25658 L .6813 .2422 L F
.868 .754 .735 r
.66544 .28268 m .67052 .25658 L .67625 .26879 L F
.696 .559 .696 r
.68621 .21273 m .68007 .19217 L .69105 .18215 L F
.78 .624 .687 r
.67538 .22609 m .68007 .19217 L .68621 .21273 L F
.67538 .22609 m .66937 .20821 L .68007 .19217 L F
.589 .485 .703 r
.69729 .20429 m .69105 .18215 L .70244 .17905 L F
.696 .559 .696 r
.68621 .21273 m .69105 .18215 L .69729 .20429 L F
.588 .466 .682 r
.69105 .18215 m .696 .15358 L .70244 .17905 L F
.937 .841 .723 r
.3473 .35053 m .34033 .34735 L .35195 .32663 L F
.915 .865 .776 r
.33597 .36649 m .34033 .34735 L .3473 .35053 L F
.875 .963 .853 r
.62742 .33851 m .6329 .32552 L .6384 .32847 L F
.62742 .33851 m .6219 .33681 L .6329 .32552 L F
.908 .918 .813 r
.6384 .32847 m .6329 .32552 L .64381 .31209 L F
.43 .363 .682 r
.70244 .17905 m .696 .15358 L .70795 .15927 L F
.411 .333 .658 r
.696 .15358 m .70137 .13189 L .70795 .15927 L F
0 0 .508 r
.24617 .34609 m .2484 .34811 L .25556 .35487 L F
.24617 .34609 m .2391 .33852 L .2484 .34811 L F
.538 .541 .805 r
.73235 .26759 m .73832 .25363 L .74398 .26663 L F
.73235 .26759 m .72664 .25385 L .73832 .25363 L F
.689 .572 .719 r
.69223 .23103 m .69729 .20429 L .70338 .22385 L F
.69223 .23103 m .68621 .21273 L .69729 .20429 L F
.768 .633 .712 r
.6813 .2422 m .68621 .21273 L .69223 .23103 L F
.6813 .2422 m .67538 .22609 L .68621 .21273 L F
.871 .671 .629 r
.65289 .21313 m .65706 .16609 L .66327 .18831 L F
.65289 .21313 m .64687 .19581 L .65706 .16609 L F
.532 .66 .918 r
.78353 .29499 m .79017 .286 L .79524 .29327 L F
.78353 .29499 m .77835 .28675 L .79017 .286 L F
.171 .701 .852 r
.58846 .35158 m .59399 .34993 L .59965 .35016 L F
.833 .692 .707 r
.67052 .25658 m .67538 .22609 L .6813 .2422 L F
.597 .529 .749 r
.70934 .2412 m .71483 .22108 L .7208 .23845 L F
.70934 .2412 m .70338 .22385 L .71483 .22108 L F
.103 .116 .587 r
.69748 .10581 m .70763 .12415 L .70137 .13189 L F
.082 .107 .587 r
.70106 .09481 m .70763 .12415 L .69748 .10581 L F
.504 .557 .844 r
.74953 .27835 m .7558 .26724 L .76125 .27786 L F
.74953 .27835 m .74398 .26663 L .7558 .26724 L F
.593 .506 .726 r
.70338 .22385 m .69729 .20429 L .70872 .20141 L F
.589 .485 .703 r
.69729 .20429 m .70244 .17905 L .70872 .20141 L F
.503 .601 .884 r
.76661 .28765 m .7731 .27811 L .77835 .28675 L F
.76661 .28765 m .76125 .27786 L .7731 .27811 L F
.868 .754 .735 r
.66544 .28268 m .65979 .27314 L .67052 .25658 L F
.907 .81 .74 r
.65465 .29746 m .65979 .27314 L .66544 .28268 L F
.739 .872 .942 r
.31412 .38443 m .31782 .3744 L .32489 .3778 L F
.31412 .38443 m .30704 .38041 L .31782 .3744 L F
.869 .501 .01 r
.47295 .21453 m .47706 .23841 L .48336 .24754 L F
.47295 .21453 m .46678 .20149 L .47706 .23841 L F
.593 .506 .726 r
.70338 .22385 m .70872 .20141 L .71483 .22108 L F
.947 .816 .683 r
.35195 .32663 m .34502 .32301 L .3569 .29743 L F
.95 .815 .675 r
.34502 .32301 m .35004 .29279 L .3569 .29743 L F
.94 .841 .719 r
.34033 .34735 m .34502 .32301 L .35195 .32663 L F
.833 .692 .707 r
.67052 .25658 m .66471 .24333 L .67538 .22609 L F
.848 .685 .68 r
.66471 .24333 m .66937 .20821 L .67538 .22609 L F
.86 .678 .654 r
.65884 .22891 m .66327 .18831 L .66937 .20821 L F
.65884 .22891 m .65289 .21313 L .66327 .18831 L F
.613 .063 0 r
.55441 .3371 m .55975 .34454 L .56564 .34558 L F
.55441 .3371 m .54846 .33384 L .55975 .34454 L F
.831 .409 0 r
.50817 .28205 m .51293 .29961 L .51911 .30458 L F
.50817 .28205 m .50203 .27369 L .51293 .29961 L F
.905 .645 .533 r
.62246 .1039 m .62206 .10646 L .62213 .10375 L F
.915 .865 .776 r
.33597 .36649 m .32893 .36341 L .34033 .34735 L F
.862 .884 .852 r
.32489 .3778 m .32893 .36341 L .33597 .36649 L F
.905 .645 .533 r
.62213 .10375 m .62206 .10646 L .62133 .10318 L F
.848 .685 .68 r
.66471 .24333 m .65884 .22891 L .66937 .20821 L F
.516 .505 .782 r
.72664 .25385 m .73254 .2391 L .73832 .25363 L F
.72664 .25385 m .7208 .23845 L .73254 .2391 L F
.335 0 0 r
.57148 .3473 m .56564 .34558 L .57695 .35041 L F
.886 .749 .705 r
.65979 .27314 m .66471 .24333 L .67052 .25658 L F
.951 .694 .511 r
.62133 .10318 m .61268 .17222 L .61501 .0989 L F
.62133 .10318 m .62206 .10646 L .61268 .17222 L F
.862 .884 .852 r
.32489 .3778 m .31782 .3744 L .32893 .36341 L F
0 .132 .622 r
.26266 .36159 m .26516 .36246 L .27234 .36823 L F
.26266 .36159 m .25556 .35487 L .26516 .36246 L F
.45 .396 .706 r
.70872 .20141 m .70244 .17905 L .71435 .18324 L F
.43 .363 .682 r
.70244 .17905 m .70795 .15927 L .71435 .18324 L F
.948 .7 .528 r
.61876 .18817 m .62206 .10646 L .62837 .13233 L F
.61876 .18817 m .61268 .17222 L .62206 .10646 L F
.152 .169 .623 r
.70795 .15927 m .70137 .13189 L .71422 .15071 L F
.103 .116 .587 r
.70137 .13189 m .70763 .12415 L .71422 .15071 L F
.948 .761 .617 r
.3486 .25002 m .34174 .24375 L .35447 .20494 L F
.907 .81 .74 r
.65465 .29746 m .64906 .29065 L .65979 .27314 L F
.931 .868 .754 r
.64381 .31209 m .64906 .29065 L .65465 .29746 L F
.425 .743 .993 r
.29661 .38192 m .2999 .37644 L .30704 .38041 L F
.29661 .38192 m .2895 .3771 L .2999 .37644 L F
.889 .529 .051 r
.46678 .20149 m .47072 .22905 L .47706 .23841 L F
.46678 .20149 m .4606 .18783 L .47072 .22905 L F
.494 .468 .757 r
.7208 .23845 m .72663 .22275 L .73254 .2391 L F
.7208 .23845 m .71483 .22108 L .72663 .22275 L F
.463 .51 .822 r
.74398 .26663 m .75025 .25562 L .7558 .26724 L F
.74398 .26663 m .73832 .25363 L .75025 .25562 L F
.532 .921 .903 r
.59965 .35016 m .6052 .34502 L .61081 .34518 L F
.59965 .35016 m .59399 .34993 L .6052 .34502 L F
0 .421 .842 r
.27946 .374 m .28233 .3723 L .2895 .3771 L F
.27946 .374 m .27234 .36823 L .28233 .3723 L F
.471 .431 .732 r
.71483 .22108 m .70872 .20141 L .72057 .20426 L F
.45 .396 .706 r
.70872 .20141 m .71435 .18324 L .72057 .20426 L F
.784 .308 0 r
.5313 .31507 m .5364 .32867 L .54246 .33101 L F
.5313 .31507 m .52523 .30975 L .5364 .32867 L F
.471 .431 .732 r
.71483 .22108 m .72057 .20426 L .72663 .22275 L F
.951 .789 .645 r
.35004 .29279 m .34311 .28827 L .3554 .25632 L F
.954 .787 .637 r
.34311 .28827 m .3486 .25002 L .3554 .25632 L F
.552 .062 0 r
.2391 .33852 m .24119 .34131 L .2484 .34811 L F
.886 .749 .705 r
.65979 .27314 m .65409 .26312 L .66471 .24333 L F
.902 .743 .674 r
.65409 .26312 m .65884 .22891 L .66471 .24333 L F
.448 .55 .868 r
.76125 .27786 m .76778 .26898 L .7731 .27811 L F
.76125 .27786 m .7558 .26724 L .76778 .26898 L F
.473 .618 .912 r
.77835 .28675 m .78506 .27868 L .79017 .286 L F
.77835 .28675 m .7731 .27811 L .78506 .27868 L F
.931 .868 .754 r
.64381 .31209 m .63826 .30779 L .64906 .29065 L F
.933 .924 .778 r
.6329 .32552 m .63826 .30779 L .64381 .31209 L F
.927 .806 .707 r
.64906 .29065 m .65409 .26312 L .65979 .27314 L F
.951 .694 .511 r
.61501 .0989 m .60656 .15493 L .61339 .0972 L F
.61501 .0989 m .61268 .17222 L .60656 .15493 L F
.945 .706 .547 r
.62478 .20292 m .62837 .13233 L .63461 .15566 L F
.62478 .20292 m .61876 .18817 L .62837 .13233 L F
.906 .553 .088 r
.4606 .18783 m .46434 .21945 L .47072 .22905 L F
.4606 .18783 m .45441 .1735 L .46434 .21945 L F
.94 .841 .719 r
.34033 .34735 m .33329 .34432 L .34502 .32301 L F
.917 .869 .776 r
.32893 .36341 m .33329 .34432 L .34033 .34735 L F
.779 .995 .872 r
.61081 .34518 m .61634 .33597 L .6219 .33681 L F
.61081 .34518 m .6052 .34502 L .61634 .33597 L F
.954 .689 .496 r
.61339 .0972 m .60656 .15493 L .60808 .09355 L F
.933 .924 .778 r
.6329 .32552 m .62736 .32327 L .63826 .30779 L F
.894 .975 .819 r
.6219 .33681 m .62736 .32327 L .6329 .32552 L F
.416 .458 .796 r
.73832 .25363 m .74459 .24279 L .75025 .25562 L F
.73832 .25363 m .73254 .2391 L .74459 .24279 L F
.865 .455 0 r
.50203 .27369 m .50669 .29486 L .51293 .29961 L F
.50203 .27369 m .49585 .26516 L .50669 .29486 L F
.204 .225 .66 r
.71435 .18324 m .70795 .15927 L .72061 .17398 L F
.152 .169 .623 r
.70795 .15927 m .71422 .15071 L .72061 .17398 L F
.902 .743 .674 r
.65409 .26312 m .64834 .25253 L .65884 .22891 L F
.915 .735 .645 r
.64834 .25253 m .65289 .21313 L .65884 .22891 L F
.894 .975 .819 r
.6219 .33681 m .61634 .33597 L .62736 .32327 L F
.711 .872 .957 r
.30704 .38041 m .31067 .37111 L .31782 .3744 L F
.30704 .38041 m .2999 .37644 L .31067 .37111 L F
0 0 .381 r
.70105 .09449 m .70763 .12415 L .70106 .09481 L F
.95 .815 .675 r
.34502 .32301 m .338 .31954 L .35004 .29279 L F
.953 .814 .668 r
.338 .31954 m .34311 .28827 L .35004 .29279 L F
0 .053 .544 r
.25556 .35487 m .25792 .35668 L .26516 .36246 L F
.25556 .35487 m .2484 .34811 L .25792 .35668 L F
0 0 .381 r
.70105 .09449 m .71553 .14031 L .70763 .12415 L F
0 0 .272 r
.6993 .07853 m .70742 .11017 L .70058 .08458 L F
.70742 .11017 m .70905 .11649 L .70802 .11262 L F
.70742 .11017 m .70802 .11262 L .70058 .08458 L F
.6991 .07496 m .70239 .0895 L .6993 .07853 L F
.86 .566 .037 r
.69663 .06561 m .69677 .06642 L .70239 .0895 L F
0 0 .272 r
.6993 .07853 m .70239 .0895 L .70905 .11649 L F
.86 .566 .037 r
.69677 .06642 m .6983 .07587 L .70239 .0895 L F
0 0 .323 r
.70101 .0943 m .71318 .13285 L .70105 .09449 L F
.71318 .13285 m .7132 .13291 L .70105 .09449 L F
.7145 .13702 m .70905 .11649 L .71553 .14031 L F
.70101 .0943 m .70905 .11649 L .7145 .13702 L F
.836 .538 0 r
.70905 .11649 m .70239 .0895 L .7036 .09594 L F
0 0 .323 r
.70058 .08458 m .70905 .11649 L .70101 .0943 L F
.204 .225 .66 r
.71435 .18324 m .72061 .17398 L .72684 .19444 L F
0 0 .444 r
.71422 .15071 m .70763 .12415 L .72185 .16138 L F
0 0 .381 r
.71951 .15526 m .71553 .14031 L .72185 .16138 L F
.70763 .12415 m .71502 .13926 L .71951 .15526 L F
.71502 .13926 m .71553 .14031 L .71951 .15526 L F
.836 .538 0 r
.70905 .11649 m .7036 .09594 L .70509 .10389 L F
0 0 .513 r
.72061 .17398 m .71422 .15071 L .72801 .18008 L F
.76 .454 0 r
.72185 .16138 m .71553 .14031 L .71672 .14486 L F
0 0 .444 r
.72426 .17208 m .72185 .16138 L .72696 .17785 L F
.71422 .15071 m .72059 .15962 L .72426 .17208 L F
.72059 .15962 m .72185 .16138 L .72426 .17208 L F
0 .033 .583 r
.72684 .19444 m .72061 .17398 L .73403 .19677 L F
0 0 .444 r
.72696 .17785 m .72185 .16138 L .72801 .18008 L F
.699 .39 0 r
.72801 .18008 m .72185 .16138 L .72304 .16516 L F
0 0 .513 r
.73026 .19036 m .72801 .18008 L .73296 .19496 L F
.72674 .17904 m .72801 .18008 L .73026 .19036 L F
0 .131 .651 r
.7329 .2125 m .72684 .19444 L .73992 .21175 L F
0 .033 .583 r
.72684 .19444 m .73403 .19677 L .73992 .21175 L F
.699 .39 0 r
.72801 .18008 m .72304 .16516 L .73726 .2102 L F
0 0 .513 r
.73296 .19496 m .72801 .18008 L .73403 .19677 L F
.72061 .17398 m .72674 .17904 L .73026 .19036 L F
0 0 .323 r
.71318 .13285 m .71553 .14031 L .7132 .13291 L F
.804 .502 0 r
.71553 .14031 m .70905 .11649 L .71321 .13542 L F
.258 .283 .697 r
.72057 .20426 m .71435 .18324 L .72684 .19444 L F
.804 .502 0 r
.71693 .14739 m .71321 .13542 L .72617 .19432 L F
.71553 .14031 m .71321 .13542 L .71693 .14739 L F
.76 .454 0 r
.72185 .16138 m .71672 .14486 L .73174 .20229 L F
.836 .538 0 r
.70965 .12013 m .70509 .10389 L .70664 .11215 L F
.7105 .12527 m .70664 .11215 L .72057 .18628 L F
.70965 .12013 m .70664 .11215 L .7105 .12527 L F
.70905 .11649 m .70509 .10389 L .70965 .12013 L F
.86 .566 .037 r
.6983 .07587 m .71491 .17819 L .70301 .09392 L F
.6983 .07587 m .70301 .09392 L .70239 .0895 L F
.94 .713 .568 r
.63075 .21662 m .63461 .15566 L .64077 .17673 L F
.63075 .21662 m .62478 .20292 L .63461 .15566 L F
.919 .574 .12 r
.45441 .1735 m .45793 .20956 L .46434 .21945 L F
.45441 .1735 m .44822 .15844 L .45793 .20956 L F
.943 .843 .714 r
.33329 .34432 m .338 .31954 L .34502 .32301 L F
.915 .735 .645 r
.64834 .25253 m .64253 .24132 L .65289 .21313 L F
.925 .728 .617 r
.64253 .24132 m .64687 .19581 L .65289 .21313 L F
.927 .806 .707 r
.64906 .29065 m .64344 .28387 L .65409 .26312 L F
.952 .865 .717 r
.63826 .30779 m .64344 .28387 L .64906 .29065 L F
.71 .181 0 r
.54846 .33384 m .55379 .34425 L .55975 .34454 L F
.54846 .33384 m .54246 .33101 L .55379 .34425 L F
.366 .402 .766 r
.73254 .2391 m .73881 .2285 L .74459 .24279 L F
.73254 .2391 m .72663 .22275 L .73881 .2285 L F
.954 .689 .496 r
.60808 .09355 m .60038 .1361 L .6049 .09022 L F
.60808 .09355 m .60656 .15493 L .60038 .1361 L F
.379 .488 .844 r
.7558 .26724 m .76239 .25927 L .76778 .26898 L F
.7558 .26724 m .75025 .25562 L .76239 .25927 L F
.917 .869 .776 r
.32893 .36341 m .32182 .36046 L .33329 .34432 L F
.856 .89 .86 r
.31782 .3744 m .32182 .36046 L .32893 .36341 L F
.933 .72 .592 r
.63667 .22938 m .64077 .17673 L .64687 .19581 L F
.63667 .22938 m .63075 .21662 L .64077 .17673 L F
.925 .728 .617 r
.64253 .24132 m .63667 .22938 L .64687 .19581 L F
.943 .8 .673 r
.64344 .28387 m .64834 .25253 L .65409 .26312 L F
.856 .89 .86 r
.31782 .3744 m .31067 .37111 L .32182 .36046 L F
.393 .559 .899 r
.7731 .27811 m .77991 .2713 L .78506 .27868 L F
.7731 .27811 m .76778 .26898 L .77991 .2713 L F
.497 0 0 r
.56564 .34558 m .57112 .35117 L .57695 .35041 L F
.56564 .34558 m .55975 .34454 L .57112 .35117 L F
.313 .343 .732 r
.72663 .22275 m .7329 .2125 L .73881 .2285 L F
.72663 .22275 m .72057 .20426 L .7329 .2125 L F
.332 .698 .982 r
.2895 .3771 m .29268 .37256 L .2999 .37644 L F
.2895 .3771 m .28233 .3723 L .29268 .37256 L F
0 .328 .77 r
.27234 .36823 m .27508 .36754 L .28233 .3723 L F
.27234 .36823 m .26516 .36246 L .27508 .36754 L F
.258 .283 .697 r
.72057 .20426 m .72684 .19444 L .7329 .2125 L F
.93 .591 .148 r
.44822 .15844 m .45148 .19939 L .45793 .20956 L F
.44822 .15844 m .44203 .14258 L .45148 .19939 L F
.833 .376 0 r
.52523 .30975 m .53028 .32688 L .5364 .32867 L F
.52523 .30975 m .51911 .30458 L .53028 .32688 L F
.954 .787 .637 r
.34311 .28827 m .33609 .28387 L .3486 .25002 L F
.957 .784 .628 r
.33609 .28387 m .34174 .24375 L .3486 .25002 L F
.955 .684 .483 r
.6049 .09022 m .60038 .1361 L .60131 .08771 L F
.89 .492 .055 r
.49585 .26516 m .50039 .29035 L .50669 .29486 L F
.49585 .26516 m .48962 .25645 L .50039 .29035 L F
.952 .865 .717 r
.63826 .30779 m .63269 .30396 L .64344 .28387 L F
.953 .926 .739 r
.62736 .32327 m .63269 .30396 L .63826 .30779 L F
.296 .413 .812 r
.75025 .25562 m .75692 .24885 L .76239 .25927 L F
.75025 .25562 m .74459 .24279 L .75692 .24885 L F
.433 .873 .824 r
.59399 .34993 m .59956 .34592 L .6052 .34502 L F
.59399 .34993 m .58828 .35068 L .59956 .34592 L F
.955 .684 .483 r
.60131 .08771 m .59417 .11557 L .59684 .083 L F
.60131 .08771 m .60038 .1361 L .59417 .11557 L F
.943 .8 .673 r
.64344 .28387 m .63778 .27713 L .64834 .25253 L F
.955 .793 .64 r
.63778 .27713 m .64253 .24132 L .64834 .25253 L F
.943 .843 .714 r
.33329 .34432 m .32616 .34146 L .338 .31954 L F
.918 .873 .777 r
.32182 .36046 m .32616 .34146 L .33329 .34432 L F
.533 .023 0 r
.2484 .34811 m .25061 .3509 L .25792 .35668 L F
.2484 .34811 m .24119 .34131 L .25061 .3509 L F
.953 .926 .739 r
.62736 .32327 m .62179 .32183 L .63269 .30396 L F
.908 .981 .777 r
.61634 .33597 m .62179 .32183 L .62736 .32327 L F
.968 .86 .679 r
.63269 .30396 m .63778 .27713 L .64344 .28387 L F
.675 .869 .972 r
.2999 .37644 m .30344 .36794 L .31067 .37111 L F
.2999 .37644 m .29268 .37256 L .30344 .36794 L F
.285 .478 .872 r
.76778 .26898 m .77472 .26387 L .77991 .2713 L F
.76778 .26898 m .76239 .25927 L .77472 .26387 L F
.953 .814 .668 r
.338 .31954 m .3309 .31625 L .34311 .28827 L F
.956 .813 .661 r
.3309 .31625 m .33609 .28387 L .34311 .28827 L F
.763 .996 .824 r
.6052 .34502 m .61074 .33614 L .61634 .33597 L F
.6052 .34502 m .59956 .34592 L .61074 .33614 L F
.201 .326 .768 r
.74459 .24279 m .75136 .23757 L .75692 .24885 L F
.74459 .24279 m .73881 .2285 L .75136 .23757 L F
.908 .981 .777 r
.61634 .33597 m .61074 .33614 L .62179 .32183 L F
.946 .844 .709 r
.32616 .34146 m .3309 .31625 L .338 .31954 L F
.957 .681 .472 r
.59684 .083 m .59417 .11557 L .59467 .08146 L F
0 .229 .684 r
.26516 .36246 m .26776 .36282 L .27508 .36754 L F
.26516 .36246 m .25792 .35668 L .26776 .36282 L F
.779 .275 0 r
.54246 .33101 m .54776 .34483 L .55379 .34425 L F
.54246 .33101 m .5364 .32867 L .54776 .34483 L F
.918 .873 .777 r
.32182 .36046 m .31461 .35767 L .32616 .34146 L F
.85 .897 .87 r
.31067 .37111 m .31461 .35767 L .32182 .36046 L F
.909 .523 .102 r
.48962 .25645 m .49403 .28612 L .50039 .29035 L F
.48962 .25645 m .48336 .24754 L .49403 .28612 L F
.22 .637 .955 r
.28233 .3723 m .28538 .36876 L .29268 .37256 L F
.28233 .3723 m .27508 .36754 L .28538 .36876 L F
.85 .897 .87 r
.31067 .37111 m .30344 .36794 L .31461 .35767 L F
.957 .784 .628 r
.33609 .28387 m .32901 .27963 L .34174 .24375 L F
.203 0 0 r
.57695 .35041 m .57112 .35117 L .58251 .35257 L F
.867 .429 .033 r
.51911 .30458 m .52408 .32572 L .53028 .32688 L F
.51911 .30458 m .51293 .29961 L .52408 .32572 L F
.957 .681 .472 r
.59467 .08146 m .58792 .09313 L .58912 .07559 L F
.59467 .08146 m .59417 .11557 L .58792 .09313 L F
.955 .793 .64 r
.63778 .27713 m .63207 .27044 L .64253 .24132 L F
.965 .784 .608 r
.63207 .27044 m .63667 .22938 L .64253 .24132 L F
.096 .231 .714 r
.73881 .2285 m .74569 .22527 L .75136 .23757 L F
.73881 .2285 m .7329 .2125 L .74569 .22527 L F
.618 .051 0 r
.55975 .34454 m .56522 .353 L .57112 .35117 L F
.55975 .34454 m .55379 .34425 L .56522 .353 L F
.147 .37 .824 r
.76239 .25927 m .76949 .25638 L .77472 .26387 L F
.76239 .25927 m .75692 .24885 L .76949 .25638 L F
.968 .86 .679 r
.63269 .30396 m .62707 .30069 L .63778 .27713 L F
.968 .922 .696 r
.62179 .32183 m .62707 .30069 L .63269 .30396 L F
0 .131 .651 r
.7329 .2125 m .73992 .21175 L .74569 .22527 L F
.98 .852 .641 r
.62707 .30069 m .63207 .27044 L .63778 .27713 L F
.965 .784 .608 r
.63207 .27044 m .62632 .26383 L .63667 .22938 L F
.972 .775 .579 r
.62632 .26383 m .63075 .21662 L .63667 .22938 L F
.958 .677 .462 r
.58912 .07559 m .58792 .09313 L .58812 .07487 L F
.946 .844 .709 r
.32616 .34146 m .31894 .3388 L .3309 .31625 L F
.92 .878 .778 r
.31461 .35767 m .31894 .3388 L .32616 .34146 L F
.63 .862 .986 r
.29268 .37256 m .29613 .36491 L .30344 .36794 L F
.29268 .37256 m .28538 .36876 L .29613 .36491 L F
.924 .548 .142 r
.48336 .24754 m .4876 .28222 L .49403 .28612 L F
.48336 .24754 m .47706 .23841 L .4876 .28222 L F
0 0 .161 r
.69768 .06845 m .70239 .0895 L .6991 .07496 L F
.958 .677 .462 r
.58812 .07487 m .58164 .06855 L .58167 .06799 L F
.58812 .07487 m .58792 .09313 L .58164 .06855 L F
.956 .813 .661 r
.3309 .31625 m .32372 .31316 L .33609 .28387 L F
.959 .812 .654 r
.32372 .31316 m .32901 .27963 L .33609 .28387 L F
.3 .782 .702 r
.58828 .35068 m .59387 .34805 L .5972 .34692 L F
0 0 0 r
.59157 .34897 m .58813 .35159 L .59387 .34805 L F
.58251 .35257 m .58813 .35159 L .59157 .34897 L F
.013 0 0 r
.58587 .35242 m .58233 .35676 L .58813 .35159 L F
.5767 .35577 m .58233 .35676 L .58587 .35242 L F
0 0 0 r
.58233 .35676 m .57647 .36382 L .57873 .36118 L F
.608 .882 .562 r
.58813 .35159 m .58233 .35676 L .58463 .35426 L F
0 0 0 r
.58251 .35257 m .5767 .35577 L .58813 .35159 L F
.608 .882 .562 r
.58813 .35159 m .58463 .35426 L .59371 .34439 L F
0 0 0 r
.59209 .34615 m .58793 .35044 L .59371 .34439 L F
.58233 .35676 m .58793 .35044 L .59209 .34615 L F
.58233 .35676 m .57873 .36118 L .58793 .35044 L F
.58635 .35228 m .58209 .35858 L .58793 .35044 L F
.57647 .36382 m .58209 .35858 L .58635 .35228 L F
.58054 .36052 m .57619 .36916 L .58209 .35858 L F
.57054 .37305 m .57619 .36916 L .58054 .36052 L F
.57506 .3717 m .57619 .36916 L .57226 .37444 L F
.818 .826 .349 r
.57514 .37124 m .57619 .36916 L .57506 .3717 L F
.153 0 0 r
.57081 .36048 m .57647 .36382 L .58233 .35676 L F
0 0 0 r
.57647 .36382 m .57054 .37305 L .58209 .35858 L F
.57226 .37444 m .57619 .36916 L .57054 .37305 L F
.818 .826 .349 r
.5766 .36348 m .57619 .36916 L .57514 .37124 L F
.846 .862 .411 r
.58209 .35858 m .57619 .36916 L .57776 .36499 L F
.367 0 0 r
.57112 .35117 m .5767 .35577 L .58251 .35257 L F
.013 0 0 r
.5767 .35577 m .57081 .36048 L .58233 .35676 L F
.846 .862 .411 r
.58209 .35858 m .57776 .36499 L .58752 .3391 L F
.871 .896 .475 r
.58793 .35044 m .58209 .35858 L .5837 .35479 L F
.58793 .35044 m .5837 .35479 L .59335 .33209 L F
.679 .943 .668 r
.59387 .34805 m .58813 .35159 L .59049 .3492 L F
.59387 .34805 m .59049 .3492 L .59943 .34015 L F
.3 .782 .702 r
.5972 .34692 m .59387 .34805 L .59956 .34592 L F
0 .129 .589 r
.25792 .35668 m .26036 .35816 L .26776 .36282 L F
.25792 .35668 m .25061 .3509 L .26036 .35816 L F
.968 .922 .696 r
.62179 .32183 m .61618 .32132 L .62707 .30069 L F
.915 .979 .727 r
.61074 .33614 m .61618 .32132 L .62179 .32183 L F
0 .236 .748 r
.75692 .24885 m .76422 .24883 L .76949 .25638 L F
.75692 .24885 m .75136 .23757 L .76422 .24883 L F
.95 .845 .705 r
.31894 .3388 m .32372 .31316 L .3309 .31625 L F
.09 .556 .907 r
.27508 .36754 m .278 .36507 L .28538 .36876 L F
.27508 .36754 m .26776 .36282 L .278 .36507 L F
.892 .47 .094 r
.51293 .29961 m .51782 .32528 L .52408 .32572 L F
.51293 .29961 m .50669 .29486 L .51782 .32528 L F
.972 .775 .579 r
.62632 .26383 m .62053 .2573 L .63075 .21662 L F
.977 .765 .552 r
.62053 .2573 m .62478 .20292 L .63075 .21662 L F
.92 .878 .778 r
.31461 .35767 m .30732 .35507 L .31894 .3388 L F
.842 .904 .88 r
.30344 .36794 m .30732 .35507 L .31461 .35767 L F
.30344 .36794 m .29613 .36491 L .30732 .35507 L F
.825 .347 .013 r
.5364 .32867 m .54167 .34639 L .54776 .34483 L F
.5364 .32867 m .53028 .32688 L .54167 .34639 L F
.73 .98 .756 r
.59956 .34592 m .60511 .33747 L .61074 .33614 L F
.59956 .34592 m .59387 .34805 L .60511 .33747 L F
.915 .979 .727 r
.61074 .33614 m .60511 .33747 L .61618 .32132 L F
.86 .566 .037 r
.69663 .06561 m .70239 .0895 L .69768 .06845 L F
.367 0 0 r
.57112 .35117 m .56522 .353 L .5767 .35577 L F
.98 .852 .641 r
.62707 .30069 m .62142 .29806 L .63207 .27044 L F
.989 .842 .604 r
.62142 .29806 m .62632 .26383 L .63207 .27044 L F
.935 .568 .176 r
.47706 .23841 m .4811 .27868 L .4876 .28222 L F
.47706 .23841 m .47072 .22905 L .4811 .27868 L F
.959 .674 .453 r
.58167 .06799 m .58164 .06855 L .58164 .06797 L F
.58164 .06797 m .58164 .06855 L .58146 .06778 L F
.977 .765 .552 r
.62053 .2573 m .6147 .25088 L .62478 .20292 L F
.98 .756 .527 r
.6147 .25088 m .61876 .18817 L .62478 .20292 L F
.984 .711 .422 r
.58146 .06778 m .57253 .21157 L .57501 .0613 L F
.58146 .06778 m .58164 .06855 L .57253 .21157 L F
.979 .915 .651 r
.61618 .32132 m .62142 .29806 L .62707 .30069 L F
.984 .716 .431 r
.57871 .2163 m .58164 .06855 L .58792 .09313 L F
.57871 .2163 m .57253 .21157 L .58164 .06855 L F
0 .086 .645 r
.75136 .23757 m .75892 .24122 L .76422 .24883 L F
.75136 .23757 m .74569 .22527 L .75892 .24122 L F
.702 .168 0 r
.55379 .34425 m .55926 .35606 L .56522 .353 L F
.55379 .34425 m .54776 .34483 L .55926 .35606 L F
.878 .587 .069 r
.69631 .06513 m .71491 .17819 L .69663 .06561 L F
.69631 .06513 m .70922 .17002 L .71491 .17819 L F
.69311 .05659 m .70922 .17002 L .69631 .06513 L F
.57 .848 .996 r
.28538 .36876 m .28872 .36204 L .29613 .36491 L F
.28538 .36876 m .278 .36507 L .28872 .36204 L F
.98 .756 .527 r
.6147 .25088 m .60882 .24459 L .61876 .18817 L F
.982 .748 .506 r
.60882 .24459 m .61268 .17222 L .61876 .18817 L F
.959 .812 .654 r
.32372 .31316 m .31644 .31029 L .32901 .27963 L F
.95 .845 .705 r
.31894 .3388 m .31163 .33636 L .32372 .31316 L F
.921 .883 .779 r
.30732 .35507 m .31163 .33636 L .31894 .3388 L F
.984 .721 .442 r
.58483 .22141 m .58792 .09313 L .59417 .11557 L F
.58483 .22141 m .57871 .2163 L .58792 .09313 L F
0 .457 .835 r
.26776 .36282 m .27054 .36149 L .278 .36507 L F
.26776 .36282 m .26036 .35816 L .27054 .36149 L F
.86 .566 .037 r
.70239 .0895 m .71491 .17819 L .72057 .18628 L F
.982 .748 .506 r
.60882 .24459 m .60289 .23847 L .61268 .17222 L F
.984 .74 .486 r
.60289 .23847 m .60656 .15493 L .61268 .17222 L F
0 0 .524 r
.74569 .22527 m .75356 .23356 L .75892 .24122 L F
.74569 .22527 m .73992 .21175 L .75356 .23356 L F
.91 .503 .145 r
.50669 .29486 m .51147 .32564 L .51782 .32528 L F
.50669 .29486 m .50039 .29035 L .51147 .32564 L F
.953 .847 .7 r
.31163 .33636 m .31644 .31029 L .32372 .31316 L F
.984 .726 .455 r
.5909 .22684 m .59417 .11557 L .60038 .1361 L F
.5909 .22684 m .58483 .22141 L .59417 .11557 L F
.984 .711 .422 r
.57501 .0613 m .5663 .20728 L .57432 .06029 L F
.57501 .0613 m .57253 .21157 L .5663 .20728 L F
.944 .586 .205 r
.47072 .22905 m .47452 .27555 L .4811 .27868 L F
.47072 .22905 m .46434 .21945 L .47452 .27555 L F
.984 .74 .486 r
.60289 .23847 m .59692 .23254 L .60656 .15493 L F
.984 .733 .47 r
.59692 .23254 m .60038 .1361 L .60656 .15493 L F
.979 .915 .651 r
.61618 .32132 m .61054 .3219 L .62142 .29806 L F
.915 .969 .67 r
.60511 .33747 m .61054 .3219 L .61618 .32132 L F
.832 .912 .892 r
.29613 .36491 m .29994 .35267 L .30732 .35507 L F
.29613 .36491 m .28872 .36204 L .29994 .35267 L F
.984 .733 .47 r
.59692 .23254 m .5909 .22684 L .60038 .1361 L F
.921 .883 .779 r
.30732 .35507 m .29994 .35267 L .31163 .33636 L F
.989 .842 .604 r
.62142 .29806 m .61573 .29618 L .62632 .26383 L F
.995 .831 .569 r
.61573 .29618 m .62053 .2573 L .62632 .26383 L F
.857 .403 .09 r
.53028 .32688 m .53549 .34908 L .54167 .34639 L F
.53028 .32688 m .52408 .32572 L .53549 .34908 L F
0 0 .401 r
.73992 .21175 m .74817 .22583 L .75356 .23356 L F
.73992 .21175 m .73403 .19677 L .74817 .22583 L F
.836 .538 0 r
.70905 .11649 m .72057 .18628 L .72617 .19432 L F
.915 .969 .67 r
.60511 .33747 m .59943 .34015 L .61054 .3219 L F
.679 .943 .668 r
.59387 .34805 m .59943 .34015 L .60511 .33747 L F
.892 .603 .095 r
.69182 .05466 m .70922 .17002 L .69311 .05659 L F
.985 .903 .605 r
.61054 .3219 m .61573 .29618 L .62142 .29806 L F
0 0 .289 r
.73403 .19677 m .74274 .21805 L .74817 .22583 L F
.73403 .19677 m .72801 .18008 L .74274 .21805 L F
.892 .603 .095 r
.69182 .05466 m .70347 .16179 L .70922 .17002 L F
.68914 .04764 m .70347 .16179 L .69182 .05466 L F
.494 .824 .999 r
.278 .36507 m .28122 .35935 L .28872 .36204 L F
.278 .36507 m .27054 .36149 L .28122 .35935 L F
.95 .6 .23 r
.46434 .21945 m .46787 .2729 L .47452 .27555 L F
.46434 .21945 m .45793 .20956 L .46787 .2729 L F
.493 0 0 r
.56522 .353 m .57081 .36048 L .5767 .35577 L F
.56522 .353 m .55926 .35606 L .57081 .36048 L F
.804 .502 0 r
.71553 .14031 m .72617 .19432 L .73174 .20229 L F
.759 .257 .024 r
.54776 .34483 m .55322 .36052 L .55926 .35606 L F
.54776 .34483 m .54167 .34639 L .55322 .36052 L F
.699 .39 0 r
.72801 .18008 m .73726 .2102 L .74274 .21805 L F
.953 .847 .7 r
.31163 .33636 m .30422 .33416 L .31644 .31029 L F
.923 .889 .78 r
.29994 .35267 m .30422 .33416 L .31163 .33636 L F
.76 .454 0 r
.72185 .16138 m .73174 .20229 L .73726 .2102 L F
.922 .53 .186 r
.50039 .29035 m .50503 .32693 L .51147 .32564 L F
.50039 .29035 m .49403 .28612 L .50503 .32693 L F
.995 .831 .569 r
.61573 .29618 m .61 .29519 L .62053 .2573 L F
.998 .819 .536 r
.61 .29519 m .6147 .25088 L .62053 .2573 L F
.819 .921 .905 r
.28872 .36204 m .29245 .35049 L .29994 .35267 L F
.28872 .36204 m .28122 .35935 L .29245 .35049 L F
.923 .889 .78 r
.29994 .35267 m .29245 .35049 L .30422 .33416 L F
.903 .616 .116 r
.68707 .04453 m .70347 .16179 L .68914 .04764 L F
.956 .612 .251 r
.45793 .20956 m .46113 .27077 L .46787 .2729 L F
.45793 .20956 m .45148 .19939 L .46113 .27077 L F
.985 .903 .605 r
.61054 .3219 m .60486 .32375 L .61573 .29618 L F
.907 .951 .607 r
.59943 .34015 m .60486 .32375 L .61054 .3219 L F
.879 .446 .151 r
.52408 .32572 m .52923 .35305 L .53549 .34908 L F
.52408 .32572 m .51782 .32528 L .52923 .35305 L F
.903 .616 .116 r
.68707 .04453 m .69768 .1535 L .70347 .16179 L F
.68483 .03874 m .69768 .1535 L .68707 .04453 L F
.987 .889 .56 r
.60486 .32375 m .61 .29519 L .61573 .29618 L F
.907 .951 .607 r
.59943 .34015 m .59371 .34439 L .60486 .32375 L F
.608 .882 .562 r
.58813 .35159 m .59371 .34439 L .59943 .34015 L F
.998 .819 .536 r
.61 .29519 m .60423 .29522 L .6147 .25088 L F
.999 .807 .506 r
.60423 .29522 m .60882 .24459 L .6147 .25088 L F
.932 .551 .221 r
.49403 .28612 m .4985 .32926 L .50503 .32693 L F
.49403 .28612 m .4876 .28222 L .4985 .32926 L F
.797 .325 .109 r
.54167 .34639 m .54711 .36658 L .55322 .36052 L F
.54167 .34639 m .53549 .34908 L .54711 .36658 L F
.912 .626 .133 r
.68211 .03466 m .69768 .1535 L .68483 .03874 L F
.583 .059 0 r
.55926 .35606 m .56486 .36691 L .57081 .36048 L F
.55926 .35606 m .55322 .36052 L .56486 .36691 L F
.912 .626 .133 r
.68211 .03466 m .69184 .14513 L .69768 .1535 L F
.68024 .02986 m .69184 .14513 L .68211 .03466 L F
.894 .48 .199 r
.51782 .32528 m .52288 .35849 L .52923 .35305 L F
.51782 .32528 m .51147 .32564 L .52288 .35849 L F
.987 .889 .56 r
.60486 .32375 m .59913 .32707 L .61 .29519 L F
.892 .926 .541 r
.59371 .34439 m .59913 .32707 L .60486 .32375 L F
.999 .807 .506 r
.60423 .29522 m .59842 .29643 L .60882 .24459 L F
.999 .796 .48 r
.59842 .29643 m .60289 .23847 L .60882 .24459 L F
.986 .873 .517 r
.59913 .32707 m .60423 .29522 L .61 .29519 L F
.939 .569 .249 r
.4876 .28222 m .49187 .33278 L .4985 .32926 L F
.4876 .28222 m .4811 .27868 L .49187 .33278 L F
.919 .634 .148 r
.67699 .02498 m .69184 .14513 L .68024 .02986 L F
.153 0 0 r
.57081 .36048 m .56486 .36691 L .57647 .36382 L F
.892 .926 .541 r
.59371 .34439 m .58793 .35044 L .59913 .32707 L F
.919 .634 .148 r
.67699 .02498 m .68596 .1367 L .69184 .14513 L F
.67541 .02099 m .68596 .1367 L .67699 .02498 L F
.823 .377 .175 r
.53549 .34908 m .5409 .3745 L .54711 .36658 L F
.53549 .34908 m .52923 .35305 L .5409 .3745 L F
.999 .796 .48 r
.59842 .29643 m .59255 .29903 L .60289 .23847 L F
.999 .785 .456 r
.59255 .29903 m .59692 .23254 L .60289 .23847 L F
.646 .156 .075 r
.55322 .36052 m .55883 .37533 L .56486 .36691 L F
.55322 .36052 m .54711 .36658 L .55883 .37533 L F
.905 .506 .238 r
.51147 .32564 m .51642 .36559 L .52288 .35849 L F
.51147 .32564 m .50503 .32693 L .51642 .36559 L F
.944 .583 .273 r
.4811 .27868 m .48512 .33765 L .49187 .33278 L F
.4811 .27868 m .47452 .27555 L .48512 .33765 L F
.986 .873 .517 r
.59913 .32707 m .59335 .33209 L .60423 .29522 L F
.983 .856 .477 r
.59335 .33209 m .59842 .29643 L .60423 .29522 L F
.871 .896 .475 r
.58793 .35044 m .59335 .33209 L .59913 .32707 L F
.999 .785 .456 r
.59255 .29903 m .58663 .30324 L .59692 .23254 L F
.997 .775 .435 r
.58663 .30324 m .5909 .22684 L .59692 .23254 L F
.268 0 0 r
.56486 .36691 m .57054 .37305 L .57647 .36382 L F
.56486 .36691 m .55883 .37533 L .57054 .37305 L F
.842 .418 .226 r
.53714 .38047 m .52923 .35305 L .5337 .37934 L F
.53714 .38047 m .5409 .3745 L .52923 .35305 L F
.5337 .37934 m .52923 .35305 L .52288 .35849 L F
.948 .595 .294 r
.47452 .27555 m .47823 .34406 L .48512 .33765 L F
.47452 .27555 m .46787 .2729 L .47823 .34406 L F
.913 .528 .27 r
.51303 .37024 m .50503 .32693 L .50919 .36817 L F
.51303 .37024 m .51642 .36559 L .50503 .32693 L F
.50919 .36817 m .50503 .32693 L .4985 .32926 L F
.69 .231 .157 r
.55445 .38301 m .54711 .36658 L .55178 .3828 L F
.55445 .38301 m .55883 .37533 L .54711 .36658 L F
.55178 .3828 m .54711 .36658 L .5409 .3745 L F
.983 .856 .477 r
.59335 .33209 m .58752 .3391 L .59842 .29643 L F
.978 .839 .44 r
.58752 .3391 m .59255 .29903 L .59842 .29643 L F
.997 .775 .435 r
.58663 .30324 m .58065 .30932 L .5909 .22684 L F
.996 .766 .417 r
.58065 .30932 m .58483 .22141 L .5909 .22684 L F
.846 .862 .411 r
.58209 .35858 m .58752 .3391 L .59335 .33209 L F
.951 .605 .311 r
.47643 .34615 m .46787 .2729 L .47077 .34196 L F
.47643 .34615 m .47823 .34406 L .46787 .2729 L F
.47077 .34196 m .46787 .2729 L .46113 .27077 L F
.996 .766 .417 r
.58065 .30932 m .5746 .31758 L .58483 .22141 L F
.994 .758 .402 r
.5746 .31758 m .57871 .2163 L .58483 .22141 L F
.357 0 .047 r
.56698 .38002 m .55883 .37533 L .56238 .38124 L F
.56698 .38002 m .57054 .37305 L .55883 .37533 L F
.56238 .38124 m .55883 .37533 L .55445 .38301 L F
.842 .418 .226 r
.5337 .37934 m .52288 .35849 L .53184 .37843 L F
.855 .449 .267 r
.53184 .37843 m .52288 .35849 L .5253 .37619 L F
.5253 .37619 m .52288 .35849 L .51642 .36559 L F
.913 .528 .27 r
.50919 .36817 m .4985 .32926 L .50801 .36729 L F
.918 .545 .296 r
.50801 .36729 m .4985 .32926 L .50131 .36362 L F
.50131 .36362 m .4985 .32926 L .49187 .33278 L F
.978 .839 .44 r
.58752 .3391 m .58163 .34842 L .59255 .29903 L F
.972 .823 .407 r
.58163 .34842 m .58663 .30324 L .59255 .29903 L F
0 0 0 r
.57226 .37444 m .57054 .37305 L .56698 .38002 L F
.69 .231 .157 r
.55178 .3828 m .5409 .3745 L .54881 .38223 L F
.722 .288 .219 r
.54881 .38223 m .5409 .3745 L .54249 .38161 L F
.54249 .38161 m .5409 .3745 L .53714 .38047 L F
.951 .605 .311 r
.47077 .34196 m .46113 .27077 L .46982 .34104 L F
.994 .758 .402 r
.56858 .32713 m .57871 .2163 L .5746 .31758 L F
.992 .751 .388 r
.56852 .32704 m .57871 .2163 L .56858 .32713 L F
.56852 .32704 m .57253 .21157 L .57871 .2163 L F
.818 .826 .349 r
.57619 .36916 m .58163 .34842 L .58752 .3391 L F
.918 .545 .296 r
.50131 .36362 m .49187 .33278 L .49786 .36103 L F
.923 .559 .317 r
.49786 .36103 m .49187 .33278 L .49356 .35865 L F
.49356 .35865 m .49187 .33278 L .48512 .33765 L F
.855 .449 .267 r
.5253 .37619 m .51642 .36559 L .51923 .37312 L F
.865 .475 .299 r
.51923 .37312 m .51642 .36559 L .51717 .37239 L F
.51717 .37239 m .51642 .36559 L .51303 .37024 L F
.992 .751 .388 r
.5641 .31865 m .57253 .21157 L .56852 .32704 L F
.991 .744 .377 r
.563 .31722 m .57253 .21157 L .5641 .31865 L F
.563 .31722 m .5663 .20728 L .57253 .21157 L F
.972 .823 .407 r
.57695 .35374 m .58663 .30324 L .58163 .34842 L F
.966 .808 .378 r
.57645 .35239 m .58663 .30324 L .57695 .35374 L F
.57645 .35239 m .58065 .30932 L .58663 .30324 L F
.818 .826 .349 r
.5766 .36348 m .58163 .34842 L .57619 .36916 L F
.972 .823 .407 r
.57695 .35374 m .58163 .34842 L .57758 .3566 L F
.853 .846 .383 r
.57758 .3566 m .58163 .34842 L .5766 .36348 L F
.991 .744 .377 r
.55928 .3102 m .5663 .20728 L .563 .31722 L F
.923 .559 .317 r
.49356 .35865 m .48512 .33765 L .48816 .35456 L F
.926 .571 .335 r
.48816 .35456 m .48512 .33765 L .48593 .35331 L F
.48593 .35331 m .48512 .33765 L .47823 .34406 L F
.966 .808 .378 r
.57475 .34476 m .58065 .30932 L .57645 .35239 L F
.96 .794 .352 r
.57273 .33934 m .58065 .30932 L .57475 .34476 L F
.57273 .33934 m .5746 .31758 L .58065 .30932 L F
.926 .571 .335 r
.48593 .35331 m .47823 .34406 L .47882 .34789 L F
.929 .581 .35 r
.47882 .34789 m .47823 .34406 L .47838 .34764 L F
.47838 .34764 m .47823 .34406 L .47643 .34615 L F
.96 .794 .352 r
.57195 .3359 m .5746 .31758 L .57273 .33934 L F
.994 .758 .402 r
.56858 .32713 m .5746 .31758 L .56887 .32768 L F
.991 .795 .413 r
.56887 .32768 m .5746 .31758 L .57195 .3359 L F
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14467 .21304 m
.1493 .21769 L
s
gsave
.13542 .20373 -77.9542 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -70.3694 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.55745 .05141 m
.56132 .05671 L
s
gsave
.54972 .04081 -69.7574 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.19287 .19417 m
.1956 .197 L
s
.24198 .17493 m
.24466 .17782 L
s
.29204 .15533 m
.29467 .15827 L
s
.39509 .11498 m
.3976 .11801 L
s
.44814 .09421 m
.45059 .09729 L
s
.50225 .07302 m
.50464 .07615 L
s
.09737 .23156 m
.10019 .23431 L
s
.05093 .24975 m
.05379 .25245 L
s
.61378 .02935 m
.61603 .03258 L
s
.67126 .00684 m
.67344 .01012 L
s
gsave
.29165 .07573 -69.9038 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.562 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{554.188, 214},
  ImageMargins->{{46, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008Z0000eR000`400?l00000o`00003oo`3ooooo
0?ooob`0oooo003o0?ooool0oooo;03oool00?l0ooooo`3oool/0?ooo`00o`3ooooo0?ooob`0oooo
003o0?ooool0oooo;03oool00?l0ooooo`3oool/0?ooo`00o`3ooooo0?ooob`0oooo003o0?ooool0
oooo;03oool00?l0ooooo`3oool/0?ooo`00o`3ooooo0?ooob`0oooo003o0?ooool0oooo;03oool0
0?l0ooooo`3oool/0?ooo`00o`3ooooo0?ooob`0oooo003o0?ooool0oooo;03oool00;h0oooo0P00
003o0?oooa<0oooo0P00001F0?ooo`00_03oool2000000030?ooo`00000000000?l0oooo403oool2
000000030?ooo`000000000005D0oooo002I0?ooo`D000006`3oool400000080oooo0P00003[0?oo
o`D00000703oool3000000<0oooo0P00001E0?ooo`00V@3oool00`000000oooo0?ooo`0K0?ooo`80
00001P3oool00`000000oooo0000003Z0?ooo`030000003oool0oooo01`0oooo0P0000060?ooo`<0
0000E03oool009X0oooo00<000000?ooo`3oool05`3oool3000000P0oooo00@000000?ooo`3oool0
0000jP3oool00`000000oooo0?ooo`0H0?ooo`<00000203oool010000000oooo0?ooo`00001C0?oo
o`00V`3oool2000001D0oooo0P00000;0?ooo`040000003oool0oooo00000>/0oooo0P00000E0?oo
o`<000002`3oool010000000oooo0?ooo`00001C0?ooo`00W@3oool00`000000oooo0?ooo`0?0?oo
o`<000003@3oool01@000000oooo0?ooo`3oool000000>`0oooo00<000000?ooo`3oool0403oool2
000000h0oooo00D000000?ooo`3oool0oooo0000001B0?ooo`00WP3oool00`000000oooo0?ooo`0;
0?ooo`<00000403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>X0oooo00<00000
0?ooo`3oool0303oool3000000d0oooo00@0jj8U0?ooo`3oool00000103oool00`000000oooo0?oo
o`1?0?ooo`00VP3oool01@000000oooo0?ooo`3oool0000000/0oooo0P0000030?ooo`030000003o
ool0oooo00h0oooo00D000000?ooo`3oool0oooo0000003X0?ooo`050000003oool0oooo0?ooo`00
0000303oool200000080oooo00<000000?ooo`3oool02`3oool20>^R9@030?ooo`000000oooo00<0
oooo00<000000?ooo`3oool0C`3oool009/0oooo0`0000090?ooo`<000005P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0>H0oooo0`00000:0?ooo`<000004P3oool20>^R9@030?oo
o`000000oooo00@0oooo00<000000?ooo`3oool0CP3oool005h0oooo0P0000000`3oool000000?oo
o`120?ooo`8000006@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:P0oooo0P00
00000`3oool000000?ooo`130?ooo`8000005@3oool20>^R9@030>VP8P3oool0000000D0oooo00<0
00000?ooo`3oool0C@3oool005d0oooo00@000000?ooo`3oool00000@@3oool3000001/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`2W0?ooo`040000003oool0oooo00000480oooo
0`00000G0?ooo`80jj8U00<0jJ0R0?ooo`0000001@3oool00`000000oooo0?ooo`1=0?ooo`00G@3o
ool010000000oooo0?ooo`00000o0?ooo`8000007P3oool00`000000oooo0?ooo`040?ooo`800000
Y`3oool010000000oooo0?ooo`0000100?ooo`8000006P3oool20>^R9@030>VP8P3WWAd0000000H0
oooo00<000000?ooo`3oool0C03oool005h0oooo1000000k0?ooo`<000000P3oool00`000000oooo
0?ooo`0:0?ooo`030>jS:`3oool0oooo00h0oooo00<000000?ooo`3oool0103oool200000:P0oooo
1000000l0?ooo`<0000000<0oooo0000003oool06@3oool20>^R9@030>VP8P3WWAd0000000D0oooo
00<000000?ooo`000000C@3oool00640oooo00<000000?ooo`3oool0=`3oool200000180oooo00<0
kZ<[0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:T0oooo00<0
00000?ooo`3oool0=`3oool3000001l0oooo0P3[XRD00`3YX280iidM000000070?ooo`030000003o
ool0oooo04/0oooo001N0?ooo`<00000=`3oool3000001@0oooo00<0kZ<[0>bQ9P3oool03P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0:D0oooo0`00000h0?ooo`8000002P3oool0
0`3k]V`0oooo0?ooo`0F0?ooo`040>^R9@3YX280iidM000000P0oooo00<000000?ooo`3oool0BP3o
ool009H0oooo0P00000G0?ooo`030>jS:`3/XBH0oooo00h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3L0?ooo`<00000303oool20?^fK1L0oooo00@0jj8U0>VP8P3WWAd000002@3o
ool00`000000oooo0?ooo`190?ooo`00T`3oool3000001T0oooo00<0kZ<[0>bQ9P3ZWB403P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo1@0000390?ooo`8000003`3oool2
0?^fK0030?^gKP3oool0oooo01@0oooo00D0jj8U0>VP8P3WWAd000000=b@2@080?ooo`030000003o
ool0oooo00/0oooo1@00000i0?ooo`00T03oool300000080oooo00<000000?ooo`3oool05`3oool0
103^Xb/0k:4V0>ZM8@3WVQ/=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`380?ooo`<0000000<0oooo0000003oool03P3oool20?^fK0030?^gKP3d
[WP0oooo01@0oooo00D0jj8U0>VP8P3WWAd000000=b@2@090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0>`3oool008h0oooo0P0000090?ooo`030?F`O03oool0oooo01@0oooo00<0
k:4V0>ZM8@3WVQ/03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo1@00
00020?ooo`030000003oool0oooo0<D0oooo0P00000D0?ooo`80nkI/00<0nkM^0?B^N03d[WP0503o
ool01@3[XRD0jJ0R0>VP8P000000001500T0oooo00<000000?ooo`3oool0103oool500000080oooo
00<000000?ooo`3oool0>P3oool008/0oooo0`00000;0?ooo`80mK1l5@3oool00`3/XBH0jYdQ0?oo
o`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool200000<80oooo0`00
000F0?ooo`80nkI/00@0nkM^0?B^N03d[WP0m:mk4`3oool01@3[XRD0jJ0R0>VP8P000000001500X0
oooo00<000000?ooo`3oool02`3oool2000003X0oooo00290?ooo`8000003P3oool20?F`O0030?Ba
OP3oool0oooo0180oooo00<0kZ<[0>bQ9P3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0_03oool3000001T0oooo0P3k]V`00`3k]fh0m:ih
0?B^N0020?B_Na80oooo0P3[XRD00`3YX28000000>2F4@0;0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0=`3oool006L0oooo0`00000L0?ooo`<00000403oool20?F`O080m;5n4`3o
ool0103^Xb/0k:4V0?ooo`0002d=0?ooo`030000003oool0oooo00P0oooo0`00000?0?ooo`030000
003oool0oooo09T0oooo0`00000M0?ooo`800000703oool20?^fK0030?^gKP3d[WP0m:ih0080m:mk
00<0m;1n0?ooo`3oool03`3oool20>^R9@040>VP8P000000i9XH0=J900P0oooo0`00000?0?ooo`03
0000003oool0oooo03H0oooo001V0?ooo`030000003oool0oooo008000006@3oool2000001<0oooo
0P3e/7`20?BaOP80m;:14@3oool0103^Xb/0k:4V0>ZM8@0002d=0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000009X0oooo00<000000?oo
o`3oool00P00000I0?ooo`<000007P3oool20?^fK0030?^gKP3k^740m:ih0080m:mk0P3d/7h@0?oo
o`80jj8U00@0jJ0R0000003TVQP0g9092`3oool00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`000000>03oool006H0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`<000005@3o
ool20?F`O080m;5n0P3d/X4A0?ooo`040>jS:`3/XBH0jYdQ0>NJ6`d0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`090?ooo`<00000V`3oool01@000000oooo0?ooo`3oool0000001L0
oooo0P00000Q0?ooo`80nkI/00<0nkM^0?^hL@3d[WP00P3d[g/20?B`OP80lk623`3oool01@3[XRD0
jJ0R0000003TVQP0eXT000`0oooo00<000000?ooo`3oool0203oool3000003T0oooo001V0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool2000001P0oooo0P3e/7`20?BaOP80
m;:100<0m;>40>ZYR@3oool03P3oool0103^Xb/0k:4V0>ZM8@3WVQ/=0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0140oooo0`00000S0?ooo`80nkI/00<0nkM^0?^hL@3k^7400P3d[g/20?B`OP80lk620P3VYX`=0?oo
o`050>^R9@3YX28000000>BJ60000580303oool00`000000oooo0?ooo`140?ooo`00IP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo0`00000J0?ooo`80mK1l0P3d/Gh20?Bb
P@030?BcQ03ZZHT0jJZ<00h0oooo00@0kZ<[0>bQ9P3ZWB40iiXK3@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`8000009P3oool20?^fK0030?^gKP3k^740nkQa0080m:mk0P3d/7h20?>aPP030?:cQ`3VYX`0
iZJ<00`0oooo00D0jj8U0>VP8P000000i9XH0>2F4@0=0?ooo`030000003oool0oooo04<0oooo001W
0?ooo`050000003oool0oooo0?ooo`0000003P3oool3000001`0oooo0P3e/7`20?BaOP80m;:100@0
m;>40>ZYR@3YZX`0jJZ<3@3oool01@3^Xb/0k:4V0>ZM8@3WVQ/0001500`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2V0?ooo`050000003oool0oooo0?ooo`0000003P3oool30000
02P0oooo0P3k]V`00`3k]fh0nkQa0?^hL@020?B_N`80m;1n0P3c/H800`3b/hL0iZJ<0>JVS0020>FW
T0X0oooo00H0jj8U0>VP8P000000i9XH0>2F4@3LT0T=0?ooo`030000003oool0oooo0480oooo001W
0?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`<000007`3oool20?F`O080m;5n0P3d/X40
103d/h@0jZV90>VZS03YZX`30>R[T0/0oooo0P3/XBH00`002H`000150?ooo`0;0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0YP3oool200000080oooo00<000000?ooo`3oool02P3o
ool2000002/0oooo0P3k]V`01@3k]fh0nkQa0?^hL@3k^G@0m:mk0080m;1n0P3c/H800`3b/hL0iZJ<
0>JVS0020>FWT0030>>XU@3AV9T0oooo00D0oooo0P2FKj@01P3[XRD0jJ0R0000003TVQP0h9HA0=J9
00d0oooo00<000000?ooo`3oool0@P3oool006P0oooo0`0000090?ooo`<000008@3oool30?F`O080
m;5n0P3d/X40103d/h@0jJZ<0>VZS03YZX`30>R[T0030>N/U03HWYP0oooo00L0oooo00D0HU2W0>bQ
9P3/XBH000V<0000A@0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0YP3oool3
000000X0oooo0`00000>0?ooo`030<mn003oool0oooo01`0oooo0P3k]V`01P3k]fh0nkQa0?^hL@3k
^G@0m:mk0?B`OP<0lk620P3b/hL0103VYX`0iJN@0>FWT03SZ9D20=6HV@80ciZN0`2gQj8209I_Y006
0>^R9@3YX280jJ0R0000003PUQ40g9093P3oool00`000000oooo0?ooo`110?ooo`00LP3oool20000
02@0oooo00@0nkUg0?F`O03e/7`0m;5n0`3d/X40103d/h@0lkB80>VZS03YZX`30>R[T0040>N/U03H
WYP0f9jH0=JOW@@0oooo0`2JMZT0103^Xb/0k:4V0>ZM8@3SUA<<0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0[`3oool300000140oooo00<0cgh00?ooo`3oool0703oool20?^fK006
0?^gKP3k^740nkQa0?^iM03d[g/0m;1n0`3c/H820?:cQ`040>JVS03UYi00iJN@0>>XU@80dIRI0P3?
VYh30;N7XP80UW>Y00L0jj8U0>VP8P3YX28000000>2F4@0J7IH0eXT000d0oooo0P0000120?ooo`00
K`3oool3000002H0oooo00@0nkUg0?F`O03e/7`0m;5n0`3d/X40103d/h@0lkB80>VZS03YZX`30>R[
T0030>N/U03HWYP0f9jH0080eYnM0P2oSJ420;f?YP80VWJY00D0kZ<[0>bQ9P3ZWB40iiXK0000A@0;
0?ooo`030000003oool0oooo00h0oooo0P00002^0?ooo`<00000503oool00`3?OP00oooo0?ooo`0K
0?ooo`<0nkI/00@0nkM^0?^hL@3k^740nkUd0P3d/7h30?>aPP80l[>70`3UYi020>>XU@040=6HV@3?
VYh0ciZN0<nJWP80]hNR00<0]HVW09IcZ@3[XRD00P3YX28010000000i9XH0>2F4@3FR@0=0?ooo`80
0000@P3oool006d0oooo0P0000000`3oool000000?ooo`0V0?ooo`80nkUg00@0mK1l0?BaOP3d/X40
m;:10P3d/h@20?>dR0030>VZS03XZi00j:^@0080ijbD00D0f9jH0=JOW@3FWid0eYnM0;n=X@030;f?
YP80VWJY00D0kZ<[0>bQ9P3ZWB40iiXK0000>00;0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0Z@3oool4000001D0oooo00<0cgh00?ooo`3oool06`3oool30?^fK0060?^gKP3k^740
nkQa0?^iM03k^gP0m;1n0`3c/H820?:cQ`030?6dS03UYi00hjRE0080hjRE00D0dIRI0<nJWP3?VYh0
ciZN0;N7XP020;F9Y`0809IcZ@3[XRD0jJ0R0>VP8P000000i9XH0>2F4@3FR@0?0?ooo`030000003o
ool0oooo03l0oooo001Z0?ooo`<00000:`3oool20?^iM`80m;5n0P3d/X420?BcQ080lkB800<0jJZ<
0>R[T03XZi000P3W[9@0103HWYP0eYnM0=JOW@3FWid40;f?YP80VWJY00D0kZ<[0>bQ9P3ZWB4021FE
0000>00;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0YP3oool2000000X0oooo
0P3Y]il=0?ooo`80cgh0703oool20?^fK080nkM^0P3k^7400`3k^G@0nk]h0?B`OP020?>aPP<0l[>7
00<0lKB<0>FWT03SZ9D00P3SZ9D40<nJWP<0]HVW0P2FLjT20>VP8P050000003TVQP0h9HA0=b@2@32
M0003`3oool00`000000oooo0?ooo`0n0?ooo`00J03oool2000002h0oooo0P3k^GL0103k^gX0m;5n
0?BbP@3d/X420?BcQ080lkB80`3XZi020>N/U0@0eYnM00@0e:6Q0;f?YP2mSjH0_HnV0P2JMZT01@3^
Xb/0k:4V0>ZM8@3WVQ/0hiDC00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2S
0?ooo`<00000303oool20>VgW`80g[2V303oool00`3?OP00oooo0?ooo`0J0?ooo`80nkI/0P3k]fh2
0?^hL@030?^iM03k^gP0m;1n0080lk620`3b/hL00`3a]8`0iJN@0>>XU@020>>XU@050>6YV`3?VYh0
ciZN0<nJWP3=Vj@00`2eRJL0202FLjT0jJ0R0>VP8P000000i9XH0>2F4@3LT0T0`W@03`3oool00`00
0000oooo0?ooo`0n0?ooo`00I@3oool3000000P0oooo102GSlPT0?ooo`80nkUg00@0nk]j0?BaOP3d
/X40m;:10P3d/h@20?>dR0030?:fS03XZi00j:^@0080ijbD00D0iJfH0=JOW@3FWid0eYnM0=BQX@03
0;f?YP80VWJY00H0kZ<[0>bQ9P3/XBH0iiXK0>>E4`3GQ`0:0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0X03oool2000000h0oooo0`3Y]il00`3X]j80g[2V0=j`YP0:0?ooo`0304YD
^`3?OP00oooo01/0oooo0P3k]V`20?^gKP050?^hL@3k^G@0nkUd0?^kN03d/7h00P3c/H830?:cQ`03
0?6dS03UYi00hjRE0080hjRE00<0hJVK0<nJWP3?VYh00P3=Vj@30;F9Y`80UW>Y00H0jJ0R0000003T
VQP0h9HA0=b@2@3=P00@0?ooo`030000003oool0oooo03d0oooo001S0?ooo`8000002P3oool20<FY
_P<0Uho800<0:4Rn0?ooo`3oool08@3oool20?^iM`040?^kNP3d/Gh0m;:10?BbP@80m;>40P3c]8P0
0`3b]X`0j:^@0>N/U0020>N/U0030>F]V03FWid0eYnM0080e:6Q0`2mSjH209Ui[@060>jS:`3/XBH0
k:4V00PEU@3SUA<0ehL02`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo09`0oooo
0`00000@0?ooo`<0jKNO0P3X]j800`3N/:H0gK2Y0=f`Z@080?ooo`0304ME_@3^UbD0oooo01/0oooo
0P3k]V`00`3k]fh0nkQa0?^hL@020?^iM0040?^kN03c/H80lk620?>aPP80l[>70P3a]8`30>>XU@80
hJVK0P3?VYh20<fKY0<0]HVW0P2FLjT00`1YEJP000000>BJ60020>2F4@030000L@3oool0oooo00l0
oooo00<000000?ooo`3oool0?03oool00600oooo0`0000000`3oool000000?ooo`080?ooo`@0aJVn
0P2GSlP202Q8_R80oooo0P3k^GL01@3k^gX0m;:10?BbP@3d/X40m;>400<0lkB800<0l[J<0>R[T03W
[9@00P3W[9@20>F]V0030=JOW@3DXJ40e:6Q0080_HnV0P2kT:X209Ui[@80k:4V00<0jYdQ0>>E4`08
5ID02`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo09X0oooo0P0000000`3oool0
00000?ooo`0@0?ooo`80jKNO0`3X]j830=f`Z@80fk6]1P3oool00`17EKd0kYLU0<Ug000K0?ooo`80
nkI/00<0nkM^0?^hL@3k^7400P3k^G@0103k^gP0nkel0?>aPP3c/H820?:cQ`80lKB<00<0l;JA0>>X
U@3SZ9D00P3QZI/0103?VYh0cI^T0<fKY03=Vj@20;F9Y`80/hb/0P2FMjh01@000000i9XH0>2F4@3P
UQ40eXT00140oooo00<000000?ooo`3oool0?03oool005h0oooo0P00000>0?ooo`040=Ve]035ZKh0
aJVn0<FY_P80Uho80P0XB;h00`0006X0oooo0?ooo`0O0?ooo`80nkUg00D0nk]j0?^lO@3d/X40m;:1
0?BcQ0030?>dR0030?:fS03XZi00ijbD0080ijbD0P3U[IP0103FWid0e:6Q0=BQX@2mSjH30;^@ZP80
VGV]0P3/XBH0103ZWB40hiDC00PEU@0006@:0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0UP3oool3000001@0oooo0`3Y]il30>RgXP030>NhY@3M/:T0fk6]0080fk6]0P35Y;T0103o
ool0W8_109b;`@2LRl4204ME_@030>jG9@3oool0oooo01T0oooo0P3k]V`00`3k]fh0nkQa0?^hL@02
0?^iM0040?^kN03k_G`0lk620?>aPP80l[>70P3a]8`00`3`]Y40hjRE0>>XU@020>6YV`@0cI^T00@0
]HVW0;><[02cS:`0/hb/0P2FMjh01P000000KUb^0>2F4@3PUQ40g9090<f00140oooo00<000000?oo
o`3oool0>`3oool005/0oooo0`00000?0?ooo`80fKFd0P35ZKh20<6Y`@80THg;0P0TAklQ0?ooo`80
nkUg00D0nk]j0?^lO@3d/X40m;:10?BcQ0020?>dR080l[J<0`3W[9@30>F]V0<0e:6Q102kT:X209Ui
[@060?NUB@3/XBH0jYdQ0>NJ6`3SUA<0001D2P3oool00`000000oooo0?ooo`0C0?ooo`800000U03o
ool3000001L0oooo00<0kkfM0>VgW`3X]j800`3X]j800`3W^:D0gK2Y0=^a[@020=^a[@040=Va/035
Y;T0aJBi0<FT^@80W8_10P17EKd00`3^UbD0`Vl00?ooo`0I0?ooo`80nkI/00<0nkM^0?^hL@3k^740
0P3k^G@0103k^gP0nkel0?^mO03c/H820?:cQ`80lKB<00<0l;JA0>>XU@3QZI/00P3QZI/0103NZj40
cI^T0<fKY03=Vj@40;><[080UWN^00H0000006iL[P3PUQ40h9HA0=b@2@0008<@0?ooo`<00000?03o
ool003L0oooo1@00000L0?ooo`<000004P3oool20=Ve]0@0`JW10`2ASL/202A7_b00oooo0P3k^GL0
1@3k^gX0nkam0?^lO@3d/X40m;>40080lkB80P3b]X`00`3a]i00ijbD0>N/U0030>F]V0040>B^W@3D
XJ40e:6Q0=6RYP<0^i2Z0P2INJd01P3gYDT0mjA60>ZM8@3WVQ/0hiDC0=j?2PX0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`1^0?ooo`D00000703oool3000001X0oooo00<0kkfM0>Vg
W`3X]j800P3X]j820>NhY@@0fk6]00<0fK6`0<FT^@35Y;T00P31Y;`209R;a00304EG`03^UbD0`Vl0
01X0oooo0P3k]V`00`3k]fh0nkQa0?^hL@020?^iM0030?^kN03k_G`0nkel0080l[>70`3a]8`00`3`
]Y40hjRE0>6YV`020>6YV`050=j[X@3=Vj@0cI^T0<fKY03:WJT00`2cS:`209Ig[P070000001^G:h0
KUb^0>2F4@3LT0T0cH000;9S000A0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003o
ool0oooo01`0oooo1000000B0?ooo`<0fKFd00@0e[Fh0<6Y`@31ZL40`JW10`2ASL/202A7_b00oooo
00<0nkUg0?^kNP3k^gX00P3k_7d20?BcQ080lkB80P3b]X`00`3a]i00ijbD0>N/U0030>F]V0040>B^
W@3DXJ40e:6Q0=6RYP<0^i2Z0P2INJd01`3gYDT0mjA60>ZM8@3WVQ/0hiDC0=j?2P0006@02@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0703oool4
000001X0oooo0P3__Id40>RgXP80ikRU00<0iKVX0=^a[@3K/Jd00P3I/K001035Y;T0`JBl0<6T_031
Y;`309R;a0030>jG9@3[TQh0`Vl001T0oooo0P3k]V`00`3k]fh0nkQa0?^hL@020?^iM0050?^kN03k
_G`0nkel0?^oP@3b/hL00`3a]8`00`3`]Y40hJVK0>6YV`020>6YV`050=j[X@3=Vj@0cI^T0<fKY03:
WJT00`2cS:`209Ig[P070000001^G:h0KUb^03@iZ03LT0T0eXT00<9d000B0?ooo`030000003oool0
oooo03T0oooo000a0?ooo`D000000P3oool00`000000oooo0?ooo`0H0?ooo`<000005@3oool30=Ve
]0<0e[Fh00<0`JW10;fXa@2mZ<D00`2<S<h00`0TAkl0dGD00?ooo`0M0?ooo`80nkUg0P3k^gX20?^l
O@040?ZmP03d/h@0lkB80?>dR080l[J<0P3a]i000`3W[9@0iJfH0>F]V0020>B^W@040=BQX@3AXZH0
dJ:V0=6RYP80^i2Z00<0^9:_09Ql/P3gYDT00P3gY4H0103WVQ/0hiDC0=j?2P3?O0090?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0IP3oool500000080oooo00<000000?ooo`3oool0
6@3oool2000001h0oooo0P3__Id00`3^_Il0j;NR0>RgXP020>NhY@<0iKVX00<0fk6]0=Va/03I/K00
1031Y;`309R;a00304EG`03[TQh0ihdF01T0oooo0P3k]V`0103k]fh0nkQa0?^hL@3k^G@20?^kN080
nkel00@0nkn10?:cQ`3a]8`0lKB<0P3`]Y400`3^^9L0hJVK0>6YV`030=j[X@040<fKY03:WJT0bYfY
0<ZMZ@80/hb/0P2FO;<00`000000UWbc07=U]00203@iZ0030=J90032M000oooo0180oooo00<00000
0?ooo`3oool0>03oool003T0oooo0P00000F0?ooo`800000603oool00`3S^jl0fKFd0=Ve]0030=Je
^0@0_JS50P2<S<h00`0PAl00dGD00?ooo`0M0?ooo`80nkUg0P3k^gX20?^lO@040?ZmP03d/h@0lkB8
0?>dR080l[J<0P3a]i030>F]V080i:jM00D0e:6Q0=6RYP3AXZH0dJ:V0;^@ZP020;RB[`0809Ql/P3g
YDT0mjA60?NTAP3WVQ/0hiDC01@RWP3?O0090?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0KP3oool2000001H0oooo0`00000P0?ooo`80kkfM0P3^_Il00`3X]j80ikRU0>NhY@030>Fi
Z0<0fK6`00@0e[:d0<6T_031Y;`0`JBl102DRlL00`3^UbD0ihdF0?ooo`0H0?ooo`80nkI/00@0nkM^
0?^hL@3k^G@0nkUd0P3k^gP20?^mO0040?^oP@3b/hL0lKB<0?6dS080l;JA00<0k[RG0>6YV`3QZI/0
0`3NZj401@3=Vj@0bYfY0<ZMZ@3:WJT0/hb/0080/Xnb00<0UWbc0000002FO;<00P1cIK@0100d>JP0
eXT00<f0002bH`0B0?ooo`030000003oool0oooo03P0oooo000k0?ooo`030000003oool0oooo0100
oooo0`00000J0?ooo`80hk^_103F]KP0103D]K/0_JS50;fXa@2mZ<D208b<cP8084O000<0dGD00?oo
o`3oool06`3oool20?^iM`80nk]j0P3k_7d00`3j_H00m;>40?>dR0030?:fS080lKN@00<0l;VD0>F]
V03U[IP00P3T[Yd40=6RYP<0^9:_00D0V7bb0?NUB@3gY4H0mjA60?JR@`020>>E4`030=N7003?O000
oooo00L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo0140oooo0P00000R0?ooo`<0kkfM0P3^_Il20>NhY@@0iKVX00<0i;V[0=Va/03F/[@00P3F/[@0
0`31Y;`0_JBo0;fT_`0309B;a`030>jG9@3[TQh0ihdF01P0oooo0P3k]V`0103k]fh0nkQa0?^iM03k
^G@20?^kN080nkel00@0nkn10?6dS03a]8`0lKB<0P3`]Y420>jhU`040>6YV`3NZj40gZ^Q0=j[X@@0
bYfY0`2bSk800`2FO;<0000009Il/`0207=U]0040498/P0d>JP0cH000<9d01<0oooo00<000000?oo
o`3oool0=`3oool003`0oooo00<000000?ooo`3oool03@3oool2000001`0oooo0`3S^jl00`3Q_;80
e[Fh0=Je^0020=Be^`80_JS50P2hYlP208F:d0030217`03AM@00oooo01`0oooo0P3k^GL20?^kNP80
nkam00<0n[f00?>dR03c]8P00P3b]X`30?6gT0030?2iU03U[IP0i:jM0080i:jM00D0h[2R0=6RYP3A
XZH0dJ:V0<nSZ`030;RB[`040?NUB@3gY4H0mjA60?JR@`80hiDC00<0gXl:0<ml003oool01`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool03@3oool3
000002@0oooo0P3__Id30>jmW`030>fnXP3W^:D0iKVX0080iKVX0P3T^J/0103I/K00e[:d0=Jb]03F
/[@40;fT_`80U8_700<0kYLU0>^B7P3WSAH0603oool20?^fK0050?^gKP3k^740nkUd0?^iM03k^gP0
0`3k_G`0103k_h40n/660?6dS03a]8`20?2fT@80k[RG103NZj401@3L[JL0bYfY0<ZMZ@3:WJT0ain_
00<0/Xnb00<0000009Il/`1cIK@00P1cIK@01012B;80cH000<9d002bH`0C0?ooo`030000003oool0
oooo03H0oooo000h0?ooo`050000003oool0oooo0?ooo`000000303oool3000000030?ooo`000000
oooo01/0oooo0P3S^jl20>6l/P040=Je^03D]K/0e;Fk0=Be^`@0^:O80P25R]000`0LAl40dGD00?oo
o`0L0?ooo`80nkUg0P3k^gX20?^lO@030?ZmP03j_h@0lkB80080l[J<0`3a]i000`3`^I@0iJfH0>B^
W@020>B^W@030>:`XP3AXZH0dJ:V0080cj>[0`2hTZl0103gYDT0mjA60?NTAP3fXT<20>>E4`030=j?
2P3?O000oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`@00000
D03oool01@000000oooo0?ooo`3oool0000000`0oooo0`0000000`3oool000000?ooo`0T0?ooo`80
kkfM0`3^_Il00`3]_Z80iKVX0>FiZ0020>FiZ080i;V[103F/[@0103D/[L0_JBo0;fT_`2mY;l209B;
a`040>jG9@3[TQh0ihdF0:MA01L0oooo0P3k]V`01@3k]fh0nkQa0?^iM03k^G@0nk]h00<0nkel00D0
nkn10?[1QP3j`HH0lKB<0?2fT@030>jhU`030>bjW@3NZj40gZ^Q0080g:fW0P3:WJT20<NO[`<0/Xnb
00<0000009Il/`1cIK@00P1cIK@20498/P030<9d000004T0oooo0180oooo00<000000?ooo`3oool0
5P3oool4000001`0oooo000i0?ooo`<000002`3oool200000200oooo0`3S^jl20>6l/P@0e;Fk00@0
dKFn0;RWb02hYlP0^:O80P25R]000`0LAl40dGD00=5e000L0?ooo`80nkUg0P3k^gX01@3k_7d0n[f0
0?ZmP03j_h@0lkB80080l[J<0P3a]i020?2iU0@0i:jM00<0h[2R0=6RYP3AXZH00P3?Xj/30;RB[`07
0?NUB@3gY4H0mjA60?JR@`3eX3l0hiDC0=j?2P020<ml00L0oooo00<000000?ooo`3oool0603oool2
000001T0oooo00<000000?ooo`3oool0D@3oool3000000/0oooo0P00000Y0?ooo`<0kkfM0P3^_Il2
0>fnXP030>boY@3U^JP0iKVX00<0i;V[00<0h[Z^0=Jb]03F/[@00P3D/[L20;fT_`80^ZC30P2@RlX0
0`3[TQh0ihdF0;5L000G0?ooo`80nkI/00D0nkM^0?^hL@3k^G@0nkUd0?^kN0030?^mO0030?^oP@3j
`HH0n/660080l;JA0`3^^9L00`3/^Yd0gZ^Q0=j[X@020=b]Y`040<ZMZ@37Wjl0ain_0<NO[`<0/Xnb
00<0000009Il/`1cIK@00P1cIK@20498/P80`W@04P3oool3000001P0oooo00<000000?ooo`3oool0
703oool004@0oooo0`00000R0?ooo`030>S1[03S^jl0hKbb0080hKbb00<0gkbe0=Be^`3D]K/00`3A
]Kh0102hYlP0]:O<0;BWc01oR=8201a7`@030=5e003oool0oooo01X0oooo0P3k^GL00`3k^gX0nkam
0?^lO@020?ZmP0040?ZoQ03b]X`0l[J<0?:fS080lKN@0P3`^I@00`3_^YX0i:jM0>B^W@020>:`XP04
0=6RYP3?Xj/0cj>[0<nSZ`80^9:_00X0]YBd0?NUB@3gY4H0mjA60?JR@`3eX3l0m9dk0=j?2P3GQ`00
cg`01`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0F`3oool3000002/0oooo00<0l/:M0>nmW@3__Id00P3^_Il20>fnXP80k;nU00<0iKVX0>BiZ`3T
^J/00P3R^Zh0103F/[@0e;:g0=Bb]`3D/[L40;ZT``80T8_:0P3[TQh00`3SQ`d0Ye400?ooo`0D0?oo
o`<0nkI/00D0nkM^0?^hL@3k^G@0nkUd0?^kN0020?^mO080nkn10P3j`HH0103j`hd0l;JA0>jhU`3^
^9L20>bjW@040=j[X@3L[JL0g:fW0=b]Y`@0ain_0P2bSk820;2B^0030000002GPKT0N6jk0080N6jk
00@0D5Nk0498/P32M000/V<0503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01/0
oooo00110?ooo`<00000903oool20>S1[0<0hKbb0`3O_;D40=6e_P@0]:O<00@0OhSB01U6`P3ZSA`0
aVL06`3oool00`3k^GL0nk]j0?^kNP020?^lO@80n[f000@0n[n40?[1R03b]X`0l[J<0P3a]i020?2i
U0030>njVP3T[Yd0i:jM0080h[2R103?Xj/30;JD]080mjE900<0mjA60?JR@`3eX3l00P3dWC/00`3G
Q`00cg`00?ooo`060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`1H0?ooo`800000;P3oool20?;2W@80k[fO0`3]_Z820>boY@<0i;V[0P3R^Zh40=Bb
]`040=6b^`2jY<<0^ZC30;ZT``80T8_:00@0m9a00>^B7P3WSAH0gX025@3oool20?fnH080nkM^00@0
nkQa0?^iM03k^G@0nk]h0P3k_G`20?^oP@80n/6600@0n/>=0?2fT@3^^9L0k[RG0P3/^Yd40=b]Y`04
0=V_[P37Wjl0ain_0<NO[`@0/9:h00<0000009N1^@1hK[/00P1hK[/2051G^`03000QYP2bH`00oooo
01<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`00?`3oool300000003
0?ooo`000000oooo02<0oooo0P3X`J`00`3W`Jl0hKbb0>6l/P030=nl]@030=fm^03A]Kh0dKFn0080
c[G20`2dYl`207n8dP030>Z=7036I`00oooo01X0oooo00<0nkUg0?^kNP3k^gX00P3k_7d00`3j_H00
n[n40?ZoQ0020?[1R0030?:fS03a]i00lKN@0080l;VD0P3_^YX0103T[Yd0h[2R0>:`XP3O/JL30<nS
Z`030<bU/02fU;@0]YBd0080mjE900<0mjA60?JR@`3eX3l00P3dWC/00`3GQ`00cg`00?ooo`070?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1D0?oo
o`<0000000<0oooo0000003oool0;03oool30?;2W@040?73X03^_Il0kKjR0>fnXP<0k;nU00<0jl2X
0>BiZ`3R^Zh00P3R^Zh00`3Q^k40e;:g0=Bb]`030=6b^`80^ZC30P2;R/d0103dW400liTj0>N=5P3N
P08E0?ooo`80oKiP00<0oL1S0?^hL@3k^7400P3k^G@00`3k^gP0nkel0?^mO0020?^oP@80n/6600@0
n/>=0>jhU`3^^9L0k[RG0P3/^Yd01@3Z_:D0g:fW0=b]Y`3L[JL0fJn^0080ain_0P34X[H30;2B^003
0000002GPKT0Uh6i0080N6jk0`1@Ek/00`008JH0oooo0?ooo`0C0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool06@3oool003d0oooo0P00000X0?ooo`80j<6/0`3W`Jl30=nl]@80gKfh
00@0dKFn0<je`P3>]L80c[G20P2dYl`20:nVc`0407R6e03ZSA`0jXdL0<IW01X0oooo00<0nkUg0?^k
NP3k^gX00P3k_7d00`3j_H00n[n40?ZoQ0020?[1R080lKN@0`3`^I@20>njVP<0h[2R00<0gk6W0<nS
Z`3?Xj/00P3<YK020;JD]080mjE90P3gY4H0103eX3l0m9dk0?BM>`3bVS@20<ml00L0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`<00000303oool4000005@0oooo0P00000b
0?ooo`<0l/:M00@0lL>P0>fnXP3]_Z80kKjR0P3/_jD20>_0Z0@0h[Z^0P3Q^k440=6b^`<0]ZC600@0
Rh[=0?BL@03cVCX0ihdF0P3NP08D0?ooo`80oKiP00<0oL1S0?k2IP3k^G@00P3k^G@0103k^gP0nkel
0?^mO03k_h420?[1QP80n/>=00<0n<JD0>jhU`3/^Yd00P3/^Yd00`3Z_:D0g:fW0=b]Y`020=V_[P04
0<NO[`34X[H0a::f0<BR]P<0/9:h00<0000009N1^@2GPKT00P1hK[/3051G^`0301Pk]P008JH0oooo
01<0oooo00<000000?ooo`3oool01@3oool3000000`0oooo1000000K0?ooo`00>P3oool3000002X0
oooo0P3X`J`30>O1[`030>K2/@3O_;D0gKfh0080gKfh103>]L840:nVc`80N8KD00<0jXdL0<IW003o
ool06@3oool00`3k^GL0nk]j0?^kNP020?^lO@030?ZmP03j_h@0n[n40080n/6800@0nL:=0?6gT03`
^I@0l;VD0`3_^YX00`3]_9l0h[2R0=naY`020=naY`040<nSZ`3<YK00c:F`0<bU/080]YBd00@0mjE9
0?NTAP3gY4H0mJ0o0P3dWC/00`3bVS@0cg`00<ml00070?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0200000600oooo0`00000d0?ooo`80l/:M0P3a
`j000`3aa:80kKjR0>fnXP020>boY@80jl2X00<0jL2[0>:j[P3R^Zh00`3Q^k400`3N^kD0dK:k0=6b
^`020<jb_`<0]ZC600D0m9a00?>I>P3cVCX0hhL=0=j00P0D0?ooo`80oKiP00@0oL1S0?k2IP3na6X0
o/AZ0P3k^gP20?^mO0030?^oP@3j`HH0n/660080n/>=00<0n<JD0>jhU`3/^Yd00P3/^Yd20>ZlY@03
0=b]Y`3I[jh0fJn^00@0a::f0`2`T[P01@000000V8No09R7_`2HQkl0OWO100<0D5Nk0P0H>kH00`00
06H0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P00000Z0?oo
o`00=`3oool3000002`0oooo0P3X`J`30>O1[`80i/:a103M_KP00`3K_K/0c[G20<je`P020<Zea@<0
[jK?0P1hQ]@00`3ZSA`0aVL00?ooo`0I0?ooo`040?^iM`3k^gX0nk]j0?^lO@80n[f00P3j_h@20?[1
R0040?W2S@3a]i00l;VD0?2iU0<0kkZJ00<0kKbO0>:`XP3O/JL00P3O/JL40<bU/0030;JD]02dU[T0
mjE90080mjA600L0mZ930?FP?`3dWC/0lYXd0?2E;@3?O000/eh000H0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000GP3oool2000003H0
oooo0`3b`Yd20?73X080lLBR0P3/_jD30>_0Z080jL2[00<0h[Z^0>6k/@3Q^k400P3N^kD0103A/[/0
c[:o0<jb_`3>/[l30;JTaP060?BL@03cVCX0liTj0>>73@3NP080001O4`3oool20?fnH0060?g0H`3n
`VH0o/AZ0?k4JP3oaVl0nk]h0P3k_G`00`3k_h40n/660?[1QP020?[3S@040?S6U03/^Yd0k;ZM0>bj
W@<0j[bU0`3I[jh0103E/K@0a::f0<BR]P34X[H30:jF_@040000002HQkl0V8No09R7_`80OWO10P1M
I/@301Pk]P030000IP3oool0oooo0180oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000002X0oooo000e0?ooo`<00000;P3oool00`3/aJ`0j<6/0>O1[`020>O1[`80i/:a00<0
iL:d0=fm^03M_KP00`3K_K/40<Zea@<0ZJCB00@0LXCF0>Z=703WR1D0aVL06@3oool0103k^GL0nk]j
0?^kNP3k_7d20?ZmP080n[n40P3j`HP0103i`Xd0l;VD0?2iU03`^I@20>njVP80kKbO00D0h[2R0=na
Y`3O/JL0gk6W0=bb[@030<bU/080]9Ji00X0mjE90?NTAP3gY4H0mZ930?FP?`3dWC/0lYXd0?2E;@3/
Sb<0`fl01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1H0?ooo`<00000>03oool30?;2W@060?73X03aa:80lLBR
0?74XP3`a:D0k;nU0P3[`:P30>W0Z`<0hK^a0P3N^kD40<jb_`<0/J?:00@0m9a00?>I>P3cVCX0lIHd
0P3NP08C0?ooo`80oKiP00D0oL1S0?k2IP3na6X0o/AZ0?o6K`030?^mO0030?^oP@3j`HH0n/660080
n/>=00@0n<JD0?O8V`3/^Yd0k;ZM0`3Z_:D0103V_Z`0fJn^0=Fa]03E/K@30<BR]P040<6T_02^U[d0
[YJm000000<0V8No0`1nMl4205eVa00303=Ca00H>kH001JU01@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo000b0?ooo`<00000<03oool2
0>c5[0<0il6_0P3V`[430>G2]0050=fm^03K_K/0fkfk0=^m^`3I_Kh00P3:]LD20<Jdb@80ZJCB00D0
LXCF0>Z=703ZSA`0i8<=0;QG000G0?ooo`80nkUg0P3k^gX0103k_7d0n[f00?ZoQ03j_h@20?[1R080
nL:=00<0n<BB0?2iU03`^I@00P3_^YX20>flW`<0gk6W0P3L/Zd20<bU/080bJJf00H0]9Ji0?NUB@3g
Y4H0mjA60?JR@`3eX3l20?BM>`040?2E;@3/Sb<0k8lS0000C@D0oooo00<000000?ooo`3oool0703o
ool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1E0?ooo`<00000>`3o
ool20?;2W@80lL>P0`3aa:80103`a:D0jl2X0>_0Z03[`:P30>W0Z`030>S1[P3Q^k40g[^e0080g[^e
00D0g;bh0<jb_`3>/[l0c[:o0<Zb`P030;6SbP80liTj00<0lIHd0=j00P3NP0804`3oool20?fnH005
0?g0H`3n`VH0o/AZ0?k4JP3oaVl00P3ob7@20?^oP@030?[1QP3j`hd0n/>=0080n<JD0P3gb9/00`3/
^Yd0j[bU0>ZlY@020>Jn[0050=V_[P3E/K@0eK6d0=Fa]034X[H00P31Y;`20:jF_@040000002HQkl0
V8No09R7_`<0OWO10P1MI/@203=Ca08001JU4P3oool3000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0W0?ooo`00<03oool2000003<0oooo0P3/aJ`00`3[aJl0il6_0>O1[`02
0>K2/@<0iL:d0`3K_K/20=Vm_P040<Zea@36]<T0a[C90<Jdb@80ZJCB00D0LXCF0>Z=703ZSA`0ihPE
0;mO000G0?ooo`060?k3LP3k^gX0nk]j0?^kNP3k_7d0n[f00P3j_h@20?[1R080nL:=0P3ha9830>nj
VP80kKbO00<0jkjU0=naY`3O/JL00P3L/Zd01P3<YK00bJJf0<VV]P39Y[H0]9Ji0?NUB@80mjA600D0
mZ930?FP?`3dWC/0m9dk0?:J=0020>b?8`030;=N003oool0oooo00<0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000E@3oool2000003d0
oooo0`3b`Yd20?73X080lLBR0P3`a:D00`3_aJL0jl2X0>_0Z0020>W0Z`80j<6^0`3N^kD30=bl^003
0<jb_`3://80b[;200<0/J?:00H0m9a00?>I>P3aUS@0ki4]0=j00P35HP0B0?ooo`80oKiP00D0oL1S
0?k2IP3na6X0o/AZ0?o6K`020?o8M0030?o;NP3k_h40n/660080n/>=0P3haY@20?O8V`<0j[bU0P3V
_Z`40=Fa]0@0`JBl00<0[YJm0000002JSLD00`2JSLD308B1b00506Yeb`0cDl@0<e?403=Ca0005ZD0
5@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool09`3oool002d0oooo
0`00000d0?ooo`<0k<F/0P3[aJl20>K2/@@0iL:d00<0hl>g0=^m^`3I_Kh00P3I_Kh40<Jdb@<0Xj?D
00D0K8;G0>Z=703WR1D0i8<=0;QG000F0?ooo`060?k3LP3oaGD0nk]j0?^kNP3k_7d0n[f00P3j_h@2
0?[1R080nL:=0P3ha9800`3gaYP0kkZJ0>flW`020>flW`030>^nY@3O/JL0g;:]0080g;:]1039Y[H0
1P2dU[T0mjE90?NTAP3gY4H0mZ930?FP?`80m9dk00D0lYXd0?2E;@3/Sb<0ihLF0000C@030?ooo`80
0000803oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`1@0?ooo`<0
0000?`3oool0103db:00l/:M0?;2W@3a`j030?74XP80l<BU0P3_aJL30>W0Z`80j<6^00<0i/:a0=jk
]@3N^kD00`3L_;P30<Zb`P<0[J?=00L0m9a00?>I>P3aUS@0ki4]0>b<903HM`00aF800140oooo0P3m
_V001@3m`6<0o/9V0?k4JP3na6X0olI_0080olQd00<0ol]j0?[1QP3j`HH00P3j`hd01P3haY@0mlRK
0?O8V`3gb9/0m<^S0>ZlY@<0i[j/00<0h[nd0=Fa]03E/K@00P3A/[/30<6T_080000000@0[I[309Z=
a@2JSLD0VXg50`24PLP206Yeb`0404]Yc`0cDl@003bo000FYA@0oooo00@000000?ooo`3oool0oooo
0P0000020?ooo`030000003oool0oooo02L0oooo000Z0?ooo`<00000=`3oool20>c5[0<0jlF_00<0
j/Ja0>G2]03U`[@00P3U`[@20>?3]`@0fKfn00<0ekk10<Jdb@36]<T00P32]<`30:>Se0040?6D=P3W
R1D0i8<=0;QG01H0oooo00<0o/=b0?o5M@3oaGD00P3k_7d00`3j_H00n[n40?ZoQ0020?[1R080nL:=
0P3ha980103gaYP0kkZJ0>flW`3]_9l20>^nY@@0g;:]00H0fKBc0<VV]P39Y[H0bJJf0;6I_P3gYDT2
0?NTAP090?JR@`3eX3l0m9dk0?BM>`3bVS@0l9D]0>b?8`3WQaH0001=00<000000P3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo0`00001@0?ooo`<00000@P3oool20?C8X080
lL>P0`3aa:801P3`a:D0klFW0>o5Y`3_aJL0k/JZ0>W0Z`<0j<6^0P3V`[430=bl^080fKbl00<0b[;2
0<NbaP37//H00P2]Xld0103dW400liTj0?>I>P3_TBd20>b<90030<m]003oool0oooo00l0oooo0P3m
_V001@3m`6<0o/9V0?k4JP3na6X0olI_0080olQd00<0ol]j0?o>P@3j`hd00P3j`hd01@3haY@0mlRK
0?O8V`3gb9/0m<^S00@0i[j/00<0h[nd0=Fa]03A/[/00P3A/[/3000000040;fW``2]V/<000000:fJ
``80VXg50`24PLP306Yeb`0304]Yc`00?;l003bo01D0oooo00@000000?ooo`3oool0oooo0`00000Z
0?ooo`00:@3oool2000003P0oooo0`3/aJ`20>_5[`80j/Ja00<0jLJc0>G2]03U`[@00`3S`kL00`3R
`kX0fKfn0=Vm_P030=Nn`@<0`[C<0`2SXm@01@3aU3H0ihPE0>N85@3OO0<0^5L001D0oooo00@0o/=b
0?o5M@3oaGD0olIi0P3j_H020?ZoQ0030?[1R03i`Xd0nL:=00<0n<BB00@0mlJH0>flW`3]_9l0kKbO
0P3[_ZD00`3X_j/0g;:]0=bb[@030=Vd/`030<VV]P36Z;/0aZRk0080mjE900<0mjA60?JR@`3eX3l0
0P3dWC/00`3bVS@0l9D]00000002000000030000C@3oool0oooo0080oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`1C0?ooo`800000@`3oool30?C8X0040?C9X`3aa:80lLBR0?74XP80
l<BU0`3_aJL0103^aZX0j<6^0>S1[P3X`Jh30>K2/@030>G2]03L_;P0fKbl0080fKbl1037//H0102]
Xld0m9a00?>I>P3cVCX20>nA;@030>b<903?K@00aF800100oooo0P3m_V000`3m`6<0o/9V0?k4JP02
0?o6K`80olQd00<0ol]j0?o>P@3odHT00P3j`hd00`3haY@0mlRK0?O8V`020?C;X`030?7<[03V_Z`0
i[j/0080h[nd00@0dK:k0000000000000000102mYl<00`2]V/<000000:fJ``0209Z=a@<0Q8780`1Z
ML/204]Yc`809EkB5@3oool00`000000oooo0?ooo`0]0?ooo`00:@3oool2000003P0oooo0P3]bJl3
0>_5[`80j/Ja0P3Ya[<30>?3]`<0h/>j0`3G_/420=>na@030<:dc02n/m00_[?@0080WJ7G0P3aU3H0
0`3WR1D0i8<=0=Ye000E0?ooo`050?k3LP3oaGD0olEe0?o6N@3ob7d00`3j_h@00`3j`HP0nL:=0?W2
S@020?S4TP80mlJH00<0m/RM0>flW`3[_ZD00P3[_ZD20>RoZ`040=bb[@3I];<0fKBc0=Vd/`<0aZRk
0P3gYDT20?NTAP80mJ0o0`0000020>b?8`030>N75P3DK000oooo00@0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`1C0?ooo`800000@`3oool30?C8X0050?C9X`3cbJD0lLBR0?74XP3`
a:D00`3_aJL20>k6ZP030>g6[@3X`Jh0j<6^0080i/:a0P3U`[@40=Vl_0060=Nl_`37//H0ak;60<Nb
aP2XX]00m9a00P3cVCX01@3aUS@0ki4]0>b<903XQAX0cfd00100oooo0P3m_V000`3m`6<0o/9V0?k4
JP020?o6K`040?o8M03obgX0ol]j0?o>P@80om690P3haY@20?O8V`80m<^S0P3ac:`0103V_Z`00000
0000000000030=6b^`040<bd`P2mYl<0_JO30;fW``80[I[300@000000:^Nb@2KTl/0Vi?;0`29R/h3
07J2dP80HGcH0P0UG]8D0?ooo`030000003oool0oooo02d0oooo000J0?ooo`030000003oool0oooo
0080oooo0`0000070?ooo`030000003oool0000003H0oooo0`3]bJl0103/b[40jlF_0>[6/@3Za[43
0>W6/`030>O7]@3S`kL0h/>j00<0h/>j00<0glBl0=Nn`@3C_/D00P3C_/D40;jcd080WJ7G00@0lI@f
0>n@;`3TP`d0gg`35@3oool01@3n`g80olEe0?o5M@3oaWT0olQm0080olZ10P3j`HP20?W2S@80n<BB
0P3gaYP0103fb9d0kKbO0>^nY@3[_ZD30>RoZ`@0fKBc00<0e[Fi0<JX^`36Z;/00P3gYDT0103gY4H0
00000000000000020?BM>`060?:J=03`UBd0k8lS0>N75P3PN`D0e6`01@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool00P3oool3000000L0oooo00<0
00000?ooo`000000@P3oool20?C8X080m<VS0P3cbJD20?34Y@<0klFW00@0k/JZ0>g6[@3]aZd0kLJ]
0`3V`[420>G2]0030>?3]`3I_;`0fKbl0080ekbo0P37//H20<>bb@090?BL@03cVCX0liTj0?6F=03_
TBd0k8`T0>R56P3SO@h0aF8000l0oooo0P3m_V000`3m`6<0o/9V0?k4JP020?o6K`040?o8M03obgX0
ol]j0?o>P@80om6900<0o]BA0?O8V`3gb9/00P3dbj<01@3ac:`00000000000000000h[nd00<0g/6l
00<0dK:k0<bd`P3<]<800`2mYl<30:^Nb@040000002KTl/0Vi?;09^Cb`80RH[>0`1fP]83065lf003
04Qjg`3oool0oooo01<0oooo00<000000?ooo`3oool0;03oool001X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`8000001@3oool200000080oooo00<000000?ooo`3oool0<`3oool20>g9[`80
k<Za0`3Za[420>W6/`80ilNe103R`kX20=o4_0@0dkk500@0d;k80;jcd02n/m00_[?@0P2GWmX01@3a
U3H0ki0_0>n@;`3OO0<0fWD001@0oooo00D0o/=b0?o5M@3oaGD0olIi0?o8O@020?o:P@040?k<QP3j
`HP0nL:=0?W2S@80n<BB0P3gaYP0103fb9d0jkjU0>^nY@3[_ZD30>RoZ`030>G1/@3I];<0fKBc0080
e[Fi0P36Z;/3000000030?NTAP3fXT<0mJ0o0080m9dk00<0lYXd0?2E;@3/Sb<00P3WQaH00`3DK000
oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0@P3oool01@000000
oooo0?ooo`3oool000000080oooo0P0000050?ooo`8000000P3oool00`000000oooo0?ooo`0n0?oo
o`<0m<RP00D0m<VS0??9Y@3cbJD0llVU0?;:Y`030>o5Y`80k/JZ0`3]aZd00`3/ajl0i/:a0>G2]002
0>G2]080hl>g00<0fKbl0=Nl_`3G_;l01033//T0103dW400liTj0?>I>P3aUS@20>nA;@030>b<903X
QAX0hgd>00l0oooo00H0oKiP0?g0H`3m`6<0o/9V0?k4JP3oaVl20?o8M080ol]j00H0olj10?oAR@3o
dHT0o]BA0?gGVP3gb9/300000080lLb/00<0kLjd0>:o]03N`K`00P3N`K`30<bd`P@0^ZW90`2[W/T0
0`000000Vi?;09^Cb`0208V:cP<0MX;B0`1QO=P204QjgaD0oooo00<000000?ooo`3oool0:`3oool0
0180oooo1@0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<@3oool30>g9[`80k<Za0P3[b[<3
0>W6/`80ilNe00<0i/Nh0>;3^P3R`kX00`3Oa;`00`3Ma;l0dkk50=>na@020=2nb0@0^K;C00@0UioJ
0?6D=P3_T2l0ki0_0P3OO0<00`2VA000oooo0?ooo`0@0?ooo`060?k3LP3oaGD0olEe0?o5M@3oaWT0
olQm0P3obX401@3nc8H0nL:=0?W2S@3i`Xd0n<BB0080mlJH0P3fb9d00`3cbJ@0jkjU0>^nY@020>Ro
Z`80iL6a00@0fKBc0=Je^@3F]KT0e[Fi0P0000020?NUB@80mjA600H0mZ930?FP?`3dWC/0m9dk0?:J
=03`UBd20>b?8`030>N75P3PN`D0e6`000D0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0j0?ooo`D000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo0`3db:001P3dbJ<0
llVU0??9Y@3cbJD0l/ZW0?7;Z@80klFW00@0k/JZ0>g6[@3]aZd0kLJ]0P3/ajl30>G2]0<0hl>g0`3G
_;l01@3C_<<0`k;90<>bb@2n/Ld0m9a00080liTj00L0lIHd0>nA;@3_TBd0k8`T0>R56P3SO@h0^E@0
00h0oooo00<0oKiP0?g0H`3n`VH00P3na6X01@3oaVl0olQd0?o8M03obgX0olj10080om690P3ne942
00000080m<^S0P3ac:`20>g>]0<0g/6l0P3H`/<20<bd`P040<Nfb@2jZLT0^ZW90;ZYb@<0Zik900@0
000009fJd02MV]00WI[@0P2?Tm<3086>f0<0LXcN0P1TSnHC0?ooo`800000;@3oool001/0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo
0?ooo`0`0?ooo`80kLV_0P3/b[430>_:/`040>_;]03Ya[<0ilNe0>O7]@<0i/Nh0`3Oa;`30=g4_`<0
d;k800H0cKg;0;Vbd`2i/]<0^K;C09NOfP3aU3H20>n@;`030>f<:03OO0<0e6d00180oooo00<0o/=b
0?o5M@3oaGD00P3oaWT0103ob7d0olZ10?o:P@3nc8H20?k>S080n<BB0P3gaYP20?K8W@80llVT0`3X
_j/20>G1/@040=Je^@000000000000000080`ZW10P3gYDT20?NTAP060?JR@`3eX3l0m9dk0?BM>`3b
VS@0l9D]0P3/Sb<0103WQaH0h7/50=A/0033EP050?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0@P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`030000003oool0oooo03`0oooo0P3db:020?C9X`80llVU0P3bbZL20?7;Z@80k/JZ0`3]
aZd20>c7[`030>[8/P3U`[@0iL:d00<0hl>g00<0hL>k0=Nl_`3C_<<00P3C_<<30;jac@030?>JC`3b
V4/0lIHd0080ki4]00D0k8`T0>R56P3SO@h0gG@00;UD000=0?ooo`030?fnH03m`6<0o/9V0080o/AZ
00H0olI_0?o8M03ob7@0ol]j0?o>P@3odHT3000000030?gGVP3jfZ@0n]ZT00<0lLb/0P3]c[@00`3X
ckd0g/6l0=S2``020=S2``040<bd`P37]/T0akK90<Nfb@80^ZW9102ZX/l00`000000WI[@09fJd003
08nCd`80PHkH0`1bS=h306B?iQ@0oooo00<000000?ooo`3oool0:P3oool001/0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0;P3oool30>g9[`80k<Za0P3[b[<20>_;]0<0ilNe0`3VakP20>G8^P<0gLBo0P3Ka<80
1@3@_/P0cKg;0<fmb`3=_L/0^K;C0080/k7F00L0T9cL0?6D=P3_T2l0kH`X0>Z77`3JM@00c6@00140
oooo00@0o/=b0?o5M@3oaGD0olIi0P3ob7d20?o:P@050?k<QP3ncX`0o/j<0?g@T@3ha9800P3gaYP0
1`3fb9d0llVT0??9Y03cbJ@0lL^Z0>RoZ`3U`K400`0000020=Je^@80d[No00<0`ZW10?NUB@3gYDT0
0P3gY4H01@3fXT<0mJ0o0?BM>`3dWC/0lYXd0080l9D]00D0k8lS0>N75P3WQaH0h7/50=A/00060?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0@@3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0j
0?ooo`<0m<RP00@0m<VS0??9Y@3cbJD0llVU0P3bbZL20?7;Z@040?3;[03]aZd0kLJ]0>g6[@80k<N_
0`3Zb;830>?3]`80hL>k0`3C_<<20=2la`80_[7=00<0liY?0?:HB`3bV4/00P3_TBd01@3/S2@0j8DJ
0>R56P3SO@h0e6P000d0oooo00<0oKiP0?g0H`3n`VH00P3na6X00`3oaVl0olQd0?o;NP0300000004
0?oAR@3ne940oMNJ0?gGVP80n]ZT00@0mmb]0?7<[03]c[@0kLjd0P3Xckd40=S2``@0akK90`2g[<h3
0:ZRc`0309fJd0000000WI[@00@0U9_H0P29VM`3082IhP80NIkY5@3oool00`000000oooo0?ooo`0Y
0?ooo`006`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo02d0oooo0P3]c[D20>c:/@<0jlZc0P3[bk@2
0>W;]P<0i/Nh0`3Ub;X00`3Sb;`0gLBo0=_4`P020=_4`P@0cKg;102c/MH00`3aU3H0ki0_0>n@;`02
0>Z77`030=A]000006@0oooo00l0oooo00@0o/=b0?o5M@3oaGD0olIi0P3ob7d00`3obX40o/b60?k<
QP020?k>S0050?g@T@3gaYP0mlJH0?O6V03fb9d00P3cbJ@01@3abjX00000000000000000iL6a0080
h/:h00D0e[Fi0=:g_`3B]kl0d[No0<:Y`@020?NUB@80mjA600@0mZ930?FP?`3dWC/0m9dk0P3bVS@0
1`3`UBd0k8lS0>N75P3WQaH0h7/50=A/0033EP001P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0440oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0i0?ooo`80mLnW0P3dbJ<20??9Y@80
l/ZW0P3abjT20?3;[0030>o<[P3]aZd0kLJ]0080k<N_0`3Zb;80103Yb;D0hl>g0>73^`3Q`k/20=k4
_P040=>l``3@_<L0d;c70=2la`80^[3@00@0liY?0?:HB`3bV4/0lIE50P3`TCl20>R56P030>=m3P3M
M000e6P000`0oooo00D0oKiP0?g0H`3n`VH0o/AZ0?o6K`03000000030?o;NP3ocX40om690080o]BA
00<0oMNJ0?[JY03jfZ@00P3gg:d20>g>]0<0j<nm00<0h/o50=S2``3H`/<00P3C`/X20<Nfb@80`[O?
0`2g[<h01P2ZX/l0ZJKD0:VVe02NX=D0000009jPe@<0U9_H0`29VM`2082IhP<0NIkY503oool00`00
0000oooo0?ooo`0Y0?ooo`006P3oool300000080oooo0P0000020?ooo`040000003oool0oooo0?oo
o`800000203oool2000002`0oooo0`3]c[D0103/c[H0jlZc0>_:/`3[b[<30>_;]080jL^f00<0j<^h
0>K7^03Ub;X00P3Ub;X20>?8_0@0flC200<0fLC50<fmb`3=_L/00P39_Ll30;>aeP030?6D=P3_T2l0
ki0_0080jXLO00<0e6d00<aT003oool03`3oool01@3n`g80olEe0?o5M@3oaWT0olQm0080olZ10P3n
c8H20?k>S0030?g@T@3ldYP0o=:H0080m/RM0`000000103abjX0k/fa0>G1/@3U`K420>;2^0@0d[No
0P2nZlH0103gYDT0mjA60?NTAP3fXT<20?FP?`80m9dk00<0lYXd0?2E;@3/Sb<00P3WQaH20>R0;@03
0<=F002X>000001j00@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0o0?ooo`<0
00000P3oool200000080oooo00@000000?ooo`3oool0oooo0P0000080?ooo`800000>@3oool20?G?
Y`040?C@Z@3cbJD0llVU0??9Y@80l/ZW0P3abjT20?3;[080klb^0P3/ajl30>[8/P80jLRe0P3Q`k/3
0=k4_P@0d;c700<0c;c;0;Z`d03cVTl00P3bV4/02@3aUDD0l94o0?2A?`3^SCP0k8L_0>=m3P3MM000
e6P00000GP0;0?ooo`030?fnH03m`6<000000080000000H0olI_0?o8M03obgX0ol]j0?o>P@3odHT2
0?kDT@030?gGVP3jfZ@0n]ZT0080mmb]00@0lmfg0>S?_@3Xckd0j<nm0P3RclD0103H`/<0dl;:0=?2
bP3C`/X40<:gc`<0]jc>102YY]@00`000000WZ3E09BKf00209BKf0<0RIWL0`2<Y>D308RXja@0oooo
00<000000?ooo`3oool0:03oool001`0oooo00@000000?ooo`3oool0oooo0`0000050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0:@3oool20>g>]@80k<jf00<0jljg0>_:/`3[b[<0
0P3[bk@20>W;]P80j<^h0`3Ub;X30>?8_0030>;9_`3Ka<80flC20080fLC51039_Ll30:f_f@070?6D
=P3_T2l0ki0_0>f<:03ZQal0iX4F0=A]000@0?ooo`050?k3LP3oaGD0olEe0?o6N@3ob7d00P3obX42
0?k<QP040?k>S03md940oM2A0?cBV0<0000000@0llVT0?7;ZP3abjX0lL^Z0P3^cK430>;2^0030=k3
_P3B]kl0d[No0080cKS50P2nZlH20?NTAP030?JR@`3eX3l0mJ0o0080m9dk00@0lYXd0?2E;@3^ST80
kXi20P3/R3T00`3XP2d0hgDL0=UT10020000NP@0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`100?ooo`040000003oool0oooo0?ooo`<000001@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo03D0oooo0P3ecjL20?C@Z@80lm2[0`3bbZL00`3abjT0l<^/0?3;[0030>o<
[P030>k</03Zb;80j/Rb0080j/Rb0P3Yb;D00`3WbKP0g/Bn0=k4_P020=k4_P030=c4`P3@_<L0d;c7
00<0c;c;00@0liY?0?:HB`3bV4/0lIE50P3`TCl00`3^SCP0k8L_0>b7;`020=ed00030<UJ000005h0
oooo00P0oooo0`0000001@3n`VH0o/AZ0?o6K`3oaVl0olQd0080ol]j00H0om690?kDT@3ne940o]BA
0?gGVP3jfZ@20?OL[@80lmfg00<0k]k10>S?_@3Xckd00P3RclD40=?2bP040<g3d@32]ll0`[O?0<:g
c`@0/joD0`2YY]@00`2PY]X000000:2VfP0309RSg0<0TJ;P0P2<Y>D308RXjaD0oooo00<000000?oo
o`3oool09`3oool002L0oooo0P00000;0?ooo`030000003oool0oooo02L0oooo0`3]c[D20>c>]P80
jljg0`3[bk@20>W;]P80j<^h0P3Wc;X30>?8_0<0h/Vo0`3Ia<D00`3Fa<T0bKg?0<Vmc`020<FldP<0
[JoI0P3_T2l01@3]S2P0jXLO0>Z77`3RNP`0c6@000l0oooo00D0o/=b0?o5M@3oaGD0olIi0?o8O@02
0?o:P@030?k<QP3ncX`0o/j<00<0000000@0o=:H0?_DWP3ieZD0llVT0P3abjX30>k=/@030>_>^03R
`[P0g/>n0080g/>n103=^<D30;^]b`030?JR@`3eX3l0mJ0o0080m9dk00@0lYXd0?2E;@3`TdT0kXi2
0P3/R3T0103XP2d0hgDL0=UT103II0@20:dY00@0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1;0?ooo`8000002`3oool00`000000oooo0?ooo`0d0?ooo`80mLnW0P3dd:T20??@Z`80
lm2/0P3abjT20?3;[080klb^0P3^c;000`3]cK<0j/Rb0>[8/P020>W8]@80ilVh00<0iLVk0=k4_P3N
a;h00`3La<840<blb`80liY?00D0lYQ;0?6EA@3`TCl0l94o0>j=>0020>b7;`040>R09@3TN1P0e6P0
0<UJ00H0oooo0`0000001@3oool0oKiP0?g0H`3n`VH0o/AZ0080olI_0P3obgX01@3kfgX0o=n40?cS
S`3lhhl0oMNJ0080n]ZT0P3gg:d0103cgKL0k]k10>kN`@3^g/420>;?a@80flo=0P3C`/X30<g3d@03
0<:gc`2m^=@0_KSD00<0/joD102XZmT00`2PY]X0000009RSg00209RSg0<0TJ;P0`2D[>H309:`ja@0
oooo00<000000?ooo`3oool09`3oool002L0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0U0?ooo`<0kLje0P3/c[H30>_>]`80j/ji0P3YbkH20>S;^0<0ilbj00<0i/bl0>?8_03RbKl0
0P3RbKl20>39`P040=W4a@3Fa<T0e/C90=K4b@@0aKcB0P2W[M`00`3aU4@0l94n0>f<:0020>Z77`80
hWX<00<0^Dd00?ooo`3oool02`3oool0103n`g80olEe0?o5M@3oaWT20?o8O@030?o:P@3nc8H00000
0080000000<0oM2A0?cBV03ldYP00P3ke9h0103ieZD0lL^Z0?7;ZP3abjX20>k=/@80jljh0`3N`kh2
0=W3a080cKS50P39^</20;^]b`030?JR@`3eX3l0mJ0o0080m9dk00@0lYXd0?2CB@3`TdT0kXi20P3/
R3T20>R0;@030>=e703II0@0bD`00080[BT000D0P@000?ooo`3oool0oooo0000000N0?ooo`800000
C03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0380oooo0P3ecjL20?C@Z@80lm2[
0`3cd:`0103bd:h0l<^/0?3;[03`bj`20>o<[P80k/b`0P3]cK<20>W8]@<0ilVh0P3UbK/30=c4`P80
fLC50P3<_</01038_<h0liY?0?>JC`3bV4/20?6EA@050?2A?`3^SCP0kXdh0>b7;`3XP2D00P3TN1P0
1039FP00^TP00?ooo`3oool3000000@0oooo00H0oKiP0?g0H`3n`VH0o/AZ0?o6K`3hdVP20?[FL006
0?_KNP3lgh@0o>>?0?cSS`3liiX0n^ZV0P3gg:d20??M]`80k]k10P3XgLT40=_?c@@0cL?A0`2m^=@4
0;6af0<0Z:_I0P2PY]X010000000W:WP09bYh02LZN0309NYh`<0U:cV0P2B/>/D0?ooo`800000:03o
ool002L0oooo0P00000=0?ooo`030000003oool0oooo02@0oooo0P3Zdkh30>c>]P80jljg0`3Zc[T0
103YckX0j<^h0>S;^03XbkP20>O<^P80i/bl0`3RbKl30>39`P<0e/C90P3Ca<`20<FldP80`;_F00@0
YjgL0?6DA03`TCh0l94n0P3ZQal0103VPAH0hWX<0<=I002iC@0<0?ooo`050?k3LP3oaGD0olEe0?o6
N@3ob7d00`000000103nc8H0o/j<0?g@T@3md9420?cBV0030?_DWP3ieZD0nMJU0080mmR/0`3^cK42
0>_>^0030>K?_P3N`kh0fL?40080fL?400D0cKS50<Vhb`39^</0bKS;0;^]b`020;N^d080mJ0o0P3d
WC/0103bVS@0lII>0?2CB@3^ST830>b8>@050>R0;@3SMA`0fF@40=UT1039C0000P2]:@0010210000
oooo0?ooo`00000P0?ooo`030000003oool0oooo04T0oooo0P00000=0?ooo`030000003oool0oooo
00d0oooo102U^NL208V/k080GYG/00<08W3P0?ooo`3oool06@3oool20?G?Y`80m=2Y0P3cd:/20??@
[080l]2^0P3adK020>o<[P80k/b`0`3]cK<0103/cKD0ilVh0>O9^03WbKP30>G9^`030>?:_P3La<80
fLC50080fLC50`38_<h20?>JC`030?:HB`3aUDD0lIE50080l94o00H0kXdh0>b7;`3XP2D0j80U0>Ah
6039FP03000000L0oooo00H0oKiP0?g0H`3n`VH0o/AZ0?O>H03hdVP20?[FL080o=n400@0o>>?0?cW
VP3jjZH0n^ZV0P3gk;800`3ckKd0k]k10>kN`@020>SMb@80hMcA0P3Kcld20=C>d`80cL?A0P36`]H0
0`2m^=@0^KWI0;Vif@030;6af0@0YjkM00<0XJ_N0000002LZN000P2LZN0309NYh`@0V[;X0`2J]N/D
0?ooo`030000003oool0oooo02D0oooo000W0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool08P3oool30>[C_P80jM:n0P3[c[L30>[>^@80jLnj0P3Yck/30>O<^P80i/bl0P3UcKh30>39
`P80g/W4103Ca<`40<2keP0:0:2[gP3aU4@0l94n0?2A?P3^SCP0k8P`0>J15P3RNP`0g7400;U=00`0
oooo00<0o/=b0?o5M@0000000P0000001@3ob7d0olZ10?k<QP3nc8H0o/j<0080oM2A00<0o=:H0?_D
WP3ke9h00P3ieZD20?OH[0040??I/`3^cK40jljh0>_>^080i/nn103I`l@40<Vhb`@0]jk@00<0Z:CA
0?BM>`3dWC/00P3aUTh00`3`TdT0kXi20>j>@P020>b8>@040>R0;@3SMA`0hgDL0=UT1080bD/:0P2e
;002098000030?ooo`000000oooo01h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00X0oooo102e`>820:Fii`<0RJc/0P1NUN`00`0RL>0004;30?oo
o`0G0?ooo`80mLnW0`3dd:T0103cd:/0lm2/0??@[03cd:`20?;@[P80lM6`00@0l=6b0>k</03^c;00
k/b`0P3]cK<20>c=]@030>_>^03WbKP0ilVh0080iLVk0P3Sb[h40=W4a@050=K4b@38_<h0b;c>0<Bk
dP3cVTl00P3bV4/0103aUDD0l94o0?2A?`3^SCP20>b7;`<0000000<0eF000;Y8003oool01P3oool2
0?fnH0050?g0H`3n`VH0mliP0?O>H03hdVP00P3jeW001@3lgh@0o>>?0?cSS`3liiX0n^ZV0080mnbb
0P3ckKd00`3^k<L0j=g90>SMb@030>7Ld@@0e<kC1036`]H40;Vif@<0[[CL0`2W[]d20:6[gP040000
002O[n<0WjoS09n_h`<0W:oU0`2J/^P409nija<0oooo00<000000?ooo`3oool09@3oool002L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`80j]>n0`3Yd[h0103Xd[l0j/ji
0>[>^@3Zc[T20>W?^P<0jLnk00@0j<nm0>O<^P3Vc;`0i/bl0`3UcKh00`3TcL00h<W20=k9a0020=k9
a0030=c:a`3Ca<`0dlC<00<0d<C?0`2j^]T0103aU4@0l94n0?2A?P3^SCP20>b8<080hWX<0P2iC@0:
0?ooo`<0000000D0olEe0?o6N@3ob7d0olQm0?o:P@020?k<QP050?k>S03md940oM2A0?cBV03ke9h0
0P3ieZD20?OH[080lmVc0P3[c[P30>K?_P030>;?a@3I`l@0fL?40080e<C:0P39^</20<Bid0<0]jk@
00<0YjOF0?BM>`3dWC/00P3aUTh00`3`TdT0kXi20>j>@P020>b8>@80j80]00<0hgDL0=AP9@3DH2D0
0P39B`X20;D/0080TP0000<0F`000000003oool07P3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool30;o4gP80]L3R0P2b_n<20:6hj@<0QJ[]
0P1JTn`00`0PKml004;3000GWP0F0?ooo`80lmRc0P3cf;@20??@Z`80lm2/0P3bd:h20?7A/080l=6b
0P3_dK@30>g=/`80k<fe0P3[c[P20>G9^`<0hlZn00<0hL_20=W4a@3Ia<D00`3Fa<T20<BkdP040?>J
C`3bV4/0lYQ;0?6EA@80l94o0`0000020>R09@040>Ah603MK@P0eF000:Lc00H0oooo0P3m_V002P3m
`6<0o/9V0?O>H03gcV00n=9X0?[FL03kfgX0o=n40?cSS`3liiX20?[ZYP80mnbb00@0lnfm0>k/a`3^
k<L0j>_@103Qg=400`3If]P0e<kC0=C>d`020<g=f@@0`L;K0P2i^MT20;Fjg@80[[CL0`2W[]d30:>`
h@040000002O[n<0WjoS09n_h`80W:oU102O]^T309nija@0oooo00<000000?ooo`3oool0903oool0
01d0oooo0`0000070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07`3oool20>[C
_P<0jM:n0P3Xd[l20>SB`0<0jLnj0P3Yck/20>S?_@<0i/bl0P3UcKh20>C=`0<0g/W40`3Lb/L30=34
c`80c<CC0P2j^]T0103aU4@0l94n0?2A?P3^SCP20>b8<080hWX<00<0g7400<aL003oool01`3oool2
000000070?ooo`3n`g80olEe0?o5M@3oaWT0olQm0?o:P@020?k<QP040?k>S03md940oM2A0?cBV080
nmBN0P3ieZD20?OH[080lmVc00@0l=Zj0>K?_P3Vckh0i/nn0`3RclD30=C4bP@0a;W@102d/=D0102W
YmH0lYUB0?6FCP3aUTh20?2CB@070>j>@P3/R3T0k8Pi0>b8>@3XP2d0hgDL0=Y^>0020=AP9@80bD/:
0`2S7P000`260000000003<0000203<0000302^Yj`1TbO`0I<Wl0080I<Wl603oool00`000000oooo
0?ooo`0m0?ooo`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo
0P35a]/30;o4gP@0/[oS0P2Q^>T208FZk@80FY?/0P0PKml00`00A<D001NN0?ooo`0C0?ooo`80lmRc
0`3cf;@0103bf;D0lm2/0??@[03cd:`20?;@[P80lM6`0P3`dK820>oA]0040>kA]P3]cK<0k<fe0>c=
]@<0jljh00@0jLjj0>?:_P3Sb[h0hlZn0`3Qbl830=K4b@80d/C=00D0a;_B0?>JC`3bV4/0lYQ;0?6E
A@0200000080kXdh00P0k8L_0>R09@3XP2D0i7PH0=e]203EH000b4h008lK00H0oooo0P3m`6<01@3e
beX0mliP0?O>H03hdVP0n]I`0080o=n400<0o>>?0?cWVP3jjZH00P3gk;800`3ckKd0k^c70>k/a`02
0>S[d0030>7Xe`3Qg=40hMcA0080fM[H0`3=cMT20<K;gP<0`L;K102e^]d20:jdg0@0Yk;P0P2S/>40
0`000000X[?U0::ci@020::ci@80X;CW0`2O]^T40:>lja@0oooo00<000000?ooo`3oool08`3oool0
01`0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool07P3oool0103Sel/0jM:n0>WB_P3Yd[h20>SB_`<0j=;00P3Wd/430>W?^`80j<nm0P3W
ckh20>G=_P<0i<g00P3ScL<30=c:a`80f/[:00@0d<C?0<c4d`3<a=<0c<CC0`2d^=`02P3aU4@0l94n
0>j=>03^SCP0k8P`0>V29`3VO1d0g7400=EW003<G0040?ooo`<000000`3oool00`3n`g80olEe0?o5
M@020?kDN@040?kGO`3ofHD0omV50?oLS080o]jC00<0oN2K0?cRXP3ieZD00P3ieZD00`3gf:`0lmVc
0??I/`020?3J^P030>cJ`@3Vckh0i/nn0080h/o50P3Mcl/00`3Da<X0clC@0<o4d0020<Bid080_k[D
0`2d/=D30:NWeP040?6FCP3`TdT0l9=90>j>@P<0k8Pi00<0j80]0=Y^>03JKSP00`3DH2D00`39B`X0
]3/Q0;@k8@020:<N0003068000000000HP0000@0L<3n0`1hbOlG0?ooo`030000003oool0oooo03`0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool00P3oool40<G6f`@0_LCO102`_^D309ffjP80P:S^00D0EY3/01i_g`0NKml004C5000GWP0C
0?ooo`80lmRc0P3cf;@20?;H]@80lMNf0`3bd:h00`3adK00l=6b0?3A/P020>oA]080k]6f0`3/cKD2
0>_>^080jLjj0P3Xckd30>7;`P80gl_5103Ba<d00`2n^]D0liY?00000002000000050?6EA@3`TCl0
kXdh0>j=>03/Qbl00P3XP2D01P3TN1P0gFd80=e]203EH000b4h009lN00H0oooo00@0oL1S0?G;FP3g
cV00mliP0P3jeW020?cOQ0050?cWVP3Zn:/0j_R[0>[j^P3ckKd00P3^k<L20>S[d0<0hNSG0P3If]P3
0=;Gg@@0a/_N0`2k`]l30;Fjg@<0[;KP0`2W/^030:Bdi0040000002R/nD0X[?U0::ci@<0XkSX0`2R
^^T40:Fmja<0oooo00<000000?ooo`3oool08`3oool001H0oooo1@0000000`3oool000000?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0L
0?ooo`@0hmO;0`3Xd[l20>SB`0@0im;100<0jLnk0>S?_@3Xckd00`3Wckh0103Vd<00i<g00>C=`03T
cL030>?=``030>7>a@3Lb/L0f/[:0080f/[:0`3<a=<20<O3eP80];SL00H0lIA40?2A?P3`TCh0kXdh
0>b8<03YPRL20>Il7@030=EW003<G000WS4000<000001P3oool00`3n`g80olEe0?kBL`020?kDN@04
0?kGO`3ofHD0omV50?oLS080o]jC00D0oN2K0?cRXP3ji:X0n^BZ0?OH[0030??I/`040?3J^P3/f/40
k=[10>cJ`@80h/o50`3Mcl/40<o4d0@0_k[D0P2d/=D30:FYfP030?6FCP3`TdT0l9=90080kXi20P3/
R3T0103XP2d0gWQ60=Y^>03JKSP20=AP9@@0]3/Q0`1o0PH00`000000JkKk07k1o00307k1o0<0PlKm
5`3oool00`000000oooo0?ooo`0e0?ooo`D0000000<0oooo0000003oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P37b=X20<G6f`80a<KL
0P2ma=l20;_3h0<0/;kU102I]N/207^VkP05056>j`0NKml07VoO0017a`0008404@3oool20??H/`<0
lmRd0P3bf;D20?7G]P80l=Nh00@0lM6`0?3A/P3`dK80l=6b0P3_dK@20>kA]P80kM:h0P3[c[P20>W>
^P<0j<nm00<0i/o00>7;`P3OblD00P3OblD00`3LblP0d/C=0=;4c@03000000050?>JC`3bV4/0lIE5
0?6EA@3`TCl00P3^SCP20>N1?080i7Xb00<0hG8V0=]W5`3EH0000P38CP000`2O7P00oooo0?ooo`03
0?ooo`0;0?g;J@3ebeX0mliP0?SBJ03jeW00nm]j0?cOQ03TkHX0j?>K0>[hZ`3Zn[X00P3XnlH00`3T
nM40goKJ0=offP030>7Xe`80f^GM0`3Bemd20<[Dh@80a/_N0P30bN420;_2g`@0/K_Q0`2/]^030:Ne
h`<0Y;CT00@000000:Bgi`2T]nL0Y;OW0`2S^>P30:FljP<0YKg[503oool00`000000oooo0?ooo`0R
0?ooo`008@3oool00`000000oooo0?ooo`020?ooo`800000503oool00`000000oooo0?ooo`0J0?oo
o`D0hmO;0P3Re//20>SB`0D0im;10`3Xckd20>O?_P80i]300P3Ud<430>?=``80hLk50`3Jb/X30=O;
c@@0al?F00D0[[KO0?6DA03`TCh0l94n0>j=>0020>b8<0030>V29`3VO1d000000080000000<0WS40
0?ooo`3oool01@3oool0103n`g80oM1^0?g@KP3ndW<20?kDN@060?kGO`3ofHD0omb<0?oLS03ngY<0
oN2K0P3lhZ820?[TZP030?SU/@3ei[T0mNJi0080l=Zj0P3/f/420>OJa`<0gLo;0P3Gcm420<o4d080
bLCE0`2o^]@30;2af@<0YJWJ00@0VZ?K0?2CB@3^ST80kXi20P3/R3T20=ihAP80fVhh0P3DH2D0102n
CcT0]3/Q0;@k8@2d>b43090O:@0307^bmP000000O;[j00@0Qkoi0`29`_XG0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool00P3oool2000001@0oooo00<000000<O8fP37b=X00P37b=X4
0<C6g0@0^l?P0`2]_^H309Vej`80NjK^0P1AS^/00`0MK]l004O70017a`0@0?ooo`<0lmRc0P3cf;@2
0?;H]@80lMNf0`3`ekP00`3_ekT0kmNj0>oG^P020>oA]080k]6f0`3]d[P0103/d[X0jLjj0>W>^P3Y
c[X20>S?_@80i/o00`3OblD0103LblP000000000000000020<k4d@80liY?00<0lYQ;0?6EA@3aUDD0
0P3[Rd/20>V7A@040>N1?03TNS80i7Xb0>5b9P80ffLG00@0deP30<M6002g>@00Wah0103oool01@3m
bfT0mL]J0?O>H03hdVP0n]I`0080g^Ei00<0i>f:0>[hZ`3Zn[X00P3XnlH00`3TnM40goKJ0=offP02
0=[bh@<0f^GM0P3BhN840<[Dh@@0`<WQ0`2f`N830;6kh@@0ZkSS0P2W]N<40:FgiP030000002T]nL0
Y;OW00@0YK_Y0P2U_>X40:Joja<0oooo0P00000S0?ooo`007@3oool4000000D0oooo00<000000?oo
o`3oool04@3oool409bik@<0RK3`0P1`Y?400`1ATnl0<H7X0?ooo`0B0?ooo`D0hmO;0`3Re//00`3R
e/X0im;10>OB`@040>OB`@80i];20P3Wckh20>K@`0<0iM3100<0i=330>?=``3Qc/D00P3Qc/D20=o>
a`<0el_=0P3Dbm420<O3eP80`l?J00<0lIA40?2A?P3`TCh00P3^SCP3000000040>5c4@3KJ@80c5`0
0<5>00L0oooo00D0oleh0?g@KP3md6h0o]9c0?kDN@020?kGO`060?oIQ@3og8`0o]jC0?kNT`3mh9/0
o>:R0P3ji:X20?SU/@80mNJi00<0lNK00>cJ`@3/f/400`3Wf/L00`3Rf/h0gLo;0=O?d@020=O?d@@0
bLCE102k^]T20;2af@@0Y:cM00<0VjON0>j>@P3^ST800P3/R3T00`3QOdl0gWQ60=ihAP020=Y^>003
0=AP9@2nCcT0_Tli0080]3/Q0`2@7bT00`26]_D0000008Jkn00208Jkn080Qkoi102<_oLE0?ooo`80
0000?@3oool4000000D0oooo00<000000?ooo`3oool04`3oool20<S9f`80alSJ0`37b=/40<;6g@<0
^L?R0`2]_^H309Bck080MZC^0P1=S>/00`0MK]l004[9000U[00?0?ooo`80k>?70P3cf;@30?;H]@80
lMNf0P3`ekP01@3_ekT0kmNj0>oG^P3_ekX0k]Jk00<0k]6f0P3]d[P20>cB^P80jm:l0P3Xckd30>K?
`0060>C@``00000000000000003LblP0fLc<0P3>a=401039`m@0liY?0?>JC`3bV4/30>b?D@030>^;
B`3YQdD0jHM50080ih4l0P3TNS801`3QLRH0ffLG0==H0`3CF0<0adH00;D^002100000`3oool20?G;
FP070?O>H03hdVP0n]I`0=kUN@3TkHX0j?>K0>[j^P020>SkaP030>Cid@3Om]X0f_;Q0080f_;Q0P3C
kND30=;QhP80bmcV1033dND40;[7i0<0]/7R0`2^_>@40:Vji@<0YkSU0P2U]nH010000000YK[X0:Fj
j02U^^P30:Fkj@<0Y[k[0`2V_n/B0?ooo`030000003oool0000002<0oooo000M0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03P3oool20;;2iP<0ZKkY0P2L^Nd408J_l080KZ?a00@0
DI?^0361j00EL>005G3P3`3oool30=CJg@80hmO;0`3Re//20>;FbP80h]G:0`3Wd/420>KB`P80i];3
0`3Vd<020>G@`@80i=330`3Qc/D20=o>a`80g/o:00@0el_=0=C;d@3Dbm40e<_A1033`mX00`3aU4@0
l94n00000002000000060>b8<03YPRL0jH8W0>Il7@3QLa40ffT20P31CP070?ooo`80oM1^00<0o]9c
0?kDN@3negl00P3ofHD00`3og8`0o]jC0?gPV`020?cRXP80n^BZ00<0n>Fa0?GV^@3ei[T00P3ai/00
103]iLH0im[70>OJa`3Wf/L20>;JcP@0eloA00<0dLkF0<W4e@39a=D00P34`mT30;^jf@<0[K?L0`2T
[=d309^WgP80k8Pi00<0hGm?0=ihAP3NN4H00P3JKSP40;i?>@@0T1lY0P26]_D010000000SK_e08fk
m@2=^oD208fmm`<0S;og5`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04@3oool40<S9f`@0alSK0P36b=`20<;6g@80`LKN0`2i`n830:Vmj0<0U;?/
0P1fY>h204f<j`0301a]gP00B/T002F/00d0oooo0`3/hlL20>_Ra`80jn370P3aekH20?3G^080kmNi
0P3_ekX20>kF^`80kMJl0P3]d[P20>cB^P<0jm:l00<0j]>n0>K?`03Vcl000`0000000`3Td<<0h]36
0=c;b0030=W<c080bL?D0P3cVTl01@3bV4/0kI9E0>b?D@3/Se40jh];0080jHM50P3WPC`20>Aj<P03
0>5b9P3KIaL0ffLG0080deP300<0adH00;D^002L40000`3oool01`3ebeX0mliP0?SBJ03Hg6T0g^Ei
0>C]RP2]lJ/00P33o]800`37o]l0b?_W0<Ofk0020<Ofk080dngU0`3=inT20<_LiP80a=SX0P33dND2
0;g>i`<0^/OT102b`>D30:bliP<0ZK[U102W^^L20:Jji`030000002U^^P0YK[X00@0Y[gZ0P2V_^/4
0:Noja@0oooo00<000000?ooo`3oool0803oool001h0oooo00<000000?ooo`3oool0103oool20000
00l0oooo102b`^H30:NnjP<0VKS]0P26[o0206jSl@80DI?^00@0<h;Y01E`h00EL>001FOK2`3oool4
0=CJg@80eMWK0`3Re//20>;FbPD0h]G:0P3Vd/830>KB``80iM;40P3Ud<430>C@``80i=740P3Oc/L3
0=k?bP<0e<_A0`3Abm@01@2m`Md00000000000000000l94n0080kXdh00P0k8P`0>V29`3YPRL0iW`M
0>5c4@3KJ@80ded00<Q?00P0oooo00D0oM1^0?kBL`3ne7T0o]Mo0?oIQ@020?oLS0050?kNT`3mh9/0
o>:R0?cRXP3ji:X00P3hiK400`3ei[T0lNK00?7V`0020>gUaP030>SUc@3Wf/L0im[70080h][>00<0
g=WC0=O?d@3Gcm400P3Ac]H40<C3f@@0][[L0`2]/m`30:>_h0<0W:_Q0P3QOdl30=ihAP030=Y^>034
GDT0_Tli0080_Tli0`2K=4401@2>]O40SKSc08fhl`2=^?<000000080SK_e0`2@_?@308jlmAL0oooo
00<000000?ooo`3oool0103oool500000340oooo00<000000?ooo`3oool0103oool200000180oooo
0`36bM`40<O9f`@0a/SL1031a]h40;O3h`80ZKgX102@/Nd2076Qk`0504V:jP0LKMh076gN001=b`00
4IL0303oool20>cSa`80jn;70`3[h<L00`3[glH0l=Nh0?3G^0020>oG^@<0kmNj0P3^e[/20>gF_004
0>cF_@3/d[X0k=:j0>cB^P80jm:l00@0j]>n00000000000000000`3Td<<20>;@aP<0fLc<0P3Fc=02
0<G3f0030?>JC`3]TUD0kI9E0080k8mA0P3[Rd/20>V7A@060>N1?03TNS80i7Xb0>Aj<P3QLRH0ffLG
0P3CF0<01P37AP00]Bh00;D^002L4000NP000?ooo`80mliP00H0n=9X0=kUN@3TkHX0[O6[0<?ndP37
o]l20<Ski`<0aoK/0P34l>l00`3=inT0an;/0<ORk0020<ORk0@0a=SX0`2mc^L40;G6iP@0[/3W0`2/
_>H30:Rki`<0Yk[W0`2V_>T00`000000Y[cY0:Jlj@040:Nnj`<0Yko[0`2W`>/D0?ooo`030000003o
ool0oooo00@0oooo1@00000F0?ooo`007P3oool4000000<0oooo00<000000?ooo`3oool0303oool4
0;O4i0<0/<;W0`2W_^X309NgkP80Pjk`0P1[XO42052BkP80<h;Y00<06gCR011^g`07K=d01`3oool4
0;OEl0<0eMWK0`3Ff=T30>;FbPH0h]G:0`3Vd/<40>GBa0<0i=330P3TdL@20>?AaP<0g/o:0`3Lcld2
0=7;e0<0000000<0_L7M0>f?C@3]Sdd00P3/S4P20>Z7@@030>R2>P3VO340iW`M0080hG<A00<0ffT2
0==M0038C`001`3oool20?kBL`030?kDN@3negl0omV50080omb<00@0oN2K0?cRXP3lhZ80n^BZ0P3h
iK400`3ei[T0lNK00?7V`0020>gUaP<0j>G=0P3Rf/h30=cId`80dLkF0P3<cMX20<C3f@80_l?M0`2f
^]`40:^dg`80XjoP0`2LZn4309V^i@80gWQ600<0fVhh0<AMB@34GDT00P2nCcT309/d@@80TkO`0`2B
^O800`000000TK_c096kl`03092lm0<0Sk[c5P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo03<0oooo100000030?ooo`030000003oool0oooo0100oooo1@36bM`20<O9f`<0alWL1035
b=d40;o6h0<0]<;U0`2V_>T2092ak@<0LJ7_00D0BH[Z01a]gP00CL/004g;000MXP0:0?ooo`80k>?7
0P3[h/L30>_Pa`80jmo60P3Zg/H0103ZgLH0kmNj0>oG^P3_ekX20>kF^`80kMJl0P3/e[d20>_F_P04
0>_B_00000000000000000<0jM?000<0imC20>C@``3Rd<H00P3Rd<H00`3PdLT0e/c@0=K<d0020=K<
d0030=;<e035`mP0aL?H0080kI9E0P3/Se420>^;B`80jHM50P3WPC`20>Aj<P030>5b9P3<Da/0c5<K
00<0`T4600<0/b/009h=002N3@000P1o00001P3gcV00oooo0000002]lJ/0R>_W09W_lP@0Xnkg00@0
a?3_0<7[l@31jo40`N_a0P2niO840<;Mk@@0_]CZ102hbnT30;74j0<0[/3W102Z_NL20:Rki`@0YkcY
0`2V_>T00`000000YkkZ0:NnjP030:Nnj`@0Yko[0P2W`>/D0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0603oool002D0oooo0P00000:0?ooo`@0^/GS102fa>@30;32i`<0YKg[0`2G
]nh208>^l080Jj7a0P1@T^h203F3j@05029hi00@K]l05WGR01IehP0OOnP00P1>XOH408O2n`@0_=G]
0`3Ff=T30=OHf0L0h]G:00<0h]C:0>KB``3Vd/<0103Ud/@20>CCa@80i=740`3SdLH20>7Bb0<0g<o=
0`0000030<g;f0030;O0h@3]Sdd0kHm=0080k8a80P3ZQd401P3XPSX0iW`a0>Il<@3RMBH0gV`I0=]Y
0P80ded000<0XR/00?ooo`3oool0103oool20?kBL`80o]Mo00@0omV50?oLS03dkiT0m?6S0P3dlj`0
1@3clkD0lOBm0?7d_@3_ll@0k?;;00<0kNG60P3XiLd20>?SdP<0g=WC0P3GemP40<c=fP@0_l?M0`2b
^n030:^dg`<0Xk;S0`2M[n@309V^i@0309B^j03JKSP0a5e90080a5e900@0_Tli09/d@@2K=440VcA1
0`2C]o0209Fjl@040000002C^_80Tk[b09>jlP<0TK[c0P2?^_<G0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0>@3oool2000000l0oooo1033b=h40<K9g0<0alWL0P36bM`20<G8g@80
`lSM0P2oa^020;g6h@<0]<;U0`2R^^X208^_kP<0K9k_00D0AHOY01a]gP00DLd0057=000MXP080?oo
o`80dN_W0P3[h/L30>_Pa`80jmo60P3Zg/H20>[MaP80jMc60`3^e[/20>gF_0030>cF_@3[e[h00000
008000000`3Zdkh20>WC`080imC20`3Rd<H20>3Ab@030=kBc03Fc=00e/c@00<0d/cD0`2o`M`20>b?
D@80jh];0P3YQdD20>N1?080i7Xb0P3BH2`20<aC6`<0`T4600H0/b/005d0001M0000G@000?SBJ03N
iGT200bAgP<0KmCk0P2YjoT40:gWn@80_^Gb0P2kgo820<;Mk@80_=S^102id>/20;S;j@80/lSZ0P2a
a>P40:c0j0<0Z[gW0`2X_NP30:Nlj@<0YkkZ00<000000:NnjP2W_^X01`2W_n/30:O0ja@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`009@3oool00`000000oooo0?ooo`07
0?ooo`<0_<KR102jaN<30;K4i0@0[l7X0P2U_N/409Bfk`80P:ga0P1YX?4204nBkP0403R4jP0RN>@0
8WST01Yeh`805WGR00<0<8[]04jQmP1>XOH0102Ba_T40<3EjP@0emSH0P3HemL50>;EbP<0h]C:103U
d/@30>CCa@040>CCaP3SdLH0hm760>?AaP<0hM;80`0000020=[@c`030=OAd`3=bmP0cL_H0080b<_L
0P3]Sdd20>b<B080jXM10P3XPSX0203VO340hWDV0=i/6@3NK1T0f6490<mB0038C`00YbL01P3oool0
0`3ne7T0o]Mo0?kGO`020?;/S`80m?6S00D0m?>/0??c]@3am;d0lOBm0>oca0020>cbb`80j?3A00@0
j>G=0>?SdP3Shm80hn?B0P3Nh]L30=OGf080dMGL0P3<cMX20<K;gP80_l?M0P2j`^020;:kh0@0ZKKR
0`2S/^<209f_i0@0Vk7W0`2H/^T209Jck0@0UkO^0`2F^Nl209Fjl@030000002C^_80Tk[b00@0T[Wb
0`2@^?8E0?ooo`030000003oool0oooo00D0oooo0P00000i0?ooo`030000003oool0oooo00d0oooo
0P2nb>820<?8gP80`lWN2@36bM`40<?8g@@0_LKQ0`2a`NH30::jjP80Rjo^0P1/W^l204F7j@0401]]
gP00DLd0057=000MXPD0oooo0`3AjnL20=CYi0<0enOQ0P3[glH20>[NaP80j]g60`3Yg<H20>WKaP80
kMJl0`0000000`3[e[h0jmK00>_F`0020>[G`@80jM?00`3We<820>KDa080h=790`3Nd/`30=;<e080
cL_H00@0_l7L0;W0g`2i`=l0k8mA0`3[Rd/20>V7A@040>N1?03GJcT0ef/i0=M[>@80dV0/0P3<Da/4
09D?00800`0000@0f]QR032Hl@0`V?40<9Sa0P1G^o/4093Jo`@0[n;h102kgo820;cHkP80^=C^0`2i
d>/40;?8jP<0[/?Y0`2/`>P40:Vnj@80Z;gX1`2W_^X00`000000Yko[0:Noj`030:Noj`L0Yl3[4`3o
ool00`000000oooo0?ooo`050?ooo`8000005`3oool002D0oooo00<000000?ooo`3oool01P3oool2
0;_6h`<0_<KR102jaN<40;G4i@<0[L7X0`2R_>`209Bfk`<0P:ga0P1YX?4204nBkP0503R4jP0WNnH0
9g_V01Yeh`0SO^L00`0`R^d205jYn0<0VlSg0P30eNX30<?Ei`<0f=OG0`3IemH30>;EbP@0h]C:0`3U
d/@20>CCa@80i=?60P3SdlL01@3Qd/P00000000000000000h=;:00<0f]3?0`3GdM<30<S;g080[kgT
0`3/S4P0103ZQd40j88j0>R2>P3VO3420>9e9P060=i/6@3HH@T0f6490<mB002j?000YbL01@3oool0
1`3ne7T0o]Mo0?3XQ@3bk8l0m>nI0?CaX`3dlj`00P3clkD0103am;d0ko?40>cbb`3/l//20>S`d@03
0>C^eP3Ok=X0gncJ00<0g^;G0P3Igm`40=7Eg0@0a/_N102j`^030:nkhP<0ZKKR102R]>D209jbiP<0
Vk7W102K]N/209Vfk0<0UkO^102H^^l209Njl0030000002E^_40UK[a00<0T[Wb102@]o4E0?ooo`80
00001`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo102nb>850<?9gP80
a/WL0P36bMd30<K9g080aLWM1032b=h40;_5hP80/L7V102M^N`208J]k`80Iic^00P0@XGY01]]gP0K
KMh005C@000l_P007Z4003Z_001de@@0O];o0P3DjN@30=OWh@80fNGN0P3Khm`30>[MaP80jMc60P3Y
flH3000000030>cF_@3[e[h0jmJn0080jmK00`3Zel40103Yel80imC20>OD`P3We<820>KDa080iMG7
0`3Nd/`20=_Bd0@0cL_H102i`=l30>^;B`80jHM500@0ih4l0=YbA03GJcT0ef/i0`3BH2`00`3<Da/0
YBLC0:DW4`0209D?00809`000P0gS^l304nXn0<0K/Cn0`2IfOd40:oMm`@0^=[b102he>h30;C<k0@0
[lK[0`2^`nT30:Zoj@<0ZKkY102W_^X60:Noj`030000002W`>/0Yl3[00T0Yl3[4`3oool2000000P0
oooo00<000000?ooo`3oool0503oool002@0oooo0`0000060?ooo`P0^lKS102iaN@30;C4iP<0[L7X
0`2P_>`3096dk`80OJ_a0P1VWo4204nAkP0403Z6jP0WNnH09g_V02AkiP808gkW0P10To4306b`n@80
VlSg0`33eNL30<KEi@<0fMOF0`3Je]@70>;DbP80i=?50P3TdlH20>?Ca`80000000@0hM;80>3BbP3P
d/X0h=;:0P3Odl`30=OAd`80e=7F1033b^030>b<B080jXM100@0j88j0>Il<@3VO340hWDV0P3NK1T2
0=QQ2@030<=1002b:`00YbL000@0oooo0P3dj8T20?;/S`80m?6S0P3clkD01@3am;d0ko?40>cbb`3/
l//0j?3A0080i>kF0`3Ok=X20=_YgP80fMoL0`3CgMl40<_Ch0<0`<WR102e`N<30:nkhP<0YkOU0`2R
]>D209jbiP@0WKGY0`2K]N/209Vfk0@0V[W^0`2H^^l309Njl0030000002F^O00U[W`00<0TkSa0`2@
]o4D0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0=03oool3000000X0oooo102h
a^D40;o8h@@0`lWN1036bMd50<G9g@80`/SN0P31b=l30;_5hP@0[/7W0P2M^N`208J]k`<0Iic^00P0
@XGY01]/gP00E=0005C@0013a000=;L003Jb001Ca@80TMWn102Qg?`30=WUgP<0fn?L0P3Lh]X20>WL
aP030>WKaP00000000000080jM_60`3Xf/H30>_F`080j]O10P3Yel820>SGa080i]C40`3UeLL0103S
e/T0fm;@0=_Bd03Kd]030=SCd`<0b<_L102a_N<209n`i080jHM50P3JLT@30=M[>@80dV0/102U9a<2
04@000030=7CF@14Rn`0DIgd0080DIgd0P1V/o/30838oP@0WmOk0`2_fOH40;CFl@@0/m3^0`2`bN`3
0:o6j`@0Zl;Z0`2Y_nX30:RnjPH0Yko[102W`>/00`000000Yl3[0:O0j`090:O0ja40oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`02
0?ooo`@0^LKT202ka^<20;W5i080^<GT0`2da>H40:_0j@80X;c/0`2>/o0207ZYl@0606BMl01?TNh0
Ci7^04nAkP0jQ^X0;WoX0P0TNnH20366j`0304nLm01i]_T0NKKi0080NKKi0`2Sbo@30<KEi@80bMGS
103Je]@20=[Fd`L0h]C:0P3TdlH300000080hmC80`3Pd/X20=oCc080gMC?0`3DdMH20=7BfP80`l[P
0P2lbN@20>b<B080jXM10P3XPSX0103VO340hWDV0>9e9P3NK1T20=QQ2@040<mB0033@@00/R/0090>
00<0oooo00<0m>R90?3XQ@3bk8l00P3dlJ<0103=o;/0doo60=Kod03Ho]L20=Slg080eoSP00@0e_GT
0=o/fP3Ok=X0gncJ0P3KjMh20=KVh@<0dmgO0P3=f^<20<_Ch080aM7S00<0`<WR0;_8i02kb>@00`2e
`N<40:bki@80YkOU102R]^L309nej080WKGY102L^>`309^ik@80V[W^102I^^l209Rjl0030000002F
^O00U[W`00@0TkS`0`2@]_4E0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
0000000g0?ooo`030000003oool0oooo00L0oooo102ba>P30;W6i0@0_lSQ1@33bMh80<G9g@@0`LSO
102iaN@30:_0j@<0VKO]0P21Znl206:IkP0803j3j00KK=h005OB001GdP00@l@003Bg001;``00JmL3
03RSm0@0[=kh0`3Khm`20=cRfP040=gQf00000000000000000<0jM_6103Xf/H20>OJa`80j]O10P3Y
el830>SGa0040>OHa@3UeLL0iMG70>GEa`80hmK90P3Qel`30=SCd`80e=?H00<0b<_L0<;:h@32b^40
0`2a_N<209n`i00308bRh`3MND`0fW940080fW940P3GJcT00`3BH2`0/3/X0;0k:0020:DW4`80A000
00<00000056;j@1HUnl00P1HUnl206FXmP<0N;[k0P2<bod40:?Dn@@0[mGd0`2bd_440;3<kP<0/<W/
0`2/a>/40:W1j`<0ZKoZ0`2X_n/30:Noj`H0Yl3[00<000000:O0j`2W`>/02P2W`>/C0?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000E0?ooo`006`3oool3000000H0oooo
00<000000?ooo`3oool01@3oool30;[6i0L0^lKS102haN@40;;3i`@0ZL3Z0P2M^nd308jcl080NZWa
0P1TWO0204jAkP0403f7j`0^OnP0;WoX02j1j@80?Hk^0P1?W?@207Vfn@@0Z/cb0`39eN<30<_Eh@<0
f]KC0`3Ke]840>;DbP<000000`3SdlL20>?Db080h]C:0P3Odl`30=gDc`80g=KA0`3Ad]X40;c9i080
VkO[0P3ZQd420>R2>P030>Il<@3RMBH0hWDV0080d5LG0P37B0@20<=100050;8[002K4000oooo0?oo
o`3`j8D00P3bk8l00`33mj`0cObk0=Kod0020=Sne`050=Slg03Gn>00eoSP0=Ohh03FmN@00`3ClNH0
103KjMh0e^KQ0=KVh@3Fi^420=7Si0@0cM[S1035dN<40;_8i0<0/L7U0`2/^nD30:Jii`<0X[KW102P
^>T209jhjP<0W;S/102L^^d209^jkP<0VK[_0`2H^^l00`000000U[W`09Jil00309>hl0@0T;K`5@3o
ool00`000000oooo0?ooo`020?ooo`<00000;P3oool3000000H0oooo00<000000?ooo`3oool01@3o
ool40:_2jP@0/lCW0`2ia^@40;o8h@<0`lWN0P34bMh40<G9g@@0a<WN102ob>440;O5i@<0Zl3Y0`2D
]^h207^Xl00405bFk@0nPnP0?X?X01]/gP8005OB00<004_9000o_@00Bl<00P00JmL205Bbn`D0]]od
00@0g>;J00000000000000000P3NgmH30=oNe0@0j=[60`3Wf/L0103WfLL0jMO20>WG`P3Yel820>SG
a080imS50P3Vf<L20>?Fb@80hMO<0P3Of=00103Hdm<0e=?H0=CCf03DdmP40<;:h@<0ZK_V0P2G[>D3
08NOh`030=YbA03GJcT0ef/i00@0/3/X0`1K00`00`000000H9C[062Dj`0306VQl@80MJof0`25__X2
09G;nP@0Y];g102^d_<40:o>l0<0[LW^0`2]a^d30:[2j`<0ZL7[1P2X_n/:0:O0j`030000002W`>/0
Yl3[00X0Yl3[4`3oool00`000000oooo0?ooo`020?ooo`<000005P3oool001X0oooo00<000000?oo
o`3oool00P0000050?ooo`8000001`3oool30;[6i0@0^lKS102ja^<40;O5i@<0/L?W0`2Y`>X309Zj
kP<0R[;`0P1gZ?4206:Ll00304jAkP0mQn/0?HO[0080=8?Y00<0>8O[03f>kP0mS^h00`1LXoD208Bj
n0@0/<k_0`3;eN430<kDg`<0fmKB0P3LeM8300000080h]C:0`3ReL/20>?Db0<0h]C:00@0hMG;0=gD
c`3Me<l0gMC?0P3Le]420=[Ge@@0cM?O102cb>T209^gj`80j88j0P3JKC<20=IS9P80d5LG0P37B0@0
2P2k=@00ZQ`00980002B0000OP000?3XQ@3bk8l0`oN/0<gl^`23j]/209Sbj0050:Kek`2`m?80/?Cb
0;3dlP3FmN@00`3ClNH00`3Ak^P0c^[Y0<kZj@030=7Si0<0cN3V0`38f>D40;o?iP@0]/KV0P2a`ND4
0:Vli`<0Y[WW0`2R^>P30:2hj@<0Wk[[0`2N^^`309bjk@<0W;_^0`2J^nl309Rjk`030000002F^O00
U[W`00<0TkS`0`2@]_0F0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool00P000005
0?ooo`800000103oool40:Fok0<0[<;Z0`2ca>L40;[6i0@0`<SQ1034bMh30<G9g@80aL[N0P34bMh2
0<?9g`80_lSQ0P2nb>830;O5i@@0Yko[0P2D]^h307^Xl00305bFk@0kPNL0>h7W008076gN0P00BlT2
001?b@<04h7U0P1/__h0102mgo4000000000000000020<?Nk@80g]oF0`3Og]@20=oMd`<0j=[60P3W
f/L40>OIa`80j=O40P3Wf<D20>KHa`80i]W90P3Qel`30=oHd0<0e=?H0P3@e=`40;_9i@80ZK_V0`2G
[>D208NOh`0307VEhP3GJcT0^4Th0080^4Th0P2`>bP205/03080J9?X0P1PU>/306VQl@80MJof102?
`OP309_;n0<0Z<oe102]c_840:g;k`80[LW^102[a>`20:[2j`@0Z<3[0`2X_n/=0:O0j`030000002W
`>/0Yl3[00X0Yl3[4`3oool00`000000oooo0?ooo`0J0?ooo`006P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool01`3oool40;[6i0@0^lKS102ja^@30;K5i@<0/L?W0`2V
_n/309ZjkP80R[;`0P1gZ?4306:Ll00404jAkP0oR>/0?hS[03Z6j`80>8O[0P1:U?4306VYmP<0S[kg
102ecnd30<kDg`80d=CM00@0g=GB00000000000000000P3LeM420>;DbPD0h]G;0`3Re<X20>7Eb`80
hMO=0P3Le]430=[Ge@030=SIf@3=dml0cM?O0080amCT102YaNh208jakP0507>Kj@3JKC<0fVdc0=Y]
<`3FHbH00`3@EaL01037B0@0^cD00;/e002Z7002098000050:GQQ@33mj`0Pn[K08?Zf`2Hl^P00P2V
mNl0102`m?80]_;d0;Kbm02fl_@20;[`m080dNkX0P3>j^T30<_Wj`<0cN3V0P38gNP01038f>D0`mGX
0<?Ej033eNP30;[<j0<0]/KV102^`>L30:Nlj0<0YK[X0P2R^>P40:6jj`<0Wk[[0`2O^nd309fkkP<0
W;_^0`2J^nl209Rjk`040000002F^O00U[W`09Jil0<0TkS`0`2@]_0E0?ooo`030000003oool0oooo
0340oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00D0oooo0`2V`>`3
0:c2jP@0]<GW102kan<40<38h@@0a<WN1035b]h40<?9g`@0_/SR102daNL30:>mk080Sk?_0`1eYO00
0`1GT^d0>h7W03^1i`0201a]gP06001Cc`00C<T004o9001?b@08LMl0;i?`0`0000001020a_h0`mk]
0<?Nk@33g^d20<ONj@<0gmkD0`3OgM<20>3LdP80im[7103WfLL20>KIb0<0imS500D0i]S70>KIb@3V
fLT0i]W90>GJb`030=oHd0<0gMWC0P3@e=`30<[EhP<0/LOZ0P2O]nT308nXi`80PIcT0P1gU>83076@
h@0406j?hP1VS^@0IXkT06J>i080J9?X0`1^W>d207NXl@<0P[Gf0`2F`oH30:3;mP@0Z<gc0`2[bo43
0:g;k`<0ZlK]102Y`^`30:S1ja80Yl3[00<000000:O0j`2W`>/02P2W`>/C0?ooo`030000003oool0
oooo01X0oooo000J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`@0^/KT102ka^<20;[6i080^LKT0`2faND40:o3j080Y[o[0`2G^Nl208N`
l@80LjKa0`1OVo00101>T>d0?hS[03n8j`0jQ^/2046<k@80BYCa0P1YZOH409O1m@80]Lo]0P2jcnX2
0=3Dg@<000000P3LeM820=cEd@80gMG@1P3ReL/20>;Fb`80hMG;0P3Qeld20>3Hc`<0f]OE0`3HfMT2
0<ODi080_mGZ0`2YaNh208jakP<0Li_Y00<0fVdc0=IS9P3FHbH00P3@EaL409P=0080P@0000@0]^jJ
001SeP00L]P007;H0P0fZ_8307kKo@80^_3d0`2mk?<20;kYl`<0bnO[0P38hn/40<SMj0<0`mGX0P2n
d^T20;[<j0@0//GX102[_nT20:Nlj0@0Y;_Y0`2R^^X20:6jj`@0X;c/0P2O^nd409jlkP<0W;c^0P2J
^nl309Rjk`040000002F^O00U[W`09Jil080TkS`0`2@]_0F0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
0`2V`>`40:g2j@<0]LGV0P2kan<20;c7h`80`<SQ0P31b>050<C9gP@0aL[N1033b^040;c8h`<0/LCX
0`2S_N`208nck`80MJG`0P1GT^d203QniP0401e]gP06G]H005??001Hd@<0000000<0B:7f093<o02@
c?`00P2@c?`30<ONj@<0bmgV0`3OgM<20>3LdP80hMcA103WfLL30>KIb080i][800@0i]S70>KIb@3V
fLT0i]W90P3Uf//20>CKc@<0gMWC0P3JfmP30<[EhP80`mKX0P2aanX309ngj@80SjSW0P21W>@307ND
hP80LI3Q0P1^Sn8306nCi@80LY[Y0`1iXnd208:^l@<0S;Wd0P2F`oH40:?9m0@0ZL_a0P2[bo440:_8
kP<0ZLC]0`2Y`^`40:S0ja80Yl3[00<000000:O0j`2W`>/02P2W`>/C0?ooo`030000003oool0oooo
01T0oooo000J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`<0^/KT102ka^<40;W6i0@0]LGV102]`nT20:Bnk0<0UkW_0P27/?4207>Vl@80
Gi_`0P1>T>d204>:k003046:k011S>d0@Hc]00<0EI_b0P1d[_H209O1m@<0^/oZ0`000000103@e=d0
dMCK0=7Df`3Ae=/20=cEd@D0gMG@0`3ReL/20>;Fb`80h]K<0P3Qeld20>3Hc`<0gm[A0`3HfMT20=GL
g@@0_mGZ0`2J`O<207jYk`<0IY?X00<0Dh7Q0=IS9P2Y9P@00`2Y9P@209P=000500/0000>H=L03V3G
01]bh@0FN^@00`0LS>X205Fkn`@0Vn3m00<0_^Wc0;kVlP2ni_800P2ni_830<SSj`80aN3/1034f^X4
0;kBj@@0]/[Y0`2^`nT30:^oj@<0Y[gY0`2T^nT40::lj`80XKc/102P_Nd309nmkP80W[c^102L_>h2
09Zkk`<0V;[_00@0000009Jil02F^O00U[W`0P2C^?03092flAD0oooo0P00000a0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`@0Yl3[0`2_
`nT30;G5iP@0_<OS1031b>030<C9gP80a<[N0P35b]h20<C:g`80`l[P0P32b^440;_8i@80/LCX102N
_>h208Val080KZ7`0P1ASn`00`0dO>D07FgN000000020000008005SA00@036gN0261j018XOH0B:7f
102McoT30<_MiP<0cmgS0P3Pg=830>7Ld@030>7Kd03Rfll0h]_?00<0i]W80P3Vf/P20>KJb@80i]_:
0P3Uf//20>CKc@80h]g@0`3JfmP20=ONg@@0`mKX0`2Ua>l309Bbk080QZ?W0P1lVN<307JCh@80Li7Q
0P1dTn<206nCi@80LY[Y0`1iXnd208:^l@@0U;cc0`2La?@30:G8lP<0ZL_a0`2Zb>l40:W5kP<0ZLC]
0`2X`N`30:S0ja<0Yl3[00<000000:O0j`2W`>/02P2W`>/A0?ooo`<000006P3oool001/0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00X0oooo102ja^@40;[7i0@0^LKU
0`2daNL30:g3j@<0XKk]0`2C]o0208>_l@<0L:Ca00@0GIW_04j@k@1>T>d0AX_/0`11R^`0101:TNl0
H:3c062Pl`1PX?<207jcmP0409k4l`0000000000000000<0_]3X0`3Ae=/20=?DfPH0gMG@0P3Ne/l2
0>;Fb`<0h]K<00<0h]O=0>3Hc`3Pf<l00`3Of]420=kLd`80eMcM0`3@gn<40;CFlP80V/7c0`1nZNl2
06JCj080Dh7Q00<0B7KL0:TV102Y9P@00P2Y9P@202eXf@0402m_g@0TKml06g;Q01]bh@80=8g^0P0m
WoD306k5o`030:CPn`2ZgoT0Z]oi0080Z]oi102nho420<GPk0<0`]g]0`2oen/40;W?j`@0//S[0P2^
`nT40:RojP80Y[gY102T_>/30::lj`<0X[g]0`2P_Nd409nmkP80W[g^0`2L_>h309Zkk`<0V;[_00<0
000009Jil02F^O000`2C^?43092glAD0oooo00<000000?ooo`3oool0<03oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0203oool40:S0j`80[l?Y102faNH40;c7h`@0`LWP
1034b]h40<C:g`<0`/[Q0P31b^830;_8i@@0[/CZ0P2N_>h308:^l@80Iig_0`00000201m]gP0300eR
f000F]<01F?I008036gN00@0>8o_05n]nP1O[OX0Gjgj102Wd_H30<oMh`80dMcQ0`3Qg=400`3Qfm00
h]_?0>;Kc`030>;Kc`80i][80P3Vf/T20>KKbP80iMc;0P3Tfld30>;Md080hMoC0P3Gg]d30=;Rh`<0
^=O`0`2Ua>l209Bbk080QZ?W0`1lVN<207JCh@80Li7Q0`1dTn<207NHi@80O9oY0`23ZNd308^bl080
U;cc102Pa?830:K7l@<0ZLS`102Ya^h20:W5kP@0Z<7/6@2W`>/00`000000Yl3[0:O0j`090:O0ja<0
oooo00<000000?ooo`3oool0603oool001/0oooo0P0000020?ooo`040000003oool0oooo0?ooo`80
00003P3oool40;[6i0@0^/OT0`2ha^D30;C5i`@0Zl;Z0P2Q_^d3092fl080Ojga0`1]X_40101KV>l0
CY3]04j@k@16Rn`304N=k@0305>Fl01PX?<0H:3c00<000000`2Ua_040<;@i@<0dmCJ0`3De=P30=gE
d0@0g]K?0`3Re/`01@3Reld0h]W=0>;Ic@3RfLd0h][?00<0g]cC0P3MgmL20=cTf`@0b^G[0`2Re_X3
08Bjn080JYk_00<0EhWV05>1h@1CPN400P18M]`01@12LMX0>FgI03U]f@0iKMT0>G3L0080;foM00<0
>GgU03B3j@0dSNh00P0dSNh205R^nP@0Sm3n102_gOL40;kPl@<0`]g]0P2of^d40;_Dk0<0]Lg/0`2b
b>/30:_2j`@0Yko[0`2U_N/20:Blj`@0Xkg/0P2R_Nd40:2nkP<0Wkg^0`2M_Nl309blk`<0V[__0P2H
^o0010000000U[[`09Jjl02F^_0209>hl@<0T;Oa5P3oool00`000000oooo0?ooo`0_0?ooo`800000
0P3oool010000000oooo0?ooo`3oool2000000/0oooo0`2X`>/40;33j0<0]lGU0P2lan<20;g7hP80
`LWP0`32bN040<C:g`@0a<_O1031b^840;W8iP<0Z/?/0`2I^^l30000000406NMk`1;Rn/0Bh_[039j
i0807fgN00@04fKK00ESf@05HmT087[U0`0hSnl207:fn`@0/=Cc0`3Ag>430=CLgP030>7Kd03Rfll0
h]_?00<0h]_?0P3Sflh30>KJb@050>KKbP3Ug</0iMc;0>GLb`3UgL`00`3RgM020>7Od`80gn?G0`3B
h^<20<[Wj`@0Y]Si0P2D_o@208J[k@80OIgW0`1hUN8207JAh080Mi;P0P1jU^8207NHi@<0O9oY0P23
ZNd409>fk`80V[ka102Sa?020:K7l@@0Z<K_102X`nd20:S2k1`0Yl3[00<000000:O0j`2W`>/02P2W
`>/C0?ooo`030000003oool0oooo01L0oooo000L0?ooo`<00000103oool00`000000oooo0?ooo`0>
0?ooo`80^/KT1P2jan@30;S6i@@0/lGX0`2Y`^/309jmkP80T;K`0P1o[O4206fRl@80FiS_0P1>T>d0
0`19SN`0Ahg]04N=k@0300000080JZGc0P28]o@40:c8kP@0aM7S0`3De=P30=KDe`D0g]K?0P3Oe/h0
103Reld0h]W=0>;Ic@3RfLd20>;Jc`80h]g@0P3MgmL20=cTf`80fN_Q0P2mjo<309W]m`<0Nm3o0P1Q
[?T00`1@Sn`0EhWV05N9iP0204ajgP0304McfP12LMX0@W7J0080@W7J0P0iL=`00`10N^40>GgU03Um
i@0204^@kP80CYcd0`1^^?`409WBn`<0/]cf102mgO030;oJk@80_=O^102gdNd20;G=k0@0[/K[0`2Y
`N/30:Noj`@0YKk/0P2T_^`40:>ok@<0X[k^0P2P_^h409nnkP80WKg_102L_Nl309Zll080V;_`00@0
000009Fjl@2E^_40UK[a0`2C^O4208nglAH0oooo00<000000?ooo`3oool0;`3oool3000000@0oooo
00<000000?ooo`3oool02`3oool40:W1jP<0/L?W0`2gaND40;g7hP<0`/WP0P33bMl20<C:g`<0a<_O
1034bn030;o;h`@0]/SX0P2Z`n`30000000309:hl@1jZ_40NZ[a0080GiW_00@0AHOY039ji00bN^@0
8FkN0P0CI]/0100EJM`05VkO021ji@0PN^D204fKm0<0P[gj102heNl30=CLgP80e]_L0P3HfmX20>;K
c`D0hm_>00@0i]_:0>GLb`3Ug</0iMc;0P3UgL`20>GOcP040>7Od`3OhmL0gn?G0=oSe`80gNSL0P3:
in/30;W^m0@0Om?o0P1j]oT207FRk@80M9KU0P1hUN8207JAh0<0Mi;P0P1jU^8207nLi@<0QJCY0P2<
[N`309>fk`@0Wko`0P2Sa?040:O6k`H0Z<?]7`2W`>/00`000000Yl3[0:O0j`0:0:O0ja<0oooo00<0
00000?ooo`3oool05P3oool002<0oooo00<000000?ooo`3oool03`3oool70;[7i0@0]lOV102aaNT2
0:W2j`@0Vkc_0P2<]?4207ZZl@80JJ3`0P1IU^h01@1?T>d00000000000000000CY3^0080G9_a0`1d
Z_<3092jl`<0/LW/0P35dN<30<SAh@<0e]CG0P3He=D30=kFc`80gmK>0P3Pelh20>7HcP80h][?0P3R
gM020>;PdP80g>CK0P3Ijn420=7ei`80]?_R103oool201nVh@0402J>k@1@Sn`0D8o/04Mmh@80C7[N
0P17LmX204Mbf@80@W7J00<0AWSN041jh@10N^400P1=RNT204^@kP<0I:Sg0P1o_o`40:7Cn@@0]=_d
0`2lfo030;cGkP80^MC^0`2gdNd40;7:k@<0ZlC/0`2Y`N/30:Jok0<0YKk/0`2T`>d30:>ok@@0XKo^
0P2P_^h409jnk`80WKk_0`2L_Nl409Zll080V;_`00<0000009Fjl@2E^_40102B^O4208nglQD0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0=0?ooo`<0Zl7Z0`2a`nL40;S6i0@0_/SR
1033bMl30<C;g`80aL_O0P34bn020<?<h@@0_/_T00@0/lSZ00000000000000000P2U`^h209:hl@80
NZ[a0`1OVNl01@15QnT0<7SS025^gP0QK]h06V[M00805FWL00<09WST03>6j`0cQ^/00P1PYOH30933
n0@0_]K/0`3Ffm`20=SKfP80f][H1@3Sflh20>?Kc@80i=c=0P3UgL`20>GOcP80iN;@0P3UiM820=gX
g080f?3R0P39nnL00`20in`0oooo0?ooo`020?ooo`03002A_`1j]oT0N[Oi00<0MJ;]0P1dU^D207F@
h080N93N0P1lTml207ZFhP<0OicU0`2=ZNP209Baj`<0V[W^102S`Nh20:G4k`@0Z<C^0P2X`ndS0:O0
j`030000002W`>/0Yl3[00T0Yl3[4`3oool00`000000oooo0?ooo`0F0?ooo`008`3oool200000140
oooo202jan@40;O7iP80/LGY102W`Nd209^lk`80S;Ca0`1jZ_4206VPl080000000D0Ci3]04f>k01=
S^`0CHk/05BDkP0205bKl@80M:[c102H_O430;79k0<0b=7Q0P3;dMl30=SDe@<0fMGD00@0gmK>0>3G
cP3Pelh0h=O>0P3Qf<h20>;JcP80h]g@0P3Rh=820>?Ue080h^gG0P3AmNL00`2dnn80oooo0?ooo`07
0?ooo`05001:]00_N^@0AggQ04Mmh@15LmX00`17LmX204Mbf@0304aff`16N=h0AWSN0080D8?T0P1=
RNT205nLl@<0M[7g0P2=a?X40:OCm`@0]]Wb102jfNl30;WDkP@0/lk^102^and20:_4k0@0Yl3/0P2V
_n`40:C1k@<0Y<3]0`2R`>h30:6okP<0X;o_0`2N_^l309fnl0<0Vkg`0`2J_?0309Nll@030000002E
^_40UK[a00<0T[Wa0P2?]o8F0?ooo`030000003oool0oooo03D0oooo0P00000?0?ooo`<0Zl7Z102b
a>L30;W6i0@0_lSQ1033b]l40<G;g`<0`lcQ0P33cN820;k;i08000000`2cb>X30:31l0<0RkGb00H0
LZKa05NDk@1GU>d0EiC]03n3i`0`N><202=_g`0401YZg@0QL>008G3P02Ihi080AY3_0P1PYOH409c7
mP@0`mKX0P3HfmX30=[Jf080fm[F0P3Sflh20>?Kc@80i=c=0P3TgLd20>GOcP80iN;@0P3UiM820>C[
e@030=S`hP39nnL0bO_W00T0oooo0P16X_H3066CjP0306f;g`1eT>00MI3P00<0N93N0P1lTml2086I
h@<0Qj3T0P2=ZNP309Baj`<0Wk_]0`2S`Nh30:O3kRT0Yl3[00<000000:O0j`2W`>/02@2W`>/C0?oo
o`030000003oool0oooo01D0oooo000S0?ooo`030000003oool0oooo0180oooo102kan@30;[8i@80
]lOV0P2fanL30:o5jP<0Y<7^0`2G^_0208NblP<0000000@0IIg`05NDkP1GU>h0D8o/0P1=S^`205BD
kP80IIoa0`1m[_<209Rml@@0]/[Y0`3;dMl30<kBg0<0fMGD0P3JeM<20=cFdP80hMS>0`3Rf/h00`3S
g<l0h^3B0>;PdP020>?Ue080h^gG0P3OmmX00`3:oll0oooo0?ooo`0:0?ooo`040;0U000iKm/0>FoK
04EcfP80B77G0P17L]T204aff`80E7oO0P1@Pn@0101OTn/0Gica05nLl@1OW?4308BhmP<0UlOh0`2/
do@40;KHl@@0^=O_102fd^l30;3;kP@0ZlG]0P2Y`^`40:K2k@<0YL7]0`2T`^h30:?1kP<0X/7_0`2Q
`>l309o0k`<0W[o`0`2M__0309^nl0<0VKg`0P2G_?4010000000UK_a09Fkl@2E^o4309:ilP80SkSb
5P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00h0oooo102/`NT40;C4iP030;W6
i02ka^<0^lKS0080_lSQ0P30bN420<?:g`<0a<_O1035c=l20<?=hP<000000`2mc>H30;38k0<0X<7`
0`22/_<00`1XX?40EiC]05NDk@0203n3i`0402ifhP0SKml08foO029^gP808G3P00<0=H7X04J@k`16
T>l00P1a[_L40:K:l`@0amOU0`3Jf]P20=_JeP80gM[D0`3Sfld01@3Tg<d0i=g=0>CMc@3TgLd0iMo>
0080iN;@0P3UiM820>C[e@030>;df03DomH0e?oF00`0oooo0`1QTnX206f;g`80MH[J0P1lSMT207bC
g`80PIWQ102?Xn8209F/iP<0VkCZ0`2T_N/30:K1kB/0Yl3[00<000000:O0j`2W`>/02P2W`>/B0?oo
o`8000005P3oool002<0oooo00<000000?ooo`3oool04`3oool20;_7i080^lST0`2jb>D40;K7i`<0
[/G[0`2T`Nh01@2B^O400000000000000000PZob0080L:Ga00<0HI[_05NDkP1GU>h00`1@Sn`00`1A
T>d0FiO^05^GkP0206jSl@<0Q[7b0`2O_nl40;_;i`<0c];L0P3@d]/30=[Ed`80g=KB0P3Mem430>;J
cP80hmc?0P3Tgll0103Ui=00h^gG0>;]e`3OmmX20<[oc`h0oooo00@01e_D03U_f`0iKm/0@fcE0P18
LML0101>LmP0C7KK04aff`1<M]/205Aog`03062<i@1OTn/0Gi?[00<0LJGa0P24^?H40:3:mP@0/=?c
0`2ge_040;ODk`@0//o_0`2]b>h30:_5k@@0YlC^0P2V`^d40:G3kP80Y<;^102S`Nl20:;1k`@0X<3_
0`2O`>l309jol0<0W;k`0P2K__0409Vml@80Ukca00<0000009Fkl@2E^o40102B^_8208jhlQ@0oooo
0P00000f0?ooo`030000003oool0oooo0100oooo0`2^`^P30;C4iP@0^lKS1030bN460<C;g`040<G=
h00000000000000000<0`/gS102kcNP40:c8k`80VKob0P22/_<206RPl@80Chk/00@0>WkU02ifhP0^
M^809W3O0P0RK]h00`0]Mn<0=H7X03F1j00205NJl@<0OkCf102^c>l40<cGhP80fm[F0P3Mf]@30=kK
d`040>CLc@3TgLd0i=g=0>CMc@80iMo>00<0i^7>0>OUc`3WiLl00P3TjmD00`3Rm=P0e?oF08_EOP0>
0?ooo`80N6Ve0P1]Rml307F:fP80O8gI0P23Tm/208VJgP<0Sj?R0P2E[>H40:6fj0<0Y;g[;P2W`>/0
0`000000Yl3[0:O0j`090:O0ja40oooo00<000000?ooo`0000005P3oool00280oooo0`00000E0?oo
o`@0^lST0`2ib>H40;C7j0<0ZlG/0`00000209:il@<0PZob0P1`YO42066Jk`0505JBk@1ASn`0DHo/
056?k01ET^d00P1KUnh206jSl@80Q[7b102V`^d40;o<i0<0d=;K0`3Cd]T20=cFdP<0gMOA0P3Of=02
0>?Lc`80i=o?0P3Ui=00103Wj]40ioC@0>Odd03Lo/H?0?ooo`801e_D00@0<63A04=/e@13K=D0CFoC
0P1>LmP205MkfP80E7oO0P1PS>D206nLk0<0P:ga0`2A_O@30:O<l`@0/m?a102feO030;CCl0@0[lc_
0P2]b>h40:S5kP@0Y/G_0P2U`nl40:C3k`80Xl;_102R`^l20:71k`@0X<7`0`2O`?0209jol0@0W;o`
0P2K__4309Vml@<0Ukcb00<0000009BklP2D^o800`2B^_8308jhla@0oooo0P00000d0?ooo`<00000
4P3oool30:k2j0@0]LCU102lan<40<79h080a<_O0`0000001035cN00aLkQ0<G>h@35c^440<;?i0@0
^<kZ0`2Vb?83096mm00307R]m01MV_00GI[`0080AHOY00D0>WkU02ech@0VL=l09W3O02Ybh00202eg
h`80AH[[0P1WX_8308fjm080[/c_0P2fc^`20<cGhP80cmOO0P3Mf]@30=kKd`80gm_A0P3Qg=020>GO
cP050>KQcP3WiLl0inG?0>OUc`3Xjm000P3Xlm0@0?ooo`<0N6Ve0P22Ij/208E][`80O8gI0P23Tm/3
08VJgP<0V9oI0`2M[>820:6fj380Yl3[00<000000:O0j`2W`>/02@2W`>/B0?ooo`8000005@3oool0
0280oooo00<000000?ooo`3oool05P3oool40;_8i0@0^LWV0P2cb>T3000000040:_5k02L_o40W;oa
09bol@<0SKOb0P1l[O8206^Rl@80GIO^00<0E97/056?k01ASn`00P1ET^d206:Jk`80MZK`0`2>]?03
0:c3j`80_lcT0`33cN830=?Bf@80eM?G0`3Mem420=oHd080hM[?0P3Tgll20>GTd0040>OZd@3Wm=00
ioC@0;[YSA40oooo00@003Fl031Pd@0`H=40@fcE0P1=Km<0101HMM@0Eg_J05MkfP1GNmX206:6g`04
06nCi@1_W>`0Kic/06nLk0<0SK?`0`2K`O840:c=l@<0]MC`102fe?040;7Al080[lc_102Zanl30:O6
k`<0Y/G_0`2Ua>l30:C3k`@0Xl;`0P2R`^l40:71l080X<7`102N`?0209fol0<0W;o`0`2J__4309Vm
l@<0U[gb00<0000009BklP2D^o800`2A^_<208jhla40oooo0`0000000`3oool000000?ooo`0c0?oo
o`030000003oool0oooo01<0oooo102_`^P30;O5i@@0_LOR0P32b^03000000<0aLcO0`35c^430<K?
h@<0`M3V102fcnd20:K8lP@0Q[[g00<0JZKd05fJl01MV_000P15QnT01@0dNN<0;G?Q02]ag`0[LMl0
:W;P0080>GkV0P15R^/206NRlP80SK[d102fc^`30<oGg`80d]OL0P3Ef=X30=oKd@80hMc@0P3SgLl0
1@3VhLh0inG?0>OUc`3WiLl0j>_@0080j??@00<0/>F80?ooo`3oool03`3oool207QY]@80PVN[0`25
KJl208Uf^080SX?30`2CTLh209ROfCP0Yl3[00<000000:O0j`2W`>/02@2W`>/>0?ooo`<0000000<0
oooo0000003oool0503oool001P0oooo0`0000070?ooo`030000003oool0oooo01P0oooo102kbND0
102ibNL000000000000000030;;8j`<0Z<G^0P2L_o4308Ndl`80MJWc00<0IIg`05fGkP1MUnh00P1D
TN`205>?k00305ZCk01RV^l0HY[_00<0MZK`0`2F]nl30:c3j`<0`lgR0P37c]l30=GCe`<0f=CE0P3O
f=030>7Jc`040>?LcP3Vh<h0i^3>0>OZd@80ioC@00<0j_[30?ooo`3oool0403oool0102:DXP003Fl
031Pd@17ILd204e_d`80F7GD0P1TOmP206:6g`<0Ki?U0P1nXn/208fcl0@0Y<C`102acnl40;KDl0<0
]=Kb102]co420:_:l0@0Z<O`0P2Wa^l40:G5l0<0Y<C`0`2S`o040:;3l080X/;`102P`O0209o1l0<0
W/3`0`2M`?4309bol@<0V[ka0`2H__8209JmlP040000002D_?80U;cb09BllP<0TK[c0P2>^O<<0?oo
o`@00000103oool00`000000oooo0?ooo`0X0?ooo`<000001`3oool00`000000oooo0?ooo`0D0?oo
o`@0/L;W0`2haN@20;g7hP<0000000@0`/[P0<?:g`33b]l0`l[O1036cMl30<K?h@80a]7R00@0`M3V
0<3Bj030d^P0`=;X102adO4209k8m@80Q[[g0P1ZY_@2052BkP0403^0iP0dNN<0=7WS02ebg`80:g7O
00<0<gOR03UniP0iO^H00P1DT^d207JYlP<0V;kb102lcnP20=;Gg0<0eMSJ0P3Hf=P20>7Ld0<0hmg?
00@0iMo?0>ORcP3Wh/h0j>_@0P3Xlm000`3Yn/@0oooo0?ooo`0@0?ooo`80N6Ve0P22Ij/308E][`80
RGJh0`2>Pl<209>AcSX0Yl3[00<000000:O0j`2W`>/02@2W`>/:0?ooo`@00000103oool00`000000
oooo0?ooo`0C0?ooo`005`3oool01@000000oooo0?ooo`3oool0000000H0oooo0P00000J0?ooo`04
0;_9i@000000000000000080^LWW0P2hb^P20;;8j`@0YLG`0P2G__8208Ndl`<0MJWc0P1UWO000`1I
U>d0Dho[05>?j`0205F?j`80FY?/0P1YWNh207jYk`<0U[O_0`2baNP30<O>g`<0blkL0`3He=D20=[E
d`<0hM[?00D0hmc>0>KPcP3Vh<h0i^3>0>SUc@020>c^ba<0oooo0P2:DXP0100jDl40AfG=04MUc@1H
KL`305Qee080I7oH0P1aRmd307jJh`80S:WY0`2H]nd30:_7kP@0]M7^102ffO830:oDl`<0[Loa0`2X
bO440:K7l0<0Y/K`0`2TaO030:C4l0<0Xl?`0`2R`o030:72l0<0X<7`0`2O`O0309k0l0<0WL3a0`2L
_o4209Znl@@0V;kb0P2F_O800`000000U;cb09BllP04096kl`80SKWd203oool3000000P0oooo00<0
00000?ooo`3oool09`3oool01@000000oooo0?ooo`3oool0000000H0oooo0P00000F0?ooo`80/L;W
0P2b`^H0102haN@000000000000000030;o8h@<0`l[O0P35bml40<O>g`@0a]7R0`30d^P30;kFj`<0
ZmCf0P2CaoT307Jdn@0505VNl`11R>/0>h3V03^0iP0`M>400P0]L]l00`0`L]l0<gOR03=ghP0204J5
j00406:IkP1fZO80MZWb07JYlP<0X/;_1032d>D30=GHfP80f=SH0P3KfMD30>?Mc`030>GOc`3Wh/h0
in;>0080jNO=00<0jno<0>Wja03oool04`3oool00`1hJKD0PVN[089WZ`0308E][`80RGJh0`2>Pl<m
0:O0j`030000002W`>/0Yl3[00T0Yl3[1P3oool3000000P0oooo00<000000?ooo`3oool04`3oool0
01L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01L0oooo0`0000030;_:i@@0^<[X102`bNd30:75lP<0TKcd0P1o/O@206fUlP80GYW_00<0E93/05>?
j`1CSn/00P1ESn/205nEk080LIo^0P26[>h309fjk0@0^<KU0`3;c]`20<k?fP<0f]GC0`3Me]401@3S
g<h0i^3>0>KPcP3Vh<h0j>G=0080k>k;00<0j_[30?ooo`3oool04@3oool208YBR080>U?100<0AfG=
05Q]c01HKL`00P1VM/h206Aof0<0LH_M0P1nV^<208bYj@@0Xk_Z0`2bbN`20;GAkP80^=Wa102bgOH3
0:[>l`<0ZLcb102Wb?420:K7l0@0YLG`0`2Ta?030:?4l0<0X/?`0`2R`_030:72l0<0X<;`0P2O`O04
09k1l@80WL3a102K_o4309ZolP80V;kb0`2F_O800`000000Tkcc09>ll`03096kl`80SKWd1@3oool3
000000`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool05P3oool0102b`^H000000000000000040;[5h`@0`<SQ0P35
bml20<K<g`80alkO0`38d>040<KCi0030;kFj`2lf^l0_=[_0080_=[_102Peo/20875o@80H:ci00<0
@i7`0468j`0aMn<00P0`M>40100^L=h0<7;O031bg`0mNn<304J5j080HYW^0P23[o440:c5k0@0am7R
0P3Hf=P30=_Ie@80gM[C00<0iMo?0>ORcP3Wh/h00P3Yild00`3[kl`0jO[40>Wja00E0?ooo`80PVN[
0`25KJm30:O0j`030000002W`>/0Yl3[00T0Yl3[0P3oool3000000`0oooo00<000000?ooo`3oool0
4P3oool001`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`<00000103o
ool40;c;iP@0]lcY102]bnl20:75lP<0RK[f0P1e[OD00`1SWo80GYW_05jIk`0205B@k080DXgZ00<0
F8oZ05nEk01OUN`00`1aWnh208J/kP<0Y;cZ0P2ha^D20;g7hP@0c/oJ0P3Bd=L30=gFd@80gmS?0P3S
f/d01@3XiLd0k>k;0>c^b`3Zn/<0iNf:01<0oooo0`2:DXP00`0jDl40FUnm05Q]c00205Q]c080IWK>
0P1cPM<3082?f080SIkO0`2H[ND30:bmiP<0//W/0P2hfO430;CZm`<0Zm7d0`2Zc_<30:O9lP@0Y/Oa
0P2Ua_440:C5l080Y<C`102S`o020:;3l0@0X/;`0P2Q`_040:32l080Wl7a102N`O4309g0l@80Vkoa
102J_o8209RnlP<0U[gb00<0000009>ll`2C_?<00`2@^o<208fim0040?ooo`0000000000000000l0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0
oooo0`000000103oool0]<?U0;C3i@2d`nD40;c6hP@0`/WP1036c=l30<S@h0<0bM;Q0P36e^H30<KK
j0@0]n3d0`2:f?l206:mo@0503fLm013TO00@i7`02mki@0aMn<00P0[Kmh00`0^L=h0=WCO03Idg`02
03ekh`80Dh_Y0P1`Wnh308ndk`<0]<OX103<d]h30=_Ie@80gM[C0P3Pfm40103Tg/l0jNO=0>WWc@3[
kl`20>Wja1H0oooo0P22Ij]70:O0j`030000002W`>/0Yl3[00T0Yl3[00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0B0?ooo`00603oool4000000D0oooo00<000000?ooo`3oool04P3oool3
000000T0oooo102lc>L30;K=j`@0Z/cb0P2KaOD208VjmP80MJge0`1SWo80101FTnh0D8cZ05:=jP1B
SNX205R?jP80IIK[0`1hX^`208j_k0<0Y;cZ0P2man820<;8g`80c/oJ0P3Bd=L20=K@e0<0gmS?0P3S
f/d20>ONb`80k>G800<0l>o30?ooo`3oool04P3oool408YBR080FUnm0P1/J;d206IfcP80Lh7C0`20
SmP208fNg`@0Y:oO0P2/_NH40;S@k0030;CZm`2/eOH0[=Gf0080[=Gf0`2XcO<30:S;lP<0Y/Sa0`2V
ao430:G5l@@0Y<C`0P2Sa?040:?3l080X/?`1P2Q`_030:32l0@0Wl7a0P2N`O4409g0l@80Vkoa102J
_o8209RnlP80U[gc00@0000009>ll`2C_?<0Tkcc0`2@^o@208fjm180oooo00<000000?ooo`3oool0
9`3oool4000000D0oooo00<000000?ooo`3oool04P3oool3000000D0oooo0`2f`n@20;c6hP80_LKQ
0P32bN030<C:g`@0b<kN0`39d^420<_EhP<0a]_X0P36h^`40:cXnP@0E<[a0P0mW?@0100TOnP0;g_U
02mki@0VK]h202]_gP03031^g00fM=l0=WCO0080AgoT00<0H97Y072OkP1`Wnh0102J^>`00`2danP0
^lSU0;_8i@020<cBgP<0d=?K00@0gM[C0>3Kd@3Pfm40h=_A0P3Tg/l01@3WhLd0jnO:0>_WbP3_l/@0
gONS01H0ooooB@2W`>/00`000000Yl3[0:O0j`090:O0ja00oooo00<000000?ooo`3oool04P3oool0
01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`<000003@3oool40;c>
j0@0]M3^102Uc_D209;5n080OKOh00D0J:Oe05RHl01HV?00F9S`04j=j`02052<jP0305::j01KSnT0
FhoY0080IIK[0P1hX^`309JajP<0ZkgW1032b=l20=;@e`<0e]3D0P3IdM420>?Jc@80imk;0P3/iLP0
0`3`kl<0iNf:0?ooo`0C0?ooo`@0RU:80P1JGkd306aX_@80N7?100<0Q7o608n>cP2?S/h00P2?S/h2
09ZNe`<0Y:oO102d^mh0102_mnh0[=[g0:cJm`2/f_L40:S?m080Z<gc102VbO830:G7l@<0YLKa102T
aO020:C4l0@0XlC`0P2S`o040:;3l0H0XL;`0P2P`_0409o1l@80W/7a102M`?4209_0l@<0V[ob0`2H
__8209Jml`030000002C_?<0Tkcc00@0T;_d0P2=^_@A0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`<000002@3oool30;K3i0@0_LKQ0`34
b]l20<G;gP@0bLoN0`3;eN830<cIh`040<KRk033kO40`nga0<?]l@80/oO^00<000000?ooo`3oool0
103oool00`06ON4006CH001Tf00202I^gP0402QYfP0`K]`0<6kL03ifg`80AgoT0P1PTNT307fUk080
V[S/102kb>D30=3Cf`80eMCH0P3IeM@20>CNc`050>OQc@3[ilX0jnO:0>oba03Mmj<04P3ooom?0:O0
j`030000002W`>/0Yl3[00T0Yl3[3`3oool00`000000oooo0?ooo`0B0?ooo`006@3oool00`000000
oooo0?ooo`050?ooo`8000003P3oool200000180oooo102ldNT40;?Cl@<0WM3j0P26`o`206fbn@03
05ROm01HV?00F9S`0080CXg[0P1<QnP00`1BR>L0FhoY05^?j@0206bHjP80P:C[0`2F/NX40;6nh`<0
a/SK0`3Fd=@20=WAd@80gM?>0P3Wg//20>cUb0030?3_``3ejKT0oooo01@0oooo1P2:DXP00`1JGkd0
K6Rm06aX_@0207Qc`@80Q7o60`2?S/h309ZNe`<0ZI_70P2d^mh30:gOn@@0ZM;e0`2Wc?<30:O:lPH0
YLOa0`2TaO440:C4l080XlC`102S`o020:;3l0@0X/;`1P2Q`_020:31l0<0Wl7a0`2N`O4309g0l@<0
Vl3b0`2J_o8209RnlP<0U[kc00<0000009>ml`2C_O<00`2@^o@308fjm100oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`050?ooo`8000003P3oool2000000d0oooo102h`n<40;o7h080
aL_N0`38c=d40<cBgP040<cIh`3>h>D0c^3U0<kPi@<0d>WW00D0/oO^0:chbP3oool0oooo00000007
0?ooo`8006CH00@076?H02QYfP0XJMX0=6gK0P0nM]l205>4h`0306fFj029ZNX0RJWZ0080RJWZ0`2T
^nT30<;:h@<0eMCH0P3IeM@20=gFd@040>OQc@3[ilX0jnO:0>_WbP80m?2h403ooomB0:O0j`030000
002W`>/0Yl3[00T0Yl3[3P3oool00`000000oooo0?ooo`0B0?ooo`006@3oool4000000@0oooo00<0
00000?ooo`3oool02P3oool3000001H0oooo0`2le>`40:oHm@80WM3j0`1`_oh00`1DZ?P0F9od05RO
m00204V?kP0304B5j01<QnP0C8OX0080DXSW0P1PS^L00`1bVNP0P:C[082Tj`0409jci`80/KkS0P2h
_n001036b=/0blWH0<_9f03;bMP20=WAd@<0gM?>0P3QeL/0103Wf<L0kMk20>gN`P3ejKTE0?ooo`L0
RU:80P1/J;d207Qc`@<0Q7o60P2?S/h409al[`80ZI_70`2/i_X30:WDm`@0Ylgd0P2Wc?<40:K8lPH0
YLKa0`2TaO030:C4l0<0XlC`0`2S`o030:;3l0<0X/;`1P2Q`_030:31l0<0Wl7a0`2N`O4309g0l@80
Vl3b102J_o8209RnlP80U[kc00@0000009Jnl`2C_O<0Tkgc0`2A_?@208fjm100oooo00<000000?oo
o`3oool0:03oool4000000@0oooo00<000000?ooo`3oool02P3oool300000100oooo102ja>440<;8
g`<0b<cM0`3;c]`20<kFgP<0d]_O0P3@jNL0103>n>L0[?S:0:chbP3_[hP30?ooo`030000003oool0
oooo00D0oooo00@003fk00=Hd`0LHmP09fCF0P0dKM/01017N=h0DhCS05>4h`1CQ><206fFj080RJWZ
102^_ND40<S;g080fMGD0`3Me]401@3Rf<d0imc90>OLb@3^hl@0m?2h00l0ooooE02W`>/00`000000
Yl3[0:O0j`090:O0j`h0oooo00<000000?ooo`3oool04P3oool00240oooo00<000000?ooo`3oool0
1`3oool3000001X0oooo102lf^l40:ONnP<0Jlol00@0AK;g05BXn01DZ?P0@I;`0P0hPnT01014QNP0
B8;U04R2i@1DQN@3062>i`0407:Ij028YNP0R:GX08RUj080W[?W102h_n030<_9f080d<WD0`3Mdlh2
0>7Eb`80imS700<0kMk20?GY^@3ng9D05@3oool708YBR0<0RU>900<0ReF<08eKTP2=Fi800P2=Fi82
099WW0<0W7b_00<0ZI_70:W/n@2Yf?P00`2Yf?P30:O?m0@0Y/[c0P2VbO840:G7l@80YLKa102TaO06
0:C4l0H0Xl?`1P2R`_060:72l0<0X<7`0`2O`O4209k1l@@0WL3a0P2K`?8409ZolP80V;ob0P2F__<0
10000000U;gc09Bml`2D_O<3096lm080SK_d403oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00L0oooo0`00000D0?ooo`80^/CQ0P2la>020<;8g`<0a<SM0`3;c]`20<k@g0<0d]_O0P3F
hn020=[_h0030=OneP3_/Xh0kjn800@0oooo00<000000?ooo`3oool01@3oool01000?K/00eSC01=G
d@0WI=H203Y/f00404MhgP1OQn80GhOR05n7hP80NY[U0P2E[>H20:jmi@80][kP0P38bm`20<k<f0<0
gMKA00@0h]S=0>OLb@3Wg<T0k^?40P3dl;P:0?oooeX0Yl3[00<000000:O0j`2W`>/02@2W`>/=0?oo
o`030000003oool0oooo0180oooo000P0?ooo`8000001P3oool3000001l0oooo0`2jh_<20;;^m`80
C/cE103oool202^Dk`04021ni`0hPnT0>8?Y03]ki080B8;U00D0E8GT06F>i01US^@0IHkT07ZIi@03
092Wi@<0YKCS102m_m/20=39e0<0e<[@0P3QeL/20>OHa`80kMk200<0mNVi0?kLU@3oool0503oool7
08YBR0<0RU>90P2;EH`308eKTP80TVNL0`2LO:l00`2YgoX0Ym;f0:OBmP020:OBmP80Ym3e102Vbo<3
0:G8lP<0YLOa0`2Ua_430:G5l0D0Y<C`2P2S`o060:;2l0H0XL;`0P2P`O0409o1l080W/7a102M`?42
09c0l@<0V[ob0`2H_o8209Jnl`030000002D_O<0U;gc00@0TKcd0P2>^oD?0?ooo`030000003oool0
oooo02h0oooo0P0000060?ooo`<00000603oool40;c4h0<0a<SM0P37bM`30<k@g0<0dMCK0P3Fhn02
0=[_h0040>;m_P3el[00kk:>0>n_R0D0oooo00<000000?ooo`3oool01@3oool01000@L@04eOA01=G
d@0YG]4203Y/f003059if`1OQn80GhOR0080NY[U0`2E[>H30;Jnh0<0c/cH0`3Cc=<20>;Hc@050>OL
b@3^hl@0k^?40?C`^03hfj`0203ooomM0:O0j`030000002W`>/0Yl3[00T0Yl3[303oool00`000000
oooo0?ooo`0B0?ooo`00803oool00`000000oooo0?ooo`020?ooo`<000008`3oool20;;^m`80R^gR
203oool00`00J/h005oC02=ch@0203]ki080AWcQ00<0Eh;Q06F>i01US^@00P1jVND2092Wi@@0[;CN
0P2m_m/20<>oe`<0e<[@0P3Ib//20>OHa`80kMk200<0mNVi0?7>[P2;DXL05@3oool708YBR0<0RU>9
0P2;EH`308eKTP80TVNL0P2LO:l30:ODm`@0Y/gd0P2Vc?<40:K8lP80YLSb102Ua_430:G5l0T0Y<C`
0`2S`nl30:?3l0<0Xl;_1P2R`_020:72l0@0XL7`0P2P`O0409o1l080W/7a0`2M`?4309c0l@<0V[ob
0`2I_o8209Nnl`030000002D_O<0U;gc00<0TKcd0`2>^oD>0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool00P3oool3000001d0oooo0`2oa=h30<O9g0<0bl_J0`3Ae=/20=OIfP80f^oP
00D0iNoD0>;m_P3/]YT0kk:>0>n_R0060?ooo`030000003oool0oooo00D0oooo00D0047400i;b00Y
G]40:EkA04=[e002059if`80K8_O0P27WN430:2_hP@0_[oK0`3Cc=<20=S=cP060>OLb@3^hl@0k^?4
0?C`^03hfj`0Re:71P3ooomP0:O0j`030000002W`>/0Yl3[00T0Yl3[303oool00`000000oooo0?oo
o`0A0?ooo`00803oool00`000000oooo00000002000003@0oooo00<005oC02=ch@0aL=h00P16O>42
05N2h@80K8gQ0P22VN4209RWh0<0[;CN0`33_mL20<Rnd@040=C:d03Ib//0fL[;0=W:b`80gL[500D0
hlZo0>W;^03YbkP0lLj^08]BQ`0E0?ooo`L0RU:80`2:DhT208]ES0<0SE^B0P2BIi`00`2LO:l0YmOh
0:OGn0040:K>m@80Y/gd102VbO830:G7l@80YLKa1P2UaO060:C4l0@0Y<?_1P2S`nl20:?2k`@0X/;_
0P2R`_030:72l0<0XL7`0`2P`O0309o1l0<0W/7a0`2M`?4309c0l@<0V[ob0P2I_o8209Nnl`040000
002G__<0U;gc09Bml`<0TKcd0P2>^oD>0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`00
00000P00000Q0?ooo`@0`/CL0`3;bmX20<k=f0<0emWJ0P3Mh]P01P3Ukm@0h_fn0000003/]YT0kk:>
0>n_R0L0oooo00<000000?ooo`3oool01@3oool200i;b00402UNd@13Jm@0@f_D05ike`80K8_O0`27
WN430:Z`g080_[oK0P35_m@40=S=cP050=k=b03Tc/80i<k20>_A^P3hfj`00P3ooomU0:O0j`030000
002W`>/0Yl3[00T0Yl3[303oool00`000000oooo0?ooo`0A0?ooo`00803oool2000003P0oooo00@0
02f[035`gP0aL=h0AGGL0P1GP^4206b=h@<0PYWQ0P2HYn040;>cf@<0b;kA0`3Ib//20=g:a@80hlZo
00@0jL^h0?7>[P3ng9D0Re:75@3oool708YBR0<0RU>90P2;EH`308eKTP80TVNL00@0YmWi0:K@m@2V
d?D0Y]3e102Vbo<20:K:lPH0YLOa102UaO030:G4l0<0Y<C`2@2T`nl20:?3k`H0Xl;_1P2R`^l40:;1
l080XL7`0`2P`O0309o1l0<0W/7`0`2M`?4209c0l@@0Vkob0P2I_o8209Nnl`040000002E__<0UKkc
09Fnl`<0T[gd0P2>^oD=0?ooo`030000003oool0oooo02h0oooo0P00000U0?ooo`80`/CL0`35aMT2
0<k=f0<0dloE0P3Mh]P01`3Ukm@0kN?60>gSaP3X^jH0kk:>0?ooo`3_[hP0203oool00`000000oooo
0?ooo`040?ooo`03000?X00@@Kh03T_80080@f_D0P1NNmL207V<fP<0TioL0P2Z/=`40<Foe0040<^n
cP3HcLh0f<g>0=k=b080i<k20P3[dKX00`3hfj`0Yl3[0:O0j`1V0:O0j`030000002W`>/0Yl3[00T0
Yl3[2`3oool00`000000oooo0?ooo`0A0?ooo`008@3oool00`000000oooo0?ooo`0g0?ooo`04000]
Z`0XHmH0AGGL04Eeg080FgkK00<0Lh_K08^Hf`2;V=/00P2;V=/20:2VfP80/k?I0P2i/]801038_]40
cKg;0<fmb`3=_L/20=g:a@80hlZo0P3YbkP00`3acZh0o]bE08]BQ`0E0?ooo`L0RU:80`2:DhT208]E
S0<0SE^B0P2BIi`20:KAmP@0Y/_c0`2Vb?420:G7l@@0YLK`0P2UaO060:G4l0@0YL?_1P2T`nl50:C2
k`X0Xl;_0P2R`^l40:;1k`80XL7`0P2P`O0409o1l080W/7`102N`?4209c0l@@0Vkoa0P2I_o8209Nn
l`040000002E__<0UKkc09Fnl`<0T[gd0P2?_?@<0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0903oool30<G5f@80bLGF0`3CcmD20=WCdP80h]W>00D0kN?60?Gb/03X^jH0kk:>0>n_
R00:0?ooo`030000003oool0oooo00@0oooo00@0df<00111_P0`FL/0CfW>0`1NNmL207V<fP80TioL
0`2c/=D20<Foe0<0bkk>0P3NcLP20>C>`P030>_A^P3hfj`0Re:706T0Yl3[00<000000:O0j`2W`>/0
2@2W`>/:0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003oool0oooo0080oooo0`00
00080?ooo`800000>03oool01000@/D0:6?F04I]e@16KMD205]nf`0407>;f`2;V=/0RiSK08^Hf`80
X:KJ102i/]830<fmb`80dK[40`3Sb[l01@3YbkP0lLj^0?7>[P3ng9D0Re:701D0oooo1`2:DXP308YC
R@80ReF<0`2=Fi82099WW0030:K=m02Vc?@0Y/cd00@0Y/Sb0P2Vb?440:G6l0D0YLC`102Ua>l60:G3
k`80Y<?_2@2T`^l90:?2k`H0X/7_0`2Q`Nl20:71l0@0X<7`0P2O`O0409k0l@80WL3a0`2K_o4309Zo
lP80V;kb00<0000009Fnl`2E__<0102C_O@208nlm0/0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`020?ooo`<00000203oool2000002D0oooo0`39aMH30<k5dP80fM?B0P3RfLh20>gS
aP040>RkYP3/]YT0kk:>0>n_R0/0oooo0P0000040?ooo`05000?X00@@Kh0446n031Ib`1?JLh00P1/
Nm0207V<fP<0WYkD0`2c/=D30<^ncP80d;c60P3Tc/820>_A^P030?SK[02;DXL0Yl3[06T0Yl3[00<0
00000:O0j`2W`>/02@2W`>/90?ooo`030000003oool0oooo0140oooo000B0?ooo`050000003oool0
oooo0?ooo`0000000P3oool2000000T0oooo00<000000?ooo`3oool0=P3oool01@00@/D095G;04I]
e@16KMD0HW[D0080Lh_K0P2;V=/30:NTd`80^K;B0P2n[l/0103=_L/0dK[40=6ja03A^/@20=Bf^`80
jL^h0P3acZh208]BQaD0oooo1`2:DXP308YCR@80ReF<0`2=Fi800`2BIi`0Y/gd0:K=m0030:K9lPH0
YLK`102UaO020:G4l0H0YLC_0`2U`nl40:G2kP80Y<;_102T`^h20:C2k`<0Y<;^2@2S`^l60:;1k`<0
XL7_0`2Q`O020:31l0<0Wl7`0`2N`?4309g0l@<0Vkoa0`2J_o800`2H_o80000009RolP0209Jnl`<0
Tkgd0`2@_?@;0?ooo`030000003oool0oooo01l0oooo00D000000?ooo`3oool0oooo000000020?oo
o`8000002@3oool00`000000oooo0?ooo`0T0?ooo`<0c/GB0P3Ba<`30>;IcP060>gSaP3S_k<0j;^V
0>bfV@3_/Xh0kjn83@3oool00`000000oooo0?ooo`020?ooo`03000?X00@@Kh0?EG20080CfW>0P1/
Nm0208J=d`<0WYkD0`2j[/d40=2laP060=Bg_@3[dKX0jm6j0>_A^P3hfj`0Re:7JP2W`>/00`000000
Yl3[0:O0j`090:O0j`T0oooo00<000000?ooo`3oool04@3oool00180oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=@3oool0102D4`00
95G;02AEb`1<IL/2069je080O8OD0P2CU]<30:NTd`<0_Zo;0`3A^/@30=Bf^`040=F^/@3acZh0lLj^
0?7>[P80Re:75@3oool708YBR0<0RU>90P2;EH`308eKTP04099WW02VbO80Y/Wb0:K9lP@0Y/Ka1@2U
aO060:G4k`H0YL?_2@2U`^h<0:C2kP80Xl;_102S`Nl60:;1k`H0XL7_0P2P`O0309o1l0<0W/3`0`2M
`?4309bol@80V[ob0P2I_o8010000000VKob09Jnl`2F__<309>mm0<0TKcd2P3oool00`000000oooo
0?ooo`0O0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo02@0oooo00@0c/GB0=;4c03Ba<`0d/C<0P3H`lH01`3]hlH0hknc0>>o/`3X^jH0
k;JI0>nbSP3_[hP03P3oool01P000000oooo0?ooo`3oool000nP01li/P80?EG200<0GVO406akd01/
Nm000P26SM<40:NLb`030;Z^c@30ZL<0`:W30080d;c60P3D]kd20=F_/P030?SK[02;DXL0Re:706/0
Yl3[00<000000:O0j`2W`>/02@2W`>/80?ooo`030000003oool0oooo0140oooo000C0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0e0?ooo`05
000S[`0TEL/0C6G;04aUb`1[M<X00P1lQm@209>Fd`@0[J3:00<0_Zo;0<:Z`@32Z/400P3A^/@20=Bf
^`80eJja0P3AXJH00`2nQYP0Re:70?ooo`0E0?ooo`L0RU:80`2:DhT208]ES0<0SE^B00<0TVNL0:K7
l@2Vao400P2Vao440:K5l080YLG`1P2Ua>l30:G3kPl0YL;^2@2T`^h30:C1kPH0Xl7^0P2S`Nl60:;1
k`@0XL7_0P2P`O030:30l0<0W/3`0P2M`?4409c0l@80Vkob0P2I_o8010000000VKob09Nnl`2G__<3
09Bml`80TKcd2P3oool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0S0?ooo`<0d/C<0P3H`lH20=g2_@060>>o/`3X
^jH0j;^V0?ooo`3_/Xh0kjn83`3oool010000000oooo0?ooo`0019<201li/P0303eE`P1NIl@0GVO4
0080NWW60P2BRlP30:NLb`@0`:W30P3D]kd30=F_/P030<fLY02;DXL0Re:706`0Yl3[00<000000:O0
j`2W`>/0202W`>/90?ooo`030000003oool0oooo0100oooo000C0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`040009V@0XAkd0C6G;
04aUb`80JgC:0P24PlT209ZAb@<0[J3:1032Z/430=Bf^`80eJja0P3AXJH00`2nQYP0Re:70?ooo`0C
0?ooo`030000001103`0RU:800H0RU:80`2:DhT208]ES0<0SE^B0`2Vao440:K5l0D0Y/C_102V`nh2
0:G3kQD0YL;^0P2T`^h:0:C1kPD0Xl7^1P2R`Nl60:71k`80X<3`102O`?0209k0l0@0WL3a0P2K_o42
09VolP040000002G__80Ukkb09NnlP80U;gc0`2A_?@90?ooo`030000003oool0oooo0200oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02@0oooo
0P3H`lH30=g2_@060>>o/`3X^jH0j;^V0>bfV@3_/Xh0kjn8403oool00`000000oooo0004T`0201li
/P0304mB]@1NIl@0GVO40080NWW60`2BRlP00`2WW</0[YNo0:jG_`020<2Y``80`j:g00<0e;Nm0=F_
/P3E[k800P3=W:@208]BQfd0Yl3[00<000000:O0j`2W`>/0202W`>/80?ooo`030000003oool0oooo
0100oooo000C0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?oo
o`800000=03oool0103;D`00j84R02Q7_@1<IL/206]dbP<0Q8?90P2JTLT00`2]X<X0/YZo0;:J_`03
0<:Z`@040<BR]`3D][/0eJja0=F^/@<0dJ6V00<0_XJH08]BQ`3oool04@3oool010000000C@A=04d4
C@1103`708YBR0<0RU>90P2;EH`308eKTP@0Y/G`1P2Va>l40:K3kPD0Y/;^4P2U`^h30:G1kP`0Y<7^
1@2S`Nh30:?1k`H0X/7_0`2Q`Nl20:30l0@0Wl3`0P2N`?0309g0l@<0Vkoa00<0V[ob0000002H__80
0`2H__8209Fnl`<0T[gd203oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`0:0?ooo`8000009@3oool30=g2_@80hknc00D0j;^V0>bfV@3_
/Xh0kk:>0>n_R00A0?ooo`040000003oool000BC01li/P80Ce:e00<0KVBg07YiaP1jNLH00`2BRlP3
0:jG_`040<2Y``33X[L0`j:g0<>R]`<0eJnb0P3=W:@208]BQfd0Yl3[00<000000:O0j`2W`>/0202W
`>/80?ooo`030000003oool0oooo0100oooo000B0?ooo`<000000P3oool200000080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0b0?ooo`030009V@0XAkd0Eebl0080JgC:0`24PlT2
09ZAb@@0/YZo00<0`Z[10<BR]`34X[L00`3E[[430=6QYP030;j6V02;DXL0oooo00h0oooo00@0L>3B
05DAFP1E4EX0EA5J0P1=14d00`1103`0RU:808YBR00508YBR0<0RU>90`2;EH`208eKTPH0Y/C_1@2V
`nh:0:K2kPP0YL;^0`2U`^d30:G1k@<0YL7^0`2U`Nd60:G1kPP0Y<7^1P2S`Nh30:;1kP<0X/7_0P2Q
`Nl30:30k`<0Wl3`0`2N`?0309g0l@<0W;oa00<0V[ob0000002H__800P2H__8309Jnl`<0Tkgd1`3o
ool00`000000oooo0?ooo`0O0?ooo`<000000P3oool200000080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0S0?ooo`80gL:m00@0hknc0>RkYP3X^jH0k;JI0P3_/Xh00`3_[hP0oooo
0?ooo`0@0?ooo`030:O0j`0019<0?CVS0080Ce:e0P1^I;L208Ie^@<0VhJl0P2^Ukl40<>R]`030<2D
Z@3E[k80cIbT0080cIbT0P2;DXM^0:O0j`030000002W`>/0Yl3[00P0Yl3[1`3oool00`000000oooo
0?ooo`0@0?ooo`00503oool010000000oooo0?ooo`3oool300000100oooo00<000000?ooo`3oool0
<`3oool0100XAkd0Eebl07E]_01eKK`308al_080X8^m0`2bV[l30<BR]`030<:GZ`3E[[40eJja0080
dJ6V0P2nQYP00`2;DXL0oooo0?ooo`0:0?ooo`0405cB^`0U00<0G1]S05`KH`<0EA5J0P1=14d00`0L
06`0RU:808YBR00508YBR0<0RU>90`2;EH`208eKTP<0Y/C_102V`nh50:K2kP@0Y/;]0P2V`^h60:K2
k@<0Y/7]4P2U`Nd20:G1kPT0Y<7^1P2S`Nh20:;1kP@0X/7_0P2Q`Nl30:70k`<0X<3`0`2O`?0309g0
l080W;oa0P2K_o4010000000VKkb09VnlP2I__8209Jnl`@0U;gc1`3oool00`000000oooo0?ooo`0P
0?ooo`040000003oool0oooo0?ooo`<00000403oool00`000000oooo0?ooo`0S0?ooo`80hknc0P3X
^jH0103/]YT0kk:>0>nbSP3_[hP>0?ooo`D0Yl3[00@000BC03diX`1?D[D0Ce:e0P1^I;L208Ie^@<0
VhJl00<0[YNo0;6>/P2aS[800P33X[L20<2DZ@040=F_/P3=W:@0cIbT0<fLY080Re:7K`2W`>/00`00
0000Yl3[0:O0j`080:O0j`H0oooo00<000000?ooo`3oool0403oool002`0oooo00<000000?ooo`3o
ool0<@3oool00`002IT0>Cf[05ML_00207E]_0<0S7bl0P2PRkd20;:J_`80]96b00@0a::g0<:GZ`32
Uj/0`YN[0`3AXJH20;j6V00308]BQ`3oool0oooo00P0oooo00@0000003H0700f01`0H29Z0P1L6f<2
05DAFP80C@A=0P0L06`708YBR0<0RU>90`2;EH`208eKTP@0Y/?^1P2V`^h<0:K2k@`0Y/7]4@2U`Nd8
0:C1kPH0Xl7^102R`Nh20:;0k`<0XL3_0`2P`>l209o0l0<0W/3`0`2L_o400`2K_o40000009^ol@03
09VolP80Ukkc102D_O<60?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool08`3oool3
0>RkYP040>bfV@3_/Xh0kk:>0>n_R0`0oooo1`2W`>/0100M5h`0?CVS03diX`1?D[D206iT]`<0QWFi
0P2KQ[`40;6>/P030<>R]`30U:T0`9BY00<0cIbT0`2;DXM_0:O0j`030000002W`>/0Yl3[00T0Yl3[
1@3oool00`000000oooo0?ooo`0@0?ooo`00;@3oool200000340oooo00@000B;03TmZ`0i?J/0Eebl
0P1eKK`208al_080X8^m102dTK801@34X[L0`YN[0<:GZ`32Uj/0^XJM0080dJ6V00<0_XJH08]BQ`2;
DXL0203oool010000000@`0`04<0<00f01`2060RJP80G1]S0P1E4EX0101=14d06P1[01`0K00L06`7
08YBR0<0RU>90`2;EH`208eKTPH0Y/;^2`2V`^dA0:K1kA40YL7]102T`Nd50:C1kPH0Xl7^0`2R`Nh3
0:;0k`H0XL3_0P2O`?0309k0l0<0WKoa00<0Vkoa0000002J_o800`2J_o8209NnlP<0U;gc1P3oool0
0`000000oooo0?ooo`0i0?ooo`8000009@3oool20>bfV@80kk:>00<0kjn80?ooo`3oool01P3oool;
0:O0j`0401dGS00m>J<0?CVS06E@Y@80KVBg0`26MKT30:5m[@<0/Hjb0`30U:T00`2bOIT0cIbT0<fL
Y00308]BQg00Yl3[00<000000:O0j`2W`>/0202W`>/50?ooo`030000003oool0oooo0100oooo000_
0?ooo`030000003oool0oooo02h0oooo00@000B;03TmZ`0i?J/0IEF[0P1eKK`208al_0<0Xh6_0`2d
TK830<:GZ`80^XJM00<0dJ6V0;j6V02nQYP00P2;DXL60?ooo`040000001=03l0C@0o04<0<080I2Q_
0P1P8VX205`KH`80EA5J0P0J06/201`0K0L0RU:80`2:DhT308]ES080SE^B00<0Y/;]0:K2kP2V`^h0
2P2V`^dJ0:K1kA40YL7]202T`Nh30:?1kP<0Xl3^0`2R`>h60:70k`80X<3_0`2O`?0309fol00309bo
l@000000V[oa00<0V[oa0P2H__8209Fml`H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0S0?ooo`040>bfV@3_/Xh0kk:>0>n_R0H0oooo3@2W`>/00`0M5h`0?CVS03diX`0206E@Y@03
07ePYP2@KjT0T6nY0080T6nY0P2QOJd30;6>/P040:n1X`30U:T0`9BY0;9mV@80cIbT0`2;DXMa0:O0
j`030000002W`>/0Yl3[0080Yl3[2`3oool00`000000oooo0?ooo`0?0?ooo`00<03oool00`000000
oooo0?ooo`0]0?ooo`030004R`2QHhT0>Cf[0080IEF[0P1oIJ/2099c[@80Xh6_0P2dTK820;65Y@80
`YN[0P2jQYd00`3AXJH0_XJH0;j6V00208]BQ`040?ooo`0F00005P0000<000<0E@Q<00<0C@0o04<0
<01W;G<00P1T:6l2060RJP80G1]S00@0EA5J01X0J`0J06/06P1[0P0L06`708YBR0<0RU>90`2;EH`0
0`2=Fi80Y/;]0:K2k@040:K2k@<0Y/7]0P2V`^dP0:K1k@l0YL7]1@2T`Nd30:C1kPH0Xl3^0`2R`>h2
0:;0k`<0XL3_0`2P`>l209o0l0@0W[o`00<0W;oa0000002K_o400P2K_o4309VnlP80U[kc1@3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0280oooo0`3_/Xh00`3_[hP0oooo0:O0j`0A
0:O0j`807AN<00<0?CVS06E@Y@1UD:D00P1mH:H3091_Z@80XGf]0P2aS[820:n1X`050<2DZ@2bOIT0
/WfI0;9mV@3=W:@00`2;DXMb0:O0j`030000002W`>/0oooo00`0oooo00<000000?ooo`3oool03`3o
ool00340oooo00<000000?ooo`3oool0;03oool00`0018/0XF>903TmZ`0206EEZ`80OfF[0P2BLjd2
0:>1[`050;BA/P2aQJD0/HFU0;65Y@32Uj/00`2jQYd00`3AXJH0_XJH0;j6V00208]BQ`0402L0000F
0000Fa9F05/BEP80E@Q<00@0C@0o06L]L`1W;G<0Ibec0P1T:6l2060RJP80G1]S00@0601Y01X0J`0J
06/06P1[0P0L06`708YBR0<0RU>90`2;EH`0102=Fi80Y/;]0:K2k@2V`^d90:K1k@@0Y/7/0P2V`Nd3
0:K1k0<0Y/7]0`2V`N`20:K1k@@0Y/7/2`2V`NdA0:G1k@<0Y<7]0`2T`>h60:?0kPD0X/3^1P2Q`>l2
09o0l0@0W[o`00@0000009fol02K_o40Vkoa2P3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo02<0oooo00<0kjn80:O0j`2W`>/04P2W`>/201dGS0030650T`1UD:D0IE2U0080OF2V0`2@
KjT20:5m[@050;6>/P2_PJ<0[h6S0:n1X`30U:T00`2bOIT0103=W:@0Re:708]BQ`2;DXM_0:O0j`<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`00<P3oool2000002`0oooo
00<0mIi:0:5SR@1D?9T00P1UEJ/207mUZ`80TW>]0P2SPJl40;65Y@040<:GZ`2jQYd0^XJM0;Z6W@<0
_XJH0P2;DXL2060JG@80Fa9F0P1E24`0101Y<7H0Ibec06L]L`1W;G<206@XK`80H29Z00<0G1]S01P0
J@0H06T00`0J06/201`0K0L0RU:80`2:DhT308]ES00308eKTP2W`Nd0Yl7]00P0Y/7]7P2V`N`;0:K1
k@P0YL7]0`2U`>d30:C1k@<0Y<3]0P2T`>h60:?0kP<0X/3^0`2R`>l30:70k`80X<3_0`2N_o000`3o
ool000000?ooo`0;0?ooo`030000003oool0oooo03h0oooo0P00000V0?oooa80Yl3[00<0J3^701dG
S01Q@9<00P1UD:D207ePYP<0T6nY0P2QOJd40:n1X`040<2DZ@2bOIT0/WfI0;9mV@@0Re:7K@2W`>/6
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool003@0oooo00<000000?oo
o`3oool0:@3oool00`3eWTX0Re:705@lV@0206EEZ`80OfF[0P2BLjd00`2SPJl0XgJQ0:=fX@030;65
Y@@0^XJM00<0YVfA0;j6V02nQYP00P2;DXL2060JG@80Fa9F00<0E@Q<06T`MP1Y<7H00`1W;G<206@X
K`80H29Z00<0G1]S01P0J@0H06T00`0J06/201`0K0L0RU:80`2:DhT308]ES00308eKTP2W`N`0Yl7/
00d0Yl7/702V`N`60:K1k@<0Y/3]0P2U`Nd;0:G0k@H0Y<3]0`2T`>h60:?0kP80X/3^0`2Q`>l70?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0T0?oo
oa40Yl3[00D0J3^701dGS01Q@9<0HD2C06E@Y@0307ePYP80T6nY00<0XGf]0:5bW@2QLYd00`2_PJ<4
0;9mV@@0Re:7J02W`>/<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool0
03D0oooo00<000000?ooo`3oool0:03oool01@3eWTX0Re:705@lV@1D?9T0IEF[0080OfF[0P2BLjd3
0:=fX@<0/HFU00D0ZWFH0;Z6W@2jQYd0^XJM0:I]T@020;j6V080Re:700D0H1YM05/BEP1K4UH0Fa9F
06/cN@0206T`MP<0Ibec00D0I2Q_060RJP1P8VX0H29Z01H0J00201P0J@<06P1[0P0L06`708YBR0<0
RU>90`2;EH`00`2=Fi80Yl7/0:O1k00C0:O1k1@0Y/7/0`2V`>`20:K1k0@0Y/3/1@2V`>d;0:G0k@H0
Y<3]0P2T`>h60:?0kPd0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo02@0oooo402W`>/01@1X>hL07AN<0650T`1Q@9<0NE2E00<0OF2V0P2@KjT30:5b
W@<0[h6S00@0XffC0;9mV@2bOIT0/WfI102;DXMV0:O0j`l0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0?0?ooo`00=P3oool00`000000oooo0?ooo`0X0?ooo`0403XOQ@1D?9T0E3bI
07AAVP80OfF[0`2EJId20:=fX@<0/HFU00D0ZWFH0;Z6W@2jQYd0^XJM0:I]T@020;j6V080Re:700<0
H1YM05/BEP1K4UH00P1[<gT206T`MP<0Ibec00D0I2Q_060RJP1P8VX0H29Z01H0J00201P0J@<06P1[
0P0L06`708YBR0<0RU>90`2;EH`J0:O1k080Y/7/7@2V`>`>0:G0k@D0Y<3]4P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0903oool?0:O0j`0406Pk
Q`0M5h`0HD2C0650T`80NE2E0P28FiL309AVVP80XG:M0P2_PJ<20:=]T`<0/WfI102;DXMQ0:O0ja@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00=`3oool00`000000oooo
0?ooo`0W0?ooo`0303XOQ@1D?9T0E3bI0080M56J0P27GY/209EYW@<0XgJQ00<0/HFU0:YeV02ZMIP0
0P2jQYd20:I]T@070;j6V02;DXL0Re:708]BQ`1P6Ud0Fa9F06dfN`0206/cN@80JC1f0`1W;G<00`1T
:6l0H29Z060RJP0201H0J080601Y0`0J06/201`0K0L0RU:80`2:DhT308]ES180Yl7/3`2W`>`L0:K0
k0/0YL3]5`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0903oool>0:O0j`80J3^70P1Q@9<207U@U@80R5^G0`2DIYX20:5bW@80[h6S0P2SKI<20;9m
V@D0Re:7G`2W`>/G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool003P0
oooo0P00000W0?ooo`0303XOQ@1D?9T0E3bI0080M56J0P27GY/209EYW@<0XgJQ00<0/HFU0:YeV02Z
MIP00P2jQYd20:I]T@040;j6V02;DXL0Re:708]BQ`<0KCIk0P1[<gT206T`MP80Ibec0P1T:6l2060R
JP805P1X0P0H06T301X0J`80701/1`2:DXP308YCR@<0ReF<2P2W`N`40:O0k080Yl7/5`2W`>`G0:K0
k0L0YL3]6`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04<0oooo0P00000U0?oo
o`d0Yl3[0P1X>hL20650T`80NE2E0P28FiL309AVVP80XG:M00@0[h6S0:=]T`2SKI<0XffC0P2bOIT5
08]BQeX0Yl3[7@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo000j0?oo
o`030000003oool0oooo02<0oooo00@0Re:703XOQ@1D?9T0E3bI0P1dDIX208MNV`80UFVM0`2SMZ40
0`2aQJD0ZWFH0:YeV0020;Z6W@80YVfA00@0_XJH08]BQ`2;DXL0Re:70`1]=W/206/cN@80JC1f0P1W
;G<206@XK`04060RJP0D06L05P1X01H0J080601Y0`0J06/201`0K0@0RU:800<08`=^02L6L00W1W00
0P0]2W42038=LP80Yl7/:`2W`>`F0:K0k200oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo02@0oooo2`2W`>/206PkQ`80HD2C0P1iD9D208QKU`<0U6JJ
0P2QLYd0102_PJ<0XffC0:=]T`2SKI<20;9mV@D0Re:7F02W`>/P0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03P3oool003/0oooo00<000000?ooo`3oool08P3oool0102;DXL0>Qn5
06m3S01D?9T207AAVP80QejK0P2EJId30:=fX@<0ZWFH0P2jQYd20:I]T@040;j6V02;DXL0Re:708]B
Q`<0KCIk0P1[<gT206T`MP80Ibec0P1T:6l201@0I`805P1X0P0H06T301X0J`80701/0P2:DXP302<3
KP809`I`0P0]2W400`0b3G80Yl7/0:O0k00]0:O0k100Y/3/9@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0903oool:0:O0j`80J3^70P1Q@9<207U@
U@80R5^G0`2DIYX20:5bW@@0XffC0P2bOIT508]BQe<0Yl3[9@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00h0oooo000l0?ooo`030000003oool0oooo0200oooo00D0@`0I08]BQ`0j
7hD0Kd><05@lV@0207AAVP80QejK0P2EJId30:=fX@<0ZWFH00D0^XJM0:I]T@2VKI40YVfA0;j6V003
08]BQ`<0KCIk0P1[<gT206T`MP80Ibec00@0I2Q_01@0I`0D06L0501W0P0F06P201P0J@<06P1[0P0L
06`00`2;DXL07`1]02<3KP0202<3KP809`I`>02W`>`80:K0k2P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo02@0oooo2@2W`>/206PkQ`80HD2C0P1i
D9D208QKU`<0U6JJ0P2QLYd01@2JHi00XffC0:=]T`2SKI<0/WfI00H0Re:7D@2W`>/X0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool003d0oooo0P00000O0?ooo`0404<06@1]
:VT0mkA603XOQ@80Kd><0P1dDIX208MNV`80UFVM0P2SMZ401@2NJI@0ZWFH0:YeV02ZMIP0^XJM00<0
YVfA00@0_XJH08]BQ`2;DXL0Re:70`1]=W/206/cN@80JC1f0P1W;G<0101T:6l0501W01@0I`0D06L2
01H0J080601Y0`0J06/201`0K0807`1]0P0S0fh00`0W1W00Yl3/0:O0k00i0:O0k080Y/3/;P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo04L0oooo0P00000T0?ooo`T0Yl3[0P1X>hL0
101mBhT0HD2C07U@U@1iD9D208QKU`<0U6JJ0P2QLYd01@2JHi00XffC0:=]T`2SKI<0/WfI00H0Re:7
C@2W`>/]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool003l0oooo00<0
00000?ooo`3oool06`3oool206l^K@0306dZJ@3g]4H0>Qn50080Kd><0P1dDIX208MNV`80UFVM00<0
XgJQ09iYU02NJI@00`2ZMIP01@2jQYd0YVfA0:I]T@2VKI40_XJH00<0Re:70P1]=W/306/cN@80JC1f
0P1W;G<0100B06H0501W01@0I`0D06L201H0J080601Y0`0J06/201`0K0807`1]?P2W`>``0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0S0?ooo`L0
Yl3[0P1X>hL0101mBhT0HD2C07U@U@1iD9D208QKU`<0U6JJ00<0XG:M09YST02JHi000`2SKI<00`2b
OIT0Re:708]BQ`0408]BQdP0Yl3[<P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00h0oooo00100?ooo`030000003oool0oooo01X0oooo0P1_;Vd00`1]:VT0mkA603XOQ@0206m3S080
M56J0P27GY/209EYW@<0WVVD0`2ZMIP40:I]T@040;j6V02;DXL0Re:708]BQ`80KCIk0`1[<gT206T`
MP80Ibec00@04P1V01@0I`0D06L0501W0P0F06P201P0J@806P1[0`0L06`70:O0k0<0Yl3[0`2W`>`3
0:O0j`80Yl3/0`2W`>/30:O0k0<0Yl3[0P2W`>`30:O0ja`0Yl3/=@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool08`3oool60:O0j`80J3^700@0OD^9
0650T`1iD9D0NE2E0P28FiL309AVVP030:5bW@2JHi00VV>@00<0XffC00<0/WfI08]BQ`2;DXL0102;
DXM60:O0jcD0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00@@3oool0
0`000000oooo0?ooo`0I0?ooo`80Kbi]00<0KBYY0?NdAP0j7hD00P1_@h`01P21D8h0M56J08MNV`27
GY/0UFVM09APT@<0WVVD0`2ZMIP40:I]T@@0Re:70P1]=W/306/cN@80JC1f00<0Ibec0180IP0B06H0
0`0D06L201H0J080601Y1@2W`>`30:O0j`80Yl3/8P2W`>/20:O0k0<0Yl3[2`2W`>`k0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0S0?ooo`D0Yl3[
0P1X>hL207e;R@80NE2E0P28FiL309AVVP<0VV>@0`2SKI=80:O0jc/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0=0?ooo`00@P3oool00`000000oooo0?ooo`0H0?ooo`80Kbi]00<0
KBYY0?NdAP0j7hD00P1_@h`2085@SP80QejK0P2DH94309iYU0<0ZWFH102VKI4408]BQ`80KCIk0`1[
<gT206T`MP0306L]L`0B06H04P1V0080501W0`0F06P20:O0k3P0Yl3[0P2W`>`n0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0T0?ooo`<0Yl3[0P1X
>hL207e;R@80NE2E0P28FiM?0:O0jch0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0=0?ooo`00@`3oool2000001P0oooo00D0Kbi]06dZJ@1]:VT0mkA603XOQ@0206m3S080PE2>0P2;
F8l209APT@<0WVVD0`2ZMIP40:I]T@@0Re:70P1]=W/306/cN@80JC1f00<0Re>80180IP0B06H0?@2W
`>]20?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C03oool2000002D0oooo0P2W
`>/206PkQ`80OD^9C`2W`>]20?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3o
ool004D0oooo00<000000?ooo`3oool05@3oool01@1_;Vd0KBYY06dZJ@3g]4H0>Qn50080Kd><0P21
D8h208]HS`80U62A0P1`=7H206hbM080K2ia0P1`>gl01P1_>Wl0Re:706liOP1_>Gh0KSMl08]BQ`80
KCIk0`1[<gT00`1Y<7H0Re>808]CR00m0:O0jdD0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo02<0oooo00<0Yl3[06PkQ`1X>hL0C02W`>]80?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool004H0oooo00<000000?ooo`3oool0
4`3oool206l^K@80KBYY00@0mkA603XOQ@1_@h`0Kd><0P21D8h2078iNP80LCMh0P1`=7H206hbM004
06`^L@1`>gl0L3]o070kO`80KcYo0P1_>Gh206hgO080KCIk0P1[<gT206T`MSX0Yl3[B`3oool01@00
0000oooo0?ooo`3oool000000540oooo00<000000?ooo`3oool08P3oool00`2W`>/0J3^70:O0j`1:
0:O0jd/0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`00A`3oool00`000000oooo0?ooo`0B
0?ooo`80Kbi]00H0KBYY07DmOP3g]4H0>Qn506m3S01d?7d207<jN`04078iNP1a=gP0LCMh074gN080
L3Af0P1^<W@0101/;W40L3]o070kO`1`>gl206ljO`80KcUn0P1^=g`00`1]=W/0Jc=i06/cN@0i0:O0
je00oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`0R0?ooo`0308]BQ`2W`>/0
Yl3[04D0Yl3[D03oool010000000oooo0?ooo`00000?0?ooo`00B03oool200000180oooo0P1_;Vd0
101e?Wl0MCen0?NdAP0j7hD207@lO@0307<jN`1b>GX0LSUj00<0LCMh00D0L3Af06hbM01^<W@0KS9d
074lP003070kO`80KcYo0P1_>Gh00`1^=g`0KCIk0:O0j`0i0:O0je80oooo00@000000?ooo`3oool0
0000D`3oool200000240oooo0P2;DXL00`3oool0Yl3[0:O0j`120:O0je80oooo00@000000?ooo`3o
ool000003`3oool004X0oooo00<000000?ooo`3oool03`3oool01P1_;Vd0MCio07DnO`1e?Gh0mkA6
08]BQ`80M3am00<0LcYk078iNP1b>GX00P1a=gP2070dMP80KS9d0P1a?803070kO`80KcYo00<0KcUn
06hgO02W`>/0=P2W`>]H0?ooo`030000003oool0000005D0oooo00<000000?ooo`3oool08P3oooln
0:O0jeP0oooo00<000000?ooo`0000003`3oool004/0oooo00<000000?ooo`3oool03P3oool01`1f
?gl0MCio07DnO`1e?Gh0mkA608]BQ`1d?7d00P1c>W/2078iNP80LCMh0P1`=7H206hbM080LCb00`1`
>gl00`1_>Wl0KcUn0:O0j`0d0:O0jed0oooo00<000000?ooo`000000E@3oool00`000000oooo0?oo
o`0S0?ooocP0Yl3[G@3oool00`000000oooo0000000>0?ooo`00C03oool00`000000oooo0?ooo`0<
0?ooo`80MSmo0P1e?Wl208]BQ`80M3am0P1c>W/2078iNP80LCMh0P1`=7H0101^<W@0Qdj5074lP01a
?802070kO`030?ooo`2W`>/0Yl3[03<0Yl3[H03oool2000005H0oooo00<000000?ooo`3oool08`3o
oole0:O0jf00oooo0P00000>0?ooo`00C@3oool2000000`0oooo0P1f?gl207DnO`80MCen0P1d?7d2
07<jN`80LSUj0P1a=gP2070dMP0306hbM027CXD0oooo00D0oooo<02W`>]T0?ooo`800000E`3oool2
000002@0oooo<02W`>]T0?ooo`8000003P3oool004l0oooo00<000000?ooo`3oool02@3oool207Ho
O`80MCio0P1e?Gh207@lO@80LcYk0P1b>GX2074gN003070dMP1^<W@0oooo00P0oooo:`2W`>]X0?oo
o`800000F@3oool00`000000oooo0?ooo`0R0?ooob/0Yl3[J03oool2000000h0oooo001@0?ooo`03
0000003oool0oooo00P0oooo0P1f?gl207DnO`80MCen0P1d?7d207<jN`03078iNP1a=gP0LCMh00`0
oooo:@2W`>]V0?ooo`@00000G03oool00`000000oooo0?ooo`0Q0?ooobT0Yl3[IP3oool400000100
oooo001A0?ooo`030000003oool0oooo00L0oooo0P1f?gl207DnO`80MCen0P1d?7d00`1c>W/0LSUj
078iNP0@0?ooob80Yl3[I`3oool400000640oooo00<000000?ooo`3oool08P3ooolS0:O0jfH0oooo
1000000D0?ooo`00DP3oool00`000000oooo0?ooo`060?ooo`80MSmo0P1e?Wl207DmOP0307@lO@1c
>W/0oooo01<0oooo7@2W`>]W0?ooo`@00000IP3oool00`000000oooo0?ooo`0R0?oooad0Yl3[I`3o
ool4000001P0oooo001C0?ooo`8000001P3oool207HoO`0307DnO`1e?Gh0MCen01P0oooo602W`>]W
0?ooo`@00000J`3oool2000002<0oooo602W`>]W0?ooo`@00000703oool005D0oooo00<000000?oo
o`3oool00`3oool00`1f?gl0MCio0?ooo`0K0?oooaD0Yl3[IP3oool300000740oooo00<000000?oo
o`3oool08@3ooolE0:O0jfH0oooo0`00000P0?ooo`00EP3oool00`000000oooo0?ooo`0R0?ooo`l0
Yl3[IP3oool4000007D0oooo00<000000?ooo`3oool08P3oool?0:O0jfH0oooo1000000S0?ooo`00
E`3oool00`000000oooo0?ooo`0R0?ooo`X0Yl3[IP3oool4000007X0oooo00<000000?ooo`3oool0
8P3oool:0:O0jfH0oooo1000000W0?ooo`00F03oool2000002<0oooo1@2W`>]V0?ooo`@00000O`3o
ool2000002<0oooo1@2W`>]V0?ooo`@00000:`3oool005X0oooo00<000000?ooo`3oool0803oool0
0`000000Yl3[0:O0j`1U0?ooo`<00000Q@3oool00`000000oooo0?ooo`0P0?ooo`030000002W`>/0
Yl3[06D0oooo0`00000_0?ooo`00F`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0640oooo100000290?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0H@3oool40000
0380oooo001L0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0G@3oool4000008h0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1M0?ooo`@00000=P3oool005d0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1I0?ooo`@00000T`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo05T0oooo1000000j0?ooo`00GP3oool2000001d0oooo00<0
00000?ooo`3oool0E@3oool4000009P0oooo0P00000M0?ooo`030000003oool0oooo05D0oooo1000
000n0?ooo`00H03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0580oooo0`00002N
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0DP3oool300000480oooo001Q0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0CP3oool400000:80oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1>0?ooo`@00000A@3oool00680oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`1:0?ooo`@00000Y`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo04X0oooo100000190?ooo`00H`3oool2000001P0oooo00<000000?ooo`3oool0
AP3oool400000:`0oooo0P00000H0?ooo`030000003oool0oooo04H0oooo1000001=0?ooo`00I@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0480oooo1000002b0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0@P3oool400000540oooo001V0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0?`3oool300000;L0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0o0?ooo`<00000E@3oool006L0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0k0?ooo`@00000^`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
03/0oooo1000001H0?ooo`00J03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03L0
oooo100000300?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0=`3oool4000005`0
oooo001Y0?ooo`8000004P3oool00`000000oooo0?ooo`0c0?ooo`@00000a@3oool200000180oooo
00<000000?ooo`3oool0<`3oool400000600oooo001[0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0<03oool300000</0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0`0?ooo`<00000I03oool006`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0/
0?ooo`@00000c`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02`0oooo1000001W
0?ooo`00K@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02T0oooo1000003D0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:@3oool4000006/0oooo001^0?ooo`80
0000303oool00`000000oooo0?ooo`0U0?ooo`@00000f@3oool2000000`0oooo00<000000?ooo`3o
ool09@3oool4000006l0oooo001`0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
8@3oool400000=l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Q0?ooo`@00000
L`3oool00740oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`<00000i03o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo0`00001g0?ooo`00LP3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000003X0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool06P3oool4000007X0oooo001c0?ooo`8000001`3oool00`00
0000oooo0?ooo`0F0?ooo`@00000k@3oool2000000L0oooo00<000000?ooo`3oool05P3oool40000
07h0oooo001e0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool400000?<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`@00000PP3oool007H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`<00000n03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00l0oooo0`0000260?ooo`00M`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo1000003l0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool4000008T0oooo001h0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool400000?l0oooo0P3oool01@000000oooo0?ooo`3oool0000000T0oooo1000002=0?ooo`00N@3o
ool2000000030?ooo`000000oooo00@0oooo1000003o0?ooo`L0oooo0P0000000`3oool000000?oo
o`040?ooo`@00000T@3oool007/0oooo0P0000000`3oool000000000000200000?l0oooo3@3oool2
000000030?ooo`000000000000800000U@3oool007`0oooo0P00003o0?oooa80oooo0P00002I0?oo
o`00o`3ooooo0?ooob`0oooo003o0?ooool0oooo;03oool00?l0ooooo`3oool/0?ooo`00o`3ooooo
0?ooob`0oooo003o0?ooool0oooo;03oool00?l0ooooo`3oool/0?ooo`00o`3ooooo0?ooob`0oooo
003o0?ooool0oooo;03oool00?l0ooooo`3oool/0?ooo`00o`3ooooo0?ooob`0oooo003o0?ooool0
oooo;03oool00001\
\>"],
  ImageRangeCache->{{{0, 553.188}, {213, 0}} -> {-0.0533341, -0.0193168, \
0.00380824, 0.00380824}, {{14, 264.062}, {207.875, 5.0625}} -> {-0.133397, \
0.00938765, 0.00411263, 0.00411263}, {{289.062, 539.125}, {207.875, 5.0625}} -> \
{-1.26463, 0.00938765, 0.00411263, 0.00411263}}],

Cell[TextData[{
  "The next graphic shows the regularized incomplete Gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Q", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " over the ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  "\[Hyphen]",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "\[Dash]plane."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.63261e-17 1.04977 -0.0679587 1.04977 [
[.14598 .19958 -18.2586 -11.1875 ]
[.14598 .19958 .11638 0 ]
[.27013 .15073 -17.1354 -11.1875 ]
[.27013 .15073 .86459 0 ]
[.40046 .09948 -16.7262 -11.1875 ]
[.40046 .09948 1.64882 0 ]
[.53742 .04564 -15.9057 -11.1875 ]
[.53742 .04564 2.40682 0 ]
[.68156 -0.01098 -7.85527 -11.1875 ]
[.68156 -0.01098 1.64473 0 ]
[.29165 .07573 -8.90381 -11.1875 ]
[.29165 .07573 .65869 0 ]
[.76745 .09703 0 -7.65955 ]
[.76745 .09703 18.375 3.52795 ]
[.82811 .18992 0 -7.54841 ]
[.82811 .18992 18 3.63909 ]
[.88369 .27502 0 -7.44862 ]
[.88369 .27502 18.375 3.73888 ]
[.93478 .35327 0 -7.35852 ]
[.93478 .35327 18.3125 3.82898 ]
[.98191 .42546 0 -7.27677 ]
[.98191 .42546 9.5 3.91073 ]
[.91861 .21225 0 -7.4972 ]
[.91861 .21225 9.6875 3.6903 ]
[.02411 .26511 -10.0625 -3.40885 ]
[.02411 .26511 0 7.77865 ]
[.01059 .34985 -9.5 -3.498 ]
[.01059 .34985 0 7.6895 ]
[-0.00369 .43938 -10.125 -3.59273 ]
[-0.00369 .43938 0 7.59477 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15519 .20892 m
.1598 .21359 L
s
gsave
.14598 .19958 -79.2586 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.27893 .16047 m
.28333 .16534 L
s
gsave
.27013 .15073 -78.1354 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.40878 .10962 m
.41294 .11469 L
s
gsave
.40046 .09948 -77.7262 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.54521 .0562 m
.5491 .06148 L
s
gsave
.53742 .04564 -76.9057 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -68.8553 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06615 .24378 m
.069 .2465 L
s
.09549 .2323 m
.09831 .23504 L
s
.12517 .22068 m
.12796 .22345 L
s
.18558 .19702 m
.18831 .19985 L
s
.21632 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25011 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13536 m
.34563 .13834 L
s
.37572 .12257 m
.37825 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08325 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07295 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -69.9038 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.562 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75514 .10157 m
.74898 .10384 L
s
gsave
.76745 .09703 -61 -11.6595 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.81573 .19425 m
.80953 .19642 L
s
gsave
.82811 .18992 -61 -11.5484 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.87123 .27915 m
.865 .28122 L
s
gsave
.88369 .27502 -61 -11.4486 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.92226 .35722 m
.91601 .35919 L
s
gsave
.93478 .35327 -61 -11.3585 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.2768 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .02629 m
.70225 .02771 L
s
.72271 .05197 m
.71903 .05337 L
s
.73911 .07706 m
.73543 .07844 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83005 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85406 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .33949 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -11.4972 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
68.688 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
gsave
.02411 .26511 -71.0625 -7.40885 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02288 .34524 m
.02902 .34294 L
s
gsave
.01059 .34985 -70.5 -7.498 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.00866 .43496 m
.01484 .43275 L
s
gsave
-0.00369 .43938 -71.125 -7.59273 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.0337 .27695 m
.03737 .27553 L
s
.03104 .29375 m
.03472 .29233 L
s
.02835 .31072 m
.03203 .30932 L
s
.02563 .32789 m
.02931 .3265 L
s
.0201 .36279 m
.02379 .36142 L
s
.01729 .38053 m
.02098 .37917 L
s
.01445 .39847 m
.01814 .39712 L
s
.01157 .41662 m
.01527 .41528 L
s
.00572 .45352 m
.00943 .45221 L
s
.00275 .47229 m
.00646 .47099 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39457 .59389 .40512 .60371 .4138 .60111 .40329 .59125 Mtetra
.40329 .59125 .4138 .60111 .42251 .5985 .41203 .58861 Mtetra
.41203 .58861 .42251 .5985 .43124 .59588 .4208 .58596 Mtetra
.4208 .58596 .43124 .59588 .44001 .59325 .4296 .5833 Mtetra
.4296 .5833 .44001 .59325 .4488 .59061 .43843 .58063 Mtetra
.43843 .58063 .4488 .59061 .45762 .58796 .44729 .57795 Mtetra
.44729 .57795 .45762 .58796 .46647 .58531 .45617 .57526 Mtetra
.45617 .57526 .46647 .58531 .47535 .58265 .46509 .57256 Mtetra
.46509 .57256 .47535 .58265 .48425 .57997 .47404 .56986 Mtetra
.47404 .56986 .48425 .57997 .49319 .57729 .48301 .56714 Mtetra
.48301 .56714 .49319 .57729 .50216 .5746 .49202 .56442 Mtetra
.49202 .56442 .50216 .5746 .51115 .5719 .50105 .56169 Mtetra
.50105 .56169 .51115 .5719 .52017 .5692 .51011 .55895 Mtetra
.51011 .55895 .52017 .5692 .52923 .56648 .51921 .5562 Mtetra
.51921 .5562 .52923 .56648 .53831 .56376 .52833 .55344 Mtetra
.52833 .55344 .53831 .56376 .54743 .56102 .53749 .55067 Mtetra
.53749 .55067 .54743 .56102 .55657 .55828 .54667 .54789 Mtetra
.54667 .54789 .55657 .55828 .56575 .55553 .55589 .54511 Mtetra
.55589 .54511 .56575 .55553 .57495 .55276 .56513 .54231 Mtetra
.56513 .54231 .57495 .55276 .58419 .54999 .57441 .53951 Mtetra
.663 .741 .908 r
.57441 .53951 .58419 .54999 .59345 .54721 .58372 .53669 Mtetra
.58372 .53669 .59345 .54721 .60275 .54442 .59306 .53387 Mtetra
.59306 .53387 .60275 .54442 .61208 .54163 .60243 .53104 Mtetra
.60243 .53104 .61208 .54163 .62144 .53882 .61184 .5282 Mtetra
.61184 .5282 .62144 .53882 .63083 .536 .62127 .52535 Mtetra
.663 .742 .908 r
.62127 .52535 .63083 .536 .64026 .53317 .63074 .5225 Mtetra
.63074 .5225 .64026 .53317 .64971 .53034 .64024 .51964 Mtetra
.663 .742 .909 r
.64024 .51964 .64971 .53034 .6592 .52749 .64977 .51676 Mtetra
.64977 .51676 .6592 .52749 .66872 .52463 .65933 .51389 Mtetra
.65933 .51389 .66872 .52463 .67827 .52177 .66893 .511 Mtetra
.663 .743 .909 r
.66893 .511 .67827 .52177 .68785 .51889 .67856 .50811 Mtetra
.663 .743 .91 r
.67856 .50811 .68785 .51889 .69747 .51601 .68822 .50521 Mtetra
.662 .743 .91 r
.68822 .50521 .69747 .51601 .70711 .51312 .69792 .50231 Mtetra
.662 .744 .911 r
.69792 .50231 .70711 .51312 .7168 .51021 .70765 .4994 Mtetra
.70765 .4994 .7168 .51021 .72651 .5073 .71741 .49648 Mtetra
.662 .745 .912 r
.71741 .49648 .72651 .5073 .73626 .50437 .72721 .49356 Mtetra
.662 .746 .912 r
.72721 .49356 .73626 .50437 .74604 .50144 .73704 .49063 Mtetra
.661 .746 .913 r
.73704 .49063 .74604 .50144 .75585 .49849 .74691 .4877 Mtetra
.661 .747 .914 r
.74691 .4877 .75585 .49849 .7657 .49554 .75681 .48476 Mtetra
.661 .748 .915 r
.75681 .48476 .7657 .49554 .77558 .49257 .76675 .48182 Mtetra
.661 .749 .916 r
.76675 .48182 .77558 .49257 .7855 .4896 .77672 .47887 Mtetra
.66 .751 .917 r
.77672 .47887 .7855 .4896 .79545 .48661 .78673 .47592 Mtetra
.66 .752 .918 r
.78673 .47592 .79545 .48661 .80544 .48362 .79677 .47296 Mtetra
.66 .753 .919 r
.79677 .47296 .80544 .48362 .81546 .48061 .80685 .47 Mtetra
.659 .755 .921 r
.80685 .47 .81546 .48061 .82551 .4776 .81697 .46704 Mtetra
.659 .756 .922 r
.81697 .46704 .82551 .4776 .8356 .47457 .82712 .46407 Mtetra
.658 .758 .924 r
.82712 .46407 .8356 .47457 .84573 .47153 .83731 .46109 Mtetra
.658 .76 .925 r
.83731 .46109 .84573 .47153 .85588 .46848 .84754 .45811 Mtetra
.657 .762 .927 r
.84754 .45811 .85588 .46848 .86608 .46543 .8578 .45513 Mtetra
.657 .764 .929 r
.8578 .45513 .86608 .46543 .87631 .46236 .8681 .45214 Mtetra
.656 .767 .931 r
.8681 .45214 .87631 .46236 .88658 .45928 .87844 .44915 Mtetra
.656 .769 .933 r
.87844 .44915 .88658 .45928 .89688 .45619 .88882 .44615 Mtetra
.655 .772 .935 r
.88882 .44615 .89688 .45619 .90722 .45308 .89923 .44315 Mtetra
.654 .774 .937 r
.89923 .44315 .90722 .45308 .9176 .44997 .90969 .44014 Mtetra
.653 .777 .939 r
.90969 .44014 .9176 .44997 .92801 .44685 .92018 .43713 Mtetra
.652 .78 .942 r
.92018 .43713 .92801 .44685 .93846 .44371 .93071 .43411 Mtetra
.651 .784 .944 r
.93071 .43411 .93846 .44371 .94895 .44057 .94128 .4311 Mtetra
.65 .787 .947 r
.94128 .4311 .94895 .44057 .95947 .43741 .95189 .42807 Mtetra
.649 .79 .95 r
.95189 .42807 .95947 .43741 .97003 .43424 .96255 .42504 Mtetra
.664 .741 .908 r
.38389 .58395 .39457 .59389 .40329 .59125 .39264 .58128 Mtetra
.39264 .58128 .40329 .59125 .41203 .58861 .40142 .5786 Mtetra
.40142 .5786 .41203 .58861 .4208 .58596 .41023 .57592 Mtetra
.41023 .57592 .4208 .58596 .4296 .5833 .41907 .57322 Mtetra
.41907 .57322 .4296 .5833 .43843 .58063 .42793 .57052 Mtetra
.42793 .57052 .43843 .58063 .44729 .57795 .43683 .56781 Mtetra
.43683 .56781 .44729 .57795 .45617 .57526 .44575 .56509 Mtetra
.44575 .56509 .45617 .57526 .46509 .57256 .45471 .56236 Mtetra
.45471 .56236 .46509 .57256 .47404 .56986 .46369 .55962 Mtetra
.46369 .55962 .47404 .56986 .48301 .56714 .47271 .55687 Mtetra
.47271 .55687 .48301 .56714 .49202 .56442 .48175 .55411 Mtetra
.48175 .55411 .49202 .56442 .50105 .56169 .49082 .55135 Mtetra
.49082 .55135 .50105 .56169 .51011 .55895 .49993 .54857 Mtetra
.49993 .54857 .51011 .55895 .51921 .5562 .50906 .54579 Mtetra
.50906 .54579 .51921 .5562 .52833 .55344 .51822 .54299 Mtetra
.663 .741 .908 r
.51822 .54299 .52833 .55344 .53749 .55067 .52742 .54019 Mtetra
.52742 .54019 .53749 .55067 .54667 .54789 .53665 .53738 Mtetra
.53665 .53738 .54667 .54789 .55589 .54511 .5459 .53456 Mtetra
.5459 .53456 .55589 .54511 .56513 .54231 .55519 .53174 Mtetra
.55519 .53174 .56513 .54231 .57441 .53951 .56451 .5289 Mtetra
.663 .742 .908 r
.56451 .5289 .57441 .53951 .58372 .53669 .57386 .52606 Mtetra
.57386 .52606 .58372 .53669 .59306 .53387 .58325 .52321 Mtetra
.663 .742 .909 r
.58325 .52321 .59306 .53387 .60243 .53104 .59266 .52036 Mtetra
.59266 .52036 .60243 .53104 .61184 .5282 .60211 .5175 Mtetra
.662 .742 .909 r
.60211 .5175 .61184 .5282 .62127 .52535 .61159 .51464 Mtetra
.662 .743 .91 r
.61159 .51464 .62127 .52535 .63074 .5225 .6211 .51177 Mtetra
.6211 .51177 .63074 .5225 .64024 .51964 .63064 .50889 Mtetra
.662 .743 .911 r
.63064 .50889 .64024 .51964 .64977 .51676 .64022 .50602 Mtetra
.661 .744 .911 r
.64022 .50602 .64977 .51676 .65933 .51389 .64983 .50314 Mtetra
.661 .744 .912 r
.64983 .50314 .65933 .51389 .66893 .511 .65948 .50025 Mtetra
.661 .745 .912 r
.65948 .50025 .66893 .511 .67856 .50811 .66916 .49737 Mtetra
.661 .746 .913 r
.66916 .49737 .67856 .50811 .68822 .50521 .67887 .49448 Mtetra
.66 .746 .914 r
.67887 .49448 .68822 .50521 .69792 .50231 .68861 .49159 Mtetra
.66 .747 .915 r
.68861 .49159 .69792 .50231 .70765 .4994 .6984 .4887 Mtetra
.659 .748 .916 r
.6984 .4887 .70765 .4994 .71741 .49648 .70821 .4858 Mtetra
.659 .749 .917 r
.70821 .4858 .71741 .49648 .72721 .49356 .71806 .4829 Mtetra
.659 .75 .918 r
.71806 .4829 .72721 .49356 .73704 .49063 .72795 .48001 Mtetra
.658 .752 .919 r
.72795 .48001 .73704 .49063 .74691 .4877 .73787 .47711 Mtetra
.658 .753 .92 r
.73787 .47711 .74691 .4877 .75681 .48476 .74783 .47421 Mtetra
.657 .754 .921 r
.74783 .47421 .75681 .48476 .76675 .48182 .75782 .4713 Mtetra
.657 .756 .923 r
.75782 .4713 .76675 .48182 .77672 .47887 .76785 .4684 Mtetra
.656 .757 .924 r
.76785 .4684 .77672 .47887 .78673 .47592 .77792 .46549 Mtetra
.655 .759 .926 r
.77792 .46549 .78673 .47592 .79677 .47296 .78802 .46259 Mtetra
.655 .76 .927 r
.78802 .46259 .79677 .47296 .80685 .47 .79817 .45968 Mtetra
.654 .762 .929 r
.79817 .45968 .80685 .47 .81697 .46704 .80835 .45677 Mtetra
.654 .764 .93 r
.80835 .45677 .81697 .46704 .82712 .46407 .81856 .45386 Mtetra
.653 .765 .932 r
.81856 .45386 .82712 .46407 .83731 .46109 .82882 .45094 Mtetra
.652 .767 .933 r
.82882 .45094 .83731 .46109 .84754 .45811 .83911 .44803 Mtetra
.652 .769 .935 r
.83911 .44803 .84754 .45811 .8578 .45513 .84944 .44511 Mtetra
.651 .771 .937 r
.84944 .44511 .8578 .45513 .8681 .45214 .85981 .44219 Mtetra
.65 .773 .939 r
.85981 .44219 .8681 .45214 .87844 .44915 .87022 .43927 Mtetra
.649 .775 .94 r
.87022 .43927 .87844 .44915 .88882 .44615 .88067 .43635 Mtetra
.648 .777 .942 r
.88067 .43635 .88882 .44615 .89923 .44315 .89116 .43342 Mtetra
.648 .78 .944 r
.89116 .43342 .89923 .44315 .90969 .44014 .90169 .43049 Mtetra
.647 .782 .946 r
.90169 .43049 .90969 .44014 .92018 .43713 .91227 .42756 Mtetra
.646 .784 .948 r
.91227 .42756 .92018 .43713 .93071 .43411 .92288 .42462 Mtetra
.645 .786 .95 r
.92288 .42462 .93071 .43411 .94128 .4311 .93353 .42169 Mtetra
.644 .789 .952 r
.93353 .42169 .94128 .4311 .95189 .42807 .94422 .41875 Mtetra
.643 .791 .953 r
.94422 .41875 .95189 .42807 .96255 .42504 .95496 .4158 Mtetra
.664 .741 .908 r
.37308 .57388 .38389 .58395 .39264 .58128 .38187 .57118 Mtetra
.38187 .57118 .39264 .58128 .40142 .5786 .39069 .56847 Mtetra
.39069 .56847 .40142 .5786 .41023 .57592 .39953 .56575 Mtetra
.39953 .56575 .41023 .57592 .41907 .57322 .4084 .56302 Mtetra
.4084 .56302 .41907 .57322 .42793 .57052 .41731 .56029 Mtetra
.41731 .56029 .42793 .57052 .43683 .56781 .42624 .55754 Mtetra
.42624 .55754 .43683 .56781 .44575 .56509 .4352 .55479 Mtetra
.4352 .55479 .44575 .56509 .45471 .56236 .4442 .55202 Mtetra
.4442 .55202 .45471 .56236 .46369 .55962 .45322 .54925 Mtetra
.45322 .54925 .46369 .55962 .47271 .55687 .46227 .54647 Mtetra
.46227 .54647 .47271 .55687 .48175 .55411 .47135 .54368 Mtetra
.47135 .54368 .48175 .55411 .49082 .55135 .48047 .54087 Mtetra
.48047 .54087 .49082 .55135 .49993 .54857 .48961 .53807 Mtetra
.663 .741 .908 r
.48961 .53807 .49993 .54857 .50906 .54579 .49878 .53525 Mtetra
.49878 .53525 .50906 .54579 .51822 .54299 .50799 .53242 Mtetra
.50799 .53242 .51822 .54299 .52742 .54019 .51723 .52959 Mtetra
.51723 .52959 .52742 .54019 .53665 .53738 .52649 .52675 Mtetra
.52649 .52675 .53665 .53738 .5459 .53456 .53579 .5239 Mtetra
.663 .742 .909 r
.53579 .5239 .5459 .53456 .55519 .53174 .54512 .52105 Mtetra
.54512 .52105 .55519 .53174 .56451 .5289 .55448 .51819 Mtetra
.662 .742 .909 r
.55448 .51819 .56451 .5289 .57386 .52606 .56388 .51533 Mtetra
.56388 .51533 .57386 .52606 .58325 .52321 .57331 .51247 Mtetra
.662 .742 .91 r
.57331 .51247 .58325 .52321 .59266 .52036 .58276 .5096 Mtetra
.662 .743 .91 r
.58276 .5096 .59266 .52036 .60211 .5175 .59226 .50673 Mtetra
.661 .743 .911 r
.59226 .50673 .60211 .5175 .61159 .51464 .60178 .50387 Mtetra
.661 .744 .911 r
.60178 .50387 .61159 .51464 .6211 .51177 .61134 .501 Mtetra
.66 .744 .912 r
.61134 .501 .6211 .51177 .63064 .50889 .62093 .49813 Mtetra
.66 .745 .913 r
.62093 .49813 .63064 .50889 .64022 .50602 .63055 .49526 Mtetra
.659 .746 .914 r
.63055 .49526 .64022 .50602 .64983 .50314 .64021 .49239 Mtetra
.659 .746 .915 r
.64021 .49239 .64983 .50314 .65948 .50025 .64991 .48952 Mtetra
.658 .747 .916 r
.64991 .48952 .65948 .50025 .66916 .49737 .65963 .48665 Mtetra
.658 .748 .917 r
.65963 .48665 .66916 .49737 .67887 .49448 .6694 .48379 Mtetra
.657 .749 .918 r
.6694 .48379 .67887 .49448 .68861 .49159 .6792 .48092 Mtetra
.657 .75 .919 r
.6792 .48092 .68861 .49159 .6984 .4887 .68903 .47806 Mtetra
.656 .751 .92 r
.68903 .47806 .6984 .4887 .70821 .4858 .6989 .47519 Mtetra
.656 .752 .921 r
.6989 .47519 .70821 .4858 .71806 .4829 .7088 .47233 Mtetra
.655 .754 .922 r
.7088 .47233 .71806 .4829 .72795 .48001 .71874 .46947 Mtetra
.654 .755 .924 r
.71874 .46947 .72795 .48001 .73787 .47711 .72872 .46661 Mtetra
.654 .756 .925 r
.72872 .46661 .73787 .47711 .74783 .47421 .73874 .46375 Mtetra
.653 .758 .926 r
.73874 .46375 .74783 .47421 .75782 .4713 .74879 .4609 Mtetra
.652 .759 .928 r
.74879 .4609 .75782 .4713 .76785 .4684 .75888 .45804 Mtetra
.652 .761 .929 r
.75888 .45804 .76785 .4684 .77792 .46549 .76901 .45518 Mtetra
.651 .762 .931 r
.76901 .45518 .77792 .46549 .78802 .46259 .77917 .45233 Mtetra
.65 .764 .932 r
.77917 .45233 .78802 .46259 .79817 .45968 .78938 .44947 Mtetra
.65 .766 .934 r
.78938 .44947 .79817 .45968 .80835 .45677 .79962 .44662 Mtetra
.649 .767 .935 r
.79962 .44662 .80835 .45677 .81856 .45386 .8099 .44376 Mtetra
.648 .769 .937 r
.8099 .44376 .81856 .45386 .82882 .45094 .82023 .44091 Mtetra
.647 .771 .939 r
.82023 .44091 .82882 .45094 .83911 .44803 .83059 .43805 Mtetra
.646 .772 .94 r
.83059 .43805 .83911 .44803 .84944 .44511 .84099 .43519 Mtetra
.646 .774 .942 r
.84099 .43519 .84944 .44511 .85981 .44219 .85143 .43233 Mtetra
.645 .776 .943 r
.85143 .43233 .85981 .44219 .87022 .43927 .86191 .42947 Mtetra
.644 .778 .945 r
.86191 .42947 .87022 .43927 .88067 .43635 .87244 .42661 Mtetra
.643 .78 .947 r
.87244 .42661 .88067 .43635 .89116 .43342 .883 .42375 Mtetra
.642 .782 .948 r
.883 .42375 .89116 .43342 .90169 .43049 .89361 .42089 Mtetra
.641 .784 .95 r
.89361 .42089 .90169 .43049 .91227 .42756 .90425 .41802 Mtetra
.64 .786 .952 r
.90425 .41802 .91227 .42756 .92288 .42462 .91494 .41515 Mtetra
.639 .788 .953 r
.91494 .41515 .92288 .42462 .93353 .42169 .92568 .41228 Mtetra
.638 .79 .955 r
.92568 .41228 .93353 .42169 .94422 .41875 .93645 .40941 Mtetra
.637 .792 .957 r
.93645 .40941 .94422 .41875 .95496 .4158 .94727 .40653 Mtetra
.664 .741 .908 r
.36214 .56369 .37308 .57388 .38187 .57118 .37096 .56096 Mtetra
.37096 .56096 .38187 .57118 .39069 .56847 .37981 .55821 Mtetra
.37981 .55821 .39069 .56847 .39953 .56575 .3887 .55546 Mtetra
.3887 .55546 .39953 .56575 .4084 .56302 .39761 .5527 Mtetra
.39761 .5527 .4084 .56302 .41731 .56029 .40655 .54993 Mtetra
.40655 .54993 .41731 .56029 .42624 .55754 .41552 .54715 Mtetra
.41552 .54715 .42624 .55754 .4352 .55479 .42452 .54436 Mtetra
.42452 .54436 .4352 .55479 .4442 .55202 .43355 .54156 Mtetra
.43355 .54156 .4442 .55202 .45322 .54925 .44261 .53875 Mtetra
.44261 .53875 .45322 .54925 .46227 .54647 .4517 .53593 Mtetra
.4517 .53593 .46227 .54647 .47135 .54368 .46083 .53311 Mtetra
.663 .741 .908 r
.46083 .53311 .47135 .54368 .48047 .54087 .46998 .53027 Mtetra
.46998 .53027 .48047 .54087 .48961 .53807 .47916 .52743 Mtetra
.47916 .52743 .48961 .53807 .49878 .53525 .48838 .52458 Mtetra
.48838 .52458 .49878 .53525 .50799 .53242 .49763 .52172 Mtetra
.49763 .52172 .50799 .53242 .51723 .52959 .5069 .51886 Mtetra
.663 .741 .909 r
.5069 .51886 .51723 .52959 .52649 .52675 .51621 .516 Mtetra
.662 .742 .909 r
.51621 .516 .52649 .52675 .53579 .5239 .52555 .51313 Mtetra
.52555 .51313 .53579 .5239 .54512 .52105 .53493 .51026 Mtetra
.662 .742 .91 r
.53493 .51026 .54512 .52105 .55448 .51819 .54433 .50739 Mtetra
.661 .742 .91 r
.54433 .50739 .55448 .51819 .56388 .51533 .55377 .50452 Mtetra
.661 .743 .911 r
.55377 .50452 .56388 .51533 .57331 .51247 .56324 .50165 Mtetra
.66 .743 .911 r
.56324 .50165 .57331 .51247 .58276 .5096 .57274 .49878 Mtetra
.66 .744 .912 r
.57274 .49878 .58276 .5096 .59226 .50673 .58228 .49592 Mtetra
.659 .744 .913 r
.58228 .49592 .59226 .50673 .60178 .50387 .59185 .49306 Mtetra
.659 .745 .914 r
.59185 .49306 .60178 .50387 .61134 .501 .60145 .4902 Mtetra
.658 .746 .915 r
.60145 .4902 .61134 .501 .62093 .49813 .61109 .48734 Mtetra
.657 .746 .916 r
.61109 .48734 .62093 .49813 .63055 .49526 .62076 .48449 Mtetra
.657 .747 .917 r
.62076 .48449 .63055 .49526 .64021 .49239 .63047 .48164 Mtetra
.656 .748 .918 r
.63047 .48164 .64021 .49239 .64991 .48952 .64021 .4788 Mtetra
.655 .749 .919 r
.64021 .4788 .64991 .48952 .65963 .48665 .64999 .47596 Mtetra
.655 .75 .92 r
.64999 .47596 .65963 .48665 .6694 .48379 .65981 .47313 Mtetra
.654 .751 .921 r
.65981 .47313 .6694 .48379 .6792 .48092 .66966 .47029 Mtetra
.653 .753 .923 r
.66966 .47029 .6792 .48092 .68903 .47806 .67954 .46747 Mtetra
.653 .754 .924 r
.67954 .46747 .68903 .47806 .6989 .47519 .68947 .46464 Mtetra
.652 .755 .925 r
.68947 .46464 .6989 .47519 .7088 .47233 .69943 .46182 Mtetra
.651 .756 .927 r
.69943 .46182 .7088 .47233 .71874 .46947 .70943 .459 Mtetra
.65 .758 .928 r
.70943 .459 .71874 .46947 .72872 .46661 .71946 .45619 Mtetra
.65 .759 .929 r
.71946 .45619 .72872 .46661 .73874 .46375 .72954 .45337 Mtetra
.649 .761 .931 r
.72954 .45337 .73874 .46375 .74879 .4609 .73965 .45056 Mtetra
.648 .762 .932 r
.73965 .45056 .74879 .4609 .75888 .45804 .7498 .44776 Mtetra
.647 .764 .934 r
.7498 .44776 .75888 .45804 .76901 .45518 .75999 .44495 Mtetra
.646 .765 .935 r
.75999 .44495 .76901 .45518 .77917 .45233 .77022 .44214 Mtetra
.646 .767 .937 r
.77022 .44214 .77917 .45233 .78938 .44947 .78048 .43934 Mtetra
.645 .768 .938 r
.78048 .43934 .78938 .44947 .79962 .44662 .79079 .43654 Mtetra
.644 .77 .94 r
.79079 .43654 .79962 .44662 .8099 .44376 .80114 .43374 Mtetra
.643 .772 .941 r
.80114 .43374 .8099 .44376 .82023 .44091 .81153 .43093 Mtetra
.642 .773 .943 r
.81153 .43093 .82023 .44091 .83059 .43805 .82196 .42813 Mtetra
.641 .775 .944 r
.82196 .42813 .83059 .43805 .84099 .43519 .83243 .42533 Mtetra
.64 .777 .946 r
.83243 .42533 .84099 .43519 .85143 .43233 .84294 .42253 Mtetra
.639 .778 .948 r
.84294 .42253 .85143 .43233 .86191 .42947 .8535 .41972 Mtetra
.638 .78 .949 r
.8535 .41972 .86191 .42947 .87244 .42661 .86409 .41692 Mtetra
.637 .782 .951 r
.86409 .41692 .87244 .42661 .883 .42375 .87473 .41411 Mtetra
.636 .784 .952 r
.87473 .41411 .883 .42375 .89361 .42089 .88541 .41131 Mtetra
.635 .785 .954 r
.88541 .41131 .89361 .42089 .90425 .41802 .89614 .4085 Mtetra
.634 .787 .955 r
.89614 .4085 .90425 .41802 .91494 .41515 .90691 .40569 Mtetra
.633 .789 .957 r
.90691 .40569 .91494 .41515 .92568 .41228 .91772 .40287 Mtetra
.632 .791 .958 r
.91772 .40287 .92568 .41228 .93645 .40941 .92857 .40006 Mtetra
.631 .792 .96 r
.92857 .40006 .93645 .40941 .94727 .40653 .93947 .39724 Mtetra
.664 .741 .908 r
.35106 .55337 .36214 .56369 .37096 .56096 .35992 .5506 Mtetra
.35992 .5506 .37096 .56096 .37981 .55821 .36881 .54783 Mtetra
.36881 .54783 .37981 .55821 .3887 .55546 .37773 .54504 Mtetra
.37773 .54504 .3887 .55546 .39761 .5527 .38668 .54224 Mtetra
.38668 .54224 .39761 .5527 .40655 .54993 .39565 .53944 Mtetra
.39565 .53944 .40655 .54993 .41552 .54715 .40466 .53662 Mtetra
.40466 .53662 .41552 .54715 .42452 .54436 .4137 .5338 Mtetra
.4137 .5338 .42452 .54436 .43355 .54156 .42277 .53096 Mtetra
.42277 .53096 .43355 .54156 .44261 .53875 .43187 .52812 Mtetra
.43187 .52812 .44261 .53875 .4517 .53593 .441 .52527 Mtetra
.663 .741 .908 r
.441 .52527 .4517 .53593 .46083 .53311 .45017 .52241 Mtetra
.45017 .52241 .46083 .53311 .46998 .53027 .45936 .51954 Mtetra
.45936 .51954 .46998 .53027 .47916 .52743 .46858 .51666 Mtetra
.46858 .51666 .47916 .52743 .48838 .52458 .47784 .51379 Mtetra
.663 .741 .909 r
.47784 .51379 .48838 .52458 .49763 .52172 .48713 .5109 Mtetra
.662 .742 .909 r
.48713 .5109 .49763 .52172 .5069 .51886 .49645 .50802 Mtetra
.49645 .50802 .5069 .51886 .51621 .516 .5058 .50514 Mtetra
.661 .742 .91 r
.5058 .50514 .51621 .516 .52555 .51313 .51518 .50226 Mtetra
.51518 .50226 .52555 .51313 .53493 .51026 .5246 .49938 Mtetra
.66 .743 .911 r
.5246 .49938 .53493 .51026 .54433 .50739 .53404 .4965 Mtetra
.66 .743 .912 r
.53404 .4965 .54433 .50739 .55377 .50452 .54353 .49363 Mtetra
.659 .744 .912 r
.54353 .49363 .55377 .50452 .56324 .50165 .55304 .49077 Mtetra
.658 .744 .913 r
.55304 .49077 .56324 .50165 .57274 .49878 .56259 .48791 Mtetra
.658 .745 .914 r
.56259 .48791 .57274 .49878 .58228 .49592 .57217 .48506 Mtetra
.657 .745 .915 r
.57217 .48506 .58228 .49592 .59185 .49306 .58179 .48222 Mtetra
.656 .746 .916 r
.58179 .48222 .59185 .49306 .60145 .4902 .59144 .47938 Mtetra
.655 .747 .917 r
.59144 .47938 .60145 .4902 .61109 .48734 .60112 .47655 Mtetra
.655 .748 .919 r
.60112 .47655 .61109 .48734 .62076 .48449 .61085 .47372 Mtetra
.654 .749 .92 r
.61085 .47372 .62076 .48449 .63047 .48164 .6206 .47091 Mtetra
.653 .75 .921 r
.6206 .47091 .63047 .48164 .64021 .4788 .6304 .4681 Mtetra
.652 .751 .922 r
.6304 .4681 .64021 .4788 .64999 .47596 .64023 .46529 Mtetra
.651 .752 .924 r
.64023 .46529 .64999 .47596 .65981 .47313 .65009 .46249 Mtetra
.65 .754 .925 r
.65009 .46249 .65981 .47313 .66966 .47029 .66 .4597 Mtetra
.65 .755 .926 r
.66 .4597 .66966 .47029 .67954 .46747 .66994 .45692 Mtetra
.649 .756 .928 r
.66994 .45692 .67954 .46747 .68947 .46464 .67992 .45413 Mtetra
.648 .758 .929 r
.67992 .45413 .68947 .46464 .69943 .46182 .68993 .45136 Mtetra
.647 .759 .931 r
.68993 .45136 .69943 .46182 .70943 .459 .69999 .44858 Mtetra
.646 .76 .932 r
.69999 .44858 .70943 .459 .71946 .45619 .71008 .44582 Mtetra
.645 .762 .934 r
.71008 .44582 .71946 .45619 .72954 .45337 .72021 .44305 Mtetra
.644 .763 .935 r
.72021 .44305 .72954 .45337 .73965 .45056 .73039 .44029 Mtetra
.643 .765 .937 r
.73039 .44029 .73965 .45056 .7498 .44776 .7406 .43753 Mtetra
.643 .766 .938 r
.7406 .43753 .7498 .44776 .75999 .44495 .75085 .43477 Mtetra
.642 .768 .94 r
.75085 .43477 .75999 .44495 .77022 .44214 .76114 .43202 Mtetra
.641 .769 .941 r
.76114 .43202 .77022 .44214 .78048 .43934 .77147 .42926 Mtetra
.64 .771 .943 r
.77147 .42926 .78048 .43934 .79079 .43654 .78185 .42651 Mtetra
.639 .772 .944 r
.78185 .42651 .79079 .43654 .80114 .43374 .79226 .42376 Mtetra
.638 .774 .945 r
.79226 .42376 .80114 .43374 .81153 .43093 .80272 .42101 Mtetra
.637 .776 .947 r
.80272 .42101 .81153 .43093 .82196 .42813 .81322 .41826 Mtetra
.636 .777 .948 r
.81322 .41826 .82196 .42813 .83243 .42533 .82376 .41551 Mtetra
.635 .779 .95 r
.82376 .41551 .83243 .42533 .84294 .42253 .83434 .41276 Mtetra
.634 .78 .951 r
.83434 .41276 .84294 .42253 .8535 .41972 .84497 .41 Mtetra
.633 .782 .953 r
.84497 .41 .8535 .41972 .86409 .41692 .85564 .40725 Mtetra
.632 .784 .954 r
.85564 .40725 .86409 .41692 .87473 .41411 .86635 .4045 Mtetra
.631 .785 .956 r
.86635 .4045 .87473 .41411 .88541 .41131 .87711 .40174 Mtetra
.63 .787 .957 r
.87711 .40174 .88541 .41131 .89614 .4085 .88791 .39898 Mtetra
.629 .788 .958 r
.88791 .39898 .89614 .4085 .90691 .40569 .89876 .39622 Mtetra
.628 .79 .96 r
.89876 .39622 .90691 .40569 .91772 .40287 .90965 .39346 Mtetra
.627 .792 .961 r
.90965 .39346 .91772 .40287 .92857 .40006 .92059 .39069 Mtetra
.626 .793 .963 r
.92059 .39069 .92857 .40006 .93947 .39724 .93157 .38792 Mtetra
.664 .741 .908 r
.33984 .54293 .35106 .55337 .35992 .5506 .34873 .54012 Mtetra
.34873 .54012 .35992 .5506 .36881 .54783 .35766 .53731 Mtetra
.35766 .53731 .36881 .54783 .37773 .54504 .36662 .53449 Mtetra
.36662 .53449 .37773 .54504 .38668 .54224 .3756 .53165 Mtetra
.3756 .53165 .38668 .54224 .39565 .53944 .38462 .52881 Mtetra
.38462 .52881 .39565 .53944 .40466 .53662 .39367 .52596 Mtetra
.39367 .52596 .40466 .53662 .4137 .5338 .40275 .5231 Mtetra
.40275 .5231 .4137 .5338 .42277 .53096 .41186 .52023 Mtetra
.663 .741 .908 r
.41186 .52023 .42277 .53096 .43187 .52812 .421 .51735 Mtetra
.421 .51735 .43187 .52812 .441 .52527 .43017 .51446 Mtetra
.43017 .51446 .441 .52527 .45017 .52241 .43937 .51157 Mtetra
.43937 .51157 .45017 .52241 .45936 .51954 .4486 .50867 Mtetra
.4486 .50867 .45936 .51954 .46858 .51666 .45787 .50577 Mtetra
.662 .741 .909 r
.45787 .50577 .46858 .51666 .47784 .51379 .46717 .50287 Mtetra
.662 .742 .909 r
.46717 .50287 .47784 .51379 .48713 .5109 .47649 .49997 Mtetra
.661 .742 .91 r
.47649 .49997 .48713 .5109 .49645 .50802 .48585 .49707 Mtetra
.48585 .49707 .49645 .50802 .5058 .50514 .49525 .49418 Mtetra
.66 .742 .911 r
.49525 .49418 .5058 .50514 .51518 .50226 .50467 .4913 Mtetra
.659 .743 .912 r
.50467 .4913 .51518 .50226 .5246 .49938 .51413 .48842 Mtetra
.51413 .48842 .5246 .49938 .53404 .4965 .52362 .48555 Mtetra
.658 .744 .913 r
.52362 .48555 .53404 .4965 .54353 .49363 .53315 .48269 Mtetra
.657 .744 .914 r
.53315 .48269 .54353 .49363 .55304 .49077 .54271 .47984 Mtetra
.656 .745 .916 r
.54271 .47984 .55304 .49077 .56259 .48791 .5523 .47701 Mtetra
.655 .746 .917 r
.5523 .47701 .56259 .48791 .57217 .48506 .56193 .47418 Mtetra
.654 .747 .918 r
.56193 .47418 .57217 .48506 .58179 .48222 .57159 .47136 Mtetra
.653 .748 .919 r
.57159 .47136 .58179 .48222 .59144 .47938 .58129 .46855 Mtetra
.652 .749 .92 r
.58129 .46855 .59144 .47938 .60112 .47655 .59103 .46575 Mtetra
.651 .75 .922 r
.59103 .46575 .60112 .47655 .61085 .47372 .6008 .46296 Mtetra
.65 .751 .923 r
.6008 .46296 .61085 .47372 .6206 .47091 .61061 .46018 Mtetra
.649 .752 .925 r
.61061 .46018 .6206 .47091 .6304 .4681 .62045 .45741 Mtetra
.648 .753 .926 r
.62045 .45741 .6304 .4681 .64023 .46529 .63033 .45465 Mtetra
.647 .755 .927 r
.63033 .45465 .64023 .46529 .65009 .46249 .64025 .45189 Mtetra
.646 .756 .929 r
.64025 .45189 .65009 .46249 .66 .4597 .65021 .44915 Mtetra
.645 .757 .93 r
.65021 .44915 .66 .4597 .66994 .45692 .6602 .4464 Mtetra
.644 .758 .932 r
.6602 .4464 .66994 .45692 .67992 .45413 .67024 .44367 Mtetra
.644 .76 .933 r
.67024 .44367 .67992 .45413 .68993 .45136 .68031 .44094 Mtetra
.643 .761 .935 r
.68031 .44094 .68993 .45136 .69999 .44858 .69043 .43821 Mtetra
.642 .763 .936 r
.69043 .43821 .69999 .44858 .71008 .44582 .70058 .43549 Mtetra
.641 .764 .938 r
.70058 .43549 .71008 .44582 .72021 .44305 .71077 .43277 Mtetra
.64 .766 .939 r
.71077 .43277 .72021 .44305 .73039 .44029 .721 .43006 Mtetra
.639 .767 .941 r
.721 .43006 .73039 .44029 .7406 .43753 .73128 .42735 Mtetra
.638 .769 .942 r
.73128 .42735 .7406 .43753 .75085 .43477 .74159 .42464 Mtetra
.637 .77 .944 r
.74159 .42464 .75085 .43477 .76114 .43202 .75195 .42194 Mtetra
.636 .772 .945 r
.75195 .42194 .76114 .43202 .77147 .42926 .76235 .41923 Mtetra
.635 .773 .947 r
.76235 .41923 .77147 .42926 .78185 .42651 .77279 .41653 Mtetra
.634 .775 .948 r
.77279 .41653 .78185 .42651 .79226 .42376 .78327 .41383 Mtetra
.633 .776 .949 r
.78327 .41383 .79226 .42376 .80272 .42101 .7938 .41113 Mtetra
.632 .778 .951 r
.7938 .41113 .80272 .42101 .81322 .41826 .80436 .40842 Mtetra
.631 .779 .952 r
.80436 .40842 .81322 .41826 .82376 .41551 .81498 .40572 Mtetra
.63 .781 .954 r
.81498 .40572 .82376 .41551 .83434 .41276 .82563 .40302 Mtetra
.629 .782 .955 r
.82563 .40302 .83434 .41276 .84497 .41 .83633 .40031 Mtetra
.628 .784 .956 r
.83633 .40031 .84497 .41 .85564 .40725 .84708 .39761 Mtetra
.627 .785 .958 r
.84708 .39761 .85564 .40725 .86635 .4045 .85787 .3949 Mtetra
.626 .787 .959 r
.85787 .3949 .86635 .4045 .87711 .40174 .8687 .39219 Mtetra
.625 .788 .96 r
.8687 .39219 .87711 .40174 .88791 .39898 .87958 .38948 Mtetra
.624 .79 .962 r
.87958 .38948 .88791 .39898 .89876 .39622 .8905 .38677 Mtetra
.623 .791 .963 r
.8905 .38677 .89876 .39622 .90965 .39346 .90148 .38405 Mtetra
.622 .793 .964 r
.90148 .38405 .90965 .39346 .92059 .39069 .91249 .38133 Mtetra
.62 .794 .965 r
.91249 .38133 .92059 .39069 .93157 .38792 .92356 .3786 Mtetra
.664 .741 .908 r
.32848 .53235 .33984 .54293 .34873 .54012 .33741 .52951 Mtetra
.33741 .52951 .34873 .54012 .35766 .53731 .34637 .52666 Mtetra
.34637 .52666 .35766 .53731 .36662 .53449 .35537 .5238 Mtetra
.35537 .5238 .36662 .53449 .3756 .53165 .36439 .52093 Mtetra
.36439 .52093 .3756 .53165 .38462 .52881 .37345 .51805 Mtetra
.37345 .51805 .38462 .52881 .39367 .52596 .38254 .51517 Mtetra
.38254 .51517 .39367 .52596 .40275 .5231 .39165 .51227 Mtetra
.39165 .51227 .40275 .5231 .41186 .52023 .4008 .50936 Mtetra
.663 .741 .908 r
.4008 .50936 .41186 .52023 .421 .51735 .40998 .50645 Mtetra
.40998 .50645 .421 .51735 .43017 .51446 .41919 .50353 Mtetra
.41919 .50353 .43017 .51446 .43937 .51157 .42843 .5006 Mtetra
.42843 .5006 .43937 .51157 .4486 .50867 .43771 .49768 Mtetra
.662 .741 .909 r
.43771 .49768 .4486 .50867 .45787 .50577 .44701 .49476 Mtetra
.44701 .49476 .45787 .50577 .46717 .50287 .45635 .49184 Mtetra
.661 .742 .91 r
.45635 .49184 .46717 .50287 .47649 .49997 .46572 .48893 Mtetra
.66 .742 .911 r
.46572 .48893 .47649 .49997 .48585 .49707 .47512 .48603 Mtetra
.659 .742 .911 r
.47512 .48603 .48585 .49707 .49525 .49418 .48456 .48314 Mtetra
.658 .743 .912 r
.48456 .48314 .49525 .49418 .50467 .4913 .49403 .48026 Mtetra
.657 .743 .913 r
.49403 .48026 .50467 .4913 .51413 .48842 .50353 .47739 Mtetra
.656 .744 .914 r
.50353 .47739 .51413 .48842 .52362 .48555 .51306 .47454 Mtetra
.655 .745 .916 r
.51306 .47454 .52362 .48555 .53315 .48269 .52263 .4717 Mtetra
.654 .745 .917 r
.52263 .4717 .53315 .48269 .54271 .47984 .53224 .46888 Mtetra
.653 .746 .918 r
.53224 .46888 .54271 .47984 .5523 .47701 .54188 .46607 Mtetra
.652 .747 .92 r
.54188 .46607 .5523 .47701 .56193 .47418 .55155 .46328 Mtetra
.651 .748 .921 r
.55155 .46328 .56193 .47418 .57159 .47136 .56126 .46049 Mtetra
.65 .749 .922 r
.56126 .46049 .57159 .47136 .58129 .46855 .57101 .45772 Mtetra
.649 .75 .924 r
.57101 .45772 .58129 .46855 .59103 .46575 .58079 .45496 Mtetra
.647 .752 .925 r
.58079 .45496 .59103 .46575 .6008 .46296 .59062 .45222 Mtetra
.646 .753 .927 r
.59062 .45222 .6008 .46296 .61061 .46018 .60047 .44948 Mtetra
.645 .754 .928 r
.60047 .44948 .61061 .46018 .62045 .45741 .61037 .44675 Mtetra
.644 .755 .93 r
.61037 .44675 .62045 .45741 .63033 .45465 .6203 .44404 Mtetra
.643 .757 .931 r
.6203 .44404 .63033 .45465 .64025 .45189 .63028 .44133 Mtetra
.642 .758 .933 r
.63028 .44133 .64025 .45189 .65021 .44915 .64029 .43863 Mtetra
.641 .759 .934 r
.64029 .43863 .65021 .44915 .6602 .4464 .65034 .43593 Mtetra
.64 .761 .936 r
.65034 .43593 .6602 .4464 .67024 .44367 .66043 .43325 Mtetra
.639 .762 .937 r
.66043 .43325 .67024 .44367 .68031 .44094 .67056 .43056 Mtetra
.638 .764 .939 r
.67056 .43056 .68031 .44094 .69043 .43821 .68073 .42789 Mtetra
.637 .765 .94 r
.68073 .42789 .69043 .43821 .70058 .43549 .69095 .42522 Mtetra
.636 .766 .942 r
.69095 .42522 .70058 .43549 .71077 .43277 .7012 .42255 Mtetra
.635 .768 .943 r
.7012 .42255 .71077 .43277 .721 .43006 .7115 .41988 Mtetra
.634 .769 .945 r
.7115 .41988 .721 .43006 .73128 .42735 .72183 .41722 Mtetra
.633 .771 .946 r
.72183 .41722 .73128 .42735 .74159 .42464 .73221 .41456 Mtetra
.632 .772 .948 r
.73221 .41456 .74159 .42464 .75195 .42194 .74263 .4119 Mtetra
.631 .774 .949 r
.74263 .4119 .75195 .42194 .76235 .41923 .7531 .40925 Mtetra
.63 .775 .95 r
.7531 .40925 .76235 .41923 .77279 .41653 .7636 .40659 Mtetra
.629 .777 .952 r
.7636 .40659 .77279 .41653 .78327 .41383 .77415 .40394 Mtetra
.628 .778 .953 r
.77415 .40394 .78327 .41383 .7938 .41113 .78475 .40128 Mtetra
.627 .78 .955 r
.78475 .40128 .7938 .41113 .80436 .40842 .79539 .39863 Mtetra
.626 .781 .956 r
.79539 .39863 .80436 .40842 .81498 .40572 .80607 .39597 Mtetra
.624 .783 .957 r
.80607 .39597 .81498 .40572 .82563 .40302 .8168 .39331 Mtetra
.623 .784 .959 r
.8168 .39331 .82563 .40302 .83633 .40031 .82757 .39065 Mtetra
.622 .786 .96 r
.82757 .39065 .83633 .40031 .84708 .39761 .83839 .38799 Mtetra
.621 .787 .961 r
.83839 .38799 .84708 .39761 .85787 .3949 .84926 .38533 Mtetra
.62 .789 .962 r
.84926 .38533 .85787 .3949 .8687 .39219 .86017 .38266 Mtetra
.619 .79 .964 r
.86017 .38266 .8687 .39219 .87958 .38948 .87113 .38 Mtetra
.618 .791 .965 r
.87113 .38 .87958 .38948 .8905 .38677 .88213 .37732 Mtetra
.617 .793 .966 r
.88213 .37732 .8905 .38677 .90148 .38405 .89319 .37465 Mtetra
.616 .794 .967 r
.89319 .37465 .90148 .38405 .91249 .38133 .90429 .37197 Mtetra
.615 .796 .968 r
.90429 .37197 .91249 .38133 .92356 .3786 .91544 .36929 Mtetra
.664 .741 .908 r
.31697 .52163 .32848 .53235 .33741 .52951 .32594 .51876 Mtetra
.32594 .51876 .33741 .52951 .34637 .52666 .33494 .51587 Mtetra
.33494 .51587 .34637 .52666 .35537 .5238 .34398 .51298 Mtetra
.34398 .51298 .35537 .5238 .36439 .52093 .35304 .51007 Mtetra
.35304 .51007 .36439 .52093 .37345 .51805 .36213 .50716 Mtetra
.36213 .50716 .37345 .51805 .38254 .51517 .37126 .50423 Mtetra
.37126 .50423 .38254 .51517 .39165 .51227 .38042 .5013 Mtetra
.663 .741 .908 r
.38042 .5013 .39165 .51227 .4008 .50936 .3896 .49836 Mtetra
.3896 .49836 .4008 .50936 .40998 .50645 .39882 .49541 Mtetra
.39882 .49541 .40998 .50645 .41919 .50353 .40807 .49246 Mtetra
.663 .741 .909 r
.40807 .49246 .41919 .50353 .42843 .5006 .41736 .48951 Mtetra
.662 .741 .909 r
.41736 .48951 .42843 .5006 .43771 .49768 .42667 .48656 Mtetra
.661 .741 .91 r
.42667 .48656 .43771 .49768 .44701 .49476 .43602 .48363 Mtetra
.66 .742 .91 r
.43602 .48363 .44701 .49476 .45635 .49184 .4454 .4807 Mtetra
.659 .742 .911 r
.4454 .4807 .45635 .49184 .46572 .48893 .45481 .47779 Mtetra
.658 .742 .912 r
.45481 .47779 .46572 .48893 .47512 .48603 .46425 .47489 Mtetra
.657 .743 .913 r
.46425 .47489 .47512 .48603 .48456 .48314 .47373 .47202 Mtetra
.656 .743 .914 r
.47373 .47202 .48456 .48314 .49403 .48026 .48324 .46916 Mtetra
.655 .744 .916 r
.48324 .46916 .49403 .48026 .50353 .47739 .49278 .46631 Mtetra
.653 .745 .917 r
.49278 .46631 .50353 .47739 .51306 .47454 .50236 .46349 Mtetra
.652 .746 .918 r
.50236 .46349 .51306 .47454 .52263 .4717 .51198 .46068 Mtetra
.651 .747 .92 r
.51198 .46068 .52263 .4717 .53224 .46888 .52163 .4579 Mtetra
.649 .748 .921 r
.52163 .4579 .53224 .46888 .54188 .46607 .53131 .45512 Mtetra
.648 .749 .923 r
.53131 .45512 .54188 .46607 .55155 .46328 .54104 .45237 Mtetra
.647 .75 .924 r
.54104 .45237 .55155 .46328 .56126 .46049 .55079 .44963 Mtetra
.646 .751 .926 r
.55079 .44963 .56126 .46049 .57101 .45772 .56059 .4469 Mtetra
.644 .752 .927 r
.56059 .4469 .57101 .45772 .58079 .45496 .57042 .44419 Mtetra
.643 .753 .929 r
.57042 .44419 .58079 .45496 .59062 .45222 .58029 .44149 Mtetra
.642 .755 .931 r
.58029 .44149 .59062 .45222 .60047 .44948 .5902 .4388 Mtetra
.641 .756 .932 r
.5902 .4388 .60047 .44948 .61037 .44675 .60015 .43613 Mtetra
.64 .757 .934 r
.60015 .43613 .61037 .44675 .6203 .44404 .61014 .43346 Mtetra
.638 .759 .935 r
.61014 .43346 .6203 .44404 .63028 .44133 .62017 .4308 Mtetra
.637 .76 .937 r
.62017 .4308 .63028 .44133 .64029 .43863 .63024 .42815 Mtetra
.636 .762 .938 r
.63024 .42815 .64029 .43863 .65034 .43593 .64034 .42551 Mtetra
.635 .763 .94 r
.64034 .42551 .65034 .43593 .66043 .43325 .65049 .42287 Mtetra
.634 .764 .941 r
.65049 .42287 .66043 .43325 .67056 .43056 .66068 .42024 Mtetra
.633 .766 .943 r
.66068 .42024 .67056 .43056 .68073 .42789 .67091 .41761 Mtetra
.632 .767 .944 r
.67091 .41761 .68073 .42789 .69095 .42522 .68118 .41499 Mtetra
.631 .769 .946 r
.68118 .41499 .69095 .42522 .7012 .42255 .6915 .41237 Mtetra
.63 .77 .947 r
.6915 .41237 .7012 .42255 .7115 .41988 .70186 .40976 Mtetra
.629 .772 .949 r
.70186 .40976 .7115 .41988 .72183 .41722 .71226 .40714 Mtetra
.627 .773 .95 r
.71226 .40714 .72183 .41722 .73221 .41456 .7227 .40453 Mtetra
.626 .775 .952 r
.7227 .40453 .73221 .41456 .74263 .4119 .73319 .40192 Mtetra
.625 .776 .953 r
.73319 .40192 .74263 .4119 .7531 .40925 .74372 .39931 Mtetra
.624 .777 .954 r
.74372 .39931 .7531 .40925 .7636 .40659 .75429 .3967 Mtetra
.623 .779 .956 r
.75429 .3967 .7636 .40659 .77415 .40394 .76491 .3941 Mtetra
.622 .78 .957 r
.76491 .3941 .77415 .40394 .78475 .40128 .77558 .39149 Mtetra
.621 .782 .958 r
.77558 .39149 .78475 .40128 .79539 .39863 .78629 .38887 Mtetra
.62 .783 .96 r
.78629 .38887 .79539 .39863 .80607 .39597 .79704 .38626 Mtetra
.619 .785 .961 r
.79704 .38626 .80607 .39597 .8168 .39331 .80785 .38365 Mtetra
.618 .786 .962 r
.80785 .38365 .8168 .39331 .82757 .39065 .8187 .38103 Mtetra
.617 .788 .963 r
.8187 .38103 .82757 .39065 .83839 .38799 .82959 .37841 Mtetra
.616 .789 .965 r
.82959 .37841 .83839 .38799 .84926 .38533 .84053 .37579 Mtetra
.615 .79 .966 r
.84053 .37579 .84926 .38533 .86017 .38266 .85152 .37317 Mtetra
.614 .792 .967 r
.85152 .37317 .86017 .38266 .87113 .38 .86256 .37054 Mtetra
.613 .793 .968 r
.86256 .37054 .87113 .38 .88213 .37732 .87365 .36791 Mtetra
.611 .794 .969 r
.87365 .36791 .88213 .37732 .89319 .37465 .88478 .36527 Mtetra
.61 .796 .97 r
.88478 .36527 .89319 .37465 .90429 .37197 .89597 .36263 Mtetra
.609 .797 .971 r
.89597 .36263 .90429 .37197 .91544 .36929 .9072 .35999 Mtetra
.664 .741 .908 r
.30532 .51078 .31697 .52163 .32594 .51876 .31432 .50787 Mtetra
.31432 .50787 .32594 .51876 .33494 .51587 .32336 .50495 Mtetra
.32336 .50495 .33494 .51587 .34398 .51298 .33244 .50201 Mtetra
.33244 .50201 .34398 .51298 .35304 .51007 .34154 .49907 Mtetra
.34154 .49907 .35304 .51007 .36213 .50716 .35067 .49612 Mtetra
.35067 .49612 .36213 .50716 .37126 .50423 .35984 .49316 Mtetra
.663 .741 .908 r
.35984 .49316 .37126 .50423 .38042 .5013 .36903 .49019 Mtetra
.36903 .49019 .38042 .5013 .3896 .49836 .37826 .48721 Mtetra
.37826 .48721 .3896 .49836 .39882 .49541 .38752 .48423 Mtetra
.662 .741 .909 r
.38752 .48423 .39882 .49541 .40807 .49246 .39681 .48125 Mtetra
.39681 .48125 .40807 .49246 .41736 .48951 .40613 .47829 Mtetra
.661 .741 .91 r
.40613 .47829 .41736 .48951 .42667 .48656 .41549 .47533 Mtetra
.66 .742 .91 r
.41549 .47533 .42667 .48656 .43602 .48363 .42487 .47239 Mtetra
.658 .742 .911 r
.42487 .47239 .43602 .48363 .4454 .4807 .43429 .46947 Mtetra
.657 .742 .913 r
.43429 .46947 .4454 .4807 .45481 .47779 .44375 .46657 Mtetra
.656 .743 .914 r
.44375 .46657 .45481 .47779 .46425 .47489 .45323 .46369 Mtetra
.654 .743 .915 r
.45323 .46369 .46425 .47489 .47373 .47202 .46275 .46083 Mtetra
.653 .744 .917 r
.46275 .46083 .47373 .47202 .48324 .46916 .47231 .458 Mtetra
.651 .745 .918 r
.47231 .458 .48324 .46916 .49278 .46631 .48189 .45519 Mtetra
.65 .746 .92 r
.48189 .45519 .49278 .46631 .50236 .46349 .49152 .45241 Mtetra
.648 .747 .921 r
.49152 .45241 .50236 .46349 .51198 .46068 .50118 .44964 Mtetra
.647 .748 .923 r
.50118 .44964 .51198 .46068 .52163 .4579 .51087 .4469 Mtetra
.645 .749 .925 r
.51087 .4469 .52163 .4579 .53131 .45512 .5206 .44418 Mtetra
.644 .75 .926 r
.5206 .44418 .53131 .45512 .54104 .45237 .53037 .44147 Mtetra
.643 .751 .928 r
.53037 .44147 .54104 .45237 .55079 .44963 .54018 .43878 Mtetra
.641 .753 .93 r
.54018 .43878 .55079 .44963 .56059 .4469 .55002 .43611 Mtetra
.64 .754 .931 r
.55002 .43611 .56059 .4469 .57042 .44419 .55991 .43345 Mtetra
.639 .755 .933 r
.55991 .43345 .57042 .44419 .58029 .44149 .56983 .4308 Mtetra
.637 .757 .935 r
.56983 .4308 .58029 .44149 .5902 .4388 .57979 .42816 Mtetra
.636 .758 .936 r
.57979 .42816 .5902 .4388 .60015 .43613 .58979 .42554 Mtetra
.635 .759 .938 r
.58979 .42554 .60015 .43613 .61014 .43346 .59983 .42293 Mtetra
.633 .761 .939 r
.59983 .42293 .61014 .43346 .62017 .4308 .60992 .42032 Mtetra
.632 .762 .941 r
.60992 .42032 .62017 .4308 .63024 .42815 .62004 .41772 Mtetra
.631 .764 .943 r
.62004 .41772 .63024 .42815 .64034 .42551 .6302 .41513 Mtetra
.63 .765 .944 r
.6302 .41513 .64034 .42551 .65049 .42287 .64041 .41255 Mtetra
.629 .767 .946 r
.64041 .41255 .65049 .42287 .66068 .42024 .65066 .40997 Mtetra
.628 .768 .947 r
.65066 .40997 .66068 .42024 .67091 .41761 .66095 .40739 Mtetra
.626 .77 .949 r
.66095 .40739 .67091 .41761 .68118 .41499 .67128 .40482 Mtetra
.625 .771 .95 r
.67128 .40482 .68118 .41499 .6915 .41237 .68166 .40225 Mtetra
.624 .773 .952 r
.68166 .40225 .6915 .41237 .70186 .40976 .69208 .39969 Mtetra
.623 .774 .953 r
.69208 .39969 .70186 .40976 .71226 .40714 .70255 .39712 Mtetra
.622 .775 .954 r
.70255 .39712 .71226 .40714 .7227 .40453 .71306 .39456 Mtetra
.621 .777 .956 r
.71306 .39456 .7227 .40453 .73319 .40192 .72361 .392 Mtetra
.62 .778 .957 r
.72361 .392 .73319 .40192 .74372 .39931 .73421 .38944 Mtetra
.619 .78 .958 r
.73421 .38944 .74372 .39931 .75429 .3967 .74485 .38687 Mtetra
.618 .781 .96 r
.74485 .38687 .75429 .3967 .76491 .3941 .75554 .38431 Mtetra
.616 .783 .961 r
.75554 .38431 .76491 .3941 .77558 .39149 .76628 .38174 Mtetra
.615 .784 .962 r
.76628 .38174 .77558 .39149 .78629 .38887 .77706 .37918 Mtetra
.614 .785 .963 r
.77706 .37918 .78629 .38887 .79704 .38626 .78789 .37661 Mtetra
.613 .787 .965 r
.78789 .37661 .79704 .38626 .80785 .38365 .79877 .37404 Mtetra
.612 .788 .966 r
.79877 .37404 .80785 .38365 .8187 .38103 .80969 .37146 Mtetra
.611 .79 .967 r
.80969 .37146 .8187 .38103 .82959 .37841 .82066 .36888 Mtetra
.61 .791 .968 r
.82066 .36888 .82959 .37841 .84053 .37579 .83169 .3663 Mtetra
.609 .792 .969 r
.83169 .3663 .84053 .37579 .85152 .37317 .84275 .36372 Mtetra
.608 .794 .97 r
.84275 .36372 .85152 .37317 .86256 .37054 .85387 .36113 Mtetra
.607 .795 .971 r
.85387 .36113 .86256 .37054 .87365 .36791 .86504 .35853 Mtetra
.606 .796 .972 r
.86504 .35853 .87365 .36791 .88478 .36527 .87626 .35593 Mtetra
.604 .798 .973 r
.87626 .35593 .88478 .36527 .89597 .36263 .88753 .35333 Mtetra
.603 .799 .975 r
.88753 .35333 .89597 .36263 .9072 .35999 .89884 .35072 Mtetra
.664 .741 .908 r
.29351 .49979 .30532 .51078 .31432 .50787 .30256 .49684 Mtetra
.30256 .49684 .31432 .50787 .32336 .50495 .31164 .49388 Mtetra
.31164 .49388 .32336 .50495 .33244 .50201 .32075 .49091 Mtetra
.32075 .49091 .33244 .50201 .34154 .49907 .32989 .48793 Mtetra
.32989 .48793 .34154 .49907 .35067 .49612 .33906 .48494 Mtetra
.663 .741 .908 r
.33906 .48494 .35067 .49612 .35984 .49316 .34826 .48194 Mtetra
.34826 .48194 .35984 .49316 .36903 .49019 .3575 .47893 Mtetra
.3575 .47893 .36903 .49019 .37826 .48721 .36677 .47592 Mtetra
.662 .741 .909 r
.36677 .47592 .37826 .48721 .38752 .48423 .37607 .47292 Mtetra
.37607 .47292 .38752 .48423 .39681 .48125 .3854 .46992 Mtetra
.661 .741 .91 r
.3854 .46992 .39681 .48125 .40613 .47829 .39476 .46694 Mtetra
.659 .741 .911 r
.39476 .46694 .40613 .47829 .41549 .47533 .40416 .46399 Mtetra
.658 .742 .912 r
.40416 .46399 .41549 .47533 .42487 .47239 .41358 .46105 Mtetra
.656 .742 .913 r
.41358 .46105 .42487 .47239 .43429 .46947 .42304 .45815 Mtetra
.654 .743 .915 r
.42304 .45815 .43429 .46947 .44375 .46657 .43254 .45527 Mtetra
.653 .743 .916 r
.43254 .45527 .44375 .46657 .45323 .46369 .44206 .45242 Mtetra
.651 .744 .918 r
.44206 .45242 .45323 .46369 .46275 .46083 .45162 .44961 Mtetra
.649 .745 .919 r
.45162 .44961 .46275 .46083 .47231 .458 .46122 .44682 Mtetra
.648 .746 .921 r
.46122 .44682 .47231 .458 .48189 .45519 .47085 .44405 Mtetra
.646 .747 .923 r
.47085 .44405 .48189 .45519 .49152 .45241 .48052 .44132 Mtetra
.644 .748 .925 r
.48052 .44132 .49152 .45241 .50118 .44964 .49022 .4386 Mtetra
.642 .749 .926 r
.49022 .4386 .50118 .44964 .51087 .4469 .49997 .43591 Mtetra
.641 .751 .928 r
.49997 .43591 .51087 .4469 .5206 .44418 .50974 .43324 Mtetra
.639 .752 .93 r
.50974 .43324 .5206 .44418 .53037 .44147 .51956 .43059 Mtetra
.638 .753 .932 r
.51956 .43059 .53037 .44147 .54018 .43878 .52942 .42796 Mtetra
.636 .755 .934 r
.52942 .42796 .54018 .43878 .55002 .43611 .53931 .42534 Mtetra
.635 .756 .935 r
.53931 .42534 .55002 .43611 .55991 .43345 .54924 .42274 Mtetra
.633 .757 .937 r
.54924 .42274 .55991 .43345 .56983 .4308 .55922 .42015 Mtetra
.632 .759 .939 r
.55922 .42015 .56983 .4308 .57979 .42816 .56923 .41757 Mtetra
.631 .76 .941 r
.56923 .41757 .57979 .42816 .58979 .42554 .57929 .41501 Mtetra
.629 .762 .942 r
.57929 .41501 .58979 .42554 .59983 .42293 .58938 .41245 Mtetra
.628 .763 .944 r
.58938 .41245 .59983 .42293 .60992 .42032 .59952 .4099 Mtetra
.627 .765 .945 r
.59952 .4099 .60992 .42032 .62004 .41772 .6097 .40736 Mtetra
.625 .766 .947 r
.6097 .40736 .62004 .41772 .6302 .41513 .61992 .40482 Mtetra
.624 .768 .949 r
.61992 .40482 .6302 .41513 .64041 .41255 .63019 .40229 Mtetra
.623 .769 .95 r
.63019 .40229 .64041 .41255 .65066 .40997 .6405 .39977 Mtetra
.622 .771 .952 r
.6405 .39977 .65066 .40997 .66095 .40739 .65085 .39724 Mtetra
.621 .772 .953 r
.65085 .39724 .66095 .40739 .67128 .40482 .66124 .39472 Mtetra
.619 .774 .954 r
.66124 .39472 .67128 .40482 .68166 .40225 .67168 .3922 Mtetra
.618 .775 .956 r
.67168 .3922 .68166 .40225 .69208 .39969 .68217 .38969 Mtetra
.617 .777 .957 r
.68217 .38969 .69208 .39969 .70255 .39712 .6927 .38717 Mtetra
.616 .778 .959 r
.6927 .38717 .70255 .39712 .71306 .39456 .70327 .38466 Mtetra
.615 .779 .96 r
.70327 .38466 .71306 .39456 .72361 .392 .71389 .38214 Mtetra
.614 .781 .961 r
.71389 .38214 .72361 .392 .73421 .38944 .72456 .37963 Mtetra
.613 .782 .962 r
.72456 .37963 .73421 .38944 .74485 .38687 .73528 .37711 Mtetra
.611 .784 .964 r
.73528 .37711 .74485 .38687 .75554 .38431 .74604 .37459 Mtetra
.61 .785 .965 r
.74604 .37459 .75554 .38431 .76628 .38174 .75685 .37207 Mtetra
.609 .786 .966 r
.75685 .37207 .76628 .38174 .77706 .37918 .7677 .36954 Mtetra
.608 .788 .967 r
.7677 .36954 .77706 .37918 .78789 .37661 .77861 .36702 Mtetra
.607 .789 .968 r
.77861 .36702 .78789 .37661 .79877 .37404 .78956 .36449 Mtetra
.606 .791 .97 r
.78956 .36449 .79877 .37404 .80969 .37146 .80056 .36195 Mtetra
.605 .792 .971 r
.80056 .36195 .80969 .37146 .82066 .36888 .81161 .35941 Mtetra
.604 .793 .972 r
.81161 .35941 .82066 .36888 .83169 .3663 .82271 .35687 Mtetra
.603 .795 .973 r
.82271 .35687 .83169 .3663 .84275 .36372 .83386 .35432 Mtetra
.602 .796 .974 r
.83386 .35432 .84275 .36372 .85387 .36113 .84506 .35177 Mtetra
.6 .797 .975 r
.84506 .35177 .85387 .36113 .86504 .35853 .85631 .34921 Mtetra
.599 .798 .976 r
.85631 .34921 .86504 .35853 .87626 .35593 .86761 .34665 Mtetra
.598 .8 .977 r
.86761 .34665 .87626 .35593 .88753 .35333 .87897 .34408 Mtetra
.597 .801 .978 r
.87897 .34408 .88753 .35333 .89884 .35072 .89037 .3415 Mtetra
.664 .741 .908 r
.28155 .48866 .29351 .49979 .30256 .49684 .29064 .48567 Mtetra
.29064 .48567 .30256 .49684 .31164 .49388 .29976 .48267 Mtetra
.29976 .48267 .31164 .49388 .32075 .49091 .3089 .47966 Mtetra
.3089 .47966 .32075 .49091 .32989 .48793 .31808 .47664 Mtetra
.31808 .47664 .32989 .48793 .33906 .48494 .3273 .47361 Mtetra
.663 .741 .908 r
.3273 .47361 .33906 .48494 .34826 .48194 .33654 .47058 Mtetra
.33654 .47058 .34826 .48194 .3575 .47893 .34582 .46753 Mtetra
.34582 .46753 .3575 .47893 .36677 .47592 .35512 .4645 Mtetra
.662 .741 .909 r
.35512 .4645 .36677 .47592 .37607 .47292 .36446 .46147 Mtetra
.66 .741 .91 r
.36446 .46147 .37607 .47292 .3854 .46992 .37383 .45847 Mtetra
.659 .741 .911 r
.37383 .45847 .3854 .46992 .39476 .46694 .38324 .45549 Mtetra
.657 .742 .912 r
.38324 .45549 .39476 .46694 .40416 .46399 .39267 .45255 Mtetra
.655 .742 .914 r
.39267 .45255 .40416 .46399 .41358 .46105 .40214 .44963 Mtetra
.653 .742 .915 r
.40214 .44963 .41358 .46105 .42304 .45815 .41164 .44676 Mtetra
.651 .743 .917 r
.41164 .44676 .42304 .45815 .43254 .45527 .42117 .44392 Mtetra
.649 .744 .919 r
.42117 .44392 .43254 .45527 .44206 .45242 .43074 .44112 Mtetra
.647 .745 .921 r
.43074 .44112 .44206 .45242 .45162 .44961 .44034 .43835 Mtetra
.645 .746 .923 r
.44034 .43835 .45162 .44961 .46122 .44682 .44998 .43561 Mtetra
.643 .747 .925 r
.44998 .43561 .46122 .44682 .47085 .44405 .45966 .43291 Mtetra
.641 .748 .927 r
.45966 .43291 .47085 .44405 .48052 .44132 .46937 .43023 Mtetra
.639 .75 .929 r
.46937 .43023 .48052 .44132 .49022 .4386 .47912 .42758 Mtetra
.637 .751 .93 r
.47912 .42758 .49022 .4386 .49997 .43591 .4889 .42495 Mtetra
.636 .752 .932 r
.4889 .42495 .49997 .43591 .50974 .43324 .49873 .42234 Mtetra
.634 .754 .934 r
.49873 .42234 .50974 .43324 .51956 .43059 .50859 .41976 Mtetra
.632 .755 .936 r
.50859 .41976 .51956 .43059 .52942 .42796 .5185 .41719 Mtetra
.631 .757 .938 r
.5185 .41719 .52942 .42796 .53931 .42534 .52844 .41463 Mtetra
.629 .758 .94 r
.52844 .41463 .53931 .42534 .54924 .42274 .53843 .41209 Mtetra
.628 .76 .942 r
.53843 .41209 .54924 .42274 .55922 .42015 .54845 .40956 Mtetra
.626 .761 .943 r
.54845 .40956 .55922 .42015 .56923 .41757 .55852 .40705 Mtetra
.625 .763 .945 r
.55852 .40705 .56923 .41757 .57929 .41501 .56863 .40454 Mtetra
.623 .764 .947 r
.56863 .40454 .57929 .41501 .58938 .41245 .57878 .40204 Mtetra
.622 .766 .948 r
.57878 .40204 .58938 .41245 .59952 .4099 .58897 .39955 Mtetra
.621 .767 .95 r
.58897 .39955 .59952 .4099 .6097 .40736 .59921 .39707 Mtetra
.619 .769 .952 r
.59921 .39707 .6097 .40736 .61992 .40482 .60949 .39459 Mtetra
.618 .77 .953 r
.60949 .39459 .61992 .40482 .63019 .40229 .61982 .39211 Mtetra
.617 .772 .955 r
.61982 .39211 .63019 .40229 .6405 .39977 .63018 .38964 Mtetra
.616 .773 .956 r
.63018 .38964 .6405 .39977 .65085 .39724 .6406 .38717 Mtetra
.614 .775 .957 r
.6406 .38717 .65085 .39724 .66124 .39472 .65106 .38471 Mtetra
.613 .776 .959 r
.65106 .38471 .66124 .39472 .67168 .3922 .66156 .38224 Mtetra
.612 .778 .96 r
.66156 .38224 .67168 .3922 .68217 .38969 .67211 .37977 Mtetra
.611 .779 .962 r
.67211 .37977 .68217 .38969 .6927 .38717 .68271 .37731 Mtetra
.61 .781 .963 r
.68271 .37731 .6927 .38717 .70327 .38466 .69335 .37484 Mtetra
.609 .782 .964 r
.69335 .37484 .70327 .38466 .71389 .38214 .70404 .37237 Mtetra
.607 .784 .965 r
.70404 .37237 .71389 .38214 .72456 .37963 .71478 .3699 Mtetra
.606 .785 .967 r
.71478 .3699 .72456 .37963 .73528 .37711 .72556 .36743 Mtetra
.605 .786 .968 r
.72556 .36743 .73528 .37711 .74604 .37459 .7364 .36496 Mtetra
.604 .788 .969 r
.7364 .36496 .74604 .37459 .75685 .37207 .74728 .36248 Mtetra
.603 .789 .97 r
.74728 .36248 .75685 .37207 .7677 .36954 .75821 .36 Mtetra
.602 .79 .971 r
.75821 .36 .7677 .36954 .77861 .36702 .76919 .35751 Mtetra
.601 .792 .972 r
.76919 .35751 .77861 .36702 .78956 .36449 .78022 .35502 Mtetra
.599 .793 .973 r
.78022 .35502 .78956 .36449 .80056 .36195 .7913 .35252 Mtetra
.598 .794 .974 r
.7913 .35252 .80056 .36195 .81161 .35941 .80243 .35002 Mtetra
.597 .796 .975 r
.80243 .35002 .81161 .35941 .82271 .35687 .81361 .34752 Mtetra
.596 .797 .976 r
.81361 .34752 .82271 .35687 .83386 .35432 .82484 .34501 Mtetra
.595 .798 .977 r
.82484 .34501 .83386 .35432 .84506 .35177 .83612 .34249 Mtetra
.594 .8 .978 r
.83612 .34249 .84506 .35177 .85631 .34921 .84746 .33997 Mtetra
.593 .801 .979 r
.84746 .33997 .85631 .34921 .86761 .34665 .85885 .33744 Mtetra
.592 .802 .98 r
.85885 .33744 .86761 .34665 .87897 .34408 .87029 .3349 Mtetra
.59 .803 .981 r
.87029 .3349 .87897 .34408 .89037 .3415 .88178 .33236 Mtetra
.664 .741 .908 r
.26944 .47738 .28155 .48866 .29064 .48567 .27857 .47435 Mtetra
.27857 .47435 .29064 .48567 .29976 .48267 .28772 .47131 Mtetra
.28772 .47131 .29976 .48267 .3089 .47966 .29691 .46827 Mtetra
.29691 .46827 .3089 .47966 .31808 .47664 .30613 .46521 Mtetra
.663 .741 .908 r
.30613 .46521 .31808 .47664 .3273 .47361 .31538 .46214 Mtetra
.31538 .46214 .3273 .47361 .33654 .47058 .32466 .45906 Mtetra
.32466 .45906 .33654 .47058 .34582 .46753 .33398 .45599 Mtetra
.662 .741 .909 r
.33398 .45599 .34582 .46753 .35512 .4645 .34332 .45293 Mtetra
.66 .741 .91 r
.34332 .45293 .35512 .4645 .36446 .46147 .3527 .4499 Mtetra
.659 .741 .911 r
.3527 .4499 .36446 .46147 .37383 .45847 .36211 .4469 Mtetra
.656 .741 .912 r
.36211 .4469 .37383 .45847 .38324 .45549 .37155 .44394 Mtetra
.654 .742 .914 r
.37155 .44394 .38324 .45549 .39267 .45255 .38103 .44102 Mtetra
.652 .742 .916 r
.38103 .44102 .39267 .45255 .40214 .44963 .39053 .43815 Mtetra
.649 .743 .918 r
.39053 .43815 .40214 .44963 .41164 .44676 .40007 .43532 Mtetra
.647 .744 .92 r
.40007 .43532 .41164 .44676 .42117 .44392 .40965 .43254 Mtetra
.645 .745 .922 r
.40965 .43254 .42117 .44392 .43074 .44112 .41926 .42979 Mtetra
.642 .746 .924 r
.41926 .42979 .43074 .44112 .44034 .43835 .4289 .42709 Mtetra
.64 .747 .926 r
.4289 .42709 .44034 .43835 .44998 .43561 .43858 .42442 Mtetra
.638 .748 .929 r
.43858 .42442 .44998 .43561 .45966 .43291 .4483 .42178 Mtetra
.636 .75 .931 r
.4483 .42178 .45966 .43291 .46937 .43023 .45806 .41917 Mtetra
.634 .751 .933 r
.45806 .41917 .46937 .43023 .47912 .42758 .46785 .41659 Mtetra
.632 .753 .935 r
.46785 .41659 .47912 .42758 .4889 .42495 .47768 .41403 Mtetra
.63 .754 .937 r
.47768 .41403 .4889 .42495 .49873 .42234 .48755 .41149 Mtetra
.628 .756 .939 r
.48755 .41149 .49873 .42234 .50859 .41976 .49747 .40898 Mtetra
.626 .757 .941 r
.49747 .40898 .50859 .41976 .5185 .41719 .50742 .40648 Mtetra
.625 .759 .943 r
.50742 .40648 .5185 .41719 .52844 .41463 .51741 .40399 Mtetra
.623 .76 .945 r
.51741 .40399 .52844 .41463 .53843 .41209 .52745 .40152 Mtetra
.621 .762 .946 r
.52745 .40152 .53843 .41209 .54845 .40956 .53753 .39906 Mtetra
.62 .764 .948 r
.53753 .39906 .54845 .40956 .55852 .40705 .54765 .39661 Mtetra
.618 .765 .95 r
.54765 .39661 .55852 .40705 .56863 .40454 .55781 .39416 Mtetra
.617 .767 .951 r
.55781 .39416 .56863 .40454 .57878 .40204 .56802 .39173 Mtetra
.616 .768 .953 r
.56802 .39173 .57878 .40204 .58897 .39955 .57827 .3893 Mtetra
.614 .77 .955 r
.57827 .3893 .58897 .39955 .59921 .39707 .58856 .38687 Mtetra
.613 .772 .956 r
.58856 .38687 .59921 .39707 .60949 .39459 .5989 .38445 Mtetra
.612 .773 .958 r
.5989 .38445 .60949 .39459 .61982 .39211 .60929 .38204 Mtetra
.61 .775 .959 r
.60929 .38204 .61982 .39211 .63018 .38964 .61972 .37962 Mtetra
.609 .776 .961 r
.61972 .37962 .63018 .38964 .6406 .38717 .6302 .37721 Mtetra
.608 .778 .962 r
.6302 .37721 .6406 .38717 .65106 .38471 .64072 .37479 Mtetra
.606 .779 .963 r
.64072 .37479 .65106 .38471 .66156 .38224 .65129 .37238 Mtetra
.605 .781 .965 r
.65129 .37238 .66156 .38224 .67211 .37977 .6619 .36996 Mtetra
.604 .782 .966 r
.6619 .36996 .67211 .37977 .68271 .37731 .67257 .36755 Mtetra
.603 .784 .967 r
.67257 .36755 .68271 .37731 .69335 .37484 .68328 .36513 Mtetra
.602 .785 .968 r
.68328 .36513 .69335 .37484 .70404 .37237 .69404 .36271 Mtetra
.6 .786 .97 r
.69404 .36271 .70404 .37237 .71478 .3699 .70485 .36028 Mtetra
.599 .788 .971 r
.70485 .36028 .71478 .3699 .72556 .36743 .7157 .35786 Mtetra
.598 .789 .972 r
.7157 .35786 .72556 .36743 .7364 .36496 .72661 .35543 Mtetra
.597 .791 .973 r
.72661 .35543 .7364 .36496 .74728 .36248 .73757 .35299 Mtetra
.596 .792 .974 r
.73757 .35299 .74728 .36248 .75821 .36 .74857 .35055 Mtetra
.595 .793 .975 r
.74857 .35055 .75821 .36 .76919 .35751 .75963 .34811 Mtetra
.593 .795 .976 r
.75963 .34811 .76919 .35751 .78022 .35502 .77074 .34566 Mtetra
.592 .796 .977 r
.77074 .34566 .78022 .35502 .7913 .35252 .7819 .3432 Mtetra
.591 .797 .978 r
.7819 .3432 .7913 .35252 .80243 .35002 .79311 .34074 Mtetra
.59 .798 .979 r
.79311 .34074 .80243 .35002 .81361 .34752 .80437 .33827 Mtetra
.589 .8 .98 r
.80437 .33827 .81361 .34752 .82484 .34501 .81569 .3358 Mtetra
.588 .801 .981 r
.81569 .3358 .82484 .34501 .83612 .34249 .82706 .33332 Mtetra
.587 .802 .982 r
.82706 .33332 .83612 .34249 .84746 .33997 .83848 .33083 Mtetra
.585 .803 .983 r
.83848 .33083 .84746 .33997 .85885 .33744 .84995 .32833 Mtetra
.584 .805 .983 r
.84995 .32833 .85885 .33744 .87029 .3349 .86148 .32583 Mtetra
.583 .806 .984 r
.86148 .32583 .87029 .3349 .88178 .33236 .87306 .32332 Mtetra
.664 .741 .908 r
.25717 .46595 .26944 .47738 .27857 .47435 .26633 .46289 Mtetra
.26633 .46289 .27857 .47435 .28772 .47131 .27553 .45981 Mtetra
.27553 .45981 .28772 .47131 .29691 .46827 .28475 .45672 Mtetra
.28475 .45672 .29691 .46827 .30613 .46521 .29401 .45362 Mtetra
.663 .741 .908 r
.29401 .45362 .30613 .46521 .31538 .46214 .3033 .45051 Mtetra
.3033 .45051 .31538 .46214 .32466 .45906 .31263 .4474 Mtetra
.662 .741 .909 r
.31263 .4474 .32466 .45906 .33398 .45599 .32198 .44431 Mtetra
.66 .741 .91 r
.32198 .44431 .33398 .45599 .34332 .45293 .33137 .44124 Mtetra
.658 .741 .911 r
.33137 .44124 .34332 .45293 .3527 .4499 .34078 .43822 Mtetra
.656 .741 .912 r
.34078 .43822 .3527 .4499 .36211 .4469 .35023 .43524 Mtetra
.653 .741 .914 r
.35023 .43524 .36211 .4469 .37155 .44394 .35971 .43231 Mtetra
.65 .742 .917 r
.35971 .43231 .37155 .44394 .38103 .44102 .36922 .42944 Mtetra
.648 .743 .919 r
.36922 .42944 .38103 .44102 .39053 .43815 .37877 .42662 Mtetra
.645 .744 .921 r
.37877 .42662 .39053 .43815 .40007 .43532 .38835 .42386 Mtetra
.642 .745 .924 r
.38835 .42386 .40007 .43532 .40965 .43254 .39796 .42114 Mtetra
.639 .746 .926 r
.39796 .42114 .40965 .43254 .41926 .42979 .40761 .41847 Mtetra
.637 .747 .928 r
.40761 .41847 .41926 .42979 .4289 .42709 .41729 .41584 Mtetra
.634 .749 .931 r
.41729 .41584 .4289 .42709 .43858 .42442 .42702 .41325 Mtetra
.632 .75 .933 r
.42702 .41325 .43858 .42442 .4483 .42178 .43678 .41069 Mtetra
.629 .752 .935 r
.43678 .41069 .4483 .42178 .45806 .41917 .44658 .40816 Mtetra
.627 .753 .938 r
.44658 .40816 .45806 .41917 .46785 .41659 .45642 .40566 Mtetra
.625 .755 .94 r
.45642 .40566 .46785 .41659 .47768 .41403 .46629 .40318 Mtetra
.623 .756 .942 r
.46629 .40318 .47768 .41403 .48755 .41149 .47621 .40072 Mtetra
.621 .758 .944 r
.47621 .40072 .48755 .41149 .49747 .40898 .48617 .39828 Mtetra
.62 .76 .946 r
.48617 .39828 .49747 .40898 .50742 .40648 .49618 .39585 Mtetra
.618 .761 .948 r
.49618 .39585 .50742 .40648 .51741 .40399 .50622 .39344 Mtetra
.616 .763 .95 r
.50622 .39344 .51741 .40399 .52745 .40152 .51631 .39104 Mtetra
.615 .765 .951 r
.51631 .39104 .52745 .40152 .53753 .39906 .52644 .38865 Mtetra
.613 .766 .953 r
.52644 .38865 .53753 .39906 .54765 .39661 .53661 .38627 Mtetra
.611 .768 .955 r
.53661 .38627 .54765 .39661 .55781 .39416 .54683 .38389 Mtetra
.61 .77 .957 r
.54683 .38389 .55781 .39416 .56802 .39173 .5571 .38152 Mtetra
.608 .771 .958 r
.5571 .38152 .56802 .39173 .57827 .3893 .5674 .37916 Mtetra
.607 .773 .96 r
.5674 .37916 .57827 .3893 .58856 .38687 .57776 .3768 Mtetra
.606 .775 .961 r
.57776 .3768 .58856 .38687 .5989 .38445 .58816 .37444 Mtetra
.604 .776 .963 r
.58816 .37444 .5989 .38445 .60929 .38204 .5986 .37208 Mtetra
.603 .778 .964 r
.5986 .37208 .60929 .38204 .61972 .37962 .6091 .36972 Mtetra
.602 .779 .965 r
.6091 .36972 .61972 .37962 .6302 .37721 .61964 .36736 Mtetra
.6 .781 .967 r
.61964 .36736 .6302 .37721 .64072 .37479 .63022 .365 Mtetra
.599 .782 .968 r
.63022 .365 .64072 .37479 .65129 .37238 .64086 .36264 Mtetra
.598 .784 .969 r
.64086 .36264 .65129 .37238 .6619 .36996 .65154 .36028 Mtetra
.597 .785 .971 r
.65154 .36028 .6619 .36996 .67257 .36755 .66228 .35792 Mtetra
.595 .787 .972 r
.66228 .35792 .67257 .36755 .68328 .36513 .67306 .35555 Mtetra
.594 .788 .973 r
.67306 .35555 .68328 .36513 .69404 .36271 .68389 .35317 Mtetra
.593 .79 .974 r
.68389 .35317 .69404 .36271 .70485 .36028 .69477 .3508 Mtetra
.592 .791 .975 r
.69477 .3508 .70485 .36028 .7157 .35786 .7057 .34842 Mtetra
.59 .792 .976 r
.7057 .34842 .7157 .35786 .72661 .35543 .71668 .34603 Mtetra
.589 .794 .977 r
.71668 .34603 .72661 .35543 .73757 .35299 .72771 .34364 Mtetra
.588 .795 .978 r
.72771 .34364 .73757 .35299 .74857 .35055 .7388 .34124 Mtetra
.587 .796 .979 r
.7388 .34124 .74857 .35055 .75963 .34811 .74993 .33884 Mtetra
.586 .798 .98 r
.74993 .33884 .75963 .34811 .77074 .34566 .76112 .33643 Mtetra
.585 .799 .981 r
.76112 .33643 .77074 .34566 .7819 .3432 .77236 .33401 Mtetra
.583 .8 .982 r
.77236 .33401 .7819 .3432 .79311 .34074 .78365 .33159 Mtetra
.582 .802 .983 r
.78365 .33159 .79311 .34074 .80437 .33827 .795 .32916 Mtetra
.581 .803 .984 r
.795 .32916 .80437 .33827 .81569 .3358 .8064 .32672 Mtetra
.58 .804 .985 r
.8064 .32672 .81569 .3358 .82706 .33332 .81786 .32428 Mtetra
.579 .805 .985 r
.81786 .32428 .82706 .33332 .83848 .33083 .82936 .32182 Mtetra
.577 .806 .986 r
.82936 .32182 .83848 .33083 .84995 .32833 .84093 .31936 Mtetra
.576 .808 .987 r
.84093 .31936 .84995 .32833 .86148 .32583 .85255 .31689 Mtetra
.575 .809 .988 r
.85255 .31689 .86148 .32583 .87306 .32332 .86422 .31441 Mtetra
.664 .741 .908 r
.24474 .45438 .25717 .46595 .26633 .46289 .25394 .45127 Mtetra
.25394 .45127 .26633 .46289 .27553 .45981 .26317 .44815 Mtetra
.26317 .44815 .27553 .45981 .28475 .45672 .27244 .44502 Mtetra
.27244 .44502 .28475 .45672 .29401 .45362 .28173 .44188 Mtetra
.663 .741 .908 r
.28173 .44188 .29401 .45362 .3033 .45051 .29107 .43873 Mtetra
.662 .741 .908 r
.29107 .43873 .3033 .45051 .31263 .4474 .30043 .4356 Mtetra
.661 .741 .909 r
.30043 .4356 .31263 .4474 .32198 .44431 .30982 .43249 Mtetra
.658 .741 .911 r
.30982 .43249 .32198 .44431 .33137 .44124 .31925 .42943 Mtetra
.656 .741 .912 r
.31925 .42943 .33137 .44124 .34078 .43822 .3287 .42643 Mtetra
.652 .741 .915 r
.3287 .42643 .34078 .43822 .35023 .43524 .33819 .42349 Mtetra
.649 .742 .917 r
.33819 .42349 .35023 .43524 .35971 .43231 .3477 .42062 Mtetra
.646 .742 .92 r
.3477 .42062 .35971 .43231 .36922 .42944 .35725 .41782 Mtetra
.642 .743 .922 r
.35725 .41782 .36922 .42944 .37877 .42662 .36683 .41508 Mtetra
.639 .744 .925 r
.36683 .41508 .37877 .42662 .38835 .42386 .37645 .4124 Mtetra
.636 .746 .928 r
.37645 .4124 .38835 .42386 .39796 .42114 .3861 .40977 Mtetra
.633 .747 .93 r
.3861 .40977 .39796 .42114 .40761 .41847 .39579 .40718 Mtetra
.63 .749 .933 r
.39579 .40718 .40761 .41847 .41729 .41584 .40551 .40465 Mtetra
.627 .75 .936 r
.40551 .40465 .41729 .41584 .42702 .41325 .41528 .40214 Mtetra
.625 .752 .938 r
.41528 .40214 .42702 .41325 .43678 .41069 .42508 .39967 Mtetra
.622 .754 .94 r
.42508 .39967 .43678 .41069 .44658 .40816 .43492 .39723 Mtetra
.62 .755 .943 r
.43492 .39723 .44658 .40816 .45642 .40566 .44481 .39482 Mtetra
.618 .757 .945 r
.44481 .39482 .45642 .40566 .46629 .40318 .45473 .39242 Mtetra
.616 .759 .947 r
.45473 .39242 .46629 .40318 .47621 .40072 .4647 .39005 Mtetra
.614 .761 .949 r
.4647 .39005 .47621 .40072 .48617 .39828 .47471 .38769 Mtetra
.612 .762 .951 r
.47471 .38769 .48617 .39828 .49618 .39585 .48476 .38535 Mtetra
.61 .764 .953 r
.48476 .38535 .49618 .39585 .50622 .39344 .49486 .38301 Mtetra
.608 .766 .955 r
.49486 .38301 .50622 .39344 .51631 .39104 .505 .38069 Mtetra
.607 .768 .957 r
.505 .38069 .51631 .39104 .52644 .38865 .51518 .37837 Mtetra
.605 .77 .959 r
.51518 .37837 .52644 .38865 .53661 .38627 .52541 .37606 Mtetra
.604 .771 .96 r
.52541 .37606 .53661 .38627 .54683 .38389 .53568 .37376 Mtetra
.602 .773 .962 r
.53568 .37376 .54683 .38389 .5571 .38152 .546 .37146 Mtetra
.601 .775 .963 r
.546 .37146 .5571 .38152 .5674 .37916 .55637 .36916 Mtetra
.599 .776 .965 r
.55637 .36916 .5674 .37916 .57776 .3768 .56678 .36686 Mtetra
.598 .778 .966 r
.56678 .36686 .57776 .3768 .58816 .37444 .57725 .36457 Mtetra
.596 .78 .968 r
.57725 .36457 .58816 .37444 .5986 .37208 .58775 .36227 Mtetra
.595 .781 .969 r
.58775 .36227 .5986 .37208 .6091 .36972 .59831 .35997 Mtetra
.594 .783 .971 r
.59831 .35997 .6091 .36972 .61964 .36736 .60891 .35767 Mtetra
.592 .784 .972 r
.60891 .35767 .61964 .36736 .63022 .365 .61957 .35537 Mtetra
.591 .786 .973 r
.61957 .35537 .63022 .365 .64086 .36264 .63027 .35307 Mtetra
.59 .787 .974 r
.63027 .35307 .64086 .36264 .65154 .36028 .64102 .35076 Mtetra
.588 .789 .975 r
.64102 .35076 .65154 .36028 .66228 .35792 .65182 .34845 Mtetra
.587 .79 .977 r
.65182 .34845 .66228 .35792 .67306 .35555 .66268 .34613 Mtetra
.586 .792 .978 r
.66268 .34613 .67306 .35555 .68389 .35317 .67358 .3438 Mtetra
.584 .793 .979 r
.67358 .3438 .68389 .35317 .69477 .3508 .68453 .34148 Mtetra
.583 .795 .98 r
.68453 .34148 .69477 .3508 .7057 .34842 .69554 .33914 Mtetra
.582 .796 .981 r
.69554 .33914 .7057 .34842 .71668 .34603 .7066 .3368 Mtetra
.581 .797 .982 r
.7066 .3368 .71668 .34603 .72771 .34364 .71771 .33446 Mtetra
.579 .799 .983 r
.71771 .33446 .72771 .34364 .7388 .34124 .72887 .3321 Mtetra
.578 .8 .984 r
.72887 .3321 .7388 .34124 .74993 .33884 .74009 .32974 Mtetra
.577 .801 .984 r
.74009 .32974 .74993 .33884 .76112 .33643 .75136 .32737 Mtetra
.576 .802 .985 r
.75136 .32737 .76112 .33643 .77236 .33401 .76268 .325 Mtetra
.575 .804 .986 r
.76268 .325 .77236 .33401 .78365 .33159 .77406 .32261 Mtetra
.573 .805 .987 r
.77406 .32261 .78365 .33159 .795 .32916 .78549 .32022 Mtetra
.572 .806 .988 r
.78549 .32022 .795 .32916 .8064 .32672 .79698 .31782 Mtetra
.571 .807 .988 r
.79698 .31782 .8064 .32672 .81786 .32428 .80852 .31541 Mtetra
.57 .808 .989 r
.80852 .31541 .81786 .32428 .82936 .32182 .82012 .31299 Mtetra
.568 .81 .99 r
.82012 .31299 .82936 .32182 .84093 .31936 .83178 .31056 Mtetra
.567 .811 .99 r
.83178 .31056 .84093 .31936 .85255 .31689 .84349 .30812 Mtetra
.566 .812 .991 r
.84349 .30812 .85255 .31689 .86422 .31441 .85526 .30567 Mtetra
.664 .741 .908 r
.23214 .44265 .24474 .45438 .25394 .45127 .24138 .4395 Mtetra
.24138 .4395 .25394 .45127 .26317 .44815 .25065 .43633 Mtetra
.25065 .43633 .26317 .44815 .27244 .44502 .25995 .43316 Mtetra
.663 .741 .908 r
.25995 .43316 .27244 .44502 .28173 .44188 .26929 .42998 Mtetra
.26929 .42998 .28173 .44188 .29107 .43873 .27866 .4268 Mtetra
.661 .741 .909 r
.27866 .4268 .29107 .43873 .30043 .4356 .28807 .42365 Mtetra
.659 .741 .91 r
.28807 .42365 .30043 .4356 .30982 .43249 .2975 .42055 Mtetra
.656 .741 .912 r
.2975 .42055 .30982 .43249 .31925 .42943 .30696 .41752 Mtetra
.652 .741 .915 r
.30696 .41752 .31925 .42943 .3287 .42643 .31645 .41456 Mtetra
.648 .741 .918 r
.31645 .41456 .3287 .42643 .33819 .42349 .32597 .41169 Mtetra
.644 .742 .921 r
.32597 .41169 .33819 .42349 .3477 .42062 .33552 .40891 Mtetra
.64 .743 .924 r
.33552 .40891 .3477 .42062 .35725 .41782 .3451 .40619 Mtetra
.636 .744 .927 r
.3451 .40619 .35725 .41782 .36683 .41508 .35472 .40355 Mtetra
.632 .746 .93 r
.35472 .40355 .36683 .41508 .37645 .4124 .36437 .40097 Mtetra
.629 .747 .933 r
.36437 .40097 .37645 .4124 .3861 .40977 .37406 .39844 Mtetra
.625 .749 .936 r
.37406 .39844 .3861 .40977 .39579 .40718 .38379 .39596 Mtetra
.622 .75 .938 r
.38379 .39596 .39579 .40718 .40551 .40465 .39356 .39353 Mtetra
.619 .752 .941 r
.39356 .39353 .40551 .40465 .41528 .40214 .40336 .39113 Mtetra
.617 .754 .944 r
.40336 .39113 .41528 .40214 .42508 .39967 .41321 .38876 Mtetra
.614 .756 .946 r
.41321 .38876 .42508 .39967 .43492 .39723 .42309 .38642 Mtetra
.612 .758 .948 r
.42309 .38642 .43492 .39723 .44481 .39482 .43302 .3841 Mtetra
.61 .76 .951 r
.43302 .3841 .44481 .39482 .45473 .39242 .44299 .3818 Mtetra
.607 .762 .953 r
.44299 .3818 .45473 .39242 .4647 .39005 .45301 .37952 Mtetra
.605 .764 .955 r
.45301 .37952 .4647 .39005 .47471 .38769 .46306 .37725 Mtetra
.603 .766 .957 r
.46306 .37725 .47471 .38769 .48476 .38535 .47317 .37499 Mtetra
.602 .767 .959 r
.47317 .37499 .48476 .38535 .49486 .38301 .48331 .37274 Mtetra
.6 .769 .961 r
.48331 .37274 .49486 .38301 .505 .38069 .4935 .3705 Mtetra
.598 .771 .963 r
.4935 .3705 .505 .38069 .51518 .37837 .50374 .36826 Mtetra
.596 .773 .964 r
.50374 .36826 .51518 .37837 .52541 .37606 .51403 .36603 Mtetra
.595 .775 .966 r
.51403 .36603 .52541 .37606 .53568 .37376 .52436 .3638 Mtetra
.593 .777 .968 r
.52436 .3638 .53568 .37376 .546 .37146 .53474 .36157 Mtetra
.592 .778 .969 r
.53474 .36157 .546 .37146 .55637 .36916 .54516 .35934 Mtetra
.59 .78 .97 r
.54516 .35934 .55637 .36916 .56678 .36686 .55564 .35712 Mtetra
.589 .782 .972 r
.55564 .35712 .56678 .36686 .57725 .36457 .56616 .35489 Mtetra
.587 .783 .973 r
.56616 .35489 .57725 .36457 .58775 .36227 .57673 .35265 Mtetra
.586 .785 .975 r
.57673 .35265 .58775 .36227 .59831 .35997 .58735 .35042 Mtetra
.584 .787 .976 r
.58735 .35042 .59831 .35997 .60891 .35767 .59802 .34818 Mtetra
.583 .788 .977 r
.59802 .34818 .60891 .35767 .61957 .35537 .60874 .34594 Mtetra
.582 .79 .978 r
.60874 .34594 .61957 .35537 .63027 .35307 .61951 .34369 Mtetra
.58 .791 .979 r
.61951 .34369 .63027 .35307 .64102 .35076 .63034 .34143 Mtetra
.579 .793 .98 r
.63034 .34143 .64102 .35076 .65182 .34845 .64121 .33918 Mtetra
.578 .794 .981 r
.64121 .33918 .65182 .34845 .66268 .34613 .65213 .33691 Mtetra
.576 .796 .982 r
.65213 .33691 .66268 .34613 .67358 .3438 .66311 .33464 Mtetra
.575 .797 .983 r
.66311 .33464 .67358 .3438 .68453 .34148 .67414 .33236 Mtetra
.574 .798 .984 r
.67414 .33236 .68453 .34148 .69554 .33914 .68522 .33007 Mtetra
.572 .8 .985 r
.68522 .33007 .69554 .33914 .7066 .3368 .69636 .32778 Mtetra
.571 .801 .986 r
.69636 .32778 .7066 .3368 .71771 .33446 .70755 .32548 Mtetra
.57 .802 .987 r
.70755 .32548 .71771 .33446 .72887 .3321 .71879 .32317 Mtetra
.568 .804 .988 r
.71879 .32317 .72887 .3321 .74009 .32974 .73009 .32085 Mtetra
.567 .805 .989 r
.73009 .32085 .74009 .32974 .75136 .32737 .74144 .31853 Mtetra
.566 .806 .989 r
.74144 .31853 .75136 .32737 .76268 .325 .75285 .31619 Mtetra
.565 .807 .99 r
.75285 .31619 .76268 .325 .77406 .32261 .76432 .31385 Mtetra
.563 .809 .991 r
.76432 .31385 .77406 .32261 .78549 .32022 .77584 .31149 Mtetra
.562 .81 .991 r
.77584 .31149 .78549 .32022 .79698 .31782 .78741 .30913 Mtetra
.561 .811 .992 r
.78741 .30913 .79698 .31782 .80852 .31541 .79905 .30675 Mtetra
.559 .812 .993 r
.79905 .30675 .80852 .31541 .82012 .31299 .81074 .30437 Mtetra
.558 .813 .993 r
.81074 .30437 .82012 .31299 .83178 .31056 .82249 .30198 Mtetra
.557 .814 .994 r
.82249 .30198 .83178 .31056 .84349 .30812 .8343 .29957 Mtetra
.556 .815 .994 r
.8343 .29957 .84349 .30812 .85526 .30567 .84616 .29716 Mtetra
.664 .741 .908 r
.21937 .43076 .23214 .44265 .24138 .4395 .22865 .42756 Mtetra
.22865 .42756 .24138 .4395 .25065 .43633 .23796 .42436 Mtetra
.23796 .42436 .25065 .43633 .25995 .43316 .24731 .42115 Mtetra
.663 .741 .908 r
.24731 .42115 .25995 .43316 .26929 .42998 .25668 .41793 Mtetra
.662 .741 .909 r
.25668 .41793 .26929 .42998 .27866 .4268 .26609 .41472 Mtetra
.66 .741 .91 r
.26609 .41472 .27866 .4268 .28807 .42365 .27553 .41157 Mtetra
.656 .74 .912 r
.27553 .41157 .28807 .42365 .2975 .42055 .285 .4085 Mtetra
.651 .74 .915 r
.285 .4085 .2975 .42055 .30696 .41752 .29449 .40552 Mtetra
.646 .741 .918 r
.29449 .40552 .30696 .41752 .31645 .41456 .30402 .40265 Mtetra
.641 .741 .921 r
.30402 .40265 .31645 .41456 .32597 .41169 .31357 .39988 Mtetra
.637 .742 .925 r
.31357 .39988 .32597 .41169 .33552 .40891 .32315 .39719 Mtetra
.632 .744 .928 r
.32315 .39719 .33552 .40891 .3451 .40619 .33277 .3946 Mtetra
.628 .745 .932 r
.33277 .3946 .3451 .40619 .35472 .40355 .34242 .39207 Mtetra
.624 .747 .935 r
.34242 .39207 .35472 .40355 .36437 .40097 .35211 .38961 Mtetra
.62 .749 .938 r
.35211 .38961 .36437 .40097 .37406 .39844 .36184 .38721 Mtetra
.616 .751 .942 r
.36184 .38721 .37406 .39844 .38379 .39596 .3716 .38485 Mtetra
.613 .753 .944 r
.3716 .38485 .38379 .39596 .39356 .39353 .38141 .38253 Mtetra
.61 .755 .947 r
.38141 .38253 .39356 .39353 .40336 .39113 .39125 .38025 Mtetra
.607 .757 .95 r
.39125 .38025 .40336 .39113 .41321 .38876 .40114 .37799 Mtetra
.605 .759 .952 r
.40114 .37799 .41321 .38876 .42309 .38642 .41107 .37576 Mtetra
.602 .761 .955 r
.41107 .37576 .42309 .38642 .43302 .3841 .42104 .37355 Mtetra
.6 .763 .957 r
.42104 .37355 .43302 .3841 .44299 .3818 .43106 .37135 Mtetra
.598 .765 .959 r
.43106 .37135 .44299 .3818 .45301 .37952 .44112 .36917 Mtetra
.596 .767 .961 r
.44112 .36917 .45301 .37952 .46306 .37725 .45123 .36699 Mtetra
.594 .769 .963 r
.45123 .36699 .46306 .37725 .47317 .37499 .46138 .36483 Mtetra
.592 .771 .965 r
.46138 .36483 .47317 .37499 .48331 .37274 .47158 .36267 Mtetra
.59 .773 .967 r
.47158 .36267 .48331 .37274 .4935 .3705 .48183 .36051 Mtetra
.588 .775 .969 r
.48183 .36051 .4935 .3705 .50374 .36826 .49212 .35836 Mtetra
.586 .777 .97 r
.49212 .35836 .50374 .36826 .51403 .36603 .50246 .35621 Mtetra
.585 .779 .972 r
.50246 .35621 .51403 .36603 .52436 .3638 .51285 .35406 Mtetra
.583 .781 .973 r
.51285 .35406 .52436 .3638 .53474 .36157 .52329 .35191 Mtetra
.581 .782 .975 r
.52329 .35191 .53474 .36157 .54516 .35934 .53377 .34975 Mtetra
.58 .784 .976 r
.53377 .34975 .54516 .35934 .55564 .35712 .54431 .3476 Mtetra
.578 .786 .978 r
.54431 .3476 .55564 .35712 .56616 .35489 .55489 .34544 Mtetra
.577 .787 .979 r
.55489 .34544 .56616 .35489 .57673 .35265 .56553 .34327 Mtetra
.575 .789 .98 r
.56553 .34327 .57673 .35265 .58735 .35042 .57622 .3411 Mtetra
.574 .791 .981 r
.57622 .3411 .58735 .35042 .59802 .34818 .58695 .33893 Mtetra
.572 .792 .982 r
.58695 .33893 .59802 .34818 .60874 .34594 .59774 .33674 Mtetra
.571 .794 .983 r
.59774 .33674 .60874 .34594 .61951 .34369 .60858 .33456 Mtetra
.57 .795 .984 r
.60858 .33456 .61951 .34369 .63034 .34143 .61948 .33236 Mtetra
.568 .797 .985 r
.61948 .33236 .63034 .34143 .64121 .33918 .63042 .33016 Mtetra
.567 .798 .986 r
.63042 .33016 .64121 .33918 .65213 .33691 .64142 .32795 Mtetra
.565 .8 .987 r
.64142 .32795 .65213 .33691 .66311 .33464 .65248 .32573 Mtetra
.564 .801 .988 r
.65248 .32573 .66311 .33464 .67414 .33236 .66358 .3235 Mtetra
.563 .803 .989 r
.66358 .3235 .67414 .33236 .68522 .33007 .67474 .32127 Mtetra
.561 .804 .99 r
.67474 .32127 .68522 .33007 .69636 .32778 .68596 .31902 Mtetra
.56 .805 .99 r
.68596 .31902 .69636 .32778 .70755 .32548 .69723 .31677 Mtetra
.558 .807 .991 r
.69723 .31677 .70755 .32548 .71879 .32317 .70856 .31451 Mtetra
.557 .808 .992 r
.70856 .31451 .71879 .32317 .73009 .32085 .71994 .31223 Mtetra
.556 .809 .993 r
.71994 .31223 .73009 .32085 .74144 .31853 .73138 .30995 Mtetra
.554 .81 .993 r
.73138 .30995 .74144 .31853 .75285 .31619 .74287 .30766 Mtetra
.553 .812 .994 r
.74287 .30766 .75285 .31619 .76432 .31385 .75443 .30535 Mtetra
.552 .813 .994 r
.75443 .30535 .76432 .31385 .77584 .31149 .76604 .30304 Mtetra
.55 .814 .995 r
.76604 .30304 .77584 .31149 .78741 .30913 .77771 .30071 Mtetra
.549 .815 .995 r
.77771 .30071 .78741 .30913 .79905 .30675 .78943 .29838 Mtetra
.547 .816 .996 r
.78943 .29838 .79905 .30675 .81074 .30437 .80122 .29603 Mtetra
.546 .817 .996 r
.80122 .29603 .81074 .30437 .82249 .30198 .81307 .29368 Mtetra
.545 .818 .997 r
.81307 .29368 .82249 .30198 .8343 .29957 .82497 .29131 Mtetra
.543 .819 .997 r
.82497 .29131 .8343 .29957 .84616 .29716 .83694 .28893 Mtetra
.664 .741 .908 r
.20643 .41871 .21937 .43076 .22865 .42756 .21575 .41547 Mtetra
.21575 .41547 .22865 .42756 .23796 .42436 .2251 .41223 Mtetra
.663 .741 .908 r
.2251 .41223 .23796 .42436 .24731 .42115 .23448 .40897 Mtetra
.23448 .40897 .24731 .42115 .25668 .41793 .2439 .40571 Mtetra
.661 .741 .909 r
.2439 .40571 .25668 .41793 .26609 .41472 .25335 .4025 Mtetra
.657 .74 .911 r
.25335 .4025 .26609 .41472 .27553 .41157 .26282 .39938 Mtetra
.651 .74 .914 r
.26282 .39938 .27553 .41157 .285 .4085 .27232 .39637 Mtetra
.646 .74 .918 r
.27232 .39637 .285 .4085 .29449 .40552 .28185 .39348 Mtetra
.639 .741 .922 r
.28185 .39348 .29449 .40552 .30402 .40265 .2914 .39072 Mtetra
.633 .742 .926 r
.2914 .39072 .30402 .40265 .31357 .39988 .30099 .38808 Mtetra
.628 .743 .93 r
.30099 .38808 .31357 .39988 .32315 .39719 .3106 .38554 Mtetra
.623 .745 .934 r
.3106 .38554 .32315 .39719 .33277 .3946 .32025 .38308 Mtetra
.618 .747 .938 r
.32025 .38308 .33277 .3946 .34242 .39207 .32993 .3807 Mtetra
.613 .749 .942 r
.32993 .3807 .34242 .39207 .35211 .38961 .33966 .37838 Mtetra
.609 .751 .945 r
.33966 .37838 .35211 .38961 .36184 .38721 .34942 .37612 Mtetra
.606 .753 .948 r
.34942 .37612 .36184 .38721 .3716 .38485 .35922 .3739 Mtetra
.602 .755 .951 r
.35922 .3739 .3716 .38485 .38141 .38253 .36906 .37171 Mtetra
.599 .758 .954 r
.36906 .37171 .38141 .38253 .39125 .38025 .37895 .36955 Mtetra
.596 .76 .957 r
.37895 .36955 .39125 .38025 .40114 .37799 .38888 .36742 Mtetra
.593 .762 .959 r
.38888 .36742 .40114 .37799 .41107 .37576 .39885 .36531 Mtetra
.591 .764 .962 r
.39885 .36531 .41107 .37576 .42104 .37355 .40887 .36321 Mtetra
.589 .767 .964 r
.40887 .36321 .42104 .37355 .43106 .37135 .41893 .36113 Mtetra
.586 .769 .966 r
.41893 .36113 .43106 .37135 .44112 .36917 .42904 .35905 Mtetra
.584 .771 .968 r
.42904 .35905 .44112 .36917 .45123 .36699 .4392 .35698 Mtetra
.582 .773 .97 r
.4392 .35698 .45123 .36699 .46138 .36483 .4494 .35492 Mtetra
.58 .775 .972 r
.4494 .35492 .46138 .36483 .47158 .36267 .45965 .35285 Mtetra
.578 .777 .974 r
.45965 .35285 .47158 .36267 .48183 .36051 .46995 .35079 Mtetra
.576 .779 .975 r
.46995 .35079 .48183 .36051 .49212 .35836 .4803 .34873 Mtetra
.575 .781 .977 r
.4803 .34873 .49212 .35836 .50246 .35621 .4907 .34666 Mtetra
.573 .783 .978 r
.4907 .34666 .50246 .35621 .51285 .35406 .50114 .3446 Mtetra
.571 .785 .98 r
.50114 .3446 .51285 .35406 .52329 .35191 .51164 .34253 Mtetra
.57 .787 .981 r
.51164 .34253 .52329 .35191 .53377 .34975 .52219 .34045 Mtetra
.568 .789 .982 r
.52219 .34045 .53377 .34975 .54431 .3476 .53279 .33837 Mtetra
.566 .79 .983 r
.53279 .33837 .54431 .3476 .55489 .34544 .54344 .33628 Mtetra
.565 .792 .985 r
.54344 .33628 .55489 .34544 .56553 .34327 .55414 .33419 Mtetra
.563 .794 .986 r
.55414 .33419 .56553 .34327 .57622 .3411 .56489 .33209 Mtetra
.562 .795 .987 r
.56489 .33209 .57622 .3411 .58695 .33893 .5757 .32998 Mtetra
.56 .797 .988 r
.5757 .32998 .58695 .33893 .59774 .33674 .58656 .32786 Mtetra
.559 .799 .989 r
.58656 .32786 .59774 .33674 .60858 .33456 .59747 .32573 Mtetra
.557 .8 .99 r
.59747 .32573 .60858 .33456 .61948 .33236 .60844 .3236 Mtetra
.556 .802 .99 r
.60844 .3236 .61948 .33236 .63042 .33016 .61946 .32146 Mtetra
.554 .803 .991 r
.61946 .32146 .63042 .33016 .64142 .32795 .63054 .3193 Mtetra
.553 .805 .992 r
.63054 .3193 .64142 .32795 .65248 .32573 .64167 .31714 Mtetra
.551 .806 .993 r
.64167 .31714 .65248 .32573 .66358 .3235 .65285 .31497 Mtetra
.55 .807 .993 r
.65285 .31497 .66358 .3235 .67474 .32127 .66409 .31279 Mtetra
.548 .809 .994 r
.66409 .31279 .67474 .32127 .68596 .31902 .67539 .31059 Mtetra
.547 .81 .995 r
.67539 .31059 .68596 .31902 .69723 .31677 .68675 .30839 Mtetra
.545 .811 .995 r
.68675 .30839 .69723 .31677 .70856 .31451 .69816 .30617 Mtetra
.544 .812 .996 r
.69816 .30617 .70856 .31451 .71994 .31223 .70963 .30395 Mtetra
.542 .814 .996 r
.70963 .30395 .71994 .31223 .73138 .30995 .72116 .30171 Mtetra
.541 .815 .997 r
.72116 .30171 .73138 .30995 .74287 .30766 .73274 .29946 Mtetra
.539 .816 .997 r
.73274 .29946 .74287 .30766 .75443 .30535 .74439 .2972 Mtetra
.538 .817 .997 r
.74439 .2972 .75443 .30535 .76604 .30304 .75609 .29493 Mtetra
.536 .818 .998 r
.75609 .29493 .76604 .30304 .77771 .30071 .76785 .29265 Mtetra
.535 .819 .998 r
.76785 .29265 .77771 .30071 .78943 .29838 .77968 .29035 Mtetra
.533 .82 .998 r
.77968 .29035 .78943 .29838 .80122 .29603 .79156 .28805 Mtetra
.532 .821 .999 r
.79156 .28805 .80122 .29603 .81307 .29368 .80351 .28573 Mtetra
.53 .822 .999 r
.80351 .28573 .81307 .29368 .82497 .29131 .81551 .2834 Mtetra
.529 .823 .999 r
.81551 .2834 .82497 .29131 .83694 .28893 .82758 .28105 Mtetra
.664 .741 .908 r
.19331 .4065 .20643 .41871 .21575 .41547 .20267 .40322 Mtetra
.20267 .40322 .21575 .41547 .2251 .41223 .21206 .39993 Mtetra
.663 .741 .908 r
.21206 .39993 .2251 .41223 .23448 .40897 .22149 .39663 Mtetra
.662 .741 .909 r
.22149 .39663 .23448 .40897 .2439 .40571 .23094 .39335 Mtetra
.658 .74 .91 r
.23094 .39335 .2439 .40571 .25335 .4025 .24043 .39015 Mtetra
.652 .74 .914 r
.24043 .39015 .25335 .4025 .26282 .39938 .24993 .38709 Mtetra
.645 .74 .918 r
.24993 .38709 .26282 .39938 .27232 .39637 .25946 .38419 Mtetra
.637 .74 .923 r
.25946 .38419 .27232 .39637 .28185 .39348 .26902 .38144 Mtetra
.63 .741 .928 r
.26902 .38144 .28185 .39348 .2914 .39072 .27859 .37884 Mtetra
.623 .742 .932 r
.27859 .37884 .2914 .39072 .30099 .38808 .2882 .37636 Mtetra
.617 .744 .937 r
.2882 .37636 .30099 .38808 .3106 .38554 .29785 .37399 Mtetra
.611 .746 .941 r
.29785 .37399 .3106 .38554 .32025 .38308 .30752 .3717 Mtetra
.606 .748 .945 r
.30752 .3717 .32025 .38308 .32993 .3807 .31724 .36949 Mtetra
.601 .751 .949 r
.31724 .36949 .32993 .3807 .33966 .37838 .32699 .36734 Mtetra
.597 .753 .953 r
.32699 .36734 .33966 .37838 .34942 .37612 .33679 .36523 Mtetra
.593 .756 .956 r
.33679 .36523 .34942 .37612 .35922 .3739 .34662 .36317 Mtetra
.589 .758 .959 r
.34662 .36317 .35922 .3739 .36906 .37171 .3565 .36113 Mtetra
.586 .761 .962 r
.3565 .36113 .36906 .37171 .37895 .36955 .36643 .35911 Mtetra
.583 .763 .965 r
.36643 .35911 .37895 .36955 .38888 .36742 .3764 .35712 Mtetra
.58 .766 .967 r
.3764 .35712 .38888 .36742 .39885 .36531 .38641 .35514 Mtetra
.578 .768 .969 r
.38641 .35514 .39885 .36531 .40887 .36321 .39648 .35317 Mtetra
.575 .771 .972 r
.39648 .35317 .40887 .36321 .41893 .36113 .40659 .3512 Mtetra
.573 .773 .974 r
.40659 .3512 .41893 .36113 .42904 .35905 .41674 .34924 Mtetra
.571 .775 .975 r
.41674 .34924 .42904 .35905 .4392 .35698 .42695 .34728 Mtetra
.568 .778 .977 r
.42695 .34728 .4392 .35698 .4494 .35492 .43721 .34532 Mtetra
.566 .78 .979 r
.43721 .34532 .4494 .35492 .45965 .35285 .44751 .34336 Mtetra
.564 .782 .981 r
.44751 .34336 .45965 .35285 .46995 .35079 .45787 .3414 Mtetra
.562 .784 .982 r
.45787 .3414 .46995 .35079 .4803 .34873 .46827 .33943 Mtetra
.561 .786 .983 r
.46827 .33943 .4803 .34873 .4907 .34666 .47873 .33746 Mtetra
.559 .788 .985 r
.47873 .33746 .4907 .34666 .50114 .3446 .48923 .33548 Mtetra
.557 .79 .986 r
.48923 .33548 .50114 .3446 .51164 .34253 .49979 .3335 Mtetra
.555 .792 .987 r
.49979 .3335 .51164 .34253 .52219 .34045 .5104 .33151 Mtetra
.554 .794 .988 r
.5104 .33151 .52219 .34045 .53279 .33837 .52107 .32951 Mtetra
.552 .796 .989 r
.52107 .32951 .53279 .33837 .54344 .33628 .53178 .3275 Mtetra
.55 .797 .99 r
.53178 .3275 .54344 .33628 .55414 .33419 .54255 .32548 Mtetra
.548 .799 .991 r
.54255 .32548 .55414 .33419 .56489 .33209 .55338 .32345 Mtetra
.547 .801 .992 r
.55338 .32345 .56489 .33209 .5757 .32998 .56425 .32141 Mtetra
.545 .802 .993 r
.56425 .32141 .5757 .32998 .58656 .32786 .57519 .31936 Mtetra
.544 .804 .994 r
.57519 .31936 .58656 .32786 .59747 .32573 .58617 .3173 Mtetra
.542 .805 .994 r
.58617 .3173 .59747 .32573 .60844 .3236 .59721 .31524 Mtetra
.54 .807 .995 r
.59721 .31524 .60844 .3236 .61946 .32146 .60831 .31315 Mtetra
.539 .808 .996 r
.60831 .31315 .61946 .32146 .63054 .3193 .61947 .31106 Mtetra
.537 .809 .996 r
.61947 .31106 .63054 .3193 .64167 .31714 .63068 .30896 Mtetra
.535 .811 .997 r
.63068 .30896 .64167 .31714 .65285 .31497 .64194 .30685 Mtetra
.534 .812 .997 r
.64194 .30685 .65285 .31497 .66409 .31279 .65327 .30472 Mtetra
.532 .813 .998 r
.65327 .30472 .66409 .31279 .67539 .31059 .66465 .30258 Mtetra
.53 .815 .998 r
.66465 .30258 .67539 .31059 .68675 .30839 .67609 .30043 Mtetra
.529 .816 .998 r
.67609 .30043 .68675 .30839 .69816 .30617 .68759 .29827 Mtetra
.527 .817 .999 r
.68759 .29827 .69816 .30617 .70963 .30395 .69915 .29609 Mtetra
.526 .818 .999 r
.69915 .29609 .70963 .30395 .72116 .30171 .71077 .2939 Mtetra
.524 .819 .999 r
.71077 .2939 .72116 .30171 .73274 .29946 .72245 .2917 Mtetra
.522 .82 .999 r
.72245 .2917 .73274 .29946 .74439 .2972 .73419 .28949 Mtetra
.521 .821 1 r
.73419 .28949 .74439 .2972 .75609 .29493 .74599 .28727 Mtetra
.519 .822 1 r
.74599 .28727 .75609 .29493 .76785 .29265 .75785 .28503 Mtetra
.517 .823 1 r
.75785 .28503 .76785 .29265 .77968 .29035 .76978 .28277 Mtetra
.516 .824 1 r
.76978 .28277 .77968 .29035 .79156 .28805 .78176 .28051 Mtetra
.514 .825 1 r
.78176 .28051 .79156 .28805 .80351 .28573 .79381 .27823 Mtetra
.512 .826 1 r
.79381 .27823 .80351 .28573 .81551 .2834 .80592 .27594 Mtetra
.51 .827 1 r
.80592 .27594 .81551 .2834 .82758 .28105 .8181 .27363 Mtetra
.664 .741 .908 r
.18002 .39412 .19331 .4065 .20267 .40322 .18942 .39079 Mtetra
.18942 .39079 .20267 .40322 .21206 .39993 .19885 .38746 Mtetra
.663 .741 .908 r
.19885 .38746 .21206 .39993 .22149 .39663 .20831 .38412 Mtetra
.66 .741 .909 r
.20831 .38412 .22149 .39663 .23094 .39335 .21781 .38084 Mtetra
.654 .74 .913 r
.21781 .38084 .23094 .39335 .24043 .39015 .22732 .3777 Mtetra
.645 .739 .917 r
.22732 .3777 .24043 .39015 .24993 .38709 .23685 .37476 Mtetra
.636 .739 .923 r
.23685 .37476 .24993 .38709 .25946 .38419 .2464 .37202 Mtetra
.626 .74 .929 r
.2464 .37202 .25946 .38419 .26902 .38144 .25598 .36946 Mtetra
.617 .741 .935 r
.25598 .36946 .26902 .38144 .27859 .37884 .26558 .36706 Mtetra
.609 .743 .94 r
.26558 .36706 .27859 .37884 .2882 .37636 .27521 .36479 Mtetra
.602 .746 .945 r
.27521 .36479 .2882 .37636 .29785 .37399 .28488 .36263 Mtetra
.596 .748 .95 r
.28488 .36263 .29785 .37399 .30752 .3717 .29458 .36055 Mtetra
.59 .751 .954 r
.29458 .36055 .30752 .3717 .31724 .36949 .30432 .35853 Mtetra
.585 .754 .958 r
.30432 .35853 .31724 .36949 .32699 .36734 .31411 .35657 Mtetra
.581 .756 .961 r
.31411 .35657 .32699 .36734 .33679 .36523 .32393 .35464 Mtetra
.577 .759 .965 r
.32393 .35464 .33679 .36523 .34662 .36317 .33381 .35275 Mtetra
.573 .762 .968 r
.33381 .35275 .34662 .36317 .3565 .36113 .34372 .35087 Mtetra
.57 .765 .97 r
.34372 .35087 .3565 .36113 .36643 .35911 .35369 .34902 Mtetra
.567 .768 .973 r
.35369 .34902 .36643 .35911 .3764 .35712 .3637 .34717 Mtetra
.564 .77 .975 r
.3637 .34717 .3764 .35712 .38641 .35514 .37376 .34533 Mtetra
.561 .773 .977 r
.37376 .34533 .38641 .35514 .39648 .35317 .38386 .3435 Mtetra
.559 .776 .979 r
.38386 .3435 .39648 .35317 .40659 .3512 .39402 .34166 Mtetra
.556 .778 .981 r
.39402 .34166 .40659 .3512 .41674 .34924 .40423 .33983 Mtetra
.554 .781 .983 r
.40423 .33983 .41674 .34924 .42695 .34728 .41448 .33799 Mtetra
.552 .783 .985 r
.41448 .33799 .42695 .34728 .43721 .34532 .42479 .33615 Mtetra
.55 .785 .986 r
.42479 .33615 .43721 .34532 .44751 .34336 .43515 .3343 Mtetra
.548 .787 .988 r
.43515 .3343 .44751 .34336 .45787 .3414 .44556 .33244 Mtetra
.545 .789 .989 r
.44556 .33244 .45787 .3414 .46827 .33943 .45602 .33058 Mtetra
.543 .792 .99 r
.45602 .33058 .46827 .33943 .47873 .33746 .46654 .3287 Mtetra
.542 .794 .991 r
.46654 .3287 .47873 .33746 .48923 .33548 .47711 .32682 Mtetra
.54 .796 .992 r
.47711 .32682 .48923 .33548 .49979 .3335 .48773 .32493 Mtetra
.538 .797 .993 r
.48773 .32493 .49979 .3335 .5104 .33151 .4984 .32302 Mtetra
.536 .799 .994 r
.4984 .32302 .5104 .33151 .52107 .32951 .50913 .32111 Mtetra
.534 .801 .995 r
.50913 .32111 .52107 .32951 .53178 .3275 .51992 .31918 Mtetra
.532 .803 .995 r
.51992 .31918 .53178 .3275 .54255 .32548 .53076 .31725 Mtetra
.53 .804 .996 r
.53076 .31725 .54255 .32548 .55338 .32345 .54165 .3153 Mtetra
.528 .806 .997 r
.54165 .3153 .55338 .32345 .56425 .32141 .5526 .31334 Mtetra
.527 .807 .997 r
.5526 .31334 .56425 .32141 .57519 .31936 .56361 .31136 Mtetra
.525 .809 .998 r
.56361 .31136 .57519 .31936 .58617 .3173 .57467 .30937 Mtetra
.523 .81 .998 r
.57467 .30937 .58617 .3173 .59721 .31524 .58579 .30738 Mtetra
.521 .812 .999 r
.58579 .30738 .59721 .31524 .60831 .31315 .59697 .30536 Mtetra
.519 .813 .999 r
.59697 .30536 .60831 .31315 .61947 .31106 .60821 .30334 Mtetra
.517 .814 .999 r
.60821 .30334 .61947 .31106 .63068 .30896 .6195 .3013 Mtetra
.516 .816 .999 r
.6195 .3013 .63068 .30896 .64194 .30685 .63085 .29925 Mtetra
.514 .817 1 r
.63085 .29925 .64194 .30685 .65327 .30472 .64226 .29718 Mtetra
.512 .818 1 r
.64226 .29718 .65327 .30472 .66465 .30258 .65373 .2951 Mtetra
.51 .819 1 r
.65373 .2951 .66465 .30258 .67609 .30043 .66527 .29301 Mtetra
.508 .82 1 r
.66527 .29301 .67609 .30043 .68759 .29827 .67686 .2909 Mtetra
.506 .821 1 r
.67686 .2909 .68759 .29827 .69915 .29609 .68851 .28878 Mtetra
.505 .822 1 r
.68851 .28878 .69915 .29609 .71077 .2939 .70022 .28665 Mtetra
.503 .823 1 r
.70022 .28665 .71077 .2939 .72245 .2917 .712 .2845 Mtetra
.501 .824 1 r
.712 .2845 .72245 .2917 .73419 .28949 .72384 .28234 Mtetra
.499 .825 1 r
.72384 .28234 .73419 .28949 .74599 .28727 .73574 .28016 Mtetra
.497 .826 .999 r
.73574 .28016 .74599 .28727 .75785 .28503 .7477 .27797 Mtetra
.495 .826 .999 r
.7477 .27797 .75785 .28503 .76978 .28277 .75973 .27576 Mtetra
.493 .827 .999 r
.75973 .27576 .76978 .28277 .78176 .28051 .77182 .27354 Mtetra
.491 .828 .999 r
.77182 .27354 .78176 .28051 .79381 .27823 .78397 .27131 Mtetra
.489 .829 .998 r
.78397 .27131 .79381 .27823 .80592 .27594 .7962 .26906 Mtetra
.487 .829 .998 r
.7962 .26906 .80592 .27594 .8181 .27363 .80848 .2668 Mtetra
.664 .741 .908 r
.16654 .38157 .18002 .39412 .18942 .39079 .17598 .3782 Mtetra
.17598 .3782 .18942 .39079 .19885 .38746 .18545 .37481 Mtetra
.662 .741 .908 r
.18545 .37481 .19885 .38746 .20831 .38412 .19495 .37145 Mtetra
.657 .74 .911 r
.19495 .37145 .20831 .38412 .21781 .38084 .20448 .36821 Mtetra
.647 .739 .916 r
.20448 .36821 .21781 .38084 .22732 .3777 .21402 .3652 Mtetra
.634 .738 .923 r
.21402 .3652 .22732 .3777 .23685 .37476 .22357 .36245 Mtetra
.622 .738 .93 r
.22357 .36245 .23685 .37476 .2464 .37202 .23313 .35994 Mtetra
.611 .74 .937 r
.23313 .35994 .2464 .37202 .25598 .36946 .24272 .35764 Mtetra
.6 .742 .944 r
.24272 .35764 .25598 .36946 .26558 .36706 .25234 .3555 Mtetra
.591 .744 .95 r
.25234 .3555 .26558 .36706 .27521 .36479 .26199 .35348 Mtetra
.584 .747 .955 r
.26199 .35348 .27521 .36479 .28488 .36263 .27168 .35156 Mtetra
.577 .75 .96 r
.27168 .35156 .28488 .36263 .29458 .36055 .2814 .34972 Mtetra
.571 .754 .964 r
.2814 .34972 .29458 .36055 .30432 .35853 .29117 .34793 Mtetra
.566 .757 .968 r
.29117 .34793 .30432 .35853 .31411 .35657 .30098 .34617 Mtetra
.561 .76 .971 r
.30098 .34617 .31411 .35657 .32393 .35464 .31084 .34445 Mtetra
.557 .763 .974 r
.31084 .34445 .32393 .35464 .33381 .35275 .32075 .34275 Mtetra
.553 .766 .977 r
.32075 .34275 .33381 .35275 .34372 .35087 .3307 .34106 Mtetra
.55 .77 .98 r
.3307 .34106 .34372 .35087 .35369 .34902 .3407 .33937 Mtetra
.547 .773 .982 r
.3407 .33937 .35369 .34902 .3637 .34717 .35075 .33769 Mtetra
.544 .775 .984 r
.35075 .33769 .3637 .34717 .37376 .34533 .36085 .33601 Mtetra
.541 .778 .986 r
.36085 .33601 .37376 .34533 .38386 .3435 .37101 .33432 Mtetra
.538 .781 .988 r
.37101 .33432 .38386 .3435 .39402 .34166 .38121 .33263 Mtetra
.536 .784 .989 r
.38121 .33263 .39402 .34166 .40423 .33983 .39147 .33093 Mtetra
.533 .786 .991 r
.39147 .33093 .40423 .33983 .41448 .33799 .40177 .32922 Mtetra
.531 .788 .992 r
.40177 .32922 .41448 .33799 .42479 .33615 .41213 .32751 Mtetra
.528 .791 .993 r
.41213 .32751 .42479 .33615 .43515 .3343 .42255 .32578 Mtetra
.526 .793 .994 r
.42255 .32578 .43515 .3343 .44556 .33244 .43302 .32404 Mtetra
.524 .795 .995 r
.43302 .32404 .44556 .33244 .45602 .33058 .44354 .32228 Mtetra
.522 .797 .996 r
.44354 .32228 .45602 .33058 .46654 .3287 .45412 .32052 Mtetra
.52 .799 .997 r
.45412 .32052 .46654 .3287 .47711 .32682 .46475 .31874 Mtetra
.517 .801 .997 r
.46475 .31874 .47711 .32682 .48773 .32493 .47543 .31695 Mtetra
.515 .803 .998 r
.47543 .31695 .48773 .32493 .4984 .32302 .48618 .31514 Mtetra
.513 .805 .998 r
.48618 .31514 .4984 .32302 .50913 .32111 .49697 .31332 Mtetra
.511 .806 .999 r
.49697 .31332 .50913 .32111 .51992 .31918 .50783 .31148 Mtetra
.509 .808 .999 r
.50783 .31148 .51992 .31918 .53076 .31725 .51874 .30963 Mtetra
.507 .81 .999 r
.51874 .30963 .53076 .31725 .54165 .3153 .52971 .30777 Mtetra
.505 .811 1 r
.52971 .30777 .54165 .3153 .5526 .31334 .54073 .30589 Mtetra
.503 .812 1 r
.54073 .30589 .5526 .31334 .56361 .31136 .55182 .304 Mtetra
.501 .814 1 r
.55182 .304 .56361 .31136 .57467 .30937 .56296 .30209 Mtetra
.498 .815 1 r
.56296 .30209 .57467 .30937 .58579 .30738 .57416 .30017 Mtetra
.496 .816 1 r
.57416 .30017 .58579 .30738 .59697 .30536 .58542 .29823 Mtetra
.494 .817 1 r
.58542 .29823 .59697 .30536 .60821 .30334 .59674 .29627 Mtetra
.492 .819 1 r
.59674 .29627 .60821 .30334 .6195 .3013 .60812 .29431 Mtetra
.49 .82 1 r
.60812 .29431 .6195 .3013 .63085 .29925 .61956 .29232 Mtetra
.488 .821 .999 r
.61956 .29232 .63085 .29925 .64226 .29718 .63107 .29032 Mtetra
.486 .822 .999 r
.63107 .29032 .64226 .29718 .65373 .2951 .64263 .28831 Mtetra
.483 .823 .999 r
.64263 .28831 .65373 .2951 .66527 .29301 .65425 .28628 Mtetra
.481 .823 .998 r
.65425 .28628 .66527 .29301 .67686 .2909 .66594 .28423 Mtetra
.479 .824 .998 r
.66594 .28423 .67686 .2909 .68851 .28878 .67769 .28217 Mtetra
.477 .825 .997 r
.67769 .28217 .68851 .28878 .70022 .28665 .6895 .2801 Mtetra
.475 .826 .997 r
.6895 .2801 .70022 .28665 .712 .2845 .70138 .27801 Mtetra
.473 .826 .996 r
.70138 .27801 .712 .2845 .72384 .28234 .71332 .2759 Mtetra
.47 .827 .996 r
.71332 .2759 .72384 .28234 .73574 .28016 .72532 .27378 Mtetra
.468 .827 .995 r
.72532 .27378 .73574 .28016 .7477 .27797 .7374 .27164 Mtetra
.466 .828 .994 r
.7374 .27164 .7477 .27797 .75973 .27576 .74953 .26949 Mtetra
.464 .828 .994 r
.74953 .26949 .75973 .27576 .77182 .27354 .76173 .26732 Mtetra
.461 .829 .993 r
.76173 .26732 .77182 .27354 .78397 .27131 .774 .26514 Mtetra
.459 .829 .992 r
.774 .26514 .78397 .27131 .7962 .26906 .78634 .26294 Mtetra
.457 .83 .991 r
.78634 .26294 .7962 .26906 .80848 .2668 .79874 .26072 Mtetra
.664 .741 .908 r
.15287 .36884 .16654 .38157 .17598 .3782 .16235 .36543 Mtetra
.663 .741 .908 r
.16235 .36543 .17598 .3782 .18545 .37481 .17187 .362 Mtetra
.66 .741 .909 r
.17187 .362 .18545 .37481 .19495 .37145 .18141 .35864 Mtetra
.65 .739 .914 r
.18141 .35864 .19495 .37145 .20448 .36821 .19095 .35551 Mtetra
.635 .737 .922 r
.19095 .35551 .20448 .36821 .21402 .3652 .20051 .35272 Mtetra
.618 .737 .931 r
.20051 .35272 .21402 .3652 .22357 .36245 .21006 .35026 Mtetra
.603 .738 .94 r
.21006 .35026 .22357 .36245 .23313 .35994 .21963 .34808 Mtetra
.589 .74 .948 r
.21963 .34808 .23313 .35994 .24272 .35764 .22923 .3461 Mtetra
.577 .743 .955 r
.22923 .3461 .24272 .35764 .25234 .3555 .23886 .34427 Mtetra
.568 .746 .961 r
.23886 .34427 .25234 .3555 .26199 .35348 .24852 .34256 Mtetra
.559 .749 .966 r
.24852 .34256 .26199 .35348 .27168 .35156 .25822 .34093 Mtetra
.552 .753 .971 r
.25822 .34093 .27168 .35156 .2814 .34972 .26796 .33936 Mtetra
.546 .757 .975 r
.26796 .33936 .2814 .34972 .29117 .34793 .27776 .33782 Mtetra
.54 .761 .978 r
.27776 .33782 .29117 .34793 .30098 .34617 .28759 .33631 Mtetra
.535 .764 .982 r
.28759 .33631 .30098 .34617 .31084 .34445 .29748 .33481 Mtetra
.531 .768 .984 r
.29748 .33481 .31084 .34445 .32075 .34275 .30742 .33332 Mtetra
.527 .771 .987 r
.30742 .33332 .32075 .34275 .3307 .34106 .31741 .33183 Mtetra
.523 .775 .989 r
.31741 .33183 .3307 .34106 .3407 .33937 .32745 .33034 Mtetra
.52 .778 .991 r
.32745 .33034 .3407 .33937 .35075 .33769 .33754 .32884 Mtetra
.517 .781 .992 r
.33754 .32884 .35075 .33769 .36085 .33601 .34768 .32733 Mtetra
.514 .784 .994 r
.34768 .32733 .36085 .33601 .37101 .33432 .35788 .32581 Mtetra
.511 .786 .995 r
.35788 .32581 .37101 .33432 .38121 .33263 .36813 .32427 Mtetra
.508 .789 .996 r
.36813 .32427 .38121 .33263 .39147 .33093 .37844 .32272 Mtetra
.505 .792 .997 r
.37844 .32272 .39147 .33093 .40177 .32922 .3888 .32116 Mtetra
.503 .794 .998 r
.3888 .32116 .40177 .32922 .41213 .32751 .39922 .31958 Mtetra
.5 .796 .998 r
.39922 .31958 .41213 .32751 .42255 .32578 .40969 .31798 Mtetra
.498 .798 .999 r
.40969 .31798 .42255 .32578 .43302 .32404 .42022 .31637 Mtetra
.495 .801 .999 r
.42022 .31637 .43302 .32404 .44354 .32228 .4308 .31473 Mtetra
.493 .802 1 r
.4308 .31473 .44354 .32228 .45412 .32052 .44144 .31309 Mtetra
.49 .804 1 r
.44144 .31309 .45412 .32052 .46475 .31874 .45214 .31142 Mtetra
.488 .806 1 r
.45214 .31142 .46475 .31874 .47543 .31695 .46289 .30974 Mtetra
.485 .808 1 r
.46289 .30974 .47543 .31695 .48618 .31514 .4737 .30804 Mtetra
.483 .809 1 r
.4737 .30804 .48618 .31514 .49697 .31332 .48457 .30632 Mtetra
.48 .811 1 r
.48457 .30632 .49697 .31332 .50783 .31148 .4955 .30459 Mtetra
.478 .812 .999 r
.4955 .30459 .50783 .31148 .51874 .30963 .50648 .30283 Mtetra
.475 .813 .999 r
.50648 .30283 .51874 .30963 .52971 .30777 .51753 .30106 Mtetra
.473 .815 .999 r
.51753 .30106 .52971 .30777 .54073 .30589 .52864 .29928 Mtetra
.47 .816 .998 r
.52864 .29928 .54073 .30589 .55182 .304 .5398 .29747 Mtetra
.468 .817 .998 r
.5398 .29747 .55182 .304 .56296 .30209 .55103 .29565 Mtetra
.465 .818 .997 r
.55103 .29565 .56296 .30209 .57416 .30017 .56231 .29381 Mtetra
.463 .819 .996 r
.56231 .29381 .57416 .30017 .58542 .29823 .57366 .29195 Mtetra
.46 .82 .996 r
.57366 .29195 .58542 .29823 .59674 .29627 .58507 .29008 Mtetra
.457 .82 .995 r
.58507 .29008 .59674 .29627 .60812 .29431 .59654 .28819 Mtetra
.455 .821 .994 r
.59654 .28819 .60812 .29431 .61956 .29232 .60807 .28628 Mtetra
.452 .822 .993 r
.60807 .28628 .61956 .29232 .63107 .29032 .61967 .28435 Mtetra
.45 .822 .992 r
.61967 .28435 .63107 .29032 .64263 .28831 .63133 .28241 Mtetra
.447 .823 .991 r
.63133 .28241 .64263 .28831 .65425 .28628 .64305 .28045 Mtetra
.445 .823 .99 r
.64305 .28045 .65425 .28628 .66594 .28423 .65484 .27848 Mtetra
.442 .824 .989 r
.65484 .27848 .66594 .28423 .67769 .28217 .66669 .27649 Mtetra
.439 .824 .988 r
.66669 .27649 .67769 .28217 .6895 .2801 .67861 .27448 Mtetra
.437 .824 .987 r
.67861 .27448 .6895 .2801 .70138 .27801 .69059 .27245 Mtetra
.434 .825 .985 r
.69059 .27245 .70138 .27801 .71332 .2759 .70264 .27041 Mtetra
.431 .825 .984 r
.70264 .27041 .71332 .2759 .72532 .27378 .71476 .26835 Mtetra
.429 .825 .983 r
.71476 .26835 .72532 .27378 .7374 .27164 .72694 .26627 Mtetra
.426 .825 .981 r
.72694 .26627 .7374 .27164 .74953 .26949 .73919 .26418 Mtetra
.423 .825 .98 r
.73919 .26418 .74953 .26949 .76173 .26732 .75151 .26207 Mtetra
.421 .825 .978 r
.75151 .26207 .76173 .26732 .774 .26514 .76389 .25994 Mtetra
.418 .825 .977 r
.76389 .25994 .774 .26514 .78634 .26294 .77635 .2578 Mtetra
.415 .825 .975 r
.77635 .2578 .78634 .26294 .79874 .26072 .78888 .25563 Mtetra
.664 .741 .908 r
.13902 .35594 .15287 .36884 .16235 .36543 .14854 .35248 Mtetra
.663 .741 .908 r
.14854 .35248 .16235 .36543 .17187 .362 .15809 .34901 Mtetra
.656 .739 .911 r
.15809 .34901 .17187 .362 .18141 .35864 .16766 .34572 Mtetra
.638 .736 .92 r
.16766 .34572 .18141 .35864 .19095 .35551 .17722 .34283 Mtetra
.615 .735 .931 r
.17722 .34283 .19095 .35551 .20051 .35272 .18676 .3404 Mtetra
.593 .735 .942 r
.18676 .3404 .20051 .35272 .21006 .35026 .19631 .33836 Mtetra
.574 .737 .952 r
.19631 .33836 .21006 .35026 .21963 .34808 .20588 .33659 Mtetra
.558 .74 .961 r
.20588 .33659 .21963 .34808 .22923 .3461 .21547 .33502 Mtetra
.545 .743 .968 r
.21547 .33502 .22923 .3461 .23886 .34427 .2251 .33358 Mtetra
.534 .747 .974 r
.2251 .33358 .23886 .34427 .24852 .34256 .23476 .33223 Mtetra
.525 .752 .979 r
.23476 .33223 .24852 .34256 .25822 .34093 .24448 .33094 Mtetra
.518 .756 .983 r
.24448 .33094 .25822 .34093 .26796 .33936 .25424 .32967 Mtetra
.511 .76 .986 r
.25424 .32967 .26796 .33936 .27776 .33782 .26405 .32843 Mtetra
.505 .764 .989 r
.26405 .32843 .27776 .33782 .28759 .33631 .27391 .32719 Mtetra
.5 .768 .991 r
.27391 .32719 .28759 .33631 .29748 .33481 .28383 .32594 Mtetra
.495 .772 .993 r
.28383 .32594 .29748 .33481 .30742 .33332 .29379 .32469 Mtetra
.491 .776 .995 r
.29379 .32469 .30742 .33332 .31741 .33183 .30382 .32343 Mtetra
.487 .779 .996 r
.30382 .32343 .31741 .33183 .32745 .33034 .31389 .32214 Mtetra
.484 .782 .997 r
.31389 .32214 .32745 .33034 .33754 .32884 .32403 .32084 Mtetra
.48 .785 .998 r
.32403 .32084 .33754 .32884 .34768 .32733 .33422 .31952 Mtetra
.477 .788 .999 r
.33422 .31952 .34768 .32733 .35788 .32581 .34446 .31818 Mtetra
.473 .791 .999 r
.34446 .31818 .35788 .32581 .36813 .32427 .35476 .31682 Mtetra
.47 .793 .999 r
.35476 .31682 .36813 .32427 .37844 .32272 .36512 .31544 Mtetra
.467 .796 .999 r
.36512 .31544 .37844 .32272 .3888 .32116 .37554 .31403 Mtetra
.464 .798 .999 r
.37554 .31403 .3888 .32116 .39922 .31958 .38601 .3126 Mtetra
.461 .8 .999 r
.38601 .3126 .39922 .31958 .40969 .31798 .39654 .31115 Mtetra
.458 .802 .998 r
.39654 .31115 .40969 .31798 .42022 .31637 .40713 .30968 Mtetra
.455 .803 .998 r
.40713 .30968 .42022 .31637 .4308 .31473 .41778 .30818 Mtetra
.452 .805 .997 r
.41778 .30818 .4308 .31473 .44144 .31309 .42848 .30667 Mtetra
.448 .807 .997 r
.42848 .30667 .44144 .31309 .45214 .31142 .43925 .30513 Mtetra
.445 .808 .996 r
.43925 .30513 .45214 .31142 .46289 .30974 .45007 .30357 Mtetra
.442 .809 .995 r
.45007 .30357 .46289 .30974 .4737 .30804 .46095 .30198 Mtetra
.439 .81 .994 r
.46095 .30198 .4737 .30804 .48457 .30632 .4719 .30038 Mtetra
.436 .811 .993 r
.4719 .30038 .48457 .30632 .4955 .30459 .4829 .29876 Mtetra
.433 .812 .991 r
.4829 .29876 .4955 .30459 .50648 .30283 .49397 .29711 Mtetra
.43 .813 .99 r
.49397 .29711 .50648 .30283 .51753 .30106 .5051 .29545 Mtetra
.427 .814 .989 r
.5051 .29545 .51753 .30106 .52864 .29928 .51628 .29376 Mtetra
.424 .814 .987 r
.51628 .29376 .52864 .29928 .5398 .29747 .52754 .29206 Mtetra
.421 .815 .986 r
.52754 .29206 .5398 .29747 .55103 .29565 .53885 .29033 Mtetra
.418 .815 .984 r
.53885 .29033 .55103 .29565 .56231 .29381 .55022 .28859 Mtetra
.414 .815 .982 r
.55022 .28859 .56231 .29381 .57366 .29195 .56166 .28683 Mtetra
.411 .816 .98 r
.56166 .28683 .57366 .29195 .58507 .29008 .57317 .28504 Mtetra
.408 .816 .979 r
.57317 .28504 .58507 .29008 .59654 .28819 .58473 .28324 Mtetra
.405 .816 .977 r
.58473 .28324 .59654 .28819 .60807 .28628 .59636 .28142 Mtetra
.402 .816 .975 r
.59636 .28142 .60807 .28628 .61967 .28435 .60806 .27958 Mtetra
.398 .816 .973 r
.60806 .27958 .61967 .28435 .63133 .28241 .61982 .27772 Mtetra
.395 .816 .971 r
.61982 .27772 .63133 .28241 .64305 .28045 .63165 .27584 Mtetra
.392 .816 .969 r
.63165 .27584 .64305 .28045 .65484 .27848 .64354 .27394 Mtetra
.389 .815 .966 r
.64354 .27394 .65484 .27848 .66669 .27649 .65551 .27203 Mtetra
.385 .815 .964 r
.65551 .27203 .66669 .27649 .67861 .27448 .66753 .2701 Mtetra
.382 .815 .962 r
.66753 .2701 .67861 .27448 .69059 .27245 .67963 .26814 Mtetra
.379 .814 .959 r
.67963 .26814 .69059 .27245 .70264 .27041 .69179 .26617 Mtetra
.376 .814 .957 r
.69179 .26617 .70264 .27041 .71476 .26835 .70403 .26419 Mtetra
.372 .813 .955 r
.70403 .26419 .71476 .26835 .72694 .26627 .71633 .26218 Mtetra
.369 .812 .952 r
.71633 .26218 .72694 .26627 .73919 .26418 .7287 .26015 Mtetra
.366 .812 .95 r
.7287 .26015 .73919 .26418 .75151 .26207 .74115 .25811 Mtetra
.362 .811 .947 r
.74115 .25811 .75151 .26207 .76389 .25994 .75366 .25605 Mtetra
.359 .81 .944 r
.75366 .25605 .76389 .25994 .77635 .2578 .76625 .25397 Mtetra
.356 .809 .942 r
.76625 .25397 .77635 .2578 .78888 .25563 .7789 .25187 Mtetra
.664 .741 .908 r
.12497 .34286 .13902 .35594 .14854 .35248 .13453 .33935 Mtetra
.662 .741 .909 r
.13453 .33935 .14854 .35248 .15809 .34901 .14412 .33587 Mtetra
.645 .737 .916 r
.14412 .33587 .15809 .34901 .16766 .34572 .15369 .33278 Mtetra
.614 .732 .93 r
.15369 .33278 .16766 .34572 .17722 .34283 .16324 .33034 Mtetra
.582 .73 .945 r
.16324 .33034 .17722 .34283 .18676 .3404 .17276 .32846 Mtetra
.553 .731 .958 r
.17276 .32846 .18676 .3404 .19631 .33836 .18228 .32698 Mtetra
.53 .734 .968 r
.18228 .32698 .19631 .33836 .20588 .33659 .19182 .32575 Mtetra
.512 .738 .976 r
.19182 .32575 .20588 .33659 .21547 .33502 .2014 .32468 Mtetra
.497 .743 .982 r
.2014 .32468 .21547 .33502 .2251 .33358 .21102 .32371 Mtetra
.485 .747 .987 r
.21102 .32371 .2251 .33358 .23476 .33223 .22068 .32278 Mtetra
.475 .752 .99 r
.22068 .32278 .23476 .33223 .24448 .33094 .2304 .32187 Mtetra
.467 .757 .993 r
.2304 .32187 .24448 .33094 .25424 .32967 .24018 .32097 Mtetra
.46 .762 .995 r
.24018 .32097 .25424 .32967 .26405 .32843 .25 .32005 Mtetra
.454 .766 .996 r
.25 .32005 .26405 .32843 .27391 .32719 .25989 .31912 Mtetra
.448 .77 .997 r
.25989 .31912 .27391 .32719 .28383 .32594 .26983 .31816 Mtetra
.443 .774 .997 r
.26983 .31816 .28383 .32594 .29379 .32469 .27983 .31718 Mtetra
.438 .777 .997 r
.27983 .31718 .29379 .32469 .30382 .32343 .28988 .31617 Mtetra
.434 .78 .997 r
.28988 .31617 .30382 .32343 .31389 .32214 .3 .31512 Mtetra
.43 .783 .997 r
.3 .31512 .31389 .32214 .32403 .32084 .31017 .31405 Mtetra
.425 .786 .996 r
.31017 .31405 .32403 .32084 .33422 .31952 .32041 .31294 Mtetra
.421 .788 .995 r
.32041 .31294 .33422 .31952 .34446 .31818 .3307 .3118 Mtetra
.417 .79 .994 r
.3307 .3118 .34446 .31818 .35476 .31682 .34105 .31064 Mtetra
.413 .792 .992 r
.34105 .31064 .35476 .31682 .36512 .31544 .35147 .30944 Mtetra
.409 .794 .99 r
.35147 .30944 .36512 .31544 .37554 .31403 .36194 .30821 Mtetra
.405 .795 .989 r
.36194 .30821 .37554 .31403 .38601 .3126 .37247 .30695 Mtetra
.401 .797 .987 r
.37247 .30695 .38601 .3126 .39654 .31115 .38306 .30567 Mtetra
.398 .798 .985 r
.38306 .30567 .39654 .31115 .40713 .30968 .39372 .30435 Mtetra
.394 .799 .982 r
.39372 .30435 .40713 .30968 .41778 .30818 .40443 .30301 Mtetra
.39 .799 .98 r
.40443 .30301 .41778 .30818 .42848 .30667 .41521 .30164 Mtetra
.386 .8 .978 r
.41521 .30164 .42848 .30667 .43925 .30513 .42604 .30024 Mtetra
.382 .8 .975 r
.42604 .30024 .43925 .30513 .45007 .30357 .43694 .29882 Mtetra
.378 .801 .973 r
.43694 .29882 .45007 .30357 .46095 .30198 .44791 .29737 Mtetra
.374 .801 .97 r
.44791 .29737 .46095 .30198 .4719 .30038 .45893 .2959 Mtetra
.37 .801 .967 r
.45893 .2959 .4719 .30038 .4829 .29876 .47002 .29441 Mtetra
.366 .801 .964 r
.47002 .29441 .4829 .29876 .49397 .29711 .48117 .29289 Mtetra
.362 .8 .961 r
.48117 .29289 .49397 .29711 .5051 .29545 .49238 .29134 Mtetra
.358 .8 .958 r
.49238 .29134 .5051 .29545 .51628 .29376 .50366 .28977 Mtetra
.354 .8 .955 r
.50366 .28977 .51628 .29376 .52754 .29206 .515 .28818 Mtetra
.35 .799 .951 r
.515 .28818 .52754 .29206 .53885 .29033 .52641 .28657 Mtetra
.346 .798 .948 r
.52641 .28657 .53885 .29033 .55022 .28859 .53788 .28494 Mtetra
.342 .798 .945 r
.53788 .28494 .55022 .28859 .56166 .28683 .54942 .28328 Mtetra
.338 .797 .941 r
.54942 .28328 .56166 .28683 .57317 .28504 .56102 .2816 Mtetra
.334 .796 .938 r
.56102 .2816 .57317 .28504 .58473 .28324 .57269 .2799 Mtetra
.33 .795 .934 r
.57269 .2799 .58473 .28324 .59636 .28142 .58443 .27818 Mtetra
.326 .794 .931 r
.58443 .27818 .59636 .28142 .60806 .27958 .59623 .27644 Mtetra
.322 .792 .927 r
.59623 .27644 .60806 .27958 .61982 .27772 .6081 .27467 Mtetra
.318 .791 .923 r
.6081 .27467 .61982 .27772 .63165 .27584 .62004 .27289 Mtetra
.314 .79 .919 r
.62004 .27289 .63165 .27584 .64354 .27394 .63205 .27109 Mtetra
.31 .788 .915 r
.63205 .27109 .64354 .27394 .65551 .27203 .64413 .26926 Mtetra
.306 .787 .912 r
.64413 .26926 .65551 .27203 .66753 .2701 .65628 .26742 Mtetra
.302 .785 .908 r
.65628 .26742 .66753 .2701 .67963 .26814 .6685 .26555 Mtetra
.298 .784 .904 r
.6685 .26555 .67963 .26814 .69179 .26617 .68079 .26367 Mtetra
.294 .782 .9 r
.68079 .26367 .69179 .26617 .70403 .26419 .69315 .26177 Mtetra
.29 .78 .896 r
.69315 .26177 .70403 .26419 .71633 .26218 .70558 .25984 Mtetra
.285 .778 .892 r
.70558 .25984 .71633 .26218 .7287 .26015 .71808 .2579 Mtetra
.281 .777 .888 r
.71808 .2579 .7287 .26015 .74115 .25811 .73066 .25594 Mtetra
.277 .775 .883 r
.73066 .25594 .74115 .25811 .75366 .25605 .74331 .25396 Mtetra
.273 .773 .879 r
.74331 .25396 .75366 .25605 .76625 .25397 .75604 .25196 Mtetra
.269 .771 .875 r
.75604 .25196 .76625 .25397 .7789 .25187 .76884 .24993 Mtetra
.664 .741 .908 r
.11072 .32959 .12497 .34286 .13453 .33935 .12032 .32603 Mtetra
.656 .74 .911 r
.12032 .32603 .13453 .33935 .14412 .33587 .12993 .32263 Mtetra
.62 .731 .926 r
.12993 .32263 .14412 .33587 .15369 .33278 .13948 .32003 Mtetra
.569 .724 .947 r
.13948 .32003 .15369 .33278 .16324 .33034 .14897 .31834 Mtetra
.523 .722 .964 r
.14897 .31834 .16324 .33034 .17276 .32846 .15843 .31725 Mtetra
.486 .723 .976 r
.15843 .31725 .17276 .32846 .18228 .32698 .1679 .31652 Mtetra
.458 .726 .984 r
.1679 .31652 .18228 .32698 .19182 .32575 .1774 .31597 Mtetra
.437 .731 .989 r
.1774 .31597 .19182 .32575 .2014 .32468 .18695 .31552 Mtetra
.42 .736 .991 r
.18695 .31552 .2014 .32468 .21102 .32371 .19655 .31509 Mtetra
.407 .741 .993 r
.19655 .31509 .21102 .32371 .22068 .32278 .20621 .31466 Mtetra
.396 .746 .993 r
.20621 .31466 .22068 .32278 .2304 .32187 .21593 .31421 Mtetra
.387 .75 .992 r
.21593 .31421 .2304 .32187 .24018 .32097 .22571 .31372 Mtetra
.379 .754 .991 r
.22571 .31372 .24018 .32097 .25 .32005 .23555 .31318 Mtetra
.372 .758 .989 r
.23555 .31318 .25 .32005 .25989 .31912 .24545 .3126 Mtetra
.365 .761 .986 r
.24545 .3126 .25989 .31912 .26983 .31816 .25542 .31197 Mtetra
.359 .764 .983 r
.25542 .31197 .26983 .31816 .27983 .31718 .26545 .3113 Mtetra
.354 .766 .98 r
.26545 .3113 .27983 .31718 .28988 .31617 .27554 .31057 Mtetra
.348 .768 .977 r
.27554 .31057 .28988 .31617 .3 .31512 .2857 .3098 Mtetra
.343 .77 .973 r
.2857 .3098 .3 .31512 .31017 .31405 .29592 .30898 Mtetra
.337 .771 .969 r
.29592 .30898 .31017 .31405 .32041 .31294 .3062 .30812 Mtetra
.332 .772 .965 r
.3062 .30812 .32041 .31294 .3307 .3118 .31654 .30722 Mtetra
.327 .772 .96 r
.31654 .30722 .3307 .3118 .34105 .31064 .32695 .30627 Mtetra
.322 .773 .956 r
.32695 .30627 .34105 .31064 .35147 .30944 .33742 .30529 Mtetra
.316 .773 .951 r
.33742 .30529 .35147 .30944 .36194 .30821 .34795 .30426 Mtetra
.311 .772 .946 r
.34795 .30426 .36194 .30821 .37247 .30695 .35854 .3032 Mtetra
.306 .772 .941 r
.35854 .3032 .37247 .30695 .38306 .30567 .3692 .30211 Mtetra
.301 .771 .936 r
.3692 .30211 .38306 .30567 .39372 .30435 .37993 .30097 Mtetra
.296 .77 .931 r
.37993 .30097 .39372 .30435 .40443 .30301 .39071 .29981 Mtetra
.291 .769 .926 r
.39071 .29981 .40443 .30301 .41521 .30164 .40157 .29861 Mtetra
.286 .768 .921 r
.40157 .29861 .41521 .30164 .42604 .30024 .41248 .29738 Mtetra
.281 .767 .915 r
.41248 .29738 .42604 .30024 .43694 .29882 .42346 .29612 Mtetra
.275 .765 .91 r
.42346 .29612 .43694 .29882 .44791 .29737 .43451 .29483 Mtetra
.27 .763 .904 r
.43451 .29483 .44791 .29737 .45893 .2959 .44562 .29351 Mtetra
.265 .762 .898 r
.44562 .29351 .45893 .2959 .47002 .29441 .45679 .29217 Mtetra
.26 .76 .893 r
.45679 .29217 .47002 .29441 .48117 .29289 .46804 .29079 Mtetra
.255 .757 .887 r
.46804 .29079 .48117 .29289 .49238 .29134 .47934 .28939 Mtetra
.25 .755 .881 r
.47934 .28939 .49238 .29134 .50366 .28977 .49072 .28796 Mtetra
.245 .753 .875 r
.49072 .28796 .50366 .28977 .515 .28818 .50216 .28651 Mtetra
.24 .751 .869 r
.50216 .28651 .515 .28818 .52641 .28657 .51367 .28502 Mtetra
.235 .748 .864 r
.51367 .28502 .52641 .28657 .53788 .28494 .52525 .28352 Mtetra
.23 .745 .858 r
.52525 .28352 .53788 .28494 .54942 .28328 .53689 .28199 Mtetra
.225 .743 .852 r
.53689 .28199 .54942 .28328 .56102 .2816 .5486 .28044 Mtetra
.22 .74 .846 r
.5486 .28044 .56102 .2816 .57269 .2799 .56039 .27886 Mtetra
.215 .737 .84 r
.56039 .27886 .57269 .2799 .58443 .27818 .57224 .27726 Mtetra
.21 .734 .834 r
.57224 .27726 .58443 .27818 .59623 .27644 .58416 .27563 Mtetra
.205 .731 .828 r
.58416 .27563 .59623 .27644 .6081 .27467 .59615 .27399 Mtetra
.201 .728 .822 r
.59615 .27399 .6081 .27467 .62004 .27289 .60822 .27232 Mtetra
.196 .725 .816 r
.60822 .27232 .62004 .27289 .63205 .27109 .62035 .27062 Mtetra
.191 .722 .81 r
.62035 .27062 .63205 .27109 .64413 .26926 .63256 .26891 Mtetra
.186 .719 .804 r
.63256 .26891 .64413 .26926 .65628 .26742 .64484 .26717 Mtetra
.181 .716 .798 r
.64484 .26717 .65628 .26742 .6685 .26555 .65719 .26542 Mtetra
.177 .713 .792 r
.65719 .26542 .6685 .26555 .68079 .26367 .66962 .26364 Mtetra
.172 .709 .786 r
.66962 .26364 .68079 .26367 .69315 .26177 .68212 .26184 Mtetra
.167 .706 .78 r
.68212 .26184 .69315 .26177 .70558 .25984 .69469 .26002 Mtetra
.163 .703 .774 r
.69469 .26002 .70558 .25984 .71808 .2579 .70734 .25817 Mtetra
.158 .699 .768 r
.70734 .25817 .71808 .2579 .73066 .25594 .72007 .25631 Mtetra
.154 .696 .762 r
.72007 .25631 .73066 .25594 .74331 .25396 .73287 .25443 Mtetra
.149 .692 .756 r
.73287 .25443 .74331 .25396 .75604 .25196 .74575 .25252 Mtetra
.145 .689 .75 r
.74575 .25252 .75604 .25196 .76884 .24993 .75871 .2506 Mtetra
.663 .741 .908 r
.09627 .31614 .11072 .32959 .12032 .32603 .10591 .31253 Mtetra
.639 .735 .918 r
.10591 .31253 .12032 .32603 .12993 .32263 .11551 .30949 Mtetra
.561 .717 .946 r
.11551 .30949 .12993 .32263 .13948 .32003 .12496 .30792 Mtetra
.475 .703 .969 r
.12496 .30792 .13948 .32003 .14897 .31834 .13433 .30741 Mtetra
.408 .697 .98 r
.13433 .30741 .14897 .31834 .15843 .31725 .14368 .30743 Mtetra
.359 .696 .983 r
.14368 .30743 .15843 .31725 .1679 .31652 .15307 .30768 Mtetra
.325 .698 .981 r
.15307 .30768 .1679 .31652 .1774 .31597 .16251 .30798 Mtetra
.3 .701 .976 r
.16251 .30798 .1774 .31597 .18695 .31552 .17202 .30827 Mtetra
.282 .704 .97 r
.17202 .30827 .18695 .31552 .19655 .31509 .18159 .30851 Mtetra
.267 .707 .962 r
.18159 .30851 .19655 .31509 .20621 .31466 .19123 .30867 Mtetra
.255 .71 .954 r
.19123 .30867 .20621 .31466 .21593 .31421 .20094 .30875 Mtetra
.245 .712 .946 r
.20094 .30875 .21593 .31421 .22571 .31372 .21073 .30874 Mtetra
.236 .713 .937 r
.21073 .30874 .22571 .31372 .23555 .31318 .22058 .30865 Mtetra
.228 .714 .928 r
.22058 .30865 .23555 .31318 .24545 .3126 .2305 .30848 Mtetra
.221 .714 .919 r
.2305 .30848 .24545 .3126 .25542 .31197 .24049 .30824 Mtetra
.214 .714 .91 r
.24049 .30824 .25542 .31197 .26545 .3113 .25055 .30792 Mtetra
.207 .713 .9 r
.25055 .30792 .26545 .3113 .27554 .31057 .26068 .30753 Mtetra
.2 .712 .891 r
.26068 .30753 .27554 .31057 .2857 .3098 .27088 .30708 Mtetra
.193 .71 .881 r
.27088 .30708 .2857 .3098 .29592 .30898 .28114 .30657 Mtetra
.187 .708 .871 r
.28114 .30657 .29592 .30898 .3062 .30812 .29147 .30599 Mtetra
.18 .706 .862 r
.29147 .30599 .3062 .30812 .31654 .30722 .30187 .30536 Mtetra
.174 .703 .852 r
.30187 .30536 .31654 .30722 .32695 .30627 .31234 .30468 Mtetra
.167 .7 .842 r
.31234 .30468 .32695 .30627 .33742 .30529 .32287 .30395 Mtetra
.161 .697 .833 r
.32287 .30395 .33742 .30529 .34795 .30426 .33347 .30317 Mtetra
.155 .694 .823 r
.33347 .30317 .34795 .30426 .35854 .3032 .34414 .30234 Mtetra
.149 .69 .814 r
.34414 .30234 .35854 .3032 .3692 .30211 .35487 .30147 Mtetra
.142 .686 .804 r
.35487 .30147 .3692 .30211 .37993 .30097 .36567 .30056 Mtetra
.136 .682 .795 r
.36567 .30056 .37993 .30097 .39071 .29981 .37654 .2996 Mtetra
.13 .678 .785 r
.37654 .2996 .39071 .29981 .40157 .29861 .38747 .29861 Mtetra
.124 .674 .776 r
.38747 .29861 .40157 .29861 .41248 .29738 .39848 .29758 Mtetra
.118 .67 .766 r
.39848 .29758 .41248 .29738 .42346 .29612 .40955 .29652 Mtetra
.113 .666 .757 r
.40955 .29652 .42346 .29612 .43451 .29483 .42068 .29542 Mtetra
.107 .661 .748 r
.42068 .29542 .43451 .29483 .44562 .29351 .43189 .29428 Mtetra
.101 .657 .739 r
.43189 .29428 .44562 .29351 .45679 .29217 .44317 .29312 Mtetra
.095 .652 .73 r
.44317 .29312 .45679 .29217 .46804 .29079 .45451 .29192 Mtetra
.09 .647 .721 r
.45451 .29192 .46804 .29079 .47934 .28939 .46593 .29069 Mtetra
.084 .643 .712 r
.46593 .29069 .47934 .28939 .49072 .28796 .47741 .28943 Mtetra
.079 .638 .703 r
.47741 .28943 .49072 .28796 .50216 .28651 .48896 .28814 Mtetra
0 0 0 r
.48896 .28814 .50216 .28651 .51367 .28502 .50059 .28683 Mtetra
.50059 .28683 .51367 .28502 .52525 .28352 .51228 .28548 Mtetra
.51228 .28548 .52525 .28352 .53689 .28199 .52405 .28411 Mtetra
.52405 .28411 .53689 .28199 .5486 .28044 .53589 .28271 Mtetra
.53589 .28271 .5486 .28044 .56039 .27886 .54779 .28128 Mtetra
.54779 .28128 .56039 .27886 .57224 .27726 .55978 .27983 Mtetra
.55978 .27983 .57224 .27726 .58416 .27563 .57183 .27836 Mtetra
.57183 .27836 .58416 .27563 .59615 .27399 .58396 .27685 Mtetra
.58396 .27685 .59615 .27399 .60822 .27232 .59616 .27533 Mtetra
.59616 .27533 .60822 .27232 .62035 .27062 .60844 .27378 Mtetra
.60844 .27378 .62035 .27062 .63256 .26891 .62079 .2722 Mtetra
.62079 .2722 .63256 .26891 .64484 .26717 .63322 .2706 Mtetra
.63322 .2706 .64484 .26717 .65719 .26542 .64573 .26898 Mtetra
.64573 .26898 .65719 .26542 .66962 .26364 .65831 .26733 Mtetra
.65831 .26733 .66962 .26364 .68212 .26184 .67097 .26567 Mtetra
.67097 .26567 .68212 .26184 .69469 .26002 .6837 .26397 Mtetra
.003 0 0 r
.6837 .26397 .69469 .26002 .70734 .25817 .69652 .26226 Mtetra
.008 0 0 r
.69652 .26226 .70734 .25817 .72007 .25631 .70941 .26052 Mtetra
.012 0 0 r
.70941 .26052 .72007 .25631 .73287 .25443 .72239 .25877 Mtetra
.016 0 0 r
.72239 .25877 .73287 .25443 .74575 .25252 .73544 .25698 Mtetra
.02 0 0 r
.73544 .25698 .74575 .25252 .75871 .2506 .74857 .25518 Mtetra
.661 .741 .909 r
.08161 .30249 .09627 .31614 .10591 .31253 .09128 .29889 Mtetra
.575 .716 .938 r
.09128 .29889 .10591 .31253 .11551 .30949 .10075 .29707 Mtetra
.394 .664 .968 r
.10075 .29707 .11551 .30949 .12496 .30792 .10996 .29746 Mtetra
.243 .624 .958 r
.10996 .29746 .12496 .30792 .13433 .30741 .11913 .29876 Mtetra
.147 .6 .929 r
.11913 .29876 .13433 .30741 .14368 .30743 .12832 .30029 Mtetra
.089 .588 .897 r
.12832 .30029 .14368 .30743 .15307 .30768 .13759 .3018 Mtetra
.055 .582 .867 r
.13759 .3018 .15307 .30768 .16251 .30798 .14695 .30317 Mtetra
.033 .578 .839 r
.14695 .30317 .16251 .30798 .17202 .30827 .15639 .30438 Mtetra
.018 .576 .814 r
.15639 .30438 .17202 .30827 .18159 .30851 .16592 .30543 Mtetra
.007 .574 .791 r
.16592 .30543 .18159 .30851 .19123 .30867 .17553 .3063 Mtetra
0 .571 .769 r
.17553 .3063 .19123 .30867 .20094 .30875 .18523 .30703 Mtetra
0 .568 .749 r
.18523 .30703 .20094 .30875 .21073 .30874 .19502 .30761 Mtetra
0 .564 .729 r
.19502 .30761 .21073 .30874 .22058 .30865 .20488 .30806 Mtetra
0 .56 .71 r
.20488 .30806 .22058 .30865 .2305 .30848 .21482 .30839 Mtetra
.026 0 0 r
.21482 .30839 .2305 .30848 .24049 .30824 .22484 .30862 Mtetra
.032 0 0 r
.22484 .30862 .24049 .30824 .25055 .30792 .23493 .30873 Mtetra
.037 0 0 r
.23493 .30873 .25055 .30792 .26068 .30753 .2451 .30876 Mtetra
.043 0 0 r
.2451 .30876 .26068 .30753 .27088 .30708 .25534 .3087 Mtetra
.048 0 0 r
.25534 .3087 .27088 .30708 .28114 .30657 .26566 .30855 Mtetra
.053 0 0 r
.26566 .30855 .28114 .30657 .29147 .30599 .27605 .30833 Mtetra
.058 0 0 r
.27605 .30833 .29147 .30599 .30187 .30536 .28651 .30804 Mtetra
.063 0 0 r
.28651 .30804 .30187 .30536 .31234 .30468 .29704 .30769 Mtetra
.068 0 0 r
.29704 .30769 .31234 .30468 .32287 .30395 .30765 .30727 Mtetra
.073 0 0 r
.30765 .30727 .32287 .30395 .33347 .30317 .31833 .30679 Mtetra
.078 0 0 r
.31833 .30679 .33347 .30317 .34414 .30234 .32907 .30625 Mtetra
.082 0 0 r
.32907 .30625 .34414 .30234 .35487 .30147 .33989 .30567 Mtetra
.087 0 0 r
.33989 .30567 .35487 .30147 .36567 .30056 .35078 .30503 Mtetra
.092 0 0 r
.35078 .30503 .36567 .30056 .37654 .2996 .36174 .30434 Mtetra
.096 0 0 r
.36174 .30434 .37654 .2996 .38747 .29861 .37278 .30361 Mtetra
.101 0 0 r
.37278 .30361 .38747 .29861 .39848 .29758 .38388 .30284 Mtetra
.105 0 0 r
.38388 .30284 .39848 .29758 .40955 .29652 .39506 .30202 Mtetra
.109 0 0 r
.39506 .30202 .40955 .29652 .42068 .29542 .40631 .30116 Mtetra
.114 0 0 r
.40631 .30116 .42068 .29542 .43189 .29428 .41763 .30027 Mtetra
.118 0 0 r
.41763 .30027 .43189 .29428 .44317 .29312 .42902 .29933 Mtetra
.122 0 0 r
.42902 .29933 .44317 .29312 .45451 .29192 .44048 .29836 Mtetra
.126 0 0 r
.44048 .29836 .45451 .29192 .46593 .29069 .45202 .29736 Mtetra
.13 0 0 r
.45202 .29736 .46593 .29069 .47741 .28943 .46363 .29632 Mtetra
.133 0 0 r
.46363 .29632 .47741 .28943 .48896 .28814 .47532 .29525 Mtetra
.137 0 0 r
.47532 .29525 .48896 .28814 .50059 .28683 .48708 .29414 Mtetra
.141 0 0 r
.48708 .29414 .50059 .28683 .51228 .28548 .49891 .29301 Mtetra
.145 0 0 r
.49891 .29301 .51228 .28548 .52405 .28411 .51082 .29184 Mtetra
.148 0 0 r
.51082 .29184 .52405 .28411 .53589 .28271 .5228 .29064 Mtetra
.151 0 0 r
.5228 .29064 .53589 .28271 .54779 .28128 .53486 .28942 Mtetra
.155 0 0 r
.53486 .28942 .54779 .28128 .55978 .27983 .547 .28816 Mtetra
.158 0 0 r
.547 .28816 .55978 .27983 .57183 .27836 .55921 .28688 Mtetra
.161 0 0 r
.55921 .28688 .57183 .27836 .58396 .27685 .5715 .28557 Mtetra
.165 0 0 r
.5715 .28557 .58396 .27685 .59616 .27533 .58387 .28423 Mtetra
.168 0 0 r
.58387 .28423 .59616 .27533 .60844 .27378 .59632 .28287 Mtetra
.171 0 0 r
.59632 .28287 .60844 .27378 .62079 .2722 .60884 .28148 Mtetra
.174 0 0 r
.60884 .28148 .62079 .2722 .63322 .2706 .62145 .28006 Mtetra
.177 0 0 r
.62145 .28006 .63322 .2706 .64573 .26898 .63413 .27862 Mtetra
.18 0 0 r
.63413 .27862 .64573 .26898 .65831 .26733 .6469 .27716 Mtetra
.183 0 0 r
.6469 .27716 .65831 .26733 .67097 .26567 .65974 .27567 Mtetra
.185 0 0 r
.65974 .27567 .67097 .26567 .6837 .26397 .67267 .27415 Mtetra
.188 0 0 r
.67267 .27415 .6837 .26397 .69652 .26226 .68568 .27261 Mtetra
.191 0 0 r
.68568 .27261 .69652 .26226 .70941 .26052 .69877 .27105 Mtetra
.193 0 0 r
.69877 .27105 .70941 .26052 .72239 .25877 .71195 .26946 Mtetra
.196 0 0 r
.71195 .26946 .72239 .25877 .73544 .25698 .72521 .26785 Mtetra
.199 0 0 r
.72521 .26785 .73544 .25698 .74857 .25518 .73856 .26621 Mtetra
.634 .734 .92 r
.06673 .28864 .08161 .30249 .09128 .29889 .07636 .28562 Mtetra
.254 .579 .943 r
.07636 .28562 .09128 .29889 .10075 .29707 .08534 .28739 Mtetra
0 .357 .761 r
.08534 .28739 .10075 .29707 .10996 .29746 .09411 .29127 Mtetra
.323 0 0 r
.09411 .29127 .10996 .29746 .11913 .29876 .10294 .29524 Mtetra
.362 0 0 r
.10294 .29524 .11913 .29876 .12832 .30029 .1119 .29885 Mtetra
.367 0 0 r
.1119 .29885 .12832 .30029 .13759 .3018 .121 .30203 Mtetra
.361 0 0 r
.121 .30203 .13759 .3018 .14695 .30317 .13023 .30479 Mtetra
.353 0 0 r
.13023 .30479 .14695 .30317 .15639 .30438 .13959 .30719 Mtetra
.344 0 0 r
.13959 .30719 .15639 .30438 .16592 .30543 .14906 .30927 Mtetra
.337 0 0 r
.14906 .30927 .16592 .30543 .17553 .3063 .15864 .31107 Mtetra
.331 0 0 r
.15864 .31107 .17553 .3063 .18523 .30703 .16833 .31263 Mtetra
.325 0 0 r
.16833 .31263 .18523 .30703 .19502 .30761 .1781 .31397 Mtetra
.321 0 0 r
.1781 .31397 .19502 .30761 .20488 .30806 .18798 .31512 Mtetra
.318 0 0 r
.18798 .31512 .20488 .30806 .21482 .30839 .19794 .31611 Mtetra
.315 0 0 r
.19794 .31611 .21482 .30839 .22484 .30862 .20799 .31693 Mtetra
.313 0 0 r
.20799 .31693 .22484 .30862 .23493 .30873 .21813 .31763 Mtetra
.312 0 0 r
.21813 .31763 .23493 .30873 .2451 .30876 .22835 .31819 Mtetra
.311 0 0 r
.22835 .31819 .2451 .30876 .25534 .3087 .23865 .31865 Mtetra
.31 0 0 r
.23865 .31865 .25534 .3087 .26566 .30855 .24903 .319 Mtetra
.24903 .319 .26566 .30855 .27605 .30833 .2595 .31925 Mtetra
.2595 .31925 .27605 .30833 .28651 .30804 .27004 .31941 Mtetra
.27004 .31941 .28651 .30804 .29704 .30769 .28066 .31949 Mtetra
.311 0 0 r
.28066 .31949 .29704 .30769 .30765 .30727 .29136 .3195 Mtetra
.29136 .3195 .30765 .30727 .31833 .30679 .30213 .31943 Mtetra
.312 0 0 r
.30213 .31943 .31833 .30679 .32907 .30625 .31298 .3193 Mtetra
.31298 .3193 .32907 .30625 .33989 .30567 .32391 .3191 Mtetra
.313 0 0 r
.32391 .3191 .33989 .30567 .35078 .30503 .33491 .31884 Mtetra
.314 0 0 r
.33491 .31884 .35078 .30503 .36174 .30434 .346 .31852 Mtetra
.315 0 0 r
.346 .31852 .36174 .30434 .37278 .30361 .35715 .31815 Mtetra
.316 0 0 r
.35715 .31815 .37278 .30361 .38388 .30284 .36839 .31773 Mtetra
.317 0 0 r
.36839 .31773 .38388 .30284 .39506 .30202 .3797 .31725 Mtetra
.318 0 0 r
.3797 .31725 .39506 .30202 .40631 .30116 .39109 .31674 Mtetra
.319 0 0 r
.39109 .31674 .40631 .30116 .41763 .30027 .40255 .31617 Mtetra
.32 0 0 r
.40255 .31617 .41763 .30027 .42902 .29933 .41409 .31557 Mtetra
.321 0 0 r
.41409 .31557 .42902 .29933 .44048 .29836 .42571 .31492 Mtetra
.322 0 0 r
.42571 .31492 .44048 .29836 .45202 .29736 .43741 .31423 Mtetra
.324 0 0 r
.43741 .31423 .45202 .29736 .46363 .29632 .44919 .3135 Mtetra
.325 0 0 r
.44919 .3135 .46363 .29632 .47532 .29525 .46104 .31273 Mtetra
.326 0 0 r
.46104 .31273 .47532 .29525 .48708 .29414 .47297 .31193 Mtetra
.327 0 0 r
.47297 .31193 .48708 .29414 .49891 .29301 .48499 .3111 Mtetra
.328 0 0 r
.48499 .3111 .49891 .29301 .51082 .29184 .49708 .31022 Mtetra
.329 0 0 r
.49708 .31022 .51082 .29184 .5228 .29064 .50925 .30932 Mtetra
.33 0 0 r
.50925 .30932 .5228 .29064 .53486 .28942 .5215 .30838 Mtetra
.331 0 0 r
.5215 .30838 .53486 .28942 .547 .28816 .53384 .30741 Mtetra
.332 0 0 r
.53384 .30741 .547 .28816 .55921 .28688 .54625 .30641 Mtetra
.333 0 0 r
.54625 .30641 .55921 .28688 .5715 .28557 .55875 .30538 Mtetra
.335 0 0 r
.55875 .30538 .5715 .28557 .58387 .28423 .57133 .30432 Mtetra
.336 0 0 r
.57133 .30432 .58387 .28423 .59632 .28287 .58399 .30324 Mtetra
.337 0 0 r
.58399 .30324 .59632 .28287 .60884 .28148 .59674 .30212 Mtetra
.338 0 0 r
.59674 .30212 .60884 .28148 .62145 .28006 .60957 .30097 Mtetra
.339 0 .002 r
.60957 .30097 .62145 .28006 .63413 .27862 .62249 .2998 Mtetra
.34 0 .006 r
.62249 .2998 .63413 .27862 .6469 .27716 .63549 .2986 Mtetra
.341 0 .01 r
.63549 .2986 .6469 .27716 .65974 .27567 .64858 .29737 Mtetra
.342 0 .013 r
.64858 .29737 .65974 .27567 .67267 .27415 .66175 .29612 Mtetra
.343 0 .017 r
.66175 .29612 .67267 .27415 .68568 .27261 .67501 .29484 Mtetra
.344 0 .02 r
.67501 .29484 .68568 .27261 .69877 .27105 .68837 .29354 Mtetra
.241 0 0 r
.68837 .29354 .69877 .27105 .71195 .26946 .70165 .28937 Mtetra
.195 0 0 r
.70165 .28937 .71195 .26946 .72521 .26785 .71497 .28484 Mtetra
.151 0 0 r
.71497 .28484 .72521 .26785 .73856 .26621 .72836 .2803 Mtetra
.16 .514 .915 r
.05165 .27459 .06673 .28864 .07636 .28562 .06045 .27721 Mtetra
.79 .291 0 r
.06045 .27721 .07636 .28562 .08534 .28739 .06805 .2886 Mtetra
.748 .264 .09 r
.06805 .2886 .08534 .28739 .09411 .29127 .07598 .29855 Mtetra
.685 .211 .12 r
.07598 .29855 .09411 .29127 .10294 .29524 .08428 .30667 Mtetra
.636 .171 .132 r
.08428 .30667 .10294 .29524 .1119 .29885 .09289 .31336 Mtetra
.599 .142 .139 r
.09289 .31336 .1119 .29885 .121 .30203 .10175 .31899 Mtetra
.57 .12 .144 r
.10175 .31899 .121 .30203 .13023 .30479 .11082 .32378 Mtetra
.548 .105 .149 r
.11082 .32378 .13023 .30479 .13959 .30719 .12006 .32793 Mtetra
.531 .093 .153 r
.12006 .32793 .13959 .30719 .14906 .30927 .12946 .33154 Mtetra
.517 .084 .157 r
.12946 .33154 .14906 .30927 .15864 .31107 .13899 .33471 Mtetra
.506 .078 .162 r
.13899 .33471 .15864 .31107 .16833 .31263 .14866 .33751 Mtetra
.496 .073 .166 r
.14866 .33751 .16833 .31263 .1781 .31397 .15845 .33999 Mtetra
.489 .069 .169 r
.15845 .33999 .1781 .31397 .18798 .31512 .16835 .34221 Mtetra
.482 .066 .173 r
.16835 .34221 .18798 .31512 .19794 .31611 .17836 .34419 Mtetra
.477 .064 .177 r
.17836 .34419 .19794 .31611 .20799 .31693 .18846 .34596 Mtetra
.472 .062 .18 r
.18846 .34596 .20799 .31693 .21813 .31763 .19867 .34754 Mtetra
.468 .061 .184 r
.19867 .34754 .21813 .31763 .22835 .31819 .20898 .34896 Mtetra
.465 .06 .187 r
.20898 .34896 .22835 .31819 .23865 .31865 .21938 .35022 Mtetra
.462 .06 .19 r
.21938 .35022 .23865 .31865 .24903 .319 .22987 .35136 Mtetra
.459 .059 .194 r
.22987 .35136 .24903 .319 .2595 .31925 .24045 .35236 Mtetra
.457 .059 .196 r
.24045 .35236 .2595 .31925 .27004 .31941 .25112 .35326 Mtetra
.455 .059 .199 r
.25112 .35326 .27004 .31941 .28066 .31949 .26188 .35405 Mtetra
.453 .06 .202 r
.26188 .35405 .28066 .31949 .29136 .3195 .27272 .35474 Mtetra
.452 .06 .205 r
.27272 .35474 .29136 .3195 .30213 .31943 .28365 .35534 Mtetra
.45 .061 .208 r
.28365 .35534 .30213 .31943 .31298 .3193 .29466 .35586 Mtetra
.449 .061 .21 r
.29466 .35586 .31298 .3193 .32391 .3191 .30576 .3563 Mtetra
.448 .062 .213 r
.30576 .3563 .32391 .3191 .33491 .31884 .31695 .35667 Mtetra
.447 .062 .215 r
.31695 .35667 .33491 .31884 .346 .31852 .32822 .35696 Mtetra
.446 .063 .217 r
.32822 .35696 .346 .31852 .35715 .31815 .33957 .35719 Mtetra
.446 .064 .219 r
.33957 .35719 .35715 .31815 .36839 .31773 .35101 .35736 Mtetra
.445 .064 .222 r
.35101 .35736 .36839 .31773 .3797 .31725 .36253 .35748 Mtetra
.445 .065 .224 r
.36253 .35748 .3797 .31725 .39109 .31674 .37414 .35753 Mtetra
.444 .066 .226 r
.37414 .35753 .39109 .31674 .40255 .31617 .38583 .35753 Mtetra
.444 .067 .228 r
.38583 .35753 .40255 .31617 .41409 .31557 .39761 .35748 Mtetra
.443 .068 .23 r
.39761 .35748 .41409 .31557 .42571 .31492 .40947 .35739 Mtetra
.443 .068 .232 r
.40947 .35739 .42571 .31492 .43741 .31423 .42141 .35724 Mtetra
.443 .069 .234 r
.42141 .35724 .43741 .31423 .44919 .3135 .43345 .35705 Mtetra
.422 .051 .227 r
.43345 .35705 .44919 .3135 .46104 .31273 .44559 .35583 Mtetra
.351 0 .197 r
.44559 .35583 .46104 .31273 .47297 .31193 .45787 .35161 Mtetra
.338 0 .172 r
.45787 .35161 .47297 .31193 .48499 .3111 .47021 .34738 Mtetra
.321 0 .143 r
.47021 .34738 .48499 .3111 .49708 .31022 .48261 .34312 Mtetra
.302 0 .109 r
.48261 .34312 .49708 .31022 .50925 .30932 .49506 .33884 Mtetra
.278 0 .069 r
.49506 .33884 .50925 .30932 .5215 .30838 .50757 .33454 Mtetra
.25 0 .021 r
.50757 .33454 .5215 .30838 .53384 .30741 .52013 .33023 Mtetra
.214 0 0 r
.52013 .33023 .53384 .30741 .54625 .30641 .53276 .32589 Mtetra
.169 0 0 r
.53276 .32589 .54625 .30641 .55875 .30538 .54544 .32154 Mtetra
.112 0 0 r
.54544 .32154 .55875 .30538 .57133 .30432 .55818 .31716 Mtetra
.04 0 0 r
.55818 .31716 .57133 .30432 .58399 .30324 .57098 .31276 Mtetra
0 0 0 r
.57098 .31276 .58399 .30324 .59674 .30212 .58384 .30835 Mtetra
.58384 .30835 .59674 .30212 .60957 .30097 .59676 .30391 Mtetra
.286 .78 .736 r
.59676 .30391 .60957 .30097 .62249 .2998 .60973 .29945 Mtetra
.408 .86 .866 r
.60973 .29945 .62249 .2998 .63549 .2986 .62277 .29497 Mtetra
.509 .897 .951 r
.62277 .29497 .63549 .2986 .64858 .29737 .63587 .29047 Mtetra
.578 .891 .988 r
.63587 .29047 .64858 .29737 .66175 .29612 .64904 .28595 Mtetra
.618 .859 .989 r
.64904 .28595 .66175 .29612 .67501 .29484 .66226 .28141 Mtetra
.638 .814 .968 r
.66226 .28141 .67501 .29484 .68837 .29354 .67555 .27684 Mtetra
.645 .768 .938 r
.67555 .27684 .68837 .29354 .70165 .28937 .6889 .27226 Mtetra
.645 .763 .934 r
.6889 .27226 .70165 .28937 .71497 .28484 .70231 .26765 Mtetra
.70231 .26765 .71497 .28484 .72836 .2803 .71578 .26302 Mtetra
.927 .657 .507 r
.03285 .28237 .05165 .27459 .06045 .27721 .01046 .48599 Mtetra
.47 .203 .426 r
.01046 .48599 .06045 .27721 .06805 .2886 .02097 .48235 Mtetra
.468 .198 .422 r
.02097 .48235 .06805 .2886 .07598 .29855 .03152 .47868 Mtetra
.465 .194 .417 r
.03152 .47868 .07598 .29855 .08428 .30667 .04211 .475 Mtetra
.463 .189 .412 r
.04211 .475 .08428 .30667 .09289 .31336 .05275 .4713 Mtetra
.46 .184 .407 r
.05275 .4713 .09289 .31336 .10175 .31899 .06344 .46759 Mtetra
.458 .179 .401 r
.06344 .46759 .10175 .31899 .11082 .32378 .07417 .46387 Mtetra
.455 .174 .396 r
.07417 .46387 .11082 .32378 .12006 .32793 .08494 .46012 Mtetra
.452 .168 .391 r
.08494 .46012 .12006 .32793 .12946 .33154 .09577 .45636 Mtetra
.449 .163 .385 r
.09577 .45636 .12946 .33154 .13899 .33471 .10664 .45259 Mtetra
.446 .157 .379 r
.10664 .45259 .13899 .33471 .14866 .33751 .11755 .4488 Mtetra
.443 .15 .372 r
.11755 .4488 .14866 .33751 .15845 .33999 .12851 .44499 Mtetra
.439 .143 .365 r
.12851 .44499 .15845 .33999 .16835 .34221 .13952 .44116 Mtetra
.435 .136 .357 r
.13952 .44116 .16835 .34221 .17836 .34419 .15058 .43732 Mtetra
.431 .128 .349 r
.15058 .43732 .17836 .34419 .18846 .34596 .16169 .43347 Mtetra
.426 .119 .34 r
.16169 .43347 .18846 .34596 .19867 .34754 .17284 .42959 Mtetra
.421 .11 .33 r
.17284 .42959 .19867 .34754 .20898 .34896 .18404 .4257 Mtetra
.415 .099 .318 r
.18404 .4257 .20898 .34896 .21938 .35022 .19529 .42179 Mtetra
.408 .087 .306 r
.19529 .42179 .21938 .35022 .22987 .35136 .20659 .41787 Mtetra
.401 .073 .292 r
.20659 .41787 .22987 .35136 .24045 .35236 .21794 .41392 Mtetra
.392 .058 .275 r
.21794 .41392 .24045 .35236 .25112 .35326 .22934 .40996 Mtetra
.382 .041 .257 r
.22934 .40996 .25112 .35326 .26188 .35405 .24079 .40599 Mtetra
.37 .021 .235 r
.24079 .40599 .26188 .35405 .27272 .35474 .25229 .40199 Mtetra
.356 0 .21 r
.25229 .40199 .27272 .35474 .28365 .35534 .26384 .39798 Mtetra
.339 0 .18 r
.26384 .39798 .28365 .35534 .29466 .35586 .27545 .39395 Mtetra
.319 0 .144 r
.27545 .39395 .29466 .35586 .30576 .3563 .2871 .3899 Mtetra
.293 0 .099 r
.2871 .3899 .30576 .3563 .31695 .35667 .2988 .38584 Mtetra
.261 0 .044 r
.2988 .38584 .31695 .35667 .32822 .35696 .31056 .38175 Mtetra
.218 0 0 r
.31056 .38175 .32822 .35696 .33957 .35719 .32237 .37765 Mtetra
.162 0 0 r
.32237 .37765 .33957 .35719 .35101 .35736 .33424 .37353 Mtetra
.085 0 0 r
.33424 .37353 .35101 .35736 .36253 .35748 .34615 .36939 Mtetra
0 0 0 r
.34615 .36939 .36253 .35748 .37414 .35753 .35812 .36523 Mtetra
.35812 .36523 .37414 .35753 .38583 .35753 .37015 .36106 Mtetra
.307 .795 .756 r
.37015 .36106 .38583 .35753 .39761 .35748 .38222 .35686 Mtetra
.454 .881 .906 r
.38222 .35686 .39761 .35748 .40947 .35739 .39436 .35265 Mtetra
.559 .898 .981 r
.39436 .35265 .40947 .35739 .42141 .35724 .40655 .34841 Mtetra
.617 .863 .989 r
.40655 .34841 .42141 .35724 .43345 .35705 .41879 .34416 Mtetra
.64 .807 .963 r
.41879 .34416 .43345 .35705 .44559 .35583 .43109 .33989 Mtetra
.645 .763 .934 r
.43109 .33989 .44559 .35583 .45787 .35161 .44344 .33559 Mtetra
.44344 .33559 .45787 .35161 .47021 .34738 .45586 .33128 Mtetra
.45586 .33128 .47021 .34738 .48261 .34312 .46833 .32695 Mtetra
.46833 .32695 .48261 .34312 .49506 .33884 .48085 .3226 Mtetra
.48085 .3226 .49506 .33884 .50757 .33454 .49344 .31823 Mtetra
.49344 .31823 .50757 .33454 .52013 .33023 .50608 .31384 Mtetra
.50608 .31384 .52013 .33023 .53276 .32589 .51878 .30943 Mtetra
.51878 .30943 .53276 .32589 .54544 .32154 .53154 .30499 Mtetra
.53154 .30499 .54544 .32154 .55818 .31716 .54436 .30054 Mtetra
.54436 .30054 .55818 .31716 .57098 .31276 .55724 .29607 Mtetra
.55724 .29607 .57098 .31276 .58384 .30835 .57018 .29157 Mtetra
.57018 .29157 .58384 .30835 .59676 .30391 .58318 .28706 Mtetra
.58318 .28706 .59676 .30391 .60973 .29945 .59624 .28252 Mtetra
.59624 .28252 .60973 .29945 .62277 .29497 .60936 .27796 Mtetra
.60936 .27796 .62277 .29497 .63587 .29047 .62255 .27338 Mtetra
.62255 .27338 .63587 .29047 .64904 .28595 .6358 .26878 Mtetra
.6358 .26878 .64904 .28595 .66226 .28141 .64911 .26416 Mtetra
.64911 .26416 .66226 .28141 .67555 .27684 .66248 .25951 Mtetra
.66248 .25951 .67555 .27684 .6889 .27226 .67592 .25484 Mtetra
.67592 .25484 .6889 .27226 .70231 .26765 .68942 .25015 Mtetra
.68942 .25015 .70231 .26765 .71578 .26302 .70298 .24544 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15519 .20892 m
.1598 .21359 L
s
gsave
.14598 .19958 -79.2586 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.27893 .16047 m
.28333 .16534 L
s
gsave
.27013 .15073 -78.1354 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.40878 .10962 m
.41294 .11469 L
s
gsave
.40046 .09948 -77.7262 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.54521 .0562 m
.5491 .06148 L
s
gsave
.53742 .04564 -76.9057 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -68.8553 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06615 .24378 m
.069 .2465 L
s
.09549 .2323 m
.09831 .23504 L
s
.12517 .22068 m
.12796 .22345 L
s
.18558 .19702 m
.18831 .19985 L
s
.21632 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25011 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13536 m
.34563 .13834 L
s
.37572 .12257 m
.37825 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08325 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07295 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -69.9038 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.562 12.125 moveto
%%IncludeResource: font Helvetica-Oblique
%%IncludeFont: Helvetica-Oblique
/Helvetica-Oblique findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[94]:=",
  ImageSize->{270.25, 219.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>0000fb000`400?l00000o`00003oo`3oool?
0?ooo`00o`3oool?0?ooo`00o`3oool?0?ooo`00o`3oool?0?ooo`00/`3oool00`000000oooo0?oo
o`1H0?ooo`00/`3oool00`000000oooo0?ooo`1H0?ooo`00/`3oool00`000000oooo0?ooo`1H0?oo
o`00]03oool00`000000oooo0?ooo`1G0?ooo`00]03oool00`000000oooo0?ooo`1G0?ooo`00]03o
ool00`000000oooo0?ooo`1G0?ooo`00/`3oool3000005P0oooo002e0?ooo`030000003oool0oooo
05H0oooo003o0?ooo`l0oooo003o0?ooo`l0oooo002h0?ooo`800000E03oool00;H0oooo0P000000
0`3oool000000000001C0?ooo`00/`3oool3000000<0oooo0P00001C0?ooo`00/@3oool2000000H0
oooo00<000000?ooo`000000DP3oool00:h0oooo0`0000080?ooo`040000003oool0oooo00000540
oooo00260?ooo`<000000P3oool010000000oooo0?ooo`3oool3000001X0oooo0P0000020?ooo`03
0000003oool0oooo00H0oooo00@000000?ooo`3oool00000D@3oool008D0oooo00<000000?ooo`3o
ool00P0000040?ooo`050000003oool0oooo0?ooo`0000005P3oool3000000d0oooo00D000000?oo
o`3oool0oooo0000001@0?ooo`00Q@3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo0000000D0?ooo`800000403oool00`000000oooo0?ooo`03000004l0oooo0025
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000A0?ooo`@000004@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04d0oooo0025
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool4000000l0oooo0P00000E
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C03oool008H0oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000002`3oool3000001L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1<0?ooo`00QP3oool200000080oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000P0oooo0`00000K0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0B`3oool004l0oooo0P0000000`3oool000000?ooo`0c
0?ooo`<000001P3oool3000000L0oooo0P0000020?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`00CP3oool010000000oooo0?ooo`000015
0?ooo`<00000803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04X0oooo001>0?oo
o`040000003oool0oooo000004<0oooo0P00000S0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`000000B`3oool004l0oooo1000000o0?ooo`@00000903oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo04P0oooo001B0?ooo`030000003oool0oooo03/0oooo0P0000040?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`180?ooo`00
C`3oool3000003/0oooo0`00000Z0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
A`3oool00680oooo0`0000020?ooo`040000003oool0oooo0?ooo`<000007@3oool2000002d0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`160?ooo`00H@3oool00`000000oooo0?oo
o`02000000@0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`<0000000<0oooo0000003oool0
;03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04H0oooo001Q0?ooo`050000003o
ool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000001L0oooo0P00000b0?ooo`03
0000003oool0oooo00L0oooo0`0000170?ooo`00H@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`<00000=03oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo0`0000020?ooo`030000003oool0oooo00D0
0000<P3oool00640oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool4000001<0
oooo0P0000000`3oool000000?ooo`0d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool0=03oool00680oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0100oooo0`00000i0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool0<`3oool00680oooo0P0000020?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo0000000<0?ooo`800000?03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`800000<`3oool006<0oooo0`0000060?ooo`<000002P3oool3000003h0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0`0?ooo`00M`3oool200000440oooo00<000000?ooo`3oool0
303oool2000000@0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo02l0
oooo001d0?ooo`<00000@`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000<0
oooo0P0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000a0?oo
o`00LP3oool2000004H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`<0
00001P3oool300000380oooo001_0?ooo`<0000000<0oooo0000003oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo03l0oooo001]0?ooo`800000B`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo03l0oooo00110?ooo`<000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01/0oooo0`00001>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0?P3oool00400oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0oooo
01P0oooo0`0000000`3oool000000?ooo`1>0?ooo`030000003oool0oooo00h0oooo0`00000o0?oo
o`00@03oool01@000000oooo0?ooo`3oool0000000@0oooo1P00000F0?ooo`800000E03oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo03d0oooo00100?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000D0?ooo`<00000EP3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo03`0oooo00100?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000B0?ooo`<00000F03oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo03/0oooo00110?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0000000>0?ooo`<00000F`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03/0oooo00110?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`800000
303oool2000005h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0j0?ooo`00@P3o
ool3000000T0oooo00<000000?ooo`3oool01`3oool300000600oooo00<000000?ooo`3oool04P3o
ool3000003/0oooo001F0?ooo`800000H`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo03T0oooo001C0?ooo`<00000I@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
03P0oooo001A0?ooo`800000J03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03L0
oooo001>0?ooo`<000000P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0=`3oool00240oooo0`0000020?ooo`030000003oool0oooo00D000007P3o
ool2000006d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0f0?ooo`00803oool0
0`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool07@3oool3000006l0oooo00<00000
0?ooo`3oool05P3oool3000003L0oooo000P0?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`0J0?ooo`80000000<0oooo0000003oool0K`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00H0oooo0`0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08@3oool00200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`8000005`3oool3000007@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo008000001`3oool00`000000oooo0?ooo`0Q0?ooo`00803oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool2000007L0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`000000103oool600000240oooo000Q0?ooo`050000003oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`0>0?ooo`@00000N03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000280oooo000Q0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000003P3oool2000007`0oooo00<000000?ooo`3oool06P3oool2000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000280oooo000R0?oo
o`<000001P3oool3000000`0oooo0`00001n0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`0000001@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`000000203oool4
000001D0oooo000h0?ooo`80000000<0oooo0000003oool0OP3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00D0oooo0P0000090?oo
o`030000003oool0oooo01D0oooo000e0?ooo`<00000Q03oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0080oooo0`0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0503oool00380oooo0`0000270?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0C0?ooo`00<03oool3000000030?ooo`000000oooo08H0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo000]
0?ooo`<00000S03oool00`000000oooo0?ooo`0L0?ooo`<00000603oool4000001@0oooo000[0?oo
o`800000S`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02h0oooo000X0?ooo`<0
000000<0oooo0000003oool0SP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02d0
oooo000V0?ooo`800000U03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02`0oooo
000S0?ooo`<00000UP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02`0oooo000Q
0?ooo`80000000<0oooo0000003oool0UP3oool00`000000oooo0?ooo`0P0?ooo`800000;@3oool0
01h0oooo0`00002K0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0:P3oool001`0
oooo0P00002M0?ooo`800000903oool00`000000oooo0?ooo`0Z0?ooo`006@3oool3000009`0oooo
0`0000020:G3k`030000003oool0oooo0280oooo00<000000?ooo`3oool0:@3oool001L0oooo0P00
002L0?ooo`<000001@2U`nl00`000000oooo0?ooo`070?ooo`801@0000<09K2o04C5g`14aMl00`14
aMlC0?ooo`030000003oool0oooo02T0oooo000E0?ooo`800000W03oool2000000T0YL?_00<00000
0?ooo`3oool00P0300000`0400001@0000D0000200D0000304K6hP1Kco40Floa00L0Floa4@3oool0
0`000000oooo0?ooo`0X0?ooo`005@3oool2000009T0oooo0`00000<0:G3k`03000000030000<P00
00D0<P0000<0GLoc05c?lP1Lco800P1Lco8406_CnP@0J]?i3P3oool00`000000oooo000000080?oo
o`<000000P3oool010000000oooo0?ooo`3oool3000001D0oooo000E0?ooo`030000003oool00000
09D0oooo0`00000?0:G3k`03034000000000<P0000<0<P001@1/doX706_CnPD0M=Cm3P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00800000103oool01@000000oooo0?ooo`3oool0
000001@0oooo000:0?ooo`<000001`3oool01@000000oooo0?ooo`3oool000000940oooo0`00000C
0:G3k`030000000b00009P0000809P000`1]do/306cCnPD0M]Cn101ee?d307CDo@h0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
0000000D0?ooo`002@3oool00`000000oooo0?ooo`02000000H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`280?ooo`H000005`2U`nl0100000009P0002H0001]do/507OCoP@0M]?n
0`1fe?h407gDo`@0O=Co3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0180oooo00090?ooo`050000
003oool0oooo0?ooo`0000001P3oool2000000D0kJR1P`3oool3000000<0:`000`00000>0:G3k`D0
YLC`202U`nl00`0000009P0007OCoP0607OCoP@0O]?o101mdol307gDo`D0P]?o2`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo1000000E0?oo
o`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000>fXP@3]
Z840103]Z8400`1h<fd0bTX00?ooo`1j0?ooo`80:0000`0Y000302X0000402/00000000000000000
00h0YL?_102Sd?L50:G4l0P0YL?_00<0000007oCo`1odol00`1odol707kCo`P0Pm?o1022dol90?oo
o`<000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool05@3oool0
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003]Z840kJR1
00@0kJR100@0N3=]0<Y:003:BP00bTX0L03oool3000000809P000`0W000202P00080:@000`0Z0000
0`0[000000000000000>0:G3k`@0W]_m102Sd?L50:G4l0<0YL?_1020d_l00`000000Om?o07oCo`04
07oCo`<0O]?o1@24d_l708?Co`@0Qm;o2`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000004`3oool000X0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003]Z840kJR100@0kJR100<0N3=]0<Y:003:BP000`3:
BP1U0?ooo`<000000P0T000602D0000402H0000W00009`0002L000<0:000101E0003000000`0YL?_
1@2Ci?`409kKo@@0Xm3g102Ua?08083Bo`030000001odol0Om?o00`0Q=;o1028d_l708OBo`X0oooo
00<000000?ooo`3oool00`3oool3000000H0oooo0`00000D0?ooo`002P3oool200000080oooo00<0
00000?ooo`3oool00P3oool00`000000kJR10>fXP@050>fXP@0307PcK@1g<V`0_d<G00D0_d<GGP3o
ool01@0Q00008P000280000R00008`0000<090001P0U000905@0000405D0000000000000000000h0
YL?_0`22iO<409?To0@0W]_m102Sd?L5087Bo`<0P=;o1025dOl010000000QM;o08GBo`25d_l408CB
o`L0R=7o1028d_l308OBo`@0Rm7o2P3oool00`000000oooo0?ooo`0R0?ooo`002`3oool3000000D0
oooo00<000000>fXP@3]Z840103]Z84207PcK@80Mc9/0`2o@aL40:lf7P80DP00CP3oool01@0M0000
7P0001h0000N00007`0000<080000`0Q0003028000P0D`002`1D0003000000l0YL?_1`22iO<309?T
o0<0W]_m0`22dOl3087Bo`P0Q]7o0P25dOl00`000000QM7o08GBo`0208GBo`@0RM7o1`28dOl408_A
oPL0Rm7o2P3oool00`000000oooo0?ooo`0Q0?ooo`004`3oool00`000000kJR10>fXP@040>fXP@80
N3=]0P1g<V`60:lf7P@0XR/Q00<0G0000?ooo`3oool0@P3oool00`0I00006P0001/0000201/00080
7@000`0N0008058000/0D`002@1D0003000000l0YL?_1P1Xg=d708?Ao`<0P]7o1@27d?l:08KAo`80
RM3o00<0000008W@o`29dOl01P29dOl708c@oP@0Rm7n0`2;dOl508k@oPL0oooo0P00000S0?ooo`00
4`3oool00`000000kJR10>fXP@040>fXP@80N3=]0P1g<V`207LaJP<0[cHN102R:b4209TT8`<0TAhT
101L000^0?ooo`<050000`0F000201L000<060000`0I000;054000L0DP002`1C000705@000<00000
3`2U`nl207kAo`P0Q=3o1`23dOl808O@o`<0Q]7o102:d?h308[@o`80RM3o00<0000008W@o`29dOl0
0P29dOl;08c@oP`0S]3n203oool00`000000oooo0?ooo`0P0?ooo`004`3oool00`000000kJR10>fX
P@040>fXP@0407PcK@1g<V`0Mc9/07LbK0<0Mc5Z102R:b4309TT8`<0TAhT0`2<6RH305P000D0EP00
101D00000`00T/@0oooo0?ooo`0D0?ooo`803P000`0@0003014000804P001@1?000;050000/0D@00
1`1B000;05<000D0E0000`00000>0:G3k`0307o@o`25col0QLoo0080QLoo2P24d?l408S?o`<0R=3o
1027d?l808_?oP<0R]3n0`2:d?l208g?oP030000002=coh0SLon00<0SM3n1P2<d?h508o?oPL0S]3n
102@cod80?ooo`030000003oool0oooo01l0oooo000B0?ooo`8000001@3]Z84207PcK@<0Mc9/0`1g
<FX207H`J@@0VB@S0`2A7R@408`J9P<0QaLW0P245BP305@00080D`001@1B0002054000D0D0006`1?
000;050000/0D@001`1B000905<000<0DP0T0`1=01/2000000h0YL?_0`26col608G?o`<0Q=3o1@29
coh608S?o`<0R=3o1@2<coh708_?oP<0S/on102=coh010000000SLon08g?oP2=coh308g@oPL0Slom
102?coh308k@oP@0TLom102@cod70?ooo`030000003oool0oooo01l0oooo000B0?ooo`030000003]
Z840kJR100@0kJR10P1h<fd307LbK0<0Mc5Z0P1f<6T00`1e;fP0VB@S09TT8`03094N90@0S1XV0`27
5bL308@E:0<0PA<Y0P1n4RX307dA:`80D@001@1@000L04l000X0D000301A0002058000H0LA4k0`1/
3CX305T0<P<0EP0/0`1B02@3000000d0YL?_0`26c_l408K?o`<0QLoo102:c_h308W>oP@0RLon0`28
col408c>oPL0S<on0`2;coh408k>o@<0S/on102=coh010000000T<km093>o@2@c_d3093?o@L0Slom
102Ac_d7097?o@<0T<om203oool00`000000oooo0?ooo`0N0?ooo`004P3oool00`000000kJR10>fX
P@040>fXP@80N3=]0P1g<V`407LaJP80MS1Y0P1e;fP3094N90@0S1XV0`275bL308@E:0<0PA<Y0P1n
4RX407dA:`80Na0/0`1j42d207P?;PD0M`l_5P1?0005050000<0LQ0g0`1b43P3074@>0H0LA0i1@1a
4CX6074A>`<0K0dj0`1I038305H0;0<000003@2U`nl01027cOh0Qlko08O>o`27c_l308K>o`D0Rlgn
1P2:c_h308W>oPD0SLkm0P2=c_h408c>oP<0S<on102?c_d708k>o@<0S/on102@c_d010000000T<km
093>o@2@c_d3093?o@L0T/kl102Ac_d3097?o@@0Tlkl0`2Cco`60?ooo`<000007`3oool00180oooo
00<000000>fXP@3]Z840103]Z840101h<fd0Mc9/07LbK01g<V`307LaJP<0MS1Y0P1e;fP207D]IP@0
S1XV0`275bL308@E:0<0PA<Y0P1n4RX407dA:`80Na0/0`1j42d207P?;PH0M`l_0`1f3c0307D?<@D0
M0lb0`1c3c<207<?=0<0L`le0`1b3cD3078?=P80LPlg0`1b43L3078@>0<0LA0h1@1a43T6074A>PD0
LA4k0`1/3CX405T0<P<00000302U`nl308S=oP<0Qlgn102<cOd708_=oP80R/kn1@2>cOd308g=o@@0
SLkm0P2=c_h5093=o@<0Slgm0`2?c_d308k>o@D0TLgl0P2Ac_d4093>o@030000002@c_d0T<km00/0
T/kl102Dc_`709?>o0<0Tlol1`3oool00`000000oooo0?ooo`0M0?ooo`004P3oool00`000000kJR1
0>fXP@030>fXP@80N3=]0`1g<V`307LaJP80MS1Y0`1e;fP207D]IP<0M2aU0`275bL308@E:0<0PA<Y
0`1n4RX307dA:`80Na0/0`1j42d307P?;PD0M`l_0`1f3c0307D?<@D0M0lb0`1c3c<307<?=0<0L`le
0P1b3cD3078?=P<0LPlg0P1b43L3078@>0<0LA0h1P1a43T5074A>PH0LA4k0`1/3CX0101I03800000
00000000000<0:G3k`<0R<gn202<c?d308c=o@<0Rlgn102?c?d308k<o@@0S/gm0`2=cOd4093<o0<0
T<gl102@cOd308o=o@<0T/gl202AcO`2097>o@<0Tlgl00<0000009?=o02CcO`00P2CcO`609;>o0@0
U<gl102Dc_`309?>o0L0ULkk1`3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`000000kJR1
0>fXP@030>fXP@80N3=]0`1g<V`307LaJP80MS1Y0`1e;fP207D]IP<0M2aU0P1c:f@308@E:0<0PA<Y
0`1n4RX307dA:`<0Na0/0`1j42d207P?;PH0M`l_0`1f3c0307D?<@D0M0lb0`1c3c<207<?=0<0L`le
0`1b3cD3078?=P80LPlg0`1b43L3078@>0<0LA0h1@1a43T6074A>PH0LA4k00@0K0dj000000000000
00003P2U`nl208g;o0@0SL_m1`2<c?d308o;o0@0Slcl0`2?c?d308k<o@L0TLcl102@c?`3093=o0@0
T/ck0`2Bc?`309;=o0@0TLgl102Cc?/309?=n`80Tlgl00<0000009?=o02CcO`00P2CcO`709C=n`<0
U<gl0`2Dc_`409G=n`L0ULkk1P3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`000000kJR1
0>fXP@030>fXP@80N3=]0P1g<V`407LaJP80MS1Y0P1e;fP307D]IP<0M2aU0P1c:f@2078YHP<0PA<Y
0`1n4RX307dA:`<0Na0/0`1j42d207P?;PH0M`l_0`1f3c0307D?<@D0M0lb0`1c3c<307<?=0<0L`le
0P1b3cD3078?=P<0LPlg0P1b43L3078@>0<0LA0h1P1a43T5074A>PD0LA4k0`00000?0:G3k`<0S/[l
0P2=bo`408g;o@@0T<[l0`2@bo`308o;o0@0Slcl0`2?c?d4097;n`H0TLcl0`2@c?`509?<n`<0T/ck
0`2Bc?`309;=o0@0U<ck102Cc?/309?=n`80ULck00<0000009G<n`2Ec?/00P2Ec?/709C=n`L0U/gk
0`2EcO/309G>n`@0Ulgk1P3oool00`000000oooo0?ooo`0K0?ooo`004@3oool00`000000oooo0>fX
P@040>fXP@80N3=]0P1g<V`307LaJP<0MS1Y0P1e;fP207D]IP@0M2aU0P1c:f@2078YHP<0LRQQ0P1a
9Ul307dA:`<0Na0/0`1j42d307P?;PH0M`l_0P1f3c0307D?<@D0M0lb101c3c<207<?=0<0L`le0`1b
3cD3078?=P80LPlg0`1b43L3078@>0<0LA0h1@1a43T6074A>P<0LA4k0P00000?0:G3k`L0S/[l0P2=
bo`5093:n`<0T<[l0`2@bo`308o;o0D0T/[k0P2Bbo/4097;n`<0TLcl1`2Cbo/409?<n`80T/ck1@2D
bo/609C<n`<0Tlck102Fc?X00`2Ec?/0000009G<n`0409G<n`<0U<gk102Fc?X709K=n`L0Ulgj0`2G
cO/40?ooo`<00000203oool300000080oooo00@000000?ooo`3oool0oooo0`0000080?ooo`004@3o
ool2000000@0kJR10P1h<fd307LbK0<0Mc5Z0P1f<6T307D_J080MBeV0`1d;6D307<[I080LRUR0`1b
:642074VG`<0L2AM0P1_8U/307X@;@<0N0l^1P1g3bl307H?<0<0M@la1@1d3c8307<?<`<0L`ld0`1c
3cD2078?=@<0LPlf0`1b3cL3078@=`<0LQ0h0`1a43P5074@>@H0LA4j0`0000020:?>mP`0YL?_00@0
SlWk08o9o02?bO`0SlWl0`2>b_`70979n`@0T<[k0`2@b_`309?9nPP0T/[k0P2Bbo/409C:nP<0U<_j
1`2Cbo/709G;nP@0U<_k0P2Dc?/809K;nP<0U/cj00<0ULck0000002Ec?/01`2Gc?X409K<nP<0U/gk
102Hc?X709O=nP<0V<gj1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00800000
103oool01@000000oooo0?ooo`3oool0000000L0oooo000A0?ooo`030000003oool0kJR100<0kJR1
0P1h<fd307LbK0<0Mc5Z0P1f<6T307D_J080MBeV0`1d;6D207<[I0<0LRUR0`1b:642074VG`<0L2AM
0P1_8U/306hPF@80KAiG1`1g3bl207H?<0<0M@la1@1d3c8407<?<`80L`ld0`1c3cD3078?=@<0LPlf
0P1b3cL3078@=`<0LQ0h0`1a43P5074@>@@0LA4j0`00000209gLo@@0Xlkf202U`nl208o8n`<0SlWk
1`2Bb?X60979n`X0TlWj102Bb_/409G9nPH0U<[j0`2DboX709K:nPL0UL_j102Gb_T:09K;nP<0Ul_i
00<0Ul_j0000002GboX01`2Gc?X409S<n@L0V<cj0`2GcOX409W<nP<0V<gj1@3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00L0oooo00090?ooo`030000003oool0oooo00D0oooo00<000000>fXP@3]Z8400`3]Z84207PcK@80
Mc9/101g<FX207H`J@80MBmX0`1e;FH307@/I@80Lb]T0P1b:F83078XH@<0LBIO0`1`95d206lRF`<0
KR1I0P1]7UL306/LE0<0JQUA0P1f3c0307D?<@D0M0lb101c3c<307<?=0<0L`le0P1b3cD3078?=P<0
LPlg0`1b43L3078@>0<0LA0h1@1a43T0101a4CX0000000000000000308oUn`<0WMcm102Sc_H40:G3
k`<0T<Sk0`2CaoT409?7nPH0T/Sj1`2Db?T909?9nPD0ULWi0`2EbOX609C:nP@0U/Wi1P2Fb_X309G;
nPP0Ul[i1P2FboX409S;n@<0Ul_i00<0Ul_j0000002GboX0102IboT309S;n@@0V<ci0`2Hc?X709W<
n@@0VLcj0`2HcOX50?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00090?ooo`030000003oool0oooo
00D0oooo00<000000>fXP@3]Z8400`3]Z84207PcK@80Mc9/0`1g<FX307H`J@80MBmX0P1e;FH407@/
I@80Lb]T0P1b:F83078XH@80LBIO0`1`95d306lRF`<0KR1I0P1]7UL306/LE0<0JQUA0P1X5Th306HB
BP<0I0i60P1Q2T4305h5?0<0L`ld0`1c3cD2078?=@<0LPlf0`1b3cL3078@=`<0LQ0h0`1a43P4074@
>@<00000101dhNL308oUn`<0WMcm0`2Sc_H00`2AaoX0U<Kh09C6n00209C6n0@0TlKi0P2CaoT409?7
nP<0ULOh102EaoT609C8n@<0TlWj1`2Fb?T409G9n@80ULWj1`2GbOT409K9n@<0U/[j0`2HbOT:09O:
n@L0V<[i102HboT309O;n@030000002IboT0VL_i00@0VL_i0`2HboT309S<n@@0V/_i1`2Ic?T709[<
n@@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo100000070?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000003]Z840kJR10080
kJR10P1h<fd307LbK0<0Mc5Z0P1f<6T307D_J080MBeV0`1d;6D207<[I0<0LRUR0`1b:642074VG`<0
L2AM0P1_8U/306hPF@<0KAiG0`1[75@306XID@80J1I>0`1V4TX306@>AP80H@Y10`1N1C`305/0=@<0
EP0^0P1A02@304/06@<0@P0;0P0g000302T000<05@001@00000409C4m`80TlCh102CaOP209;5n@@0
ULGg0`2DaOP309C6n0@0TlKi0P2CaoT509K6n080ULOh102EaoT309C8n@<0UlOh102Fb?P609K8n@@0
V<Sh0`2Gb?P609O9n@@0V<Sh0`2HbOP309S9n@@0Ul[i1`2IbOP609S:n@@0V/[h0`2Ib_P00`000000
VL_i09W;n@0409W;n@<0V/_h1`2JboT309W<n@@0Vl_h1`2Jc?T20?ooo`030000003oool0000000D0
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000001P3oool0
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0>fXP@030>fXP@80N3=]0`1g<V`307La
JP80MS1Y0`1e;fP207D]IP<0M2aU0P1c:f@3078YHP80LRQQ0`1a9Ul3070TG@80Kb9K0`1^85T206dN
E`<0JaaD0`1Z6E4206PFCP<0IQ9:0`1T3TH2064:@@@0GPDl0`1K03D205H0;P80D@0T0`1;01T30480
2`80=`000`0Y000201D000@000000P2F`_H209G3m`@0U<Cg0P2Ca?P409K4mP<0U/Cg0`2EaOL309C5
n0<0U<Kh102GaOL709K6n080ULOh102Ga_L609O7n0@0U/Sh0P2Fb?T509S7n0<0V<Sh0`2Gb?P309O9
n@@0VLSh0`2Hb?P309S9n0<0V<Wi2`2IbOP209S:n@D0V/Wh0`2Jb_P309W:n0040000002Kb_P0Vl[h
09_:n0<0V/[h0`2JboP309[;n@/0Vl_h0`2Jc?T409_<n0@0oooo00<000000?ooo`3oool00P3oool2
00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo000:
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3]Z8400`3]Z84207PcK@80Mc9/101g<FX2
07H`J@80MBmX0`1e;FH307@/I@80Lb]T0P1b:F83078XH@<0LBIO0P1`95d306lRF`<0KR1I0P1]7UL3
06/LE0<0JQUA0P1X5Th306HBBP<0I0i60P1Q2T4305h5?0<0F`0e0`1F02h2054090<0B`0I0P1200/2
03L000<0:@0000@05@0009O1m000000000000P2F`_D409K2mP80UL?g102G`oD309O3mP<0U/Cf0`2F
a?L309G5m`<0V<Cf1`2GaOL309K6n0@0V<Gf0`2Ha_L309O6m`H0UlOh102IaoL309S7m`@0V<Oh0P2H
b?P409W7m`<0VLSg102Ib?P309S8n0L0V/Sg1P2IbOP409[9m`L0V/Wh0P2Jb_P409_9m`040000002K
b_P0Vl[h09_:n0<0V/[h0`2JboP409_:n0H0Vl_h1`2LboP409_<n0<0oooo00<000000?ooo`3oool0
0`3oool3000000H0oooo0`0000070?ooo`002P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0kJR100<0kJR10P1h<fd207LbK0<0Mc5Z0`1f<6T207D_J080MBeV0`1d;6D307<[I080LRUR0`1b
:642074VG`<0L2AM0P1_8U/306hPF@<0KAiG0`1[75@306XID@80J1I>0`1V4TX206@>AP<0H@Y10`1N
1C`305/0=@80EP0^0P1A02@304/06@<0@P0;00@0=`0002T0000Y0000V<3c0`00000309O1m080U/;e
102I`_@209S2m0@0Ul?e0`2G`oH309K4mP<0VL?e1P2Ha?H709O5m`<0VLGf102HaOH309S6m`<0UlKg
0`2Ia_H409W6m`<0VLOg0`2HaoL409[7mP<0V/Og0`2IaoL309W8m`@0V/Og2P2Jb?L609_8m`@0V/Wg
0`2JbOP909_9m`040000002Kb_P0Vl[h09_:n0L0W<[g102Kb_P209_;n0@0W<_g1`2LboP409g;m`<0
oooo00<000000?ooo`3oool05@3oool000T0oooo0`0000040?ooo`030000003oool0kJR10080kJR1
0`1h<fd207LbK0<0Mc5Z0P1f<6T307D_J080MBeV0`1d;6D207<[I0<0LRUR0`1b:642074VG`<0L2AM
0P1_8U/306hPF@80KAiG0`1[75@306XID@80J1I>0`1V4TX306@>AP80H@Y10`1N1C`305/0=@<0EP0^
0P1A02@304/06@80@P0;00<0=`0009^ol@0000000P00000309S0l`@0Vl3b0P2J`O<409W2m080V<;d
102G`oD309[2m0@0VL?d0P2I`oD609S4mP@0V/Ce0`2Ia?H309W5mP@0V<Gf0`2JaOD409[5mP80VLKf
102Ia_L209W7m`@0V/Kf102JaoH309[7m`<0VLOg0`2KaoH409[7m`H0V/Sg102Kb?H609_8m`<0V/Wg
102Lb?L909_9m`040000002LbOL0W<Wg09c9m`L0W<[g1`2Mb_L309c;m`<0W<_h202MboL30?ooo`03
0000003oool0oooo01@0oooo000;0?ooo`030000003oool0oooo0080oooo0P0000030>fXP@80N3=]
0`1g<V`307LaJP80MS1Y0P1e;fP307D]IP<0M2aU0P1c:f@2078YHP<0LRQQ0`1a9Ul2070TG@<0Kb9K
0`1^85T206dNE`<0JaaD0`1Z6E4206PFCP<0IQ9:0`1T3TH2064:@@<0GPDl0`1K03D205H0;P80D@0T
0`1;01T204802`<0000000@0Vkoa09W0lP2I`?80VL3b0`2K`?4409_0lP80V/7c102I`_@209S2m0@0
V/;c0`2J`_@409W3m080VL?e102J`o@309[4m0<0V/Ce0`2Ia?H309W5mPL0V/Ge102JaOH209W6mP@0
VlGe0`2Ka_H309[6mP<0V/Of102Ka_H609_7mP<0V/Og1`2LaoH409_8mP<0VlSg1P2Lb?H409c8m`<0
VlWg102Mb?H209c9m`040000002LbOL0W<Wg09c9m`<0W<[g102MbOL709g:m`<0W/[g2P2MboL30?oo
o`030000003oool0oooo01@0oooo000@0?ooo`030000003]Z840kJR10080kJR10P1h<fd207LbK0@0
Mc5Z0P1f<6T207D_J0<0MBeV0`1d;6D207<[I080LRUR0`1b:643074VG`80L2AM0P1_8U/306hPF@<0
KAiG0`1[75@306XID@80J1I>0P1V4TX306@>AP<0H@Y10`1N1C`205/0=@<0EP0^0P1A02@204/06@<0
00000P2L__0409jol0<0W;oa0P2K`?4409_0lP80V/7c102L`O8309_1l`<0V/;c0`2J`_@409c2l`80
Vl?c102J`o@309[4m0<0V/Ce1`2Ka?@609[5m@@0W<Gd1P2KaOD309_6mP<0V/Kf102La_D309_6mPH0
VlOf102LaoD609c7mP<0VlSf102MaoH609c8mP/0WLSf00<0W<Wg0000002LbOL00`2NbOH309g9mP@0
WLWg0`2Mb_L409k:mP<0W/[g0`2MboL409o;mP<0W/_g0`3oool00`000000oooo0?ooo`0C0?ooo`00
3`3oool00`000000oooo0>fXP@030>fXP@80N3=]0P1g<V`307LaJP<0MS1Y0P1e;fP207D]IP<0M2aU
0P1c:f@3078YHP<0LRQQ0P1a9Ul3070TG@80Kb9K0`1^85T206dNE`<0JaaD0`1Z6E4206PFCP<0IQ9:
0`1T3TH2064:@@<0GPDl0`1K03D205H0;P80D@0T0`0000040:2nkP80Wkk_102N_o0309bol@80Vl3a
102M`?4309c0l@<0W<7b0`2K`O<309[2l`<0W<;b102L`_<209_3l`@0V/?d1`2L`o<609_4m080V/Ge
102La?@409c5m0D0VlGe102LaO@309c5m@@0W<Ke0`2Ka_H309g6m0<0W<Ke102LaoD309c7mPH0WLOe
102MaoH309c8mP<0W/Oe2P2Mb?H209k8mP030000002Nb?H0W/Wf0080W/Wf0`2MbOH709k9mP@0W/[f
0P2Nb_L409o:mP@0Wl_f0`2NboL30?ooo`030000003oool0oooo0180oooo000?0?ooo`030000003o
ool0kJR10080kJR10`1h<fd207LbK0<0Mc5Z0P1f<6T307D_J080MBeV0`1d;6D207<[I0<0LRUR0P1b
:643074VG`80L2AM0`1_8U/306hPF@80KAiG0`1[75@306XID@80J1I>0`1V4TX206@>AP<0H@Y10`1N
1C`205/0=@80EP0^0`000000102Q_Nd0X[g]0::mk@2R_Nd40:2nkP80Wkk_102N_o0309nok`80W[o`
102M`?4309c0l@<0W<7b0`2M`O4409g1lP80W<;b102L`_<209_3l`@0WL;b1`2L`o<209_4m0@0WL?c
0`2La?<309c4m0<0W<Gd102Ma?<309g5m0<0W<Gd0`2LaOD709g5m0<0WLKd0`2La_D409k6m0<0WLKd
1P2MaoD409k7m0H0W/Oe102Mb?H609k8m@80W/Sf00<0000009k8mP2NbOH00P2NbOH409o9m@H0W/Wf
102ObOD609o:mP<0Wl_f102PboH20?ooo`030000003oool0oooo0180oooo000?0?ooo`8000000`3]
Z84207PcK@<0Mc9/0`1g<FX207H`J@80MBmX0`1e;FH307@/I@80Lb]T0P1b:F83078XH@<0LBIO0P1`
95d306lRF`80KR1I0`1]7UL306/LE0<0JQUA0P1X5Th206HBBP<0I0i60`1Q2T4205h5?0<0F`0e0P00
00020:Fmj`<0Xkg/0`2R_Nd40:2nkP80Wkk_102P_^h309nok`80W[o`102M`?4309nol0<0W/3`0`2M
`O4409g1lP80W<;b102N`O4609g2lP<0W<?c102N`_8609g3l`<0W<Cc0`2La?@709g4l`<0WLGd0`2L
aO@309k5l`L0WLGd0`2Ma_@709k6m0<0WLKd0`2MaoD309k6m0@0W/Od1P2NaoD409o7m0H0W/Se0P2O
b?@00`000000WlSd09o8m@0209o8m@@0WlWe0P2NbOH40:39m@@0WlWe0`2Ob_H30:3:m@<0X<[f102P
boH20?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0kJR10080kJR10P1h<fd2
07LbK0<0Mc5Z0`1f<6T207D_J0<0MBeV0`1d;6D207<[I080LRUR0`1b:642074VG`<0L2AM0P1_8U/3
06hPF@<0KAiG0`1[75@206XID@80J1I>0`1V4TX306@>AP80H@Y10`1N1C`300000080Y[gY0`2U_N/3
0:>mk0<0X[g]102S_N`20:6nk@@0X;k^0`2O_nl209jol0@0Wko_0`2O_o0309k0l0<0WL7a102O`O06
09k1l@H0WL;b1`2N`_8609g3l`<0W/?b0`2N`o<709g4l`H0W/Cc0`2NaO<409g5m0<0WlGc0`2NaO<7
09k6m0<0WlKc0`2Oa_@309k6m0@0W/Od0`2Oa_@709o7m0<0W/Se0`2Pao@0102Ob?@0000009o8m02O
b?@309o8m@@0X<Sd0P2Pb?D40:39m@<0WlWe102QbOD30:3:m@<0X<[f102Qb_D00`3oool000000?oo
o`0B0?ooo`003`3oool00`000000oooo0>fXP@020>fXP@80N3=]0P1g<V`307LaJP<0MS1Y0P1e;fP2
07D]IP<0M2aU0P1c:f@3078YHP<0LRQQ0P1a9Ul2070TG@<0Kb9K0`1^85T206dNE`<0JaaD0`1Z6E42
06PFCP<0IQ9:0P1T3TH3064:@@<000000`2X_NT30:Jmj@<0YKg[0`2S_N`30:Bmj`@0Xkg/0P2Q_^d4
0:2nkP<0XKk^0`2Q_nh309nok`<0Wko`0`2N`?0309o0l0@0Wl7`1P2N`O4309o1l@@0W/;a1P2N`_83
09o2l@H0W/?b0`2N`o<309g4l`@0WlCb1P2Na?<309k5l`@0WlCc0`2OaO<309k5l`<0W/Kd102OaO<3
09o6l`<0WlKd0`2Na_@409o6l`<0WlKd0`2Oao@40:37l`H0X<Od00<0WlSd0000002Ob?@0102Qb?@4
0:38m080X<Se102Qb?@30:79m0@0XLWe0P2Pb_D80:7:m@030?ooo`000000oooo0140oooo000?0?oo
o`040000003oool0kJR10>fXP@<0N3=]0P1g<V`307LaJP80MS1Y0`1e;fP207D]IP<0M2aU0P1c:f@3
078YHP80LRQQ0`1a9Ul2070TG@<0Kb9K0P1^85T306dNE`<0JaaD0`1Z6E4206PFCP80IQ9:0`1T3TH3
000000<0ZKgX102X_NT30:Jmj@@0Y[gZ0P2U_N/30:Bmj`@0Xkg/0P2Q_^d40::nk@<0XKk^102Q_nh2
09nok`<0XKo^102P_nl209o0l0@0Wl7`0`2P`?0309o1l0<0Wl7a102N`_4209k2lPL0Wl;a1P2N`o83
09o3l@@0Wl?b0`2Oa?8309k4l`L0WlCb0`2Oa?<309o5l`<0X<Gb1`2OaO<309o6l`<0X<Gc0`2Pa_<4
09o6l`<0WlKd0`2Qa_<40:37l`<0X<Od0`2Qao<00`2Qao@000000:77m0040:78m0<0X<Sd1`2Qb?@3
0:79m0H0X/Wd1`2Qb_D20?ooo`030000003oool0oooo00l0oooo000>0?ooo`030000003oool0oooo
0080kJR10`1h<fd207LbK0<0Mc5Z0P1f<6T207D_J0<0MBeV0`1d;6D207<[I080LRUR0`1b:643074V
G`80L2AM0P1_8U/306hPF@<0KAiG0`1[75@206XID@80J1I>0`1V4TX3000000L0ZKgX102X_NT30:Nm
j@@0Y[gZ0P2U_N/70:Bmj`80Xkk/102R_^d30:6nkP@0X[k]0P2R_nh30:6okP@0X;o_0P2O`?040:70
k`<0X<3`0`2O`O0309o1l@L0X<7`1P2O`_470:32l@80Wl?a102O`o8209o4lP@0X<?a1`2Oa?8209o4
l`@0X<Cb0`2PaO8309o5l`L0XLGb0`2PaO<30:36l`@0XLKb1P2Qa_<30:37l`L0XLOc00<0XLOd0000
002Qao@00`2Qb?@40:;8l`H0XLSd102Rb?@60:;9m0L0Xl[d0P0000090?ooo`030000003oool0oooo
00D0oooo000>0?ooo`80000000<0oooo0>fXP@3]Z8400P1h<fd207LbK0<0Mc5Z0`1f<6T207D_J0<0
MBeV0P1d;6D207<[I0<0LRUR0`1b:642074VG`80L2AM0`1_8U/306hPF@80KAiG0`1[75@306XID@80
J1I>0`00000;0:Vmj0@0Z;gX0`2W_NT40:JmjPD0YKg[102T_N/20:>nk0@0X[k]0`2S_^`40::nk@80
X[o^0`2Q_nh40::okP80XKo^102Q`>l30:30l0<0Wl7`0`2Q`Nl70:31l080Wl;a102Q`_070:32l@80
Wl?a102Q`o460:33l@<0WlCb102Q`o430:74lP<0X<Cb0`2PaO830:74lPL0XLGb0`2PaO<30:75lP@0
XLKb1@2Qa_<40:;6lPL0XLOc00<000000:;7l`2Rao<00`2Rao<40:;8l`80XLSd102Rb?<40:;8m0<0
X/Wd0`2SbO<70:?:m0030?ooo`000000oooo00L0oooo00<000000?ooo`3oool01@3oool000h0oooo
00<000000?ooo`3]Z8400P3]Z84207PcK@80Mc9/0`1g<FX307H`J@80MBmX0P1e;FH307@/I@80Lb]T
0`1b:F82078XH@<0LBIO0P1`95d306lRF`80KR1I0`1]7UL306/LE080JQUA0`00000?0:Vmj0@0Z;gX
1`2W_NT20:JmjP<0YKg[102T_N/20:>nk0@0Y;k/0`2S_^`40::nk@80X[o^0`2S_nd40::okP80XKo^
102Q`>l30:;0kP<0XL3_0`2Q`Nl30:31l0@0XL7_0`2Q`O030:72l0<0X<;a1`2Q`_030:73l@<0X<?a
0`2Q`o070:73l@<0XLCb0`2Ra?430:74l@<0XLCb0`2QaO840:;4l@<0X/Gb0`2QaO830:76lP@0X/Gb
1P2Ra_830:77l`@0X/Kb00<000000:;7l`2Rao<00`2Rao<40:?7lP<0XlSc0`2Rb?<30:;8m0L0XlWc
0`2Sb_@40:C:l`030?ooo`000000oooo00H0oooo00<000000?ooo`3oool01@3oool000h0oooo00@0
00000?ooo`3]Z840kJR10`1h<fd207LbK0<0Mc5Z0P1f<6T207D_J0<0MBeV0`1d;6D207<[I080LRUR
0`1b:643074VG`80L2AM0P1_8U/306hPF@<0KAiG0`1[75@2000000@0oooo3`2Y_NP70:Rmj0@0YkgY
0P2V_NX30:Fmj`@0Y[gZ0`2U_N/30:Bnk0<0Xkk/102T_^`20:>nk@<0Xko]102R_nh20:6okP@0X[o^
0`2R`>h30:70k`<0XL7_0`2R`Nl40:71k`<0XL7`0`2Q`_030:;1k`L0XL;`0P2Q`o440:;2l0<0XL?`
1P2Q`o440:;3l0<0X/Ca0`2Qa?430:74lPL0X/Ca0`2RaO830:75lP<0X/Ga102RaO830:;6lP<0XlKa
0`2Sa_840:;6lP030000002Rao<0XlOb00L0XlOb0`2Sb?<30:C8lP<0Y<Sc102SbO<30:G9l`<0Y<Wc
102Tb_<00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo000>0?ooo`040000003o
ool0kJR10>fXP@<0N3=]0P1g<V`307LaJP80MS1Y0P1e;fP307D]IP<0M2aU0P1c:f@2078YHP<0LRQQ
0`1a9Ul0101`95d0Kb9K06lRF`1_8U/306hPF@80KAiG00@0JaaD00000000000000001`3ooolC0:Vm
j0<0Z;gX102W_NT90:JmjP<0YKg[0`2T_^`30:Fnj`@0Y;k/0P2S_^d:0:>ok@<0X[o^0`2R`>h30:?0
kP@0X/3^0P2R`Nl40:71k`T0X/7_0`2Q`_040:;2k`H0X/;`0`2Q`o0:0:;3l0<0X/Ca0`2S`o090:;4
l@@0XlCa0`2SaO430:;5l@<0X/Gb102SaO430:?6l@<0XlKb0`2Ta_4010000000XlKb0:?6lP2Sa_86
0:?7lP@0Y<Ob0`2Tb?830:C8l`@0YLSb0`2UbO<30:C9l`@0Y/[c00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`003P3oool200000080kJR10P1h<fd207LbK0<0Mc5Z0`1f<6T207D_
J0<0MBeV0P1d;6D207<[I0<0LRUR0`1b:642074VG`80L2AM0`1_8U/206hPF@040?ooo`0000000000
000000/0oooo4`2Y_NP30:Rmj0@0Z;gY0P2W_NT:0:JmjPH0YKk[0`2T_^`30:>nk@<0Y;k/1`2S_nd2
0::okP@0Xko]0`2S`>h40:;0kP80X/7_102S`>h90:;1k`<0Xl7_102R`^l50:;2l0@0Xl;_2@2R`o07
0:?3l0H0X/Ca102Sa?030:?4l@<0XlGa0`2Ta?070:?5l@<0XlKa0`2TaO430:C6l@040000002Sa_80
XlKb0:?6lP<0YLKa0`2Tao440:C7lP80Y<Sb202Ub?820:G9l`@0Y/Wb0`2Vb_<00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo000=0?ooo`80000000<0oooo0>fXP@3]Z8400P1h<fd2
07LbK0<0Mc5Z0`1f<6T207D_J080MBeV0`1d;6D207<[I0<0LRUR0P1b:643074VG`80L2AM0P1_8U/0
103oool0000000000000000?0?oooaH0ZKgX102X_NT20:Nmj@<0Y[gZ102W_NT30:JmjPT0YKk[102U
_^`20:Bnk0@0Xko]0`2T_n`30:Bok@<0Xko]0`2S`>h40:C0k@H0Xl3^0`2R`Nl60:?1kP<0Xl7_0`2R
`^l40:?1k`H0Xl;_0`2R`o040:?2k`<0Xl?_1P2S`o030:C3l0L0XlC`0P2Sa?470:C4l0H0XlGa102T
aO030:C5l@<0Y<Ka00<000000:G6l@2Ua_40102Ua_430:C7l@@0YLKa0P2Uao470:G8lP<0Y/Sa102V
bO820:K:l`030000003oool0oooo00@0oooo0`0000050?ooo`000P3oool5000000H0oooo00@00000
0?ooo`3oool0kJR10`1h<fd207LbK0<0Mc5Z0P1f<6T207D_J0<0MBeV0`1d;6D207<[I080LRUR0`1b
:643074VG`03070TG@3oool00000008000004`3ooolF0:Vmj0@0Z;gY2@2W_NT30:JmjP<0YKk[0`2V
_^/30:Fnj`@0YKk/0P2T_^`40:Fnk0<0Y;o/0`2T_nd30:>ok@<0Y;o]102T`>d50:?0kP@0Y<3^1P2S
`Nh30:?1k`<0Y<7^102S`Nl50:?2k`@0Y<;_102S`^l30:?3k`80Xl?`102T`nl30:C3l0<0XlC`102T
`nl90:C4l0<0YLC`1`2TaO020:C5l@@0YLG`00<000000:G6l@2Ua_400`2Ua_440:K6l0@0YLKa0P2U
ao440:O6l0<0Y/Oa0`2Vb?450?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00080oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`3]Z84307PcK@80Mc9/0`1g
<FX207H`J@80MBmX0`1e;FH307@/I@0407<[I01b:F80LRUR078YHP<0LRQQ0P1a9Ul3000001L0oooo
5P2Y_NP40:Rmj080Z;gY2P2W_NT30:JmjP<0Y[k[0`2U_^/40:Jnj`80YKk[102U_^`30:Bok0<0YKo/
0`2T_n`30:Bok@<0Y<3]102T_nd20:C0k@@0Y<3^0`2S`Nh30:C0k@H0Y<7^0`2S`Nl40:C1kP<0Y<;^
0`2T`^l30:?2k`@0Y<;^0`2T`^l30:C3k`<0Y<?`1`2T`nl50:C4l0@0YLC_0`2Ua?030:C5l0@0YLC_
1@2UaO0010000000YLKa0:G6l@2Ua_430:K5l0@0Y/K`0`2Ua_430:O6k`@0YlK`0`2Vao480?ooo`03
0000003oool0oooo00/0oooo00030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
kJR10`1h<fd0101g<V`0Mc5Z07LaJP1g<FX307H`J@80MBmX0`1e;FH207@/I@80Lb]T0`1b:F82078X
H@<000006`3ooolF0:Vmj0@0Z;gX0P2X_NT:0:Nmj@<0Y[gZ0`2V_^/30:JnjP@0Y[k[0P2U_^/30:Fn
k0@0YKk[0`2U_n`30:Bok0<0Y;o]0`2U_n`40:Bok@80Y<3]0`2T`>h70:C0k@d0Y<7^0`2T`^h20:C2
k`P0Y<;^0`2T`^l20:C3k`@0YL?_1P2T`nl60:G3k`@0YLC_0`2Ua?030:K4k`@0YLC_0`2UaO020:K4
k`040000002VaNl0Y/G_0:K5k`<0Y/G`0`2Va_040:O5k`<0YlK_0`2Wa_0;0?ooo`030000003oool0
oooo00/0oooo00040?ooo`8000001`3oool2000000040?ooo`3]Z840N3=]07PcK@80Mc9/0`1g<FX3
07H`J@80MBmX0P1e;FH307@/I@80Lb]T0P1b:F800`3oool000000000000O0?oooaH0ZKgX102X_NP5
0:Rmj@L0YkgY0`2V_NX30:NmjP<0Y[kZ102V_^/20:Fnj`<0Y[k[102U_^/30:Fok080Y;o/1`2U_n`4
0:Bok@80Y<3]0`2U`>d70:C0k@<0YL3]0`2U`Nd60:C1kP@0YL7]0`2U`Nh60:C2kPH0YL;^102U`nl2
0:C3k`@0YL?^1P2U`nl40:K3kPH0Y/C_0`2Ua>l40:K4kP80Y/C_00@000000:K5k`2VaNl0Y/G_1P2W
a>h40:O5k`80YlK_3P3oool00`000000oooo0?ooo`0;0?ooo`001P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0kJR100<0N3=]0P1g<V`307LaJP80MS1Y0P1e;fP307D]IP<0M2aU00<0Lb]T
0?ooo`0000000P00000R0?oooaX0ZKgX0P2X_NP30:Rmj@@0YkgY0`2X_NT30:Nmj@<0YkgZ0`2V_^X4
0:NnjPD0Y[k[102U_^/30:Jnj`<0YKo[3@2U_n`20:G0k@@0Y<3]0`2U`>`30:G0k@<0YL7]0`2T`Nh7
0:G1k@<0YL7^0P2T`^h40:G2k@H0YL;^102V`^d30:K2kP<0YL?^0`2U`nl70:K3kPD0Y/C_102W`nh4
0:K4kP80Y/C_00@000000:S3k@2X`nd0Z<?]1P2Wa>hC0?ooo`030000003oool0oooo00/0oooo0007
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0kJR10`1h<fd207LbK0<0Mc5Z0P1f
<6T207D_J0<0MBeV0P1d;6D3000002H0oooo6P2Y_NP20:Rmj0X0Z;gY0`2W_NT30:NmjPL0YkkZ302V
_^/30:Foj`<0YKo/0`2V_n/70:Fok080YL3]102V_n`30:G0k0<0YL3]0`2V`>`30:G0k@H0YL7]1`2V
`Nd30:G2k@<0YL;^1`2V`^d30:K2kP80YL?^102V`^d60:K3kP@0Yl?]1P2W`nh30:K4kP80Z<?]00<0
00000:S3k@2X`nd00P2X`nd20:O4kQH0oooo00<000000?ooo`3oool02`3oool000<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0>fXP@<0N3=]00@0Mc9/07LaJP1g<FX0
Mc5Z0`1f<6T207D_J080MBeV0`00000Z0?oooaX0ZKgX1@2X_NP:0:Rmj@<0YkgY3@2W_^X90:Jnj`H0
Y[o[0`2U_n`40:Joj`H0Y[o/0`2U`>`60:K0k0<0YL3]0`2U`Nd30:K1k0L0Y/7]0P2U`^d40:K1k@H0
Y/;]102W`^d60:K2k@<0Y/?^0`2W`^d40:O3k@80Yl?^1`2X`^`20:S3k@040000002X`nd0Z<?]0:S3
kAP0oooo00<000000?ooo`3oool02`3oool000@0oooo0`0000050?ooo`040000003oool0oooo0>fX
P@80N3=]0P1g<V`307LaJP<0MS1Y00@0MBmX0000000000000000;P3ooolM0:Vmj080Z;gX2P2X_NT3
0:Nmj@<0YkkZ0`2W_^T70:NnjP80Y[k[102W_^X30:Jnj`d0Y[o[2@2V_n`<0:K0k0<0Y/7/0`2V`Nd4
0:O1k0<0Y/7/0`2V`Nd30:K2k@<0Yl7/102W`^d50:K2k@L0Yl;]0`2W`nd30:S1k0L0Z<;/0P2X`nd0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo000<0?ooo`80000000@0oooo07Pc
K@1h<fd0N3=]0P1g<V`307LaJP0407H`J@000000000000000380oooo7@2Y_NP20:Rmj0@0ZKgX1P2X
_NT30:Nmj@<0Z;gY0`2W_^T40:NnjP<0YkkY1P2W_^X30:Jnj`<0YkkZ0`2W_^/60:Joj`@0Yko[0`2V
_n/30:Jok0<0Y/3/0`2W_n/60:K0k0<0Y/7/0`2W`>`40:O1k0<0Y/7/0P2V`Nd70:O1k0<0Yl;]102X
`N`20:O1k0H0Yl;]102X`N/30:S1k0<0Z<;/1P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00X0oooo000<0?ooo`030000003oool0oooo00<0N3=]0P1g<V`0101g<FX0000000000000
000f0?ooob<0ZKgX0`2X_NT30:Rmj0H0Z;gY0`2W_^T40:Rnj@<0YkkY302W_^X30:Nnj`<0Y[o[1`2W
_n/30:Joj`80Y[o/1`2W_n/30:K0k0<0Yko[0`2W`>/30:O0k0<0Yl7/102W`>/90:O1k0<0Z<7[102X
`N`20:O1k0L0Z<3[0`2X`N/30:S1k0P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0:0?ooo`00303oool00`000000oooo0?ooo`0307PcK@0307LbK0000000000003X0oooo9P2Y_NP3
0:Rmj0T0Z;gY102X_^T30:Nnj@80YkkZ0`2W_^T=0:NnjPH0Yko[102W_nX?0:Noj`<0Yl3[0`2W`>`7
0:O0j`<0Yl7/1P2X`>/30:S1j`<0Z<7/0`2X`>X70:S0j`80Z<7[303oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00X0oooo000;0?ooo`050000003oool0oooo0?ooo`1h<fd00`00000n
0?ooobD0ZKgX1P2X_NP60:Rmj@X0Z;kY0P2W_^T40:NnjP<0Z;kY1P2W_^X30:Noj`<0YkkZ102W_nX?
0:Noj`H0Z;o[1P2W`>/40:Roj`H0Z<3[0P2X`N/40:VojP<0Z<3Z0`2X`>/B0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`0000000P0000120?oo
obP0ZKgX0`2X_NP90:Rmj@L0Z;kY0P2W_^T70:Rnj@<0YkkZ0`2X_^T30:RnjP<0YkkZ0`2W_nX40:Rn
jP80Z;oZ1P2W_n/40:RojPH0Z;o[0`2W`>/30:RojP@0Z;o[0P2X`>/40:Voj@H0ZKoZ0`2X`>XD0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool000/0oooo0P0000160?ooobP0
ZKgX0`2X_NP40:Vmj0D0Z;gY5P2X_^T30:RnjP<0YkkZ1`2X_^X20:RojP<0Yko[1`2X_nX30:Roj`T0
Z;oZ0`2X_n/30:Vnj@@0ZKoY1@2Y_nXH0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool02P3oool000`0oooo00<000000?ooo`3oool0A@3oool_0:Vmj0P0Z;gY6@2X_^T60:RnjP<0Z;kY
0`2X_^X60:RojP@0Z;kY202X_nX70:Vnj@<0ZKoY7P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00X0oooo000=0?ooo`800000AP3ooole0:Vmj080Z;gY6@2X_^T30:RnjPH0Z;kY0`2X
_^X30:RojP<0ZKkY102X_^T20:RojPd0ZKkY8@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00T0oooo000?0?ooo`030000003oool0oooo04@0oooo=@2Y_NP20:Rmj@<0ZKgX4`2X_^T3
0:Vnj@T0Z;kY2@2Y_^T30:Rnj@`0ZKkY903oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00T0oooo000@0?ooo`030000003oool0oooo04@0oooo>P2Y_NP30:Rnj@@0ZKgX0`2Y_^T50:Rn
j@L0ZKkY1@2X_^T=0:Vnj@<0ZKkX1P2Y_^TZ0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02@3oool00140oooo00<000000?ooo`3oool0A03ooom10:Vmj0<0ZKkY0P2X_^T30:Vnj0L0
ZKkY0`2Y_^P90:Vnj@T0ZKkX0`2Y_^T]0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool02@3oool00180oooo0P0000150?ooodH0ZKgX0`2Y_^P30:Vnj@L0ZKkX1@2Y_^T40:Vmj0P0ZKkX
<@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo000D0?ooo`030000003o
ool0oooo04<0ooooAP2Y_NP30:Vnj0<0ZKgX1P2Y_^P:0:Vmj080ZKkX=P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00T0oooo000E0?ooo`030000003oool0oooo04<0ooooC02Y_NP3
0:Vnj0`0ZKgX>@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo000F0?oo
o`030000003oool0oooo04@0ooooE02Y_NPo0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0203oool001L0oooo0P0000150?oooe40ZKgX@@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo04<0ooooC@2Y_NQ50?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0203oool001X0oooo00<000000?ooo`3oool0@`3o
oom80:Vmj4X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`006`3oool0
0`000000oooo0?ooo`130?oood@0ZKgXCP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00P0oooo000L0?ooo`800000A03ooolo0:Vmj580oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`120?oooc/0ZKgXEP3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo000O0?ooo`030000003oool0oooo0480oooo
=P2Y_NQK0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00200oooo00<0
00000?ooo`3oool0@P3ooolb0:Vmj5l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`070?ooo`008@3oool2000004<0oooo;`2Y_NQQ0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool0@@3ooolZ0:Vmj6H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`070?ooo`00903oool00`000000oooo0?ooo`110?ooobH0
ZKgXJP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo000U0?ooo`030000
003oool0oooo0440oooo8@2Y_NQ^0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1`3oool002H0oooo0P0000130?oooa`0ZKgXLP3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo000X0?ooo`030000003oool0oooo0440oooo5`2Y_NQg0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool002T0oooo00<000000?ooo`3oool0@@3ooolD0:Vm
j7X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000
oooo0?ooo`110?ooo`h0ZKgXO`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo000[0?ooo`800000@P3oool;0:Vmj880oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`00;@3oool00`000000oooo0?ooo`100?ooo`H0ZKgXQ`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo000^0?ooo`030000003oool0oooo0400oooo0P2Y_NR;
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool002l0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00300oooo0P00000o0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`00<P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`00<`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`00=03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`00=@3oool20000
03X0oooo00<000000?ooo`3oool0SP3oool01@000000oooo0?ooo`3oool0000000L0oooo000g0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0S`3oool010000000oooo0?ooo`000007
0?ooo`00>03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo08l0oooo00@000000?oo
o`3oool000001`3oool003T0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0000000L0oooo000j0?ooo`800000=@3oool00`000000oooo0?ooo`2A0?ooo`03
0000003oool0000000H0oooo000l0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
TP3oool2000000H0oooo000m0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0TP3o
ool2000000H0oooo000n0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0T`3oool2
000000H0oooo000o0?ooo`800000;`3oool00`000000oooo0?ooo`2?0?ooo`@00000203oool00440
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2;0?ooo`@00000303oool00480oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`270?ooo`@00000403oool004<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`230?ooo`@00000503oool004@0oooo0P00000Z
0?ooo`030000003oool0oooo07l0oooo1000000H0?ooo`00AP3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo07/0oooo1000000L0?ooo`00A`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo07L0oooo1000000P0?ooo`00B03oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo07<0oooo1000000T0?ooo`00B@3oool2000002D0oooo00<000000?ooo`3oool0K`3o
ool4000002P0oooo001;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0K03oool3
000002`0oooo001<0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0J03oool40000
02l0oooo001=0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0I03oool4000003<0
oooo001>0?ooo`800000803oool00`000000oooo0?ooo`1P0?ooo`@00000=`3oool00500oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1L0?ooo`@00000>`3oool00540oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`@00000?`3oool00580oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1D0?ooo`@00000@`3oool005<0oooo0P00000K0?ooo`03
0000003oool0oooo0500oooo100000170?ooo`00E@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo04`0oooo1000001;0?ooo`00EP3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo04P0oooo1000001?0?ooo`00E`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo04D0oooo0`00001C0?ooo`00F03oool2000001H0oooo00<000000?ooo`3oool0@@3oool40000
05H0oooo001J0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool4000005X0
oooo001K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>@3oool4000005h0oooo
001L0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=@3oool400000680oooo001M
0?ooo`8000004@3oool00`000000oooo0?ooo`0a0?ooo`@00000IP3oool005l0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0^0?ooo`@00000JP3oool00600oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0Z0?ooo`@00000KP3oool00640oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0V0?ooo`@00000LP3oool00680oooo0P00000;0?ooo`030000003o
ool0oooo02<0oooo0`00001f0?ooo`00I03oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01l0oooo1000001i0?ooo`00I@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01/0oooo1000001m0?ooo`00IP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0
oooo100000210?ooo`00I`3oool2000000H0oooo00<000000?ooo`3oool04`3oool4000008D0oooo
001Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool4000008T0oooo001Z
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool4000008d0oooo001[0?oo
o`050000003oool0oooo0?ooo`0000002@3oool400000940oooo001/0?ooo`80000000<0oooo0000
003oool0103oool4000009D0oooo001^0?ooo`80000000<0oooo0000000000000P00002I0?ooo`00
K`3oool2000009d0oooo0000\
\>"],
  ImageRangeCache->{{{0, 269.25}, {218.062, 0}} -> {-0.0449014, 0.0119217, \
0.00378562, 0.00378562}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Connections within the group of gamma functions and with function \
groups\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["Representations through more general functions", "Subsubsection"],

Cell[TextData[{
  "The incomplete gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " are particular cases of more the general hypergeometric and Meijer G \
functions."
}], "Text"],

Cell[TextData[{
  "For example, they can be represented through hypergeometric functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[InvisiblePrefixScriptBase]", "1"], 
          SubscriptBox["F", 
            FormBox["1",
              "TraditionalForm"]]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[InvisiblePrefixScriptBase]", 
            FormBox["1",
              "TraditionalForm"]], 
          SubscriptBox[
            OverscriptBox["F", "~"], 
            FormBox["1",
              "TraditionalForm"]]}], TraditionalForm]]],
  " or the Tricomi confluent hypergeometric function ",
  Cell[BoxData[
      FormBox["U", TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", 
                RowBox[{
                  SuperscriptBox["z", "a"], " ", 
                  TagBox[
                    TagBox[
                      RowBox[{
                        RowBox[{
                          SubscriptBox["\[InvisiblePrefixScriptBase]", 
                            FormBox["1",
                              "TraditionalForm"]], 
                          SubscriptBox[
                            OverscriptBox["F", "~"], 
                            FormBox["1",
                              "TraditionalForm"]]}], 
                        "\[InvisibleApplication]", 
                        RowBox[{"(", 
                          RowBox[{
                            TagBox[
                              TagBox[
                                TagBox["a",
                                  HypergeometricPFQRegularized,
                                  Editable->True],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->False], ";", 
                            TagBox[
                              TagBox[
                                TagBox[
                                  RowBox[{"a", "+", "1"}],
                                  HypergeometricPFQRegularized,
                                  Editable->True],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->False], ";", 
                            TagBox[
                              RowBox[{"-", "z"}],
                              HypergeometricPFQRegularized,
                              Editable->True]}], ")"}]}],
                      InterpretTemplate[ 
                      HypergeometricPFQRegularized[ #, #2, #3]&],
                      Editable->False],
                    HypergeometricPFQRegularized]}]}], ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{"-", "a"}], "\[NotElement]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "-", 
            RowBox[{
              FractionBox[
                SuperscriptBox["z", "a"], "a"], " ", 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["1",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            TagBox["a",
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          RowBox[{"-", "z"}],
                          HypergeometricPFQ,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                HypergeometricPFQ]}]}]}], "/;", 
        RowBox[{
          RowBox[{"-", "a"}], "\[NotElement]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", "z"}]], " ", 
          RowBox[{
            TagBox["U",
              HypergeometricU], "(", 
            RowBox[{
              RowBox[{"1", "-", "a"}], ",", 
              RowBox[{"1", "-", "a"}], ",", "z"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["z", "2", "a"], " ", 
                  TagBox[
                    TagBox[
                      RowBox[{
                        RowBox[{
                          SubscriptBox["\[InvisiblePrefixScriptBase]", 
                            FormBox["1",
                              "TraditionalForm"]], 
                          SubscriptBox[
                            OverscriptBox["F", "~"], 
                            FormBox["1",
                              "TraditionalForm"]]}], 
                        "\[InvisibleApplication]", 
                        RowBox[{"(", 
                          RowBox[{
                            TagBox[
                              TagBox[
                                TagBox["a",
                                  HypergeometricPFQRegularized,
                                  Editable->True],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->False], ";", 
                            TagBox[
                              TagBox[
                                TagBox[
                                  RowBox[{"a", "+", "1"}],
                                  HypergeometricPFQRegularized,
                                  Editable->True],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->False], ";", 
                            TagBox[
                              RowBox[{"-", 
                                SubscriptBox["z", "2"]}],
                              HypergeometricPFQRegularized,
                              Editable->True]}], ")"}]}],
                      InterpretTemplate[ 
                      HypergeometricPFQRegularized[ #, #2, #3]&],
                      Editable->False],
                    HypergeometricPFQRegularized]}], "-", 
                RowBox[{
                  SubsuperscriptBox["z", "1", "a"], " ", 
                  TagBox[
                    TagBox[
                      RowBox[{
                        RowBox[{
                          SubscriptBox["\[InvisiblePrefixScriptBase]", 
                            FormBox["1",
                              "TraditionalForm"]], 
                          SubscriptBox[
                            OverscriptBox["F", "~"], 
                            FormBox["1",
                              "TraditionalForm"]]}], 
                        "\[InvisibleApplication]", 
                        RowBox[{"(", 
                          RowBox[{
                            TagBox[
                              TagBox[
                                TagBox["a",
                                  HypergeometricPFQRegularized,
                                  Editable->True],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->False], ";", 
                            TagBox[
                              TagBox[
                                TagBox[
                                  RowBox[{"a", "+", "1"}],
                                  HypergeometricPFQRegularized,
                                  Editable->True],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->False], ";", 
                            TagBox[
                              RowBox[{"-", 
                                SubscriptBox["z", "1"]}],
                              HypergeometricPFQRegularized,
                              Editable->True]}], ")"}]}],
                      InterpretTemplate[ 
                      HypergeometricPFQRegularized[ #, #2, #3]&],
                      Editable->False],
                    HypergeometricPFQRegularized]}]}], ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{"-", "a"}], "\[NotElement]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              FractionBox[
                SubsuperscriptBox["z", "2", "a"], "a"], 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["1",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            TagBox["a",
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          RowBox[{"-", 
                            SubscriptBox["z", "2"]}],
                          HypergeometricPFQ,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                HypergeometricPFQ]}], "-", 
            RowBox[{
              FractionBox[
                SubsuperscriptBox["z", "1", "a"], "a"], 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["1",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            TagBox["a",
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          RowBox[{"-", 
                            SubscriptBox["z", "1"]}],
                          HypergeometricPFQ,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                HypergeometricPFQ]}]}]}], "/;", 
        RowBox[{
          RowBox[{"-", "a"}], "\[NotElement]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
                SubscriptBox["z", "1"]}]], " ", 
            RowBox[{
              TagBox["U",
                HypergeometricU], "(", 
              RowBox[{
                RowBox[{"1", "-", "a"}], ",", 
                RowBox[{"1", "-", "a"}], ",", 
                SubscriptBox["z", "1"]}], ")"}]}], "-", 
          RowBox[{
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
                SubscriptBox["z", "2"]}]], " ", 
            RowBox[{
              TagBox["U",
                HypergeometricU], "(", 
              RowBox[{
                RowBox[{"1", "-", "a"}], ",", 
                RowBox[{"1", "-", "a"}], ",", 
                SubscriptBox["z", "2"]}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{"1", "-", 
            RowBox[{
              SuperscriptBox["z", "a"], " ", 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["1",
                          "TraditionalForm"]], 
                      SubscriptBox[
                        OverscriptBox["F", "~"], 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQRegularized,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQRegularized,
                          Editable->False], ";", 
                        TagBox[
                          RowBox[{"-", "z"}],
                          HypergeometricPFQRegularized,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ 
                  HypergeometricPFQRegularized[ #, #2, #3]&],
                  Editable->False],
                HypergeometricPFQRegularized]}]}]}], "/;", 
        RowBox[{
          RowBox[{"-", "a"}], "\[NotElement]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{"1", "-", 
            RowBox[{
              FractionBox[
                SuperscriptBox["z", "a"], 
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{"a", "+", "1"}], ")"}]], 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["1",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            TagBox["a",
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          RowBox[{"-", "z"}],
                          HypergeometricPFQ,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                HypergeometricPFQ]}]}]}], "/;", 
        RowBox[{
          RowBox[{"-", "a"}], "\[NotElement]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], 
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", "z"}]], " ", 
          RowBox[{
            TagBox["U",
              HypergeometricU], "(", 
            RowBox[{
              RowBox[{"1", "-", "a"}], ",", 
              RowBox[{"1", "-", "a"}], ",", "z"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox["z", "2", "a"], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["1",
                        "TraditionalForm"]], 
                    SubscriptBox[
                      OverscriptBox["F", "~"], 
                      FormBox["1",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          TagBox["a",
                            HypergeometricPFQRegularized,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          TagBox[
                            RowBox[{"a", "+", "1"}],
                            HypergeometricPFQRegularized,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"-", 
                          SubscriptBox["z", "2"]}],
                        HypergeometricPFQRegularized,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQRegularized[ #, #2, #3]&],
                
                Editable->False],
              HypergeometricPFQRegularized]}], "-", 
          RowBox[{
            SubsuperscriptBox["z", "1", "a"], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["1",
                        "TraditionalForm"]], 
                    SubscriptBox[
                      OverscriptBox["F", "~"], 
                      FormBox["1",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          TagBox["a",
                            HypergeometricPFQRegularized,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          TagBox[
                            RowBox[{"a", "+", "1"}],
                            HypergeometricPFQRegularized,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"-", 
                          SubscriptBox["z", "1"]}],
                        HypergeometricPFQRegularized,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQRegularized[ #, #2, #3]&],
                
                Editable->False],
              HypergeometricPFQRegularized]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              FractionBox[
                SubsuperscriptBox["z", "2", "a"], 
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{"a", "+", "1"}], ")"}]], " ", 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["1",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            TagBox["a",
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          RowBox[{"-", 
                            SubscriptBox["z", "2"]}],
                          HypergeometricPFQ,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                HypergeometricPFQ]}], "-", 
            RowBox[{
              FractionBox[
                SubsuperscriptBox["z", "1", "a"], 
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{"a", "+", "1"}], ")"}]], 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["1",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            TagBox["a",
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQ,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          HypergeometricPFQ,
                          Editable->False], ";", 
                        TagBox[
                          RowBox[{"-", 
                            SubscriptBox["z", "1"]}],
                          HypergeometricPFQ,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                HypergeometricPFQ]}]}]}], "/;", 
        RowBox[{
          RowBox[{"-", "a"}], "\[NotElement]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                      SubscriptBox["z", "1"]}]], " ", 
                  RowBox[{
                    TagBox["U",
                      HypergeometricU], "(", 
                    RowBox[{
                      RowBox[{"1", "-", "a"}], ",", 
                      RowBox[{"1", "-", "a"}], ",", 
                      SubscriptBox["z", "1"]}], ")"}]}], "-", 
                RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                      SubscriptBox["z", "2"]}]], " ", 
                  RowBox[{
                    TagBox["U",
                      HypergeometricU], "(", 
                    RowBox[{
                      RowBox[{"1", "-", "a"}], ",", 
                      RowBox[{"1", "-", "a"}], ",", 
                      SubscriptBox["z", "2"]}], ")"}]}]}], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell["\<\
These functions also have rather simple representations in terms of \
classical Meijer G functions:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", 
          RowBox[{"(", 
            RowBox[{"a", ",", "z"}], ")"}]}], "\[Equal]", 
        TagBox[
          RowBox[{
            SubsuperscriptBox[
              TagBox["G",
                MeijerG], 
              RowBox[{"1", ",", "2"}], 
              RowBox[{"2", ",", "0"}]], "\[InvisibleApplication]", 
            RowBox[{"(", 
              RowBox[{
                TagBox["z",
                  MeijerG,
                  Editable->True], "\[VerticalSeparator]", GridBox[{
                    {
                      TagBox["1",
                        MeijerG,
                        Editable->True]},
                    {
                      RowBox[{
                        TagBox["0",
                          MeijerG,
                          Editable->True], ",", 
                        TagBox["a",
                          MeijerG,
                          Editable->True]}]}
                    }]}], ")"}]}],
          MeijerG,
          Editable->False]}], TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          TagBox[
            RowBox[{
              SubsuperscriptBox[
                TagBox["G",
                  MeijerG], 
                RowBox[{"1", ",", "2"}], 
                RowBox[{"1", ",", "1"}]], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    SubscriptBox["z", "2"],
                    MeijerG,
                    Editable->True], "\[VerticalSeparator]", GridBox[{
                      {
                        TagBox["1",
                          MeijerG,
                          Editable->True]},
                      {
                        RowBox[{
                          TagBox["a",
                            MeijerG,
                            Editable->True], ",", 
                          TagBox["0",
                            MeijerG,
                            Editable->True]}]}
                      }]}], ")"}]}],
            MeijerG,
            Editable->False], "-", 
          TagBox[
            RowBox[{
              SubsuperscriptBox[
                TagBox["G",
                  MeijerG], 
                RowBox[{"1", ",", "2"}], 
                RowBox[{"1", ",", "1"}]], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    SubscriptBox["z", "1"],
                    MeijerG,
                    Editable->True], "\[VerticalSeparator]", GridBox[{
                      {
                        TagBox["1",
                          MeijerG,
                          Editable->True]},
                      {
                        RowBox[{
                          TagBox["a",
                            MeijerG,
                            Editable->True], ",", 
                          TagBox["0",
                            MeijerG,
                            Editable->True]}]}
                      }]}], ")"}]}],
            MeijerG,
            Editable->False]}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], 
          TagBox[
            RowBox[{
              SubsuperscriptBox[
                TagBox["G",
                  MeijerG], 
                RowBox[{"1", ",", "2"}], 
                RowBox[{"2", ",", "0"}]], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox["z",
                    MeijerG,
                    Editable->True], "\[VerticalSeparator]", GridBox[{
                      {
                        TagBox["1",
                          MeijerG,
                          Editable->True]},
                      {
                        RowBox[{
                          TagBox["0",
                            MeijerG,
                            Editable->True], ",", 
                          TagBox["a",
                            MeijerG,
                            Editable->True]}]}
                      }]}], ")"}]}],
            MeijerG,
            Editable->False]}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                TagBox[
                  RowBox[{
                    SubsuperscriptBox[
                      TagBox["G",
                        MeijerG], 
                      RowBox[{"1", ",", "2"}], 
                      RowBox[{"1", ",", "1"}]], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          SubscriptBox["z", "2"],
                          MeijerG,
                          Editable->True], "\[VerticalSeparator]", GridBox[{
                            {
                              TagBox["1",
                                MeijerG,
                                Editable->True]},
                            {
                              RowBox[{
                                TagBox["a",
                                  MeijerG,
                                  Editable->True], ",", 
                                TagBox["0",
                                  MeijerG,
                                  Editable->True]}]}
                            }]}], ")"}]}],
                  MeijerG,
                  Editable->False], "-", 
                TagBox[
                  RowBox[{
                    SubsuperscriptBox[
                      TagBox["G",
                        MeijerG], 
                      RowBox[{"1", ",", "2"}], 
                      RowBox[{"1", ",", "1"}]], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          SubscriptBox["z", "1"],
                          MeijerG,
                          Editable->True], "\[VerticalSeparator]", GridBox[{
                            {
                              TagBox["1",
                                MeijerG,
                                Editable->True]},
                            {
                              RowBox[{
                                TagBox["a",
                                  MeijerG,
                                  Editable->True], ",", 
                                TagBox["0",
                                  MeijerG,
                                  Editable->True]}]}
                            }]}], ")"}]}],
                  MeijerG,
                  Editable->False]}], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " can be expressed through polygamma and zeta functions by the following \
formulas:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          RowBox[{"log\[CapitalGamma]", 
            RowBox[{"(", "z", ")"}]}],
          ScriptLevel->0], "\[Equal]", 
        RowBox[{
          SubsuperscriptBox["\[Integral]", "1", "z"], 
          RowBox[{
            RowBox[{
              TagBox["\[Psi]",
                PolyGamma], "(", "t", ")"}], 
            RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
          ScriptLevel->0], "\[Equal]", 
        FractionBox[
          RowBox[{
            SuperscriptBox["\[PartialD]", 
              RowBox[{
                RowBox[{"-", "\[Nu]"}], "-", "1"}]], 
            RowBox[{
              SuperscriptBox[
                TagBox["\[Psi]",
                  PolyGamma], 
                RowBox[{"(", "\[Nu]", ")"}]], "(", "z", ")"}]}], 
          RowBox[{"\[PartialD]", 
            SuperscriptBox["z", 
              RowBox[{
                RowBox[{"-", "\[Nu]"}], "-", "1"}]]}],
          MultilineFunction->None]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"log", "(", 
                RowBox[{"2", " ", "\[Pi]"}], ")"}]}], "+", 
            RowBox[{
              SuperscriptBox["\[Zeta]", 
                TagBox[
                  RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                MultilineFunction->None], "(", 
              RowBox[{"0", ",", "z"}], ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "z", ")"}], ">", "0."}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Representations through related equivalent functions", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " can be represented using the related exponential integral ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            TagBox["E",
              ExpIntegralE], "\[Nu]"], "(", "z", ")"}], TraditionalForm]]],
  " by the following formulas:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          SuperscriptBox["z", "a"], " ", 
          RowBox[{
            SubscriptBox[
              TagBox["E",
                ExpIntegralE], 
              RowBox[{"1", "-", "a"}]], "(", "z", ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox["z", "1", "a"], " ", 
            RowBox[{
              SubscriptBox[
                TagBox["E",
                  ExpIntegralE], 
                RowBox[{"1", "-", "a"}]], "(", 
              SubscriptBox["z", "1"], ")"}]}], "-", 
          RowBox[{
            SubsuperscriptBox["z", "2", "a"], " ", 
            RowBox[{
              SubscriptBox[
                TagBox["E",
                  ExpIntegralE], 
                RowBox[{"1", "-", "a"}]], "(", 
              SubscriptBox["z", "2"], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        FractionBox[
          RowBox[{
            SuperscriptBox["z", "a"], " ", 
            RowBox[{
              SubscriptBox[
                TagBox["E",
                  ExpIntegralE], 
                RowBox[{"1", "-", "a"}]], "(", "z", ")"}]}], 
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["z", "1", "a"], " ", 
                  RowBox[{
                    SubscriptBox[
                      TagBox["E",
                        ExpIntegralE], 
                      RowBox[{"1", "-", "a"}]], "(", 
                    SubscriptBox["z", "1"], ")"}]}], "-", 
                RowBox[{
                  SubsuperscriptBox["z", "2", "a"], " ", 
                  RowBox[{
                    SubscriptBox[
                      TagBox["E",
                        ExpIntegralE], 
                      RowBox[{"1", "-", "a"}]], "(", 
                    SubscriptBox["z", "2"], ")"}]}]}], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Relations to inverse functions", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " are connected with the inverse of the regularized incomplete gamma \
function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and the inverse of the generalized regularized incomplete gamma function \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " by the following formulas:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", "z"}], ")"}]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", "z"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
          SubscriptBox["z", "2"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", "z"}], ")"}]}], ")"}], "\[Equal]", "z"}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], ")"}], "\[Equal]", 
        SubscriptBox["z", "2"]}], TraditionalForm]], "TraditionalFormEquation",\

  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            RowBox[{
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"]}], ")"}], "-", 
              SubscriptBox["z", "2"]}]}], ")"}], "\[Equal]", 
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], 
              RowBox[{"-", "1"}]], "(", 
            RowBox[{"a", ",", 
              RowBox[{
                RowBox[{
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], "(", 
                  RowBox[{"a", ",", 
                    SubscriptBox["z", "1"]}], ")"}], "-", 
                SubscriptBox["z", "2"]}]}], ")"}], "."}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Representations through other gamma functions", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "a", ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " are connected with each other by the formulas:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "\[Equal]", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "0"}], ")"}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "+", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", "z", ",", "0"}], ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], "(", 
                  RowBox[{"a", ",", "z", ",", "0"}], ")"}], "+", "1"}], 
              ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "z"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"]}], ")"}], "-", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "2"]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            FractionBox[
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", "z", ",", "0"}], ")"}], 
              RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], "+", "1"}]}], "/;",
         
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", "z", ",", "0"}], ")"}], "+", "1"}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        FractionBox[
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}], 
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"]}], ")"}], "-", 
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "2"]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        FractionBox[
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], 
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{"log", "(", 
            RowBox[{"\[CapitalGamma]", "(", "z", ")"}], ")"}]}], "/;", 
        RowBox[{
          RowBox[{"0", "<", 
            RowBox[{"Re", "(", "z", ")"}], "\[LessEqual]", "2"}], "\[And]", 
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{"Im", "(", "z", ")"}], "\[RightBracketingBar]"}], 
            "\[LessEqual]", 
            FractionBox["7", "2"]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
              RowBox[{"k", "(", "z", ")"}]}], "+", 
            RowBox[{"log", "(", 
              RowBox[{"\[CapitalGamma]", "(", "z", ")"}], ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{
            RowBox[{"k", "(", "z", ")"}], "\[Equal]", 
            RowBox[{
              SubsuperscriptBox["\[Integral]", "0", "z"], 
              RowBox[{
                RowBox[{
                  InterpretationBox["\[Theta]",
                    UnitStep,
                    Editable->False,
                    Selectable->False], "(", 
                  RowBox[{"-", 
                    RowBox[{"Re", "(", 
                      RowBox[{"\[CapitalGamma]", "(", "t", ")"}], ")"}]}], 
                  ")"}], " ", 
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{"Im", "(", 
                    RowBox[{
                      RowBox[{"\[CapitalGamma]", "(", "t", ")"}], " ", 
                      RowBox[{
                        TagBox["\[Psi]",
                          PolyGamma], "(", "t", ")"}]}], ")"}], 
                  "\[RightBracketingBar]"}], " ", 
                RowBox[{
                  InterpretationBox["\[Delta]",
                    DiracDelta,
                    Editable->False,
                    Selectable->False], "(", 
                  RowBox[{"Im", "(", 
                    RowBox[{"\[CapitalGamma]", "(", "t", ")"}], ")"}], ")"}], 
                
                RowBox[{"\[DifferentialD]", "t"}]}]}]}], "\[Element]", 
          RowBox[{
            TagBox["\[DoubleStruckCapitalZ]",
              (Integers&)], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The best\[Hyphen]known properties and formulas for exponential \
integrals\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["Real values for real arguments", "Subsubsection"],

Cell[TextData[{
  "For real values of ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ", the values of the gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " are real (or infinity). For real values of the parameter ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  " and positive arguments ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  ", the values of the gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        FormBox[
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}],
          "TraditionalForm"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Q", 
          RowBox[{"(", 
            RowBox[{"a", ",", "z"}], ")"}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        FormBox[
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}],
          "TraditionalForm"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " are real (or infinity). "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simple values at zero", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        FormBox[
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}],
          "TraditionalForm"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Q", 
          RowBox[{"(", 
            RowBox[{"a", ",", "z"}], ")"}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        FormBox[
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}],
          "TraditionalForm"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " have the following values at zero arguments:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", "0", ")"}], "\[Equal]", 
        StyleBox[
          OverscriptBox["\[Infinity]", "~"],
          "Traditional"]}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"0", ",", "0"}], ")"}], "\[Equal]", 
        StyleBox[
          OverscriptBox["\[Infinity]", "~"],
          "Traditional"]}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"0", ",", "0", ",", "0"}], ")"}], "\[Equal]", 
        "\[DownQuestion]"}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"Q", "(", 
          RowBox[{"0", ",", "0"}], ")"}], "\[Equal]", 
        StyleBox["0",
          "Traditional"]}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"Q", "(", 
          RowBox[{"0", ",", "0", ",", "0"}], ")"}], "\[Equal]", "0"}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"log\[CapitalGamma]", "(", "0", ")"}], "\[Equal]", 
        StyleBox["\[Infinity]",
          "Traditional"]}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"0", ",", "0"}], ")"}], "\[Equal]", "0"}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"0", ",", "0", ",", "0"}], ")"}], "\[Equal]", "0."}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Specific values for specialized variables", "Subsubsection"],

Cell[TextData[{
  "If the variable ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  " is equal to ",
  Cell[BoxData[
      FormBox["0", TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"Re", 
            RowBox[{"(", "a", ")"}]}], ">", "0"}], TraditionalForm]]],
  ", the incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " coincides with the gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "a", ")"}], TraditionalForm]]],
  " and the corresponding regularized gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " is equal to ",
  Cell[BoxData[
      FormBox["1", TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                RowBox[{"\[CapitalGamma]", 
                  RowBox[{"(", 
                    RowBox[{"a", ",", "0"}], ")"}]}], "\[Equal]", 
                RowBox[{"\[CapitalGamma]", "(", "a", ")"}]}], "/;", 
              RowBox[{
                RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], 
                  RowBox[{"(", 
                    RowBox[{"a", ",", "0"}], ")"}]}], "\[Equal]", "1"}], "/;",
               
              RowBox[{
                RowBox[{"Re", "(", "a", ")"}], ">", "0."}]}]}
          }], TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "In the cases when the parameter ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  " equals ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", ",", "2", ",", "3", ",", "\[Ellipsis]"}], 
        TraditionalForm]]],
  ", the incomplete gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " can be expressed as an exponential function multiplied by a polynomial. \
In cases when the parameter ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  " equals ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "2"}], ",", "\[Ellipsis]"}], TraditionalForm]]],
  ", the incomplete gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " can be expressed with the exponential integral ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Ei", 
          RowBox[{"(", "z", ")"}]}], TraditionalForm]]],
  ", exponential, and logarithmic functions, but the regularized incomplete \
gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " is equal to ",
  Cell[BoxData[
      FormBox["0", TraditionalForm]]],
  ".  In the cases when the parameter ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  " equals ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[PlusMinus]", 
            FractionBox["1", "2"]}], ",", 
          RowBox[{"\[PlusMinus]", 
            FractionBox["3", "2"]}], ",", 
          RowBox[{"\[PlusMinus]", 
            FractionBox["5", "2"]}], ",", "\[Ellipsis]"}], 
        TraditionalForm]]],
  "the incomplete gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " can be expressed through complementary error function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"erfc", "(", "z", ")"}], TraditionalForm]]],
  " and exponential function. For example,"
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"\[CapitalGamma]", 
                RowBox[{"(", 
                  RowBox[{"1", ",", "z"}], ")"}]}], "\[Equal]", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]]}], 
            RowBox[{
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"(", 
                  RowBox[{"1", ",", "z"}], ")"}]}], "\[Equal]", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]]}]},
          {
            RowBox[{
              RowBox[{"\[CapitalGamma]", 
                RowBox[{"(", 
                  RowBox[{"0", ",", "z"}], ")"}]}], "\[Equal]", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"Ei", "(", 
                    RowBox[{"-", "z"}], ")"}]}], "+", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"log", "(", 
                        RowBox[{"-", "z"}], ")"}], "-", 
                      RowBox[{"log", "(", 
                        RowBox[{"-", 
                          FractionBox["1", "z"]}], ")"}]}], ")"}]}], "-", 
                RowBox[{"log", 
                  RowBox[{"(", "z", ")"}]}]}]}], 
            RowBox[{
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"(", 
                  RowBox[{"0", ",", "z"}], ")"}]}], "\[Equal]", "0"}]},
          {
            RowBox[{
              RowBox[{"\[CapitalGamma]", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], ",", "z"}], ")"}]}], "\[Equal]", 
              RowBox[{
                RowBox[{"Ei", "(", 
                  RowBox[{"-", "z"}], ")"}], "+", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"log", "(", 
                        RowBox[{"-", 
                          FractionBox["1", "z"]}], ")"}], "-", 
                      RowBox[{"log", "(", 
                        RowBox[{"-", "z"}], ")"}]}], ")"}]}], "+", 
                RowBox[{"log", "(", "z", ")"}], "+", 
                FractionBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", "z"}]], "z"]}]}], 
            RowBox[{
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], ",", "z"}], ")"}]}], "\[Equal]", 
              "0"}]},
          {
            RowBox[{
              RowBox[{"\[CapitalGamma]", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox["1", "2"], ",", "z"}], ")"}]}], "\[Equal]", 
              RowBox[{
                SqrtBox["\[Pi]"], " ", "erfc", 
                RowBox[{"(", 
                  SqrtBox["z"], ")"}]}]}], 
            RowBox[{
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox["1", "2"], ",", "z"}], ")"}]}], "\[Equal]", 
              " ", 
              RowBox[{"erfc", 
                RowBox[{"(", 
                  SqrtBox["z"]}]}]}]},
          {
            RowBox[{
              RowBox[{"\[CapitalGamma]", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox["1", "2"]}], ",", "z"}], ")"}]}], 
              "\[Equal]", 
              RowBox[{
                FractionBox[
                  RowBox[{"2", " ", 
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"-", "z"}]]}], 
                  SqrtBox["z"]], "-", 
                RowBox[{"2", " ", 
                  SqrtBox["\[Pi]"], " ", 
                  RowBox[{"erfc", "(", 
                    SqrtBox["z"], ")"}]}]}]}], 
            RowBox[{
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox["1", "2"]}], ",", "z"}], ")"}]}], 
              "\[Equal]", 
              RowBox[{
                RowBox[{"erfc", "(", 
                  SqrtBox["z"], ")"}], "-", 
                RowBox[{
                  FractionBox[
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"-", "z"}]], 
                    RowBox[{
                      SqrtBox["\[Pi]"], " ", 
                      SqrtBox["z"]}]], "."}]}]}]}
          }], TraditionalForm]], "TraditionalFormEquation"],

Cell["\<\
The above formulas are particular cases of the following general \
formulas:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"n", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"n", "-", "1"}]], " "}], 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"-", "n"}], ")"}], "!"}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"Ei", "(", 
                    RowBox[{"-", "z"}], ")"}], "-", 
                  RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"log", "(", 
                          RowBox[{"-", "z"}], ")"}], "-", 
                        RowBox[{"log", "(", 
                          RowBox[{"-", 
                            FractionBox["1", "z"]}], ")"}]}], ")"}]}], "+", 
                  RowBox[{"log", "(", "z", ")"}]}], ")"}]}], "+", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "0"}], 
                  RowBox[{"n", "-", "1"}]], 
                FractionBox[
                  SuperscriptBox["z", "k"], 
                  TagBox[
                    SubscriptBox[
                      RowBox[{"(", "n", ")"}], 
                      RowBox[{"k", "-", "n", "+", "1"}]],
                    Pochhammer]]}]}], "-", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "n"}], 
                  RowBox[{"-", "1"}]], 
                FractionBox[
                  SuperscriptBox["z", "k"], 
                  TagBox[
                    SubscriptBox[
                      RowBox[{"(", "n", ")"}], 
                      RowBox[{"k", "-", "n", "+", "1"}]],
                    Pochhammer]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          TagBox["\[DoubleStruckCapitalZ]",
            (Integers&)]}]}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{
              RowBox[{"n", "+", 
                FractionBox["1", "2"]}], ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              RowBox[{"erfc", "(", 
                SqrtBox["z"], ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"n", "+", 
                  FractionBox["1", "2"]}], ")"}]}], "+", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "0"}], 
                  RowBox[{"n", "-", "1"}]], 
                FractionBox[
                  SuperscriptBox["z", 
                    RowBox[{"k", "+", 
                      FractionBox["1", "2"]}]], 
                  TagBox[
                    SubscriptBox[
                      RowBox[{"(", 
                        RowBox[{"n", "+", 
                          FractionBox["1", "2"]}], ")"}], 
                      RowBox[{"k", "-", "n", "+", "1"}]],
                    Pochhammer]]}]}], "-", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "n"}], 
                  RowBox[{"-", "1"}]], 
                FractionBox[
                  SuperscriptBox["z", 
                    RowBox[{"k", "+", 
                      FractionBox["1", "2"]}]], 
                  TagBox[
                    SubscriptBox[
                      RowBox[{"(", 
                        RowBox[{"n", "+", 
                          FractionBox["1", "2"]}], ")"}], 
                      RowBox[{"k", "-", "n", "+", "1"}]],
                    Pochhammer]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          TagBox["\[DoubleStruckCapitalZ]",
            (Integers&)]}]}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"n", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", "z"}]], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], 
                RowBox[{"n", "-", "1"}]], 
              FractionBox[
                SuperscriptBox["z", "k"], 
                RowBox[{"k", "!"}]]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{
              RowBox[{"-", "n"}], ",", "z"}], ")"}], "\[Equal]", "0"}], "/;", 
        
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{
              RowBox[{"n", "+", 
                FractionBox["1", "2"]}], ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"erfc", "(", 
              SqrtBox["z"], ")"}], "+", 
            RowBox[{
              FractionBox["1", 
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{"n", "+", 
                    FractionBox["1", "2"]}], ")"}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"-", "z"}]], " ", 
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", 
                        RowBox[{"k", "=", "0"}], 
                        RowBox[{"n", "-", "1"}]], 
                      FractionBox[
                        SuperscriptBox["z", 
                          RowBox[{"k", "+", 
                            FractionBox["1", "2"]}]], 
                        TagBox[
                          SubscriptBox[
                            RowBox[{"(", 
                              RowBox[{"n", "+", 
                                FractionBox["1", "2"]}], ")"}], 
                            RowBox[{"k", "-", "n", "+", "1"}]],
                          Pochhammer]]}]}], "-", 
                  RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"-", "z"}]], " ", 
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", 
                        RowBox[{"k", "=", "n"}], 
                        RowBox[{"-", "1"}]], 
                      FractionBox[
                        SuperscriptBox["z", 
                          RowBox[{"k", "+", 
                            FractionBox["1", "2"]}]], 
                        TagBox[
                          SubscriptBox[
                            RowBox[{"(", 
                              RowBox[{"n", "+", 
                                FractionBox["1", "2"]}], ")"}], 
                            RowBox[{"k", "-", "n", "+", "1"}]],
                          Pochhammer]]}]}]}], ")"}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          RowBox[{
            TagBox["\[DoubleStruckCapitalZ]",
              (Integers&)], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "If the argument ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", ">", "0"}], TraditionalForm]]],
  ", the log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " coincides with logarithm of the gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ". That allows to evaluate its values in those points where the gamma \
function can be evaluated in closed form or recursively represent that values \
through values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"\[CapitalGamma]", "(", "z", ")"}]}], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", 
          RowBox[{"Re", 
            RowBox[{"(", "z", ")"}]}], "<", "1"}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"log\[CapitalGamma]", "(", "1", ")"}], "\[Equal]", 
        StyleBox["0",
          "Traditional"]}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "n", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{"log", "(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}], "!"}], ")"}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", 
              FractionBox["n", "2"], ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{"log", "(", 
            FractionBox[
              RowBox[{
                SuperscriptBox["2", 
                  RowBox[{"1", "-", "n"}]], " ", 
                SqrtBox["\[Pi]"], " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}], "!"}]}], 
              RowBox[{
                FractionBox[
                  RowBox[{"n", "-", "1"}], "2"], "!"}]], ")"}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", 
              RowBox[{"-", "n"}], ")"}],
            ScriptLevel->0], "\[Equal]", 
          StyleBox["\[Infinity]",
            "Traditional"]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"log\[CapitalGamma]", "(", 
            RowBox[{
              FractionBox["p", "q"], "+", "n"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"log", "(", 
              RowBox[{"\[CapitalGamma]", "(", 
                FractionBox["p", "q"], ")"}], ")"}], "-", 
            RowBox[{"n", " ", 
              RowBox[{"log", "(", "q", ")"}]}], "+", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "1"}], "n"], 
              RowBox[{"log", "(", 
                RowBox[{"p", "+", 
                  RowBox[{"k", " ", "q"}], "-", "q"}], ")"}]}]}]}], "/;", 
        RowBox[{
          RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}], "\[And]", 
          RowBox[{"p", "\[Element]", 
            SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}], "\[And]", 
          RowBox[{"q", "\[Element]", 
            TagBox[
              SuperscriptBox["\[DoubleStruckCapitalN]", "+"],
              (Integers&)]}], "\[And]", 
          RowBox[{"p", "<", "q"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"log\[CapitalGamma]", "(", 
            RowBox[{
              FractionBox["p", "q"], "-", "n"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"log", "(", 
              RowBox[{"\[CapitalGamma]", "(", 
                FractionBox["p", "q"], ")"}], ")"}], "+", 
            RowBox[{
              RowBox[{"log", "(", "q", ")"}], " ", "n"}], "-", 
            RowBox[{"\[Pi]", " ", "\[ImaginaryI]", " ", "n"}], "-", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "1"}], "n"], 
              RowBox[{"log", "(", 
                RowBox[{
                  RowBox[{"q", " ", "k"}], "-", "p"}], ")"}]}]}]}], "/;", 
        RowBox[{
          RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}], "\[And]", 
          RowBox[{"p", "\[Element]", 
            SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}], "\[And]", 
          RowBox[{"q", "\[Element]", 
            TagBox[
              SuperscriptBox["\[DoubleStruckCapitalN]", "+"],
              (Integers&)]}], "\[And]", 
          RowBox[{"p", "<", 
            RowBox[{"q", "."}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "The generalized incomplete gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " in particular cases can be represented through incomplete gamma functions \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and the gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "a", ")"}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", "0"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"]}], ")"}], "-", 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "0", ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "-", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "2"]}], ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", "\[Infinity]"}], ")"}], "\[Equal]", 
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"]}], ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "\[Infinity]", ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{"-", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "2"]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "0", ",", "\[Infinity]"}], ")"}], "\[Equal]", 
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{
              RowBox[{"-", "n"}], ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", "0"}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", "\[Infinity]"}], ")"}], "\[Equal]", 
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"]}], ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "0", ",", "\[Infinity]"}], ")"}], "\[Equal]", 
          "1"}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", "0"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"]}], ")"}], "-", "1"}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "0", ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{"1", "-", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "2"]}], ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "a", ")"}], ">", "0."}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "The inverse of the regularized incomplete gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " for particular values of arguments satisfy the following relations:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox[
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], 
              RowBox[{"-", "1"}]], "(", 
            RowBox[{"a", ",", "0"}], ")"}], "\[Equal]", "\[Infinity]"}], "/;",
         
        RowBox[{"a", ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox[
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], 
              RowBox[{"-", "1"}]], "(", 
            RowBox[{"a", ",", "1"}], ")"}], "\[Equal]", "0"}], "/;", 
        RowBox[{"a", ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "\[Infinity]", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], 
              RowBox[{"-", "1"}]], "(", 
            RowBox[{"a", ",", 
              RowBox[{"-", "z"}]}], ")"}], "."}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Analyticity", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " are defined for all complex values of their arguments.  "
}], "Text"],

Cell[TextData[{
  "The functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Q", 
          RowBox[{"(", 
            RowBox[{"a", ",", "z"}], ")"}]}], TraditionalForm]]],
  " are analytic functions of ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  " over the whole complex ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  "\[Hyphen] and ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "\[Hyphen]planes excluding the branch cut on the ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "\[Hyphen]plane. For fixed ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ", they are entire functions of ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  ". The functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " are analytic functions of ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  " over the whole complex ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  "\[Hyphen], ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  "\[Hyphen], and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  "\[Hyphen]planes excluding the branch cuts on the ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  "\[Hyphen] and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  "\[Hyphen]planes. For fixed ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  ", they are entire functions of ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", 
          StyleBox["z",
            "Traditional",
            FontFamily->"Times"], ")"}], TraditionalForm]]],
  " is an analytical function of ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  " over the whole complex ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "\[Hyphen]plane excluding the branch cut."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Poles and essential singularities", "Subsubsection"],

Cell[TextData[{
  "For fixed ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  ", the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Q", 
          RowBox[{"(", 
            RowBox[{"a", ",", "z"}], ")"}]}], TraditionalForm]]],
  " have an essential singularity at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "\[Equal]", 
          OverscriptBox["\[Infinity]", "~"]}], TraditionalForm]]],
  ". At the same time, the point ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "\[Equal]", 
          OverscriptBox["\[Infinity]", "~"]}], TraditionalForm]]],
  " is a branch point for generic ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  ". For fixed ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ", the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Q", 
          RowBox[{"(", 
            RowBox[{"a", ",", "z"}], ")"}]}], TraditionalForm]]],
  " have only one singular point at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          OverscriptBox["\[Infinity]", "~"]}], TraditionalForm]]],
  ".  It is an essential singularity. "
}], "Text"],

Cell[TextData[{
  "For fixed ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  ", the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " have an essential singularity at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["z", "1"], "\[Equal]", 
          OverscriptBox["\[Infinity]", "~"]}], TraditionalForm]]],
  " (for fixed ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  ") and at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["z", "2"], "\[Equal]", 
          OverscriptBox["\[Infinity]", "~"]}], TraditionalForm]]],
  " (for fixed ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  "). At the same time, the points ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox["z", "k"], "\[Equal]", 
              OverscriptBox["\[Infinity]", "~"]}], "/;", 
            RowBox[{"k", "\[Equal]", "1"}]}], ",", "2"}], TraditionalForm]]],
  " are branch points for generic ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  ". For fixed ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  ", the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " have only one singular point at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          OverscriptBox["\[Infinity]", "~"]}], TraditionalForm]]],
  ".  It is an essential singularity. "
}], "Text"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", 
          StyleBox["z",
            "Traditional"], ")"}], TraditionalForm]]],
  " does not have poles or essential singularities."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Branch points and branch cuts", "Subsubsection"],

Cell[TextData[{
  "For fixed ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  ", not a positive integer, the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Q", 
          RowBox[{"(", 
            RowBox[{"a", ",", "z"}], ")"}]}], TraditionalForm]]],
  " have two branch points: ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "\[Equal]", "0"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "\[Equal]", 
          OverscriptBox["\[Infinity]", "~"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "For fixed ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  ", not positive integer, the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Q", 
          RowBox[{"(", 
            RowBox[{"a", ",", "z"}], ")"}]}], TraditionalForm]]],
  " are single\[Hyphen]valued functions on the ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "\[Hyphen]plane cut along the interval ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "\[Infinity]"}], ",", " ", "0"}], ")"}], 
        TraditionalForm]]],
  ", where from above they are continuous:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                RowBox[{"x", "+", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]}], ")"}]}], 
          "\[Equal]", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "x"}], ")"}]}], "/;", 
        RowBox[{"x", "<", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                RowBox[{"x", "-", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]}], ")"}]}], 
          "\[Equal]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "-", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                  RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "\[Pi]", " ",
                   "a"}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "-", 
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", ",", "x"}], ")"}]}], ")"}]}]}]}], "/;", 
        RowBox[{"x", "<", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                RowBox[{"x", "+", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]}], ")"}]}], 
          "\[Equal]", 
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "x"}], ")"}]}], "/;", 
        RowBox[{"x", "<", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                RowBox[{"x", "-", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]}], ")"}]}], 
          "\[Equal]", 
          RowBox[{"1", "-", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                  RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "\[Pi]", " ",
                   "a"}]], " ", 
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  RowBox[{
                    InterpretationBox["Q",
                      GammaRegularized,
                      Editable->False,
                      Selectable->False], "(", 
                    RowBox[{"a", ",", "x"}], ")"}]}], ")"}]}]}]}], "/;", 
        RowBox[{"x", "<", "0."}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "For fixed ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ", the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Q", 
          RowBox[{"(", 
            RowBox[{"a", ",", "z"}], ")"}]}], TraditionalForm]]],
  " do not have branch points and branch cuts."
}], "Text"],

Cell[TextData[{
  "For fixed ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  "or fixed ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  "(with ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "\[NotElement]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}], 
        TraditionalForm]]],
  "), the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        FormBox[
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}],
          "TraditionalForm"], TraditionalForm]]],
  " have two branch points with respect to ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  "or ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  ": ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["z", "k"], "\[Equal]", "0"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["z", "k"], "\[Equal]", 
            OverscriptBox["\[Infinity]", "~"]}], ",", 
          RowBox[{"k", "=", "1"}], ",", "2"}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "For fixed ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  " and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "\[NotElement]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}], 
        TraditionalForm]]],
  ", the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        FormBox[
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}],
          "TraditionalForm"], TraditionalForm]]],
  " are single\[Hyphen]valued functions on the ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  "\[Hyphen]plane cut along the interval ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "\[Infinity]"}], ",", " ", "0"}], ")"}], 
        TraditionalForm]]],
  ", where from above they are continuous:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                RowBox[{
                  SubscriptBox["x", "2"], "+", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]}], ")"}]}], 
          "\[Equal]", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["x", "2"]}], ")"}]}], "/;", 
        RowBox[{
          SubscriptBox["x", "2"], "<", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                RowBox[{
                  SubscriptBox["x", "2"], "-", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]}], ")"}]}], 
          "\[Equal]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["x", "2"]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "\[Pi]", 
                      " ", "a"}]]}], ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["x", "2"], ",", "0"}], ")"}]}]}]}], "/;", 
        RowBox[{
          SubscriptBox["x", "2"], "<", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                RowBox[{
                  SubscriptBox["x", "2"], "+", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]}], ")"}]}], 
          "\[Equal]", 
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["x", "2"]}], ")"}]}], "/;", 
        RowBox[{
          SubscriptBox["x", "2"], "<", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                RowBox[{
                  SubscriptBox["x", "2"], "-", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]}], ")"}]}], 
          "\[Equal]", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["x", "2"]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "\[Pi]", 
                      " ", "a"}]]}], ")"}], " ", 
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["x", "2"], ",", "0"}], ")"}]}]}]}], "/;", 
        RowBox[{
          SubscriptBox["x", "2"], "<", "0."}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "For fixed ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  " and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "\[NotElement]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}], 
        TraditionalForm]]],
  ", the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        FormBox[
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}],
          "TraditionalForm"], TraditionalForm]]],
  " are single\[Hyphen]valued functions on the ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  "\[Hyphen]plane cut along the interval ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "\[Infinity]"}], ",", " ", "0"}], ")"}], 
        TraditionalForm]]],
  ", where from above they are continuous:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                RowBox[{
                  SubscriptBox["x", "1"], "+", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], "\[Equal]", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["x", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}]}], "/;", 
        RowBox[{
          SubscriptBox["x", "1"], "<", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                RowBox[{
                  SubscriptBox["x", "1"], "-", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], "\[Equal]", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "\[Pi]", 
                      " ", "a"}]]}], ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", "0", ",", 
                  SubscriptBox["x", "1"]}], ")"}]}], "+", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                SubscriptBox["x", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}]}], "/;", 
        RowBox[{
          SubscriptBox["x", "1"], "<", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                RowBox[{
                  SubscriptBox["x", "1"], "+", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], "\[Equal]", 
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["x", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}]}], "/;", 
        RowBox[{
          SubscriptBox["x", "1"], "<", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                RowBox[{
                  SubscriptBox["x", "1"], "-", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], "\[Equal]", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "\[Pi]", 
                      " ", "a"}]]}], ")"}], " ", 
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", 
                RowBox[{"a", ",", "0", ",", 
                  SubscriptBox["x", "1"]}], ")"}]}], "+", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["x", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}]}], "/;", 
        RowBox[{
          SubscriptBox["x", "1"], "<", "0."}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "For fixed ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  ", the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " do not have branch points and branch cuts."
}], "Text"],

Cell[TextData[{
  " The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"log\[CapitalGamma]", "(", 
            StyleBox["z",
              "Traditional",
              FontFamily->"Times"], ")"}]}], TraditionalForm]]],
  " has two branch points: ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "\[Equal]", "0"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", " ", "=", " ", 
          OverscriptBox["\[Infinity]", "~"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{"log\[CapitalGamma]", "(", 
              StyleBox["z",
                "Traditional",
                FontFamily->"Times"], ")"}],
            "TraditionalForm"]}], TraditionalForm]]],
  " is a single\[Hyphen]valued function on the ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  "\[Hyphen]plane cut along the interval ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "\[Infinity]"}], ",", " ", "0"}], ")"}], 
        TraditionalForm]]],
  ", where from above it is continuous."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{"log\[CapitalGamma]", "(", 
              RowBox[{"x", "+", 
                RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}]}], 
          "\[Equal]", 
          RowBox[{"log\[CapitalGamma]", "(", "x", ")"}]}], "/;", 
        RowBox[{"x", "<", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"\[Epsilon]", "\[Rule]", 
                RowBox[{"+", "0"}]}]], "\[ThinSpace]", 
            RowBox[{"log\[CapitalGamma]", "(", 
              RowBox[{"x", "-", 
                RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}]}], 
          "\[Equal]", 
          RowBox[{
            RowBox[{"log\[CapitalGamma]", "(", "x", ")"}], "-", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
              RowBox[{"\[LeftFloor]", "x", "\[RightFloor]"}]}]}]}], "/;", 
        RowBox[{"x", "<", "0."}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Periodicity", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", the log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", and their inverses ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " do not have periodicity."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Parity and symmetry", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", and the log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " have mirror symmetry (except on the branch cut intervals):"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{
              OverscriptBox["a", "_"], ",", 
              OverscriptBox["z", "_"]}], ")"}], "\[Equal]", 
          OverscriptBox[
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", "z"}], ")"}], "_"]}], "/;", 
        RowBox[{"z", "\[NotElement]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "\[Infinity]"}], ",", "0"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{
              OverscriptBox["a", "_"], ",", 
              OverscriptBox[
                SubscriptBox["z", "1"], "_"], ",", 
              OverscriptBox[
                SubscriptBox["z", "2"], "_"]}], ")"}], "\[Equal]", 
          OverscriptBox[
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}], "_"]}], "/;", 
        RowBox[{
          RowBox[{
            SubscriptBox["z", "1"], "\[NotElement]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "\[Infinity]"}], ",", "0"}], ")"}]}], "\[And]", 
          RowBox[{
            SubscriptBox["z", "2"], "\[NotElement]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "\[Infinity]"}], ",", "0"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{
              OverscriptBox["a", "_"], ",", 
              OverscriptBox["z", "_"]}], ")"}], "\[Equal]", 
          OverscriptBox[
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", "z"}], ")"}], "_"]}], "/;", 
        RowBox[{"z", "\[NotElement]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "\[Infinity]"}], ",", "0"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{
              OverscriptBox["a", "_"], ",", 
              OverscriptBox[
                SubscriptBox["z", "1"], "_"], ",", 
              OverscriptBox[
                SubscriptBox["z", "2"], "_"]}], ")"}], "\[Equal]", 
          OverscriptBox[
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}], "_"]}], "/;", 
        RowBox[{
          RowBox[{
            SubscriptBox["z", "1"], "\[NotElement]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "\[Infinity]"}], ",", "0"}], ")"}]}], "\[And]", 
          RowBox[{
            SubscriptBox["z", "2"], "\[NotElement]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "\[Infinity]"}], ",", "0"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"log\[CapitalGamma]", "(", 
            OverscriptBox["z", "_"], ")"}], "\[Equal]", 
          OverscriptBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], "_"]}], "/;", 
        RowBox[{"z", "\[NotElement]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "\[Infinity]"}], ",", "0"}], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell["Two of them have the following permutation symmetry:", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{"-", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "2"], ",", 
              SubscriptBox["z", "1"]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{"-", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "2"], ",", 
                SubscriptBox["z", "1"]}], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Series representations", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", the log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", and the inverse ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " have the following series expansions:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Proportional]", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "-", 
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox["z", "a"], " "}], "a"], 
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  FractionBox[
                    RowBox[{"a", " ", "z"}], 
                    RowBox[{"a", "+", "1"}]], "+", 
                  FractionBox[
                    RowBox[{"a", " ", 
                      SuperscriptBox["z", "2"]}], 
                    RowBox[{"2", " ", 
                      RowBox[{"(", 
                        RowBox[{"a", "+", "2"}], ")"}]}]], "-", 
                  "\[Ellipsis]"}], ")"}]}]}]}], "/;", 
        RowBox[{"(", 
          RowBox[{"z", "\[Rule]", "0"}], ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "-", 
          RowBox[{
            SuperscriptBox["z", "a"], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "\[Infinity]"], 
              FractionBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "z"}], ")"}], "k"], 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"a", "+", "k"}], ")"}], " ", 
                  RowBox[{"k", "!"}]}]]}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"n", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}], "!"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", "z"}]], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], 
                RowBox[{"n", "-", "1"}]], 
              FractionBox[
                SuperscriptBox["z", "k"], 
                RowBox[{"k", "!"}]]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{
              RowBox[{"-", "n"}], ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              FractionBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "n"], 
                RowBox[{"n", "!"}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    TagBox["\[Psi]",
                      PolyGamma], "(", 
                    RowBox[{"n", "+", "1"}], ")"}], "-", 
                  RowBox[{"log", "(", "z", ")"}]}], ")"}]}], "-", 
            RowBox[{
              SuperscriptBox["z", 
                RowBox[{"-", "n"}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  UnderscriptBox[
                    RowBox[{"k", "=", "0"}], 
                    RowBox[{"k", "\[NotEqual]", "n"}]], "\[Infinity]"], 
                FractionBox[
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "z"}], ")"}], "k"], 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"k", "-", "n"}], ")"}], " ", 
                    RowBox[{"k", "!"}]}]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Proportional]", 
          RowBox[{
            RowBox[{
              SubsuperscriptBox["z", "2", "a"], " ", 
              RowBox[{"(", 
                RowBox[{
                  FractionBox["1", "a"], "-", 
                  FractionBox[
                    SubscriptBox["z", "2"], 
                    RowBox[{"a", "+", "1"}]], "+", 
                  FractionBox[
                    SubsuperscriptBox["z", "2", "2"], 
                    RowBox[{"2", " ", 
                      RowBox[{"(", 
                        RowBox[{"a", "+", "2"}], ")"}]}]], "+", 
                  "\[Ellipsis]"}], ")"}]}], "-", 
            RowBox[{
              SubsuperscriptBox["z", "1", "a"], " ", 
              RowBox[{"(", 
                RowBox[{
                  FractionBox["1", "a"], "-", 
                  FractionBox[
                    SubscriptBox["z", "1"], 
                    RowBox[{"a", "+", "1"}]], "+", 
                  FractionBox[
                    SubsuperscriptBox["z", "1", "2"], 
                    RowBox[{"2", " ", 
                      RowBox[{"(", 
                        RowBox[{"a", "+", "2"}], ")"}]}]], "+", 
                  "\[Ellipsis]"}], ")"}]}]}]}], "/;", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["z", "1"], "\[Rule]", "0"}], ")"}], "\[And]", 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["z", "2"], "\[Rule]", "0"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox["z", "2", "a"], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "\[Infinity]"], 
              FractionBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", 
                      SubscriptBox["z", "2"]}], ")"}], "k"], 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"a", "+", "k"}], ")"}], " ", 
                  RowBox[{"k", "!"}]}]]}]}], "-", 
          RowBox[{
            SubsuperscriptBox["z", "1", "a"], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "\[Infinity]"], 
              FractionBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", 
                      SubscriptBox["z", "1"]}], ")"}], "k"], 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"a", "+", "k"}], ")"}], " ", 
                  RowBox[{"k", "!"}]}]]}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"n", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}], "!"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                      SubscriptBox["z", "1"]}]], " ", 
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"k", "=", "0"}], 
                      RowBox[{"n", "-", "1"}]], 
                    FractionBox[
                      SubsuperscriptBox["z", "1", "k"], 
                      RowBox[{"k", "!"}]]}]}], "-", 
                RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                      SubscriptBox["z", "2"]}]], " ", 
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"k", "=", "0"}], 
                      RowBox[{"n", "-", "1"}]], 
                    FractionBox[
                      SubsuperscriptBox["z", "2", "k"], 
                      RowBox[{"k", "!"}]]}]}]}], ")"}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{
              RowBox[{"-", "n"}], ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              FractionBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                  RowBox[{"n", "-", "1"}]], 
                RowBox[{"n", "!"}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"log", "(", 
                    SubscriptBox["z", "1"], ")"}], "-", 
                  RowBox[{"log", "(", 
                    SubscriptBox["z", "2"], ")"}]}], ")"}]}], "+", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                UnderscriptBox[
                  RowBox[{"k", "=", "0"}], 
                  RowBox[{"k", "\[NotEqual]", "n"}]], "\[Infinity]"], 
              FractionBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], "k"], 
                  RowBox[{"(", 
                    RowBox[{
                      SubsuperscriptBox["z", "2", 
                        RowBox[{"k", "-", "n"}]], "-", 
                      SubsuperscriptBox["z", "1", 
                        RowBox[{"k", "-", "n"}]]}], ")"}]}], 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"k", "-", "n"}], ")"}], " ", 
                  RowBox[{"k", "!"}]}]]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Proportional]", 
          RowBox[{"1", "-", 
            RowBox[{
              SuperscriptBox["z", "a"], " ", 
              RowBox[{"(", 
                RowBox[{
                  FractionBox["1", 
                    RowBox[{"\[CapitalGamma]", "(", 
                      RowBox[{"a", "+", "1"}], ")"}]], "-", 
                  FractionBox[
                    RowBox[{"a", " ", "z"}], 
                    RowBox[{"\[CapitalGamma]", "(", 
                      RowBox[{"a", "+", "2"}], ")"}]], "+", 
                  FractionBox[
                    RowBox[{"a", " ", 
                      RowBox[{"(", 
                        RowBox[{"a", "+", "1"}], ")"}], " ", 
                      SuperscriptBox["z", "2"]}], 
                    RowBox[{"2", " ", 
                      RowBox[{"\[CapitalGamma]", "(", 
                        RowBox[{"a", "+", "3"}], ")"}]}]], "-", 
                  "\[Ellipsis]"}], ")"}]}]}]}], "/;", 
        RowBox[{"(", 
          RowBox[{"z", "\[Rule]", "0"}], ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{"1", "-", 
          RowBox[{
            SuperscriptBox["z", "a"], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "\[Infinity]"], 
              FractionBox[
                RowBox[{
                  TagBox[
                    SubscriptBox[
                      RowBox[{"(", "a", ")"}], "k"],
                    Pochhammer], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "z"}], ")"}], "k"]}], 
                RowBox[{
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", "+", "k", "+", "1"}], ")"}], " ", 
                  RowBox[{"k", "!"}]}]]}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"n", ",", "z"}], ")"}], "\[Equal]", " ", 
          RowBox[{
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", "z"}]], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], 
                RowBox[{"n", "-", "1"}]], 
              FractionBox[
                SuperscriptBox["z", "k"], 
                RowBox[{"k", "!"}]]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Proportional]", 
          RowBox[{
            RowBox[{
              SubsuperscriptBox["z", "2", "a"], " ", 
              RowBox[{"(", 
                RowBox[{
                  FractionBox["1", 
                    RowBox[{"\[CapitalGamma]", "(", 
                      RowBox[{"a", "+", "1"}], ")"}]], "-", 
                  FractionBox[
                    RowBox[{"a", " ", 
                      SubscriptBox["z", "2"]}], 
                    RowBox[{"\[CapitalGamma]", "(", 
                      RowBox[{"a", "+", "2"}], ")"}]], "+", 
                  FractionBox[
                    RowBox[{"a", " ", 
                      RowBox[{"(", 
                        RowBox[{"a", "+", "1"}], ")"}], " ", 
                      SubsuperscriptBox["z", "2", "2"]}], 
                    RowBox[{"2", " ", 
                      RowBox[{"\[CapitalGamma]", "(", 
                        RowBox[{"a", "+", "3"}], ")"}]}]], "-", 
                  "\[Ellipsis]"}], ")"}]}], "-", 
            RowBox[{
              SubsuperscriptBox["z", "1", "a"], " ", 
              RowBox[{"(", 
                RowBox[{
                  FractionBox["1", 
                    RowBox[{"\[CapitalGamma]", "(", 
                      RowBox[{"a", "+", "1"}], ")"}]], "-", 
                  FractionBox[
                    RowBox[{"a", " ", 
                      SubscriptBox["z", "1"]}], 
                    RowBox[{"\[CapitalGamma]", "(", 
                      RowBox[{"a", "+", "2"}], ")"}]], "+", 
                  FractionBox[
                    RowBox[{"a", " ", 
                      RowBox[{"(", 
                        RowBox[{"a", "+", "1"}], ")"}], " ", 
                      SubsuperscriptBox["z", "1", "2"]}], 
                    RowBox[{"2", " ", 
                      RowBox[{"\[CapitalGamma]", "(", 
                        RowBox[{"a", "+", "3"}], ")"}]}]], "-", 
                  "\[Ellipsis]"}], ")"}]}]}]}], "/;", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["z", "1"], "\[Rule]", "0"}], ")"}], "\[And]", 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["z", "2"], "\[Rule]", "0"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox["z", "2", "a"], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "\[Infinity]"], 
              FractionBox[
                RowBox[{
                  TagBox[
                    SubscriptBox[
                      RowBox[{"(", "a", ")"}], "k"],
                    Pochhammer], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", 
                        SubscriptBox["z", "2"]}], ")"}], "k"]}], 
                RowBox[{
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", "+", "k", "+", "1"}], ")"}], " ", 
                  RowBox[{"k", "!"}]}]]}]}], "-", 
          RowBox[{
            SubsuperscriptBox["z", "1", "a"], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "\[Infinity]"], 
              FractionBox[
                RowBox[{
                  TagBox[
                    SubscriptBox[
                      RowBox[{"(", "a", ")"}], "k"],
                    Pochhammer], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", 
                        SubscriptBox["z", "1"]}], ")"}], "k"]}], 
                RowBox[{
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", "+", "k", "+", "1"}], ")"}], " ", 
                  RowBox[{"k", "!"}]}]]}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"n", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                  SubscriptBox["z", "1"]}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "0"}], 
                  RowBox[{"n", "-", "1"}]], 
                FractionBox[
                  SubsuperscriptBox["z", "1", "k"], 
                  RowBox[{"k", "!"}]]}]}], "-", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                  SubscriptBox["z", "2"]}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "0"}], 
                  RowBox[{"n", "-", "1"}]], 
                FractionBox[
                  SubsuperscriptBox["z", "2", "k"], 
                  RowBox[{"k", "!"}]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Proportional]", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"log", "(", "z", ")"}]}], "-", 
            RowBox[{
              TagBox["\[DoubledGamma]",
                (EulerGamma&)], " ", "z"}], "+", 
            FractionBox[
              RowBox[{
                SuperscriptBox["\[Pi]", "2"], " ", 
                SuperscriptBox["z", "2"]}], "12"], "-", 
            FractionBox[
              RowBox[{" ", 
                RowBox[{
                  TagBox[
                    RowBox[{"\[Zeta]", "(", 
                      TagBox["3",
                        (Editable -> True)], ")"}],
                    InterpretTemplate[ 
                      Function[ e, 
                        Zeta[ e]]]], " ", 
                  SuperscriptBox["z", "3"]}]}], "3"], "+", 
            FractionBox[
              RowBox[{
                SuperscriptBox["\[Pi]", "4"], " ", 
                SuperscriptBox["z", "4"]}], "360"], "-", "\[Ellipsis]"}]}], "/;",
         
        RowBox[{"(", 
          RowBox[{"z", "\[Rule]", "0"}], ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"log", "(", "z", ")"}]}], "-", 
            RowBox[{
              TagBox["\[DoubledGamma]",
                (EulerGamma&)], " ", "z"}], "+", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"j", "=", "0"}], "\[Infinity]"], 
              FractionBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], "j"], " ", 
                  TagBox[
                    RowBox[{"\[Zeta]", "(", 
                      TagBox[
                        RowBox[{"j", "+", "2"}],
                        (Editable -> True)], ")"}],
                    InterpretTemplate[ 
                      Function[ e, 
                        Zeta[ e]]]], " ", 
                  SuperscriptBox["z", 
                    RowBox[{"j", "+", "2"}]]}], 
                RowBox[{"j", "+", "2"}]]}]}]}], "/;", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], "<",
           "1"}]}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], "\[Proportional]", 
          RowBox[{
            RowBox[{"log\[CapitalGamma]", "(", 
              SubscriptBox["z", "0"], ")"}], "+", 
            RowBox[{
              RowBox[{
                TagBox["\[Psi]",
                  PolyGamma], "(", 
                SubscriptBox["z", "0"], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{"z", "-", 
                  SubscriptBox["z", "0"]}], ")"}]}], "+", 
            RowBox[{
              FractionBox[
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    RowBox[{
                      TagBox["2",
                        (Editable -> True)], ",", 
                      TagBox[
                        SubscriptBox["z", "0"],
                        (Editable -> True)]}], ")"}],
                  InterpretTemplate[ 
                    Function[ {e1, e2}, 
                      Zeta[ e1, e2]]]], "2"], "  ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"z", "-", 
                    SubscriptBox["z", "0"]}], ")"}], "2"]}], "-", 
            RowBox[{
              FractionBox[
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    RowBox[{
                      TagBox["3",
                        (Editable -> True)], ",", 
                      TagBox[
                        SubscriptBox["z", "0"],
                        (Editable -> True)]}], ")"}],
                  InterpretTemplate[ 
                    Function[ {e1, e2}, 
                      Zeta[ e1, e2]]]], "3"], "  ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"z", "-", 
                    SubscriptBox["z", "0"]}], ")"}], "3"]}], "+", 
            "\[Ellipsis]"}]}], "/;", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"z", "\[Rule]", 
              SubscriptBox["z", "0"]}], ")"}], "\[And]", 
          RowBox[{"\[Not]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SubscriptBox["z", "0"], "\[Element]", 
                  TagBox["\[DoubleStruckCapitalZ]",
                    (Integers&)]}], "\[And]", 
                RowBox[{
                  SubscriptBox["z", "0"], "\[LessEqual]", "0"}]}], 
              ")"}]}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{"log\[CapitalGamma]", "(", 
              SubscriptBox["z", "0"], ")"}], "+", 
            RowBox[{
              RowBox[{
                TagBox["\[Psi]",
                  PolyGamma], "(", 
                SubscriptBox["z", "0"], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{"z", "-", 
                  SubscriptBox["z", "0"]}], ")"}]}], "+", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "\[Infinity]"], 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"j", "=", "0"}], "\[Infinity]"], 
                FractionBox[
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", "1"}], ")"}], "j"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"z", "-", 
                          SubscriptBox["z", "0"]}], ")"}], 
                      RowBox[{"j", "+", "2"}]]}], 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"j", "+", "2"}], ")"}], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"k", "+", 
                          SubscriptBox["z", "0"]}], ")"}], 
                      RowBox[{"j", "+", "2"}]]}]]}]}]}]}], "/;", 
        RowBox[{"\[Not]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubscriptBox["z", "0"], "\[Element]", 
                TagBox["\[DoubleStruckCapitalZ]",
                  (Integers&)]}], "\[And]", 
              RowBox[{
                SubscriptBox["z", "0"], "\[LessEqual]", "0"}]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"log", "(", 
                RowBox[{"z", "+", "n"}], ")"}]}], "+", 
            RowBox[{
              StyleBox["log\[CapitalGamma]",
                ScriptLevel->0], 
              StyleBox["(",
                ScriptLevel->0], 
              RowBox[{"z", "+", "n", "+", "1"}], ")"}], "-", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], 
                RowBox[{"n", "-", "1"}]], 
              RowBox[{"log", "(", 
                RowBox[{"z", "+", "k"}], ")"}]}]}]}], "/;", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"z", "\[Rule]", 
              RowBox[{"-", "n"}]}], ")"}], "\[And]", 
          RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Proportional]", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"log", "(", 
                RowBox[{"z", "+", "n"}], ")"}]}], "-", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], 
                RowBox[{"n", "-", "1"}]], 
              RowBox[{
                RowBox[{"log", "(", 
                  RowBox[{"z", "+", "k"}], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{"1", "+", 
                    RowBox[{"O", "(", 
                      RowBox[{"z", "+", "n"}], ")"}]}], ")"}]}]}]}]}], "/;", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"z", "\[Rule]", 
              RowBox[{"-", "n"}]}], ")"}], "\[And]", 
          RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"(", 
                    RowBox[{"z", "-", "1"}], ")"}]}], " ", 
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{"a", "+", "1"}], ")"}]}], ")"}], 
            RowBox[{"1", "/", "a"}]], "+", 
          FractionBox[
            SuperscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", 
                        RowBox[{"(", 
                          RowBox[{"z", "-", "1"}], ")"}]}], " ", 
                      RowBox[{"\[CapitalGamma]", "(", 
                        RowBox[{"a", "+", "1"}], ")"}]}], ")"}], 
                  RowBox[{"1", "/", "a"}]], ")"}], "2"], 
            RowBox[{"a", "+", "1"}]], "+", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"3", " ", "a"}], "+", "5"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{"z", "-", "1"}], ")"}]}], " ", 
                        RowBox[{"\[CapitalGamma]", "(", 
                          RowBox[{"a", "+", "1"}], ")"}]}], ")"}], 
                    RowBox[{"1", "/", "a"}]], ")"}], "3"]}], 
            RowBox[{"2", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"a", "+", "1"}], ")"}], "2"], " ", 
              RowBox[{"(", 
                RowBox[{"a", "+", "2"}], ")"}]}]], "+", 
          RowBox[{
            RowBox[{"O", "(", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"z", "-", "1"}], ")"}], 
                RowBox[{"4", "/", "a"}]], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Asymptotic series expansions", "Subsubsection"],

Cell[TextData[{
  "The asymptotic behavior of the gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", the log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ", and the inverse ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " can be described by the following formulas (only the main terms of \
asymptotic expansion are given):"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Proportional]", 
          RowBox[{
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", "z"}]], " ", 
            SuperscriptBox["z", 
              RowBox[{"a", "-", "1"}]], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"O", "(", 
                  FractionBox["1", "z"], ")"}]}], ")"}]}]}], "/;", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], 
            "\[Rule]", "\[Infinity]"}], ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Proportional]", 
          RowBox[{
            FractionBox[
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", "z"}]], " ", 
                SuperscriptBox["z", 
                  RowBox[{"a", "-", "1"}]]}], 
              RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"O", "(", 
                  FractionBox["1", "z"], ")"}]}], ")"}]}]}], "/;", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], 
            "\[Rule]", "\[Infinity]"}], ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], "\[Proportional]", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"z", "-", 
                  FractionBox["1", "2"]}], ")"}], " ", 
              RowBox[{"log", "(", "z", ")"}]}], "-", "z", "+", 
            FractionBox[
              RowBox[{"log", "(", 
                RowBox[{"2", " ", "\[Pi]"}], ")"}], "2"], "+", 
            RowBox[{
              FractionBox["1", 
                RowBox[{"12", " ", "z"}]], 
              RowBox[{"(", 
                RowBox[{"1", "+", 
                  RowBox[{"O", "(", 
                    FractionBox["1", 
                      SuperscriptBox["z", "2"]], ")"}]}], ")"}]}]}]}], "/;", 
        RowBox[{
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{"Arg", "(", "z", ")"}], "\[RightBracketingBar]"}], "<", 
            "\[Pi]"}], "\[And]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], 
              "\[Rule]", "\[Infinity]"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox[
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], 
              RowBox[{"-", "1"}]], "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Proportional]", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", 
                RowBox[{"a", "-", "1"}], ")"}]}], " ", 
            RowBox[{
              SubscriptBox["W", 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"-", 
                FractionBox[
                  RowBox[{
                    SuperscriptBox["z", 
                      FractionBox["1", 
                        RowBox[{"a", "-", "1"}]]], " ", 
                    SuperscriptBox[
                      RowBox[{"\[CapitalGamma]", "(", "a", ")"}], 
                      FractionBox["1", 
                        RowBox[{"a", "-", "1"}]]]}], 
                  RowBox[{"a", "-", "1"}]]}], ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"z", "\[Rule]", "0"}], ")"}], "."}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Integral representations", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", and the log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " can also be represented through the following integrals:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          SubsuperscriptBox["\[Integral]", "z", "\[Infinity]"], 
          RowBox[{
            RowBox[{
              SuperscriptBox["t", 
                RowBox[{"a", "-", "1"}]], " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "t"}]]}], 
            RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          SubsuperscriptBox["\[Integral]", 
            SubscriptBox["z", "1"], 
            SubscriptBox["z", "2"]], 
          RowBox[{
            RowBox[{
              SuperscriptBox["t", 
                RowBox[{"a", "-", "1"}]], " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "t"}]]}], 
            RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], 
          RowBox[{
            SubsuperscriptBox["\[Integral]", "z", "\[Infinity]"], 
            RowBox[{
              RowBox[{
                SuperscriptBox["t", 
                  RowBox[{"a", "-", "1"}]], " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", "t"}]]}], 
              RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], 
          RowBox[{
            SubsuperscriptBox["\[Integral]", 
              SubscriptBox["z", "1"], 
              SubscriptBox["z", "2"]], 
            RowBox[{
              RowBox[{
                SuperscriptBox["t", 
                  RowBox[{"a", "-", "1"}]], " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", "t"}]]}], 
              RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{
                SubsuperscriptBox["\[Integral]", "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                RowBox[{
                  FractionBox[
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"-", "t"}]], "t"], 
                  RowBox[{"(", 
                    RowBox[{
                      FractionBox[
                        RowBox[{
                          SuperscriptBox["\[ExponentialE]", 
                            RowBox[{"t", " ", "z"}]], "-", "1"}], 
                        RowBox[{"1", "-", 
                          SuperscriptBox["\[ExponentialE]", 
                            RowBox[{"-", "t"}]]}]], "-", "z"}], ")"}], 
                  RowBox[{"\[DifferentialD]", "t"}]}]}]}], "+", 
            RowBox[{"log", "(", "\[Pi]", ")"}], "-", 
            RowBox[{"log", "(", 
              RowBox[{"sin", "(", 
                RowBox[{"\[Pi]", " ", "z"}], ")"}], ")"}]}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "z", ")"}], "<", "1"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]], 
            RowBox[{
              FractionBox["1", "t"], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"z", "-", "1"}], ")"}], 
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"-", "t"}]]}], "+", 
                  FractionBox[
                    RowBox[{
                      SuperscriptBox["\[ExponentialE]", 
                        RowBox[{
                          RowBox[{"-", "t"}], " ", "z"}]], "-", 
                      SuperscriptBox["\[ExponentialE]", 
                        RowBox[{"-", "t"}]]}], 
                    RowBox[{"1", "-", 
                      SuperscriptBox["\[ExponentialE]", 
                        RowBox[{"-", "t"}]]}]]}], ")"}], 
              RowBox[{"\[DifferentialD]", "t"}]}]}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "z", ")"}], ">", "0"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{
                SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
                RowBox[{
                  FractionBox[
                    RowBox[{
                      SuperscriptBox["tan", 
                        RowBox[{"-", "1"}]], "(", 
                      FractionBox["t", "z"], ")"}], 
                    RowBox[{
                      SuperscriptBox["\[ExponentialE]", 
                        RowBox[{"2", " ", "\[Pi]", " ", "t"}]], "-", "1"}]], 
                  RowBox[{"\[DifferentialD]", "t"}]}]}]}], "+", 
            FractionBox[
              RowBox[{"log", "(", 
                RowBox[{"2", " ", "\[Pi]"}], ")"}], "2"], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"z", "-", 
                  FractionBox["1", "2"]}], ")"}], " ", 
              RowBox[{"log", "(", "z", ")"}]}], "-", "z"}]}], "/;", 
        RowBox[{
          RowBox[{"Re", "(", "z", ")"}], ">", "0."}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Transformations", "Subsubsection"],

Cell[TextData[{
  "The argument of the log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", 
          RowBox[{"a", "-", "z"}], ")"}], TraditionalForm]]],
  " can be simplified if ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "\[Equal]", "1"}], TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox["0", TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", 
              RowBox[{"1", "-", "z"}], ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            RowBox[{"log", "(", "\[Pi]", ")"}], "-", 
            RowBox[{"log", "(", 
              RowBox[{"sin", "(", 
                RowBox[{"\[Pi]", " ", "z"}], ")"}], ")"}], "-", 
            StyleBox[
              RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
              ScriptLevel->0]}]}], "/;", 
        RowBox[{
          RowBox[{"-", 
            FractionBox["1", "2"]}], "\[LessEqual]", 
          RowBox[{"Re", "(", "z", ")"}], "<", 
          FractionBox["\[Pi]", "2"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", 
              RowBox[{"1", "-", "z"}], ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            RowBox[{"log", "(", "\[Pi]", ")"}], "-", 
            RowBox[{"log", "(", 
              RowBox[{"sin", "(", 
                RowBox[{"\[Pi]", " ", "z"}], ")"}], ")"}], "-", 
            StyleBox[
              RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
              ScriptLevel->0], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
              RowBox[{"\[LeftFloor]", 
                FractionBox[
                  RowBox[{
                    RowBox[{"2", " ", 
                      RowBox[{"Re", "(", "z", ")"}]}], "+", "1"}], "4"], 
                "\[RightFloor]"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sgn", "(", 
                    RowBox[{"Im", "(", "z", ")"}], ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"sgn", "(", 
                            RowBox[{"Im", "(", "z", ")"}], ")"}], "2"], "-", 
                        "1"}], ")"}], " ", 
                    RowBox[{"sgn", "(", 
                      RowBox[{"Re", "(", "z", ")"}], ")"}]}]}], ")"}]}]}]}], "/;",
         
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{"2", " ", 
                RowBox[{"Re", "(", "z", ")"}]}], "+", "1"}], "4"], 
          "\[NotElement]", 
          TagBox["\[DoubleStruckCapitalZ]",
            (Integers&)]}]}], TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", 
              RowBox[{"-", "z"}], ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            RowBox[{"log", "(", "\[Pi]", ")"}], "-", 
            RowBox[{"log", "(", 
              RowBox[{"-", "z"}], ")"}], "-", 
            RowBox[{"log", "(", 
              RowBox[{"sin", "(", 
                RowBox[{"\[Pi]", " ", "z"}], ")"}], ")"}], "-", 
            StyleBox[
              RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
              ScriptLevel->0]}]}], "/;", 
        RowBox[{
          RowBox[{"-", 
            FractionBox["1", "2"]}], "\[LessEqual]", 
          RowBox[{"Re", "(", "z", ")"}], "<", 
          FractionBox["\[Pi]", "2"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", 
              RowBox[{"-", "z"}], ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            RowBox[{"log", "(", "\[Pi]", ")"}], "-", 
            RowBox[{"log", "(", 
              RowBox[{"-", "z"}], ")"}], "-", 
            RowBox[{"log", "(", 
              RowBox[{"sin", "(", 
                RowBox[{"\[Pi]", " ", "z"}], ")"}], ")"}], "-", 
            StyleBox[
              RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
              ScriptLevel->0], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
              RowBox[{"\[LeftFloor]", 
                FractionBox[
                  RowBox[{
                    RowBox[{"2", " ", 
                      RowBox[{"Re", "(", "z", ")"}]}], "+", "1"}], "4"], 
                "\[RightFloor]"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sgn", "(", 
                    RowBox[{"Im", "(", "z", ")"}], ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"sgn", "(", 
                            RowBox[{"Im", "(", "z", ")"}], ")"}], "2"], "-", 
                        "1"}], ")"}], " ", 
                    RowBox[{"sgn", "(", 
                      RowBox[{"Re", "(", "z", ")"}], ")"}]}]}], ")"}]}]}]}], "/;",
         
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{"2", " ", 
                RowBox[{"Re", "(", "z", ")"}]}], "+", "1"}], "4"], 
          "\[NotElement]", 
          RowBox[{
            TagBox["\[DoubleStruckCapitalZ]",
              (Integers&)], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple arguments", "Subsubsection"],

Cell[TextData[{
  "The log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", 
          RowBox[{"m", " ", "z"}], ")"}], TraditionalForm]]],
  " with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"m", "\[Equal]", "2"}], ",", "3", ",", "\[Ellipsis]"}], 
        TraditionalForm]]],
  " can be represented by a formula that follows from the corresponding \
multiplication formula for the gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          RowBox[{"log\[CapitalGamma]", "(", 
            RowBox[{"2", "z"}], ")"}],
          ScriptLevel->0], "\[Equal]", 
        RowBox[{
          RowBox[{
            StyleBox["log\[CapitalGamma]",
              ScriptLevel->0], 
            StyleBox["(",
              ScriptLevel->0], 
            RowBox[{"z", "+", 
              FractionBox["1", "2"]}], ")"}], "+", 
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"2", " ", "z"}], "-", "1"}], ")"}], " ", 
            RowBox[{"log", "(", "2", ")"}]}], "-", 
          FractionBox[
            RowBox[{"log", "(", "\[Pi]", ")"}], "2"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"log\[CapitalGamma]", "(", 
            RowBox[{"m", " ", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], 
                RowBox[{"m", "-", "1"}]], 
              RowBox[{"log\[CapitalGamma]", "(", 
                RowBox[{"z", "+", 
                  FractionBox["k", "m"]}], ")"}]}], "+", 
            RowBox[{"m", " ", "z", " ", 
              RowBox[{"log", "(", "m", ")"}]}], "-", 
            RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"log", "(", "m", ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"m", "-", "1"}], ")"}], " ", "log", 
                    RowBox[{"(", 
                      RowBox[{"2", " ", "\[Pi]"}], ")"}]}]}], ")"}]}]}]}], "/;",
         
        RowBox[{"m", "\[Element]", 
          RowBox[{
            SuperscriptBox["\[DoubleStruckCapitalN]", "+"], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", and the log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " satisfy the following recurrence identities:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          FractionBox["1", "a"], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{
                  RowBox[{"a", "+", "1"}], ",", "z"}], ")"}], "-", 
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", "z"}]], " ", 
                SuperscriptBox["z", "a"]}]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "1"}], ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{
                RowBox[{"a", "-", "1"}], ",", "z"}], ")"}]}], "+", 
          RowBox[{
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", "z"}]], " ", 
            SuperscriptBox["z", 
              RowBox[{"a", "-", "1"}]]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          FractionBox["1", "a"], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{
                  RowBox[{"a", "+", "1"}], ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}], "-", 
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    SubscriptBox["z", "1"]}]], " ", 
                SubsuperscriptBox["z", "1", "a"]}], "+", 
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    SubscriptBox["z", "2"]}]], " ", 
                SubsuperscriptBox["z", "2", "a"]}]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "1"}], ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{
                RowBox[{"a", "-", "1"}], ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], "+", 
          RowBox[{
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
                SubscriptBox["z", "1"]}]], " ", 
            SubsuperscriptBox["z", "1", 
              RowBox[{"a", "-", "1"}]]}], "-", 
          RowBox[{
            SubsuperscriptBox["z", "2", 
              RowBox[{"a", "-", "1"}]], " ", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
                SubscriptBox["z", "2"]}]]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{
              RowBox[{"a", "+", "1"}], ",", "z"}], ")"}], "-", 
          FractionBox[
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]], " ", 
              SuperscriptBox["z", "a"]}], 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", "+", "1"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{
              RowBox[{"a", "-", "1"}], ",", "z"}], ")"}], "+", 
          FractionBox[
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]], " ", 
              SuperscriptBox["z", 
                RowBox[{"a", "-", "1"}]]}], 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{
              RowBox[{"a", "+", "1"}], ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "+", 
          FractionBox[
            RowBox[{
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    SubscriptBox["z", "2"]}]], " ", 
                SubsuperscriptBox["z", "2", "a"]}], "-", 
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    SubscriptBox["z", "1"]}]], " ", 
                SubsuperscriptBox["z", "1", "a"]}]}], 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", "+", "1"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{
              RowBox[{"a", "-", "1"}], ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "+", 
          FractionBox[
            RowBox[{
              RowBox[{
                SubsuperscriptBox["z", "1", 
                  RowBox[{"a", "-", "1"}]], " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    SubscriptBox["z", "1"]}]]}], "-", 
              RowBox[{
                SubsuperscriptBox["z", "2", 
                  RowBox[{"a", "-", "1"}]], " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    SubscriptBox["z", "2"]}]]}]}], 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
          ScriptLevel->0], "\[Equal]", 
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", 
              RowBox[{"z", "+", "1"}], ")"}],
            ScriptLevel->0], "-", 
          RowBox[{"log", "(", "z", ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
          ScriptLevel->0], "\[Equal]", 
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", 
              RowBox[{"z", "-", "1"}], ")"}],
            ScriptLevel->0], "+", 
          RowBox[{
            RowBox[{"log", "(", 
              RowBox[{"z", "-", "1"}], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell["\<\
The above formulas can be generalized to the following recurrence \
identities with jump of length n:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              FractionBox["1", 
                TagBox[
                  SubscriptBox[
                    RowBox[{"(", "a", ")"}], "n"],
                  Pochhammer]], 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{
                  RowBox[{"a", "+", "n"}], ",", "z"}], ")"}]}], "-", 
            RowBox[{
              SuperscriptBox["z", 
                RowBox[{"a", "-", "1"}]], " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "1"}], "n"], 
                FractionBox[
                  SuperscriptBox["z", "k"], 
                  TagBox[
                    SubscriptBox[
                      RowBox[{"(", "a", ")"}], "k"],
                    Pochhammer]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "n"], " ", 
            TagBox[
              SubscriptBox[
                RowBox[{"(", 
                  RowBox[{"1", "-", "a"}], ")"}], "n"],
              Pochhammer], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{
                    RowBox[{"a", "-", "n"}], ",", "z"}], ")"}], "+", 
                RowBox[{
                  SuperscriptBox["z", 
                    RowBox[{"a", "-", "n", "-", "1"}]], 
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", "z"}]], " ", 
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"k", "=", "1"}], "n"], 
                    FractionBox[
                      SuperscriptBox["z", "k"], 
                      TagBox[
                        SubscriptBox[
                          RowBox[{"(", 
                            RowBox[{"a", "-", "n"}], ")"}], "k"],
                        Pochhammer]]}]}]}], ")"}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              FractionBox["1", 
                TagBox[
                  SubscriptBox[
                    RowBox[{"(", "a", ")"}], "n"],
                  Pochhammer]], 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{
                  RowBox[{"a", "+", "n"}], ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], "-", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                  SubscriptBox["z", "1"]}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "1"}], "n"], 
                FractionBox[
                  SubsuperscriptBox["z", "1", 
                    RowBox[{"a", "+", "k", "-", "1"}]], 
                  TagBox[
                    SubscriptBox[
                      RowBox[{"(", "a", ")"}], "k"],
                    Pochhammer]]}]}], "+", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                  SubscriptBox["z", "2"]}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "1"}], "n"], 
                FractionBox[
                  SubsuperscriptBox["z", "2", 
                    RowBox[{"a", "+", "k", "-", "1"}]], 
                  TagBox[
                    SubscriptBox[
                      RowBox[{"(", "a", ")"}], "k"],
                    Pochhammer]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "n"], " ", 
            TagBox[
              SubscriptBox[
                RowBox[{"(", 
                  RowBox[{"1", "-", "a"}], ")"}], "n"],
              Pochhammer], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{
                    RowBox[{"a", "-", "n"}], ",", 
                    SubscriptBox["z", "1"], ",", 
                    SubscriptBox["z", "2"]}], ")"}], "+", 
                RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                      SubscriptBox["z", "1"]}]], " ", 
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"k", "=", "1"}], "n"], 
                    FractionBox[
                      SubsuperscriptBox["z", "1", 
                        RowBox[{"a", "+", "k", "-", "n", "-", "1"}]], 
                      TagBox[
                        SubscriptBox[
                          RowBox[{"(", 
                            RowBox[{"a", "-", "n"}], ")"}], "k"],
                        Pochhammer]]}]}], "-", 
                RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"-", 
                      SubscriptBox["z", "2"]}]], " ", 
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"k", "=", "1"}], "n"], 
                    FractionBox[
                      SubsuperscriptBox["z", "2", 
                        RowBox[{"a", "+", "k", "-", "n", "-", "1"}]], 
                      TagBox[
                        SubscriptBox[
                          RowBox[{"(", 
                            RowBox[{"a", "-", "n"}], ")"}], "k"],
                        Pochhammer]]}]}]}], ")"}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{
                RowBox[{"a", "+", "n"}], ",", "z"}], ")"}], "-", 
            RowBox[{
              SuperscriptBox["z", 
                RowBox[{"a", "-", "1"}]], " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "1"}], "n"], 
                FractionBox[
                  SuperscriptBox["z", "k"], 
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", "+", "k"}], ")"}]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", "z"}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{
                RowBox[{"a", "-", "n"}], ",", "z"}], ")"}], "+", 
            RowBox[{
              SuperscriptBox["z", 
                RowBox[{"a", "-", "1"}]], " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "0"}], 
                  RowBox[{"n", "-", "1"}]], 
                FractionBox[
                  SuperscriptBox["z", 
                    RowBox[{"-", "k"}]], 
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", "-", "k"}], ")"}]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{
                RowBox[{"a", "+", "n"}], ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}], "-", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                  SubscriptBox["z", "1"]}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "1"}], "n"], 
                FractionBox[
                  SubsuperscriptBox["z", "1", 
                    RowBox[{"a", "+", "k", "-", "1"}]], 
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", "+", "k"}], ")"}]]}]}], "+", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                  SubscriptBox["z", "2"]}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "1"}], "n"], 
                FractionBox[
                  SubsuperscriptBox["z", "2", 
                    RowBox[{"a", "+", "k", "-", "1"}]], 
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", "+", "k"}], ")"}]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], "(", 
            RowBox[{"a", ",", 
              SubscriptBox["z", "1"], ",", 
              SubscriptBox["z", "2"]}], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{
                RowBox[{"a", "-", "n"}], ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}], "+", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                  SubscriptBox["z", "1"]}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "0"}], 
                  RowBox[{"n", "-", "1"}]], 
                FractionBox[
                  SubsuperscriptBox["z", "1", 
                    RowBox[{"a", "-", "k", "-", "1"}]], 
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", "-", "k"}], ")"}]]}]}], "-", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                  SubscriptBox["z", "2"]}]], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "0"}], 
                  RowBox[{"n", "-", "1"}]], 
                FractionBox[
                  SubsuperscriptBox["z", "2", 
                    RowBox[{"a", "-", "k", "-", "1"}]], 
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", "-", "k"}], ")"}]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            StyleBox[
              RowBox[{"log\[CapitalGamma]", "(", 
                RowBox[{"z", "+", "n"}], ")"}],
              ScriptLevel->0], "-", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], 
                RowBox[{"n", "-", "1"}]], 
              RowBox[{"log", "(", 
                RowBox[{"z", "+", "k"}], ")"}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
            ScriptLevel->0], "\[Equal]", 
          RowBox[{
            StyleBox[
              RowBox[{"log\[CapitalGamma]", "(", 
                RowBox[{"z", "-", "n"}], ")"}],
              ScriptLevel->0], "+", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "1"}], "n"], 
              RowBox[{"log", "(", 
                RowBox[{"z", "-", "k"}], ")"}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          RowBox[{"\[DoubleStruckCapitalN]", "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Representations of derivatives", "Subsubsection"],

Cell[TextData[{
  "The derivatives of the gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " with respect to the variables ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  " have simple representations in terms of elementary functions:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", "z"}], ")"}]}], 
          RowBox[{"\[PartialD]", "z"}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          RowBox[{"-", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", "z"}]]}], " ", 
          SuperscriptBox["z", 
            RowBox[{"a", "-", "1"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], 
          RowBox[{"\[PartialD]", 
            SubscriptBox["z", "1"]}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          RowBox[{"-", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
                SubscriptBox["z", "1"]}]]}], " ", 
          SubsuperscriptBox["z", "1", 
            RowBox[{"a", "-", "1"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], 
          RowBox[{"\[PartialD]", 
            SubscriptBox["z", "2"]}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
              SubscriptBox["z", "2"]}]], " ", 
          SubsuperscriptBox["z", "2", 
            RowBox[{"a", "-", "1"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", "z"}], ")"}]}], 
          RowBox[{"\[PartialD]", "z"}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "z"}]], " ", 
              SuperscriptBox["z", 
                RowBox[{"a", "-", "1"}]]}], 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], 
          RowBox[{"\[PartialD]", 
            SubscriptBox["z", "1"]}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                  SubscriptBox["z", "1"]}]], " ", 
              SubsuperscriptBox["z", "1", 
                RowBox[{"a", "-", "1"}]]}], 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], 
          RowBox[{"\[PartialD]", 
            SubscriptBox["z", "2"]}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                  SubscriptBox["z", "2"]}]], " ", 
              SubsuperscriptBox["z", "2", 
                RowBox[{"a", "-", "1"}]]}], 
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], "."}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "The derivatives of the log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " and the inverses of the regularized incomplete gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " with respect to the variables ",
  Cell[BoxData[
      FormBox["z", TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "1"], TraditionalForm]]],
  ",and  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["z", "2"], TraditionalForm]]],
  " have more complicated representations by the formulas:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"\[PartialD]", 
              StyleBox["log\[CapitalGamma]",
                ScriptLevel->0]}], 
            StyleBox[
              RowBox[{"(", "z", ")"}],
              ScriptLevel->0]}], 
          RowBox[{"\[PartialD]", "z"}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          TagBox["\[Psi]",
            PolyGamma], "(", "z", ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", "z"}], ")"}]}], 
          RowBox[{"\[PartialD]", "z"}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          RowBox[{"-", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                SuperscriptBox[
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], 
                  RowBox[{"-", "1"}]], "(", 
                RowBox[{"a", ",", "z"}], ")"}]]}], " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", "z"}], ")"}], 
            RowBox[{"1", "-", "a"}]], " ", 
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], 
          RowBox[{"\[PartialD]", 
            SubscriptBox["z", "1"]}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], 
                  RowBox[{"-", "1"}]], "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}], "-", 
              SubscriptBox["z", "1"]}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              FractionBox[
                RowBox[{
                  SuperscriptBox[
                    InterpretationBox["Q",
                      GammaRegularized,
                      Editable->False,
                      Selectable->False], 
                    RowBox[{"-", "1"}]], "(", 
                  RowBox[{"a", ",", 
                    SubscriptBox["z", "1"], ",", 
                    SubscriptBox["z", "2"]}], ")"}], 
                SubscriptBox["z", "1"]], ")"}], 
            RowBox[{"1", "-", "a"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], 
          RowBox[{"\[PartialD]", 
            SubscriptBox["z", "2"]}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]], " ", 
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
          RowBox[{
            SuperscriptBox[
              RowBox[{
                SuperscriptBox[
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], 
                  RowBox[{"-", "1"}]], "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}], 
              RowBox[{"1", "-", "a"}]], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "The derivative of the exponential integral ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            TagBox["E",
              ExpIntegralE], "\[Nu]"], "(", "z", ")"}], TraditionalForm]]],
  " by its parameterr ",
  Cell[BoxData[
      FormBox["\[Nu]", TraditionalForm]]],
  " can be represented in terms of the regularized hypergeometric function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[InvisiblePrefixScriptBase]", 
            FormBox["2",
              "TraditionalForm"]], 
          SubscriptBox[
            OverscriptBox["F", "~"], 
            FormBox["2",
              "TraditionalForm"]]}], TraditionalForm]],
    GridBoxOptions->{ColumnAlignments->{Left}}],
  ":"
}], "Text"],

Cell[TextData[{
  "The derivatives of the gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", and their inverses ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " with respect to the parameter ",
  Cell[BoxData[
      FormBox["a", TraditionalForm]]],
  " can be represented in terms of the regularized hypergeometric function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[InvisiblePrefixScriptBase]", 
            FormBox["2",
              "TraditionalForm"]], 
          SubscriptBox[
            OverscriptBox["F", "~"], 
            FormBox["2",
              "TraditionalForm"]]}], TraditionalForm]],
    GridBoxOptions->{ColumnAlignments->{Left}}],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", "z"}], ")"}]}], 
          RowBox[{"\[PartialD]", "a"}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "2"], " ", 
            SuperscriptBox["z", "a"], 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox[
                      OverscriptBox["F", "~"], 
                      FormBox["2",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"-", "z"}],
                        HypergeometricPFQRegularized,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQRegularized[ #, #2, #3]&],
                
                Editable->False],
              HypergeometricPFQRegularized]}], "-", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", "0", ",", "z"}], ")"}], " ", 
            RowBox[{"log", "(", "z", ")"}]}], "+", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
            RowBox[{
              TagBox["\[Psi]",
                PolyGamma], "(", "a", ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], 
          RowBox[{"\[PartialD]", "a"}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "2"], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox[
                      OverscriptBox["F", "~"], 
                      FormBox["2",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"-", 
                          SubscriptBox["z", "1"]}],
                        HypergeometricPFQRegularized,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQRegularized[ #, #2, #3]&],
                
                Editable->False],
              HypergeometricPFQRegularized], " ", 
            SubsuperscriptBox["z", "1", "a"]}], "-", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "2"], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox[
                      OverscriptBox["F", "~"], 
                      FormBox["2",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"-", 
                          SubscriptBox["z", "2"]}],
                        HypergeometricPFQRegularized,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQRegularized[ #, #2, #3]&],
                
                Editable->False],
              HypergeometricPFQRegularized], " ", 
            SubsuperscriptBox["z", "2", "a"]}], "-", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", "0", ",", 
                SubscriptBox["z", "1"]}], ")"}], " ", 
            RowBox[{"log", "(", 
              SubscriptBox["z", "1"], ")"}]}], "+", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"a", ",", "0", ",", 
                SubscriptBox["z", "2"]}], ")"}], " ", 
            RowBox[{"log", "(", 
              SubscriptBox["z", "2"], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", "z"}], ")"}]}], 
          RowBox[{"\[PartialD]", "a"}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], 
            SuperscriptBox["z", "a"], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox[
                      OverscriptBox["F", "~"], 
                      FormBox["2",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"-", "z"}],
                        HypergeometricPFQRegularized,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQRegularized[ #, #2, #3]&],
                
                Editable->False],
              HypergeometricPFQRegularized]}], " ", "+", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", "z", ",", "0"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"log", "(", "z", ")"}], "-", 
                RowBox[{
                  TagBox["\[Psi]",
                    PolyGamma], "(", "a", ")"}]}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], 
          RowBox[{"\[PartialD]", "a"}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], 
            SubsuperscriptBox["z", "1", "a"], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox[
                      OverscriptBox["F", "~"], 
                      FormBox["2",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"-", 
                          SubscriptBox["z", "1"]}],
                        HypergeometricPFQRegularized,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQRegularized[ #, #2, #3]&],
                
                Editable->False],
              HypergeometricPFQRegularized]}], " ", "-", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], 
            SubsuperscriptBox["z", "2", "a"], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox[
                      OverscriptBox["F", "~"], 
                      FormBox["2",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox["a",
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"a", "+", "1"}],
                              HypergeometricPFQRegularized,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        HypergeometricPFQRegularized,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"-", 
                          SubscriptBox["z", "2"]}],
                        HypergeometricPFQRegularized,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQRegularized[ #, #2, #3]&],
                
                Editable->False],
              HypergeometricPFQRegularized]}], "+", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", "0"}], ")"}], " ", 
            RowBox[{"log", "(", 
              SubscriptBox["z", "1"], ")"}]}], "-", 
          RowBox[{
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "2"], ",", "0"}], ")"}], " ", 
            RowBox[{"log", "(", 
              SubscriptBox["z", "2"], ")"}]}], "-", 
          RowBox[{
            RowBox[{
              TagBox["\[Psi]",
                PolyGamma], "(", "a", ")"}], " ", 
            RowBox[{
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{"\[PartialD]", 
              RowBox[{
                SuperscriptBox[
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], 
                  RowBox[{"-", "1"}]], "(", 
                RowBox[{"a", ",", "z"}], ")"}]}], 
            RowBox[{"\[PartialD]", "a"}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            SuperscriptBox["\[ExponentialE]", "w"], " ", 
            SuperscriptBox["w", 
              RowBox[{"1", "-", "a"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "2"], " ", 
                  TagBox[
                    TagBox[
                      RowBox[{
                        RowBox[{
                          SubscriptBox["\[InvisiblePrefixScriptBase]", 
                            FormBox["2",
                              "TraditionalForm"]], 
                          SubscriptBox[
                            OverscriptBox["F", "~"], 
                            FormBox["2",
                              "TraditionalForm"]]}], 
                        "\[InvisibleApplication]", 
                        RowBox[{"(", 
                          RowBox[{
                            TagBox[
                              TagBox[
                                RowBox[{
                                  TagBox["a",
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox["a",
                                    HypergeometricPFQRegularized,
                                    Editable->True]}],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->False], ";", 
                            TagBox[
                              TagBox[
                                RowBox[{
                                  TagBox[
                                    RowBox[{"a", "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    RowBox[{"a", "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True]}],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->False], ";", 
                            TagBox[
                              RowBox[{"-", "w"}],
                              HypergeometricPFQRegularized,
                              Editable->True]}], ")"}]}],
                      InterpretTemplate[ 
                      HypergeometricPFQRegularized[ #, #2, #3]&],
                      Editable->False],
                    HypergeometricPFQRegularized], " ", 
                  SuperscriptBox["w", "a"]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"z", "-", "1"}], ")"}], " ", 
                  RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
                  RowBox[{"log", "(", "w", ")"}]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "-", 
                      RowBox[{"\[CapitalGamma]", "(", 
                        RowBox[{"a", ",", "w"}], ")"}]}], ")"}], " ", 
                  RowBox[{
                    TagBox["\[Psi]",
                      PolyGamma], "(", "a", ")"}]}]}], ")"}]}]}], "/;", 
        RowBox[{"w", "\[Equal]", 
          RowBox[{
            SuperscriptBox[
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], 
              RowBox[{"-", "1"}]], "(", 
            RowBox[{"a", ",", "z"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{"\[PartialD]", 
              RowBox[{
                SuperscriptBox[
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], 
                  RowBox[{"-", "1"}]], "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], 
            RowBox[{"\[PartialD]", "a"}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            SuperscriptBox["\[ExponentialE]", "w"], " ", 
            SuperscriptBox["w", 
              RowBox[{"1", "-", "a"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FractionBox["1", 
                    SuperscriptBox["a", "2"]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["w", "a"], " ", 
                        TagBox[
                          TagBox[
                            RowBox[{
                              RowBox[{
                                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                                  FormBox["2",
                                    "TraditionalForm"]], 
                                SubscriptBox["F", 
                                  FormBox["2",
                                    "TraditionalForm"]]}], 
                              "\[InvisibleApplication]", 
                              RowBox[{"(", 
                                RowBox[{
                                  TagBox[
                                    TagBox[
                                      RowBox[{
                                        TagBox["a",
                                        HypergeometricPFQ,
                                        Editable->True], ",", 
                                        TagBox["a",
                                        HypergeometricPFQ,
                                        Editable->True]}],
                                      InterpretTemplate[ {
                                        SlotSequence[ 1]}&]],
                                    HypergeometricPFQ,
                                    Editable->False], ";", 
                                  TagBox[
                                    TagBox[
                                      RowBox[{
                                        TagBox[
                                        RowBox[{"a", "+", "1"}],
                                        HypergeometricPFQ,
                                        Editable->True], ",", 
                                        TagBox[
                                        RowBox[{"a", "+", "1"}],
                                        HypergeometricPFQ,
                                        Editable->True]}],
                                      InterpretTemplate[ {
                                        SlotSequence[ 1]}&]],
                                    HypergeometricPFQ,
                                    Editable->False], ";", 
                                  TagBox[
                                    RowBox[{"-", "w"}],
                                    HypergeometricPFQ,
                                    Editable->True]}], ")"}]}],
                            InterpretTemplate[ 
                            HypergeometricPFQ[ #, #2, #3]&],
                            Editable->False],
                          HypergeometricPFQ]}], "-", 
                      RowBox[{
                        SubsuperscriptBox["z", "1", "a"], " ", 
                        TagBox[
                          TagBox[
                            RowBox[{
                              RowBox[{
                                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                                  FormBox["2",
                                    "TraditionalForm"]], 
                                SubscriptBox["F", 
                                  FormBox["2",
                                    "TraditionalForm"]]}], 
                              "\[InvisibleApplication]", 
                              RowBox[{"(", 
                                RowBox[{
                                  TagBox[
                                    TagBox[
                                      RowBox[{
                                        TagBox["a",
                                        HypergeometricPFQ,
                                        Editable->True], ",", 
                                        TagBox["a",
                                        HypergeometricPFQ,
                                        Editable->True]}],
                                      InterpretTemplate[ {
                                        SlotSequence[ 1]}&]],
                                    HypergeometricPFQ,
                                    Editable->False], ";", 
                                  TagBox[
                                    TagBox[
                                      RowBox[{
                                        TagBox[
                                        RowBox[{"a", "+", "1"}],
                                        HypergeometricPFQ,
                                        Editable->True], ",", 
                                        TagBox[
                                        RowBox[{"a", "+", "1"}],
                                        HypergeometricPFQ,
                                        Editable->True]}],
                                      InterpretTemplate[ {
                                        SlotSequence[ 1]}&]],
                                    HypergeometricPFQ,
                                    Editable->False], ";", 
                                  TagBox[
                                    RowBox[{"-", 
                                      SubscriptBox["z", "1"]}],
                                    HypergeometricPFQ,
                                    Editable->True]}], ")"}]}],
                            InterpretTemplate[ 
                            HypergeometricPFQ[ #, #2, #3]&],
                            Editable->False],
                          HypergeometricPFQ]}]}], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", ",", "w", ",", "0"}], ")"}], " ", 
                  RowBox[{"log", "(", "w", ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", ",", "0", ",", 
                      SubscriptBox["z", "1"]}], ")"}], " ", 
                  RowBox[{"log", "(", 
                    SubscriptBox["z", "1"], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[CapitalGamma]", "(", 
                    RowBox[{"a", ",", 
                      SubscriptBox["z", "1"], ",", "w"}], ")"}], " ", 
                  RowBox[{
                    TagBox["\[Psi]",
                      PolyGamma], "(", "a", ")"}]}]}], ")"}]}]}], "/;", 
        RowBox[{"w", "\[Equal]", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "The symbolic nth order derivatives of all gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", and their inverses ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " have the following representations:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", "z"}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SuperscriptBox["z", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            SuperscriptBox["z", 
              RowBox[{"-", "n"}]], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "n"], 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "n"], " ", 
                TagBox[
                  RowBox[{"(", GridBox[{
                        {
                          TagBox["n",
                            Identity,
                            Editable->True]},
                        {
                          TagBox["k",
                            Identity,
                            Editable->True]}
                        }], ")"}],
                  InterpretTemplate[ Binomial[ #, #2]&],
                  Editable->False], " ", 
                TagBox[
                  SubscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "a"}], ")"}], "k"],
                  Pochhammer], " ", 
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{
                    RowBox[{"a", "-", "k", "+", "n"}], ",", "z"}], 
                  ")"}]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", "z"}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SuperscriptBox["a", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            RowBox[{
              SuperscriptBox["\[CapitalGamma]", 
                TagBox[
                  RowBox[{"(", "n", ")"}],
                  Derivative],
                MultilineFunction->None], "(", "a", ")"}], "-", 
            RowBox[{
              SuperscriptBox["z", "a"], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"j", "=", "0"}], "n"], 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"n", "-", "j"}]], " ", 
                  TagBox[
                    RowBox[{"(", GridBox[{
                          {
                            TagBox["n",
                              Identity,
                              Editable->True]},
                          {
                            TagBox["j",
                              Identity,
                              Editable->True]}
                          }], ")"}],
                    InterpretTemplate[ Binomial[ #, #2]&],
                    Editable->False], " ", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"n", "-", "j"}], ")"}], "!"}], " ", 
                  SuperscriptBox[
                    RowBox[{"\[CapitalGamma]", "(", "a", ")"}], 
                    RowBox[{"n", "-", "j", "+", "1"}]], " ", 
                  RowBox[{
                    SuperscriptBox["log", "j"], "(", "z", ")"}], " ", 
                  TagBox[
                    TagBox[
                      RowBox[{
                        RowBox[{
                          SubscriptBox["\[InvisiblePrefixScriptBase]", 
                            RowBox[{"n", "-", "j", "+", "1"}]], 
                          SubscriptBox[
                            OverscriptBox["F", "~"], 
                            RowBox[{"n", "-", "j", "+", "1"}]]}], 
                        "\[InvisibleApplication]", 
                        RowBox[{"(", 
                          RowBox[{
                            TagBox[
                              TagBox[
                                RowBox[{
                                  TagBox[
                                    SubscriptBox["a", "1"],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    SubscriptBox["a", "2"],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox["\[Ellipsis]",
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    SubscriptBox["a", 
                                      RowBox[{"n", "-", "j", "+", "1"}]],
                                    HypergeometricPFQRegularized,
                                    Editable->True]}],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->True], ";", 
                            TagBox[
                              TagBox[
                                RowBox[{
                                  TagBox[
                                    RowBox[{
                                      SubscriptBox["a", "1"], "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    RowBox[{
                                      SubscriptBox["a", "2"], "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox["\[Ellipsis]",
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    RowBox[{
                                      SubscriptBox["a", 
                                        RowBox[{"n", "-", "j", "+", "1"}]], 
                                      "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True]}],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->True], ";", 
                            TagBox[
                              RowBox[{"-", "z"}],
                              HypergeometricPFQRegularized,
                              Editable->True]}], ")"}]}],
                      InterpretTemplate[ 
                      HypergeometricPFQRegularized[ #, #2, #3]&],
                      Editable->True],
                    HypergeometricPFQRegularized]}]}]}]}]}], "/;", 
        RowBox[{
          RowBox[{
            SubscriptBox["a", "1"], "\[Equal]", 
            SubscriptBox["a", "2"], "\[Equal]", "\[Ellipsis]", "\[Equal]", 
            SubscriptBox["a", 
              RowBox[{"n", "+", "1"}]], "\[Equal]", "a"}], "\[And]", 
          RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SubsuperscriptBox["z", "1", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            SubsuperscriptBox["z", "1", 
              RowBox[{"-", "n"}]], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "n"], 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "n"], " ", 
                TagBox[
                  RowBox[{"(", GridBox[{
                        {
                          TagBox["n",
                            Identity,
                            Editable->True]},
                        {
                          TagBox["k",
                            Identity,
                            Editable->True]}
                        }], ")"}],
                  InterpretTemplate[ Binomial[ #, #2]&],
                  Editable->False], " ", 
                TagBox[
                  SubscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "a"}], ")"}], "k"],
                  Pochhammer], " ", 
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{
                    RowBox[{"a", "-", "k", "+", "n"}], ",", 
                    SubscriptBox["z", "1"]}], ")"}]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SubsuperscriptBox["z", "2", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            RowBox[{"-", 
              SubsuperscriptBox["z", "2", 
                RowBox[{"-", "n"}]]}], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "n"], 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "n"], " ", 
                TagBox[
                  RowBox[{"(", GridBox[{
                        {
                          TagBox["n",
                            Identity,
                            Editable->True]},
                        {
                          TagBox["k",
                            Identity,
                            Editable->True]}
                        }], ")"}],
                  InterpretTemplate[ Binomial[ #, #2]&],
                  Editable->False], " ", 
                TagBox[
                  SubscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "a"}], ")"}], "k"],
                  Pochhammer], " ", 
                RowBox[{"\[CapitalGamma]", "(", 
                  RowBox[{
                    RowBox[{"a", "-", "k", "+", "n"}], ",", 
                    SubscriptBox["z", "2"]}], ")"}]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SuperscriptBox["a", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            RowBox[{
              SubsuperscriptBox["z", "2", "a"], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"j", "=", "0"}], "n"], 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"n", "-", "j"}]], " ", 
                  TagBox[
                    RowBox[{"(", GridBox[{
                          {
                            TagBox["n",
                              Identity,
                              Editable->True]},
                          {
                            TagBox["j",
                              Identity,
                              Editable->True]}
                          }], ")"}],
                    InterpretTemplate[ Binomial[ #, #2]&],
                    Editable->False], " ", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"n", "-", "j"}], ")"}], "!"}], " ", 
                  SuperscriptBox[
                    RowBox[{"\[CapitalGamma]", "(", "a", ")"}], 
                    RowBox[{"n", "-", "j", "+", "1"}]], " ", 
                  RowBox[{
                    SuperscriptBox["log", "j"], "(", 
                    SubscriptBox["z", "2"], ")"}], " ", 
                  TagBox[
                    TagBox[
                      RowBox[{
                        RowBox[{
                          SubscriptBox["\[InvisiblePrefixScriptBase]", 
                            RowBox[{"n", "-", "j", "+", "1"}]], 
                          SubscriptBox[
                            OverscriptBox["F", "~"], 
                            RowBox[{"n", "-", "j", "+", "1"}]]}], 
                        "\[InvisibleApplication]", 
                        RowBox[{"(", 
                          RowBox[{
                            TagBox[
                              TagBox[
                                RowBox[{
                                  TagBox[
                                    SubscriptBox["a", "1"],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    SubscriptBox["a", "2"],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox["\[Ellipsis]",
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    SubscriptBox["a", 
                                      RowBox[{"n", "-", "j", "+", "1"}]],
                                    HypergeometricPFQRegularized,
                                    Editable->True]}],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->True], ";", 
                            TagBox[
                              TagBox[
                                RowBox[{
                                  TagBox[
                                    RowBox[{
                                      SubscriptBox["a", "1"], "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    RowBox[{
                                      SubscriptBox["a", "2"], "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox["\[Ellipsis]",
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    RowBox[{
                                      SubscriptBox["a", 
                                        RowBox[{"n", "-", "j", "+", "1"}]], 
                                      "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True]}],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->True], ";", 
                            TagBox[
                              RowBox[{"-", 
                                SubscriptBox["z", "2"]}],
                              HypergeometricPFQRegularized,
                              Editable->True]}], ")"}]}],
                      InterpretTemplate[ 
                      HypergeometricPFQRegularized[ #, #2, #3]&],
                      Editable->True],
                    HypergeometricPFQRegularized]}]}]}], "-", 
            RowBox[{
              SubsuperscriptBox["z", "1", "a"], " ", 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"j", "=", "0"}], "n"], 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"n", "-", "j"}]], " ", 
                  TagBox[
                    RowBox[{"(", GridBox[{
                          {
                            TagBox["n",
                              Identity,
                              Editable->True]},
                          {
                            TagBox["j",
                              Identity,
                              Editable->True]}
                          }], ")"}],
                    InterpretTemplate[ Binomial[ #, #2]&],
                    Editable->False], " ", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"n", "-", "j"}], ")"}], "!"}], " ", 
                  SuperscriptBox[
                    RowBox[{"\[CapitalGamma]", "(", "a", ")"}], 
                    RowBox[{"n", "-", "j", "+", "1"}]], " ", 
                  RowBox[{
                    SuperscriptBox["log", "j"], "(", 
                    SubscriptBox["z", "1"], ")"}], " ", 
                  TagBox[
                    TagBox[
                      RowBox[{
                        RowBox[{
                          SubscriptBox["\[InvisiblePrefixScriptBase]", 
                            RowBox[{"n", "-", "j", "+", "1"}]], 
                          SubscriptBox[
                            OverscriptBox["F", "~"], 
                            RowBox[{"n", "-", "j", "+", "1"}]]}], 
                        "\[InvisibleApplication]", 
                        RowBox[{"(", 
                          RowBox[{
                            TagBox[
                              TagBox[
                                RowBox[{
                                  TagBox[
                                    SubscriptBox["a", "1"],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    SubscriptBox["a", "2"],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox["\[Ellipsis]",
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    SubscriptBox["a", 
                                      RowBox[{"n", "-", "j", "+", "1"}]],
                                    HypergeometricPFQRegularized,
                                    Editable->True]}],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->True], ";", 
                            TagBox[
                              TagBox[
                                RowBox[{
                                  TagBox[
                                    RowBox[{
                                      SubscriptBox["a", "1"], "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    RowBox[{
                                      SubscriptBox["a", "2"], "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox["\[Ellipsis]",
                                    HypergeometricPFQRegularized,
                                    Editable->True], ",", 
                                  TagBox[
                                    RowBox[{
                                      SubscriptBox["a", 
                                        RowBox[{"n", "-", "j", "+", "1"}]], 
                                      "+", "1"}],
                                    HypergeometricPFQRegularized,
                                    Editable->True]}],
                                InterpretTemplate[ {
                                  SlotSequence[ 1]}&]],
                              HypergeometricPFQRegularized,
                              Editable->True], ";", 
                            TagBox[
                              RowBox[{"-", 
                                SubscriptBox["z", "1"]}],
                              HypergeometricPFQRegularized,
                              Editable->True]}], ")"}]}],
                      InterpretTemplate[ 
                      HypergeometricPFQRegularized[ #, #2, #3]&],
                      Editable->True],
                    HypergeometricPFQRegularized]}]}]}]}]}], "/;", 
        RowBox[{
          RowBox[{
            SubscriptBox["a", "1"], "\[Equal]", 
            SubscriptBox["a", "2"], "\[Equal]", "\[Ellipsis]", "\[Equal]", 
            SubscriptBox["a", 
              RowBox[{"n", "+", "1"}]], "\[Equal]", "a"}], "\[And]", 
          RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", 
                RowBox[{"a", ",", "z"}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SuperscriptBox["z", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            RowBox[{"-", "a"}], " ", 
            SuperscriptBox["z", 
              RowBox[{"-", "n"}]], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "n"], 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                  RowBox[{"n", "-", "k"}]], " ", 
                TagBox[
                  RowBox[{"(", GridBox[{
                        {
                          TagBox["n",
                            Identity,
                            Editable->True]},
                        {
                          TagBox["k",
                            Identity,
                            Editable->True]}
                        }], ")"}],
                  InterpretTemplate[ Binomial[ #, #2]&],
                  Editable->False], " ", 
                TagBox[
                  SubscriptBox[
                    RowBox[{"(", 
                      RowBox[{"1", "-", "a", "-", "k"}], ")"}], 
                    RowBox[{"n", "-", "1"}]],
                  Pochhammer], " ", 
                RowBox[{
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], "(", 
                  RowBox[{
                    RowBox[{"a", "+", "k"}], ",", "z"}], ")"}]}]}]}]}], "/;", 
        
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", 
                RowBox[{"a", ",", "z"}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SuperscriptBox["a", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            FractionBox[
              RowBox[{
                SuperscriptBox["\[CapitalGamma]", 
                  TagBox[
                    RowBox[{"(", "n", ")"}],
                    Derivative],
                  MultilineFunction->None], "(", "a", ")"}], 
              RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], "-", 
            RowBox[{
              FractionBox["1", 
                RowBox[{"\[CapitalGamma]", "(", "a", ")"}]], 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", "0"}], "\[Infinity]"], 
                FractionBox[
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", "1"}], ")"}], 
                      RowBox[{"n", "-", "k"}]], " ", 
                    RowBox[{"\[CapitalGamma]", "(", 
                      RowBox[{
                        RowBox[{"n", "+", "1"}], ",", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"(", 
                              RowBox[{"a", "+", "k"}], ")"}]}], " ", 
                          RowBox[{"log", "(", "z", ")"}]}]}], ")"}]}], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"a", "+", "k"}], ")"}], 
                      RowBox[{"n", "+", "1"}]], " ", 
                    RowBox[{"k", "!"}]}]]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SubsuperscriptBox["z", "1", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            RowBox[{"-", "a"}], " ", 
            SubsuperscriptBox["z", "1", 
              RowBox[{"-", "n"}]], 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "n"], 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                  RowBox[{"n", "-", "k"}]], " ", 
                TagBox[
                  RowBox[{"(", GridBox[{
                        {
                          TagBox["n",
                            Identity,
                            Editable->True]},
                        {
                          TagBox["k",
                            Identity,
                            Editable->True]}
                        }], ")"}],
                  InterpretTemplate[ Binomial[ #, #2]&],
                  Editable->False], " ", 
                TagBox[
                  SubscriptBox[
                    RowBox[{"(", 
                      RowBox[{"1", "-", "a", "-", "k"}], ")"}], 
                    RowBox[{"n", "-", "1"}]],
                  Pochhammer], " ", 
                RowBox[{
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], "(", 
                  RowBox[{
                    RowBox[{"a", "+", "k"}], ",", 
                    SubscriptBox["z", "1"]}], ")"}]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SubsuperscriptBox["z", "2", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{"a", " ", 
            SubsuperscriptBox["z", "2", 
              RowBox[{"-", "n"}]], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "n"], 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                  RowBox[{"n", "-", "k"}]], " ", 
                TagBox[
                  RowBox[{"(", GridBox[{
                        {
                          TagBox["n",
                            Identity,
                            Editable->True]},
                        {
                          TagBox["k",
                            Identity,
                            Editable->True]}
                        }], ")"}],
                  InterpretTemplate[ Binomial[ #, #2]&],
                  Editable->False], " ", 
                TagBox[
                  SubscriptBox[
                    RowBox[{"(", 
                      RowBox[{"1", "-", "a", "-", "k"}], ")"}], 
                    RowBox[{"n", "-", "1"}]],
                  Pochhammer], " ", 
                RowBox[{
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], "(", 
                  RowBox[{
                    RowBox[{"a", "+", "k"}], ",", 
                    SubscriptBox["z", "2"]}], ")"}]}]}]}]}], "/;", 
        RowBox[{"n", "\[Element]", 
          SuperscriptBox["\[DoubleStruckCapitalN]", "+"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SuperscriptBox["a", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            RowBox[{"n", "!"}], " ", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "n"], 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SubsuperscriptBox["z", "2", "a"], " ", 
                      RowBox[{
                        UnderoverscriptBox["\[Sum]", 
                          RowBox[{"i", "=", "0"}], 
                          RowBox[{"n", "-", "k"}]], 
                        RowBox[{
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"-", "1"}], ")"}], 
                            RowBox[{"n", "-", "i", "-", "k"}]], " ", 
                          TagBox[
                            RowBox[{"(", GridBox[{
                                  {
                                    TagBox[
                                      RowBox[{"n", "-", "k"}],
                                      Identity,
                                      Editable->True]},
                                  {
                                    TagBox["i",
                                      Identity,
                                      Editable->True]}
                                  }], ")"}],
                            InterpretTemplate[ Binomial[ #, #2]&],
                            Editable->False], " ", 
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{"n", "-", "i", "-", "k"}], ")"}], "!"}],
                           " ", 
                          SuperscriptBox[
                            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], 
                            RowBox[{"n", "-", "i", "-", "k", "+", "1"}]], " ",
                           
                          RowBox[{
                            SuperscriptBox["log", "i"], "(", 
                            SubscriptBox["z", "2"], ")"}], " ", 
                          RowBox[{
                            RowBox[{
                              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                                RowBox[{"n", "-", "k", "-", "i", "+", "1"}]], 
                              
                              SubscriptBox[
                                OverscriptBox["F", "~"], 
                                RowBox[{
                                "n", "-", "k", "-", "i", "+", "1"}]]}], 
                            "\[InvisibleApplication]", 
                            RowBox[{"(", 
                              RowBox[{
                                TagBox[
                                  TagBox[
                                    RowBox[{
                                      TagBox[
                                        SubscriptBox["a", "1"],
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox[
                                        SubscriptBox["a", "2"],
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox["\[Ellipsis]",
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox[
                                        SubscriptBox["a", 
                                        RowBox[{
                                        "n", "-", "k", "-", "i", "+", "1"}]],
                                        HypergeometricPFQRegularized,
                                        Editable->True]}],
                                    InterpretTemplate[ {
                                      SlotSequence[ 1]}&]],
                                  HypergeometricPFQRegularized,
                                  Editable->True], ";", 
                                TagBox[
                                  TagBox[
                                    RowBox[{
                                      TagBox[
                                        RowBox[{
                                        SubscriptBox["a", "1"], "+", "1"}],
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox[
                                        RowBox[{
                                        SubscriptBox["a", "2"], "+", "1"}],
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox["\[Ellipsis]",
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox[
                                        RowBox[{
                                        SubscriptBox["a", 
                                        RowBox[{
                                        "n", "-", "k", "-", "i", "+", "1"}]], 
                                        "+", "1"}],
                                        HypergeometricPFQRegularized,
                                        Editable->True]}],
                                    InterpretTemplate[ {
                                      SlotSequence[ 1]}&]],
                                  HypergeometricPFQRegularized,
                                  Editable->True], ";", 
                                TagBox[
                                  RowBox[{"-", 
                                    SubscriptBox["z", "2"]}],
                                  HypergeometricPFQRegularized,
                                  Editable->True]}], ")"}]}]}]}]}], "-", 
                    RowBox[{
                      SubsuperscriptBox["z", "1", "a"], " ", 
                      RowBox[{
                        UnderoverscriptBox["\[Sum]", 
                          RowBox[{"i", "=", "0"}], 
                          RowBox[{"n", "-", "k"}]], 
                        RowBox[{
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"-", "1"}], ")"}], 
                            RowBox[{"n", "-", "i", "-", "k"}]], " ", 
                          TagBox[
                            RowBox[{"(", GridBox[{
                                  {
                                    TagBox[
                                      RowBox[{"n", "-", "k"}],
                                      Identity,
                                      Editable->True]},
                                  {
                                    TagBox["i",
                                      Identity,
                                      Editable->True]}
                                  }], ")"}],
                            InterpretTemplate[ Binomial[ #, #2]&],
                            Editable->False], " ", 
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{"n", "-", "i", "-", "k"}], ")"}], "!"}],
                           " ", 
                          SuperscriptBox[
                            RowBox[{"\[CapitalGamma]", "(", "a", ")"}], 
                            RowBox[{"n", "-", "i", "-", "k", "+", "1"}]], " ",
                           
                          RowBox[{
                            SuperscriptBox["log", "i"], "(", 
                            SubscriptBox["z", "1"], ")"}], 
                          RowBox[{
                            RowBox[{
                              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                                RowBox[{"n", "-", "k", "-", "i", "+", "1"}]], 
                              
                              SubscriptBox[
                                OverscriptBox["F", "~"], 
                                RowBox[{
                                "n", "-", "k", "-", "i", "+", "1"}]]}], 
                            "\[InvisibleApplication]", 
                            RowBox[{"(", 
                              RowBox[{
                                TagBox[
                                  TagBox[
                                    RowBox[{
                                      TagBox[
                                        SubscriptBox["a", "1"],
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox[
                                        SubscriptBox["a", "2"],
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox["\[Ellipsis]",
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox[
                                        SubscriptBox["a", 
                                        RowBox[{
                                        "n", "-", "k", "-", "i", "+", "1"}]],
                                        HypergeometricPFQRegularized,
                                        Editable->True]}],
                                    InterpretTemplate[ {
                                      SlotSequence[ 1]}&]],
                                  HypergeometricPFQRegularized,
                                  Editable->True], ";", 
                                TagBox[
                                  TagBox[
                                    RowBox[{
                                      TagBox[
                                        RowBox[{
                                        SubscriptBox["a", "1"], "+", "1"}],
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox[
                                        RowBox[{
                                        SubscriptBox["a", "2"], "+", "1"}],
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox["\[Ellipsis]",
                                        HypergeometricPFQRegularized,
                                        Editable->True], ",", 
                                      TagBox[
                                        RowBox[{
                                        SubscriptBox["a", 
                                        RowBox[{
                                        "n", "-", "k", "-", "i", "+", "1"}]], 
                                        "+", "1"}],
                                        HypergeometricPFQRegularized,
                                        Editable->True]}],
                                    InterpretTemplate[ {
                                      SlotSequence[ 1]}&]],
                                  HypergeometricPFQRegularized,
                                  Editable->True], ";", 
                                TagBox[
                                  RowBox[{"-", 
                                    SubscriptBox["z", "1"]}],
                                  HypergeometricPFQRegularized,
                                  Editable->True]}], ")"}]}]}]}]}]}], ")"}], 
                " ", 
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"j", "=", "0"}], "k"], 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"-", "1"}], ")"}], "j"], " ", 
                        RowBox[{"(", 
                          RowBox[{"k", "+", "1"}], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], 
                          RowBox[{
                            RowBox[{"-", "j"}], "-", "1"}]]}], 
                      RowBox[{
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{"j", "+", "1"}], ")"}], "!"}], " ", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{"n", "-", "k"}], ")"}], "!"}], " ", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{"k", "-", "j"}], ")"}], "!"}]}]], " ", 
                    FractionBox[
                      RowBox[{
                        SuperscriptBox["\[PartialD]", "k"], 
                        SuperscriptBox[
                          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], "j"]}], 
                      
                      RowBox[{"\[PartialD]", 
                        SuperscriptBox["a", "k"]}],
                      MultilineFunction->None]}]}]}]}]}]}], "/;", 
        RowBox[{
          RowBox[{
            SubscriptBox["a", "1"], "\[Equal]", 
            SubscriptBox["a", "2"], "\[Equal]", "\[Ellipsis]", "\[Equal]", 
            SubscriptBox["a", 
              RowBox[{"n", "+", "1"}]], "\[Equal]", "a"}], "\[And]", 
          RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SuperscriptBox["\[PartialD]", "\[Alpha]"], 
            StyleBox[
              RowBox[{"log\[CapitalGamma]", "(", "z", ")"}],
              ScriptLevel->0]}], 
          RowBox[{"\[PartialD]", 
            SuperscriptBox["z", "\[Alpha]"]}],
          MultilineFunction->None], "\[Equal]", 
        RowBox[{
          SuperscriptBox[
            TagBox["\[Psi]",
              PolyGamma], 
            RowBox[{"(", 
              RowBox[{"\[Alpha]", "-", "1"}], ")"}]], "(", "z", ")"}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{
                SuperscriptBox[
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], 
                  RowBox[{"-", "1"}]], "(", 
                RowBox[{"a", ",", "z"}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SuperscriptBox["z", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            RowBox[{"w", " ", 
              SubscriptBox[
                InterpretationBox["\[Delta]",
                  KroneckerDelta,
                  Editable->False,
                  Selectable->False], "n"]}], "+", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", 
                    FractionBox[
                      RowBox[{
                        RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
                        SuperscriptBox["\[ExponentialE]", "w"]}], 
                      SuperscriptBox["w", 
                        RowBox[{"a", "-", "1"}]]]}], ")"}], "n"], 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{
                    SubscriptBox["j", "2"], "=", "0"}], "n"], 
                RowBox[{"\[Ellipsis]", " ", 
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{
                        SubscriptBox["j", "n"], "=", "0"}], "n"], 
                    RowBox[{
                      SubscriptBox[
                        InterpretationBox["\[Delta]",
                          KroneckerDelta,
                          Editable->False,
                          Selectable->False], 
                        RowBox[{
                          RowBox[{
                            UnderoverscriptBox["\[Sum]", 
                              RowBox[{"i", "=", "2"}], "n"], 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{"i", "-", "1"}], ")"}], " ", 
                              SubscriptBox["j", "i"]}]}], ",", 
                          RowBox[{"n", "-", "1"}]}]], " ", 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"-", "1"}], ")"}], 
                        RowBox[{
                          UnderoverscriptBox["\[Sum]", 
                            RowBox[{"i", "=", "2"}], "n"], 
                          SubscriptBox["j", "i"]}]], " ", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{"n", "+", 
                            RowBox[{
                              UnderoverscriptBox["\[Sum]", 
                                RowBox[{"i", "=", "2"}], "n"], 
                              SubscriptBox["j", "i"]}], "-", "1"}], ")"}], 
                        "!"}], " ", 
                      RowBox[{
                        UnderoverscriptBox["\[Product]", 
                          RowBox[{"i", "=", "2"}], "n"], 
                        RowBox[{
                          FractionBox["1", 
                            RowBox[{
                              SubscriptBox["j", "i"], "!"}]], 
                          SuperscriptBox[
                            RowBox[{"(", 
                              FractionBox[
                                RowBox[{
                                  RowBox[{"\[CapitalGamma]", "(", 
                                    RowBox[{"a", "+", "1"}], ")"}], " ", 
                                  SuperscriptBox["\[ExponentialE]", "w"], " ",
                                   
                                  SuperscriptBox["w", 
                                    RowBox[{
                                      RowBox[{"-", "a"}], "-", "i", "+", 
                                      "1"}]]}], 
                                RowBox[{"i", "!"}]], ")"}], 
                            SubscriptBox["j", "i"]], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"k", "=", "0"}], "i"], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{"-", "1"}], ")"}], 
                                    RowBox[{"i", "-", "k"}]], " ", 
                                  TagBox[
                                    RowBox[{"(", GridBox[{
                                        {
                                        TagBox["i",
                                        Identity,
                                        Editable->True]},
                                        {
                                        TagBox["k",
                                        Identity,
                                        Editable->True]}
                                        }], ")"}],
                                    InterpretTemplate[ Binomial[ #, #2]&],
                                    Editable->False], " ", 
                                  TagBox[
                                    SubscriptBox[
                                      RowBox[{"(", 
                                        RowBox[{
                                        RowBox[{"-", "a"}], "-", "k", "+", 
                                        "1"}], ")"}], 
                                      RowBox[{"i", "-", "1"}]],
                                    Pochhammer], " ", 
                                  RowBox[{
                                    InterpretationBox["Q",
                                      GammaRegularized,
                                      Editable->False,
                                      Selectable->False], "(", 
                                    RowBox[{
                                      RowBox[{"a", "+", "k"}], ",", "w"}], 
                                    ")"}]}]}], ")"}], 
                            SubscriptBox["j", "i"]]}]}]}]}]}]}]}]}]}], " ", "/;",
         
        RowBox[{
          RowBox[{"w", "\[Equal]", 
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", "z"}], ")"}]}], "\[And]", 
          RowBox[{"n", "\[Element]", "\[DoubleStruckCapitalN]"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[PartialD]", "n"], 
              RowBox[{
                SuperscriptBox[
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], 
                  RowBox[{"-", "1"}]], "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], 
            RowBox[{"\[PartialD]", 
              SubsuperscriptBox["z", "2", "n"]}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            RowBox[{"w", " ", 
              SubscriptBox[
                InterpretationBox["\[Delta]",
                  KroneckerDelta,
                  Editable->False,
                  Selectable->False], "n"]}], "+", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"`", "(", 
                  FractionBox[
                    RowBox[{
                      RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
                      SuperscriptBox["\[ExponentialE]", "w"]}], 
                    SuperscriptBox["w", 
                      RowBox[{"a", "-", "1"}]]], ")"}], "n"], 
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{
                    SubscriptBox["j", "2"], "=", "0"}], "n"], 
                RowBox[{"\[Ellipsis]", " ", 
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{
                        SubscriptBox["j", "n"], "=", "0"}], "n"], 
                    RowBox[{
                      SubscriptBox[
                        InterpretationBox["\[Delta]",
                          KroneckerDelta,
                          Editable->False,
                          Selectable->False], 
                        RowBox[{
                          RowBox[{
                            UnderoverscriptBox["\[Sum]", 
                              RowBox[{"i", "=", "2"}], "n"], 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{"i", "-", "1"}], ")"}], " ", 
                              SubscriptBox["j", "i"]}]}], ",", 
                          RowBox[{"n", "-", "1"}]}]], " ", 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"-", "1"}], ")"}], 
                        RowBox[{
                          UnderoverscriptBox["\[Sum]", 
                            RowBox[{"i", "=", "2"}], "n"], 
                          SubscriptBox["j", "i"]}]], " ", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{"n", "+", 
                            RowBox[{
                              UnderoverscriptBox["\[Sum]", 
                                RowBox[{"i", "=", "2"}], "n"], 
                              SubscriptBox["j", "i"]}], "-", "1"}], ")"}], 
                        "!"}], " ", 
                      RowBox[{
                        UnderoverscriptBox["\[Product]", 
                          RowBox[{"i", "=", "2"}], "n"], 
                        RowBox[{
                          FractionBox["1", 
                            RowBox[{
                              SubscriptBox["j", "i"], "!"}]], 
                          SuperscriptBox[
                            RowBox[{"(", 
                              FractionBox[
                                RowBox[{
                                  RowBox[{"\[CapitalGamma]", "(", 
                                    RowBox[{"a", "+", "1"}], ")"}], " ", 
                                  SuperscriptBox["\[ExponentialE]", "w"], " ",
                                   
                                  SuperscriptBox["w", 
                                    RowBox[{"1", "-", "a"}]]}], 
                                RowBox[{"i", "!"}]], ")"}], 
                            SubscriptBox["j", "i"]], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{
                                RowBox[{"a", " ", 
                                  SuperscriptBox["w", 
                                    RowBox[{"-", "i"}]], 
                                  RowBox[{
                                    UnderoverscriptBox["\[Sum]", 
                                      RowBox[{"k", "=", "0"}], "i"], 
                                    RowBox[{
                                      SuperscriptBox[
                                        RowBox[{"(", 
                                        RowBox[{"-", "1"}], ")"}], 
                                        RowBox[{"i", "-", "k"}]], " ", 
                                      TagBox[
                                        RowBox[{"(", GridBox[{
                                        {
                                        TagBox["i",
                                        Identity,
                                        Editable->True]},
                                        {
                                        TagBox["k",
                                        Identity,
                                        Editable->True]}
                                        }], ")"}],
                                        InterpretTemplate[ Binomial[ #, #2]&],
                                        
                                        Editable->False], " ", 
                                      TagBox[
                                        SubscriptBox[
                                        RowBox[{"(", 
                                        RowBox[{"1", "-", "a", "-", "k"}], 
                                        ")"}], 
                                        RowBox[{"i", "-", "1"}]],
                                        Pochhammer], " ", 
                                      RowBox[{
                                        InterpretationBox["Q",
                                        GammaRegularized,
                                        Editable->False,
                                        Selectable->False], "(", 
                                        RowBox[{
                                        RowBox[{"a", "+", "k"}], ",", "w"}], 
                                        ")"}]}]}]}], "+", 
                                RowBox[{
                                  RowBox[{
                                    InterpretationBox["Q",
                                      GammaRegularized,
                                      Editable->False,
                                      Selectable->False], "(", 
                                    RowBox[{"a", ",", 
                                      SubscriptBox["z", "1"]}], ")"}], " ", 
                                  SubscriptBox[
                                    InterpretationBox["\[Delta]",
                                      KroneckerDelta,
                                      Editable->False,
                                      Selectable->False], "i"]}]}], ")"}], 
                            SubscriptBox["j", "i"]]}]}]}]}]}]}]}]}]}], "/;", 
        RowBox[{
          RowBox[{"w", "\[Equal]", 
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}]}], "\[And]", 
          RowBox[{"n", "\[Element]", 
            RowBox[{"\[DoubleStruckCapitalN]", "."}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Differential equations", "Subsubsection"],

Cell[TextData[{
  "The gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          InterpretationBox["Q",
            GammaRegularized,
            Editable->False,
            Selectable->False], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " satisfy the following second order linear differential equations:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"z", " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "z", ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "a", "+", "z"}], ")"}], " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "(", "z", ")"}]}]}], "\[Equal]", 
          "0"}], "/;", 
        RowBox[{
          RowBox[{"w", "(", "z", ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              SubscriptBox["c", "1"], 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", "z"}], ")"}]}], " ", "+", 
            SubscriptBox["c", "2"]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox["z", "1"], " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", 
                SubscriptBox["z", "1"], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "a", "+", 
                  SubscriptBox["z", "1"]}], ")"}], " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "(", 
                SubscriptBox["z", "1"], ")"}]}]}], "\[Equal]", "0"}], "/;", 
        RowBox[{
          RowBox[{"w", "(", 
            SubscriptBox["z", "1"], ")"}], "\[Equal]", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["c", "1"], 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], "+", 
            SubscriptBox["c", "2"]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox["z", "2"], " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", 
                SubscriptBox["z", "2"], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "a", "+", 
                  SubscriptBox["z", "2"]}], ")"}], " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "(", 
                SubscriptBox["z", "2"], ")"}]}]}], "\[Equal]", "0"}], "/;", 
        RowBox[{
          RowBox[{"w", "(", 
            SubscriptBox["z", "2"], ")"}], "\[Equal]", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["c", "1"], 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], "+", 
            SubscriptBox["c", "2"]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"z", " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "z", ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "a", "+", "z"}], ")"}], " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "(", "z", ")"}]}]}], "\[Equal]", 
          "0"}], "/;", 
        RowBox[{
          RowBox[{"w", "(", "z", ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              SubscriptBox["c", "1"], 
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", 
                RowBox[{"a", ",", "z"}], ")"}]}], " ", "+", 
            SubscriptBox["c", "2"]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox["z", "1"], " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", 
                SubscriptBox["z", "1"], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "a", "+", 
                  SubscriptBox["z", "1"]}], ")"}], " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "(", 
                SubscriptBox["z", "1"], ")"}]}]}], "\[Equal]", "0"}], "/;", 
        RowBox[{
          RowBox[{"w", "(", 
            SubscriptBox["z", "1"], ")"}], "\[Equal]", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["c", "1"], 
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", 
                RowBox[{"a", ",", 
                  SubscriptBox["z", "1"], ",", 
                  SubscriptBox["z", "2"]}], ")"}]}], "+", 
            SubscriptBox["c", "2"]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                SubscriptBox["z", "2"], " ", 
                RowBox[{
                  SuperscriptBox["w", "\[Prime]\[Prime]",
                    MultilineFunction->None], "(", 
                  SubscriptBox["z", "2"], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"1", "-", "a", "+", 
                    SubscriptBox["z", "2"]}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["w", "\[Prime]",
                    MultilineFunction->None], "(", 
                  SubscriptBox["z", "2"], ")"}]}]}], "\[Equal]", "0"}], "/;", 
          
          RowBox[{
            RowBox[{"w", "(", 
              SubscriptBox["z", "2"], ")"}], "\[Equal]", " ", 
            RowBox[{
              RowBox[{
                SubscriptBox["c", "1"], 
                RowBox[{
                  InterpretationBox["Q",
                    GammaRegularized,
                    Editable->False,
                    Selectable->False], "(", 
                  RowBox[{"a", ",", 
                    SubscriptBox["z", "1"], ",", 
                    SubscriptBox["z", "2"]}], ")"}]}], "+", 
              SubscriptBox["c", "2"]}]}]}], ","}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "1"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "2"], TraditionalForm]]],
  " are arbitrary constants."
}], "Text"],

Cell[TextData[{
  "The log\[Hyphen]gamma function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], TraditionalForm]]],
  " satisfies the following simple first order linear differential equation:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{"\[PartialD]", 
              RowBox[{"w", "(", "z", ")"}]}], 
            RowBox[{"\[PartialD]", "z"}],
            MultilineFunction->None], "\[Equal]", 
          RowBox[{
            TagBox["\[Psi]",
              PolyGamma], "(", "z", ")"}]}], "/;", 
        RowBox[{
          RowBox[{"w", "(", "z", ")"}], "\[Equal]", 
          StyleBox[
            RowBox[{
              RowBox[{"log\[CapitalGamma]", "(", "z", ")"}], "."}],
            ScriptLevel->0]}]}], TraditionalForm]], "TraditionalFormEquation"],

Cell[TextData[{
  "The inverses of the regularized incomplete gamma functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", "z"}], ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            InterpretationBox["Q",
              GammaRegularized,
              Editable->False,
              Selectable->False], 
            RowBox[{"-", "1"}]], "(", 
          RowBox[{"a", ",", 
            SubscriptBox["z", "1"], ",", 
            SubscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
  " satisfy the following ordinary nonlinear second order differential \
equation:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"w", "(", "z", ")"}], " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "z", ")"}]}], "-", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["w", "\[Prime]",
                    MultilineFunction->None], "(", "z", ")"}], "2"], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"w", "(", "z", ")"}], "+", "1", "-", "a"}], 
                ")"}]}]}], "\[Equal]", "0"}], "/;", 
        RowBox[{
          RowBox[{"w", "(", "z", ")"}], "\[Equal]", 
          RowBox[{
            SuperscriptBox[
              InterpretationBox["Q",
                GammaRegularized,
                Editable->False,
                Selectable->False], 
              RowBox[{"-", "1"}]], "(", 
            RowBox[{"a", ",", "z"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"w", "(", 
                SubscriptBox["z", "2"], ")"}], " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", 
                SubscriptBox["z", "2"], ")"}]}], "-", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["w", "\[Prime]",
                    MultilineFunction->None], "(", 
                  SubscriptBox["z", "2"], ")"}], "2"], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", "a"}], "+", 
                  RowBox[{"w", "(", 
                    SubscriptBox["z", "2"], ")"}], "+", "1"}], ")"}]}]}], 
          "\[Equal]", "0"}], "/;", 
        RowBox[{
          RowBox[{"w", "(", 
            SubscriptBox["z", "2"], ")"}], "\[Equal]", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], 
                RowBox[{"-", "1"}]], "(", 
              RowBox[{"a", ",", 
                SubscriptBox["z", "1"], ",", 
                SubscriptBox["z", "2"]}], ")"}], "."}]}]}], 
      TraditionalForm]], "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Applications of gamma functions", "Subsection"],

Cell["\<\
The gamma functions are used throughout mathematics, the exact \
sciences, and engineering. In particular, the incomplete gamma function is \
used in solid state physics and statistics, and the logarithm of the gamma \
function is used in discrete mathematics, number theory, and other fields of \
sciences.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{699, 642},
WindowMargins->{{186, Automatic}, {121, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "mtrott7", "Texts"}, \
"TitleOfBox1.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
PrivateNotebookOptions->{"ShortBoxForm"->False},
ShowSelection->True,
CellLabelAutoDelete->False,
ShowCellTags->False,
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "NoCodePrintout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["Input", "NoCodePrintout"],
    CellMargins->{{39, 0}, {4, 6}},
    CellOpen->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageSize->{Automatic, 160},
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Special Styles", "Section"],
  
  Cell[StyleData["GraphicsTitle"],
    CellMargins->{{12, Inherited}, {20, 40}},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["IntroductionSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["NSDLMetaDataSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["NSDLMetaData"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AltTag"],
    CellMargins->{{12, 10}, {7, 7}},
    CellFrameLabels->{{
      Cell[ "AT", "Text", FontColor -> RGBColor[ 0, 0.299992, 0.299992]], 
          Inherited}, {Inherited, Inherited}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["AltTag", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GraphicsCount"],
    CellMargins->{{12, 10}, {7, 7}},
    CellFrameLabels->{{
      Cell[ "CG", "Text", FontColor -> GrayLevel[ 0.2]], Inherited}, {
        Inherited, Inherited}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["GC", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrivateInput"],
    CellFrame->{{6, 0}, {0, 0}},
    CellMargins->{{50, 4}, {2, 6}},
    CellBracketOptions->{"Thickness"->2,
    "Color"->RGBColor[0, 0.299992, 0.299992]},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0, 0.299992, 0.299992],
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    SpellingOptions->{"AlwaysStop"->{}},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["PrivateInput", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TraditionalFormEquation"],
    CellMargins->{{85, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->{"OutputGrouping", 50},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Above,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Plain"],
  
  Cell[StyleData["TraditionalFormEquation", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["TraditionalFormEquation", "WebSite"],
    CellMargins->{{56, 10}, {5, 7}}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{59, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{108, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{158, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 38, 0, 61, "Section"],

Cell[CellGroupData[{
Cell[1839, 57, 29, 0, 45, "Subsection"],
Cell[1871, 59, 716, 20, 68, "Text"],
Cell[2590, 81, 276, 8, 28, "TraditionalFormEquation"],
Cell[2869, 91, 243, 7, 50, "Text"],
Cell[3115, 100, 800, 21, 53, "TraditionalFormEquation"],
Cell[3918, 123, 372, 8, 50, "Text"],
Cell[4293, 133, 996, 25, 46, "TraditionalFormEquation"],
Cell[5292, 160, 1648, 43, 122, "Text"],
Cell[6943, 205, 1413, 32, 140, "Text"],
Cell[8359, 239, 1090, 22, 122, "Text"],
Cell[9452, 263, 2502, 72, 122, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11991, 340, 52, 0, 29, "Subsection"],
Cell[12046, 342, 2334, 68, 104, "Text"],
Cell[14383, 412, 622, 16, 44, "TraditionalFormEquation"],
Cell[15008, 430, 953, 25, 62, "TraditionalFormEquation"],
Cell[15964, 457, 537, 14, 45, "TraditionalFormEquation"],
Cell[16504, 473, 665, 18, 47, "TraditionalFormEquation"],
Cell[17172, 493, 462, 13, 45, "TraditionalFormEquation"],
Cell[17637, 508, 614, 17, 45, "TraditionalFormEquation"],
Cell[18254, 527, 782, 22, 52, "TraditionalFormEquation"],
Cell[19039, 551, 996, 26, 68, "Text"],
Cell[20038, 579, 649, 19, 29, "TraditionalFormEquation"],
Cell[20690, 600, 847, 24, 29, "TraditionalFormEquation"],
Cell[21540, 626, 113, 3, 32, "Text"],
Cell[21656, 631, 175, 4, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[21868, 640, 57, 0, 29, "Subsection"],
Cell[21928, 642, 317, 8, 50, "Text"],
Cell[22248, 652, 125542, 5645, 212, 87269, 5167, "GraphicsData", \
"PostScript", "Graphics"],
Cell[147793, 6299, 244, 7, 32, "Text"],
Cell[148040, 6308, 1354005, 101708, 211, 1324453, 101338, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1502048, 108018, 403, 14, 32, "Text"],
Cell[1502454, 108034, 931794, 23108, 222, 819133, 21712, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2434251, 131144, 377, 13, 32, "Text"],
Cell[2434631, 131159, 199117, 4874, 228, 156690, 4345, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[2633785, 136038, 104, 3, 29, "Subsection"],

Cell[CellGroupData[{
Cell[2633914, 136045, 71, 0, 42, "Subsubsection"],
Cell[2633988, 136047, 1075, 35, 50, "Text"],
Cell[2635066, 136084, 761, 24, 50, "Text"],
Cell[2635830, 136110, 2510, 55, 30, "TraditionalFormEquation"],
Cell[2638343, 136167, 2143, 51, 44, "TraditionalFormEquation"],
Cell[2640489, 136220, 500, 14, 28, "TraditionalFormEquation"],
Cell[2640992, 136236, 4748, 102, 30, "TraditionalFormEquation"],
Cell[2645743, 136340, 4012, 95, 44, "TraditionalFormEquation"],
Cell[2649758, 136437, 1087, 30, 28, "TraditionalFormEquation"],
Cell[2650848, 136469, 2343, 56, 30, "TraditionalFormEquation"],
Cell[2653194, 136527, 2327, 57, 46, "TraditionalFormEquation"],
Cell[2655524, 136586, 692, 20, 46, "TraditionalFormEquation"],
Cell[2656219, 136608, 4039, 98, 30, "TraditionalFormEquation"],
Cell[2660261, 136708, 4321, 103, 46, "TraditionalFormEquation"],
Cell[2664585, 136813, 1495, 39, 46, "TraditionalFormEquation"],
Cell[2666083, 136854, 123, 3, 32, "Text"],
Cell[2666209, 136859, 1110, 32, 45, "TraditionalFormEquation"],
Cell[2667322, 136893, 2276, 63, 45, "TraditionalFormEquation"],
Cell[2669601, 136958, 1352, 38, 46, "TraditionalFormEquation"],
Cell[2670956, 136998, 2895, 73, 46, "TraditionalFormEquation"],
Cell[2673854, 137073, 258, 7, 32, "Text"],
Cell[2674115, 137082, 474, 14, 44, "TraditionalFormEquation"],
Cell[2674592, 137098, 733, 21, 46, "TraditionalFormEquation"],
Cell[2675328, 137121, 789, 22, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2676154, 137148, 77, 0, 42, "Subsubsection"],
Cell[2676234, 137150, 1246, 41, 50, "Text"],
Cell[2677483, 137193, 459, 13, 28, "TraditionalFormEquation"],
Cell[2677945, 137208, 891, 25, 28, "TraditionalFormEquation"],
Cell[2678839, 137235, 656, 19, 46, "TraditionalFormEquation"],
Cell[2679498, 137256, 1263, 34, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2680798, 137295, 55, 0, 42, "Subsubsection"],
Cell[2680856, 137297, 1866, 60, 68, "Text"],
Cell[2682725, 137359, 606, 16, 29, "TraditionalFormEquation"],
Cell[2683334, 137377, 760, 20, 29, "TraditionalFormEquation"],
Cell[2684097, 137399, 633, 18, 29, "TraditionalFormEquation"],
Cell[2684733, 137419, 780, 22, 29, "TraditionalFormEquation"],
Cell[2685516, 137443, 1069, 31, 29, "TraditionalFormEquation"],
Cell[2686588, 137476, 1127, 32, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2687752, 137513, 70, 0, 42, "Subsubsection"],
Cell[2687825, 137515, 1254, 42, 50, "Text"],
Cell[2689082, 137559, 346, 9, 28, "TraditionalFormEquation"],
Cell[2689431, 137570, 522, 13, 28, "TraditionalFormEquation"],
Cell[2689956, 137585, 751, 20, 28, "TraditionalFormEquation"],
Cell[2690710, 137607, 518, 14, 28, "TraditionalFormEquation"],
Cell[2691231, 137623, 579, 15, 28, "TraditionalFormEquation"],
Cell[2691813, 137640, 624, 17, 28, "TraditionalFormEquation"],
Cell[2692440, 137659, 682, 19, 46, "TraditionalFormEquation"],
Cell[2693125, 137680, 706, 20, 28, "TraditionalFormEquation"],
Cell[2693834, 137702, 508, 14, 45, "TraditionalFormEquation"],
Cell[2694345, 137718, 867, 26, 28, "TraditionalFormEquation"],
Cell[2695215, 137746, 660, 18, 45, "TraditionalFormEquation"],
Cell[2695878, 137766, 711, 18, 44, "TraditionalFormEquation"],
Cell[2696592, 137786, 1912, 47, 44, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2698553, 137839, 104, 3, 29, "Subsection"],

Cell[CellGroupData[{
Cell[2698682, 137846, 55, 0, 42, "Subsubsection"],
Cell[2698740, 137848, 1768, 60, 68, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2700545, 137913, 46, 0, 42, "Subsubsection"],
Cell[2700594, 137915, 1979, 67, 50, "Text"],
Cell[2702576, 137984, 289, 7, 28, "TraditionalFormEquation"],
Cell[2702868, 137993, 320, 8, 28, "TraditionalFormEquation"],
Cell[2703191, 138003, 268, 6, 28, "TraditionalFormEquation"],
Cell[2703462, 138011, 265, 7, 28, "TraditionalFormEquation"],
Cell[2703730, 138020, 238, 6, 28, "TraditionalFormEquation"],
Cell[2703971, 138028, 261, 6, 28, "TraditionalFormEquation"],
Cell[2704235, 138036, 416, 12, 29, "TraditionalFormEquation"],
Cell[2704654, 138050, 427, 12, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2705118, 138067, 66, 0, 42, "Subsubsection"],
Cell[2705187, 138069, 1025, 35, 50, "Text"],
Cell[2706215, 138106, 886, 23, 28, "TraditionalFormEquation"],
Cell[2707104, 138131, 2828, 89, 124, "Text"],
Cell[2709935, 138222, 5275, 141, 135, "TraditionalFormEquation"],
Cell[2715213, 138365, 100, 3, 32, "Text"],
Cell[2715316, 138370, 2465, 62, 85, "TraditionalFormEquation"],
Cell[2717784, 138434, 2143, 54, 64, "TraditionalFormEquation"],
Cell[2719930, 138490, 846, 23, 64, "TraditionalFormEquation"],
Cell[2720779, 138515, 489, 14, 28, "TraditionalFormEquation"],
Cell[2721271, 138531, 2602, 63, 85, "TraditionalFormEquation"],
Cell[2723876, 138596, 910, 27, 68, "Text"],
Cell[2724789, 138625, 251, 6, 28, "TraditionalFormEquation"],
Cell[2725043, 138633, 527, 14, 28, "TraditionalFormEquation"],
Cell[2725573, 138649, 827, 22, 57, "TraditionalFormEquation"],
Cell[2726403, 138673, 445, 12, 28, "TraditionalFormEquation"],
Cell[2726851, 138687, 1199, 29, 52, "TraditionalFormEquation"],
Cell[2728053, 138718, 1286, 31, 52, "TraditionalFormEquation"],
Cell[2729342, 138751, 1216, 39, 50, "Text"],
Cell[2730561, 138792, 592, 15, 28, "TraditionalFormEquation"],
Cell[2731156, 138809, 592, 15, 28, "TraditionalFormEquation"],
Cell[2731751, 138826, 405, 10, 28, "TraditionalFormEquation"],
Cell[2732159, 138838, 435, 11, 28, "TraditionalFormEquation"],
Cell[2732597, 138851, 412, 10, 28, "TraditionalFormEquation"],
Cell[2733012, 138863, 558, 15, 28, "TraditionalFormEquation"],
Cell[2733573, 138880, 617, 18, 28, "TraditionalFormEquation"],
Cell[2734193, 138900, 487, 14, 28, "TraditionalFormEquation"],
Cell[2734683, 138916, 776, 22, 28, "TraditionalFormEquation"],
Cell[2735462, 138940, 777, 22, 28, "TraditionalFormEquation"],
Cell[2736242, 138964, 865, 26, 50, "Text"],
Cell[2737110, 138992, 510, 15, 29, "TraditionalFormEquation"],
Cell[2737623, 139009, 491, 14, 29, "TraditionalFormEquation"],
Cell[2738117, 139025, 759, 22, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2738913, 139052, 36, 0, 42, "Subsubsection"],
Cell[2738952, 139054, 1264, 42, 50, "Text"],
Cell[2740219, 139098, 2604, 93, 86, "Text"],
Cell[2742826, 139193, 454, 15, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2743317, 139213, 58, 0, 42, "Subsubsection"],
Cell[2743378, 139215, 1427, 48, 68, "Text"],
Cell[2744808, 139265, 2593, 86, 68, "Text"],
Cell[2747404, 139353, 253, 8, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2747694, 139366, 54, 0, 42, "Subsubsection"],
Cell[2747751, 139368, 731, 26, 32, "Text"],
Cell[2748485, 139396, 790, 26, 50, "Text"],
Cell[2749278, 139424, 660, 17, 35, "TraditionalFormEquation"],
Cell[2749941, 139443, 1098, 27, 36, "TraditionalFormEquation"],
Cell[2751042, 139472, 896, 25, 35, "TraditionalFormEquation"],
Cell[2751941, 139499, 1257, 33, 36, "TraditionalFormEquation"],
Cell[2753201, 139534, 456, 16, 32, "Text"],
Cell[2753660, 139552, 1743, 63, 50, "Text"],
Cell[2755406, 139617, 1303, 43, 50, "Text"],
Cell[2756712, 139662, 852, 22, 35, "TraditionalFormEquation"],
Cell[2757567, 139686, 1327, 33, 36, "TraditionalFormEquation"],
Cell[2758897, 139721, 1088, 30, 35, "TraditionalFormEquation"],
Cell[2759988, 139753, 1702, 45, 36, "TraditionalFormEquation"],
Cell[2761693, 139800, 1303, 43, 50, "Text"],
Cell[2762999, 139845, 841, 21, 35, "TraditionalFormEquation"],
Cell[2763843, 139868, 1316, 32, 36, "TraditionalFormEquation"],
Cell[2765162, 139902, 1077, 29, 35, "TraditionalFormEquation"],
Cell[2766242, 139933, 1691, 44, 36, "TraditionalFormEquation"],
Cell[2767936, 139979, 823, 28, 32, "Text"],
Cell[2768762, 140009, 539, 19, 32, "Text"],
Cell[2769304, 140030, 681, 22, 50, "Text"],
Cell[2769988, 140054, 594, 15, 35, "TraditionalFormEquation"],
Cell[2770585, 140071, 755, 18, 35, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2771377, 140094, 36, 0, 42, "Subsubsection"],
Cell[2771416, 140096, 1987, 66, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2773440, 140167, 44, 0, 42, "Subsubsection"],
Cell[2773487, 140169, 1186, 38, 50, "Text"],
Cell[2774676, 140209, 609, 16, 29, "TraditionalFormEquation"],
Cell[2775288, 140227, 1067, 28, 29, "TraditionalFormEquation"],
Cell[2776358, 140257, 845, 24, 30, "TraditionalFormEquation"],
Cell[2777206, 140283, 1303, 36, 30, "TraditionalFormEquation"],
Cell[2778512, 140321, 542, 14, 30, "TraditionalFormEquation"],
Cell[2779057, 140337, 68, 0, 32, "Text"],
Cell[2779128, 140339, 501, 13, 28, "TraditionalFormEquation"],
Cell[2779632, 140354, 763, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2780432, 140381, 47, 0, 42, "Subsubsection"],
Cell[2780482, 140383, 1493, 49, 50, "Text"],
Cell[2781978, 140434, 1056, 27, 50, "TraditionalFormEquation"],
Cell[2783037, 140463, 808, 21, 62, "TraditionalFormEquation"],
Cell[2783848, 140486, 842, 22, 64, "TraditionalFormEquation"],
Cell[2784693, 140510, 1511, 39, 72, "TraditionalFormEquation"],
Cell[2786207, 140551, 1772, 45, 70, "TraditionalFormEquation"],
Cell[2787982, 140598, 1419, 37, 62, "TraditionalFormEquation"],
Cell[2789404, 140637, 1593, 39, 64, "TraditionalFormEquation"],
Cell[2791000, 140678, 1792, 45, 72, "TraditionalFormEquation"],
Cell[2792795, 140725, 1373, 34, 50, "TraditionalFormEquation"],
Cell[2794171, 140761, 1078, 29, 62, "TraditionalFormEquation"],
Cell[2795252, 140792, 851, 23, 64, "TraditionalFormEquation"],
Cell[2796106, 140817, 2622, 63, 70, "TraditionalFormEquation"],
Cell[2798731, 140882, 1957, 51, 62, "TraditionalFormEquation"],
Cell[2800691, 140935, 1451, 38, 64, "TraditionalFormEquation"],
Cell[2802145, 140975, 1330, 36, 46, "TraditionalFormEquation"],
Cell[2803478, 141013, 1365, 35, 64, "TraditionalFormEquation"],
Cell[2804846, 141050, 2500, 65, 63, "TraditionalFormEquation"],
Cell[2807349, 141117, 2008, 50, 64, "TraditionalFormEquation"],
Cell[2809360, 141169, 1086, 29, 54, "TraditionalFormEquation"],
Cell[2810449, 141200, 1073, 28, 54, "TraditionalFormEquation"],
Cell[2811525, 141230, 2428, 63, 70, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2813990, 141298, 53, 0, 42, "Subsubsection"],
Cell[2814046, 141300, 1046, 32, 50, "Text"],
Cell[2815095, 141334, 779, 20, 44, "TraditionalFormEquation"],
Cell[2815877, 141356, 1019, 27, 48, "TraditionalFormEquation"],
Cell[2816899, 141385, 1265, 32, 44, "TraditionalFormEquation"],
Cell[2818167, 141419, 1259, 34, 62, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2819463, 141458, 49, 0, 42, "Subsubsection"],
Cell[2819515, 141460, 1184, 38, 50, "Text"],
Cell[2820702, 141500, 537, 14, 45, "TraditionalFormEquation"],
Cell[2821242, 141516, 665, 18, 47, "TraditionalFormEquation"],
Cell[2821910, 141536, 812, 22, 47, "TraditionalFormEquation"],
Cell[2822725, 141560, 944, 26, 49, "TraditionalFormEquation"],
Cell[2823672, 141588, 1420, 34, 47, "TraditionalFormEquation"],
Cell[2825095, 141624, 1378, 34, 47, "TraditionalFormEquation"],
Cell[2826476, 141660, 1291, 32, 52, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2827804, 141697, 40, 0, 42, "Subsubsection"],
Cell[2827847, 141699, 407, 14, 32, "Text"],
Cell[2828257, 141715, 827, 22, 44, "TraditionalFormEquation"],
Cell[2829087, 141739, 1803, 45, 64, "TraditionalFormEquation"],
Cell[2830893, 141786, 902, 24, 44, "TraditionalFormEquation"],
Cell[2831798, 141812, 1915, 49, 64, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2833750, 141866, 43, 0, 42, "Subsubsection"],
Cell[2833796, 141868, 596, 18, 50, "Text"],
Cell[2834395, 141888, 916, 26, 44, "TraditionalFormEquation"],
Cell[2835314, 141916, 1219, 31, 54, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2836570, 141952, 35, 0, 42, "Subsubsection"],
Cell[2836608, 141954, 1172, 38, 50, "Text"],
Cell[2837783, 141994, 648, 17, 44, "TraditionalFormEquation"],
Cell[2838434, 142013, 672, 18, 29, "TraditionalFormEquation"],
Cell[2839109, 142033, 1073, 27, 44, "TraditionalFormEquation"],
Cell[2840185, 142062, 1104, 29, 29, "TraditionalFormEquation"],
Cell[2841292, 142093, 876, 25, 46, "TraditionalFormEquation"],
Cell[2842171, 142120, 878, 25, 48, "TraditionalFormEquation"],
Cell[2843052, 142147, 1324, 36, 46, "TraditionalFormEquation"],
Cell[2844379, 142185, 1367, 37, 48, "TraditionalFormEquation"],
Cell[2845749, 142224, 467, 13, 28, "TraditionalFormEquation"],
Cell[2846219, 142239, 530, 15, 28, "TraditionalFormEquation"],
Cell[2846752, 142256, 125, 3, 32, "Text"],
Cell[2846880, 142261, 1228, 32, 62, "TraditionalFormEquation"],
Cell[2848111, 142295, 1485, 37, 62, "TraditionalFormEquation"],
Cell[2849599, 142334, 1966, 50, 62, "TraditionalFormEquation"],
Cell[2851568, 142386, 2347, 56, 83, "TraditionalFormEquation"],
Cell[2853918, 142444, 1220, 32, 62, "TraditionalFormEquation"],
Cell[2855141, 142478, 1295, 34, 64, "TraditionalFormEquation"],
Cell[2856439, 142514, 1911, 48, 62, "TraditionalFormEquation"],
Cell[2858353, 142564, 1989, 50, 64, "TraditionalFormEquation"],
Cell[2860345, 142616, 766, 20, 54, "TraditionalFormEquation"],
Cell[2861114, 142638, 755, 20, 52, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2861906, 142663, 55, 0, 42, "Subsubsection"],
Cell[2861964, 142665, 1333, 45, 50, "Text"],
Cell[2863300, 142712, 582, 16, 44, "TraditionalFormEquation"],
Cell[2863885, 142730, 740, 20, 46, "TraditionalFormEquation"],
Cell[2864628, 142752, 708, 19, 46, "TraditionalFormEquation"],
Cell[2865339, 142773, 799, 22, 48, "TraditionalFormEquation"],
Cell[2866141, 142797, 959, 26, 48, "TraditionalFormEquation"],
Cell[2867103, 142825, 959, 26, 48, "TraditionalFormEquation"],
Cell[2868065, 142853, 1295, 41, 50, "Text"],
Cell[2869363, 142896, 568, 17, 44, "TraditionalFormEquation"],
Cell[2869934, 142915, 1396, 38, 46, "TraditionalFormEquation"],
Cell[2871333, 142955, 1799, 48, 51, "TraditionalFormEquation"],
Cell[2873135, 143005, 1680, 45, 48, "TraditionalFormEquation"],
Cell[2874818, 143052, 773, 24, 50, "Text"],
Cell[2875594, 143078, 2257, 73, 50, "Text"],
Cell[2877854, 143153, 3068, 73, 44, "TraditionalFormEquation"],
Cell[2880925, 143228, 5711, 133, 63, "TraditionalFormEquation"],
Cell[2886639, 143363, 3272, 80, 44, "TraditionalFormEquation"],
Cell[2889914, 143445, 6425, 155, 63, "TraditionalFormEquation"],
Cell[2896342, 143602, 4454, 100, 66, "TraditionalFormEquation"],
Cell[2900799, 143704, 7773, 162, 118, "TraditionalFormEquation"],
Cell[2908575, 143868, 1777, 58, 50, "Text"],
Cell[2910355, 143928, 1757, 46, 52, "TraditionalFormEquation"],
Cell[2912115, 143976, 6057, 128, 150, "TraditionalFormEquation"],
Cell[2918175, 144106, 1912, 49, 52, "TraditionalFormEquation"],
Cell[2920090, 144157, 1944, 50, 52, "TraditionalFormEquation"],
Cell[2922037, 144209, 11099, 229, 201, "TraditionalFormEquation"],
Cell[2933139, 144440, 2138, 57, 52, "TraditionalFormEquation"],
Cell[2935280, 144499, 2166, 53, 62, "TraditionalFormEquation"],
Cell[2937449, 144554, 2298, 60, 52, "TraditionalFormEquation"],
Cell[2939750, 144616, 2275, 59, 52, "TraditionalFormEquation"],
Cell[2942028, 144677, 14307, 279, 293, "TraditionalFormEquation"],
Cell[2956338, 144958, 681, 19, 44, "TraditionalFormEquation"],
Cell[2957022, 144979, 6901, 148, 241, "TraditionalFormEquation"],
Cell[2963926, 145129, 7970, 166, 294, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2971933, 145300, 47, 0, 42, "Subsubsection"],
Cell[2971983, 145302, 1048, 34, 50, "Text"],
Cell[2973034, 145338, 894, 24, 28, "TraditionalFormEquation"],
Cell[2973931, 145364, 1145, 30, 28, "TraditionalFormEquation"],
Cell[2975079, 145396, 1145, 30, 28, "TraditionalFormEquation"],
Cell[2976227, 145428, 1024, 28, 28, "TraditionalFormEquation"],
Cell[2977254, 145458, 1275, 34, 28, "TraditionalFormEquation"],
Cell[2978532, 145494, 1372, 36, 28, "TraditionalFormEquation"],
Cell[2979907, 145532, 246, 10, 32, "Text"],
Cell[2980156, 145544, 248, 6, 32, "Text"],
Cell[2980407, 145552, 615, 17, 44, "TraditionalFormEquation"],
Cell[2981025, 145571, 877, 27, 50, "Text"],
Cell[2981905, 145600, 1074, 29, 29, "TraditionalFormEquation"],
Cell[2982982, 145631, 1408, 38, 29, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2984439, 145675, 53, 0, 29, "Subsection"],
Cell[2984495, 145677, 331, 6, 68, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

