(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    471956,       9937]*)
(*NotebookOutlinePosition[    518034,      11459]*)
(*  CellTagsIndexPosition[    517990,      11455]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "The cosine function in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "Section"],

Cell[CellGroupData[{

Cell["Overview", "Subsection"],

Cell[TextData[{
  "The following shows how the cosine function is realized in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". In the following, various examples of evaluating ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions applied to various numeric and exact expressions that involve \
the cosine function or return it are shown. These involve plots, numeric, and \
symbolic calculations."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Notations", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " forms of notations"
}], "Subsubsection"],

Cell[TextData[{
  "Following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s general naming convention, the functions names in ",
  StyleBox["StandardForm", "Input",
    FontWeight->"Plain"],
  " are just capitalized versions of the traditional mathematics names which \
are also used in ",
  StyleBox["TraditionalForm", "Input",
    FontWeight->"Plain"],
  ". In the case of cosine function these forms are the following."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cos", "[", "z", "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Cos", "[", "z", "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "TraditionalForm"}]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"cos", "(", "z", ")"}], TraditionalForm]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Additional forms of notations", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " also knows about the most popular forms of notations for the cosine \
function that is used in other programming languages. Here are three \
examples: ",
  StyleBox["CForm,",
    FontFamily->"Courier"],
  " ",
  StyleBox["TeXForm",
    FontFamily->"Courier"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "and ",
  StyleBox["FortranForm",
    FontFamily->"Courier"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"CForm", "[", 
          RowBox[{"Cos", "[", 
            RowBox[{"2", "\[Pi]", " ", "z"}], "]"}], "]"}], ",", 
        RowBox[{"FortranForm", "[", 
          RowBox[{"Cos", "[", 
            RowBox[{"2", "\[Pi]", " ", "z"}], "]"}], "]"}], ",", 
        RowBox[{"TeXForm", "[", 
          RowBox[{"Cos", "[", 
            RowBox[{"2", "\[Pi]", " ", "z"}], "]"}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          StyleBox[
            RowBox[{"Cos", 
              RowBox[{"(", 
                RowBox[{"2", "*", "Pi", "*", "z"}], ")"}]}],
            ShowStringCharacters->True,
            NumberMarks->True],
          CForm[ 
            Cos[ 
              Times[ 2, Pi, z]]],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox[
            RowBox[{"Cos", 
              RowBox[{"(", 
                RowBox[{"2", "*", "Pi", "*", "z"}], ")"}]}],
            ShowStringCharacters->True,
            NumberMarks->True],
          FortranForm[ 
            Cos[ 
              Times[ 2, Pi, z]]],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox[
            RowBox[{
              RowBox[{"\\", "cos"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", "\\"}], ",", 
                  RowBox[{
                    RowBox[{"\\", "pi"}], " ", "\\"}], ",", "z"}], ")"}]}],
            ShowStringCharacters->True,
            NumberMarks->True],
          TeXForm[ 
            Cos[ 
              Times[ 2, Pi, z]]],
          Editable->True,
          AutoDelete->True]}], "}"}]], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Automatic evaluations and transformations", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Evaluation for exact, machine\[Hyphen]number, and \
high\[Hyphen]precision arguments\
\>", "Subsubsection"],

Cell[TextData[{
  "For the exact argument ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "=", 
          RowBox[{"\[Pi]", "/", "4"}]}], TraditionalForm]]],
  ", ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " returns an exact result."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cos", "[", 
      FractionBox["\[Pi]", "4"], "]"}]], "Input"],

Cell[BoxData[
    FractionBox["1", 
      SqrtBox["2"]]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Cos", "[", "z", "]"}], "/.", "\[InvisibleSpace]", 
      RowBox[{"z", "\[Rule]", 
        FractionBox["\[Pi]", "4"]}]}]], "Input"],

Cell[BoxData[
    FractionBox["1", 
      SqrtBox["2"]]], "Output"]
}, Closed]],

Cell["\<\
For a machine\[Hyphen]number argument (a numerical argument with a \
decimal point and not too many digits), a machine number is also \
returned.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cos", "[", "5.", "]"}]], "Input"],

Cell[BoxData["0.28366218546322625`"], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Cos", "[", "z", "]"}], "/.", "\[InvisibleSpace]", 
      RowBox[{"z", "\[Rule]", "3."}]}]], "Input"],

Cell[BoxData[
    RowBox[{"-", "0.9899924966004454`"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "These calculate 100\[Hyphen]digit approximations at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "=", "1"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "=", "2"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"N", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"Cos", "[", "z", "]"}], "/.", "\[InvisibleSpace]", 
          RowBox[{"z", "\[Rule]", "1"}]}], ",", "100"}], "]"}]], "Input"],

Cell[BoxData[
  "0.5403023058681397174009366074429766037323104206179222276700972553811003947\
7447176451795185608718308934357173116`100"], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"N", "[", 
      RowBox[{
        RowBox[{"Cos", "[", "2", "]"}], ",", "100"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
    "-", "0.416146836547142386997568229500762189766000771075544890755149973781\
9649361240791690745317778601691403673667913652157`100"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Cos", "[", "2", "]"}], "//", 
      RowBox[{
        RowBox[{"N", "[", 
          RowBox[{"#", ",", "100"}], "]"}], "&"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
    "-", "0.416146836547142386997568229500762189766000771075544890755149973781\
9649361240791690745317778601691403673667913652157`100"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "Within a second, it is possible to calculate thousands of digits for the \
cosine function. This calculates 10000 digits for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "1", ")"}], TraditionalForm]]],
  " and analyzes the frequency of the digit ",
  Cell[BoxData[
      FormBox["k", TraditionalForm]]],
  " in the resulting decimal number."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Map", "[", 
      RowBox[{
        RowBox[{"Function", "[", 
          RowBox[{"w", ",", " ", 
            RowBox[{
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"First", "[", "#", "]"}], ",", 
                    RowBox[{"Length", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
              RowBox[{"Split", "[", 
                RowBox[{"Sort", "[", 
                  RowBox[{"First", "[", 
                    RowBox[{"RealDigits", "[", "w", "]"}], "]"}], "]"}], 
                "]"}]}]}], "]"}], " ", ",", " ", 
        RowBox[{"N", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"{", 
                RowBox[{"Cos", "[", "z", "]"}], "}"}], "/.", 
              "\[InvisibleSpace]", 
              RowBox[{"z", "\[Rule]", "1"}]}], ",", "10000"}], "]"}]}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"0", ",", "998"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"1", ",", "1034"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"2", ",", "982"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"3", ",", "1015"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"4", ",", "1013"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"5", ",", "963"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"6", ",", "1034"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"7", ",", "966"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"8", ",", "991"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"9", ",", "1004"}], "}"}]}], "}"}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "Here is 50\[Hyphen]digit approximation of the cosine function at the \
complex argument ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "=", 
          RowBox[{"3", "+", 
            RowBox[{"2", "i"}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"N", "[", 
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{"3", "+", 
            RowBox[{"2", " ", "\[ImaginaryI]"}]}], "]"}], ",", "50"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
      "-", "3.7245455049153225654739707032559725286749657732153307267858945631\
036`50"}], "-", 
      RowBox[{
      "0.5118225699873846088344638498018756342455566094907438674553837746766`\
50", " ", "\[ImaginaryI]"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"N", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"Cos", "[", "z", "]"}], "/.", "\[InvisibleSpace]", 
              RowBox[{"z", "\[Rule]", 
                RowBox[{"3", "+", 
                  RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]}], ",", "50"}], 
          "]"}], ",", 
        RowBox[{
          RowBox[{"Cos", "[", 
            RowBox[{"3", "+", 
              RowBox[{"2", " ", "\[ImaginaryI]"}]}], "]"}], "//", 
          RowBox[{
            RowBox[{"N", "[", 
              RowBox[{"#", ",", "50"}], "]"}], "&"}]}]}], "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
          "-", "3.724545504915322565473970703255972528674965773215330726785894\
5631036`50"}], "-", 
          RowBox[{
          "0.51182256998738460883446384980187563424555660949074386745538377467\
66`50", " ", "\[ImaginaryI]"}]}], ",", 
        RowBox[{
          RowBox[{
          "-", "3.724545504915322565473970703255972528674965773215330726785894\
5631036`50"}], "-", 
          RowBox[{
          "0.51182256998738460883446384980187563424555660949074386745538377467\
66`50", " ", "\[ImaginaryI]"}]}]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " always automatically evaluates mathematical functions with machine \
precision, if the arguments of function are machine\[Hyphen]number elements. \
In this case, only six digits after the decimal point are shown in the \
results. The remaining digits are suppressed, but can be displayed using the \
",
  "function",
  " ",
  StyleBox["InputForm", "Input",
    FontWeight->"Plain"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", "2.", "]"}], ",", 
        RowBox[{"N", "[", 
          RowBox[{"Cos", "[", "2", "]"}], "]"}], ",", 
        RowBox[{"N", "[", 
          RowBox[{
            RowBox[{"Cos", "[", "2", "]"}], ",", "16"}], "]"}], ",", 
        RowBox[{"N", "[", 
          RowBox[{
            RowBox[{"Cos", "[", "2", "]"}], ",", "5"}], "]"}], ",", 
        RowBox[{"N", "[", 
          RowBox[{
            RowBox[{"Cos", "[", "2", "]"}], ",", "20"}], "]"}]}], 
      "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"-", "0.4161468365471424`"}], ",", 
        RowBox[{"-", "0.4161468365471424`"}], ",", 
        RowBox[{"-", "0.4161468365471424`"}], ",", 
        RowBox[{"-", "0.4161468365471424`"}], ",", 
        RowBox[{"-", "0.416146836547142386997568229500762`20"}]}], 
      "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "InputForm"}]], "Input"],

Cell["\<\
{-0.4161468365471424, -0.4161468365471424, -0.4161468365471424, \
-0.4161468365471424, 
 -0.416146836547142386997568229500762`20}\
\>", "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simplification of the argument", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows symmetry and periodicity of cosine function. Here are some \
examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cos", "[", 
      RowBox[{"-", "3"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Cos", "[", "3", "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{"-", "z"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"z", "+", "\[Pi]"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"z", "+", 
            RowBox[{"2", "\[Pi]"}]}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"z", "+", 
            RowBox[{"342", "\[Pi]"}]}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{
            RowBox[{"-", "z"}], "+", 
            RowBox[{"21", "\[Pi]"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        RowBox[{"-", 
          RowBox[{"Cos", "[", "z", "]"}]}], ",", 
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        RowBox[{"-", 
          RowBox[{"Cos", "[", "z", "]"}]}]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " automatically simplifies the composition of the direct and the inverse \
cosine functions into its argument."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cos", "[", 
      RowBox[{"ArcCos", "[", "z", "]"}], "]"}]], "Input"],

Cell[BoxData["z"], "Output"]
}, Closed]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " also automatically simplifies the composition of the direct and any of \
the inverse trigonometric functions into algebraic functions of the \
argument."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{"ArcSin", "[", "z", "]"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"ArcCos", "[", "z", "]"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"ArcTan", "[", "z", "]"}], "]"}], ",", " ", 
        RowBox[{"Cos", "[", 
          RowBox[{"ArcCot", "[", "z", "]"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"ArcCsc", "[", "z", "]"}], "]"}], ",", " ", 
        RowBox[{"Cos", "[", 
          RowBox[{"ArcSec", "[", "z", "]"}], "]"}]}], "}"}]], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        SqrtBox[
          RowBox[{"1", "-", 
            SuperscriptBox["z", "2"]}]], ",", "z", ",", 
        FractionBox["1", 
          SqrtBox[
            RowBox[{"1", "+", 
              SuperscriptBox["z", "2"]}]]], ",", 
        FractionBox["1", 
          SqrtBox[
            RowBox[{"1", "+", 
              FractionBox["1", 
                SuperscriptBox["z", "2"]]}]]], ",", 
        SqrtBox[
          RowBox[{"1", "-", 
            FractionBox["1", 
              SuperscriptBox["z", "2"]]}]], ",", 
        FractionBox["1", "z"]}], "}"}]], "Output",
  CellLabel->"Out[1]="]
}, Closed]],

Cell[TextData[{
  "If the argument has the structure ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Pi]", " ", 
            RowBox[{"k", "/", "2"}]}], "+", "z"}], TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Pi]", " ", 
            RowBox[{"k", "/", "2"}]}], "-", "z"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Pi]", " ", 
            RowBox[{"k", "/", "2"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]}], TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Pi]", " ", 
            RowBox[{"k", "/", "2"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]}], TraditionalForm]]],
  " with integer ",
  Cell[BoxData[
      FormBox["k", TraditionalForm]]],
  ", the cosine function can be automatically transformed into trigonometric \
or hyperbolic sine or cosine functions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cos", "[", 
      RowBox[{
        FractionBox["\[Pi]", "2"], "-", "4"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Sin", "[", "4", "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{
            FractionBox["\[Pi]", "2"], "-", "z"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{
            FractionBox["\[Pi]", "2"], "+", "z"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{
            RowBox[{"-", 
              FractionBox["\[Pi]", "2"]}], "-", "z"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{
            RowBox[{"-", 
              FractionBox["\[Pi]", "2"]}], "+", "z"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"\[Pi]", "-", "z"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"\[Pi]", "+", "z"}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Sin", "[", "z", "]"}], ",", 
        RowBox[{"-", 
          RowBox[{"Sin", "[", "z", "]"}]}], ",", 
        RowBox[{"-", 
          RowBox[{"Sin", "[", "z", "]"}]}], ",", 
        RowBox[{"Sin", "[", "z", "]"}], ",", 
        RowBox[{"-", 
          RowBox[{"Cos", "[", "z", "]"}]}], ",", 
        RowBox[{"-", 
          RowBox[{"Cos", "[", "z", "]"}]}]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cos", "[", 
      RowBox[{"\[ImaginaryI]", " ", "5"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Cosh", "[", "5", "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{"\[ImaginaryI]", " ", "z"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{
            FractionBox["\[Pi]", "2"], "-", 
            RowBox[{"\[ImaginaryI]", " ", "z"}]}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{
            FractionBox["\[Pi]", "2"], "+", 
            RowBox[{"\[ImaginaryI]", " ", "z"}]}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"\[Pi]", "-", 
            RowBox[{"\[ImaginaryI]", " ", "z"}]}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"\[Pi]", "+", 
            RowBox[{"\[ImaginaryI]", " ", "z"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cosh", "[", "z", "]"}], ",", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Sinh", "[", "z", "]"}]}], ",", 
        RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"Sinh", "[", "z", "]"}]}], ",", 
        RowBox[{"-", 
          RowBox[{"Cosh", "[", "z", "]"}]}], ",", 
        RowBox[{"-", 
          RowBox[{"Cosh", "[", "z", "]"}]}]}], "}"}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Simplification of simple expressions containing the cosine function\
\
\>", "Subsubsection"],

Cell["\<\
Sometimes simple arithmetic operations containing the cosine \
function can automatically produce other trigonometric functions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"1", "/", 
      RowBox[{"Cos", "[", "4", "]"}]}]], "Input"],

Cell[BoxData[
    RowBox[{"Sec", "[", "4", "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"1", "/", 
          RowBox[{"Cos", "[", "z", "]"}]}], ",", 
        RowBox[{"1", "/", 
          RowBox[{"Cos", "[", 
            RowBox[{
              RowBox[{"\[Pi]", "/", "2"}], "-", "z"}], "]"}]}], ",", 
        RowBox[{
          RowBox[{"Cos", "[", 
            RowBox[{
              RowBox[{"\[Pi]", "/", "2"}], "-", "z"}], "]"}], "/", 
          RowBox[{"Cos", "[", "z", "]"}]}], ",", 
        RowBox[{
          RowBox[{"Cos", "[", "z", "]"}], "/", 
          RowBox[{"Cos", "[", 
            RowBox[{
              RowBox[{"\[Pi]", "/", "2"}], "-", "z"}], "]"}]}], ",", 
        RowBox[{"1", "/", 
          RowBox[{"Cos", "[", 
            RowBox[{
              RowBox[{"\[Pi]", "/", "2"}], "-", "z"}], "]"}]}], ",", 
        RowBox[{
          RowBox[{"Cos", "[", 
            RowBox[{
              RowBox[{"\[Pi]", "/", "2"}], "-", "z"}], "]"}], "/", 
          RowBox[{
            RowBox[{"Cos", "[", "z", "]"}], "^", "2"}]}]}], "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Sec", "[", "z", "]"}], ",", 
        RowBox[{"Csc", "[", "z", "]"}], ",", 
        RowBox[{"Tan", "[", "z", "]"}], ",", 
        RowBox[{"Cot", "[", "z", "]"}], ",", 
        RowBox[{"Csc", "[", "z", "]"}], ",", 
        RowBox[{
          RowBox[{"Sec", "[", "z", "]"}], " ", 
          RowBox[{"Tan", "[", "z", "]"}]}]}], "}"}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The cosine function arising as special cases from more general \
functions\
\>", "Subsubsection"],

Cell[TextData[{
  "The cosine function can be treated as a particular case of some more \
sophisticated special functions. For example, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " can appear automatically from Bessel, Mathieu, Jacobi, hypergeometric, \
and Meijer functions for appropriate values of their parameters."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"BesselJ", "[", 
          RowBox[{
            RowBox[{"-", 
              FractionBox["1", "2"]}], ",", "z"}], "]"}], ",", 
        RowBox[{"MathieuC", "[", 
          RowBox[{"1", ",", "0", ",", "z"}], "]"}], ",", 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "0"}], "]"}], ",", " ", 
        RowBox[{"Hypergeometric0F1", "[", 
          RowBox[{
            FractionBox["1", "2"], ",", 
            RowBox[{"-", 
              FractionBox[
                SuperscriptBox["z", "2"], "4"]}]}], "]"}], ",", 
        RowBox[{"MeijerG", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"{", "}"}], ",", 
                RowBox[{"{", "}"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"{", "0", "}"}], ",", 
                RowBox[{"{", 
                  FractionBox["1", "2"], "}"}]}], "}"}], ",", 
            FractionBox[
              SuperscriptBox["z", "2"], "4"]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        FractionBox[
          RowBox[{
            SqrtBox[
              FractionBox["2", "\[Pi]"]], " ", 
            RowBox[{"Cos", "[", "z", "]"}]}], 
          SqrtBox["z"]], ",", 
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        RowBox[{"Cos", "[", 
          SqrtBox[
            SuperscriptBox["z", "2"]], "]"}], ",", 
        FractionBox[
          RowBox[{"Cos", "[", "z", "]"}], 
          SqrtBox["\[Pi]"]]}], "}"}]], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Equivalence transformations carried out by specialized ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions"
}], "Subsection"],

Cell[CellGroupData[{

Cell["General remarks", "Subsubsection"],

Cell[TextData[{
  "Almost everybody prefers ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"cos", "(", "z", ")"}], "/", "2"}], TraditionalForm]]],
  " instead of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"sin", "(", 
            RowBox[{
              RowBox[{"\[Pi]", "/", "2"}], "-", "z"}], ")"}], 
          RowBox[{"cos", "(", 
            RowBox[{"\[Pi]", "/", "3"}], ")"}]}], TraditionalForm]]],
  " and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " automatically transforms the last expression into the first one. \
Automatic application of transformation rules to mathematical expressions can \
result in overly complicated results. Compact expressions like ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"cos", "(", 
            RowBox[{"2", "z"}], ")"}], 
          RowBox[{"cos", "(", 
            RowBox[{"\[Pi]", "/", "16"}], ")"}]}], TraditionalForm]]],
  " should not be automatically expanded into the more complicated expression \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["cos", "2"], "(", "z", ")"}], "-", 
              FractionBox["1", "2"]}], ")"}], 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"2", "+", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"2", "+", 
                      SuperscriptBox["2", 
                        RowBox[{"1", "/", "2"}]]}], ")"}], 
                  RowBox[{"1", "/", "2"}]]}], ")"}], 
            RowBox[{"1", "/", "2"}]]}], TraditionalForm]]],
  ". ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has special ",
  "function",
  "s that produce such expansions. Some are demonstrated below. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigExpand", "Subsubsection"],

Cell[TextData[{
  "The ",
  "function",
  " ",
  StyleBox["TrigExpand", "Input",
    FontWeight->"Plain"],
  " expands out trigonometric and hyperbolic functions. In more detail, it \
splits up sums and integer multiples that appear in arguments of \
trigonometric and hyperbolic functions, and then expands out products of \
trigonometric and hyperbolic functions into sums of powers, using \
trigonometric and hyperbolic identities where possible. Here are some \
examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TrigExpand", "[", 
      RowBox[{"Cos", "[", 
        RowBox[{"x", "-", "y"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Cos", "[", "x", "]"}], " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "+", 
      RowBox[{
        RowBox[{"Sin", "[", "x", "]"}], " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Cos", "[", 
        RowBox[{"4", "z"}], "]"}], "//", "TrigExpand"}]], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox[
        RowBox[{"Cos", "[", "z", "]"}], "4"], "-", 
      RowBox[{"6", " ", 
        SuperscriptBox[
          RowBox[{"Cos", "[", "z", "]"}], "2"], " ", 
        SuperscriptBox[
          RowBox[{"Sin", "[", "z", "]"}], "2"]}], "+", 
      SuperscriptBox[
        RowBox[{"Sin", "[", "z", "]"}], "4"]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      SuperscriptBox[
        RowBox[{"Cos", "[", 
          RowBox[{"2", "z"}], "]"}], "2"], "//", "TrigExpand"}]], "Input"],

Cell[BoxData[
    RowBox[{
      FractionBox["1", "2"], "+", 
      FractionBox[
        SuperscriptBox[
          RowBox[{"Cos", "[", "z", "]"}], "4"], "2"], "-", 
      RowBox[{"3", " ", 
        SuperscriptBox[
          RowBox[{"Cos", "[", "z", "]"}], "2"], " ", 
        SuperscriptBox[
          RowBox[{"Sin", "[", "z", "]"}], "2"]}], "+", 
      FractionBox[
        SuperscriptBox[
          RowBox[{"Sin", "[", "z", "]"}], "4"], "2"]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TrigExpand", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Cos", "[", 
            RowBox[{"x", "+", "y", "+", "z"}], "]"}], ",", 
          RowBox[{"Cos", "[", 
            RowBox[{"3", " ", "z"}], "]"}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"Cos", "[", "x", "]"}], " ", 
            RowBox[{"Cos", "[", "y", "]"}], " ", 
            RowBox[{"Cos", "[", "z", "]"}]}], "-", 
          RowBox[{
            RowBox[{"Cos", "[", "z", "]"}], " ", 
            RowBox[{"Sin", "[", "x", "]"}], " ", 
            RowBox[{"Sin", "[", "y", "]"}]}], "-", 
          RowBox[{
            RowBox[{"Cos", "[", "y", "]"}], " ", 
            RowBox[{"Sin", "[", "x", "]"}], " ", 
            RowBox[{"Sin", "[", "z", "]"}]}], "-", 
          RowBox[{
            RowBox[{"Cos", "[", "x", "]"}], " ", 
            RowBox[{"Sin", "[", "y", "]"}], " ", 
            RowBox[{"Sin", "[", "z", "]"}]}]}], ",", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"Cos", "[", "z", "]"}], "3"], "-", 
          RowBox[{"3", " ", 
            RowBox[{"Cos", "[", "z", "]"}], " ", 
            SuperscriptBox[
              RowBox[{"Sin", "[", "z", "]"}], "2"]}]}]}], "}"}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigFactor", "Subsubsection"],

Cell[TextData[{
  "The ",
  "function",
  " ",
  StyleBox["TrigFactor", "Input",
    FontWeight->"Plain"],
  " factors trigonometric and hyperbolic functions. In more detail, it splits \
up sums and integer multiples that appear in arguments of trigonometric and \
hyperbolic functions, and then factors resulting polynomials in trigonometric \
and hyperbolic functions, using trigonometric and hyperbolic identities where \
possible. Here are some examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TrigFactor", "[", 
      RowBox[{
        RowBox[{"Cos", "[", "x", "]"}], "+", 
        RowBox[{"Cos", "[", "y", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"2", " ", 
      RowBox[{"Cos", "[", 
        RowBox[{
          FractionBox["x", "2"], "-", 
          FractionBox["y", "2"]}], "]"}], " ", 
      RowBox[{"Cos", "[", 
        RowBox[{
          FractionBox["x", "2"], "+", 
          FractionBox["y", "2"]}], "]"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Cos", "[", "x", "]"}], "+", 
        RowBox[{"Sin", "[", "y", "]"}]}], "//", "TrigFactor"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        RowBox[{
          RowBox[{"Cos", "[", 
            RowBox[{
              FractionBox["x", "2"], "-", 
              FractionBox["y", "2"]}], "]"}], "-", 
          RowBox[{"Sin", "[", 
            RowBox[{
              FractionBox["x", "2"], "-", 
              FractionBox["y", "2"]}], "]"}]}], ")"}], " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"Cos", "[", 
            RowBox[{
              FractionBox["x", "2"], "+", 
              FractionBox["y", "2"]}], "]"}], "+", 
          RowBox[{"Sin", "[", 
            RowBox[{
              FractionBox["x", "2"], "+", 
              FractionBox["y", "2"]}], "]"}]}], ")"}]}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigReduce", "Subsubsection"],

Cell[TextData[{
  "The ",
  "function",
  " ",
  StyleBox["TrigReduce", "Input",
    FontWeight->"Plain"],
  " rewrites products and powers of trigonometric and hyperbolic functions in \
terms of trigonometric and hyperbolic functions with combined arguments. In \
more detail, it typically yields a linear expression involving trigonometric \
and hyperbolic functions with more complicated arguments. ",
  StyleBox["TrigReduce", "Input",
    FontWeight->"Plain"],
  " is approximately inverse to ",
  StyleBox["TrigExpand", "Input",
    FontWeight->"Plain"],
  " and ",
  StyleBox["TrigFactor", "Input",
    FontWeight->"Plain"],
  StyleBox[". ",
    FontWeight->"Plain"],
  "Here are some examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TrigReduce", "[", 
      RowBox[{
        RowBox[{"Cos", "[", "x", "]"}], 
        RowBox[{"Cos", "[", "y", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"Cos", "[", 
            RowBox[{"x", "-", "y"}], "]"}], "+", 
          RowBox[{"Cos", "[", 
            RowBox[{"x", "+", "y"}], "]"}]}], ")"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Sin", "[", "x", "]"}], 
        RowBox[{"Cos", "[", "y", "]"}]}], "//", "TrigReduce"}]], "Input"],

Cell[BoxData[
    RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"Sin", "[", 
            RowBox[{"x", "-", "y"}], "]"}], "+", 
          RowBox[{"Sin", "[", 
            RowBox[{"x", "+", "y"}], "]"}]}], ")"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Table", "[", 
      RowBox[{
        RowBox[{"TrigReduce", "[", 
          RowBox[{
            RowBox[{"Cos", "[", "z", "]"}], "^", "n"}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"n", ",", "2", ",", "5"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "z"}], "]"}]}], ")"}]}], ",", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", " ", 
                RowBox[{"Cos", "[", "z", "]"}]}], "+", 
              RowBox[{"Cos", "[", 
                RowBox[{"3", " ", "z"}], "]"}]}], ")"}]}], ",", 
        RowBox[{
          FractionBox["1", "8"], " ", 
          RowBox[{"(", 
            RowBox[{"3", "+", 
              RowBox[{"4", " ", 
                RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "z"}], "]"}]}], "+", 
              RowBox[{"Cos", "[", 
                RowBox[{"4", " ", "z"}], "]"}]}], ")"}]}], ",", 
        RowBox[{
          FractionBox["1", "16"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"10", " ", 
                RowBox[{"Cos", "[", "z", "]"}]}], "+", 
              RowBox[{"5", " ", 
                RowBox[{"Cos", "[", 
                  RowBox[{"3", " ", "z"}], "]"}]}], "+", 
              RowBox[{"Cos", "[", 
                RowBox[{"5", " ", "z"}], "]"}]}], ")"}]}]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TrigReduce", "[", 
      RowBox[{"TrigExpand", "[", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"Cos", "[", 
              RowBox[{"x", "+", "y", "+", "z"}], "]"}], ",", 
            RowBox[{"Cos", "[", 
              RowBox[{"3", " ", "z"}], "]"}], ",", 
            RowBox[{
              RowBox[{"Cos", "[", "x", "]"}], 
              RowBox[{"Cos", "[", "y", "]"}]}]}], "}"}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{"x", "+", "y", "+", "z"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
          RowBox[{"3", " ", "z"}], "]"}], ",", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"Cos", "[", 
                RowBox[{"x", "-", "y"}], "]"}], "+", 
              RowBox[{"Cos", "[", 
                RowBox[{"x", "+", "y"}], "]"}]}], ")"}]}]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigFactor", "[", 
        RowBox[{
          RowBox[{"Cos", "[", "x", "]"}], "+", 
          RowBox[{"Cos", "[", "y", "]"}]}], "]"}], "//", 
      "TrigReduce"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Cos", "[", "x", "]"}], "+", 
      RowBox[{"Cos", "[", "y", "]"}]}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigToExp", "Subsubsection"],

Cell[TextData[{
  "The ",
  "function",
  " ",
  StyleBox["TrigToExp", "Input",
    FontWeight->"Plain"],
  " converts trigonometric and hyperbolic functions to exponentials.",
  StyleBox[" ",
    FontWeight->"Plain"],
  "It tries, when possible, to give results that do not involve explicit \
complex numbers. Here are some examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TrigToExp", "[", 
      RowBox[{"Cos", "[", "z", "]"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      FractionBox[
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]], "2"], "+", 
      FractionBox[
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]], "2"]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{"a", " ", "z"}], "]"}], "+", 
        RowBox[{"Cos", "[", 
          RowBox[{"b", " ", "z"}], "]"}]}], "//", "TrigToExp"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "a", " ", "z"}]]}], "+", 
      RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "a", " ", "z"}]]}], "+", 
      RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "b", " ", "z"}]]}], "+", 
      RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "b", " ", "z"}]]}]}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ExpToTrig", "Subsubsection"],

Cell[TextData[{
  "The ",
  "function",
  " ",
  StyleBox["ExpToTrig", "Input",
    FontWeight->"Plain"],
  " converts exponentials to trigonometric and hyperbolic functions.",
  StyleBox[" ",
    FontWeight->"Plain"],
  "It is approximately inverse to ",
  StyleBox["TrigToExp", "Input",
    FontWeight->"Plain"],
  ". Here are some examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpToTrig", "[", 
      RowBox[{"TrigToExp", "[", 
        RowBox[{"Cos", "[", "z", "]"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Cos", "[", "z", "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"\[Alpha]", " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", "x", " ", 
                  "\[Beta]"}]]}], "+", 
            RowBox[{"\[Alpha]", " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", " ", "x", " ", "\[Beta]"}]]}]}], ",",
           
          RowBox[{
            RowBox[{"\[Alpha]", " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", "x", " ", 
                  "\[Beta]"}]]}], "+", 
            RowBox[{"\[Gamma]", " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", " ", "x", " ", "\[Beta]"}]]}]}]}], 
        "}"}], "//", "ExpToTrig"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"2", " ", "\[Alpha]", " ", 
          RowBox[{"Cos", "[", 
            RowBox[{"x", " ", "\[Beta]"}], "]"}]}], ",", 
        RowBox[{
          RowBox[{"\[Alpha]", " ", 
            RowBox[{"Cos", "[", 
              RowBox[{"x", " ", "\[Beta]"}], "]"}]}], "+", 
          RowBox[{"\[Gamma]", " ", 
            RowBox[{"Cos", "[", 
              RowBox[{"x", " ", "\[Beta]"}], "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
            RowBox[{"Sin", "[", 
              RowBox[{"x", " ", "\[Beta]"}], "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Gamma]", " ", 
            RowBox[{"Sin", "[", 
              RowBox[{"x", " ", "\[Beta]"}], "]"}]}]}]}], "}"}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ComplexExpand", "Subsubsection"],

Cell[TextData[{
  "The ",
  "function",
  " ",
  StyleBox["ComplexExpand", "Input",
    FontWeight->"Plain"],
  " expands expression assuming that all variables are real. The value option \
",
  StyleBox["TargetFunctions", "Input",
    FontWeight->"Plain"],
  " is a list of functions from the set {",
  StyleBox["Re,", "Input",
    FontWeight->"Plain"],
  " ",
  StyleBox["Im,", "Input",
    FontWeight->"Plain"],
  " ",
  StyleBox["Abs,", "Input",
    FontWeight->"Plain"],
  " ",
  StyleBox["Arg,", "Input",
    FontWeight->"Plain"],
  " ",
  StyleBox["Conjugate,", "Input",
    FontWeight->"Plain"],
  " ",
  StyleBox["Sign}", "Input",
    FontWeight->"Plain"],
  ". ",
  StyleBox["ComplexExpand", "Input",
    FontWeight->"Plain"],
  " tries to give results in terms of the functions specified. Here are some \
examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexExpand", "[", 
      RowBox[{"Cos", "[", 
        RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Cos", "[", "x", "]"}], " ", 
        RowBox[{"Cosh", "[", "y", "]"}]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "x", "]"}], " ", 
        RowBox[{"Sinh", "[", "y", "]"}]}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "+", 
        RowBox[{"Cos", "[", 
          RowBox[{"x", "-", 
            RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "//", 
      "ComplexExpand"}]], "Input"],

Cell[BoxData[
    RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "x", "]"}], " ", 
      RowBox[{"Cosh", "[", "y", "]"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexExpand", "[", 
      RowBox[{
        RowBox[{"Re", "[", 
          RowBox[{"Cos", "[", 
            RowBox[{"x", "+", 
              RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Cos", "[", "x", "]"}], " ", 
      RowBox[{"Cosh", "[", "y", "]"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexExpand", "[", 
      RowBox[{
        RowBox[{"Im", "[", 
          RowBox[{"Cos", "[", 
            RowBox[{"x", "+", 
              RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", 
        RowBox[{"Sin", "[", "x", "]"}]}], " ", 
      RowBox[{"Sinh", "[", "y", "]"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexExpand", "[", 
      RowBox[{
        RowBox[{"Abs", "[", 
          RowBox[{"Cos", "[", 
            RowBox[{"x", "+", 
              RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    SqrtBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"Cosh", "[", "y", "]"}], "2"]}], "+", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"Sin", "[", "x", "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"Sinh", "[", "y", "]"}], "2"]}]}]]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ComplexExpand", "[", 
        RowBox[{
          RowBox[{"Abs", "[", 
            RowBox[{"Cos", "[", 
              RowBox[{"x", "+", 
                RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
          RowBox[{"TargetFunctions", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "//", 
      RowBox[{
        RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"x", ",", "y"}], "}"}], "\[Element]", "Reals"}]}], 
          "]"}], "&"}]}]], "Input"],

Cell[BoxData[
    FractionBox[
      SqrtBox[
        RowBox[{
          RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "x"}], "]"}], "+", 
          RowBox[{"Cosh", "[", 
            RowBox[{"2", " ", "y"}], "]"}]}]], 
      SqrtBox["2"]]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexExpand", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"Re", "[", 
            RowBox[{"Cos", "[", 
              RowBox[{"x", "+", 
                RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "+", 
          RowBox[{"Im", "[", 
            RowBox[{"Cos", "[", 
              RowBox[{"x", "+", 
                RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Cos", "[", "x", "]"}], " ", 
        RowBox[{"Cosh", "[", "y", "]"}]}], "-", 
      RowBox[{
        RowBox[{"Sin", "[", "x", "]"}], " ", 
        RowBox[{"Sinh", "[", "y", "]"}]}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexExpand", "[", 
      RowBox[{
        RowBox[{"Arg", "[", 
          RowBox[{"Cos", "[", 
            RowBox[{"x", "+", 
              RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"ArcTan", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"Cos", "[", "x", "]"}], " ", 
          RowBox[{"Cosh", "[", "y", "]"}]}], ",", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"Sin", "[", "x", "]"}]}], " ", 
          RowBox[{"Sinh", "[", "y", "]"}]}]}], "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ComplexExpand", "[", 
        RowBox[{
          RowBox[{"Arg", "[", 
            RowBox[{"Cos", "[", 
              RowBox[{"x", "+", 
                RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
          RowBox[{"TargetFunctions", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "//", 
      RowBox[{
        RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"x", ",", "y"}], "}"}], "\[Element]", "Reals"}]}], 
          "]"}], "&"}]}]], "Input"],

Cell[BoxData[
    RowBox[{"ArcTan", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"Cos", "[", "x", "]"}], " ", 
          RowBox[{"Cosh", "[", "y", "]"}]}], ",", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"Sin", "[", "x", "]"}]}], " ", 
          RowBox[{"Sinh", "[", "y", "]"}]}]}], "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ComplexExpand", "[", 
        RowBox[{
          RowBox[{"Conjugate", "[", 
            RowBox[{"Cos", "[", 
              RowBox[{"x", "+", 
                RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
          RowBox[{"TargetFunctions", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "//", 
      "Simplify"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Cos", "[", "x", "]"}], " ", 
        RowBox[{"Cosh", "[", "y", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "x", "]"}], " ", 
        RowBox[{"Sinh", "[", "y", "]"}]}]}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simplify", "Subsubsection"],

Cell[TextData[{
  "The ",
  "function",
  " ",
  StyleBox["Simplify", "Input",
    FontWeight->"Plain"],
  " performs a sequence of algebraic transformations on its argument, and \
returns the simplest form it finds. Here are some examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{"2", 
            RowBox[{"ArcCos", "[", "z", "]"}]}], "]"}], "/", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
              SuperscriptBox["z", "2"]}]}], ")"}]}], "//", 
      "Simplify"}]], "Input"],

Cell[BoxData["1"], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Simplify", "[", 
          RowBox[{
            RowBox[{"Cos", "[", 
              RowBox[{"2", "z"}], "]"}], "-", 
            SuperscriptBox[
              RowBox[{"Cos", "[", "z", "]"}], "2"]}], "]"}], ",", 
        RowBox[{
          RowBox[{
            RowBox[{"Cos", "[", 
              RowBox[{"2", "z"}], "]"}], "+", 
            SuperscriptBox[
              RowBox[{"Sin", "[", "z", "]"}], "2"]}], "//", "Simplify"}]}], 
      "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox[
            RowBox[{"Sin", "[", "z", "]"}], "2"]}], ",", 
        SuperscriptBox[
          RowBox[{"Cos", "[", "z", "]"}], "2"]}], "}"}]], "Output"]
}, Closed]],

Cell["\<\
Here is a large collection of trigonometric identities. All are \
written as one large logical conjunction.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Simplify", "[", "#", "]"}], "&"}], "/@", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"Cos", "[", "z", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{"Sin", "[", "z", "]"}], "2"]}], "==", "1"}], "\[And]",
           "\n", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"Cos", "[", "z", "]"}], "2"], "==", 
            FractionBox[
              RowBox[{"1", "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", "z"}], "]"}]}], "2"]}], "\[And]", "\n", 
          RowBox[{
            RowBox[{"Cos", "[", 
              RowBox[{"2", "z"}], "]"}], "\[Equal]", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"Cos", "[", "z", "]"}], "2"], "-", 
              SuperscriptBox[
                RowBox[{"Sin", "[", "z", "]"}], "2"]}], "\[Equal]", 
            RowBox[{
              RowBox[{"2", 
                SuperscriptBox[
                  RowBox[{"Cos", "[", "z", "]"}], "2"]}], "-", "1"}]}], 
          "\[And]", "\n", 
          RowBox[{
            RowBox[{"Cos", "[", 
              RowBox[{"a", "+", "b"}], "]"}], "\[Equal]", 
            RowBox[{
              RowBox[{
                RowBox[{"Cos", "[", "a", "]"}], 
                RowBox[{"Cos", "[", "b", "]"}]}], "-", 
              RowBox[{
                RowBox[{"Sin", "[", "a", "]"}], 
                RowBox[{"Sin", "[", "b", "]"}]}]}]}], "\[And]", 
          RowBox[{
            RowBox[{"Cos", "[", 
              RowBox[{"a", "-", "b"}], "]"}], "\[Equal]", 
            RowBox[{
              RowBox[{
                RowBox[{"Cos", "[", "a", "]"}], 
                RowBox[{"Cos", "[", "b", "]"}]}], "+", 
              RowBox[{
                RowBox[{"Sin", "[", "a", "]"}], 
                RowBox[{"Sin", "[", "b", "]"}]}]}]}], "\[And]", "\n", "\n", 
          RowBox[{
            RowBox[{
              RowBox[{"Cos", "[", "a", "]"}], "+", 
              RowBox[{"Cos", "[", "b", "]"}]}], "\[Equal]", 
            RowBox[{"2", 
              RowBox[{"Cos", "[", 
                FractionBox[
                  RowBox[{"a", "+", "b"}], "2"], "]"}], 
              RowBox[{"Cos", "[", 
                FractionBox[
                  RowBox[{"a", "-", "b"}], "2"], "]"}]}]}], "\[And]", 
          RowBox[{
            RowBox[{
              RowBox[{"Cos", "[", "a", "]"}], "-", 
              RowBox[{"Cos", "[", "b", "]"}]}], "\[Equal]", 
            RowBox[{"2", 
              RowBox[{"Sin", "[", 
                FractionBox[
                  RowBox[{"a", "+", "b"}], "2"], "]"}], 
              RowBox[{"Sin", "[", 
                FractionBox[
                  RowBox[{"b", "-", "a"}], "2"], "]"}]}]}], "\[And]", "\n", 
          RowBox[{
            RowBox[{
              RowBox[{"A", " ", 
                RowBox[{"Sin", "[", "z", "]"}]}], "+", 
              RowBox[{"B", " ", 
                RowBox[{"Cos", "[", "z", "]"}]}]}], "\[Equal]", 
            RowBox[{"A", " ", 
              SqrtBox[
                RowBox[{"1", "+", 
                  FractionBox[
                    SuperscriptBox["B", "2"], 
                    SuperscriptBox["A", "2"]]}]], " ", 
              RowBox[{"Sin", "[", 
                RowBox[{"z", "+", 
                  RowBox[{"ArcTan", "[", 
                    FractionBox["B", "A"], "]"}]}], "]"}]}]}], "\[And]", "\n",
           
          RowBox[{
            RowBox[{
              RowBox[{"Cos", "[", "a", "]"}], 
              RowBox[{"Cos", "[", "b", "]"}]}], "\[Equal]", 
            FractionBox[
              RowBox[{
                RowBox[{"Cos", "[", 
                  RowBox[{"a", "-", "b"}], "]"}], "+", 
                RowBox[{"Cos", "[", 
                  RowBox[{"a", "+", "b"}], "]"}]}], "2"]}], "\[And]", 
          RowBox[{
            RowBox[{
              RowBox[{"Sin", "[", "a", "]"}], 
              RowBox[{"Cos", "[", "b", "]"}]}], "\[Equal]", 
            FractionBox[
              RowBox[{
                RowBox[{"Sin", "[", 
                  RowBox[{"a", "+", "b"}], "]"}], "+", 
                RowBox[{"Sin", "[", 
                  RowBox[{"a", "-", "b"}], "]"}]}], "2"]}], "\[And]", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"Cos", "[", 
                FractionBox["z", "2"], "]"}], "2"], "\[Equal]", 
            FractionBox[
              RowBox[{"1", "+", 
                RowBox[{"Cos", "[", "z", "]"}]}], "2"]}]}], ")"}]}]], "Input",\

  AutoIndent->False],

Cell[BoxData["True"], "Output"]
}, Closed]],

Cell[TextData[{
  "The ",
  "function",
  " ",
  StyleBox["Simplify", "Input",
    FontWeight->"Plain"],
  " has the ",
  StyleBox["Assumption", "Input",
    FontWeight->"Plain"],
  " option. For example, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"-", "1"}], "\[LessEqual]", 
          RowBox[{"cos", "(", "x", ")"}], "\[LessEqual]", "1"}], 
        TraditionalForm]]],
  " for all real ",
  Cell[BoxData[
      FormBox["x", TraditionalForm]]],
  ", and knows about the periodicity of trigonometric functions for the \
symbolic integer coefficient ",
  Cell[BoxData[
      FormBox["k", TraditionalForm]]],
  " of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", " ", "\[Pi]"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Simplify", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"Abs", "[", 
            RowBox[{"Cos", "[", "x", "]"}], "]"}], "\[LessEqual]", "1"}], ",",
         
        RowBox[{"x", "\[Element]", "Reals"}]}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Abs", "[", 
          RowBox[{"Cos", "[", "x", "]"}], "]"}], "\[LessEqual]", "1"}], "//", 
      
      RowBox[{
        RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
            RowBox[{"x", "\[Element]", "Reals"}]}], "]"}], "&"}]}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Simplify", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"Cos", "[", 
              RowBox[{"z", "+", 
                RowBox[{"2", " ", "k", " ", "\[Pi]"}]}], "]"}], ",", 
            RowBox[{
              RowBox[{"Cos", "[", 
                RowBox[{"z", "+", 
                  RowBox[{"k", " ", "\[Pi]"}]}], "]"}], "/", 
              RowBox[{"Cos", "[", "z", "]"}]}]}], "}"}], ",", 
        RowBox[{"k", "\[Element]", "Integers"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "k"]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " also knows that composition of inverse and direct trigonometric functions \
produces the value of internal argument under the corresponding restriction."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ArcCos", "[", 
      RowBox[{"Cos", "[", "z", "]"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"ArcCos", "[", 
      RowBox[{"Cos", "[", "z", "]"}], "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Simplify", "[", 
      RowBox[{
        RowBox[{"ArcCos", "[", 
          RowBox[{"Cos", "[", "z", "]"}], "]"}], ",", 
        RowBox[{"0", "<", 
          RowBox[{"Re", "[", "z", "]"}], "<", "\[Pi]"}]}], "]"}]], "Input"],

Cell[BoxData["z"], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FunctionExpand (and Together)", "Subsubsection"],

Cell[TextData[{
  "While the trigonometric functions auto\[Hyphen]evaluate for simple \
fractions of ",
  Cell[BoxData[
      FormBox["\[Pi]", TraditionalForm]]],
  ", for more complicated cases they stay as trigonometric functions to avoid \
the build\[Hyphen]up of large expressions. Using the function ",
  StyleBox["FunctionExpand,", "Input",
    FontWeight->"Plain"],
  " cosine function sometimes can be transformed into explicit radicals. Here \
are some examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", 
          FractionBox["\[Pi]", "16"], "]"}], ",", 
        RowBox[{"Cos", "[", 
          FractionBox["\[Pi]", "60"], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", 
          FractionBox["\[Pi]", "16"], "]"}], ",", 
        RowBox[{"Cos", "[", 
          FractionBox["\[Pi]", "60"], "]"}]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["FunctionExpand[%]", "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          SqrtBox[
            RowBox[{"2", "+", 
              SqrtBox[
                RowBox[{"2", "+", 
                  SqrtBox["2"]}]]}]]}], ",", 
        RowBox[{
          RowBox[{"-", 
            FractionBox[
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    FractionBox["1", "8"]}], " ", 
                  SqrtBox["3"], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", 
                      SqrtBox["5"]}], ")"}]}], "-", 
                RowBox[{
                  FractionBox["1", "4"], " ", 
                  SqrtBox[
                    RowBox[{
                      FractionBox["1", "2"], " ", 
                      RowBox[{"(", 
                        RowBox[{"5", "+", 
                          SqrtBox["5"]}], ")"}]}]]}]}], 
              SqrtBox["2"]]}], "-", 
          FractionBox[
            RowBox[{
              RowBox[{
                FractionBox["1", "8"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SqrtBox["5"]}], ")"}]}], "-", 
              RowBox[{
                FractionBox["1", "4"], " ", 
                SqrtBox[
                  RowBox[{
                    FractionBox["3", "2"], " ", 
                    RowBox[{"(", 
                      RowBox[{"5", "+", 
                        SqrtBox["5"]}], ")"}]}]]}]}], 
            SqrtBox["2"]]}]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Together", "[", "%", "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          SqrtBox[
            RowBox[{"2", "+", 
              SqrtBox[
                RowBox[{"2", "+", 
                  SqrtBox["2"]}]]}]]}], ",", 
        RowBox[{
          FractionBox["1", "16"], " ", 
          RowBox[{"(", 
            RowBox[{
              SqrtBox["2"], "-", 
              SqrtBox["6"], "-", 
              SqrtBox["10"], "+", 
              SqrtBox["30"], "+", 
              RowBox[{"2", " ", 
                SqrtBox[
                  RowBox[{"5", "+", 
                    SqrtBox["5"]}]]}], "+", 
              RowBox[{"2", " ", 
                SqrtBox[
                  RowBox[{"3", " ", 
                    RowBox[{"(", 
                      RowBox[{"5", "+", 
                        SqrtBox["5"]}], ")"}]}]]}]}], ")"}]}]}], 
      "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "If the denominator contains squares of integers other than 2, the results \
always contain the complex numbers (meaning the imaginary number ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ImaginaryI]", "=", 
          SqrtBox[
            RowBox[{"-", "1"}]]}], TraditionalForm]]],
  " appears unavoidably)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Cos", "[", 
        FractionBox["\[Pi]", "9"], "]"}], "}"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Cos", "[", 
        FractionBox["\[Pi]", "9"], "]"}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["FunctionExpand[%] // Together", "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        FractionBox["1", "8"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      SqrtBox["3"]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      SqrtBox["3"]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}], "+", 
            RowBox[{
              SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      SqrtBox["3"]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["2", 
                RowBox[{"2", "/", "3"}]], " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      SqrtBox["3"]}]}], ")"}], 
                RowBox[{"1", "/", "3"}]]}]}], ")"}]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "The function ",
  StyleBox["RootReduce", "Input",
    FontWeight->"Plain"],
  " allows for writing the last algebraic numbers as roots of polynomial \
equations."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"RootReduce", "[", 
      RowBox[{"Simplify", "[", "%", "]"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Root", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"-", "1"}], "-", 
              RowBox[{"6", " ", "#1"}], "+", 
              RowBox[{"8", " ", 
                SuperscriptBox["#1", "3"]}]}], "&"}], ",", "3"}], "]"}], 
      "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "The ",
  "function",
  " ",
  StyleBox["FunctionExpand", "Input",
    FontWeight->"Plain"],
  " also reduces trigonometric expressions with compound arguments or \
compositions including inverse trigonometric functions to simpler ones. Here \
are some examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Cos", "[", 
            SqrtBox[
              SuperscriptBox["z", "2"]], "]"}], ",", 
          RowBox[{"Cos", "[", 
            FractionBox[
              RowBox[{"ArcCos", "[", "z", "]"}], "2"], "]"}], ",", 
          RowBox[{"Cos", "[", 
            RowBox[{"3", 
              RowBox[{"ArcCos", "[", "z", "]"}]}], "]"}]}], "}"}], "//", 
      "FunctionExpand"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        FractionBox[
          SqrtBox[
            RowBox[{"1", "+", "z"}]], 
          SqrtBox["2"]], ",", 
        RowBox[{
          SuperscriptBox["z", "3"], "-", 
          RowBox[{"3", " ", "z", " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", 
                SuperscriptBox["z", "2"]}], ")"}]}]}]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "Applying ",
  StyleBox["Simplify", "Input",
    FontWeight->"Plain"],
  " to the last expression gives a more compact result."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        FractionBox[
          SqrtBox[
            RowBox[{"1", "+", "z"}]], 
          SqrtBox["2"]], ",", 
        RowBox[{"z", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"4", " ", 
                SuperscriptBox["z", "2"]}]}], ")"}]}]}], "}"}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FullSimplify", "Subsubsection"],

Cell[TextData[{
  "The function ",
  StyleBox["FullSimplify", "Input",
    FontWeight->"Plain"],
  " tries a wider range of transformations than ",
  StyleBox["Simplify", "Input",
    FontWeight->"Plain"],
  " and returns the simplest form it finds. Here are some examples that \
contrast the results of applying the ",
  "function",
  "s ",
  StyleBox["Simplify", "Input",
    FontWeight->"Plain"],
  " and ",
  StyleBox["FullSimplify", "Input",
    FontWeight->"Plain"],
  " to the same expressions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"set1", "=", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Cos", "[", 
            RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", 
              RowBox[{"Log", "[", 
                RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "z"}], "+", 
                  SqrtBox[
                    RowBox[{"1", "-", 
                      SuperscriptBox["z", "2"]}]]}], "]"}]}], "]"}], ",", 
          RowBox[{"Cos", "[", 
            RowBox[{
              FractionBox["\[Pi]", "2"], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    RowBox[{"\[ImaginaryI]", " ", "z"}], "+", 
                    SqrtBox[
                      RowBox[{"1", "-", 
                        SuperscriptBox["z", "2"]}]]}], "]"}]}]}], "]"}], ",", 
          
          RowBox[{"Cos", "[", 
            RowBox[{
              RowBox[{
                FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
                RowBox[{"Log", "[", 
                  RowBox[{"1", "-", 
                    RowBox[{"\[ImaginaryI]", " ", "z"}]}], "]"}]}], "-", 
              RowBox[{
                FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
                RowBox[{"Log", "[", 
                  RowBox[{"1", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "z"}]}], "]"}]}]}], "]"}], 
          ",", 
          RowBox[{"Cos", "[", 
            RowBox[{
              RowBox[{
                FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
                RowBox[{"Log", "[", 
                  RowBox[{"1", "-", 
                    FractionBox["\[ImaginaryI]", "z"]}], "]"}]}], "-", 
              RowBox[{
                FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
                RowBox[{"Log", "[", 
                  RowBox[{"1", "+", 
                    FractionBox["\[ImaginaryI]", "z"]}], "]"}]}]}], "]"}], 
          ",", 
          RowBox[{"Cos", "[", 
            RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", 
              RowBox[{"Log", "[", 
                RowBox[{
                  SqrtBox[
                    RowBox[{"1", "-", 
                      FractionBox["1", 
                        SuperscriptBox["z", "2"]]}]], "+", 
                  FractionBox["\[ImaginaryI]", "z"]}], "]"}]}], "]"}], ",", 
          RowBox[{"Cos", "[", 
            RowBox[{
              FractionBox["\[Pi]", "2"], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
                RowBox[{"Log", "[", 
                  RowBox[{
                    SqrtBox[
                      RowBox[{"1", "-", 
                        FractionBox["1", 
                          SuperscriptBox["z", "2"]]}]], "+", 
                    FractionBox["\[ImaginaryI]", "z"]}], "]"}]}]}], "]"}]}], 
        "}"}]}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        FractionBox[
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "z"}], "+", 
                  SqrtBox[
                    RowBox[{"1", "-", 
                      SuperscriptBox["z", "2"]}]]}], ")"}], "2"]}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "z"}], "+", 
                SqrtBox[
                  RowBox[{"1", "-", 
                    SuperscriptBox["z", "2"]}]]}], ")"}]}]], ",", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"\[ImaginaryI]", " ", "z"}], "+", 
                        SqrtBox[
                          RowBox[{"1", "-", 
                            SuperscriptBox["z", "2"]}]]}], ")"}], "2"]}], 
                ")"}]}], 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", "z"}], "+", 
                  SqrtBox[
                    RowBox[{"1", "-", 
                      SuperscriptBox["z", "2"]}]]}], ")"}]}]]}], ",", 
        RowBox[{"Cosh", "[", 
          RowBox[{
            RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"Log", "[", 
                RowBox[{"1", "-", 
                  RowBox[{"\[ImaginaryI]", " ", "z"}]}], "]"}]}], "-", 
            RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"Log", "[", 
                RowBox[{"1", "+", 
                  RowBox[{"\[ImaginaryI]", " ", "z"}]}], "]"}]}]}], "]"}], 
        ",", 
        RowBox[{"Cosh", "[", 
          RowBox[{
            RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"Log", "[", 
                RowBox[{"1", "-", 
                  FractionBox["\[ImaginaryI]", "z"]}], "]"}]}], "-", 
            RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"Log", "[", 
                RowBox[{"1", "+", 
                  FractionBox["\[ImaginaryI]", "z"]}], "]"}]}]}], "]"}], ",", 
        
        FractionBox[
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SqrtBox[
                    RowBox[{"1", "-", 
                      FractionBox["1", 
                        SuperscriptBox["z", "2"]]}]], "+", 
                  FractionBox["\[ImaginaryI]", "z"]}], ")"}], "2"]}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                SqrtBox[
                  RowBox[{"1", "-", 
                    FractionBox["1", 
                      SuperscriptBox["z", "2"]]}]], "+", 
                FractionBox["\[ImaginaryI]", "z"]}], ")"}]}]], ",", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        SqrtBox[
                          RowBox[{"1", "-", 
                            FractionBox["1", 
                              SuperscriptBox["z", "2"]]}]], "+", 
                        FractionBox["\[ImaginaryI]", "z"]}], ")"}], "2"]}], 
                ")"}]}], 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                RowBox[{
                  SqrtBox[
                    RowBox[{"1", "-", 
                      FractionBox["1", 
                        SuperscriptBox["z", "2"]]}]], "+", 
                  FractionBox["\[ImaginaryI]", "z"]}], ")"}]}]]}]}], 
      "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"set1", "//", "Simplify"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        FractionBox[
          RowBox[{"1", "-", 
            SuperscriptBox["z", "2"], "+", 
            RowBox[{"\[ImaginaryI]", " ", "z", " ", 
              SqrtBox[
                RowBox[{"1", "-", 
                  SuperscriptBox["z", "2"]}]]}]}], 
          RowBox[{
            RowBox[{"\[ImaginaryI]", " ", "z"}], "+", 
            SqrtBox[
              RowBox[{"1", "-", 
                SuperscriptBox["z", "2"]}]]}]], ",", "z", ",", 
        RowBox[{"Cosh", "[", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"Log", "[", 
                  RowBox[{"1", "-", 
                    RowBox[{"\[ImaginaryI]", " ", "z"}]}], "]"}], "-", 
                RowBox[{"Log", "[", 
                  RowBox[{"1", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "z"}]}], "]"}]}], ")"}]}], 
          "]"}], ",", 
        RowBox[{"Cosh", "[", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"Log", "[", 
                  FractionBox[
                    RowBox[{
                      RowBox[{"-", "\[ImaginaryI]"}], "+", "z"}], "z"], "]"}],
                 "-", 
                RowBox[{"Log", "[", 
                  FractionBox[
                    RowBox[{"\[ImaginaryI]", "+", "z"}], "z"], "]"}]}], 
              ")"}]}], "]"}], ",", 
        FractionBox[
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox[
                RowBox[{"1", "-", 
                  FractionBox["1", 
                    SuperscriptBox["z", "2"]]}]], " ", "z"}], "+", 
            SuperscriptBox["z", "2"]}], 
          RowBox[{"z", " ", 
            RowBox[{"(", 
              RowBox[{"\[ImaginaryI]", "+", 
                RowBox[{
                  SqrtBox[
                    RowBox[{"1", "-", 
                      FractionBox["1", 
                        SuperscriptBox["z", "2"]]}]], " ", "z"}]}], ")"}]}]], 
        ",", 
        FractionBox["1", "z"]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"set1", "//", "FullSimplify"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        SqrtBox[
          RowBox[{"1", "-", 
            SuperscriptBox["z", "2"]}]], ",", "z", ",", 
        FractionBox["1", 
          SqrtBox[
            RowBox[{"1", "+", 
              SuperscriptBox["z", "2"]}]]], ",", 
        FractionBox["1", 
          SqrtBox[
            RowBox[{"1", "+", 
              FractionBox["1", 
                SuperscriptBox["z", "2"]]}]]], ",", 
        SqrtBox[
          RowBox[{"1", "-", 
            FractionBox["1", 
              SuperscriptBox["z", "2"]]}]], ",", 
        FractionBox["1", "z"]}], "}"}]], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Operations carried out by specialized ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Series expansions", "Subsubsection"],

Cell["\<\
Calculating the series expansion of a cosine function to hundreds \
of terms can be done in seconds.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Series", "[", 
      RowBox[{
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"z", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"1", "-", 
        FractionBox[
          SuperscriptBox["z", "2"], "2"], "+", 
        InterpretationBox[
          SuperscriptBox[
            RowBox[{"O", "[", "z", "]"}], "4"],
          SeriesData[ z, 0, {}, 0, 4, 1]]}],
      SeriesData[ z, 0, {1, 0, 
        Rational[ -1, 2]}, 0, 4, 1]]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Normal", "[", "%", "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"1", "-", 
      FractionBox[
        SuperscriptBox["z", "2"], "2"]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Series", "[", 
        RowBox[{
          RowBox[{"Cos", "[", "z", "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"z", ",", "0", ",", "100"}], "}"}]}], "]"}], "//", 
      "Timing"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"8.534839501805891`*^-16", " ", "Second"}], ",", 
        InterpretationBox[
          RowBox[{"1", "-", 
            FractionBox[
              SuperscriptBox["z", "2"], "2"], "+", 
            FractionBox[
              SuperscriptBox["z", "4"], "24"], "-", 
            FractionBox[
              SuperscriptBox["z", "6"], "720"], "+", 
            FractionBox[
              SuperscriptBox["z", "8"], "40320"], "-", 
            FractionBox[
              SuperscriptBox["z", "10"], "3628800"], "+", 
            FractionBox[
              SuperscriptBox["z", "12"], "479001600"], "-", 
            FractionBox[
              SuperscriptBox["z", "14"], "87178291200"], "+", 
            FractionBox[
              SuperscriptBox["z", "16"], "20922789888000"], "-", 
            FractionBox[
              SuperscriptBox["z", "18"], "6402373705728000"], "+", 
            FractionBox[
              SuperscriptBox["z", "20"], "2432902008176640000"], "-", 
            FractionBox[
              SuperscriptBox["z", "22"], "1124000727777607680000"], "+", 
            FractionBox[
              SuperscriptBox["z", "24"], "620448401733239439360000"], "-", 
            FractionBox[
              SuperscriptBox["z", "26"], "403291461126605635584000000"], "+", 
            
            FractionBox[
              SuperscriptBox["z", "28"], "304888344611713860501504000000"], 
            "-", 
            FractionBox[
              SuperscriptBox["z", "30"], "265252859812191058636308480000000"],
             "+", 
            FractionBox[
              SuperscriptBox["z", "32"], 
              "263130836933693530167218012160000000"], "-", 
            FractionBox[
              SuperscriptBox["z", "34"], 
              "295232799039604140847618609643520000000"], "+", 
            FractionBox[
              SuperscriptBox["z", "36"], 
              "371993326789901217467999448150835200000000"], "-", 
            FractionBox[
              SuperscriptBox["z", "38"], 
              "523022617466601111760007224100074291200000000"], "+", 
            FractionBox[
              SuperscriptBox["z", "40"], 
              "815915283247897734345611269596115894272000000000"], "-", 
            FractionBox[
              SuperscriptBox["z", "42"], 
              "1405006117752879898543142606244511569936384000000000"], "+", 
            FractionBox[
              SuperscriptBox["z", "44"], 
              "2658271574788448768043625811014615890319638528000000000"], "-",
             
            FractionBox[
              SuperscriptBox["z", "46"], 
              "5502622159812088949850305428800254892961651752960000000000"], 
            "+", 
            FractionBox[
              SuperscriptBox["z", "48"], 
              "12413915592536072670862289047373375038521486354677760000000000"\
], "-", 
            FractionBox[
              SuperscriptBox["z", "50"], 
              "304140932017133780436126081660647688443776415689605120000000000\
00"], "+", 
            FractionBox[
              SuperscriptBox["z", "52"], 
              "806581751709438785716606368564037669752895054408832778240000000\
00000"], "-", 
            FractionBox[
              SuperscriptBox["z", "54"], 
              "230843697339241380472092742683027581083278564571807941132288000\
000000000"], "+", 
            FractionBox[
              SuperscriptBox["z", "56"], 
              "710998587804863451854045647463724949736497978881168458687447040\
000000000000"], "-", 
            FractionBox[
              SuperscriptBox["z", "58"], 
              "235056133128287857182947491051507468382886231818114292442069991\
4240000000000000"], "+", 
            FractionBox[
              SuperscriptBox["z", "60"], 
              "832098711274139014427634118322336438075417260636124595244927769\
6409600000000000000"], "-", 
            RowBox[{
              SuperscriptBox["z", "62"], "/", 
              "314699732603879375256531223549507640880122807972582321921631682\
47821107200000000000000"}], "+", 
            RowBox[{
              SuperscriptBox["z", "64"], "/", 
              "126886932185884164103433389335161480802865516174545192198801894\
375214704230400000000000000"}], "-", 
            RowBox[{
              SuperscriptBox["z", "66"], "/", 
              "544344939077443064003729240247842752644293064388798874532860126\
869671081148416000000000000000"}], "+", 
            RowBox[{
              SuperscriptBox["z", "68"], "/", 
              "248003554243683059960099041856917158104739920135536767237171073\
8018221445712183296000000000000000"}], "-", 
            RowBox[{
              SuperscriptBox["z", "70"], "/", 
              "119785716699698917960727837216890987364589381425464258575553628\
64628009582789845319680000000000000000"}], "+", 
            RowBox[{
              SuperscriptBox["z", "72"], "/", 
              "612344583768860868615240703852746727407780917846973289838230149\
63978384987221689274204160000000000000000"}], "-", 
            RowBox[{
              SuperscriptBox["z", "74"], "/", 
              "330788544151938641225953028221253782145683251820934971170611926\
835411235700971565459250872320000000000000000"}], "+", 
            RowBox[{
              SuperscriptBox["z", "76"], "/", 
              "188549470166605025498793226086114655823039453537932933567248798\
2961844043495537923117729972224000000000000000000"}], "-", 
            RowBox[{
              SuperscriptBox["z", "78"], "/", 
              "113242811782062978314575211587320462287317495794882519900489628\
25668835325234200766245086213177344000000000000000000"}], "+", 
            RowBox[{
              SuperscriptBox["z", "80"], "/", 
              "715694570462638022948115337231865321655846573423657525771094450\
58227039255480148842668944867280814080000000000000000000"}], "-", 
            RowBox[{
              SuperscriptBox["z", "82"], "/", 
              "475364333701284174842138206989404946643813294067993328617160934\
076743994734899148613007131808479167119360000000000000000000"}], "+", 
            RowBox[{
              SuperscriptBox["z", "84"], "/", 
              "331424013456535326699938757913013128800066628624204948711884603\
2383059131291716864129885722968716753156177920000000000000000000"}], "-", 
            RowBox[{
              SuperscriptBox["z", "86"], "/", 
              "242270953836727323817655232034412597152848705524293817508387644\
96720162249742450276789464634901319465571660595200000000000000000000"}], "+", 
            
            RowBox[{
              SuperscriptBox["z", "88"], "/", 
              "185482642257398439114796845645546284380220968949399346684421580\
986889562184028199319100141244804501828416633516851200000000000000000000"}], 
            "-", 
            RowBox[{
              SuperscriptBox["z", "90"], "/", 
              "148571596448176149730952273362082573788556996128468876694221686\
3704985393094065876545992131370884059645617234469978112000000000000000000000"}\
], "+", 
            RowBox[{
              SuperscriptBox["z", "92"], "/", 
              "124384140546413072554753243258735530775779917158754143568402395\
829381377109835195184430461238370413473531074869826567536640000000000000000000\
00"}], "-", 
            RowBox[{
              SuperscriptBox["z", "94"], "/", 
              "108736615665674308027365285256786601004186803580182872307497374\
434045199869417927630229109214583415458560865651202385340530688000000000000000\
000000"}], "+", 
            RowBox[{
              SuperscriptBox["z", "96"], "/", 
              "991677934870949689209571401541893801158183648651267795444376054\
838492222809091499987689476037000748982075094738965754305639874560000000000000\
000000000"}], "-", 
            RowBox[{
              SuperscriptBox["z", "98"], "/", 
              "942689044888324774562618574305724247380969376407895166349423877\
729470707002322379888297615920772911982360585058860846042941264756736000000000\
0000000000000"}], "+", 
            RowBox[{
              SuperscriptBox["z", "100"], "/", 
              "933262154439441526816992388562667004907159682643816214685929638\
952175999932299156089414639761565182862536979208272237582511852109168640000000\
00000000000000000"}], "+", 
            InterpretationBox[
              SuperscriptBox[
                RowBox[{"O", "[", "z", "]"}], "101"],
              SeriesData[ z, 0, {}, 0, 101, 1]]}],
          SeriesData[ z, 0, {1, 0, 
            Rational[ -1, 2], 0, 
            Rational[ 1, 24], 0, 
            Rational[ -1, 720], 0, 
            Rational[ 1, 40320], 0, 
            Rational[ -1, 3628800], 0, 
            Rational[ 1, 479001600], 0, 
            Rational[ -1, 87178291200], 0, 
            Rational[ 1, 20922789888000], 0, 
            Rational[ -1, 6402373705728000], 0, 
            Rational[ 1, 2432902008176640000], 0, 
            Rational[ -1, 1124000727777607680000], 0, 
            Rational[ 1, 620448401733239439360000], 0, 
            Rational[ -1, 403291461126605635584000000], 0, 
            Rational[ 1, 304888344611713860501504000000], 0, 
            Rational[ -1, 265252859812191058636308480000000], 0, 
            Rational[ 1, 263130836933693530167218012160000000], 0, 
            Rational[ -1, 295232799039604140847618609643520000000], 0, 
            Rational[ 1, 371993326789901217467999448150835200000000], 0, 
            Rational[ -1, 523022617466601111760007224100074291200000000], 0, 
            Rational[ 1, 815915283247897734345611269596115894272000000000], 0,
             
            
            Rational[ -1, 
              1405006117752879898543142606244511569936384000000000], 0, 
            Rational[ 
            1, 2658271574788448768043625811014615890319638528000000000], 0, 
            
            Rational[ -1, 
              5502622159812088949850305428800254892961651752960000000000], 0, 
            
            Rational[ 
            1, 12413915592536072670862289047373375038521486354677760000000000]\
, 0, 
            
            Rational[ -1, 
              3041409320171337804361260816606476884437764156896051200000000000\
0], 0, 
            Rational[ 
            1, 
              8065817517094387857166063685640376697528950544088327782400000000\
0000], 0, 
            
            Rational[ -1, 
              2308436973392413804720927426830275810832785645718079411322880000\
00000000], 0, 
            Rational[ 
            1, 710998587804863451854045647463724949736497978881168458687447040\
000000000000], 0, 
            
            Rational[ -1, 
              2350561331282878571829474910515074683828862318181142924420699914\
240000000000000], 0, 
            Rational[ 
            1, 832098711274139014427634118322336438075417260636124595244927769\
6409600000000000000], 0, 
            
            Rational[ -1, 
              3146997326038793752565312235495076408801228079725823219216316824\
7821107200000000000000], 0, 
            Rational[ 
            1, 126886932185884164103433389335161480802865516174545192198801894\
375214704230400000000000000], 0, 
            
            Rational[ -1, 
              5443449390774430640037292402478427526442930643887988745328601268\
69671081148416000000000000000], 0, 
            Rational[ 
            1, 248003554243683059960099041856917158104739920135536767237171073\
8018221445712183296000000000000000], 0, 
            
            Rational[ -1, 
              1197857166996989179607278372168909873645893814254642585755536286\
4628009582789845319680000000000000000], 0, 
            Rational[ 
            1, 612344583768860868615240703852746727407780917846973289838230149\
63978384987221689274204160000000000000000], 0, 
            
            Rational[ -1, 
              3307885441519386412259530282212537821456832518209349711706119268\
35411235700971565459250872320000000000000000], 0, 
            Rational[ 
            1, 188549470166605025498793226086114655823039453537932933567248798\
2961844043495537923117729972224000000000000000000], 0, 
            
            Rational[ -1, 
              1132428117820629783145752115873204622873174957948825199004896282\
5668835325234200766245086213177344000000000000000000], 0, 
            Rational[ 
            1, 715694570462638022948115337231865321655846573423657525771094450\
58227039255480148842668944867280814080000000000000000000], 0, 
            Rational[ -1, 
              4753643337012841748421382069894049466438132940679933286171609340\
76743994734899148613007131808479167119360000000000000000000], 0, 
            Rational[ 
            1, 331424013456535326699938757913013128800066628624204948711884603\
2383059131291716864129885722968716753156177920000000000000000000], 0, 
            
            Rational[ -1, 
              2422709538367273238176552320344125971528487055242938175083876449\
6720162249742450276789464634901319465571660595200000000000000000000], 0, 
            Rational[ 
            1, 185482642257398439114796845645546284380220968949399346684421580\
986889562184028199319100141244804501828416633516851200000000000000000000], 0, 
            
            
            Rational[ -1, 
              1485715964481761497309522733620825737885569961284688766942216863\
704985393094065876545992131370884059645617234469978112000000000000000000000], 
            0, 
            Rational[ 
            1, 124384140546413072554753243258735530775779917158754143568402395\
829381377109835195184430461238370413473531074869826567536640000000000000000000\
00], 0, 
            
            Rational[ -1, 
              1087366156656743080273652852567866010041868035801828723074973744\
340451998694179276302291092145834154585608656512023853405306880000000000000000\
00000], 0, 
            Rational[ 
            1, 991677934870949689209571401541893801158183648651267795444376054\
838492222809091499987689476037000748982075094738965754305639874560000000000000\
000000000], 0, 
            
            Rational[ -1, 
              9426890448883247745626185743057242473809693764078951663494238777\
294707070023223798882976159207729119823605850588608460429412647567360000000000\
000000000000], 0, 
            Rational[ 
            1, 933262154439441526816992388562667004907159682643816214685929638\
952175999932299156089414639761565182862536979208272237582511852109168640000000\
00000000000000000]}, 0, 101, 1]]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " comes with the add\[Hyphen]on package ",
  StyleBox["DiscreteMath`RSolve`", "Input",
    FontWeight->"Plain"],
  StyleBox[" ",
    FontWeight->"Plain"],
  "that allows to find the general terms of series for many functions. After \
loading this package, and using package ",
  "function",
  " ",
  StyleBox["SeriesTerm", "Input",
    FontWeight->"Plain"],
  ", the following ",
  Cell[BoxData[
      FormBox["n", TraditionalForm]]],
  "th term of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  " can be evaluated."
}], "Text"],

Cell[BoxData[
    RowBox[{"<<", "DiscreteMath`RSolve`"}]], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SeriesTerm", "[", 
        RowBox[{
          RowBox[{"Cos", "[", "z", "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"z", ",", "0", ",", "n"}], "}"}]}], "]"}], 
      RowBox[{"z", "^", "n"}]}]], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    FractionBox[
      RowBox[{
        SuperscriptBox["\[ImaginaryI]", "n"], " ", 
        SuperscriptBox["z", "n"], " ", 
        RowBox[{"KroneckerDelta", "[", 
          RowBox[{"Mod", "[", 
            RowBox[{"n", ",", "2"}], "]"}], "]"}]}], 
      RowBox[{"Gamma", "[", 
        RowBox[{"1", "+", "n"}], "]"}]]], "Output",
  CellLabel->"Out[3]="]
}, Closed]],

Cell["This result can be checked in the following way.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FunctionExpand", "[", 
      RowBox[{
        UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{"Evaluate", "[", "%", "]"}]}], "]"}]], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    RowBox[{"Cos", "[", "z", "]"}]], "Output",
  CellLabel->"Out[4]="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Differentiation", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can evaluate derivatives of the cosine function of arbitrary positive \
integer order."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      SubscriptBox["\[PartialD]", "z"], 
      RowBox[{"Cos", "[", "z", "]"}]}]], "Input"],

Cell[BoxData[
    RowBox[{"-", 
      RowBox[{"Sin", "[", "z", "]"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      SubscriptBox["\[PartialD]", 
        RowBox[{"{", 
          RowBox[{"z", ",", "2"}], "}"}]], 
      RowBox[{"Cos", "[", "z", "]"}]}]], "Input"],

Cell[BoxData[
    RowBox[{"-", 
      RowBox[{"Cos", "[", "z", "]"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Table", "[", 
      RowBox[{
        RowBox[{"D", "[", 
          RowBox[{
            RowBox[{"Cos", "[", "z", "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"z", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"n", ",", "10"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"Sin", "[", "z", "]"}]}], ",", 
        RowBox[{"-", 
          RowBox[{"Cos", "[", "z", "]"}]}], ",", 
        RowBox[{"Sin", "[", "z", "]"}], ",", 
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        RowBox[{"-", 
          RowBox[{"Sin", "[", "z", "]"}]}], ",", 
        RowBox[{"-", 
          RowBox[{"Cos", "[", "z", "]"}]}], ",", 
        RowBox[{"Sin", "[", "z", "]"}], ",", 
        RowBox[{"Cos", "[", "z", "]"}], ",", 
        RowBox[{"-", 
          RowBox[{"Sin", "[", "z", "]"}]}], ",", 
        RowBox[{"-", 
          RowBox[{"Cos", "[", "z", "]"}]}]}], "}"}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Finite summation", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can calculate finite symbolic sums that contain the cosine function. Here \
are some examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "1"}], "n"], 
      RowBox[{"Cos", "[", 
        RowBox[{"a", " ", "k"}], "]"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
        RowBox[{"Cos", "[", 
          FractionBox[
            RowBox[{"a", " ", "n"}], "2"], "]"}], " ", 
        RowBox[{"Csc", "[", 
          FractionBox["a", "2"], "]"}], " ", 
        RowBox[{"Sin", "[", 
          RowBox[{
            FractionBox["a", "2"], "+", 
            FractionBox[
              RowBox[{"a", " ", "n"}], "2"]}], "]"}]}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "1"}], "n"], 
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "k"], " ", 
        RowBox[{"Cos", "[", 
          RowBox[{"a", " ", "k"}], "]"}]}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{
            FractionBox[
              RowBox[{"a", " ", "n"}], "2"], "+", 
            FractionBox[
              RowBox[{"n", " ", "\[Pi]"}], "2"]}], "]"}], " ", 
        RowBox[{"Cos", "[", 
          RowBox[{
            FractionBox["a", "2"], "+", 
            FractionBox[
              RowBox[{"a", " ", "n"}], "2"], "+", 
            FractionBox[
              RowBox[{"n", " ", "\[Pi]"}], "2"]}], "]"}], " ", 
        RowBox[{"Sec", "[", 
          FractionBox["a", "2"], "]"}]}]}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Infinite summation", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can calculate infinite sums including the cosine function. Here are some \
examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "1"}], "\[Infinity]"], 
      RowBox[{
        SuperscriptBox["z", "k"], " ", 
        RowBox[{"Cos", "[", 
          RowBox[{"k", " ", "x"}], "]"}]}]}]], "Input"],

Cell[BoxData[
    RowBox[{"-", 
      FractionBox[
        RowBox[{"z", " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], "-", 
              RowBox[{"2", " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", "z"}]}], ")"}]}],
         
        RowBox[{"2", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", " ", "x"}]], "-", "z"}], ")"}], " ", 
          
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", "z"}]}], 
            ")"}]}]]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "1"}], "\[Infinity]"], 
      FractionBox[
        RowBox[{"Cos", "[", 
          RowBox[{"k", " ", "x"}], "]"}], 
        RowBox[{"k", "!"}]]}]], "Input"],

Cell[BoxData[
    RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"-", "2"}], "+", 
          SuperscriptBox["\[ExponentialE]", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]]], "+", 
          SuperscriptBox["\[ExponentialE]", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", "x"}]]]}], ")"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "1"}], "\[Infinity]"], 
      FractionBox[
        RowBox[{"Cos", "[", 
          RowBox[{"k", " ", "x"}], "]"}], "k"]}]], "Input"],

Cell[BoxData[
    RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"Log", "[", 
              RowBox[{"1", "-", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]]}], "]"}]}], 
          "-", 
          RowBox[{"Log", "[", 
            RowBox[{"1", "-", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", " ", "x"}]]}], "]"}]}], 
        ")"}]}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Finite products", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can calculate some finite symbolic products that contain the cosine \
function. Here is an example."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      UnderoverscriptBox["\[Product]", 
        RowBox[{"k", "=", "1"}], 
        RowBox[{"n", "-", "1"}]], 
      RowBox[{"Cos", "[", 
        RowBox[{"z", "+", 
          FractionBox[
            RowBox[{"\[Pi]", " ", "k"}], "n"]}], "]"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"]}], " ", 
      SuperscriptBox["2", 
        RowBox[{"1", "-", "n"}]], " ", 
      RowBox[{"Sec", "[", "z", "]"}], " ", 
      RowBox[{"Sin", "[", 
        RowBox[{
          FractionBox["1", "2"], " ", "n", " ", 
          RowBox[{"(", 
            RowBox[{"\[Pi]", "-", 
              RowBox[{"2", " ", "z"}]}], ")"}]}], "]"}]}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Indefinite integration", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can calculate a huge number of doable indefinite integrals that contain \
the cosine function. Here are some examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[Integral]", 
      RowBox[{
        RowBox[{"Cos", "[", "z", "]"}], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]], "Input"],

Cell[BoxData[
    RowBox[{"Sin", "[", "z", "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[Integral]", 
      RowBox[{
        SuperscriptBox[
          RowBox[{"Cos", "[", "z", "]"}], "a"], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]], "Input"],

Cell[BoxData[
    RowBox[{"-", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"Cos", "[", "z", "]"}], 
            RowBox[{"1", "+", "a"}]], " ", 
          RowBox[{"Hypergeometric2F1", "[", 
            RowBox[{
              FractionBox[
                RowBox[{"1", "+", "a"}], "2"], ",", 
              FractionBox["1", "2"], ",", 
              FractionBox[
                RowBox[{"3", "+", "a"}], "2"], ",", 
              SuperscriptBox[
                RowBox[{"Cos", "[", "z", "]"}], "2"]}], "]"}], " ", 
          RowBox[{"Sin", "[", "z", "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", "a"}], ")"}], " ", 
          SqrtBox[
            SuperscriptBox[
              RowBox[{"Sin", "[", "z", "]"}], "2"]]}]]}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Definite integration", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can calculate wide classes of definite integrals that contain the cosine \
function. Here are some examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], 
      RowBox[{
        SqrtBox[
          RowBox[{"Cos", "[", "z", "]"}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]], "Input"],

Cell[BoxData[
    RowBox[{"2", " ", 
      RowBox[{"EllipticE", "[", 
        RowBox[{
          FractionBox["\[Pi]", "4"], ",", "2"}], "]"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
        FractionBox["\[Pi]", "2"]], 
      RowBox[{
        SuperscriptBox[
          RowBox[{"Cos", "[", "z", "]"}], "a"], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]], "Input"],

Cell[BoxData[
    FractionBox[
      RowBox[{
        SqrtBox["\[Pi]"], " ", 
        RowBox[{"Gamma", "[", 
          FractionBox[
            RowBox[{"1", "+", "a"}], "2"], "]"}]}], 
      RowBox[{"a", " ", 
        RowBox[{"Gamma", "[", 
          FractionBox["a", "2"], "]"}]}]]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Limit operation", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can calculate limits that contain the cosine function. Here are some \
examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Limit", "[", 
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"Cos", "[", 
              RowBox[{"2", "z"}], "]"}], "-", "1"}], 
          SuperscriptBox["z", "2"]], ",", 
        RowBox[{"z", "\[Rule]", "0"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"-", "2"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Limit", "[", 
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"Cos", "[", 
              SqrtBox[
                SuperscriptBox["z", "2"]], "]"}], "-", "1"}], 
          SuperscriptBox["z", "2"]], ",", 
        RowBox[{"z", "\[Rule]", "0"}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"-", 
      FractionBox["1", "2"]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Limit", "[", 
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"Cos", "[", 
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox["z", "2"], ")"}], 
                RowBox[{"1", "/", "4"}]], "]"}], "-", "1"}], "z"], ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]], "Input",
  CellLabel->"In[573]:="],

Cell[BoxData[
    FractionBox["1", "2"]], "Output",
  CellLabel->"Out[573]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Limit", "[", 
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"Cos", "[", 
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox["z", "2"], ")"}], 
                RowBox[{"1", "/", "4"}]], "]"}], "-", "1"}], "z"], ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Direction", "\[Rule]", 
          RowBox[{"-", "1"}]}]}], "]"}]], "Input",
  CellLabel->"In[574]:="],

Cell[BoxData[
    RowBox[{"-", 
      FractionBox["1", "2"]}]], "Output",
  CellLabel->"Out[574]="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving equations", "Subsubsection"],

Cell["\<\
The next inpus solve two equations that contain the cosine \
function. Because of the multivalued nature of the inverse of the cosine \
function, a printed message indicates that only some of the possible \
solutions are returned.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Solve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox[
              RowBox[{"Cos", "[", "z", "]"}], "2"], "+", 
            RowBox[{"4", " ", 
              RowBox[{"Cos", "[", 
                RowBox[{"z", "-", 
                  RowBox[{"Pi", "/", "6"}]}], "]"}]}]}], "\[Equal]", "4"}], 
        ",", "z"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Solve", "::", "\<\"ifun\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Inverse functions are being used by \\!\\(Solve\\), so \
some solutions may not be found.\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"z", "\[Rule]", 
            RowBox[{"ArcCos", "[", 
              RowBox[{
                RowBox[{"-", 
                  SqrtBox["3"]}], "-", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  SqrtBox[
                    RowBox[{
                      FractionBox["20", "3"], "+", 
                      RowBox[{
                        FractionBox["1", "3"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"22112", "-", 
                              RowBox[{"288", " ", 
                                SqrtBox["85"]}]}], ")"}], 
                          RowBox[{"1", "/", "3"}]]}], "+", 
                      RowBox[{
                        FractionBox["2", "3"], " ", 
                        SuperscriptBox["2", 
                          RowBox[{"2", "/", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"691", "+", 
                              RowBox[{"9", " ", 
                                SqrtBox["85"]}]}], ")"}], 
                          RowBox[{"1", "/", "3"}]]}]}]]}], "-", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                      RowBox[{
                        FractionBox["40", "3"], "-", 
                        RowBox[{
                          FractionBox["1", "3"], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"22112", "-", 
                                RowBox[{"288", " ", 
                                  SqrtBox["85"]}]}], ")"}], 
                            RowBox[{"1", "/", "3"}]]}], "-", 
                        RowBox[{
                          FractionBox["2", "3"], " ", 
                          SuperscriptBox["2", 
                            RowBox[{"2", "/", "3"}]], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"691", "+", 
                                RowBox[{"9", " ", 
                                  SqrtBox["85"]}]}], ")"}], 
                            RowBox[{"1", "/", "3"}]]}], "-", 
                        FractionBox["16", 
                          SqrtBox[
                            RowBox[{
                              FractionBox["1", "3"], " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  FractionBox["20", "3"], "+", 
                                  RowBox[{
                                    FractionBox["1", "3"], " ", 
                                    SuperscriptBox[
                                      RowBox[{"(", 
                                        RowBox[{"22112", "-", 
                                        RowBox[{"288", " ", 
                                        SqrtBox["85"]}]}], ")"}], 
                                      RowBox[{"1", "/", "3"}]]}], "+", 
                                  RowBox[{
                                    FractionBox["2", "3"], " ", 
                                    SuperscriptBox["2", 
                                      RowBox[{"2", "/", "3"}]], " ", 
                                    SuperscriptBox[
                                      RowBox[{"(", 
                                        RowBox[{"691", "+", 
                                        RowBox[{"9", " ", 
                                        SqrtBox["85"]}]}], ")"}], 
                                      RowBox[{"1", "/", "3"}]]}]}], 
                                ")"}]}]]]}], ")"}]}]}]}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
          RowBox[{"z", "\[Rule]", 
            RowBox[{"ArcCos", "[", 
              RowBox[{
                RowBox[{"-", 
                  SqrtBox["3"]}], "-", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  SqrtBox[
                    RowBox[{
                      FractionBox["20", "3"], "+", 
                      RowBox[{
                        FractionBox["1", "3"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"22112", "-", 
                              RowBox[{"288", " ", 
                                SqrtBox["85"]}]}], ")"}], 
                          RowBox[{"1", "/", "3"}]]}], "+", 
                      RowBox[{
                        FractionBox["2", "3"], " ", 
                        SuperscriptBox["2", 
                          RowBox[{"2", "/", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"691", "+", 
                              RowBox[{"9", " ", 
                                SqrtBox["85"]}]}], ")"}], 
                          RowBox[{"1", "/", "3"}]]}]}]]}], "+", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                      RowBox[{
                        FractionBox["40", "3"], "-", 
                        RowBox[{
                          FractionBox["1", "3"], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"22112", "-", 
                                RowBox[{"288", " ", 
                                  SqrtBox["85"]}]}], ")"}], 
                            RowBox[{"1", "/", "3"}]]}], "-", 
                        RowBox[{
                          FractionBox["2", "3"], " ", 
                          SuperscriptBox["2", 
                            RowBox[{"2", "/", "3"}]], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"691", "+", 
                                RowBox[{"9", " ", 
                                  SqrtBox["85"]}]}], ")"}], 
                            RowBox[{"1", "/", "3"}]]}], "-", 
                        FractionBox["16", 
                          SqrtBox[
                            RowBox[{
                              FractionBox["1", "3"], " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  FractionBox["20", "3"], "+", 
                                  RowBox[{
                                    FractionBox["1", "3"], " ", 
                                    SuperscriptBox[
                                      RowBox[{"(", 
                                        RowBox[{"22112", "-", 
                                        RowBox[{"288", " ", 
                                        SqrtBox["85"]}]}], ")"}], 
                                      RowBox[{"1", "/", "3"}]]}], "+", 
                                  RowBox[{
                                    FractionBox["2", "3"], " ", 
                                    SuperscriptBox["2", 
                                      RowBox[{"2", "/", "3"}]], " ", 
                                    SuperscriptBox[
                                      RowBox[{"(", 
                                        RowBox[{"691", "+", 
                                        RowBox[{"9", " ", 
                                        SqrtBox["85"]}]}], ")"}], 
                                      RowBox[{"1", "/", "3"}]]}]}], 
                                ")"}]}]]]}], ")"}]}]}]}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
          RowBox[{"z", "\[Rule]", 
            RowBox[{"ArcCos", "[", 
              RowBox[{
                RowBox[{"-", 
                  SqrtBox["3"]}], "+", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  SqrtBox[
                    RowBox[{
                      FractionBox["20", "3"], "+", 
                      RowBox[{
                        FractionBox["1", "3"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"22112", "-", 
                              RowBox[{"288", " ", 
                                SqrtBox["85"]}]}], ")"}], 
                          RowBox[{"1", "/", "3"}]]}], "+", 
                      RowBox[{
                        FractionBox["2", "3"], " ", 
                        SuperscriptBox["2", 
                          RowBox[{"2", "/", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"691", "+", 
                              RowBox[{"9", " ", 
                                SqrtBox["85"]}]}], ")"}], 
                          RowBox[{"1", "/", "3"}]]}]}]]}], "-", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                      RowBox[{
                        FractionBox["40", "3"], "-", 
                        RowBox[{
                          FractionBox["1", "3"], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"22112", "-", 
                                RowBox[{"288", " ", 
                                  SqrtBox["85"]}]}], ")"}], 
                            RowBox[{"1", "/", "3"}]]}], "-", 
                        RowBox[{
                          FractionBox["2", "3"], " ", 
                          SuperscriptBox["2", 
                            RowBox[{"2", "/", "3"}]], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"691", "+", 
                                RowBox[{"9", " ", 
                                  SqrtBox["85"]}]}], ")"}], 
                            RowBox[{"1", "/", "3"}]]}], "+", 
                        FractionBox["16", 
                          SqrtBox[
                            RowBox[{
                              FractionBox["1", "3"], " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  FractionBox["20", "3"], "+", 
                                  RowBox[{
                                    FractionBox["1", "3"], " ", 
                                    SuperscriptBox[
                                      RowBox[{"(", 
                                        RowBox[{"22112", "-", 
                                        RowBox[{"288", " ", 
                                        SqrtBox["85"]}]}], ")"}], 
                                      RowBox[{"1", "/", "3"}]]}], "+", 
                                  RowBox[{
                                    FractionBox["2", "3"], " ", 
                                    SuperscriptBox["2", 
                                      RowBox[{"2", "/", "3"}]], " ", 
                                    SuperscriptBox[
                                      RowBox[{"(", 
                                        RowBox[{"691", "+", 
                                        RowBox[{"9", " ", 
                                        SqrtBox["85"]}]}], ")"}], 
                                      RowBox[{"1", "/", "3"}]]}]}], 
                                ")"}]}]]]}], ")"}]}]}]}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
          RowBox[{"z", "\[Rule]", 
            RowBox[{"-", 
              RowBox[{"ArcCos", "[", 
                RowBox[{
                  RowBox[{"-", 
                    SqrtBox["3"]}], "+", 
                  RowBox[{
                    FractionBox["1", "2"], " ", 
                    SqrtBox[
                      RowBox[{
                        FractionBox["20", "3"], "+", 
                        RowBox[{
                          FractionBox["1", "3"], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"22112", "-", 
                                RowBox[{"288", " ", 
                                  SqrtBox["85"]}]}], ")"}], 
                            RowBox[{"1", "/", "3"}]]}], "+", 
                        RowBox[{
                          FractionBox["2", "3"], " ", 
                          SuperscriptBox["2", 
                            RowBox[{"2", "/", "3"}]], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"691", "+", 
                                RowBox[{"9", " ", 
                                  SqrtBox["85"]}]}], ")"}], 
                            RowBox[{"1", "/", "3"}]]}]}]]}], "+", 
                  RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"\[Sqrt]", 
                      RowBox[{"(", 
                        RowBox[{
                          FractionBox["40", "3"], "-", 
                          RowBox[{
                            FractionBox["1", "3"], " ", 
                            SuperscriptBox[
                              RowBox[{"(", 
                                RowBox[{"22112", "-", 
                                  RowBox[{"288", " ", 
                                    SqrtBox["85"]}]}], ")"}], 
                              RowBox[{"1", "/", "3"}]]}], "-", 
                          RowBox[{
                            FractionBox["2", "3"], " ", 
                            SuperscriptBox["2", 
                              RowBox[{"2", "/", "3"}]], " ", 
                            SuperscriptBox[
                              RowBox[{"(", 
                                RowBox[{"691", "+", 
                                  RowBox[{"9", " ", 
                                    SqrtBox["85"]}]}], ")"}], 
                              RowBox[{"1", "/", "3"}]]}], "+", 
                          FractionBox["16", 
                            SqrtBox[
                              RowBox[{
                                FractionBox["1", "3"], " ", 
                                RowBox[{"(", 
                                  RowBox[{
                                    FractionBox["20", "3"], "+", 
                                    RowBox[{
                                      FractionBox["1", "3"], " ", 
                                      SuperscriptBox[
                                        RowBox[{"(", 
                                        RowBox[{"22112", "-", 
                                        RowBox[{"288", " ", 
                                        SqrtBox["85"]}]}], ")"}], 
                                        RowBox[{"1", "/", "3"}]]}], "+", 
                                    RowBox[{
                                      FractionBox["2", "3"], " ", 
                                      SuperscriptBox["2", 
                                        RowBox[{"2", "/", "3"}]], " ", 
                                      SuperscriptBox[
                                        RowBox[{"(", 
                                        RowBox[{"691", "+", 
                                        RowBox[{"9", " ", 
                                        SqrtBox["85"]}]}], ")"}], 
                                        RowBox[{"1", "/", "3"}]]}]}], 
                                  ")"}]}]]]}], ")"}]}]}]}], "]"}]}]}], 
          "}"}]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Solve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"Cos", "[", "x", "]"}], "\[Equal]", "a"}], ",", "x"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Solve", "::", "\<\"ifun\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Inverse functions are being used by \\!\\(Solve\\), so \
some solutions may not be found.\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"x", "\[Rule]", 
            RowBox[{"-", 
              RowBox[{"ArcCos", "[", "a", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", "\[Rule]", 
            RowBox[{"ArcCos", "[", "a", "]"}]}], "}"}]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "A complete solution of the last equation can be obtained using the \
function ",
  StyleBox["Reduce", "Input",
    FontWeight->"Plain"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Reduce", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"Cos", "[", "x", "]"}], "\[Equal]", "a"}], ",", "x"}], 
        "]"}], "//", "InputForm"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"//", "InputForm"}], "=", 
        RowBox[{
          RowBox[{
            RowBox[{"C", "[", "1", "]"}], "\[Element]", "Integers"}], "&&", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"x", "\[Equal]", 
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"ArcCos", "[", "a", "]"}]}], "+", 
                  RowBox[{"2", "*", "Pi", "*", 
                    RowBox[{"C", "[", "1", "]"}]}]}]}], "||", 
              RowBox[{"x", "\[Equal]", 
                RowBox[{
                  RowBox[{"ArcCos", "[", "a", "]"}], "+", 
                  RowBox[{"2", "*", "Pi", "*", 
                    RowBox[{"C", "[", "1", "]"}]}]}]}]}], ")"}]}]}], 
      "\n"}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving differential equations", "Subsubsection"],

Cell[TextData[{
  "Here are differential equations whose linear independent solutions include \
the cosine function. The solutions of the simplest second order linear \
ordinary differential equation with constant coefficients can be represented \
using ",
  Cell[BoxData[
      FormBox[
        RowBox[{"sin", "(", "z", ")"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", "(", "z", ")"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"w", "'"}], "'"}], "[", "z", "]"}], "+", 
            RowBox[{"w", "[", "z", "]"}]}], "\[Equal]", "0"}], ",", 
        RowBox[{"w", "[", "z", "]"}], ",", "z"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"w", "[", "z", "]"}], "\[Rule]", 
          RowBox[{
            RowBox[{
              RowBox[{"C", "[", "1", "]"}], " ", 
              RowBox[{"Cos", "[", "z", "]"}]}], "+", 
            RowBox[{
              RowBox[{"C", "[", "2", "]"}], " ", 
              RowBox[{"Sin", "[", "z", "]"}]}]}]}], "}"}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"dsol1", "=", 
      RowBox[{"DSolve", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"2", " ", 
                RowBox[{"w", "[", "z", "]"}]}], "+", 
              RowBox[{"3", " ", 
                RowBox[{
                  SuperscriptBox["w", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "z", "]"}]}], "+", 
              RowBox[{
                SuperscriptBox["w", 
                  TagBox[
                    RowBox[{"(", "4", ")"}],
                    Derivative],
                  MultilineFunction->None], "[", "z", "]"}]}], "==", "0"}], 
          ",", 
          RowBox[{"w", "[", "z", "]"}], ",", "z"}], "]"}]}]], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"w", "[", "z", "]"}], "\[Rule]", 
          RowBox[{
            RowBox[{
              RowBox[{"C", "[", "3", "]"}], " ", 
              RowBox[{"Cos", "[", "z", "]"}]}], "+", 
            RowBox[{
              RowBox[{"C", "[", "1", "]"}], " ", 
              RowBox[{"Cos", "[", 
                RowBox[{
                  SqrtBox["2"], " ", "z"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"C", "[", "4", "]"}], " ", 
              RowBox[{"Sin", "[", "z", "]"}]}], "+", 
            RowBox[{
              RowBox[{"C", "[", "2", "]"}], " ", 
              RowBox[{"Sin", "[", 
                RowBox[{
                  SqrtBox["2"], " ", "z"}], "]"}]}]}]}], "}"}], 
      "}"}]], "Output",
  CellLabel->"Out[9]="]
}, Closed]],

Cell[TextData[{
  "In the last input, the differential equation was solved for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"w", "(", "z", ")"}], TraditionalForm]]],
  ". If the argument is suppressed, the result is returned as a pure function \
(in the sense of the ",
  Cell[BoxData[
      FormBox["\[Lambda]", TraditionalForm]]],
  "\[Hyphen]calculus)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"dsol2", "=", 
      RowBox[{"DSolve", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"2", " ", 
                RowBox[{"w", "[", "z", "]"}]}], "+", 
              RowBox[{"3", " ", 
                RowBox[{
                  SuperscriptBox["w", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "z", "]"}]}], "+", 
              RowBox[{
                SuperscriptBox["w", 
                  TagBox[
                    RowBox[{"(", "4", ")"}],
                    Derivative],
                  MultilineFunction->None], "[", "z", "]"}]}], "==", "0"}], 
          ",", "w", ",", "z"}], "]"}]}]], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"w", "\[Rule]", 
          RowBox[{"Function", "[", 
            RowBox[{
              RowBox[{"{", "z", "}"}], ",", 
              RowBox[{
                RowBox[{
                  RowBox[{"C", "[", "3", "]"}], " ", 
                  RowBox[{"Cos", "[", "z", "]"}]}], "+", 
                RowBox[{
                  RowBox[{"C", "[", "1", "]"}], " ", 
                  RowBox[{"Cos", "[", 
                    RowBox[{
                      SqrtBox["2"], " ", "z"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"C", "[", "4", "]"}], " ", 
                  RowBox[{"Sin", "[", "z", "]"}]}], "+", 
                RowBox[{
                  RowBox[{"C", "[", "2", "]"}], " ", 
                  RowBox[{"Sin", "[", 
                    RowBox[{
                      SqrtBox["2"], " ", "z"}], "]"}]}]}]}], "]"}]}], "}"}], 
      "}"}]], "Output",
  CellLabel->"Out[10]="]
}, Closed]],

Cell["\<\
The advantage of such a pure function is, that it can be used for \
different arguments, derivatives, and more.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"w", "'"}], "[", "\[Zeta]", "]"}], " ", "/.", 
      "dsol1"}]], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        SuperscriptBox["w", "\[Prime]",
          MultilineFunction->None], "[", "\[Zeta]", "]"}], "}"}]], "Output",
  CellLabel->"Out[11]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"w", "'"}], "[", "\[Zeta]", "]"}], " ", "/.", 
      "dsol2"}]], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{"C", "[", "4", "]"}], " ", 
          RowBox[{"Cos", "[", "\[Zeta]", "]"}]}], "+", 
        RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"C", "[", "2", "]"}], " ", 
          RowBox[{"Cos", "[", 
            RowBox[{
              SqrtBox["2"], " ", "\[Zeta]"}], "]"}]}], "-", 
        RowBox[{
          RowBox[{"C", "[", "3", "]"}], " ", 
          RowBox[{"Sin", "[", "\[Zeta]", "]"}]}], "-", 
        RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"C", "[", "1", "]"}], " ", 
          RowBox[{"Sin", "[", 
            RowBox[{
              SqrtBox["2"], " ", "\[Zeta]"}], "]"}]}]}], "}"}]], "Output",
  CellLabel->"Out[12]="]
}, Closed]],

Cell[TextData[{
  "In carrying out the algorithm to solve the following nonlinear \
differential equation, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has to solve a transcendental equation. In doing so, the generically \
multivariate inverse of a function is encountered, and a message that \
potentially a solution branch is missed, is issued."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "[", "z", "]"}], "==", 
              SqrtBox[
                RowBox[{"1", "-", 
                  SuperscriptBox[
                    RowBox[{"w", "[", "z", "]"}], "2"]}]]}], ",", 
            RowBox[{
              RowBox[{"w", "[", "0", "]"}], "\[Equal]", "1"}]}], "}"}], ",", 
        RowBox[{"w", "[", "z", "]"}], ",", "z"}], "]"}]], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{"Solve", "::", "\<\"ifun\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Inverse functions are being used by \\!\\(Solve\\), so \
some solutions may not be found.\"\>"}]], "Message",
  CellLabel->"From In[13]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"w", "[", "z", "]"}], "\[Rule]", 
          RowBox[{"Cos", "[", "z", "]"}]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[13]="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Integral transforms", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " supports main integral transforms like direct and inverse Fourier, \
Laplace and Z transforms that can give results that contain classical or \
generalized functions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LaplaceTransform", "[", 
      RowBox[{
        RowBox[{"Cos", "[", "t", "]"}], ",", "t", ",", "s"}], "]"}]], "Input"],

Cell[BoxData[
    FractionBox["s", 
      RowBox[{"1", "+", 
        SuperscriptBox["s", "2"]}]]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourierTransform", "[", 
      RowBox[{
        RowBox[{"Cos", "[", "t", "]"}], ",", "t", ",", "s"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SqrtBox[
          FractionBox["\[Pi]", "2"]], " ", 
        RowBox[{"DiracDelta", "[", 
          RowBox[{
            RowBox[{"-", "1"}], "+", "s"}], "]"}]}], "+", 
      RowBox[{
        SqrtBox[
          FractionBox["\[Pi]", "2"]], " ", 
        RowBox[{"DiracDelta", "[", 
          RowBox[{"1", "+", "s"}], "]"}]}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourierSinTransform", "[", 
      RowBox[{
        RowBox[{"Cos", "[", "t", "]"}], ",", "t", ",", "s"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      FractionBox["1", 
        RowBox[{
          SqrtBox[
            RowBox[{"2", " ", "\[Pi]"}]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "s"}], ")"}]}]], "+", 
      FractionBox["1", 
        RowBox[{
          SqrtBox[
            RowBox[{"2", " ", "\[Pi]"}]], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", "s"}], ")"}]}]]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourierCosTransform", "[", 
      RowBox[{
        RowBox[{"Cos", "[", "t", "]"}], ",", "t", ",", "s"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SqrtBox[
          FractionBox["\[Pi]", "2"]], " ", 
        RowBox[{"DiracDelta", "[", 
          RowBox[{
            RowBox[{"-", "1"}], "+", "s"}], "]"}]}], "+", 
      RowBox[{
        SqrtBox[
          FractionBox["\[Pi]", "2"]], " ", 
        RowBox[{"DiracDelta", "[", 
          RowBox[{"1", "+", "s"}], "]"}]}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ZTransform", "[", 
      RowBox[{
        RowBox[{"Cos", "[", 
          RowBox[{"\[Pi]", " ", "t"}], "]"}], ",", "t", ",", "s"}], 
      "]"}]], "Input"],

Cell[BoxData[
    FractionBox["s", 
      RowBox[{"1", "+", "s"}]]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has built\[Hyphen]in functions for 2D and 3D graphics. Here are some \
examples."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Cos", "[", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", "0"}], "5"], 
              SuperscriptBox["z", "k"]}], "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"z", ",", 
              RowBox[{"-", 
                FractionBox[
                  RowBox[{"2", " ", "\[Pi]"}], "3"]}], ",", 
              FractionBox[
                RowBox[{"2", " ", "\[Pi]"}], "3"]}], "}"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"(V5.2 on byblis2) In[1]:="],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004m0000a2000`400?l0
0000o`00003oWP3oool00`000000oooo0?ooo`2L0?ooo`00WP3oool00`00
0000oooo0?ooo`2L0?ooo`00WP3oool00`000000oooo0?ooo`2L0?ooo`00
U@3oool4000000D0oooo00<000000?ooo`3oool0W03oool009L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2L0?ooo`003@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool04@3oool2000005l0oooo00<000000?ooo`3oool0103oool3
00000300oooo0`00000N0?ooo`8000003@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000090?ooo`003@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00P0oooo0P00000C0?ooo`030000003oool0
000005H0oooo100000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0<03oool010000000oooo0?ooo`00000M0?ooo`8000003@3o
ool2000000P0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000T0
oooo000=0?ooo`030000003oool0oooo00D0oooo0P00000:0?ooo`800000
4`3oool00`000000oooo0000001N0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01X0oooo0P00000=0?ooo`800000203oool2000000H0oooo
0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000090?ooo`003@3oool00`000000oooo0?ooo`050?ooo`80
00002P3oool00`000000oooo0000000B0?ooo`030000003oool0000005`0
oooo0`0000060?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0J0?ooo`8000003@3oool2000000P0
oooo0P0000060?ooo`800000103oool2000000@0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`070?ooo`003@3oool00`00
0000oooo0?ooo`050?ooo`8000002P3oool00`000000oooo0000000B0?oo
o`030000003oool0000005h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool06P3oool2000000d0oooo0P0000080?ooo`8000001P3oool20000
00@0oooo0P0000040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool01`3oool000d0oooo00<000000?ooo`3oool01@3oool2
000000X0oooo00<000000?ooo`0000004P3oool010000000oooo0?ooo`00
001T0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0000000`0oooo0P00
00080?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool01`3oool000d0oooo
00<000000?ooo`3oool01@3oool2000000X0oooo00<000000?ooo`000000
4@3oool01@000000oooo0?ooo`3oool0000006@0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`000000303oool2000000P0oooo0P0000060?ooo`80
0000103oool2000000@0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`070?ooo`003@3oool00`000000oooo0?ooo`050?oo
o`8000002P3oool00`000000oooo0000000A0?ooo`050000003oool0oooo
0?ooo`000000I03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`00
000<0?ooo`800000203oool2000000H0oooo0P0000040?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00L0
oooo000=0?ooo`030000003oool0oooo00D0oooo0P00000:0?ooo`030000
003oool000000140oooo00D000000?ooo`3oool0oooo0000001T0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0H0?ooo`040000003oool0oooo000000`0oooo0P0000080?oo
o`8000001P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool01`3oool000d0oooo00<00000
0?ooo`3oool01@3oool2000000X0oooo00<000000?ooo`0000004@3oool0
1@000000oooo0?ooo`3oool0000006@0oooo0P00000]0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool05`3oool010000000oooo0?oo
o`00000<0?ooo`800000203oool2000000H0oooo0P0000040?ooo`800000
103oool010000000oooo0?ooo`3oool2000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000002@3oool0
00d0oooo00<000000?ooo`3oool01@3oool2000000X0oooo00<000000?oo
o`0000004@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01L0oooo00@000000?ooo`3oool00000303oool2
000000P0oooo0P0000060?ooo`800000103oool2000000@0oooo00@00000
0?ooo`3oool0oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000T0oooo000<0?ooo`030000
003oool0000000H0oooo0P00000:0?ooo`030000003oool000000140oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0G0?ooo`040000003oool0oooo000000`0oooo0P0000080?ooo`80
00001P3oool2000000@0oooo0P0000040?ooo`040000003oool0oooo0?oo
o`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000090?ooo`00303oool00`000000oooo00000006
0?ooo`8000002P3oool00`000000oooo0000000A0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05`3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0000000P0oooo0P00
00060?ooo`800000103oool2000000@0oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000T0oooo000<0?ooo`030000003oool0000000H0
oooo00<000000?ooo`0000002@3oool00`000000oooo0000000@0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0H@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool05`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool00000
00P0oooo0P0000060?ooo`800000103oool2000000<0oooo0P0000030?oo
o`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000090?ooo`00303oool00`000000oooo00000006
0?ooo`030000003oool0000000T0oooo00<000000?ooo`000000403oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01L0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000
00080?ooo`8000001P3oool2000000@0oooo0P0000030?ooo`8000000`3o
ool2000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000002@3oool000`0oooo00<000000?ooo`000000
1P3oool00`000000oooo000000080?ooo`040000003oool0oooo00000100
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1Q0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0F0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`0000001`3oool00`000000oooo000000060?ooo`800000103oool20000
00<0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`020000
0080oooo0P0000020?ooo`030000003oool0oooo00L0oooo000<0?ooo`03
0000003oool0000000H0oooo00<000000?ooo`000000203oool010000000
oooo0?ooo`00000@0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001P3oool2
000000@0oooo0P0000030?ooo`8000000`3oool2000000<0oooo00<00000
0?ooo`3oool00P0000020?ooo`8000000P3oool00`000000oooo0?ooo`07
0?ooo`00303oool00`000000oooo000000060?ooo`030000003oool00000
00P0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo000000070?ooo`030000003o
ool0000000D0oooo00<000000?ooo`000000103oool2000000<0oooo00<0
00000?ooo`0000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool200000080oooo00<000000?ooo`3oool01`3oool000`0oooo00<00000
0?ooo`0000001P3oool00`000000oooo000000080?ooo`040000003oool0
oooo00000100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1Q0?ooo`800000:`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01H0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
000000070?ooo`030000003oool0000000D0oooo00<000000?ooo`000000
103oool2000000<0oooo00<000000?ooo`0000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool2000000030?ooo`000000000000T0oooo
000<0?ooo`030000003oool0000000H0oooo00<000000?ooo`000000203o
ool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0000000L0oooo00<000000?ooo`00
00001@3oool00`000000oooo000000040?ooo`8000000`3oool00`000000
oooo000000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`80
000000<0oooo0000000000002@3oool000`0oooo00<000000?ooo`000000
1P3oool00`000000oooo000000080?ooo`040000003oool0oooo00000100
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000002P3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0000000D0oooo00<00000
0?ooo`000000103oool2000000<0oooo00<000000?ooo`0000000P3oool2
00000080oooo0P0000020?ooo`8000000P3oool2000000030?ooo`000000
000000T0oooo000<0?ooo`030000003oool0000000H0oooo00<000000?oo
o`000000203oool010000000oooo0?ooo`00000?0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05P3oool0
1@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo000000050?ooo`030000003oool0000000@0oooo
0P0000030?ooo`030000003oool000000080oooo0P0000020?ooo`800000
0P3oool200000080oooo0P0000000`3oool00000000000090?ooo`00303o
ool00`000000oooo000000060?ooo`030000003oool0000000P0oooo00@0
00000?ooo`3oool000003`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`0000001@3oool00`000000oooo000000040?ooo`8000000`3oool00`00
0000oooo000000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`80000000<0oooo0000000000002@3oool000`0oooo00<000000?ooo`00
00001P3oool00`000000oooo000000080?ooo`040000003oool0oooo0000
00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000002P3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0000000D0oooo00<0
00000?ooo`000000103oool2000000<0oooo00<000000?ooo`0000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool2000000030?ooo`00
0000000000T0oooo000<0?ooo`030000003oool0000000H0oooo00<00000
0?ooo`000000203oool010000000oooo0?ooo`00000?0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo000000050?ooo`030000003oool0000000@0
oooo0P0000030?ooo`030000003oool000000080oooo0P0000020?ooo`80
00000P3oool200000080oooo0P0000000`3oool00000000000090?ooo`00
303oool00`000000oooo000000050?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`0000001@3oool00`000000oooo000000040?ooo`8000000`3o
ool00`000000oooo000000020?ooo`8000000P3oool200000080oooo0P00
00020?ooo`80000000<0oooo0000000000002@3oool000`0oooo00<00000
0?ooo`0000001@3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`00
00002P3oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`000000103oool2000000<0oooo00<00000
0?ooo`0000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
000000030?ooo`000000000000T0oooo000<0?ooo`030000003oool00000
00D0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool000001P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0000000@0oooo0P0000030?ooo`03
0000003oool000000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000000`3oool00000000000090?ooo`00303oool00`000000oooo
000000050?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3o
ool0oooo0000000>0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0H03oool2000002T0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000060?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`000000103oool2000000<0oooo00<0
00000?ooo`0000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool2000000030?ooo`000000000000T0oooo000<0?ooo`030000003oool0
000000D0oooo00@000000?ooo`3oool00000203oool01@000000oooo0?oo
o`3oool0000000h0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000060?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`000000103oool20000
00<0oooo00<000000?ooo`0000000P3oool200000080oooo0P0000020?oo
o`8000000P3oool2000000030?ooo`000000000000T0oooo000<0?ooo`03
0000003oool0000000D0oooo00@000000?ooo`3oool00000203oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00
00060?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`000000
103oool2000000<0oooo00<000000?ooo`0000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool2000000030?ooo`000000000000T0oooo
000<0?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool00000
203oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`0000060?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`000000103oool2000000<0oooo00<000000?ooo`0000000P3oool2
00000080oooo0P0000020?ooo`8000000P3oool2000000030?ooo`000000
000000T0oooo000<0?ooo`030000003oool0000000D0oooo00@000000?oo
o`3oool00000203oool01@000000oooo0?ooo`3oool0000000d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`000000103oool2000000<0oooo00<000000?ooo`00
00000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000003
0?ooo`000000000000T0oooo000<0?ooo`030000003oool0000000D0oooo
00@000000?ooo`3oool00000203oool01@000000oooo0?ooo`3oool00000
00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000060?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`000000103oool2000000<0oooo00<0
00000?ooo`0000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool2000000030?ooo`000000000000T0oooo000<0?ooo`030000003oool0
000000D0oooo00@000000?ooo`3oool00000203oool01@000000oooo0?oo
o`3oool0000000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000060?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`000000103oool20000
00<0oooo00<000000?ooo`0000000P3oool200000080oooo0P0000020?oo
o`8000000P3oool2000000030?ooo`000000000000T0oooo000<0?ooo`03
0000003oool0000000D0oooo00@000000?ooo`3oool00000203oool01@00
0000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00
00060?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`000000
103oool2000000<0oooo00<000000?ooo`0000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool2000000030?ooo`000000000000T0oooo
000<0?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool00000
203oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`0000060?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`000000103oool2000000<0oooo00<000000?ooo`0000000P3oool2
00000080oooo00@000000?ooo`000000oooo0P0000020?ooo`80000000<0
oooo0000000000002@3oool000`0oooo00<000000?ooo`0000001@3oool0
10000000oooo0?ooo`0000080?ooo`050000003oool0oooo0?ooo`000000
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05l0oooo
0P00000W0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0000000@0oooo0P0000030?ooo`030000003oool00000
0080oooo0P0000020?ooo`040000003oool000000?ooo`8000000P3oool2
000000030?ooo`000000000000T0oooo000<0?ooo`030000003oool00000
00D0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00
00060?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`000000
103oool2000000<0oooo00<000000?ooo`0000000P3oool200000080oooo
00@000000?ooo`000000oooo0P0000020?ooo`80000000<0oooo00000000
00002@3oool000`0oooo00<000000?ooo`0000001@3oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000H0oooo00@000000?oo
o`3oool00000103oool00`000000oooo000000040?ooo`8000000`3oool0
0`000000oooo000000020?ooo`8000000P3oool010000000oooo0000003o
ool200000080oooo0P0000000`3oool00000000000090?ooo`00303oool0
0`000000oooo000000050?ooo`040000003oool0oooo000000L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000001P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0000000@0oooo0P0000030?ooo`030000003oool000000080
oooo0P0000020?ooo`040000003oool000000?ooo`8000000P3oool20000
00030?ooo`000000000000T0oooo000<0?ooo`030000003oool0000000D0
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000006
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`000000103o
ool2000000<0oooo00<000000?ooo`0000000P3oool200000080oooo00@0
00000?ooo`000000oooo0P0000020?ooo`80000000<0oooo000000000000
2@3oool000`0oooo00<000000?ooo`0000001@3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool200000080oooo00@000000?oo
o`000000oooo0P0000020?ooo`80000000<0oooo0000000000002@3oool0
00`0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`000007
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo05h0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool00000
103oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool200000080oooo00@000000?ooo`000000
oooo0P0000020?ooo`80000000<0oooo0000000000002@3oool000`0oooo
00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo04X0oooo0P0000040?ooo`03
0000003oool0oooo0080oooo0`0000060?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool010000000
oooo0?ooo`0000060?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0
00000080oooo0P0000020?ooo`040000003oool000000?ooo`8000000P3o
ool2000000030?ooo`000000000000T0oooo000<0?ooo`030000003oool0
000000D0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`190?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00001P3oool010000000oooo0?ooo`0000040?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`8000000P3oool010000000oooo0000003oool200000080oooo0P000000
0`3oool00000000000090?ooo`00303oool00`000000oooo000000050?oo
o`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0B@3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo00<0oooo0`00000T0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`3oool000001P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`8000000P3oool010000000
oooo0000003oool200000080oooo0P0000000`3oool00000000000090?oo
o`00303oool00`000000oooo000000050?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@`3oool40000
0080oooo00@000000?ooo`3oool00000203oool3000000H0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool00000
103oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool200000080oooo00@000000?ooo`000000
oooo0P0000020?ooo`80000000<0oooo0000000000002@3oool000`0oooo
00<000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0B03oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000H0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`00
0000oooo0P0000020?ooo`80000000<0oooo0000000000002@3oool000`0
oooo00<000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0B03oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool00000
103oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool020000000oooo0000003oool000000?oo
o`000000oooo0P0000020?ooo`80000000<0oooo0000000000002@3oool0
00`0oooo00<000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0B@3oool2
000000T0oooo100000050?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00@000000?ooo`3oool00000103oool00`000000oooo
000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0P3oool020000000oooo0000003oool000000?ooo`000000oooo0P000002
0?ooo`80000000<0oooo0000000000002@3oool000`0oooo00<000000?oo
o`0000001@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000
003oool000000080oooo00P000000?ooo`000000oooo0000003oool00000
0?ooo`8000000P3oool2000000030?ooo`000000000000T0oooo000;0?oo
o`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`080000003oool000000?oo
o`000000oooo0000003oool200000080oooo0P0000000`3oool000000000
00090?ooo`002`3oool010000000oooo0?ooo`0000050?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1M0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00@000000?ooo`3oool00000103oool00`000000oooo000000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02000
0000oooo0000003oool000000?ooo`000000oooo0P0000020?ooo`800000
00<0oooo0000000000002@3oool000/0oooo00@000000?ooo`3oool00000
1@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00P000000?ooo`000000oooo0000003oool000000?oo
o`8000000P3oool2000000030?ooo`000000000000T0oooo000;0?ooo`04
0000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`080000003oool000000?oo
o`000000oooo0000003oool200000080oooo0P0000000`3oool000000000
00090?ooo`002`3oool010000000oooo0?ooo`0000050?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1M0?ooo`8000008P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000
oooo0?ooo`0000040?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`080000003oool0
00000?ooo`000000oooo0000003oool200000080oooo0P0000000`3oool0
0000000000090?ooo`002`3oool010000000oooo0?ooo`0000050?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`00
0000oooo0P0000020?ooo`80000000<0oooo0000000000002@3oool000/0
oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00P000000?ooo`000000oooo0000003oool000000?ooo`8000000P3oool2
000000030?ooo`000000000000T0oooo000;0?ooo`040000003oool0oooo
000000D0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`080000003oool000000?oo
o`000000oooo0000003oool200000080oooo0P0000000`3oool000000000
00090?ooo`002`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo05d0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000
003oool200000080oooo0P0000000`3oool00000000000090?ooo`002`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`080000003oool000000?ooo`000000oooo0000003oool200000080
oooo0P0000000`3oool00000000000090?ooo`002`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`080000003o
ool000000?ooo`000000oooo0000003oool200000080oooo0P0000000`3o
ool00000000000090?ooo`002`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`080000003oool000000?ooo`00
0000oooo0000003oool200000080oooo0P0000000`3oool0000000000009
0?ooo`002`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003o
ool200000080oooo0P0000000`3oool00000000000090?ooo`002`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05`0oooo
0P00000P0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool02000
0000oooo0000003oool000000?ooo`000000oooo0P0000020?ooo`800000
00<0oooo0000000000002@3oool000/0oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`080000003oool0
00000?ooo`000000oooo0000003oool200000080oooo0P0000000`3oool0
0000000000090?ooo`002`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000
00030?ooo`030000003oool000000080oooo00P000000?ooo`000000oooo
0000003oool000000?ooo`8000000P3oool2000000030?ooo`0000000000
00T0oooo000;0?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool020000000oooo0000003oool000000?oo
o`000000oooo0P0000020?ooo`80000000<0oooo0000000000002@3oool0
00/0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1L0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003o
ool200000080oooo0P0000000`3oool00000000000090?ooo`001`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool010000000oooo0?ooo`0000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool020000000oooo0000003oool0
00000?ooo`000000oooo0P0000020?ooo`80000000<0oooo000000000000
2@3oool000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo000000030?ooo`030000003oool000000080oooo00P00000
0?ooo`000000oooo0000003oool000000?ooo`8000000P3oool200000003
0?ooo`000000000000T0oooo00070?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`080000003oool000000?ooo`000000oooo0000003oool20000
0080oooo0P0000000`3oool00000000000090?ooo`001`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool020000000oooo0000003oool000000?oo
o`000000oooo0P0000020?ooo`80000000<0oooo0000000000002@3oool0
00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo05/0oooo0P00000N0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool020000000oooo0000003oool00000
0?ooo`000000oooo0P0000020?ooo`80000000<0oooo0000000000002@3o
ool000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00`000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool20000
00030?ooo`000000000000T0oooo00070?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`0<0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0P0000000`3oool00000000000090?ooo`001`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool030000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo
0000000000002@3oool000L0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00`000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool2000000030?ooo`000000000000T0oooo00070?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool000000080oooo00`000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool2000000030?oo
o`000000000000T0oooo00070?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
0080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool000000080oooo00`000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool2000000030?ooo`000000000000T0oooo0007
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00`0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool2000000030?ooo`000000000000T0oooo00070?ooo`050000003oool0
oooo0?ooo`0000000`3oool4000000030?ooo`000000oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0D0?ooo`@00000@`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool00`3oool4000000H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool0
20000000oooo0000003oool000000?ooo`000000oooo1P0000000`3oool0
0000000000090?ooo`001`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool0
00000P3oool020000000oooo0000003oool000000?ooo`000000oooo0`00
0000103oool000000000003oool2000000T0oooo00070?ooo`050000003o
ool0oooo0?ooo`0000000`3oool2000000<0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0@P3oool2000001/0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool00000
0P3oool030000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`80000000<0oooo0000000000002@3oool000L0oooo00<0
00000?ooo`0000000`0000020?ooo`030000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo100000040?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`0:0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`@0000000<0oooo
0000000000002@3oool000L0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000
oooo00000080oooo00`000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool2000000030?ooo`000000000000T0oooo0008
0?ooo`040000003oool0oooo000000<0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool04`3oool3000004@0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0
oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`00
0000oooo00000080oooo00P000000?ooo`000000oooo0000003oool00000
0?ooo`<0000000@0oooo000000000000oooo0P0000090?ooo`00203oool0
10000000oooo0?ooo`0000030?ooo`<000000P3oool01@000000oooo0?oo
o`3oool0000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo
0000003oool000000P3oool02P000000oooo0000003oool000000?ooo`00
0000oooo0000003oool4000000030?ooo`000000000000T0oooo00080?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`0<0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0P000000
0`3oool00000000000090?ooo`00203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000
003oool000000P3oool030000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`80000000<0oooo0000000000002@3oool0
00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00`00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool2
000000030?ooo`000000000000T0oooo00080?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3o
ool000000?ooo`0000020?ooo`0<0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0P0000000`3oool0000000000009
0?ooo`00o`00000n00000000203oool010000000oooo0?ooo`0000020?oo
o`800000103oool01@000000oooo0?ooo`3oool0000000@0oooo0P000007
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool000003@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo008000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00<000000P3oool02P000000
oooo0000003oool000000?ooo`000000oooo0000003oool4000000030?oo
o`000000000000T0oooo00080?ooo`040000003oool0oooo00000080oooo
0P0000040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`0:0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`@0000000<0
oooo0000000000002@3oool000P0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
0000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo
00`000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool2000000030?ooo`000000000000T0oooo00080?ooo`040000003o
ool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool00000
0?ooo`0000020?ooo`0<0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0P0000000`3oool00000000000090?ooo`00
203oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000P3oool030000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo0000
000000002@3oool000P0oooo00@000000?ooo`3oool000000`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00`00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool2
000000030?ooo`000000000000T0oooo00080?ooo`040000003oool0oooo
000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`00
00020?ooo`0<0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0P0000000`3oool00000000000090?ooo`00203oool0
10000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0
oooo0000003oool000000P3oool030000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`80000000<0oooo000000000000
2@3oool000P0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1I0?ooo`8000005@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`080000003o
ool0oooo0000003oool000000?ooo`0000020?ooo`0:0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo00000000
00002@3oool000P0oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool020000000oooo0?ooo`000000oooo0000003oool000000P3oool0
2P000000oooo0000003oool000000?ooo`000000oooo0000003oool20000
00030?ooo`000000000000T0oooo00080?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00P000000?ooo`3oool000000?ooo`000000
oooo00000080oooo00X000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0P0000000`3oool00000000000090?ooo`00203oool01000
0000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool000000P3oool020000000oooo0?ooo`000000
oooo0000003oool000000P3oool02P000000oooo0000003oool000000?oo
o`000000oooo0000003oool2000000030?ooo`000000000000T0oooo0008
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000020?ooo`080000003oool0
oooo0000003oool000000?ooo`0000020?ooo`0:0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`80000000<0oooo000000000000
2@3oool000P0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00P0
00000?ooo`3oool000000?ooo`000000oooo00000080oooo00X000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0P0000000`3oool0
0000000000090?ooo`00203oool010000000oooo0?ooo`0000030?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool020000000oooo0?ooo`000000oooo0000003oool000000P3oool0
2P000000oooo0000003oool000000?ooo`000000oooo0000003oool20000
00030?ooo`000000000000T0oooo00080?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0
00000P3oool020000000oooo0?ooo`000000oooo0000003oool000000P3o
ool02P000000oooo0000003oool000000?ooo`000000oooo0000003oool2
000000030?ooo`000000000000T0oooo00080?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3o
ool000000P3oool020000000oooo0?ooo`000000oooo0000003oool00000
0P3oool02P000000oooo0000003oool000000?ooo`000000oooo0000003o
ool2000000030?ooo`000000000000T0oooo00080?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05P0oooo
0P00000A0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000002
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?ooo`0:
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`800000
00<0oooo0000000000002@3oool000P0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00@0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00
00020?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?oo
o`0:0000003oool000000?ooo`000000oooo0000003oool000000?ooo`80
000000<0oooo0000000000002@3oool000P0oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000000@0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?oo
o`0000020?ooo`080000003oool0oooo0000003oool000000?ooo`000002
0?ooo`0:0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`80000000<0oooo0000000000002@3oool000P0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00@000000?ooo`3oool000000`3oool010000000oooo
0?ooo`0000020?ooo`080000003oool0oooo0000003oool000000?ooo`00
00020?ooo`080000003oool000000?ooo`000000oooo0000003oool20000
00030?ooo`000000oooo008000002@3oool000P0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00@000000?ooo`3oool000000`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`00
00000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P00
00000`3oool000000?ooo`02000000T0oooo00080?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000<0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80
000000<0oooo0000003oool00P0000090?ooo`00203oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`0000000P3oool00`000000oooo
000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2
000000030?ooo`000000oooo008000002@3oool000P0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?oo
o`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo
0P0000000`3oool000000?ooo`02000000T0oooo00080?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo000000020?ooo`030000003o
ool000000080oooo00P000000?ooo`000000oooo0000003oool000000?oo
o`80000000<0oooo0000003oool00P0000090?ooo`00203oool010000000
oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`0000000P3oool00`000000
oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003o
ool2000000030?ooo`000000oooo008000002@3oool000P0oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
E`3oool2000000d0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
0000103oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000`3oool200000080oooo00P00000
0?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo0000003o
ool00P0000090?ooo`00203oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`0000000`3oool200000080oooo00P000000?ooo`000000
oooo0000003oool000000?ooo`80000000<0oooo0000003oool00P000009
0?ooo`00203oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo
0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`0000000`3oool200000080oooo00P000000?ooo`000000oooo0000003o
ool000000?ooo`80000000<0oooo0000003oool00P0000090?ooo`00203o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3o
ool200000080oooo00P000000?ooo`000000oooo0000003oool000000?oo
o`80000000D0oooo000000000000oooo000000090?ooo`00203oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool20000
0080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`800000
00D0oooo000000000000oooo000000090?ooo`00203oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`0000000`3oool200000080oooo
00P000000?ooo`000000oooo0000003oool000000?ooo`80000000D0oooo
000000000000oooo000000090?ooo`00203oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
0000103oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000`3oool200000080oooo00P00000
0?ooo`000000oooo0000003oool000000?ooo`80000000D0oooo00000000
0000oooo000000090?ooo`00203oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103o
ool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`0000000`3oool200000080oooo00P000000?ooo`00
0000oooo0000003oool000000?ooo`80000000D0oooo000000000000oooo
000000090?ooo`00203oool00`000000oooo000000050?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`0000000`3oool200000080oooo00P000000?ooo`000000oooo0000
003oool000000?ooo`80000000D0oooo000000000000oooo000000090?oo
o`00203oool00`000000oooo000000050?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`1F0?ooo`8000001`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`800000
0P3oool020000000oooo0000003oool000000?ooo`000000oooo0P000000
1@3oool000000000003oool0000000T0oooo00080?ooo`030000003oool0
000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000040?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo000000030?ooo`8000000P3oool02000
0000oooo0000003oool000000?ooo`000000oooo0P0000001@3oool00000
0000003oool0000000T0oooo00080?ooo`030000003oool0000000D0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000040?oo
o`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo000000030?ooo`8000000P3oool020000000oooo0000
003oool000000?ooo`000000oooo0P0000001@3oool000000000003oool0
000000T0oooo00080?ooo`030000003oool0000000D0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo000000030?ooo`8000000P3oool020000000oooo0000003oool00000
0?ooo`000000oooo0P0000001@3oool000000000003oool0000000T0oooo
00080?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0000
00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo00000003
0?ooo`8000000P3oool020000000oooo0000003oool000000?ooo`000000
oooo0P0000001@3oool000000000003oool0000000T0oooo00080?ooo`03
0000003oool0000000D0oooo00@000000?ooo`3oool000001@3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo000000030?ooo`8000000P3oool020000000
oooo0000003oool000000?ooo`000000oooo0P0000001@3oool000000000
003oool0000000T0oooo00080?ooo`030000003oool0000000D0oooo00<0
00000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2P3oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo000000030?ooo`8000000P3o
ool020000000oooo0000003oool000000?ooo`000000oooo0P0000001@3o
ool000000000003oool0000000T0oooo00080?ooo`030000003oool00000
00D0oooo00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0440oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`0000060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00X0oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003o
ool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool20000
0080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`800000
00D0oooo000000000000oooo000000090?ooo`00203oool00`000000oooo
000000050?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`100?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000003l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:
0?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo0P0000020?oo
o`080000003oool000000?ooo`000000oooo0000003oool2000000050?oo
o`00000000000?ooo`0000002@3oool000P0oooo00<000000?ooo`000000
1@3oool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0@03oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo00<0oooo100000100?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0
000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo000000030?ooo`8000000P3oool200000080oooo00@000000?ooo`00
0000oooo0P0000000`3oool00000000000020?ooo`030000003oool0oooo
00H0oooo00080?ooo`030000003oool0000000D0oooo00<000000?ooo`00
00001P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0400oooo00@000000?ooo`3oool00000203oool3000000H0oooo00<00000
0?ooo`000000@@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00X0oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003o
ool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool20000
0080oooo0P0000020?ooo`040000003oool000000?ooo`80000000<0oooo
0000000000000P3oool00`000000oooo0?ooo`060?ooo`00203oool00`00
0000oooo000000050?ooo`030000003oool0000000H0oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`100?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00120?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3o
ool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool0
00001@3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000`3oool200000080oooo0P000002
0?ooo`040000003oool000000?ooo`80000000<0oooo0000000000000P3o
ool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo00000005
0?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`100?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool01P3oool2000004<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`00
00001`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo
000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000
00030?ooo`8000000P3oool200000080oooo00@000000?ooo`000000oooo
0P0000000`3oool00000000000020?ooo`030000003oool0oooo00H0oooo
00080?ooo`030000003oool0000000D0oooo00<000000?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0440oooo
0P0000090?ooo`@000001@3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool01@000000oooo
0?ooo`3oool0000000L0oooo00@000000?ooo`3oool000001@3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`0000000`3oool200000080oooo0P0000020?ooo`040000003o
ool000000?ooo`80000000<0oooo0000000000000P3oool00`000000oooo
0?ooo`060?ooo`00203oool00`000000oooo000000050?ooo`030000003o
ool0000000H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`1C0?ooo`800000A03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000070?ooo`04
0000003oool0oooo000000D0oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo0P00
00020?ooo`8000000P3oool010000000oooo0000003oool2000000030?oo
o`00000000000080oooo00<000000?ooo`3oool01P3oool000P0oooo00<0
00000?ooo`0000001@3oool00`000000oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
000000140?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3o
ool000001@3oool010000000oooo0?ooo`0000030?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`0000000`3oool200000080oooo0P00
00020?ooo`040000003oool000000?ooo`80000000<0oooo000000000000
0P3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0000
00050?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`1A0?ooo`040000003oool0oooo000004@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`000005
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000030?ooo`8000000P3oool200000080oooo00@0
00000?ooo`000000oooo0P0000000`3oool00000000000020?ooo`030000
003oool0oooo00H0oooo00080?ooo`030000003oool0000000D0oooo00<0
00000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0500oooo00D000000?ooo`3oool0oooo000000140?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool01@000000
oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0000000@0oooo0P00
00030?ooo`8000000P3oool200000080oooo00@000000?ooo`000000oooo
0P0000000`3oool00000000000020?ooo`030000003oool0oooo00H0oooo
00080?ooo`030000003oool0000000D0oooo00<000000?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool01@000000oooo
0?ooo`3oool0000000L0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo000000040?ooo`030000003oool0000000@0oooo0P0000030?oo
o`8000000P3oool200000080oooo00@000000?ooo`000000oooo0P000000
0`3oool00000000000020?ooo`030000003oool0oooo00H0oooo00080?oo
o`030000003oool0000000D0oooo00<000000?ooo`0000001P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool00`3oool2000004<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo
00<000000?ooo`000000103oool2000000<0oooo0P0000020?ooo`800000
0P3oool010000000oooo0000003oool200000080oooo00@000000?ooo`3o
ool00000203oool000P0oooo00<000000?ooo`0000001@3oool00`000000
oooo000000060?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0C03oool2000000H0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00D000000?oo
o`3oool0oooo000000070?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`0000001@3oool2000000@0oooo0P0000030?ooo`8000000P3o
ool200000080oooo00@000000?ooo`000000oooo0P0000020?ooo`040000
003oool0oooo000000P0oooo00080?ooo`030000003oool0000000D0oooo
00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02`3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo000000050?ooo`800000103oool2
000000<0oooo0P0000020?ooo`8000000P3oool010000000oooo0000003o
ool200000080oooo00@000000?ooo`3oool00000203oool000P0oooo00<0
00000?ooo`0000001@3oool00`000000oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`00
00001`3oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
00D0oooo0P0000040?ooo`8000000`3oool200000080oooo0P0000020?oo
o`040000003oool000000?ooo`8000000P3oool010000000oooo0?ooo`00
00080?ooo`00203oool00`000000oooo000000050?ooo`030000003oool0
000000H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`170?ooo`8000002P3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?oo
o`3oool0000000L0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo000000050?ooo`800000103oool2000000<0oooo0P0000020?ooo`80
00000P3oool010000000oooo0000003oool200000080oooo00@000000?oo
o`3oool00000203oool000P0oooo00<000000?ooo`0000001@3oool00`00
0000oooo000000070?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo000000050?ooo`800000103oool2000000<0oooo
0P0000020?ooo`8000000P3oool010000000oooo0000003oool200000080
oooo00@000000?ooo`3oool00000203oool000P0oooo00<000000?ooo`00
00001@3oool00`000000oooo000000070?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo04@0oooo0P00000=0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?oo
o`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0000000D0oooo0P0000040?ooo`8000000`3o
ool200000080oooo0P0000020?ooo`040000003oool000000?ooo`800000
0P3oool010000000oooo0?ooo`0000080?ooo`00203oool00`000000oooo
000000050?ooo`030000003oool0000000L0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000001`3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0000000D0oooo0P000004
0?ooo`8000000`3oool200000080oooo0P0000020?ooo`040000003oool0
00000?ooo`8000000P3oool010000000oooo0?ooo`0000080?ooo`00203o
ool00`000000oooo000000050?ooo`030000003oool0000000L0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0@03oool200000100oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000070?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`0000001@3oool20000
00@0oooo0P0000030?ooo`8000000P3oool200000080oooo00@000000?oo
o`000000oooo0P0000020?ooo`040000003oool0oooo000000P0oooo0008
0?ooo`030000003oool0000000D0oooo00<000000?ooo`0000001`3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0100oooo0P0000140?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000L0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo000000050?ooo`80
0000103oool2000000<0oooo0P0000020?ooo`8000000P3oool010000000
oooo0000003oool200000080oooo00@000000?ooo`3oool00000203oool0
00P0oooo00<000000?ooo`0000001@3oool00`000000oooo000000070?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03d0oooo0P00000C
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0000000D0oooo
0P0000040?ooo`8000000`3oool200000080oooo0P0000020?ooo`040000
003oool000000?ooo`8000000P3oool010000000oooo0?ooo`0000080?oo
o`00203oool00`000000oooo000000050?ooo`030000003oool0000000L0
oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?oo
o`0000001`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
000000D0oooo0P0000040?ooo`8000000`3oool200000080oooo0P000002
0?ooo`040000003oool000000?ooo`8000000P3oool010000000oooo0?oo
o`0000080?ooo`00203oool00`000000oooo000000050?ooo`030000003o
ool0000000L0oooo00<000000?ooo`0000002`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0>@3o
ool2000001H0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo
000000070?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`00
00001@3oool2000000@0oooo0P0000030?ooo`8000000P3oool200000080
oooo00@000000?ooo`000000oooo0P0000020?ooo`040000003oool0oooo
000000P0oooo00080?ooo`030000003oool0000000D0oooo00<000000?oo
o`0000001`3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0g0?oo
o`800000603oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0
000000P0oooo00<000000?ooo`0000001P3oool2000000D0oooo0P000004
0?ooo`8000000`3oool200000080oooo0P0000020?ooo`8000000P3oool2
00000080oooo00@000000?ooo`3oool00000203oool000P0oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000070?ooo`030000003oool0
000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo03D0oooo0P00000J0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0000
00060?ooo`8000001@3oool2000000@0oooo0P0000030?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool010000000oooo0?oo
o`0000080?ooo`00203oool00`000000oooo000000050?ooo`030000003o
ool0000000L0oooo00<000000?ooo`0000002`3oool01@000000oooo0?oo
o`3oool0000001d0oooo00<000000?ooo`3oool0<`3oool2000001`0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0000000H0oooo0P0000050?ooo`800000103oool2000000<0
oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`04
0000003oool0oooo000000P0oooo00080?ooo`030000003oool0000000D0
oooo00<000000?ooo`0000001`3oool00`000000oooo0000000;0?ooo`05
0000003oool0oooo0?ooo`0000007P3oool00`000000oooo0?ooo`0`0?oo
o`8000007P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`000009
0?ooo`030000003oool0000000H0oooo0P0000050?ooo`800000103oool2
000000<0oooo0P0000020?ooo`8000000P3oool200000080oooo0P000002
0?ooo`040000003oool0oooo000000P0oooo00080?ooo`030000003oool0
000000D0oooo00<000000?ooo`0000001`3oool00`000000oooo0000000;
0?ooo`050000003oool0oooo0?ooo`0000007P3oool00`000000oooo0?oo
o`0^0?ooo`800000803oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0303oool010000000oooo0?oo
o`0000090?ooo`030000003oool0000000H0oooo0P0000050?ooo`800000
103oool2000000<0oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo`040000003oool0oooo000000P0oooo00080?ooo`030000
003oool0000000D0oooo00<000000?ooo`0000001`3oool00`000000oooo
0000000;0?ooo`050000003oool0oooo0?ooo`0000007P3oool00`000000
oooo0?ooo`0/0?ooo`8000008P3oool2000004@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`0000001P3oool2000000D0oooo0P0000040?oo
o`8000000`3oool200000080oooo0P0000020?ooo`8000000P3oool20000
0080oooo00@000000?ooo`3oool00000203oool000T0oooo0P0000050?oo
o`030000003oool0000000L0oooo00<000000?ooo`0000002`3oool01@00
0000oooo0?ooo`3oool0000001h0oooo00<000000?ooo`3oool0:@3oool3
000002@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo000000060?ooo`8000001@3oool2000000@0oooo0P00
00030?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool010000000oooo0?ooo`0000080?ooo`002@3oool2000000D0oooo00<0
00000?ooo`0000001`3oool00`000000oooo0000000<0?ooo`040000003o
ool0oooo000001l0oooo00<000000?ooo`3oool09P3oool2000002L0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00`0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo000000060?ooo`8000001@3oool2000000@0oooo0P0000030?ooo`80
00000P3oool200000080oooo0P0000020?ooo`8000000P3oool010000000
oooo0?ooo`0000080?ooo`002@3oool2000000D0oooo00<000000?ooo`00
00001`3oool00`000000oooo0000000<0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool0903oool2000002T0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo00000006
0?ooo`8000001@3oool2000000@0oooo0P0000030?ooo`8000000P3oool2
000000<0oooo00<000000?ooo`3oool00P0000020?ooo`040000003oool0
oooo000000P0oooo00090?ooo`8000001@3oool00`000000oooo00000007
0?ooo`030000003oool0000000`0oooo00@000000?ooo`3oool000007`3o
ool00`000000oooo0?ooo`0R0?ooo`800000:`3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0000000H0oooo
0P0000050?ooo`800000103oool2000000<0oooo0P0000020?ooo`800000
0`3oool00`000000oooo0?ooo`0200000080oooo00@000000?ooo`3oool0
0000203oool000T0oooo0P0000050?ooo`030000003oool0000000L0oooo
00<000000?ooo`000000303oool010000000oooo0?ooo`00000O0?ooo`03
0000003oool0oooo0200oooo0P00000]0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0000000T0oooo00<000000?ooo`0000001P3oool2000000D0
oooo0P0000040?ooo`8000000`3oool200000080oooo0P0000030?ooo`03
0000003oool0oooo008000000P3oool010000000oooo0?ooo`0000080?oo
o`002@3oool2000000D0oooo00<000000?ooo`0000001`3oool00`000000
oooo0000000<0?ooo`040000003oool0oooo000001l0oooo00<000000?oo
o`3oool07P3oool2000002l0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`0000002@3oool00`000000oooo000000060?ooo`8000001@3oool20000
00@0oooo0P0000030?ooo`8000000P3oool2000000<0oooo00<000000?oo
o`3oool00P0000020?ooo`040000003oool0oooo000000P0oooo00090?oo
o`8000001@3oool00`000000oooo000000070?ooo`030000003oool00000
00`0oooo00@000000?ooo`3oool00000803oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0A03oool0
1@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`0000002@3o
ool00`000000oooo000000060?ooo`8000001@3oool2000000@0oooo0P00
00030?ooo`8000000P3oool2000000<0oooo00<000000?ooo`3oool00P00
00020?ooo`040000003oool0oooo000000P0oooo00090?ooo`8000001@3o
ool00`000000oooo000000070?ooo`030000003oool0000000`0oooo00@0
00000?ooo`3oool00000803oool00`000000oooo0?ooo`0J0?ooo`800000
<P3oool00`000000oooo0?ooo`140?ooo`050000003oool0oooo0?ooo`00
0000403oool00`000000oooo000000090?ooo`8000001`3oool2000000D0
oooo0P0000040?ooo`8000000`3oool2000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`8000000P3oool010000000oooo0?ooo`000008
0?ooo`002@3oool2000000D0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0000000<0?ooo`030000003oool000000280oooo00<000000?oo
o`3oool05`3oool2000003@0oooo00<000000?ooo`3oool0A03oool01@00
0000oooo0?ooo`3oool000000100oooo00<000000?ooo`0000002@3oool2
000000L0oooo0P0000050?ooo`800000103oool2000000<0oooo0P000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool200000080oooo00@0
00000?ooo`3oool00000203oool000T0oooo0P0000050?ooo`030000003o
ool0000000L0oooo00<000000?ooo`000000303oool00`000000oooo0000
000R0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0=03o
ool2000004D0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000
003oool0000000T0oooo0P0000070?ooo`8000001@3oool2000000@0oooo
0P0000030?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080
oooo0P0000020?ooo`040000003oool0oooo000000P0oooo00090?ooo`80
00001@3oool00`000000oooo000000070?ooo`030000003oool0000000`0
oooo00<000000?ooo`0000008P3oool00`000000oooo0?ooo`0D0?ooo`80
0000=`3oool00`000000oooo0?ooo`140?ooo`050000003oool0oooo0?oo
o`000000403oool00`000000oooo000000090?ooo`8000001`3oool20000
00D0oooo0P0000040?ooo`8000000`3oool2000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`8000000P3oool010000000oooo0?ooo`00
00080?ooo`002@3oool2000000H0oooo0P0000070?ooo`030000003oool0
000000`0oooo00<000000?ooo`0000008P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0A@3oool0
10000000oooo0?ooo`00000@0?ooo`030000003oool0000000T0oooo0P00
00070?ooo`8000001@3oool2000000@0oooo0P0000030?ooo`8000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo0P0000020?ooo`040000
003oool0oooo000000P0oooo00090?ooo`8000001P3oool2000000L0oooo
00<000000?ooo`000000303oool00`000000oooo0000000S0?ooo`030000
003oool0oooo0100oooo0P00000j0?ooo`030000003oool0oooo04D0oooo
00@000000?ooo`3oool00000403oool00`000000oooo000000090?ooo`80
00001`3oool2000000D0oooo0P0000040?ooo`8000000`3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool01000
0000oooo0?ooo`0000080?ooo`002@3oool2000000H0oooo0P0000070?oo
o`030000003oool0000000`0oooo00<000000?ooo`0000008`3oool00`00
0000oooo0?ooo`0>0?ooo`800000?03oool00`000000oooo0?ooo`150?oo
o`030000003oool000000140oooo00<000000?ooo`0000002@3oool20000
00L0oooo0P0000050?ooo`800000103oool2000000<0oooo0P0000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool200000080oooo00@00000
0?ooo`3oool00000203oool000T0oooo0P0000060?ooo`8000001`3oool0
0`000000oooo0000000<0?ooo`030000003oool0000002@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`0000004@3oool00`000000oooo00000009
0?ooo`8000001`3oool2000000D0oooo0P0000040?ooo`8000000`3oool2
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3o
ool010000000oooo0?ooo`0000080?ooo`002@3oool2000000H0oooo00<0
00000?ooo`3oool01`3oool2000000d0oooo0P00000U0?ooo`030000003o
ool0oooo00T0oooo0P00000o0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`0000004P3oool2000000X0oooo00<000000?ooo`3oool01@3o
ool2000000D0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P00
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool000T0oooo
0P0000060?ooo`030000003oool0oooo00L0oooo0P00000=0?ooo`800000
9P3oool00`000000oooo0?ooo`060?ooo`800000>03oool4000000D0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0000000B0?ooo`800000
2P3oool00`000000oooo0?ooo`050?ooo`8000001@3oool2000000@0oooo
00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01P3oool000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00`0oooo0P00000W0?ooo`800000
0`3oool3000003`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`150?ooo`030000003oool000000180oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0
203oool010000000oooo0?ooo`0000080?ooo`004@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
9`3oool5000003h0oooo00<000000?ooo`3oool0103oool3000004H0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0N0?ooo`040000
003oool0oooo000000P0oooo002G0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0W03oool009L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2L0?ooo`00U@3oool3000000H0oooo00<00000
0?ooo`3oool0W03oool009L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2L0?ooo`00\
\>"], "Graphics",
  CellLabel->"From (V5.2 on byblis2) In[1]:=",
  Evaluatable->False,
  ImageSize->{317.875, 196.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{
          RowBox[{"Arg", "[", 
            RowBox[{"Cos", "[", 
              FractionBox["1", 
                RowBox[{"x", "+", 
                  RowBox[{"\[ImaginaryI]", " ", "y"}]}]], "]"}], "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"x", ",", 
              RowBox[{"-", 
                FractionBox["1", "2"]}], ",", 
              FractionBox["1", "2"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"y", ",", 
              RowBox[{"-", 
                FractionBox["1", "2"]}], ",", 
              FractionBox["1", "2"]}], "}"}], ",", 
          RowBox[{"PlotPoints", "\[Rule]", "400"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}]}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
              "\"\<x\>\"", ",", "\"\<y\>\"", ",", "None", ",", "None"}], 
              "}"}]}], ",", 
          RowBox[{"ColorFunction", "\[Rule]", "Hue"}], ",", 
          RowBox[{"ContourLines", "\[Rule]", "False"}], ",", 
          RowBox[{"Contours", "\[Rule]", "200"}]}], "]"}], ";"}]], "Input",
  CellLabel->"(V5.2 on byblis2) In[3]:="],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004k0001>b000`400?l0
0000o`00003oo`3oooll0?ooo`00o`3oooll0?ooo`00o`3oooll0?ooo`00
o`3oooll0?ooo`00o`3oooll0?ooo`00o`3oooll0?ooo`00o`3oooll0?oo
o`00o`3oooll0?ooo`00o`3oooll0?ooo`00o`3oooll0?ooo`00o`3oooll
0?ooo`00o`3oooll0?ooo`00[@3oool2000000030?ooo`000000000008T0
oooo002^0?ooo`030000003oool0000008X0oooo002_0?ooo`030000003o
ool0oooo08T0oooo002^0?ooo`030000003oool0000008X0oooo002]0?oo
o`80000000<0oooo000000000000R@3oool00?l0oooo?03oool00?l0oooo
?03oool00?l0oooo?03oool00?l0oooo?03oool00480oooo0P0000040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool09@3oool20000
00@0oooo00<000000?ooo`3oool00P3oool4000002T0oooo0P00000]0?oo
o`800000103oool00`000000oooo0?ooo`020?ooo`@000009P3oool20000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?oo
o`00@@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
02@0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0Y
0?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool0603oool00440oooo00@000000?ooo`3oool0
00001`3oool5000002D0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0X0?ooo`040000003oool0oooo000002/0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`0U0?ooo`040000003o
ool0oooo000000L0oooo1@00000I0?ooo`00>`3oool400000080oooo00@0
00000?ooo`3oool000001`3oool010000000oooo0?ooo`00000P0?ooo`@0
00000P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
02L0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?ooo`00
000:0?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3oool00000
1`3oool010000000oooo0?ooo`00000J0?ooo`00@@3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0000002H0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo
000002/0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0S0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`000000
6P3oool00440oooo00@000000?ooo`3oool000002@3oool2000002H0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000X0?oo
o`040000003oool0oooo000002/0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000U0?ooo`040000003oool0oooo000000T0
oooo0P00000J0?ooo`00@P3oool2000000/0oooo00<000000?ooo`3oool0
9@3oool2000000X0oooo0P00000Z0?ooo`800000;@3oool2000000X0oooo
0P00000W0?ooo`8000002`3oool00`000000oooo0?ooo`0H0?ooo`00o`3o
ooll0?ooo`00o`3oooll0?ooo`00o`3oooll0?ooo`009P3ooooo000001D0
00000@3oool002H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool100000040oooo000V0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0L0?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool0o`3ooolA
0?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool0o`3ooolA0?oo
o`4000000@3oool002H0oooo0`00003o0?oooa00oooo0P0000010?ooo`00
9P3oool00`000000oooo0?ooo`030?ooo`h002So3`008Ol@000Xo`P0033o
1`00>?l5000oo`D004Oo1000Col4001Go`<005ko1000I_l3001^o`<007Go
0`00OOl20025o`<008co0`00U?l2002Lo`800:?o0`00Zol2002co`<00;[o
0P00`_l2003:o`800=7o0P00fOl2003Qo`<00>So0P00l?l2003ho`800?oo
0P00ooP2003ol0800?oX0`00on42003of@800?oA0P00olX2003o`P<00?nj
0P00ok<2003oZ`<00?nS0P00oi`3003oU0800?n<0`00ohD3003oO@<00?me
0`00ofh4003oIP<00?mN1000oeL4003oC`D00?m71@00ocl6003o>0T00?l`
4000obP?003o8@h00?lX1@3oool100000040oooo000V0?ooo`030000003o
ool0oooo00<0oooo1P00:?lN000Qo``002So2000<?l6000ho`D003oo1000
Aol4001?o`@005Oo0`00G_l4001Vo`<006ko0`00MOl2001mo`<008Go0`00
S?l2002Do`8009co0`00Xol2002[o`800;?o0`00^_l20032o`800<[o0P00
dOl2003Io`<00>7o0P00j?l2003`o`800?So0P00ool2003on0800?o`0P00
onP2003oh@<00?oI0P00om42003obP800?o20P00okX3003o/`800?n[0P00
oj<3003oW0800?nD0`00oh`3003oQ@800?mm0`00ogD3003oKP<00?mV1000
oeh4003oE`@00?m?1000odL5003o?`H00?lh2000oc0<003o:1h00?lQ1P00
obP50?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool0
0`00:?l0027o000Qo`0V000Qo`X002So1`00<?l5000ho`H003oo1000Aol4
001?o`<005Oo0`00G_l4001Vo`<006ko0`00MOl2001mo`<008Go0P00S?l2
002Do`<009co0P00Xol3002[o`800;?o0P00^_l20032o`800<[o0`00dOl2
003Io`800>7o0P00j?l2003`o`800?So0P00ool2003on0800?o`0P00onP2
003oh@800?oI0`00om42003obP800?o20P00okX2003o/`800?n[0`00oj<2
003oW0<00?nD0P00oh`3003oQ@800?mm0`00ogD3003oKP@00?mV0`00oeh3
003oE`@00?m?1000odL5003o?`H00?lh1`00oc09003o:2T00?lQ00<00?lX
0?ooo`3oool00`3oool100000040oooo000V0?ooo`030000003oool0oooo
00<0oooo4P008Ol:000Ioa40027o2000:?l7000`o`D003So1@00?ol40017
o`@004oo0`00Eol3001No`<006Ko0`00K_l3001eo`<007go0P00QOl3002<
o`8009Co0P00W?l3002So`800:_o0P00/ol2002jo`800<;o0`00b_l2003A
o`800=Wo0P00hOl2003Xo`800?3o0P00n?l2003oo`800?oh0P00oo02003o
j0800?oQ0P00omT2003od@800?o:0`00ol82003o^P800?nc0P00oj/2003o
X`<00?nL0P00oi@3003oS0800?n50`00ogd3003oM@<00?m^0`00ofH3003o
GP<00?mG1000odl4003oA`D00?lo1@00ocP6003o<0P00?lX4P00ob4:003o
6A800?lQ1@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0
oooo20008OlM000Io``0027o1`00:?l6000`o`D003So1000?ol40017o`@0
04oo0`00Eol3001No`<006Ko0`00K_l3001eo`8007go0`00QOl2002<o`<0
09Co0P00W?l2002So`800:_o0`00/ol2002jo`800<;o0P00b_l2003Ao`80
0=Wo0P00hOl2003Xo`800?3o0P00n?l2003oo`800?oh0P00oo02003oj080
0?oQ0P00omT2003od@800?o:0P00ol82003o^P800?nc0`00oj/2003oX`80
0?nL0`00oi@2003oS0800?n50`00ogd3003oM@800?m^1000ofH3003oGP<0
0?mG1000odl4003oA`@00?lo1@00ocP6003o<0L00?lX3000ob4L003o6@T0
0?lQ1@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo
10008OlV000Io`T0027o1`00:?l6000`o`D003So1000?ol30017o`@004oo
0`00Eol3001No`<006Ko0`00K_l2001eo`<007go0P00QOl3002<o`8009Co
0P00W?l3002So`800:_o0P00/ol2002jo`800<;o0P00b_l2003Ao`800=Wo
0P00hOl2003Xo`800?3o0P00n?l2003oo`800?oh0P00oo02003oj0800?oQ
0P00omT2003od@800?o:0P00ol82003o^P800?nc0P00oj/3003oX`800?nL
0P00oi@2003oS0<00?n50P00ogd3003oM@<00?m^0`00ofH3003oGP<00?mG
0`00odl4003oA`@00?lo1@00ocP6003o<0H00?lX2P00ob4V003o6@@00?lQ
1@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo5@00
6Ol7000Aoa8001Wo20008Ol7000Xo`@0033o1@00>?l4000oo`@004Oo0`00
Col3001Go`<005ko0`00I_l3001^o`8007Go0`00OOl20025o`8008co0`00
U?l2002Lo`800:?o0P00Zol2002co`800;[o0P00`_l2003:o`800=7o0P00
fOl2003Qo`800>So0P00l?l2003ho`800?oo0P00ooP2003ol0800?oX0P00
on42003of@800?oA0P00olX2003o`P800?nj0P00ok<2003oZ`800?nS0P00
oi`2003oU0<00?n<0P00ohD3003oO@800?me0`00ofh3003oIP<00?mN0`00
oeL3003oC`@00?m71000ocl5003o>0@00?l`1`00obP8003o8A800?lI1`00
oa4E003o6@D0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`03
0?ooo`X001Wo70004Ol;000Io`P0027o1P00:?l4000`o`@003So1000?ol4
0017o`<004oo0`00Eol3001No`<006Ko0P00K_l3001eo`8007go0P00QOl3
002<o`8009Co0P00W?l2002So`800:_o0P00/ol2002jo`800<;o0P00b_l2
003Ao`800=Wo0P00hOl2003Xo`800?3o0P00n?l2003oo`800?oh0P00oo02
003oj0800?oQ00<00?oI003od@00om400P00olX2003o`P800?nj0P00ok<2
003oZ`<00?nS0P00oi`2003oU0800?n<0`00ohD2003oO@<00?me0P00ofh3
003oIP<00?mN0`00oeL3003oC`@00?m71000ocl4003o>0@00?l`1P00obP7
003o8@`00?lI6`00oa4;003o6@D0oooo0@0000010?ooo`009P3oool00`00
0000oooo0?ooo`030?ooo`H001Wo9@004Ol:000Io`H0027o1P00:?l4000`
o`@003So1000?ol30017o`<004oo0`00Eol3001No`<006Ko0P00K_l2001e
o`<007go0P00QOl3002<o`8009Co0P00W?l2002So`800:_o0P00/ol2002j
o`800<;o0P00b_l2003Ao`800=Wo00<00>7o003Xo`00j?l00P00l?l2003h
o`800?oo0P00ooP2003ol003003oj000on400?oQ00800?oI0P00om42003o
bP800?o20P00okX2003o/`800?n[0P00oj<2003oW0800?nD0`00oh`2003o
Q@800?mm0`00ogD2003oKP<00?mV0`00oeh3003oE`<00?m?0`00odL4003o
?`@00?lh1000oc06003o:0H00?lQ2P00oaTU003o4@H00?lI1@3oool10000
0040oooo000V0?ooo`030000003oool0oooo00<0oooo0P006OlC000Ao`T0
00[o4@004Ol8000Io`H0027o1@00:?l5000`o`<003So1000?ol30017o`<0
04oo0`00Eol3001No`8006Ko0`00K_l2001eo`8007go0`00QOl2002<o`80
09Co0P00W?l2002So`800:_o0P00/ol2002jo`800<;o0P00b_l2003Ao`80
0=Wo00<00>7o003Xo`00j?l00P00l?l2003ho`800?oo0P00ooP2003ol003
003oj000on400?oQ00800?oI0P00om42003obP800?o20P00okX2003o/`80
0?n[0P00oj<2003oW0800?nD0P00oh`2003oQ@<00?mm0P00ogD3003oKP80
0?mV0`00oeh3003oE`<00?m?0`00odL4003o?`<00?lh1@00oc05003o:0D0
0?lQ2000oaTB003o4@T00?l:4`00oa42003o6@D0oooo0@0000010?ooo`00
9P3oool00`000000oooo0?ooo`030?ooo``0017o70002_l;000Ao`H001Wo
1P008Ol5000Xo`@0033o1000>?l3000oo`@004Oo0P00Col3001Go`<005ko
0P00I_l3001^o`8007Go0P00OOl20025o`8008co0P00U?l3002Lo`800:?o
0P00Zol00`00/ol00;[o002jo`020032o`800<[o0P00dOl2003Io`800>7o
00<00>So003`o`00l?l00P00n?l2003oo`800?oh00<00?o`003oj000onP0
0P00on42003of@800?oA0P00olX00`00ol800?nj003o^P02003o/`800?n[
0P00oj<2003oW0800?nD0P00oh`3003oQ@800?mm0P00ogD3003oKP800?mV
0`00oeh3003oE`800?m?1000odL3003o?`@00?lh1000oc04003o:0H00?lQ
1`00oaT;003o4A`00?l:3000oa450?ooo`4000000@3oool002H0oooo00<0
00000?ooo`3oool00`3oool6000AobL000[o20004Ol7000Io`D0027o1000
:?l4000`o`@003So0`00?ol30017o`<004oo0`00Eol2001No`<006Ko0P00
K_l2001eo`<007go0P00QOl2002<o`8009Co0P00W?l2002So`800:_o0P00
/ol2002jo`030032o`00b_l00<[o00800=7o0P00fOl2003Qo`03003Xo`00
l?l00?3o00800?So0P00ool2003on003003ol000onP00?oX00800?oQ0P00
omT2003od@03003obP00ol800?o200800?nj0P00ok<2003oZ`800?nS0P00
oi`2003oU0800?n<0P00ohD2003oO@<00?me0P00ofh3003oIP800?mN0`00
oeL3003oC`<00?m70`00ocl4003o>0@00?l`1000obP5003o8@H00?lI2@00
oa4V003o2PL00?lA1@3oool100000040oooo000V0?ooo`030000003oool0
oooo00<0oooo0`004OlA000:o`h000;o3`002_l8000Ao`D001Wo1@008Ol4
000Xo`@0033o1000>?l2000oo`@004Oo0P00Col3001Go`8005ko0P00I_l3
001^o`8007Go0P00OOl30025o`8008co0P00U?l00`00W?l00:?o002So`02
002[o`800;?o0P00^_l20032o`800<[o00<00=7o003Io`00fOl00P00hOl2
003Xo`03003`o`00n?l00?So00800?oo0P00ooP00`00oo000?oX003oj002
003oh@800?oI00<00?oA003obP00olX00P00ol82003o^P800?nc00<00?n[
003oX`00oj<00P00oi`2003oU0800?n<0`00ohD2003oO@800?me0P00ofh2
003oIP<00?mN0`00oeL2003oC`@00?m70P00ocl4003o>0@00?l`1000obP5
003o8@D00?lI2000oa4?003o2Ph00?l24@00o`X3003o4@D0oooo0@000001
0?ooo`009P3oool3000000<0oooo30002_lN0002o`X000[o1`004Ol5000I
o`D0027o1000:?l3000`o`<003So0`00?ol30017o`<004oo0P00Eol3001N
o`8006Ko0`00K_l2001eo`8007go0P00QOl2002<o`8009Co0P00W?l2002S
o`800:_o00<00;?o002jo`00^_l00P00`_l2003:o`03003Ao`00fOl00=Wo
00800>7o0P00j?l00`00l?l00?So003ho`02003oo`03003on000oo000?o`
00800?oX0P00on400`00omT00?oA003od@02003obP800?o20P00okX00`00
ok<00?n[003oZ`02003oX`800?nL0P00oi@2003oS0800?n50P00ogd2003o
M@<00?m^0P00ofH2003oGP<00?mG0`00odl2003oA`@00?lo0`00ocP3003o
<0@00?lX1@00ob45003o6@L00?lA2P00o`XN003o0P`00?l:103oool20000
0040oooo000V0?ooo`030000003oool0oooo00<0oooo1`002_lX0002o`P0
00[o1P004Ol5000Io`D0027o0`00:?l3000`o`@003So0`00?ol30017o`80
04oo0P00Eol3001No`8006Ko0P00K_l2001eo`8007go0P00QOl2002<o`80
09Co0P00W?l2002So`800:_o0P00/ol00`00^_l00<;o0032o`02003:o`80
0=7o00<00=Wo003Qo`00hOl00P00j?l00`00l?l00?So003ho`02003oo`03
003on000oo000?o`00800?oX0P00on400`00omT00?oA003od@02003obP03
003o`P00okX00?nj00800?nc0P00oj/2003oX`03003oW000oi@00?nD0080
0?n<0P00ohD2003oO@800?me0`00ofh2003oIP<00?mN0P00oeL2003oC`<0
0?m70`00ocl4003o>0<00?l`0`00obP5003o8@@00?lI1P00oa49003o2RP0
0?l21`00o`X50?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool0
0`3oool4000:o`h000;o5@050?l<0002o`L000[o1@004Ol5000Io`@0027o
0`00:?l4000`o`<003So0`00?ol20017o`<004oo0P00Eol2001No`<006Ko
0P00K_l2001eo`8007go0P00QOl2002<o`8009Co0P00W?l00`00Xol00:_o
002[o`02002co`800;[o00<00<;o003:o`00b_l00P00dOl00`00fOl00>7o
003Qo`02003Xo`03003`o`00n?l00?So00800?oo00<00?oh003ol000oo00
0P00onP00`00on400?oI003of@02003od@03003obP00ol800?o200800?nj
0P00ok<00`00oj/00?nS003oX`02003oW0800?nD0P00oh`2003oQ@800?mm
0P00ogD2003oKP800?mV0`00oeh2003oE`<00?m?0P00odL3003o?`<00?lh
1000oc03003o:0@00?lQ1000oaT6003o4@L00?l:3000o`8E00Go00h00?l2
1000o`X50?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3o
ool<0002ob401@3o2@000_l7000:o`@0017o1@006Ol3000Qo`@002So0`00
<?l3000ho`<003oo0P00Aol3001?o`8005Oo0P00G_l3001Vo`8006ko0P00
MOl2001mo`8008Go00<008co002Do`00U?l00P00W?l2002So`800:_o00<0
0;?o002jo`00^_l00P00`_l00`00b_l00=7o003Ao`02003Io`03003Qo`00
j?l00>So00800?3o00@00?So003oo`00ool00?oh0P00oo02003oj003003o
h@00omT00?oI00800?oA00<00?o:003o`P00ol800P00okX00`00ok<00?n[
003oZ`02003oX`800?nL00<00?nD003oS000oh`00P00ohD2003oO@800?me
0P00ofh3003oIP800?mN0P00oeL2003oC`<00?m70`00ocl3003o>0<00?l`
1000obP3003o8@D00?lI1000oa47003o2PT00?l28@05o`0;003o0P03003o
2P3oool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000oooo0?oo
o`030?ooo`P000;o4`050?l500`0oa401@3o20000_l6000:o`@0017o1000
6Ol4000Qo`<002So0`00<?l3000ho`<003oo0P00Aol2001?o`<005Oo0P00
G_l2001Vo`8006ko0P00MOl2001mo`8008Go0P00S?l2002Do`03002Lo`00
Xol00:?o00800:_o0P00/ol01000^_l00<;o0032o`00b_l2003Ao`800=Wo
00<00>7o003Xo`00j?l00P00l?l01000n?l00?oo003oo`00ooP2003ol080
0?oX00@00?oQ003of@00omT00?oA0P00olX2003o`P03003o^P00ok<00?nc
00800?n[0P00oj<00`00oi`00?nD003oU002003oS0800?n50P00ogd2003o
M@800?m^0P00ofH2003oGP800?mG0`00odl2003oA`<00?lo0`00ocP3003o
<0<00?lX1000ob44003o6@@00?lA1P00o`X7003o0Q801Ol01@0<o`0C00Go
00P00?l21@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0
oooo10000_l<00D0oa/0303o2P050?l70002o`D000[o10004Ol4000Io`@0
027o0P00:?l4000`o`8003So0`00?ol20017o`<004oo00@005Oo001No`00
G_l005ko0P00I_l2001^o`8007Go0P00OOl00`00QOl008co002<o`02002D
o`8009co0P00Xol00`00Zol00;?o002co`02002jo`040032o`00b_l00<[o
003Ao`800=Wo00<00>7o003Xo`00j?l00P00l?l01000n?l00?oo003oo`00
ooP2003ol003003oj000on400?oQ00800?oI00@00?oA003obP00olX00?o2
0P00okX2003o/`03003oZ`00oj<00?nS00800?nL00<00?nD003oS000oh`0
0P00ohD2003oO@800?me0P00ofh2003oIP800?mN0P00oeL3003oC`800?m7
0`00ocl2003o>0@00?l`0P00obP4003o8@@00?lI1000oa45003o2PH00?l2
2`05o`0K00co00`01Ol01000o`850?ooo`4000000@3oool002H0oooo00<0
00000?ooo`3oool00`3oool00`000_l01@3o00D0o`0800D0obD0303o2005
0?l60002o`D000[o10004Ol4000Io`<0027o0`00:?l3000`o`8003So0`00
?ol20017o`8004oo0P00Eol2001No`8006Ko0P00K_l2001eo`8007go0P00
QOl2002<o`03002Do`00W?l009co00800:?o00<00:_o002co`00/ol00P00
^_l01000`_l00<[o003:o`00dOl2003Io`800>7o00@00>So003`o`00l?l0
0?So0P00ool01000ooP00?o`003ol000onP2003oh@03003of@00om400?oA
00800?o:00@00?o2003o^P00okX00?nc0P00oj/2003oX`03003oW000oi@0
0?nD00800?n<0P00ohD2003oO@03003oM@00ofh00?m^00800?mV0`00oeh2
003oE`800?m?0P00odL3003o?`800?lh0`00oc03003o:0<00?lQ1000oaT4
003o4@D00?l:1P00o`8800Go02D03?l02P05o`000`00o`80oooo0?ooo`03
0?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool700D0
o`h0303o500D0?l;00`0o`L01@3o1P000_l4000:o`@0017o0`006Ol3000Q
o`<002So0`00<?l2000ho`<003oo0P00Aol2001?o`8005Oo0P00G_l2001V
o`8006ko0P00MOl2001mo`8008Go00<008co002Do`00U?l00P00W?l01000
Xol00:_o002[o`00/ol2002jo`800<;o00@00<[o003Ao`00dOl00=Wo0P00
hOl01000j?l00?3o003`o`00n?l2003oo`04003on000oo000?o`003oj080
0?oQ00@00?oI003od@00om400?o:0P00ol800`00okX00?nc003o/`02003o
Z`03003oX`00oi`00?nL00800?nD00<00?n<003oQ@00ohD00P00ogd2003o
M@800?m^0P00ofH2003oGP800?mG0P00odl2003oA`<00?lo0P00ocP3003o
<0<00?lX0`00ob43003o6@@00?lA1000o`X5003o0PP01Ol02`0<o`0D01Co
00h03?l01`05o`050?ooo`4000000@3oool002H0oooo00<000000?ooo`3o
ool00`3oool400D0o`/0303o800D0?l900`0o`H01@3o1@000_l4000:o`<0
017o0`006Ol3000Qo`<002So0`00<?l2000ho`8003oo0`00Aol2001?o`80
05Oo0P00G_l2001Vo`8006ko00<007Go001mo`00OOl00P00QOl2002<o`04
002Do`00W?l009co002So`800:_o0P00/ol01000^_l00<;o0032o`00b_l2
003Ao`04003Io`00hOl00>7o003Xo`800?3o00@00?So003oo`00ool00?oh
0P00oo001000onP00?oQ003oh@00omT2003od@04003obP00ol800?o2003o
^P800?nc00<00?n[003oX`00oj<00P00oi`00`00oi@00?n<003oS002003o
Q@03003oO@00ogD00?me00800?m^0P00ofH2003oGP800?mG0P00odl2003o
A`<00?lo0P00ocP3003o<0800?lX1000ob43003o6@<00?lA1000o`X5003o
0PH01Ol0200<o`0Q01Co00/03?l01005o`050?ooo`4000000@3oool002H0
oooo00<000000?ooo`3oool00`3oool00`050?l0303o00`0o`0700`0oa40
503o2P0L0?l>01@0o`P0303o1@050?l50002o`@000[o0`004Ol3000Io`<0
027o0`00:?l2000`o`8003So0`00?ol20017o`8004oo0P00Eol2001No`80
06Ko00<006ko001eo`00MOl00P00OOl00`00QOl008co002<o`02002Do`04
002Lo`00Xol00:?o002[o`800;?o00@00;[o0032o`00`_l00<[o0P00dOl0
1000fOl00>7o003Qo`00j?l2003`o`04003ho`00ool00?oo003on0800?o`
00D00?oX003oh@00omT00?oI003od@02003obP04003o`P00okX00?nj003o
/`800?n[0P00oj<01000oi`00?nD003oU000oh`2003oQ@800?mm0P00ogD0
0`00ofh00?mV003oIP02003oGP800?mG0P00odl2003oA`<00?lo0P00ocP2
003o<0<00?lX0`00ob43003o6@<00?lA1000o`X5003o0PD01Ol01`0<o`0?
01Co00X07?l0400Do`0:00co000300Go003oool0oooo00<0oooo0@000001
0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`L0303o2`0D0?lL01`0
o`T0503o1P0<0?l500D0o`@000;o10002_l3000Ao`<001Wo0`008Ol2000X
o`<0033o0P00>?l2000oo`8004Oo0P00Col2001Go`8005ko0P00I_l2001^
o`03001eo`00OOl007go008008Go00<008co002Do`00U?l00P00W?l01000
Xol00:_o002[o`00/ol2002jo`050032o`00b_l00<[o003Ao`00fOl00P00
hOl01000j?l00?3o003`o`00n?l2003oo`05003on000oo000?oX003oj000
on400P00omT01000om400?o:003obP00ol82003o^P04003o/`00oj/00?n[
003oX`800?nL00<00?nD003oS000oh`00P00ohD00`00ogd00?me003oM@02
003oKP800?mV0P00oeh2003oE`800?m?0P00odL2003o?`800?lh0P00oc03
003o:0<00?lQ0`00oaT3003o4@<00?l:1000o`8500Go00H03?l02P0Do`0L
01co00/05?l01`0<o`050?ooo`4000000@3oool001<0oooo0P0000040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`@0303o2@0D0?lV01`0o`P0503o1@0<0?l500D0
o`<000;o10002_l3000Ao`8001Wo0`008Ol3000Xo`80033o0P00>?l2000o
o`8004Oo0P00Col2001Go`8005ko0P00I_l00`00K_l007Go001eo`02001m
o`040025o`00S?l008co002Do`8009co0P00Xol01@00Zol00;?o002co`00
^_l00<;o00800<[o00D00=7o003Io`00fOl00>7o003Xo`02003`o`05003h
o`00ool00?oo003on000oo000P00onP01@00on400?oI003of@00om400?o:
00800?o200@00?nj003o/`00ok<00?n[0P00oj<01000oi`00?nD003oU000
oh`2003oQ@800?mm00<00?me003oKP00ofh00P00ofH2003oGP800?mG0P00
odl2003oA`800?lo0P00ocP2003o<0<00?lX0`00ob42003o6@<00?lA1000
o`X3003o0PD01Ol01@0<o`0701Co02L07?l02@0Do`0400co00D0oooo0@00
00010?ooo`004P3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`0<0?l0503o01@0
o`0701@0o``0703o5`0S0?l:01`0o`H0503o1@0<0?l400D0o`@000;o0`00
2_l3000Ao`<001Wo0P008Ol3000Xo`80033o0P00>?l2000oo`8004Oo0P00
Col2001Go`03001No`00I_l006Ko008006ko0P00MOl01000OOl008Go0025
o`00S?l2002Do`04002Lo`00Xol00:?o002[o`800;?o00D00;[o0032o`00
`_l00<[o003Ao`02003Io`05003Qo`00j?l00?3o003`o`00n?l00P00ool0
1@00ooP00?o`003oj000onP00?oQ00800?oI00D00?oA003obP00ol800?o2
003o^P02003o/`04003oZ`00oj<00?nS003oW0800?nD00@00?n<003oQ@00
ohD00?mm0P00ogD2003oKP03003oIP00oeh00?mN00800?mG0P00odl2003o
A`800?lo0P00ocP2003o<0<00?lX0P00ob43003o6@<00?lA0`00o`X3003o
0PD01Ol0100<o`0601Co00X07?l0600So`0<01co00T05?l000<03?l00?oo
o`3oool00`3oool100000040oooo000B0?ooo`040000003oool0oooo0000
00L0oooo1@0000040?ooo`<000000`3oool601@0o`X0703o8`0S0?l801`0
o`D0503o1@0<0?l300D0o`@000;o0`002_l2000Ao`<001Wo0`008Ol2000X
o`80033o0P00>?l2000oo`8004Oo0P00Col00`00Eol005ko001No`02001V
o`8006ko00@007Go001mo`00OOl008Go0P00S?l01000U?l009co002Lo`00
Xol2002[o`05002co`00^_l00<;o0032o`00b_l00P00dOl01P00fOl00>7o
003Xo`00j?l00?3o003ho`800?oo00H00?oh003ol000onP00?oX003oh@00
omT2003od@05003obP00ol800?o2003o^P00ok<00P00oj/01000oj<00?nL
003oW000oi@2003oS004003oQ@00ogd00?mm003oM@800?m^0P00ofH00`00
oeh00?mG003oE`02003oC`800?m70P00ocl2003o>0800?l`0P00obP3003o
8@<00?lI0P00oa43003o2P@00?l20`05o`0500co00D05?l0200Lo`0S02?o
00T07?l01`0Do`040?ooo`8000000@3oool000`0oooo100000020?ooo`04
0000003oool0oooo000000L0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`030?ooo`@0503o200L0?l<02<0oaD0:`3o2P0S0?l6
01`0o`D0503o100<0?l400D0o`<000;o0`002_l3000Ao`8001Wo0P008Ol3
000Xo`80033o0P00>?l2000oo`030017o`00Col004oo008005Oo0P00G_l0
0`00I_l006ko001^o`02001eo`04001mo`00QOl008Go002<o`8009Co00D0
09co002So`00Zol00:_o002co`02002jo`060032o`00b_l00=7o003Ao`00
fOl00>7o0P00j?l01P00l?l00?So003oo`00ool00?oh003ol0800?oX00H0
0?oQ003of@00om400?oA003obP00ol82003o^P05003o/`00oj/00?nS003o
X`00oi`00P00oi@01000oh`00?n5003oQ@00ogd2003oM@03003oKP00ofH0
0?mV00800?mN0P00oeL00`00odl00?m7003oA`02003o?`800?lh0P00oc02
003o:0<00?lQ0P00oaT3003o4@<00?l:0`00o`8300Go00@03?l01@0Do`06
01co00/08ol05@0[o`0<02?o00P07?l0100Do`050?ooo`4000000@3oool0
0180oooo00@000000?ooo`3oool00000203oool00`000000oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<0503o01`0o`0L0?l01@0L0?l:
02<0ob40:`3o200S0?l501`0o`D0503o100<0?l300D0o`<000;o0P002_l3
000Ao`<001Wo0P008Ol2000Xo`80033o00<003So000oo`00?ol00P00Aol2
001?o`8005Oo0P00G_l01000I_l006ko001^o`00MOl2001mo`050025o`00
S?l008co002Do`00W?l00P00Xol01@00Zol00;?o002co`00^_l00<;o0080
0<[o00<00=7o003Io`00hOl00P00j?l01`00l?l00?So003oo`00ool00?oh
003ol000onP00P00on401P00omT00?oA003obP00olX00?o2003o^P800?nc
00D00?n[003oX`00oi`00?nL003oU002003oS004003oQ@00ogd00?mm003o
M@800?m^00<00?mV003oGP00oeh00P00oeL00`00odl00?m7003oA`02003o
?`800?lh0P00oc02003o:0800?lQ0`00oaT3003o4@800?l:0`00o`8300Go
00@03?l01@0Do`0501co00P08ol08@0[o`0902?o00P07?l000<05?l00?oo
o`3oool00`3oool100000040oooo000B0?ooo`040000003oool0oooo0000
00T0oooo0P0000050?ooo`030000003oool0oooo00<0oooo1P0L0?l802<0
o`d0:`3o4@0c0?l;02/0o`L08`3o1@0L0?l401@0o`<0303o0`050?l30002
o`<000[o0P004Ol2000Io`<0027o0P00:?l2000`o`03000ho`00?ol003oo
008004Oo0P00Col00`00Eol005ko001No`02001Vo`05001^o`00MOl007Go
001mo`00QOl00P00S?l01@00U?l009co002Lo`00Xol00:_o00800;?o00L0
0;[o0032o`00b_l00<[o003Ao`00fOl00>7o00800>So00L00?3o003ho`00
ool00?oo003on000oo000?oX00800?oQ00H00?oI003od@00olX00?o:003o
`P00okX2003o/`06003oZ`00oj<00?nL003oW000oi@00?n<0P00ohD01000
ogd00?me003oM@00ofh2003oIP800?mN00<00?mG003oC`00odl00P00odL0
0`00ocl00?lh003o>002003o<0800?lX0P00ob43003o6@800?lA0`00o`X3
003o0P<01Ol00`0<o`0401Co00D07?l01P0So`0<02_o0140<ol03@0[o`08
02?o00H07?l01@3oool100000040oooo000C0?ooo`8000002`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0`0L0?l702<0
o`X0:`3o7`0c0?l802/0o`H08`3o100L0?l401@0o`<0303o0`050?l30002
o`8000[o0`004Ol2000Io`80027o0P00:?l00`00<?l003So000ho`02000o
o`8004Oo0P00Col01000Eol005ko001No`00I_l2001^o`05001eo`00OOl0
07go0025o`00S?l00P00U?l01P00W?l00:?o002[o`00Zol00;?o002jo`80
0<;o00<00<[o003Ao`00fOl00P00hOl00`00j?l00?3o003ho`02003oo`03
003on000oo000?oX00800?oQ00<00?oI003od@00olX00P00ol800`00okX0
0?nc003oZ`02003oX`05003oW000oi@00?n<003oS000ohD00P00ogd01000
ogD00?m^003oKP00ofH2003oGP03003oE`00odl00?m?00800?m700<00?lo
003o>000ocP00P00oc02003o:0800?lQ0P00oaT3003o4@800?l:0`00o`83
00Go00<03?l0100Do`0401co00D08ol0200[o`0P03?o00T0:ol0200So`03
01co00D0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?oo
o`0301`0o`0S0?l08`3o00@08`3o2@0[0?l=03<0oa00>P3o2`0c0?l602/0
o`D08`3o100L0?l301@0o`<0303o0`050?l30002o`8000[o0P004Ol3000I
o`80027o00<002So000`o`00<?l00P00>?l2000oo`030017o`00Col004oo
008005Oo00@005ko001Vo`00I_l006ko0P00MOl01P00OOl008Go002<o`00
S?l009Co002Lo`800:?o00<00:_o002co`00^_l00P00`_l00`00b_l00=7o
003Io`02003Qo`03003Xo`00l?l00?So00800?oo00@00?oh003ol000onP0
0?oQ0P00omT00`00om400?o:003o`P02003o^P06003o/`00oj/00?nS003o
X`00oi`00?nD0P00oh`01@00ohD00?mm003oM@00ogD00?m^00800?mV00@0
0?mN003oE`00oeL00?m?0P00odL2003o?`800?lh00<00?l`003o:000obP0
0P00ob42003o6@<00?lA0P00o`X3003o0P801Ol00`0<o`0401Co00@07?l0
1@0So`0602_o00/0<ol0400jo`0=03?o00P0:ol01`0So`000`0Lo`00oooo
0?ooo`030?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3o
ool402<0o`P0:`3o2P0c0?lN03X0o`P0<`3o1@0[0?l402<0o`@0703o100D
0?l200`0o`<01@3o0`000_l2000:o`80017o0P006Ol2000Qo`03000Xo`00
<?l0033o008003So0P00?ol01000Aol004oo001?o`00Eol2001No`04001V
o`00K_l006ko001eo`8007go00<008Go002<o`00U?l00P00W?l00`00Xol0
0:_o002co`02002jo`030032o`00b_l00=7o00800=Wo00@00>7o003Xo`00
l?l00?So0P00ool01@00ooP00?o`003oj000on400?oI00800?oA00<00?o:
003o`P00okX00P00ok<00`00oj/00?nS003oW002003oU006003oS000ohD0
0?mm003oO@00ogD00?m^0P00ofH00`00oeh00?mG003oE`02003oC`04003o
A`00ocl00?lo003o>0800?l`0P00obP2003o8@800?lI0P00oa42003o2P<0
0?l20`05o`0200co00@05?l0100Lo`0402?o00D0:ol0200co`0N03[o00X0
<ol01`0[o`0502?o00D0oooo0@0000010?ooo`009P3oool00`000000oooo
0?ooo`030?ooo`808`3o1`0[0?l803<0o`d0>P3o3`120?l<03X0o`H0<`3o
1@0[0?l302<0o`@0703o0`0D0?l300`0o`801@3o0P000_l3000:o`80017o
0P006Ol00`008Ol002So000Xo`02000`o`8003So00@003oo0017o`00Aol0
04oo0P00Eol01@00G_l006Ko001Vo`00K_l007Go008007go00L008Go002<
o`00U?l009Co002Lo`00Xol00:_o00800;?o00@00;[o0032o`00b_l00=7o
0P00fOl01000hOl00>So003`o`00n?l2003oo`05003on000oo000?oX003o
h@00omT00P00om401000olX00?o2003o^P00ok<2003oZ`03003oX`00oi`0
0?nD00800?n<00D00?n5003oO@00ogD00?me003oKP02003oIP04003oGP00
oeL00?m?003oC`800?m700<00?lo003o>000ocP00P00oc000`00obP00?lQ
003o8@02003o6@800?lA0P00o`X3003o0P801Ol00`0<o`0301Co00<07?l0
100So`0502_o00H0<ol02`0jo`0@04;o00d0>_l0200co`0602_o00<08ol0
1@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo1P0[
0?l803<0o`T0>P3o7P120?l803X0o`D0<`3o100[0?l402<0o`<0703o0`0D
0?l200`0o`<01@3o0P000_l2000:o`80017o0P006Ol00`008Ol002So000X
o`02000`o`8003So00@003oo0017o`00Aol004oo0P00Eol01P00G_l006Ko
001^o`00K_l007Go001mo`8008Go00<008co002Do`00W?l00P00Xol01@00
Zol00;?o002jo`00`_l00<[o00800=7o00H00=Wo003Qo`00j?l00?3o003h
o`00ool2003on005003ol000onP00?oQ003of@00om400P00olX01@00ol80
0?nj003o/`00oj/00?nS00800?nL00<00?nD003oS000ohD00P00ogd01@00
ogD00?m^003oIP00ofH00?mN00800?mG00@00?m?003oA`00odL00?lo0P00
ocP00`00oc000?lX003o:002003o8@800?lI0P00oa42003o2P800?l20P05
o`0300co00<05?l00`0Lo`0402?o00@0:ol01@0co`0803[o01h0@_l02@0j
o`0703?o00H0:ol000<08ol00?ooo`3oool00`3oool100000040oooo000V
0?ooo`030000003oool0oooo00<0oooo100[0?l603<0o`P0>P3o3@120?l@
04X0o`/0@P3o1P0j0?l403<0o`@0:`3o0`0S0?l301`0o`<0503o0P0<0?l3
00D0o`8000;o0P002_l2000Ao`8001Wo00<0027o000Xo`00:?l00P00<?l0
1000>?l003oo000oo`00Aol2001?o`06001Go`00G_l006Ko001Vo`00K_l0
07Go0P00OOl00`00QOl008co002Do`02002Lo`05002So`00Zol00;?o002j
o`00`_l00P00b_l01`00dOl00=Wo003Qo`00j?l00?3o003ho`00ool00P00
ooP01P00oo000?oX003oh@00omT00?oA003obP800?o200D00?nj003o/`00
oj/00?nS003oW002003oU003003oS000ohD00?mm00800?me00D00?m^003o
IP00oeh00?mN003oE`02003oC`04003oA`00ocl00?lo003o>0800?l`0P00
obP00`00ob400?lI003o6@02003o4@800?l:0P00o`8200Go00<03?l00`0D
o`0201co00@08ol00`0[o`0503?o00H0>_l02`12o`0@04[o00`0@_l0200j
o`0703?o00@0:ol01@3oool100000040oooo000V0?ooo`030000003oool0
oooo00<0oooo0P0[0?l603<0o`L0>P3o2@120?lO04X0o`L0@P3o1@0j0?l4
03<0o`@0:`3o0P0S0?l301`0o`<0503o0P0<0?l200D0o`8000;o0P002_l2
000Ao`03000Io`008Ol0027o008002So0P00<?l01@00>?l003oo0017o`00
Aol004oo008005Oo00L005ko001Vo`00K_l006ko001eo`00OOl008Go0080
08co00D009Co002Lo`00Xol00:_o002co`02002jo`090032o`00b_l00=7o
003Io`00hOl00>So003`o`00n?l00?oo00800?oh00P00?o`003oj000on40
0?oI003od@00olX00?o2003o^P800?nc00D00?n[003oX`00oi`00?nD003o
S002003oQ@03003oO@00ogD00?m^00800?mV00D00?mN003oE`00odl00?m?
003oA`02003o?`04003o>000oc000?l`003o:0800?lQ0P00oaT2003o4@80
0?l:0P00o`8200Go00803?l00`0Do`0301co00808ol0100[o`0403?o00D0
>_l01`12o`0O04[o00T0@_l01`0jo`0603?o0080:ol01@3oool100000040
oooo000V0?ooo`030000003oool0oooo00<0oooo1@0c0?l703X0o`P0@P3o
301:0?lA0540o`X0BP3o1P120?l403X0o`@0<`3o0`0[0?l302<0o`<0703o
0P0D0?l200`0o`801@3o0P000_l2000:o`80017o00<001Wo000Qo`008Ol0
0P00:?l01@00<?l003So000ho`00?ol004Oo008004oo00L005Oo001No`00
I_l006Ko001^o`00MOl007go008008Go00D008co002Do`00W?l00:?o002[
o`02002co`0:002jo`00`_l00<[o003Ao`00fOl00>7o003Xo`00l?l00?So
003oo`800?oh00T00?o`003oj000on400?oI003od@00olX00?o2003o^P00
ok<00P00oj/01@00oj<00?nL003oU000oh`00?n500800?mm00<00?me003o
KP00ofH00P00oeh01@00oeL00?m?003oA`00odL00?lo00800?lh00@00?l`
003o:000obP00?lQ0P00oaT2003o4@800?l:0P00o`8200Go00803?l00P0D
o`0301co00<08ol00`0[o`0403?o00@0>_l01P12o`0904[o0180DOl0301:
o`0804;o00H0>_l01P0co`050?ooo`4000000@3oool002H0oooo00<00000
0?ooo`3oool00`3oool303<0o`H0>P3o1`120?l804X0ob00D@3o1`1:0?l5
0480o`@0>P3o0`0c0?l302/0o`<08`3o0P0L0?l201@0o`<0303o0P050?l0
0`000_l000[o000:o`02000Ao`03000Io`008Ol0027o008002So00D0033o
000ho`00?ol003oo0017o`02001?o`03001Go`00G_l006Ko008006ko00D0
07Go001mo`00QOl008co002Do`02002Lo`0>002So`00Zol00;?o002jo`00
`_l00<[o003Ao`00fOl00>7o003Xo`00l?l00?So003oo`00ooP2003ol00;
003oj000on400?oI003od@00olX00?o2003o^P00ok<00?n[003oX`00oi`0
0P00oi@01@00oh`00?n5003oO@00ogD00?m^00800?mV00H00?mN003oE`00
odl00?m?003oA`00ocl2003o>004003o<000obP00?lX003o8@800?lI0P00
oa42003o2P03003o0P05o`001Ol000<03?l00P0Do`0201co00<08ol00`0[
o`0303?o00@0>_l01012o`0804[o0200DOl0201:o`0704;o00H0>_l00`0c
o`050?ooo`4000000@3oool002H0oooo0`0000030?ooo`0303<0o`0j0?l0
>P3o00@0>P3o1P120?l704X0o`/0D@3o5@1I0?l90540o`D0BP3o10120?l4
03X0o`<0<`3o0`0[0?l202<0o`80703o0`0D0?l200`0o`801@3o00<000;o
000:o`002_l00P004Ol010006Ol0027o000Qo`00:?l2000`o`06000ho`00
?ol004Oo0017o`00Col005Oo0P00G_l01@00I_l006ko001eo`00OOl008Go
008008co010009Co002Lo`00Xol00:_o002co`00^_l00<;o003:o`00dOl0
0=Wo003Qo`00j?l00?3o003ho`00ool00?oh0P00oo003@00onP00?oQ003o
f@00om400?o:003o`P00okX00?nc003oZ`00oj<00?nL003oU000oh`00P00
ohD01000ogd00?me003oKP00ofH2003oGP03003oE`00odl00?m700800?lo
00@00?lh003o<000oc000?lX0P00ob400`00oaT00?lA003o4@02003o2P03
003o0P05o`001Ol000803?l00P0Do`0301co00808ol00`0[o`0303?o00@0
>_l01012o`0504[o00T0DOl05@1Io`0;057o00L0B_l01P12o`0603[o0003
03?o003oool0oooo0080oooo0P0000010?ooo`009P3oool00`000000oooo
0?ooo`030?ooo`@0>P3o1P120?l604X0o`T0D@3o8@1I0?l70540o`@0BP3o
10120?l303X0o`<0<`3o0`0[0?l202<0o`80703o0P0D0?l200`0o`801@3o
0P000_l010002_l0017o000Ao`006Ol2000Qo`06000Xo`00<?l003So000h
o`00?ol004Oo0P00Col00`00Eol005ko001Vo`02001^o`0I001eo`00OOl0
08Go002<o`00U?l009co002So`00Zol00;?o002jo`00`_l00<[o003Ao`00
fOl00>7o003Xo`00l?l00?So003oo`00ooP00?o`003oj000on400?oI003o
d@02003obP0<003o`P00okX00?nc003oZ`00oj<00?nL003oU000oh`00?n5
003oO@00ogD00?m^0P00ofH00`00oeh00?mG003oC`02003oA`06003o?`00
ocP00?l`003o<000obP00?lQ0P00oaT2003o4@03003o2P00o`800?l20080
1Ol00P0<o`0201Co00807?l00P0So`0302_o00<0<ol00`0jo`0404;o00@0
B_l01`1Ao`0Q05Wo00T0DOl01P1:o`0504;o00D0>_l01@3oool100000040
oooo000V0?ooo`030000003oool0oooo00<0oooo0P0j0?l60480o`H0BP3o
1`1A0?l:05T0oaL0H@3o201I0?l50540o`D0BP3o0`120?l303X0o`80<`3o
0`0[0?l202<0o`80703o0P0D0?l200`0o`801@3o00<000;o000:o`002_l0
0P004Ol01P006Ol0027o000Xo`00:?l0033o000ho`8003oo00<004Oo001?
o`00Eol00P00G_l08@00I_l006ko001eo`00OOl008Go002<o`00U?l009co
002So`00Zol00;?o002jo`00`_l00<[o003Ao`00fOl00>7o003Xo`00l?l0
0?So003oo`00ooP00?o`003oj000on400?oI003od@00olX00?o2003o^P00
ok<00?n[003oX`02003oW008003oU000oh`00?n5003oO@00ogD00?m^003o
IP00oeh2003oE`03003oC`00odL00?lo00800?lh00D00?l`003o:000ob40
0?lQ003o6@02003o4@03003o2P00o`800?l200801Ol00P0<o`0201Co0080
7?l00P0So`0202_o00<0<ol00`0jo`0304;o00@0B_l01P1Ao`0705Wo01P0
HOl02P1Io`07057o00H0B_l01P12o`0203[o00D0oooo0@0000010?ooo`00
9P3oool00`000000oooo0?ooo`030?ooo`D0@P3o1@1:0?l70540o`P0F@3o
3`1Q0?l806P0o``0H@3o1P1I0?l50540o`<0BP3o0`120?l303X0o`<0<`3o
0P0[0?l202<0o`80703o0P0D0?l00`0<0?l01@3o00D0o`020002o`05000:
o`004Ol001Wo000Io`008Ol00P00:?l00`00<?l003So000oo`020017o`05
001?o`00Eol005ko001Vo`00K_l00P00MOl09000OOl008Go002<o`00U?l0
09co002So`00Zol00;?o002jo`00`_l00<[o003Ao`00fOl00>7o003Xo`00
n?l00?oo003on000oo000?oX003oh@00omT00?oA003obP00ol800?nj003o
/`00oj/00?nS003oW000oi@00?n<003oQ@00ogd00?me003oKP800?mV00@0
0?mN003oE`00odl00?m70P00ocl00`00ocP00?l`003o:002003o8@04003o
6@00oa400?lA003o2P800?l200<01Ol000co000<o`000P0Do`0201co0080
8ol00P0[o`0303?o00<0>_l00`12o`0304[o00D0DOl01P1Io`0<067o00P0
J?l03`1Qo`0805Wo00H0DOl01P1:o`0404;o000303[o003oool0oooo00<0
oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`<0@P3o
1@1:0?l60540o`L0F@3o2@1Q0?lK06P0o`L0H@3o1@1I0?l40540o`<0BP3o
0`120?l203X0o`<0<`3o0P0[0?l202<0o`80703o0P0D0?l0100<0?l01@3o
00D0o`000_l2000:o`05000Ao`006Ol001Wo000Qo`00:?l00P00<?l01@00
>?l003oo0017o`00Col005Oo008005ko02T006Ko001^o`00MOl007go0025
o`00S?l009Co002Lo`00Xol00:_o002co`00^_l00<;o003:o`00dOl00=Wo
003Qo`00j?l00?3o003oo`00ooP00?o`003oj000on400?oI003od@00olX0
0?o2003o^P00ok<00?n[003oX`00oi`00?nD003oS000ohD00?mm003oM@00
ofh00?mV003oGP02003oE`04003oC`00odL00?lo003o>0800?l`00H00?lX
003o8@00oaT00?lI003o4@00o`X2003o0P801Ol000<03?l001Co000Do`00
0P0Lo`0202?o0080:ol00P0co`0303[o00<0@_l00`1:o`04057o00D0FOl0
1`1Qo`0K06So00T0HOl01`1Io`05057o00H0B_l00`12o`050?ooo`400000
0@3oool002H0oooo00<000000?ooo`3oool00`3oool00`120?l0BP3o04X0
o`0304X0o`D0D@3o1`1I0?l70640o`/0J03o4@1`0?l:06P0o`D0H@3o101I
0?l30540o`@0BP3o0P120?l203X0o`<0<`3o0P0[0?l00`0S0?l0703o01`0
o`0201@0o`0300`0o`050?l01@3o008000;o00L000[o000Ao`006Ol001Wo
000Qo`00:?l0033o008003So03<003oo0017o`00Col005Oo001No`00I_l0
06ko001eo`00OOl008Go002<o`00U?l009co002So`00Zol00;?o002jo`00
`_l00<[o003Ao`00fOl00>7o003Xo`00l?l00?oo003on000oo000?oX003o
h@00omT00?oA003obP00ol800?nj003o/`00oj/00?nS003oW000oi@00?n<
003oQ@00ogd00?me003oKP00ofH00?mN003oE`00odl00?m7003o?`00ocP0
0P00oc000`00obP00?lQ003o6@02003o4@04003o2P00o`800?l200Go0080
3?l00P0Do`0201co000302?o000[o`00:ol000<0<ol00P0jo`0204;o00@0
B_l00`1Ao`0405Wo00D0HOl02@1Xo`0B073o00/0J?l01`1Qo`0705Wo00D0
DOl01@1:o`000`12o`00oooo0?ooo`030?ooo`4000000@3oool002H0oooo
00<000000?ooo`3oool00`3oool404X0o`D0D@3o1P1I0?l60640o`P0J03o
7`1`0?l606P0o`D0H@3o0`1I0?l30540o`<0BP3o0P120?l303X0o`80<`3o
0P0[0?l00`0S0?l0703o01`0o`0201@0o`0400`0o`050?l01@3o0002o`80
00[o00<0017o000Io`008Ol00P00:?l01P00<?l003So000oo`00Aol004oo
001Go`8005ko02P006Ko001^o`00MOl007go0025o`00S?l009Co002So`00
Zol00;?o002jo`00`_l00<[o003Ao`00fOl00>7o003Xo`00l?l00?oo003o
n000oo000?oX003oh@00omT00?oA003obP00ol800?nj003o/`00oj<00?nL
003oU000oh`00?n5003oO@00ogD00?m^003oIP00oeh00?mG0P00odl01@00
odL00?lo003o>000oc000?lX00800?lQ00D00?lI003o4@00o`X00?l:003o
0P0200Go000400co000Do`005?l001co00808ol00P0[o`0203?o0080>_l0
0`12o`0204[o00@0DOl00`1Io`05067o00H0J?l07P1`o`0906So00H0HOl0
1P1Io`05057o00@0B_l01@3oool100000040oooo000V0?ooo`030000003o
ool0oooo00<0oooo0P1:0?l40540o`H0F@3o1P1Q0?l606P0o`X0L03o5`1h
0?l80700o`D0J03o101Q0?l305T0o`<0D@3o0P1:0?l30480o`80>P3o0P0c
0?l00`0[0?l08`3o02<0o`0201`0o`0501@0o`0<0?l01@3o00D0o`000_l0
0P002_l00`004Ol001Wo000Qo`02000Xo`0e000`o`00>?l003oo0017o`00
Col005Oo001No`00I_l006ko001eo`00OOl008Go002<o`00U?l009co002S
o`00Zol00;?o0032o`00b_l00=7o003Io`00hOl00>So003`o`00ool00?oh
003ol000onP00?oQ003of@00om400?o:003o^P00ok<00?n[003oX`00oi`0
0?nD003oS000ohD00?mm003oM@00ofh00?mV003oGP00oeL00?m?003oA`00
ocl00?lh003o<000obP00P00ob400`00oaT00?lA003o2P02003o0P0400Go
000<o`003?l001Co00807?l000<08ol002_o000[o`000P0co`0203[o00<0
@_l00P1:o`03057o00<0FOl0101Qo`0506So00L0L?l0601ho`0:073o00H0
J?l01P1Qo`0505Wo00D0DOl00P1:o`050?ooo`4000000@3oool002H0oooo
00<000000?ooo`3oool00`3oool40540o`H0F@3o1@1Q0?l606P0o`L0L03o
3@1h0?l<07l0o`X0N03o1P1`0?l406P0o`<0H@3o0`1I0?l30540o`80BP3o
0P120?l203X0o`80<`3o0P0[0?l0100S0?l0703o01@0o`0D0?l200`0o`08
00D0o`000_l000[o000:o`004Ol001Wo000Qo`00:?l2000`o`8003oo0280
04Oo001?o`00Eol005ko001Vo`00K_l007Go001mo`00S?l009Co002Lo`00
Xol00:_o002co`00^_l00<;o003Ao`00fOl00>7o003Xo`00l?l00?oo003o
n000oo000?oX003oh@00omT00?o:003o`P00okX00?nc003oZ`00oj<00?nL
0P00oh`02`00ogd00?me003oKP00ofH00?mN003oE`00odl00?m7003o?`00
ocP00?l`00800?lX00@00?lQ003o6@00oa400?l:0P00o`801005o`003?l0
01Co000Do`0201co000302?o000[o`00:ol00080<ol00P0jo`0204;o0080
B_l00`1Ao`0305Wo00<0HOl0101Xo`05073o00/0N?l0301oo`0=07So00L0
L?l01P1Xo`05067o00D0FOl0101Ao`000`1:o`00oooo0?ooo`030?ooo`40
00000@3oool002H0oooo00<000000?ooo`3oool00`3oool20540o`D0F@3o
1@1Q0?l606P0o`H0L03o2@1h0?lL07l0o`H0N03o1@1`0?l306P0o`@0H@3o
0P1I0?l20540o`<0BP3o0P120?l00`0j0?l0<`3o03<0o`0202/0o`0502<0
o`0L0?l0703o01@0o`0<0?l00P050?l0?@000_l000[o000Ao`004Ol001Wo
000Qo`00:?l0033o000ho`00?ol004Oo001?o`00Eol005ko001Vo`00K_l0
07Go001mo`00QOl008co002Lo`00Xol00:_o002co`00^_l00<;o003Ao`00
fOl00>7o003Xo`00l?l00?So003on000oo000?oX003oh@00omT00?o:003o
`P00okX00?nc003oZ`00oj<00?nD003oS000ohD00?mm003oM@00ofh00?mV
003oGP00oeL00?m?003oA`00ocl00?lh003o<000obP00?lQ003o6@00oa40
0P00o`X01P00o`801Ol000co000<o`005?l001co00808ol00P0[o`0203?o
000303[o0012o`00@_l000<0B_l00P1Ao`0205Wo00@0HOl00`1Xo`05073o
00D0N?l07@1oo`0907So00H0L?l01P1Xo`05067o00@0FOl00`1Ao`050?oo
o`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool00`1A0?l0
F@3o05T0o`0205T0o`D0H@3o1@1X0?l60700o`L0N03o2P1o0?lE08L0o`L0
O`3o1@1h0?l40700o`<0J03o0`1Q0?l205T0o`80D@3o0P1:0?l20480o`80
>P3o0P0c0?l01@0[0?l08`3o02<0o`0L0?l0503o0080303o00@01@3o0002
o`002_l0017o0P006Ol2000Xo`06000`o`00>?l003oo0017o`00Col005Oo
0P00I_l0:`00MOl007go0025o`00S?l009Co002Lo`00Xol00;?o002jo`00
`_l00<[o003Io`00hOl00>So003`o`00n?l00?oh003ol000onP00?oQ003o
d@00olX00?o2003o^P00oj/00?nS003oW000oi@00?n<003oQ@00ogD00?m^
003oIP00oeh00?mG003oC`00odL00?lo003o>000oc000?lX003o8@00oaT0
0P00oa401000o`X00?l200Go000<o`0201Co000401co000So`008ol002_o
0080<ol00P0jo`0204;o0080B_l00P1Ao`0205Wo00<0HOl00`1Xo`04073o
00D0N?l01`1oo`0E08Oo00X0Ool01`1ho`06073o00D0J?l01@1Qo`0405Wo
0003057o003oool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000
oooo0?ooo`030?ooo`<0F@3o1@1Q0?l406P0o`H0L03o1P1h0?l807l0o``0
Q`3o2P2?0?l;08L0o`D0O`3o101h0?l30700o`<0J03o0`1Q0?l205T0o`80
D@3o0P1:0?l20480o`0503X0o`0c0?l0<`3o02/0o`0S0?l00P0L0?l0@@0D
0?l0303o00D0o`050?l000;o000:o`004Ol001Wo000Qo`00:?l0033o000h
o`00?ol004Oo001?o`00Eol005ko001Vo`00K_l007Go0025o`00S?l009Co
002Lo`00Xol00;?o002jo`00`_l00<[o003Ao`00hOl00>So003`o`00n?l0
0?oh003ol000onP00?oQ003od@00olX00?o2003o^P00oj/00?nS003oW000
oi@00?n<003oO@00ogD00?m^003oIP00oeh00?mG003oC`00odL00?lo003o
>000oc000?lX003o8@00oaT00?lA003o2P00o`801Ol000803?l000D05?l0
01co000So`008ol002_o000203?o000303[o0012o`00@_l00080B_l00P1A
o`0205Wo00<0HOl00`1Xo`03073o00@0N?l01@1oo`0;08Oo00X0Sol03027
o`0807oo00H0N?l01P1`o`0406So00D0HOl00`1Io`050?ooo`4000000@3o
ool002H0oooo00<000000?ooo`3oool00`3oool205T0o`@0H@3o101X0?l5
0700o`D0N03o1`1o0?l808L0oa`0S`3o1P270?l407l0o`@0N03o0`1`0?l3
06P0o`80H@3o0P1I0?l20540o`80BP3o00D0@P3o03X0o`0c0?l0<`3o02/0
o`0202<0o`0401`0o`0D0?l0303o00`0o`8000;o00X000[o000Ao`006Ol0
027o000Xo`00<?l003So000oo`00Aol004oo0P00G_l0;`00K_l007Go001m
o`00QOl008co002Lo`00Xol00:_o002co`00`_l00<[o003Ao`00hOl00>So
003`o`00n?l00?oh003ol000onP00?oI003od@00olX00?nj003o/`00oj/0
0?nS003oU000oh`00?n5003oO@00ogD00?mV003oGP00oeL00?m?003oA`00
ocl00?lh003o<000obP00?lQ003o6@00oa400?l:003o0P05o`003?l00080
5?l000@07?l002?o000[o`00:ol00P0co`00100jo`00@_l004[o001:o`02
057o0080FOl00P1Qo`0306So00<0L?l0101ho`0407oo00D0Qol07@2?o`08
08Oo00L0Ool01@1ho`04073o00D0J?l0101Qo`0205Wo00D0oooo0@000001
0?ooo`009P3oool3000000<0oooo101Q0?l406P0o`@0L03o1P1h0?l507l0
o`L0Q`3o2P2?0?lE09L0o`L0S`3o1@270?l407l0o`80N03o0`1`0?l206P0
o`80H@3o0P1I0?l20540o`80BP3o00H0@P3o03X0o`0c0?l0<`3o02/0o`0S
0?l201`0o`0401@0o`0<0?l01@3o0002o`8000[o0P006Ol2000Xo`0b000h
o`00?ol004Oo001?o`00Eol005ko001Vo`00MOl007go0025o`00S?l009Co
002So`00Zol00;?o0032o`00b_l00=7o003Io`00j?l00?3o003ho`00ooP0
0?o`003oj000omT00?oA003obP00okX00?nc003oZ`00oj<00?nD003oS000
ohD00?mm003oKP00ofH00?mN003oE`00odl00?m7003o>000oc000?lX003o
8@00oaT00?lA003o2P00o`8200Go000300co000Do`007?l000808ol000D0
:ol003?o000jo`00>_l004;o000204[o0080DOl000@0FOl0067o001Qo`00
HOl00P1Xo`03073o0080N?l0101oo`0508Oo00H0Sol05P2Go`0:08oo00L0
Qol01@1oo`0607So00<0L?l01@1Xo`04067o00@0oooo0P0000010?ooo`00
9P3oool00`000000oooo0?ooo`030?ooo`80H@3o101X0?l40700o`D0N03o
1@1o0?l608L0o`P0S`3o2`2G0?l=09h0o`T0U`3o1@2?0?l408L0o`<0O`3o
0`1h0?l20700o`80J03o0P1Q0?l205T0o`040540o`1:0?l0BP3o0480o`80
>P3o03/0<`3o02/0o`0S0?l08`3o01`0o`0D0?l0303o00D0o`000_l000[o
000Ao`006Ol0027o000Xo`00<?l003So000oo`00Aol004oo001Go`00I_l0
06ko001eo`00OOl008co002Do`00W?l00:_o002co`00^_l00<[o003Ao`00
fOl00>So003`o`00n?l00?oh003ol000on400?oI003od@00ol800?nj003o
/`00oj<00?nL003oU000oh`00?mm003oM@00ofh00?mN003oE`00odl00?m7
003o?`00ocP00?l`003o:002003o6@800?l:0P05o`00100<o`005?l001co
000So`0202_o000403?o000jo`00@_l004;o0080B_l000<0DOl005Wo001I
o`000P1Qo`0206So0080L?l00`1ho`0307oo00@0Qol01@2?o`0909Oo00d0
W_l02`2Go`0808oo00H0Qol01@1oo`0407So00@0L?l01@1Xo`02067o00D0
oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`@0J03o
101`0?l507P0o`D0O`3o1@270?l608l0o`P0U`3o7@2N0?l509L0o`@0S`3o
10270?l207l0o`<0N03o0P1`0?l206P0o`80H@3o00@0F@3o0540o`1A0?l0
BP3o0P120?l0100j0?l0<`3o02/0o`0S0?l201`0o`0n01@0o`0<0?l01@3o
0002o`002_l0017o000Io`008Ol002So000`o`00?ol004Oo001?o`00Eol0
05ko001^o`00MOl007go0025o`00U?l009co002So`00/ol00;[o0032o`00
dOl00=Wo003Xo`00l?l00?So003on000oo000?oQ003of@00om400?o2003o
^P00ok<00?nS003oW000oi@00?n5003oO@00ogD00?mV003oGP00oeL00?m?
003oA`00ocP00?l`003o:000ob400?lI003o4@00o`X00?l200Go000<o`00
5?l001co000So`0202_o000503?o000jo`00@_l004;o001:o`000P1Ao`00
0`1Io`00HOl0067o000206So0080L?l00`1ho`0207oo00@0Qol0102?o`05
09Oo01d0W_l0202Go`0608oo00D0Qol01@1oo`0407So00@0L?l0101Xo`00
0`1Qo`00oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<000000?oo
o`3oool00`3oool206P0o`@0L03o101h0?l507l0o`D0Q`3o1P2?0?l609L0
o`P0WP3o6@2V0?l609h0o`@0U`3o102?0?l208L0o`80O`3o0`1h0?l20700
o`0306P0o`1Q0?l0H@3o0080F@3o00L0D@3o04X0o`1:0?l0@P3o03X0o`0c
0?l0:`3o00808`3o03d0703o01@0o`0<0?l01@3o0002o`002_l0017o000I
o`00:?l0033o000ho`00?ol004Oo001?o`00G_l006Ko001^o`00OOl008Go
002<o`00W?l00:?o002[o`00^_l00<;o003Ao`00fOl00>So003`o`00n?l0
0?oh003ol000on400?oI003obP00ol800?nj003oZ`00oj<00?nL003oS000
ohD00?me003oKP00ofH00?mG003oC`00odL00?lo003o>000obP00?lQ003o
6@00oa400?l:003o0P05o`003?l001Co000Lo`008ol00080:ol00P0jo`00
1012o`00B_l004[o001Ao`0205Wo0080HOl000<0J?l0073o001`o`000`1h
o`0207oo0080Qol0102?o`0409Oo00H0W_l06@2Vo`0809ko00H0Uol01P2?
o`0508Oo00@0Ool0101ho`04073o00<0J?l01@3oool100000040oooo000V
0?ooo`030000003oool0oooo00<0oooo00@0J03o0700o`1`0?l0L03o101h
0?l507l0o`@0Q`3o1@2?0?l609L0o`H0WP3o2P2V0?lC0:h0o`P0YP3o102N
0?l309L0o`<0S`3o0P270?l307l0o`0307P0o`1`0?l0L03o0080J03o0P1Q
0?l00`1I0?l0D@3o04X0o`020480o`0403X0o`0c0?l0:`3o02<0o`80703o
0P0<0?l0>0000_l000[o000Ao`006Ol0027o000Xo`00<?l003So0017o`00
Col005Oo001Vo`00K_l007Go0025o`00S?l009Co002So`00Zol00;[o0032
o`00dOl00=Wo003Qo`00l?l00?So003on000oo000?oQ003of@00olX00?o2
003o/`00oj/00?nS003oU000oh`00?mm003oM@00ofh00?mN003oE`00odl0
0?m7003o>000oc000?lX003o8@00oaT00?l:003o0P05o`003?l001Co000L
o`008ol00P0[o`000`0co`00>_l004;o000204[o0004057o001Io`00HOl0
067o0080J?l00P1`o`00101ho`00Ool007oo001oo`0208Oo00<0Sol00`2G
o`0409ko00L0Y_l0502^o`0:0:Ko00H0W_l01P2Go`0508oo00@0Qol0101o
o`0407So00@0L?l000<0J?l00?ooo`3oool00`3oool100000040oooo000V
0?ooo`030000003oool0oooo00<0oooo0`1`0?l307P0o`@0O`3o1@270?l5
08l0o`@0U`3o1P2N0?l80:H0o`/0[P3o302e0?l90:h0o`D0YP3o0`2N0?l3
09L0o`80S`3o0P270?l207l0o`80N03o0P1`0?l206P0o`030640o`1I0?l0
D@3o0080BP3o00@0@P3o03X0o`0c0?l0:`3o0P0S0?l201@0o`801@3o03D0
00[o000Ao`006Ol0027o000`o`00>?l003oo0017o`00Eol005ko001Vo`00
MOl007go0025o`00U?l009co002[o`00/ol00<;o003:o`00fOl00>7o003`
o`00n?l00?oh003ol000on400?oI003obP00ol800?nc003oZ`00oi`00?nD
003oQ@00ogd00?m^003oIP00oeh00?m?003oA`00ocl00?l`003o:000ob40
0?lI003o4@00o`801Ol000co000Do`007?l002?o000202_o0080>_l000H0
@_l004[o001Ao`00DOl005Wo001Qo`0206So0080L?l00P1ho`0207oo0080
Qol00P2?o`0309Oo00<0W_l01@2Vo`090:ko00`0]Ol02`2^o`080:Ko00H0
W_l0102Go`0508oo00@0Qol0101oo`0407So00<0L?l01@3oool100000040
oooo000V0?ooo`030000003oool0oooo00<0oooo00<0L03o07P0o`1h0?l0
0P1h0?l307l0o`@0Q`3o1@2?0?l509L0o`D0WP3o1P2V0?l70:h0oad0]@3o
1@2^0?l40:H0o`<0WP3o0P2G0?l208l0o`80Q`3o0P1o0?l207P0o`80L03o
00<0J03o0640o`1I0?l00P1A0?l0A@1:0?l0@P3o03X0o`0c0?l0:`3o02<0
o`0L0?l0503o00`0o`050?l000;o000:o`004Ol0027o000Xo`00<?l003So
0017o`00Col005ko001Vo`00K_l007go0025o`00U?l009co002[o`00/ol0
0<;o003:o`00fOl00>7o003`o`00n?l00?oh003ol000on400?oA003obP00
okX00?nc003oX`00oi`00?n<003oQ@00ogd00?m^003oIP00oeL00?m?003o
A`00ocP00?l`003o:000oaT00?lA003o2P00o`801Ol000co000Do`007?l0
02?o000[o`00<ol003[o0012o`00B_l0057o000205Wo0004067o001Xo`00
L?l0073o0080N?l00P1oo`0208Oo0080Sol00P2Go`0309ko00@0Y_l01@2^
o`0M0;Go00L0[_l01P2Vo`0509ko00D0Uol0102?o`0408Oo00@0Ool0101h
o`000`1`o`00oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<00000
0?ooo`3oool00`3oool307P0o`@0O`3o0`270?l408l0o`D0U`3o1@2N0?l5
0:H0o`L0[P3o1`2e0?lJ0;d0o`D0]@3o102^0?l30:H0o`80WP3o0P2G0?l2
08l0o`80Q`3o0P1o0?l207P0o`030700o`1X0?l0H@3o0080F@3o03/0D@3o
04X0o`120?l0>P3o03<0o`0[0?l08`3o01`0o`0D0?l0303o00D0o`000_l0
017o000Io`008Ol002So000ho`00?ol004Oo001Go`00G_l006ko001eo`00
QOl008co002Lo`00Xol00;?o002jo`00b_l00=Wo003Qo`00l?l00?So003o
n000onP00?oQ003od@00olX00?nj003o/`00oj<00?nD003oS000ogd00?me
003oIP00oeh00?mG003oA`00ocl00?l`003o:000ob400?lI003o2P00o`80
1Ol000co000201co0080:ol00P0jo`0204[o0006057o001Io`00HOl0067o
001Xo`00L?l00P1ho`0207oo0080Qol00P2?o`0209Oo0080W_l00`2Vo`04
0:ko00D0]Ol06@2mo`080;Go00L0[_l01@2Vo`0509ko00D0Uol00`2?o`04
08Oo00@0Ool00`1ho`050?ooo`4000000@3oool002H0oooo00<000000?oo
o`3oool00`3oool207P0o`<0O`3o10270?l308l0o`@0U`3o1@2N0?l50:H0
o`H0[P3o1P2e0?l80;d0oaH0a@3o1P2m0?l40;D0o`<0[P3o0P2V0?l309h0
o`80U`3o00<0S`3o08L0o`270?l00P1o0?l00`1h0?l0L03o06P0o`020640
o`1505T0o`1A0?l0BP3o0480o`0j0?l0<`3o02/0o`0S0?l0703o01@0o`0<
0?l000;o000:o`004Ol001Wo000Xo`00<?l003So0017o`00Col005ko001V
o`00MOl007go002<o`00U?l00:?o002co`00^_l00<[o003Ao`00hOl00?3o
003ho`00ooP00?oX003oh@00om400?o:003o^P00oj/00?nS003oU000oh`0
0?mm003oM@00ofH00?mN003oC`00odL00?lh003o<000obP00?lI003o4@00
o`X01Ol000co000Do`007?l002?o000[o`00<ol003[o0012o`00B_l0057o
001Io`00HOl00080J?l000@0L?l007So001oo`00Ool00P27o`000`2?o`00
Uol009Oo000309ko0080Y_l00`2^o`040;Go00H0_Ol05P35o`080;go00H0
]Ol01P2^o`050:Ko00@0W_l01@2Go`0308oo00@0Qol00`1oo`0207So00D0
oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`<0O`3o
10270?l308l0o`@0U`3o102N0?l50:H0o`D0[P3o1P2e0?l60;d0o`T0a@3o
4P3<0?l70<D0o`@0_@3o0`2e0?l20:h0o`<0YP3o0P2N0?l209L0o`0608l0
o`270?l0Q`3o07l0o`1h0?l0L03o0P1X0?l02P1Q0?l0F@3o0540o`1:0?l0
@P3o03X0o`0c0?l0:`3o02<0o`0L0?l200`0o`0a0002o`002_l001Wo000Q
o`00:?l003So000oo`00Col005Oo001Vo`00K_l007go0025o`00U?l00:?o
002[o`00^_l00<[o003Ao`00hOl00?3o003ho`00ooP00?oX003oh@00om40
0?o2003o^P00oj/00?nL003oU000ohD00?me003oKP00oeh00?mG003oA`00
ocl00?l`003o:000ob400?lA003o2P00o`803?l001Co000Lo`008ol002_o
000203[o0080B_l00P1Io`001P1Qo`00J?l0073o001`o`00N?l007oo0080
Qol000<0Sol009Oo002Go`000P2No`030:Ko0080[_l00`2eo`040;go00L0
aOl04P3<o`090<Go00H0_Ol01P2eo`050:ko00D0Y_l0102No`0309Oo00@0
Sol01027o`0307oo00D0oooo0@0000010?ooo`009P3oool00`000000oooo
0?ooo`030?ooo`80O`3o0`270?l408l0o`<0U`3o102N0?l40:H0o`D0[P3o
1@2e0?l60;d0o`H0a@3o2P3<0?l?0=@0o`L0c03o10350?l30;d0o`<0]@3o
0P2^0?l20:H0o`80WP3o00@0U`3o08l0o`2?0?l0Q`3o0P1o0?l0B01h0?l0
L03o06P0o`1Q0?l0F@3o0540o`1:0?l0@P3o03X0o`0c0?l0:`3o02<0o`0D
0?l0303o00D0o`000_l0017o000Io`00:?l0033o000oo`00Aol005Oo001N
o`00K_l007Go0025o`00U?l009co002[o`00^_l00<;o003Ao`00hOl00?3o
003ho`00ooP00?oX003oh@00om400?o2003o/`00oj/00?nL003oS000ohD0
0?me003oKP00oeh00?mG003oA`00ocP00?l`003o8@00oaT00?lA003o0P05
o`003?l001co000So`00:ol003?o000jo`00@_l004[o001Ao`00FOl0067o
001Xo`00L?l007So0080Ool000@0Qol008oo002?o`00Uol00P2No`020:Ko
0080[_l00`2eo`030;go00@0aOl01`3<o`0?0=Co00X0c?l01P35o`060;go
00D0]Ol01@2^o`040:Ko00@0W_l00`2Go`0408oo00<0Qol00P1oo`050?oo
o`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool408L0o`<0
S`3o0`2G0?l409h0o`@0YP3o102^0?l50;D0o`D0_@3o1P350?l60<`0o`/0
e03o2`3L0?l80=@0o`@0c03o0`350?l30;d0o`<0]@3o00<0[P3o0:H0o`2V
0?l00P2N0?l0@`2G0?l0S`3o08L0o`270?l0O`3o07P0o`1`0?l0J03o0640
o`1I0?l0D@3o04X0o`120?l0>P3o03<0o`0[0?l0703o01@0o`0<0?l01@3o
000:o`004Ol0027o000Xo`00>?l003oo001?o`00Eol006Ko001eo`00OOl0
08co002Lo`00Zol00;?o0032o`00dOl00>7o003Xo`00n?l00?oh003oj000
omT00?oA003o`P00ok<00?nS003oW000oh`00?mm003oKP00ofH00?mG003o
C`00ocl00?l`003o:000oaT00?lA003o0P05o`003?l001Co000So`00:ol0
03?o000jo`000P1:o`0205Wo0080J?l00P1ho`001@1oo`00Qol008oo002?
o`00Uol00080W_l00P2Vo`00102^o`00]Ol00;Go002eo`030;go00<0aOl0
103<o`080=Co00/0g?l02`3Do`060<co00H0aOl01@2mo`050;Go00@0[_l0
102Vo`0309ko00@0Uol00`2?o`0308Oo000307oo003oool0oooo00<0oooo
0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`80Q`3o0`2?
0?l309L0o`@0WP3o102V0?l40:h0o`@0]@3o1@2m0?l50<D0o`H0c03o1P3D
0?l=0=`0o`H0h`3o2@3L0?l50=@0o`<0c03o0`350?l20;d0o`80]@3o00D0
[P3o0:H0o`2V0?l0WP3o09L0o`0208l0o`1408L0o`1o0?l0N03o0700o`1X
0?l0H@3o05T0o`1A0?l0BP3o0480o`0j0?l0<`3o02<0o`0L0?l0503o00D0
o`000_l0017o000Io`00:?l0033o000oo`00Aol005Oo001Vo`00K_l007go
002<o`00W?l00:?o002co`00`_l00=7o003Qo`00j?l00?So003on000onP0
0?oI003obP00ol800?nc003oX`00oi@00?n<003oO@00ofh00?mN003oE`00
odL00?lh003o<000ob400?lI003o2P00o`803?l001Co000Lo`00:ol003?o
000jo`00@_l004[o001Io`00HOl006So001`o`0207So000307oo0027o`00
Sol00080Uol000@0W_l00:Ko002Vo`00[_l00P2eo`020;go00<0aOl00`3<
o`050=Co00T0g?l01P3So`0=0=co00H0e?l01P3<o`050<Go00D0_Ol0102e
o`040:ko00@0Y_l00`2No`0409Oo00<0Sol00P27o`050?ooo`4000000@3o
ool002H0oooo00<000000?ooo`3oool00`3oool408l0o`<0U`3o0`2N0?l4
0:H0o`@0[P3o102e0?l40;d0o`@0a@3o1P3<0?l50=@0o`L0g03o6`3S0?l4
0=`0o`<0e03o0`3<0?l20<D0o`80_@3o0P2e0?l01`2^0?l0YP3o0:H0o`2N
0?l0U`3o08l0o`270?l00P1o0?l20700o`80H@3o03d0D@3o04X0o`120?l0
>P3o02/0o`0S0?l0703o01@0o`050?l000;o000Ao`006Ol002So000ho`00
Aol004oo001No`00K_l007Go0025o`00U?l00:?o002co`00`_l00<[o003I
o`00j?l00?So003on000onP00?oI003obP00okX00?nc003oX`00oi@00?n5
003oM@00ofH00?mN003oC`00odL00?l`003o:000oaT00?lA003o0P05o`00
5?l001co000So`00<ol003[o0012o`00B_l005Wo001Qo`00J?l0073o001h
o`00Ool00080Qol00P2Go`00102No`00Y_l00:Ko002^o`020;Go0080_Ol0
0P35o`030<co00<0e?l0103Lo`0K0>?o00H0g?l01P3Do`060<co00@0aOl0
102mo`040;Go00@0[_l00`2Vo`0409ko00<0Uol00`2?o`000`27o`00oooo
0?ooo`030?ooo`4000000@3oool002H0oooo0`0000030?ooo`80S`3o0`2G
0?l309h0o`@0YP3o102^0?l30;D0o`@0_@3o1@350?l40<`0o`D0e03o1P3L
0?l70><0oaT0j`3o103S0?l40=`0o`80e03o0P3<0?l20<D0o`80_@3o0P2e
0?l00`2^0?l0YP3o09h0o`0209L0o`1508l0o`270?l0O`3o07P0o`1`0?l0
J03o05T0o`1A0?l0BP3o0480o`0c0?l0:`3o02<0o`0D0?l0303o0002o`00
2_l001Wo000Xo`00<?l003oo001?o`00Eol006Ko001eo`00QOl009Co002S
o`00/ol00;[o003:o`00fOl00>So003ho`00ooP00?oX003of@00olX00?nj
003oZ`00oi`00?n<003oQ@00ogD00?mV003oE`00odL00?lo003o<000ob40
0?lI003o2P00o`803?l001Co000So`00:ol003[o0012o`00B_l0057o001Q
o`00J?l0073o001ho`00Ool008Oo002?o`00Uol00080W_l000@0Y_l00:ko
002eo`00]Ol00P2mo`020<Go0080c?l00P3Do`040=co00@0hol06@3[o`07
0>?o00H0g?l01@3Do`040<co00D0aOl0102mo`030;Go00@0[_l00`2Vo`04
09ko00<0Uol00P2?o`040?ooo`8000000@3oool002H0oooo00<000000?oo
o`3oool00`3oool409L0o`80WP3o102V0?l40:h0o`<0]@3o102m0?l40<D0
o`@0c03o1@3D0?l50=`0o`D0h`3o1`3[0?lI0?<0o`@0j`3o0`3S0?l30=`0
o`80e03o0P3<0?l010350?l0_@3o0;d0o`2e0?l20:h0o`0<0:H0o`2N0?l0
U`3o08l0o`270?l0O`3o07P0o`1`0?l0J03o0640o`1A0?l0BP3o0P0j0?l0
=@0[0?l08`3o01@0o`0<0?l000;o000Ao`008Ol002So000ho`00Aol005Oo
001No`00K_l007go002<o`00W?l00:_o002jo`00b_l00=Wo003Xo`00n?l0
0?oh003oj000omT00?o:003o^P00oj/00?nL003oS000ogd00?m^003oGP00
oeL00?lo003o>000obP00?lI003o2P00o`803?l001Co000So`00:ol003[o
0012o`00B_l005Wo001Qo`00J?l0073o001ho`00Ool00080Sol000@0Uol0
09ko002Vo`00[_l00P2eo`020;go00030<Go003<o`00c?l00080e?l00`3L
o`030>?o00@0jol0603co`080>_o00D0hol01@3Lo`050=Co00@0c?l01035
o`040;go00<0]Ol0102^o`030:Ko00<0W_l00`2Go`000`2?o`00oooo0?oo
o`030?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool2
09L0o`<0WP3o0`2V0?l40:h0o`<0]@3o102m0?l30<D0o`@0c03o1@3D0?l5
0=`0o`@0h`3o1P3[0?l70?<0oaP0nP3o103c0?l30>/0o`<0h`3o0P3L0?l0
1@3D0?l0c03o0<`0o`350?l0_@3o0080]@3o04<0[P3o0:H0o`2N0?l0U`3o
08l0o`270?l0O`3o07P0o`1`0?l0J03o05T0o`1A0?l0BP3o03X0o`0c0?l0
8`3o01`0o`0<0?l01@3o000:o`006Ol002So000`o`00?ol004oo001No`00
K_l007go002<o`00W?l00:_o002jo`00b_l00=Wo003Xo`00n?l00?oh003o
j000omT00?o:003o^P00oj/00?nL003oS000ogd00?m^003oGP00odl00?lo
003o<000ob400?lI003o2P05o`003?l001co000[o`00<ol004;o001:o`00
DOl0067o001Xo`00L?l007So001oo`00Qol00080Uol000@0W_l00:Ko002^
o`00]Ol00P2mo`001035o`00c?l00=Co003Do`020=co00<0hol00`3[o`04
0??o01P0n_l01`3co`060>_o00@0hol01@3Lo`050=Co00@0c?l00`35o`04
0;go00<0]Ol00`2^o`040:Ko00<0W_l00P2Go`050?ooo`4000000@3oool0
02H0oooo00<000000?ooo`3oool00`3oool409h0o`80YP3o102^0?l30;D0
o`<0_@3o10350?l40<`0o`@0e03o103L0?l50><0o`@0j`3o1P3c0?l70?X0
oaP0o`3m103j0?l30?<0o`80j`3o0P3S0?l20=`0o`80e03o00<0c03o0<D0
o`2m0?l00P2e0?l20:H0o`80U`3o0P270?l0?`1h0?l0L03o06P0o`1Q0?l0
D@3o04X0o`0j0?l0<`3o02<0o`0L0?l0303o0002o`004Ol001Wo000Xo`00
>?l004Oo001Go`00I_l007Go0025o`00U?l00:?o002jo`00b_l00=Wo003X
o`00n?l00?oh003oj000om400?o2003o/`00oj<00?nD003oQ@00ogD00?mV
003oE`00odL00?lh003o:000oaT00?l:003o0P0<o`007?l002?o000co`00
@_l004[o001Io`00HOl006So001`o`00Ool008Oo002?o`00Uol009ko002V
o`00[_l00;Go00020;go00040<Go003<o`00e?l00=Co0080g?l00P3So`02
0>_o00<0lol0103jo`0H0?om00H0n_l01P3co`050>_o00D0hol0103Lo`04
0=Co00@0c?l01035o`030;go00<0]Ol00`2^o`030:Ko00<0W_l000<0Uol0
0?ooo`3oool00`3oool100000040oooo000V0?ooo`030000003oool0oooo
00<0oooo0P2N0?l30:H0o`<0[P3o0`2e0?l30;d0o`@0a@3o103<0?l40=@0
o`@0g03o103S0?l40>/0o`D0l`3o1@3j0?l70?l0oAP0o`3e103o0?d20?X0
o`<0l`3o0P3[0?l0103S0?l0g03o0=`0o`3D0?l20<`0o`190<D0o`2m0?l0
]@3o0:h0o`2V0?l0WP3o09L0o`2?0?l0O`3o07P0o`1`0?l0J03o05T0o`1A
0?l0@P3o03X0o`0[0?l0703o01@0o`050?l000[o000Io`00:?l003So0017
o`00Eol006Ko001eo`00QOl009Co002So`00/ol00<;o003Io`00j?l00?So
003on000onP00?oA003o`P00ok<00?nS003oU000ohD00?m^003oGP00odl0
0?lo003o<000obP00?lI003o2P05o`005?l002?o000[o`00>_l004;o001A
o`00FOl006So001`o`00N?l008Oo002?o`00Uol009ko002Vo`00[_l00;Go
002mo`00aOl00<co00020=Co0080g?l000<0hol00>_o003[o`000`3co`02
0?[o00@0ood0603om@070?om00D0n_l01@3co`040>_o00@0hol0103Lo`04
0=Co00@0c?l00`35o`040;go00<0]Ol00`2^o`030:Ko0080W_l01@3oool1
00000040oooo000V0?ooo`030000003oool0oooo00<0oooo102V0?l20:h0
o`@0]@3o0P2m0?l40<D0o`@0c03o0`3D0?l40=`0o`@0h`3o103[0?l50?<0
o`@0nP3o1@3o0?d60?l0m@X0o`3^203o0>H70?l0kP@0o`3e0`3o0?d20?X0
o`80l`3o00L0j`3o0><0o`3S0?l0g03o0=@0o`3<0?l0a@3o0080_@3o0P2^
0?l0>@2N0?l0U`3o08l0o`270?l0N03o0700o`1Q0?l0F@3o04X0o`120?l0
<`3o02/0o`0L0?l0303o0002o`004Ol0027o000`o`00?ol004oo001No`00
K_l007go002<o`00Xol00;?o0032o`00dOl00>So003ho`00ooP00?oQ003o
d@00ol800?nc003oW000oh`00?mm003oKP00oeh00?m7003o?`00obP00?lQ
003o2P05o`003?l001co000[o`00>_l004;o001Ao`00FOl006So001`o`00
Ool008Oo000209Oo00040:Ko002^o`00]Ol00;go0080aOl00P3Do`00103L
o`00hol00>?o003[o`020??o0080n_l00`3oo@040?oe00L0onh0203oiP09
0?o^00H0ooD01P3oo@040?[o00D0lol0103[o`040>?o00@0g?l00`3Do`04
0<co00@0aOl00P2mo`030;Go00<0[_l00`2Vo`000`2No`00oooo0?ooo`03
0?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool20:H0
o`<0[P3o0`2e0?l30;d0o`<0a@3o103<0?l30=@0o`<0g03o103S0?l40>/0
o`@0l`3o1@3j0?l40?l0o@D0o`3e1P3o0>h90?l0iPX0o`3N1P3o0>H40?l0
kP80o`3e0P3o0?d20?X0o`80l`3o04`0j`3o0><0o`3S0?l0g03o0=@0o`3<
0?l0a@3o0;d0o`2e0?l0[P3o0:H0o`2G0?l0S`3o08L0o`1h0?l0L03o0640
o`1I0?l0BP3o03X0o`0c0?l08`3o01@0o`050?l000[o000Io`00:?l003So
0017o`00Eol006ko001mo`00S?l009co002co`00`_l00=7o003Xo`00n?l0
0?oh003oh@00om400?o2003oZ`00oi`00?n<003oM@00ofH00?mG003oA`00
ocP00?lX003o6@00o`X01Ol001Co000So`00<ol004;o001:o`00FOl006So
001`o`00N?l008Oo002?o`00W_l00:Ko002^o`00]Ol00;go0035o`00c?l0
0=Co003Lo`00hol00P3[o`020??o0080n_l00P3oo@020?oe00@0onh01P3o
iP0:0?oN00T0onH01P3okP040?oe00D0ood01@3jo`040??o00@0jol00`3S
o`040=co00<0e?l0103<o`030<Go00<0_Ol00`2eo`030:ko0080Y_l01@3o
ool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo0`2^0?l3
0;D0o`<0_@3o0`350?l40<`0o`<0e03o0`3L0?l40><0o`@0j`3o103c0?l4
0?X0o`<0o`3m1@3o0?D50?l0kPH0o`3V1`3o0=h>0?l0e`D0o`3N0`3o0>H3
0?l0kP80o`3e00D0o`3m0?X0o`3j0?l0l`3o0>/0o`020><0o`80e03o0P35
0?l0>@2e0?l0[P3o0:H0o`2N0?l0S`3o08L0o`1h0?l0L03o0640o`1I0?l0
BP3o03X0o`0[0?l0703o00`0o`000_l0017o000Qo`00<?l003oo001?o`00
I_l007Go0025o`00W?l00:_o0032o`00dOl00>So003ho`00ooP00?oQ003o
d@00okX00?n[003oW000ohD00?me003oGP00odl00?lo003o<000oaT00?lA
00Go000Do`008ol003?o000jo`00B_l005Wo001Xo`00L?l007oo0027o`00
Uol009ko00020:ko00060;go0035o`00c?l00=Co003Lo`00hol00P3[o`00
103co`00n_l00?[o003oo@020?oe00<0onh00`3oiP050?oN00h0omL01`3o
gP060?oV00D0onh0103om@040?om00@0n_l0103co`040>_o00@0hol00`3L
o`030=Co00@0c?l00`35o`020;go00@0]Ol00P2^o`000`2Vo`00oooo0?oo
o`030?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool2
0:h0o`<0]@3o0`2m0?l30<D0o`<0c03o0`3D0?l30=`0o`@0h`3o0`3[0?l4
0?<0o`@0nP3o103o0?d40?l0m@@0o`3^103o0>H60?l0gPH0o`3G4@3o0<l5
0?l0e`80o`3N0`3o0>H0103o0>h0o`3e0?l0m@3o0?d20?X0o`190?<0o`3[
0?l0h`3o0=`0o`3D0?l0c03o0<D0o`2m0?l0[P3o0:H0o`2N0?l0S`3o08L0
o`1h0?l0J03o0640o`1A0?l0@P3o03<0o`0S0?l0503o00D0o`002_l001Wo
000Xo`00?ol004oo001No`00MOl008Go002Do`00Zol00;[o003Ao`00hOl0
0?So003on000on400?oA003o^P00oj/00?nD003oQ@00ofh00?mN003oC`00
ocP00?lX003o6@00o`X01Ol001co000[o`00>_l004;o001Ao`00HOl0073o
001ho`00Qol008oo002No`00Y_l00;Go002mo`00aOl00<co003Do`00g?l0
0>?o003[o`00lol00?[o00020?om0080ooD000@0onh00?oV003oiP00onH0
0P3ogP050?oG0100oll01`3oe`050?oN00D0onH0103okP040?oe00@0ood0
103jo`040??o00<0jol0103So`030=co00<0e?l00`3<o`030<Go00<0_Ol0
0`2eo`020:ko00D0oooo0@0000010?ooo`009P3oool00`000000oooo0?oo
o`030?ooo`<0]@3o0`2m0?l30<D0o`<0c03o0`3D0?l30=`0o`@0h`3o0`3[
0?l30?<0o`@0nP3o103o0?d40?l0m@<0o`3^1@3o0>H40?l0gPD0o`3G1P3o
0<lD0?l0a`<0o`3?0`3o0=L20?l0gP80o`3V00<0o`3^0?l0m@3o0?d00P3j
0?l0103c0?l0j`3o0><0o`3L0?l20<`0o`0o0;d0o`2e0?l0YP3o09h0o`2?
0?l0Q`3o07P0o`1`0?l0F@3o0540o`120?l0<`3o02<0o`0D0?l000;o000A
o`008Ol0033o0017o`00Eol006ko001mo`00U?l00:?o002jo`00dOl00>7o
003ho`00oo000?oQ003obP00okX00?nS003oU000ogd00?m^003oE`00odL0
0?l`003o8@00o`X00?l201Co000So`00<ol004;o001Ao`00HOl0073o001o
o`00Qol009Oo002No`00[_l00;Go0035o`00c?l00=Co003Lo`00hol00>_o
003co`00n_l00080ood000@0ooD00?o^003oiP00onH00P3ogP030?oG00<0
oll0503oa`050?o?00H0omL0103ogP040?oV00@0onh0103om@040?om00@0
n_l00`3co`030>_o00@0hol00`3Lo`030=Co00<0c?l00`35o`030;go0080
]Ol000<0[_l00?ooo`3oool00`3oool100000040oooo000V0?ooo`030000
003oool0oooo00<0oooo0P2e0?l30;d0o`80a@3o0`3<0?l30=@0o`<0g03o
103S0?l30>/0o`<0l`3o103j0?l30?l0o@@0o`3e103o0>h40?l0iP@0o`3N
103o0=L40?l0c`H0o`37203o0;l80?l0^0H0o`2o0`3o0<L20?l0c`80o`3G
0P3o0=h0103o0>H0o`3^0?l0m@3o0?d20?X0o`110>/0o`3S0?l0g03o0=@0
o`3<0?l0_@3o0;D0o`2V0?l0WP3o08l0o`1o0?l0N03o06P0o`1I0?l0BP3o
03X0o`0[0?l0503o00D0o`002_l001Wo000`o`00?ol005Oo001Vo`00OOl0
09Co002So`00^_l00<[o003Qo`00n?l00?o`003oh@00olX00?nc003oX`00
oh`00?me003oIP00odl00?lo003o:000oaT00?l:00Go000Lo`00:ol003[o
001:o`00FOl006So001ho`00Qol008oo002No`00[_l00;Go0035o`00c?l0
0=Co003Lo`00jol00??o003jo`000P3oo@000`3om@00onh00?oV00020?oN
0080omL00P3oc`030?o700H0okl0203o^0080?no00D0olL01@3oc`040?oG
00@0omh0103oiP040?o^00@0ooD00`3oo@040?[o00<0lol00`3[o`040>?o
00<0g?l00P3Do`040<co0080aOl00`2mo`020;Go00D0oooo0@0000010?oo
o`004`3oool2000000@0oooo00<000000?ooo`3oool00P3oool4000000@0
oooo00<000000?ooo`3oool00`3oool30;d0o`<0a@3o0P3<0?l30=@0o`<0
g03o103S0?l20>/0o`@0l`3o103j0?l30?l0o@<0o`3e103o0>h30?l0iP@0
o`3N103o0=L40?l0c`@0o`371@3o0;l70?l0^0h0o`2`103o0;P20?l0_`80
o`370P3o0<l0A03o0=L0o`3N0?l0gP3o0>H0o`3^0?l0m@3o0?d0nP3o0?<0
o`3[0?l0h`3o0=@0o`3<0?l0_@3o0;D0o`2V0?l0WP3o08l0o`270?l0L03o
06P0o`1A0?l0BP3o03<0o`0S0?l0503o0002o`004Ol002So000ho`00Col0
05ko001eo`00S?l00:?o002co`00b_l00>7o003ho`00oo000?oQ003obP00
ok<00?nL003oQ@00ogD00?mN003oA`00ocP00?lQ003o4@05o`005?l002_o
000jo`00B_l005Wo001Xo`00N?l008Oo002Go`00W_l00:ko002eo`00aOl0
0<co003Lo`00hol00P3co`020?om0080onh000@0onH00?oN003oe`00omL0
0P3oc`020?o70080okl0103o^00>0?n`00L0okP0103o_`040?o700@0oll0
103oe`040?oN00@0onH0103okP030?oe00<0ood0103jo`040??o0080jol0
103So`030=co0080e?l00`3<o`030<Go0080_Ol000<0]Ol00?ooo`3oool0
0`3oool100000040oooo000B0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`80_@3o
0P350?l30<`0o`<0e03o0`3L0?l30><0o`<0j`3o0`3c0?l30?X0o`<0o`3m
103o0?D40?l0kP<0o`3V0`3o0=h40?l0e`@0o`3?0`3o0<L40?l0_`D0o`2h
1@3o0;0B0?l0Z0@0o`2`0P3o0;P20?l0_`1;0?l0a`3o0<l0o`3?0?l0e`3o
0=h0o`3V0?l0kP3o0?D0o`3m0?X0o`3c0?l0h`3o0=`0o`3<0?l0a@3o0;D0
o`2V0?l0WP3o08l0o`1o0?l0L03o0640o`1A0?l0>P3o02/0o`0L0?l01@3o
000:o`008Ol0033o0017o`00G_l007Go0025o`00W?l00;?o003:o`00hOl0
0?So003ol000omT00?o:003o/`00oi`00?n5003oKP00oeL00?m7003o<000
oaT00?l:00co000Lo`00:ol004;o001Ao`00HOl0073o001oo`00Sol009ko
002^o`00]Ol00<Go003Do`00g?l00>?o003co`00n_l00?om003om@00onh0
0?oV003ogP00omL00080oll000<0olL00?no003o_`000P3o^0040?n`0180
ojP01@3o/0040?nh00@0okl0103oa`040?o?00<0omL0103ogP030?oV00@0
onh00`3om@040?om00<0n_l00`3co`030>_o00<0hol00`3Lo`030=Co0080
c?l00`35o`020;go00D0oooo0@0000010?ooo`004P3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00@0oooo0`0000030?ooo`80
a@3o0`3<0?l30=@0o`<0g03o0`3S0?l30>/0o`<0l`3o0`3j0?l30?l0o@@0
o`3e0`3o0>h30?l0iP@0o`3N0`3o0=L40?l0c`<0o`37103o0;l30?l0^0@0
o`2`1@3o0:P70?l0X@X0o`2I1@3o0:430?l0Z080o`2`04H0o`2h0?l0_`3o
0;l0o`370?l0c`3o0=L0o`3N0?l0iP3o0>h0o`3e0?l0o@3c0?l0j`3o0=`0
o`3D0?l0a@3o0;d0o`2V0?l0WP3o08l0o`1o0?l0J03o0640o`1:0?l0>P3o
02<0o`0D0?l000;o000Ao`00:?l003oo001Go`00K_l008Go002Lo`00/ol0
0<[o003Qo`00n?l00?o`003of@00ol800?n[003oU000ogd00?mV003oE`00
ocl00?lX003o4@00o`805?l002?o000jo`00DOl0067o001`o`00Ool008oo
002No`00[_l00;go003<o`00e?l00>?o003[o`00n_l00?om003om@00onh0
0P3ogP000`3oe`00oll00?o700020?no00030?nh003o/000ok0000<0ojP0
1@3oX@0:0?nI00L0oj40103oZ0040?n`00@0okP0103o_`030?o700<0oll0
103oe`040?oN00<0onH00`3okP040?oe00<0ood00`3jo`030??o00<0jol0
0`3So`030=co00<0e?l00P3<o`020<Go00030;go003oool0oooo0080oooo
0P0000010?ooo`00303oool400000080oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00@0a@3o0<`0o`3<0?l0c03o0`3D0?l20=`0o`<0h`3o0`3[0?l30?<0o`<0
nP3o0`3o0?d40?l0m@<0o`3^0`3o0>H40?l0gP<0o`3G0`3o0<l30?l0a`@0
o`2o0`3o0;P40?l0/0<0o`2X103o0:460?l0VA00o`2A0`3o09T20?l0X@80
o`2X04T0o`2`0?l0^03o0;l0o`2o0?l0a`3o0<l0o`3G0?l0gP3o0>H0o`3e
0?l0o@3j0?l0j`3o0><0o`3D0?l0a@3o0;D0o`2V0?l0U`3o08L0o`1h0?l0
J03o0540o`120?l0:`3o01`0o`050?l0017o000Qo`00>?l004oo001Vo`00
OOl009Co002[o`00`_l00>7o003ho`00oo000?oI003o`P00oj/00?nD003o
O@00ofH00?m?003o>000ob400?l:00Go000Lo`00<ol004;o001Io`00J?l0
07So002?o`00W_l00:ko002mo`00aOl00=Co003So`00jol00?[o003oo@00
onh00?oV003ogP00omL00?o?003oa`00okl00080okP000<0ok000?nX003o
Z0000P3oX@030?nI0100oi401P3oV@030?nQ00@0ojP0103o/0030?nh00<0
okl0103oa`030?o?00<0omL0103ogP030?oV00<0onh0103om@030?om00<0
n_l00`3co`030>_o00<0hol00P3Lo`030=Co0080c?l00P35o`050?ooo`40
00000@3oool00180oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P3<0?l30=@0o`<0
g03o0P3S0?l30>/0o`<0l`3o0`3j0?l30?l0o@<0o`3e0`3o0>h40?l0iP<0
o`3N0`3o0=L30?l0c`@0o`370`3o0;l30?l0^0<0o`2`0`3o0:P40?l0X@@0
o`2I103o09460?l0RPX0o`22103o08X30?l0T@80o`2I04D0o`2Q0?l0Z03o
0;00o`2`0?l0^03o0;l0o`370?l0c`3o0=L0o`3N0?l0kP3o0?D0nP3o0?<0
o`3S0?l0g03o0<D0o`2m0?l0YP3o09h0o`270?l0N03o0640o`1A0?l0>P3o
02/0o`0D0?l000;o000Io`00<?l004Oo001No`00MOl009Co002[o`00`_l0
0=Wo003ho`00oo000?oI003o`P00oj<00?n<003oM@00oeh00?m7003o<000
oaT00?l201Co000[o`00>_l0057o001Xo`00N?l008oo002No`00[_l00;go
003<o`00g?l00>_o003co`00ood00?oe003oiP00omh00?oG003oc`000P3o
_`001@3o^000ok000?nX003oZ000oj400080oiT00`3oT@040?n:00X0oh80
1P3oRP040?nA00<0oiT0103oX@040?nX0080ok00103o^0030?no00<0olL0
103oc`030?oG00<0omh0103oiP030?o^00<0ooD00`3oo@030?[o00<0lol0
0P3[o`030>?o00<0g?l00P3Do`030<co00D0oooo0@0000010?ooo`004P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool0103<0?l0e03o0=@0o`3D0?l20=`0
o`<0h`3o0`3[0?l20?<0o`<0nP3o0`3o0?d30?l0m@<0o`3^103o0>H30?l0
gP<0o`3G0`3o0<l30?l0a`<0o`2o0`3o0;P40?l0/0<0o`2X0`3o0:430?l0
V@<0o`2A103o08X40?l0PQ40o`1j0`3o08820?l0RP190?l0T@3o09T0o`2I
0?l0X@3o0:P0o`2`0?l0^03o0;l0o`370?l0c`3o0=h0o`3V0?l0m@3o0?d0
l`3o0><0o`3D0?l0a@3o0;D0o`2V0?l0U`3o07l0o`1`0?l0F@3o0480o`0c
0?l0703o00D0o`004Ol002So000oo`00G_l007Go002<o`00Xol00<;o003I
o`00n?l00?o`003of@00okX00?nS003oS000ofh00?mG003o?`00obP00?lA
00Go000Lo`00<ol004[o001Io`00L?l007oo002Go`00Y_l00;Go0035o`00
e?l00>?o003co`00ood00?o^003oiP00omh00?o?003oa`00okl00?nh003o
/000ojP00?nQ00020?nI00030?nA003oRP00ohX000<0oh804@3oNP040?n2
00@0ohX00`3oT@030?nI00<0oj400`3oZ0030?n`00<0okP0103o_`030?o7
00<0oll00`3oe`030?oN00<0onH0103okP030?oe00<0ood00P3jo`030??o
00<0jol00`3So`020=co00<0e?l000<0c?l00?ooo`3oool00`3oool10000
0040oooo000C0?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3o
ool00`3oool20=@0o`80g03o0`3S0?l30>/0o`80l`3o0`3j0?l30?l0o@<0
o`3e0`3o0>h40?l0iP80o`3N103o0=L30?l0c`<0o`370`3o0;l30?l0^0<0
o`2`0`3o0:P30?l0X@80o`2I103o09430?l0RP<0o`22103o07X40?l0L`h0
o`1[0`3o07<20?l0NP80o`220440o`2:0?l0T@3o09T0o`2I0?l0Z03o0;00
o`2h0?l0_`3o0<l0o`3G0?l0iP3o0>h0o`3m0?X0o`3S0?l0g03o0<D0o`2e
0?l0YP3o09L0o`1o0?l0J03o0540o`120?l08`3o01@0o`002_l0027o000h
o`00Col006ko0025o`00Xol00;[o003Io`00l?l00?o`003od@00okX00?nL
003oQ@00ofh00?m?003o>000oaT00?l:01Co000So`00@_l0057o001`o`00
Ool009Oo002Vo`00_Ol00<co003Lo`00jol00?[o003om@00onh00?oN003o
e`00olL00?no00020?n`00050?nQ003oV@00oi400?nA003oRP000P3oPP02
0?mj00<0og<03P3oJ`040?mc00@0ogX00`3oPP030?n:00<0oi400`3oV@03
0?nQ00<0ojP00`3o/0030?nh00<0okl00`3oa`030?o?00@0omL00P3ogP04
0?oV00<0onh00`3om@030?om00<0n_l00P3co`030>_o0080hol00`3Lo`02
0=Co00D0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?oo
o`030=@0o`3L0?l0g03o00<0h`3o0P3[0?l30?<0o`<0nP3o0`3o0?d30?l0
m@80o`3^103o0>H30?l0gP<0o`3G0`3o0<l30?l0a`<0o`2o0`3o0;P30?l0
/080o`2X0`3o0:430?l0V@<0o`2A0`3o08X20?l0PP<0o`1j0`3o07<40?l0
J`D0o`1S2`3o05`30?l0H`80o`1[0P3o07<0103o07X0o`220?l0RP3o08X2
0?l0V@0o0?l0Z03o0;00o`2h0?l0a`3o0<l0o`3N0?l0kP3o0?d0l`3o0><0
o`3D0?l0a@3o0:h0o`2N0?l0Q`3o0700o`1Q0?l0BP3o03<0o`0D0?l000;o
000Io`00<?l004oo001Vo`00QOl00:?o002jo`00fOl00?3o003ol000om40
0?nj003oW000ogd00?mV003oA`00oc000?lI00Go000Lo`00<ol004[o001Q
o`00N?l008oo002No`00]Ol00<Go003Lo`00jol00?[o003om@00onH00?oN
003oc`00okl00?nh003o/000oj400?nI003oT@00ohX00080oh8000<0ogX0
0?mc003oL`000P3oJ`030?mS00/0oe`01@3oH`030?m[00@0og<00P3oNP03
0?n200<0ohX00`3oT@030?nI0080oj400`3oZ0030?n`00<0okP00`3o_`03
0?o700<0oll00`3oe`030?oN00<0onH00`3okP030?oe00<0ood00`3jo`02
0??o00<0jol00`3So`020=co00030=Co003oool0oooo00<0oooo0@000001
0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`80g03o0P3S0?l20>/0
o`<0l`3o0`3j0?l20?l0o@@0o`3e0P3o0>h40?l0iP80o`3N103o0=L20?l0
c`@0o`370P3o0;l30?l0^0<0o`2`0`3o0:P20?l0X@<0o`2I0`3o09420?l0
RP<0o`220`3o07X30?l0L`<0o`1[0P3o06<40?l0G0D0o`1D2@3o04`40?l0
E0030?l0G03o06<0o`1S0080o`1[0440o`1c0?l0NP3o0880o`2:0?l0T@3o
09T0o`2X0?l0/03o0;l0o`370?l0e`3o0>H0o`3e0?X0o`3[0?l0g03o0<D0
o`2e0?l0U`3o08L0o`1`0?l0F@3o0480o`0S0?l0303o000:o`00:?l004Oo
001No`00OOl009co002jo`00dOl00?3o003ol000om400?nc003oU000ogD0
0?mN003o?`00obP00?l:00co000[o`00@_l005Wo001`o`00Qol009ko002e
o`00c?l00=co003co`00n_l00?o^003oiP00oll00?o7003o^000ok000?nQ
003oV@00oi400?n:00020?mj00040?mc003oJ`00of<00?mS0080oe`0103o
E0090?m<00D0oe@0103oG0020?mS00<0of/00`3oL`030?mj0080oh800`3o
RP030?nA0080oiT00`3oX@030?nX0080ok00103o^0020?no00@0olL00P3o
c`040?oG0080omh0103oiP020?o^00@0ooD00P3oo@030?[o0080lol00`3[
o`020>?o0080g?l01@3oool100000040oooo000V0?ooo`030000003oool0
oooo00<0oooo0`3S0?l20>/0o`<0l`3o0P3j0?l30?l0o@<0o`3e0`3o0>h3
0?l0iP<0o`3N0`3o0=L30?l0c`<0o`370P3o0;l30?l0^0<0o`2`0`3o0:P3
0?l0X@80o`2I0`3o09420?l0RP<0o`220P3o07X30?l0L`80o`1[0`3o06<3
0?l0G080o`1D103o04`50?l0A@L0o`0m103o04D20?l0C080o`1D04<0o`1L
0?l0H`3o06/0o`1c0?l0NP3o0880o`2:0?l0T@3o0:40o`2X0?l0^03o0<L0
o`3G0?l0iP3o0?D0nP3o0><0o`3D0?l0_@3o0:H0o`2?0?l0N03o0640o`1:
0?l0<`3o01@0o`000_l0027o000oo`00G_l007go002Do`00/ol00=7o003`
o`00oo000?oA003o/`00oi@00?me003oE`00ocP00?lQ003o0P0Lo`00<ol0
04[o001Xo`00Ool009Oo002^o`00aOl00=Co003[o`00n_l00?oe003ogP00
oll00?no003o^000ojP00?nI003oT@00ohX00?mj003oL`00of/00080of<0
00<0oe`00?mD003oE0000P3oC0040?m500L0ocd01@3oA@030?m<00<0oe@0
0`3oG0030?mS0080of/00`3oL`020?mj0080oh800`3oRP030?nA0080oiT0
0`3oX@030?nX00<0ok000P3o^0030?no00<0olL00`3oc`030?oG00<0omh0
0`3oiP030?o^00<0ooD00P3oo@030?[o00<0lol00P3[o`020>?o00030=co
003oool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000oooo0?oo
o`030?ooo`040><0o`3[0?l0j`3o0>/0o`80l`3o0P3j0?l30?l0o@<0o`3e
0`3o0>h30?l0iP80o`3N103o0=L20?l0c`@0o`370P3o0;l30?l0^0<0o`2`
0`3o0:P20?l0X@<0o`2I0P3o09430?l0RP80o`220P3o07X30?l0L`<0o`1[
0P3o06<20?l0G080o`1D0`3o04`30?l0A@<0o`0m1@3o03D70?l0;P@0o`0e
0P3o03d20?l0A@0o0?l0C03o05@0o`1L0?l0H`3o06/0o`1c0?l0PP3o08X0
o`2I0?l0X@3o0;00o`2h0?l0c`3o0=h0o`3e0?l0o@3S0?l0e03o0;d0o`2V
0?l0S`3o07P0o`1I0?l0@P3o02<0o`050?l0017o000`o`00Col006ko002D
o`00/ol00=7o003`o`00oo000?o:003oZ`00oh`00?m^003oC`00oc000?lA
00co000So`00@_l005Wo001ho`00Sol00:ko0035o`00g?l00>_o003oo@00
onh00?oN003oa`00okP00?nX003oX@00oi400?n:003oNP00og<00080of<0
0P3oE0000`3oC000odD00?m500020?lm00@0ocD01`3o;P050?le00<0ocd0
0`3oA@030?m<0080oe@00P3oG0020?mS00<0of/00P3oL`020?mj00<0oh80
0`3oRP020?nA0080oiT00`3oX@030?nX00<0ok000`3o^0020?no00@0olL0
0P3oc`040?oG0080omh00`3oiP030?o^00<0ooD00P3oo@030?[o0080lol0
0`3[o`000`3So`00oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<0
00000?ooo`3oool00`3oool20>/0o`<0l`3o0P3j0?l30?l0o@80o`3e0`3o
0>h30?l0iP<0o`3N0`3o0=L30?l0c`<0o`370P3o0;l30?l0^0<0o`2`0`3o
0:P20?l0X@<0o`2I0`3o09420?l0RP80o`220`3o07X20?l0L`80o`1[0P3o
06<20?l0G0<0o`1D0P3o04`20?l0A@<0o`0m0P3o03D30?l0;P@0o`0V2@3o
01h30?l09P80o`0^04@0o`0e0?l0?@3o03d0o`150?l0C03o05@0o`1S0?l0
J`3o07<0o`220?l0T@3o09T0o`2X0?l0_`3o0<l0o`3N0?l0m@3j0?l0h`3o
0<`0o`2e0?l0WP3o07l0o`1X0?l0BP3o02/0o`0<0?l0017o000`o`00Col0
06ko002<o`00Zol00=7o003`o`00onP00?o:003oZ`00oh`00?mV003oA`00
obP00?l:01Co000co`00DOl006So0027o`00W_l00;Go003<o`00hol00?[o
003okP00omh00?o7003o^000ojP00?nI003oRP00oh800?mc003oJ`00oe`0
0?mD003oC000odD00?lm0080ocD00P3o;P030?lV00T0oah0103o9P030?l^
0080ocD00`3o?@020?m50080od`00P3oE0030?mL0080of<00P3oJ`020?mc
0080ogX00`3oPP020?n:00<0oi400P3oV@030?nQ00<0ojP00`3o/0020?nh
00<0okl00`3oa`030?o?00<0omL00`3ogP030?oV0080onh00`3om@030?om
0080n_l00P3co`030>_o00D0oooo0@0000010?ooo`009P3oool00`000000
oooo0?ooo`030?ooo`030>/0o`3c0?l0l`3o00<0nP3o0P3o0?d20?l0m@<0
o`3^0`3o0>H30?l0gP<0o`3G0P3o0<l40?l0a`80o`2o0`3o0;P30?l0/0<0
o`2X0P3o0:430?l0V@80o`2A0`3o08X20?l0PP80o`1j0P3o07<30?l0J`80
o`1S0P3o05`20?l0E080o`1<0P3o04D20?l0?@<0o`0e0P3o02h20?l09P<0
o`0N0`3o01L60?l03`80o`070P3o00l30?l05`80o`0N00@0o`0V0?l0;P3o
03D0o`0e0P3o04D0>`3o05@0o`1L0?l0J`3o07<0o`2:0?l0T@3o0:P0o`2`
0?l0a`3o0=L0o`3e0?X0o`3S0?l0c03o0:h0o`2G0?l0N03o0640o`120?l0
8`3o0002o`008Ol003oo001Vo`00QOl00:_o003:o`00l?l00?oX003obP00
oj<00?n5003oGP00ocl00?lI00Go000So`00@_l0067o001ho`00W_l00:ko
003<o`00jol00?om003oiP00omL00?no003o/000oiT00?nA003oNP00og<0
0?mS003oG000od`00?m5003o?@00ocD00080obh000<0obH00?lN003o5`00
0`3o5`020?l?0080o`L01P3o3`030?lG00<0oah00P3o9P020?l^00<0ocD0
0P3o?@020?m50080od`00P3oE0020?mL0080of<00P3oJ`020?mc0080ogX0
0`3oPP030?n:0080oi400P3oV@030?nQ00<0ojP00`3o/0030?nh0080okl0
103oa`020?o?00<0omL00`3ogP030?oV0080onh00`3om@020?om00<0n_l0
0P3co`000`3[o`00oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<0
00000?ooo`3oool00`3oool20?<0o`80nP3o0`3o0?d20?l0m@<0o`3^0P3o
0>H30?l0gP<0o`3G0`3o0<l30?l0a`<0o`2o0P3o0;P30?l0/0<0o`2X0`3o
0:420?l0V@<0o`2A0P3o08X20?l0PP<0o`1j0P3o07<20?l0J`80o`1S0P3o
05`20?l0E080o`1<0P3o04D20?l0?@80o`0e0P3o02h20?l09P80o`0N0P3o
01L30?l03`80o`071P3o00000`00omT0o`0V0?l000030?l000<0o`070440
o`0?0?l05`3o01h0o`0V0?l0;P3o03D0o`0m0?l0A@3o05@0o`1S0?l0L`3o
0880o`2A0?l0X@3o0;00o`370?l0gP3o0?D0l`3o0=`0o`2m0?l0YP3o08L0
o`1X0?l0BP3o02/0o`050?l001Wo000oo`00G_l008Go002So`00b_l00?3o
003oj000ol800?nS003oO@00oeL00?lh003o4@0<o`00:ol0057o001`o`00
Qol00:Ko0035o`00g?l00??o003okP00omL00?o7003o/000oj400?n:003o
NP00of/00?mL003oE000odD00?lm003o=@00obH00?lN00020?lG00030?l?
003o1`00o`L000D0o`0000<0B_l007So003o0000103o00030?l700<0o`l0
0P3o5`020?lN0080obH00P3o;P020?le0080ocd00P3oA@020?m<0080oe@0
0P3oG0020?mS0080of/00P3oL`020?mj00<0oh800P3oRP030?nA0080oiT0
0`3oX@030?nX0080ok000`3o^0030?no00<0olL00`3oc`030?oG0080omh0
0`3oiP030?o^0080ooD00`3oo@020?[o0080lol01@3oool100000040oooo
000V0?ooo`030000003oool0oooo00<0oooo0P3j0?l30?l0o@80o`3e0`3o
0>h20?l0iP<0o`3N0`3o0=L30?l0c`<0o`370P3o0;l40?l0^080o`2`0`3o
0:P30?l0X@80o`2I0`3o09420?l0RP80o`220P3o07X20?l0L`<0o`1[0P3o
06<20?l0G0030?l0E03o04`0o`1<0080o`150P3o03d20?l0=@80o`0^0P3o
02H20?l07P80o`0G0P3o00l20?l00004000Xo`00S?l008Go0?l70080o`00
103o1`020?l?00@0o`L00P3o0000103o1`0008co002<o`3o00020?l01`10
0?l05`3o02H0o`0^0?l0?@3o04D0o`1D0?l0H`3o07<0o`220?l0V@3o0:P0
o`370?l0e`3o0?D0l`3o0=@0o`2m0?l0WP3o07l0o`1Q0?l0>P3o01`0o`00
2_l0033o001Go`00OOl00:?o003:o`00l?l00?oX003o`P00oi`00?me003o
C`00obP00?l201co0012o`00HOl007oo002No`00_Ol00=Co003jo`00onh0
0?oG003o_`00ojP00?nA003oPP00of/00?mS003oC000odD00?le003o;P00
oah00?lG003o1`00o`000?oN0000oh`00?n50?l01`80o`00103o00L20?l0
3`@0o`070P3o0000103o00L00?n5003oS03o^0020?l00080o`l00P3o5`02
0?lN0080obH00P3o;P020?le00030?lm003oA@00odD00080od`00P3oE002
0?mL0080of<00P3oJ`020?mc0080ogX00`3oPP020?n:00<0oi400P3oV@03
0?nQ00<0ojP00P3o/0040?nh0080okl00`3oa`030?o?00<0omL00`3ogP02
0?oV00<0onh00P3om@020?om0080n_l000<0lol00?ooo`3oool00`3oool1
00000040oooo000V0?ooo`<000000`3oool0103j0?l0o`3m0?l0o@3o0?d2
0?l0m@80o`3^0`3o0>H30?l0gP80o`3G0`3o0<l30?l0a`<0o`2o0`3o0;P2
0?l0/0<0o`2X0`3o0:430?l0V@80o`2A0P3o08X30?l0PP80o`1j0P3o07<2
0?l0J`80o`1S0P3o05`20?l0E080o`1<0P3o04D00`3o03d0o`0e0?l0=@02
0?l0;P030?l09P3o01h0o`0N0080o`0G0P3o00l00`3o00L0o`000?l00002
0?mD00040?l7003o0000o`L00?l?00<0oaL02`3o7P000`3o5`00o`L00?l0
00020?mL00110?mc003o0000o`0?0?l05`3o02H0o`0^0?l0?@3o04`0o`1L
0?l0L`3o0880o`2I0?l0/03o0<L0o`3N0?l0o@3[0?l0c03o0:h0o`270?l0
J03o0480o`0S0?l000;o000Xo`00Col007Go002Lo`00b_l00?3o003oj000
ol800?nD003oKP00odL00?lQ00Go000[o`00B_l0073o002?o`00[_l00<co
003[o`00ooD00?oN003o_`00ojP00?nI003oPP00of/00?mL003oC000ocd0
0?l^003o7P00oaL00?l7003o0000o`1D0?l0G03o00l0o`000?l01`3o01L0
2`3o01h30?l05`040?l03`3o00L0o`000?l01`80o`1D0P3o00000`3o1`00
o`l00?l?00020?lG00030?lN003o9P00obH00080obh000<0ocD00?lm003o
?@000P3oA@020?m<0080oe@00P3oG0020?mS0080of/00P3oL`020?mj0080
oh800`3oRP020?nA00<0oiT00`3oX@020?nX00<0ok000`3o^0030?no00<0
olL00`3oc`020?oG00<0omh00P3oiP030?o^0080ooD00`3oo@000`3jo`00
oooo0?ooo`020?ooo`8000000@3oool002H0oooo00<000000?ooo`3oool0
0`3oool20?l0o@80o`3e0P3o0>h30?l0iP<0o`3N0P3o0=L30?l0c`<0o`37
0`3o0;l30?l0^080o`2`0`3o0:P30?l0X@80o`2I0`3o09420?l0RP<0o`22
0P3o07X20?l0L`80o`1[0P3o06<20?l0G080o`1D0P3o04`00`3o04D0o`0m
0?l0?@020?l0=@80o`0^00@0o`0V0?l07P3o01h0o`0G0P3o00l0103o00L0
o`0003X0o`00Xol20?l00080o`l00P3o5`020?lN0080obH0103o;P080?le
0080obh00P3o9P00?P3o7P00oaL00?l7003o1`000:_o0?l0003o00l0o`0V
0?l0;P3o04D0o`1<0?l0J`3o07<0o`2A0?l0Z03o0<L0o`3N0?l0o@3S0?l0
a@3o0:H0o`1o0?l0F@3o03<0o`0<0?l001Wo000oo`00K_l009Co0032o`00
l?l00?oX003o^P00oi@00?mV003o?`00oaT05?l003[o001Qo`00Ool00:Ko
0035o`00jol00?om003oe`00okP00?nQ003oRP00og<00?mL003oC000ocD0
0?l^003o5`00o`L00?n:0000oj/0o`000?l01`3o01L0o`0N0P3o02H20?l0
;PP0o`0e103o02h20?l09P80o`0N0P3o01L20?l03`80o`0000@00?nS0?mS
003o0000o`L00P3o3`00103o5`00oah00?lN003o9P020?l^00030?le003o
?@00ocd00080odD00P3oC0020?mD0080oe`00P3oH`020?m[0080og<00P3o
NP020?n200<0ohX00`3oT@020?nI00<0oj400`3oZ0020?n`00<0okP00`3o
_`030?o700<0oll00P3oe`030?oN0080onH00P3okP030?oe0080ood01@3o
ool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo00<0o`3m
0?l0m@3o0?D00P3o0>h30?l0iP80o`3N0`3o0=L30?l0c`80o`370`3o0;l3
0?l0^0<0o`2`0`3o0:P20?l0X@<0o`2I0`3o09420?l0RP80o`220`3o07X2
0?l0L`80o`1[0P3o06<20?l0G080o`1D00<0o`1<0?l0A@3o04D00P3o03d0
0`3o03D0o`0^0?l0;P020?l09P040?l07P3o01L0o`0G0?l03`80o`0700D0
o`000>_o003o1`00o`000?l?00020?lG0080oah000<0obH00?l^003o;P00
0P3o=@020?lm00@0odD01P3oC0030?m5000m0?lm003o=@00obh00?lV003o
7P00o`l00?lm00008Ol0o`070?l05`3o02H0o`0m0?l0C03o06<0o`1j0?l0
T@3o0;00o`370?l0iP3c0?l0e03o0;D0o`2?0?l0J03o0480o`0D0?l0017o
000oo`00I_l009Co0032o`00l?l00?oX003o^P00oh`00?mN003o>000o`X0
7?l004;o001`o`00Sol00;Go003Lo`00n_l00?oV003oa`00ojP00?nA003o
NP00of<00?m<003o=@00obH00?lG003o000005ko0?l05`3o00l0o`0N0?l0
;P020?l0=@040?l0?@3o04D0o`150?l0A@H0o`1<103o04D20?l0?@80o`0e
0P3o02h0103o02H0o`0N0?l07P3o01L20?l03`80o`0000D008co0?l0003o
1`00o`L00?l?00020?lG00040?lN003o9P00obH00?l^0080ocD00P3o?@00
0`3oA@00od`00?m<00020?mD0080oe`00P3oH`020?m[0080og<00P3oNP03
0?n20080ohX00`3oT@030?nI0080oj400`3oZ0030?n`00<0okP00`3o_`02
0?o700<0oll00`3oe`020?oN00<0onH00P3okP020?oe00030?om003oool0
oooo00<0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?oo
o`030?l0m@3o0>h0o`3^00<0o`3V0P3o0=h30?l0e`<0o`3?0P3o0<L30?l0
_`<0o`2h0`3o0;030?l0Z080o`2Q0`3o09T30?l0T@80o`2:0P3o08830?l0
NP80o`1c0P3o06/20?l0H`80o`1L0P3o05@20?l0C0040?l0A@3o03d0o`0m
0?l0=@80o`0^0P3o02H0303o01h0o`0G0?l03`3o00l0o`070?l0001h0?l0
0<[o0?l0003o1`00o`l00?lG0080oah000@0obH00?l^003o=@00ocD00P3o
?@000`3oA@00od`00?m<00030?mD0080oe`01`3oH`020?mL0080oe@003T0
od`00?m5003o?@00ocD00?lV003o7P00o`l0003:o`3o0000o`0?0?l0;P3o
03d0o`1L0?l0J`3o0940o`2X0?l0c`3o0>H0l`3o0<`0o`2V0?l0O`3o05T0
o`0[0?l000;o000`o`00G_l008co002jo`00j?l00?oQ003o/`00ohD00?mG
003o:005o`00<ol005Wo0027o`00Y_l00=Co003co`00onH00?o?003oX@00
oh800?m[003oE000ocd00?lV003o3`00oe@0003obP3o00l0o`0N0?l0;P3o
03D00P3o04D00`3o04`0o`1D0?l0G0020?l0G0L0o`1S0P3o05`30?l0E080
o`1<00<0o`150?l0?@3o03d00P3o03D0303o02h0o`0V0?l07P3o01h0o`0G
0?l03`3o00L0o`00003obP3o=@00o`000?l70080o`l000<0oaL00?lN003o
9P000P3o;P020?le0080ocd000<0odD00?m<003oC0000P3oE000103oG000
of<00?mS003oH`020?m[0080og<00`3oNP020?n20080ohX00`3oT@030?nI
0080oj400`3oZ0030?n`00<0okP00`3o_`020?o700<0oll00P3oe`030?oN
00<0onH00P3okP000`3om@00oooo0?ooo`030?ooo`4000000@3oool002H0
oooo00<000000?ooo`3oool00`3oool20?l0kP80o`3V0`3o0=h20?l0e`<0
o`3?0`3o0<L20?l0_`<0o`2h0`3o0;030?l0Z0<0o`2Q0P3o09T30?l0T@<0
o`2:0P3o08820?l0NP<0o`1c0P3o06/20?l0H`80o`1L0P3o05@00`3o04`0
o`150?l0A@020?l0?@040?l0=@3o02h0o`0^0?l09P80o`0N00H0o`0G0?l0
3`3o00l0o`070?l0002eo`020?l700060?l?003o5`00oah00?lN003o9P00
obh00P3o=@001@3o?@00odD00?m<003oC000oe@00080oe`000<0of<00?m[
003oJ`000`3oL`070?mj0080og<00P3oJ`001P3oH`00oe`00?mD003oA@00
ocd00?l^0080oah00380703o0?l03`3o02H0o`0m0?l0G03o07<0o`2A0?l0
^03o0=L0o`3m0=`0o`2e0?l0S`3o0640o`0c0?l01@3o000Xo`00Eol008Go
002jo`00j?l00?oQ003o/`00ogd00?m?003o8@0<o`00>_l006So002Go`00
_Ol00>?o003om@00oll00?n`003oT@00og<00?mD003o?@00obH00?l00000
W?l0o`0G0?l07P3o02h0o`0m0?l0A@3o05@0o`1L0?l0H`80o`1[0P3o07<7
0?l0NP80o`1c0P3o06/20?l0H`80o`1L00D0o`1D0?l0C03o04`0o`150?l0
?@020?l0=@030?l0;P3o02H0o`0N0080o`0G00H0o`0?0?l01`3o00000<[o
0?l0003o1`020?l?00050?lG003o7P00obH00?lV003o;P000P3o=@020?lm
00030?m5003oC000od`00080oe@00P3oG0020?mS0080of/00P3oL`030?mj
0080oh800`3oRP020?nA00<0oiT00`3oX@030?nX00<0ok000P3o^0030?no
00<0olL00P3oc`030?oG0080omh00`3oiP020?o^00D0oooo0@0000010?oo
o`009P3oool00`000000oooo0?ooo`030?ooo`80o`3V0`3o0=h20?l0e`<0
o`3?0P3o0<L30?l0_`<0o`2h0`3o0;030?l0Z080o`2Q103o09T20?l0T@<0
o`2:0P3o08830?l0NP80o`1c0P3o06/20?l0H`80o`1L0P3o05@20?l0C003
0?l0A@3o03d0o`0m0080o`0e00@0o`0^0?l09P3o02H0o`0N0P3o01L0203o
00l0o`070?l00000hOl0o`000?l7003o3`00oaL00P3o7P00103o9P00obh0
0?le003o?@020?m500040?m<003oE000oe`00?mS0080of/00P3oL`000`3o
NP00oh800?n200020?n:00T0oi400P3oRP000`3oPP00ogX00?mc00020?mS
000e0?m<003oA@00obh00?lV003o1`00>P3o0?l05`3o02h0o`1D0?l0J`3o
0940o`2`0?l0e`3o0?d0e03o0:h0o`1o0?l0BP3o01`0o`006Ol004Oo001m
o`00/ol00>So003oh@00oj/00?me003o?`00oa408ol0057o001oo`00]Ol0
0=Co003om@00omL00?nX003oT@00of<00?m5003o;P00o`L0003oh@3o00l0
o`0V0?l0?@3o04D0o`1D0?l0H`3o06/0o`1c0?l0NP3o08800P3o08X90?l0
T@80o`2:0P3o08800`3o07X0o`1c0?l0L`020?l0J`040?l0H`3o05`0o`1D
0?l0C080o`1500@0o`0m0?l0=@3o02h0o`0V0P3o01h02@3o01L0o`0?0?l0
1`3o00000?oQ0?l0003o1`00o`l00?lG00020?lN0080obH000@0obh00?le
003o?@00ocd00P3oA@020?m<0080oe@00P3oG0020?mS0080of/00P3oL`03
0?mj0080oh800`3oRP020?nA00@0oiT00P3oX@030?nX00<0ok000`3o^003
0?no0080olL00`3oc`020?oG0080omh00P3oiP000`3okP00oooo0?ooo`03
0?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool0103o
0>H0o`3N0?l0gP3o0=h20?l0e`80o`3?0`3o0<L30?l0_`<0o`2h0P3o0;03
0?l0Z0<0o`2Q0`3o09T30?l0T@80o`2:0`3o08820?l0NP<0o`1c0P3o06/2
0?l0H`80o`1L0P3o05@20?l0C0030?l0A@3o03d0o`0m0080o`0e00D0o`0^
0?l09P3o02H0o`0N0?l05`020?l03`030?l01`3o0000o`L00080o`L000H0
o`l00?lG003o7P00obH00?l^003o=@020?lm00070?m5003oC000oe@00?mL
003oH`00of/00?mc00020?mj00050?n2003oRP00oi400?nA003oV@000P3o
X@030?nX00D0ok000`3oZ000>P3oX@00oiT00?nA003oRP00ogX00?mc003o
H`00oe@00?lm003o;P00oaL00>?o003o00L0o`0e0?l0E03o07X0o`2I0?l0
_`3o0>h0j`3o0;d0o`270?l0F@3o02<0o`002_l003oo001eo`00/ol00>So
003oh@00oj/00?m^003o>000o`80:ol0067o002?o`00aOl00>_o003oiP00
okl00?nI003oL`00od`00?l^003o1`00o`070?l05`3o02h0o`150?l0E03o
06<0o`1c0?l0PP3o08X0o`2A0?l0V@3o0:420?l0Z0H0o`2`0`3o0:P00`3o
0:40o`2I0?l0V@020?l0T@030?l0RP3o0880o`1j0080o`1c00L0o`1[0?l0
H`3o05`0o`1D0?l0C03o04D0o`0m0080o`0e00/0o`0^0?l09P3o01h0o`0G
0?l03`3o00L0o`000?l01`3o0000o`L00?l?00020?lG00040?lN003o9P00
obH00?l^0080ocD000<0ocd00?m5003oA@000P3oC0020?mD0080oe`00P3o
H`020?m[00<0og<00P3oNP030?n20080ohX00`3oT@030?nI00<0oj400`3o
Z0020?n`00<0okP00`3o_`020?o700<0oll00P3oe`020?oN0080onH01@3o
ool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo0P3o0=h2
0?l0e`80o`3?0`3o0<L30?l0_`80o`2h0`3o0;030?l0Z0<0o`2Q0`3o09T2
0?l0T@<0o`2:0`3o08820?l0NP<0o`1c0P3o06/20?l0H`80o`1L0P3o05@2
0?l0C080o`150P3o03d0103o03D0o`0^0?l0;P3o02H20?l07P0:0?l05`3o
00l0o`070?l0003<0?l0o`000?l7003o3`00oaL00?lN0080obH00P3o=@02
0?m50080oe@000P0oe`00?mS003oJ`00og<00?mj003oPP00ohX00?nA0080
oiT00P3oZ0020?n`00030?nh003o_`00okl000<0olL00`3oc`030?o70003
0?no003o^000okP00080ojP003<0oiT00?n:003oNP00of/00?mD003oA@00
obH00?l?003o0000o`0V0?l0C03o07<0o`2I0?l0a`3o0?D0g03o0:h0o`1h
0?l0@P3o00D0o`00<?l006ko002[o`00j?l00?oI003oX`00ofH00?lX00co
0012o`00Ool00:ko003So`00ooD00?no003oV@00of/00?m<003o7P00o`l0
0?l07P3o02h0o`150?l0G03o06/0o`220?l0RP3o0:40o`2X0?l0/03o0;P0
0P3o0;l20?l0a`@0o`3?0`3o0<L20?l0_`030?l0^03o0;00o`2`0080o`2X
0P3o09T0203o0940o`2:0?l0PP3o07X0o`1c0?l0J`3o06<0o`1L0P3o05@2
0?l0A@80o`0e0P3o02H0103o01h0o`0G0?l03`3o00L30?l00080o`l000@0
oaL00?lN003o7P00obH00P3o;P000`3o=@00ocd00?lm00020?m500030?m<
003oE000oe@00080oe`00`3oH`020?m[00<0og<00P3oNP030?n200<0ohX0
0P3oT@030?nI00<0oj400`3oZ0030?n`0080okP00`3o_`020?o700<0oll0
0P3oe`020?oN00D0oooo0@0000010?ooo`009P3oool00`000000oooo0?oo
o`030?ooo`80o`3G0`3o0<l20?l0a`<0o`2o0P3o0;P30?l0/0<0o`2X0`3o
0:430?l0V@<0o`2A0`3o08X20?l0PP<0o`1j0`3o07<20?l0J`80o`1S0P3o
05`20?l0E080o`1<00<0o`150?l0?@3o03d00P3o03D0103o02h0o`0V0?l0
9P3o01h20?l05`040?l03`3o00L0o`0?0?l03`80o`L001P0o`l00?lG003o
7P00obH00?l^003o=@00ocd00?m5003oC000oe@00?mL003oH`00of/00?mc
003oNP00oh800?n:003oT@00oiT00?nQ003oZ000ok000?nh003o_`020?o7
00040?o?003oe`00omh00?oN00<0onH0103okP020?oV0080omh000/0oll0
0?o7003o^000ok000?nQ003oT@00ogX00?m[003oC000ocD00?lG00020?l0
9P0J0?l0A@3o07X0o`2I0?l0e`3o0?d0a@3o09L0o`1I0?l0703o000Qo`00
G_l00:?o003Qo`00omT00?nL003oE`00ob408ol005Wo002No`00aOl00?oe
003oe`00oiT00?mj003oA@020?lV000;0?l09P3o03D0o`1L0?l0J`3o08X0
o`2A0?l0Z03o0;00o`2o0?l0a`3o0=L00P3o0=h20?l0iP@0o`3^0`3o0>H2
0?l0gP0S0?l0e`3o0<l0o`370?l0a`3o0;l0o`2h0?l0/03o0:P0o`2Q0?l0
V@3o0940o`2:0?l0PP3o07X0o`1c0?l0J`3o06<0o`1L0?l0E03o04`0o`15
0?l0?@3o03D0o`0^0?l09P3o01h0o`0G0?l03`3o00L0o`000?l?003o0000
o`L00?l?003o5`000P3o7P020?lV00040?l^003o=@00ocd00?lm0080odD0
0P3oC0020?mD0080oe`00P3oH`020?m[00<0og<00`3oNP020?n200<0ohX0
0`3oT@030?nI00<0oj400`3oZ0030?n`0080okP00`3o_`020?o70080oll0
0P3oe`000`3ogP00oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<0
00000?ooo`3oool00`3oool00`3o0=L0o`3?0?l0c`030?l0a`80o`2o0P3o
0;P30?l0/0<0o`2X0`3o0:430?l0V@<0o`2A0`3o08X20?l0PP<0o`1j0`3o
07<20?l0J`80o`1S0`3o05`20?l0E080o`1<00<0o`150?l0?@3o03d00P3o
03D01@3o02h0o`0V0?l09P3o01h0o`0G0080o`0?00@0o`070?l0003o0000
o`000P3o3`001P3o5`00oah00?lV003o;P00ocD00?lm0080od`00P3oG000
1P3oJ`00og<00?mj003oPP00ohX00?nA0080oj400P3o/000103o_`00olL0
0?o?003oe`020?oN0080onh000<0ooD00?om003oo@000P3jo`050??o0080
n_l00380ood00?oe003okP00onH00?oN003oa`00okl00?nQ003oT@00og<0
0?mS003o?@00oaL0003of@3o00l0o`1D0?l0PP3o0;00o`3V0><0o`2V0?l0
J03o02/0o`006Ol005ko002Lo`00hOl00?oI003oU000odl00?lA03?o001`
o`00[_l00>?o003ogP00ok000?mj003oE000o`l0003Io`3o01L0o`1<0?l0
H`3o0880o`2A0?l0/03o0;l0o`3?0?l0gP80o`3^0P3o0?d20?X0o`@0l`3o
0`3j0?l20?l0o@030?l0m@3o0>h0o`3^0080o`3N00@0o`3G0?l0c`3o0<L0
o`2o0P3o0;020?l0X@060?l0T@3o08X0o`220?l0NP3o07<0o`1[0P3o05`0
3`3o04`0o`150?l0?@3o03D0o`0^0?l09P3o01h0o`0G0?l03`3o00L0o`00
003Io`3o0000o`L00?l?00020?lG00040?lN003o9P00obh00?l^0080ocD0
0P3o?@000`3oA@00od`00?m<00020?mD00<0oe`00P3oH`020?m[00<0og<0
0`3oNP020?n200<0ohX00`3oT@030?nI00<0oj400`3oZ0020?n`00<0okP0
0P3o_`030?o70080oll000<0omL00?ooo`3oool00`3oool100000040oooo
000V0?ooo`030000003oool0oooo00<0oooo00@0o`3?0?l0a`3o0<L0o`37
0P3o0;l30?l0^0<0o`2`0P3o0:P30?l0X@<0o`2I0`3o09430?l0RP<0o`22
0`3o07X20?l0L`<0o`1[0P3o06<20?l0G080o`1D0P3o04`20?l0A@80o`0m
0P3o03D0103o02h0o`0V0?l07P3o01h20?l05`80o`0700@0o`0V0?l0003o
1`00o`L00P3o5`020?lV0080ocD000H0odD00?m<003oE000oe`00?mS003o
J`020?mj000:0?n:003oT@00oiT00?nQ003o/000okP00?no003oa`00oll0
0?oG0080onH00P3om@020?[o00030>_o003So`00hol00080g?l01`3Do`00
9`3Lo`00hol00>?o003co`00n_l00?oe003oiP00oll00?no003oX@00oi40
0?mS003oE000oah00?l7003o02H0o`1<0?l0T@3o0;P0o`3m0<`0o`270?l0
@P3o0002o`00Col009Co003Qo`00om400?n<003o?`00o`80B_l008Oo003D
o`00ood00?n`003oT@00od`00?lV00020?l07P0;0?l0E03o07X0o`2A0?l0
/03o0;l0o`3N0?l0iP3o0?d0nP3o0>/0o`3S0?l00P3L0?l70=@0o`80g03o
00<0h`3o0>/0o`3[0?l00P3j0?l20?l0m@80o`3V00X0o`3G0?l0c`3o0<L0
o`2o0?l0^03o0;00o`2Q0?l0V@3o0940o`2:0P3o07X01P3o06/0o`1S0?l0
G03o05@0o`1<0?l0A@80o`0e0P3o02H00`3o01L0o`0?0?l01`030?l00005
0?l7003o3`00oaL00?lG003o7P000P3o9P00103o;P00ocD00?le003o?@02
0?m50080od`00P3oE0030?mL0080of<00`3oJ`020?mc00<0ogX00`3oPP03
0?n:00<0oi400`3oV@030?nQ0080ojP00`3o/0020?nh00<0okl00`3oa`00
0`3oc`00oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<000000?oo
o`3oool00`3oool20?l0a`80o`2o0`3o0;P30?l0/080o`2X0`3o0:430?l0
V@<0o`2A0`3o08X30?l0PP<0o`1j0P3o07<30?l0J`<0o`1S0P3o05`20?l0
E080o`1<0P3o04D20?l0?@030?l0=@3o02h0o`0^0080o`0V00D0o`0N0?l0
5`3o00l0o`0?0?l01`020?l0000T0?l7003o3`00o`l00?lG003o7P00obH0
0?l^003o?@00odD00?m<003oE000oe`00?mS003oL`00ogX00?n2003oRP00
oiT00?nQ003oZ000ok000?no003oa`00oll00?oG003oiP00onh00?oe003o
o@00lol00>_o003So`00g?l00=Co003<o`00aOl00P2mo`020;Go00H0[_l0
0340]Ol00;go0035o`00c?l00=co003[o`00ood00?oe003oc`00okl00?nI
003oNP00od`00?l^0000ok<0o`0G0?l0J`3o0:40o`3N0=`0o`2G0?l0D@3o
00D0o`00?ol009Co003Qo`00om400?n5003o>00Do`00FOl009ko003[o`00
omh00?nI003oJ`00oaL0002co`3o03D0o`1<0?l0PP3o0:P0o`2o0?l0gP3o
0?D0l`3o0>/0o`3D0?l0c03o0080_@3o00<0]@3o0:h0o`2^0?l0102^0?l2
0;D0o`0Z0;d0o`350?l0a@3o0<`0o`3D0?l0g03o0><0o`3[0?l0l`3o0?l0
o@3o0?D0o`3^0?l0iP3o0=L0o`3?0?l0a`3o0;l0o`2`0?l0Z03o0:40o`2I
0?l0RP3o0880o`1j0?l0J`3o06<0o`1L0?l0E03o04`0o`150?l0=@3o02h0
o`0V0?l07P3o01L0o`0?0?l01`3o00000;[o0?l0003o1`00o`l00P3o5`00
103o7P00obH00?lV003o;P020?le0080ocd00P3oA@020?m<0080oe@00P3o
G0030?mS00<0of/00P3oL`030?mj00<0oh800`3oRP030?nA00<0oiT00`3o
X@020?nX00<0ok000P3o^0030?no0080olL01@3oool100000040oooo000V
0?ooo`030000003oool0oooo00<0oooo0P3o0;l30?l0^0<0o`2`0P3o0:P3
0?l0X@<0o`2I0`3o09430?l0RP<0o`220`3o07X30?l0L`<0o`1[0P3o06<2
0?l0G0<0o`1D0P3o04`20?l0A@80o`0m00@0o`0e0?l0;P3o02h0o`0V0P3o
01h20?l05`040?l03`3o00L0o`150?l00080o`L00P3o5`020?lV0080ocD0
0180odD00?m<003oE000oe`00?m[003oL`00ogX00?n2003oT@00oiT00?nX
003o/000okP00?no003oc`00omL00?oV003okP020?om000;0??o003[o`00
g?l00=Co003<o`00aOl00;Go002^o`00Y_l009ko002Go`000P2?o`0708Oo
000S08oo002Go`00W_l00:ko002eo`00c?l00=co003jo`00ooD00?o7003o
/000oh800?mS003o9P00o`000?l0?@3o06/0o`2h0?l0m@2m0?l0L03o02<0
o`00<?l008Go003Io`00om400?me003o8@0So`00Ool00;go003oiP00okP0
0?mS003o?@000P3o02H02`3o06<0o`220?l0/03o0=h0o`3e0>/0o`3L0?l0
a@3o0;D0o`2V0?l0WP3o0080S`3o1P270?l208l0o`80U`3o0P2V0?l20;D0
o`060<D0o`3<0?l0e03o0=`0o`3[0?l0l`3o0P3o0?d04P3o0>h0o`3V0?l0
e`3o0<l0o`2o0?l0^03o0;00o`2X0?l0V@3o0940o`220?l0NP3o07<0o`1[
0?l0G03o05@0o`1<0?l0A@80o`0e00D0o`0V0?l07P3o01L0o`0?0?l01`03
0?l000050?l7003o3`00oaL00?lG003o7P000P3o9P020?l^00030?le003o
?@00ocd00080odD00P3oC0030?mD0080oe`00P3oH`030?m[00<0og<00`3o
NP030?n200<0ohX00`3oT@030?nI0080oj400`3oZ0030?n`0080okP00P3o
_`000`3oa`00oooo0?ooo`030?ooo`4000000@3oool002H0oooo0`000003
0?ooo`030?l0_`3o0;P0o`2h00<0o`2`0P3o0:P30?l0X@<0o`2I0`3o0943
0?l0RP<0o`220`3o07X30?l0L`<0o`1[0P3o06<30?l0G0<0o`1D0P3o04`2
0?l0A@80o`0m00<0o`0e0?l0;P3o02h00P3o02H0<@3o01h0o`0G0?l05`3o
00l0o`070?l0003o0=h0o`000?l7003o3`00oaL00?lN003o9P00obh00?le
003o?@00od`00?mD003oG000of<00?mc003oNP00ohX00?nA003oV@00ojP0
0?n`003o^000olL00?o?003ogP00onH00?oe003oo@00lol00>_o003Lo`00
e?l00<Go002mo`00[_l00:Ko002No`00Sol008Oo001oo`00N?l0073o001X
o`000P1Qo`0505Wo000`067o001Xo`00J?l007So001oo`00Uol00:Ko0035
o`00e?l00?[o003oiP00okP00?nA003oG000oah00?l0003o04`0o`2A0?l0
gP3D0?l0Q`3o03<0o`00:?l007go003Io`00olX00?me003o6@0jo`00Sol0
0=co003oc`00oi400?m5003o0000o`0N0?l0G03o09T0o`2h0?l0kP3[0?l0
e03o0;D0o`2V0?l0S`3o07l0o`1`0?l0J03o0P1Q0?l405T0o`80H@3o0P1X
0?l0:01`0?l0N03o08L0o`270?l0U`3o09h0o`2V0?l0[P3o0;d0o`350?l0
e03o0=`0o`3[0?l0l`3o0?l0o@3o0?D0o`3V0?l0gP3o0<l0o`370?l0^03o
0;00o`2X0?l0V@3o0940o`220?l0NP3o07<0o`1S0?l0G03o05@0o`1<0?l0
?@3o03D0o`0^0?l09P3o01h0o`0G0?l03`3o00L30?l000050?l7003o3`00
oaL00?lG003o7P000P3o9P000`3o;P00ocD00?le00020?lm0080odD00P3o
C0030?mD0080oe`00`3oH`030?m[00<0og<00`3oNP030?n200<0ohX00`3o
T@030?nI0080oj400`3oZ0030?n`0080okP000<0okl00?ooo`3oool00P3o
ool200000040oooo000V0?ooo`030000003oool0oooo00<0oooo00@0o`2h
0?l0/03o0;00o`2`0P3o0:P30?l0X@<0o`2I0`3o09430?l0RP<0o`220`3o
07X30?l0L`<0o`1[0`3o06<30?l0G080o`1D0P3o04`20?l0A@80o`0m0P3o
03D20?l0;P030?l09P3o01h0o`0N0080o`0G00`0o`0?0?l01`3o0000o`1L
0?l0003o1`00o`l00?lG003o7P00obH00?l^003o=@020?m5000O0?mD003o
G000of/00?mc003oNP00oh800?nA003oV@00ojP00?n`003o_`00olL00?oG
003ogP00onh00?om003co`00jol00=co003Do`00aOl00;go002^o`00Y_l0
09Oo002?o`00Ool0073o001Xo`00HOl005Wo000204[o0080>_l00P0co`04
02_o000?03?o000jo`00@_l004[o001Qo`00J?l008Oo002Go`00aOl00=co
003okP00omL00?nA003oJ`00oah00080o`1S00h0o`2Q0?l0o@2^0?l0D@3o
000Ao`00MOl00=Wo003obP00ofH00?l2057o002mo`00ood00?nI0080of<0
00`0o`0m0?l0J`3o0940o`3G0?l0kP3L0?l0[P3o09L0o`1h0?l0J03o0540
o`1:0?l203X0o`0303<0o`0[0?l0:`3o0080:`3o0P0c0?l0;P0j0?l0@P3o
04X0o`1A0?l0F@3o0640o`1X0?l0N03o07l0o`2?0?l0U`3o0:H0o`2^0?l0
_@3o0<D0o`3D0?l0g03o0>/0o`3c0?l0o`3m0?l0kP3o0=h0o`3G0?l0a`3o
0;l0o`2`0?l0Z03o09T0o`2A0?l0PP3o07X0o`1c0?l0J`3o05`0o`1D0?l0
A@3o03d0o`0e0?l0;P3o02H0o`0N0?l05`3o00l0o`070?l0003oG0020?l7
00040?l?003o5`00oah00?lN0080obH00P3o;P020?le0080ocd00P3oA@02
0?m<0080oe@00`3oG0030?mS00<0of/00`3oL`030?mj00<0oh800`3oRP03
0?nA00<0oiT00P3oX@030?nX00<0ok0000<0okP00?ooo`3oool00`3oool1
00000040oooo000V0?ooo`030000003oool0oooo00<0oooo0P3o0;020?l0
Z0<0o`2Q0`3o09T30?l0T@<0o`2:0`3o08830?l0NP@0o`1c0P3o06/40?l0
H`80o`1L0`3o05@20?l0C080o`150P3o03d20?l0=@80o`0^0P3o02H0103o
01h0o`0G0?l05`3o00l20?l01`0[0?l0a`3o0000o`L00?l?003o5`00oah0
0?lV003o;P00ocD00?lm003oA@00od`00?mL003oH`00of/00?mj003oPP00
oi400?nI003oZ000okP00?no003oc`00omL00?oV003okP00n_l00??o003S
o`00g?l00<co002mo`00[_l00:Ko002Go`00Sol007oo001`o`00HOl0057o
001:o`00>_l003?o000202?o000401Co000<o`001Ol000Go00H00?l202`0
3?l001Co000So`00:ol004[o001Io`00Ool009Oo003<o`00lol00?o?003o
V@00oe@00?lG003o03D0o`2:0?l0gP350?l0H@3o0002o`00K_l00=7o003o
`P00oeL03?l0073o003Do`00omL00?mj003o=@00o`0e0?l0E03o0:P0o`3?
0>/0o`3<0?l0U`3o0700o`1I0?l0>P3o02/0o`0L0?l0503o00D0o`H000;o
02X01@3o00`0o`0<0?l0703o02<0o`0[0?l0<`3o0480o`1:0?l0F@3o0640
o`1`0?l0O`3o08l0o`2G0?l0YP3o0:h0o`2m0?l0c03o0=`0o`3S0?l0l`3o
0?l0o@3o0>h0o`3V0?l0e`3o0<l0o`2o0?l0/03o0:P0o`2I0?l0T@3o0880
o`1j0?l0J`3o06<0o`1L0?l0C03o04D0o`0m0?l0=@3o02h20?l07P80o`0?
00@0o`070?l0003o0000o`L00P3o3`000`3o5`00oah00?lN00020?lV0003
0?l^003o=@00ocD00080ocd00`3oA@020?m<00<0oe@00P3oG0040?mS0080
of/0103oL`030?mj00<0oh800`3oRP030?nA00<0oiT00P3oX@030?nX0080
ok001@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo
0P3o0:P30?l0X@<0o`2I0P3o09440?l0RP<0o`220`3o07X40?l0L`80o`1[
103o06<20?l0G0<0o`1D0`3o04`20?l0A@80o`0m0P3o03D20?l0;P80o`0V
00<0o`0N0?l05`3o01L00P3o00l0103o00L0o`000?l0003o1`020?l?0080
oah002T0obh00?le003o?@00odD00?m<003oE000of<00?m[003oNP00oh80
0?nA003oV@00ojP00?n`003o_`00olL00?oN003oiP00ooD00?om003[o`00
hol00=Co0035o`00]Ol00:ko002Go`00Sol007oo001ho`00HOl005Wo001:
o`00<ol002_o000Lo`005?l000Go0000o`800?lA003o6@02003o:003003o
<000ocP00?lh00<00?lh02T00?l`003o:000oaT00?lA00Go000Do`00>_l0
057o0027o`00Y_l00>_o003okP00oi400?mS003o07<0o`0N0?l0Z03c0?l0
Q`3o01`0o`00Eol00=7o003o^P00odL0:ol008oo003oo@00ojP00?lN003o
L`00o`1S0?l0T@3o0>h0j`3o0:H0o`270?l0D@3o02/0o`0D0?l000[o000A
o`02000Xo`H003So02T0033o000Xo`008Ol001Wo000:o`000_l0303o01@0
o`0S0?l0:`3o03X0o`1:0?l0F@3o0640o`1h0?l0O`3o08l0o`2G0?l0[P3o
0;D0o`350?l0e03o0><0o`3[0?l0o`3m0?l0m@3o0>H0o`3N0?l0a`3o0;l0
o`2`0?l0Z03o09T0o`2A0?l0PP3o07X0o`1[0?l0H`3o05@0o`1<0?l0A@02
0?l0=@040?l09P3o01h0o`0G0?l03`80o`0700<0og<00?l0003o1`000P3o
3`000`3o5`00oah00?lN00020?lV0080obh00P3o=@020?lm0080odD00`3o
C0030?mD0080oe`0103oH`020?m[00@0og<00`3oNP030?n200<0ohX00`3o
T@030?nI0080oj400`3oZ0050?ooo`4000000@3oool002H0oooo00<00000
0?ooo`3oool00`3oool30?l0X@<0o`2I0P3o09440?l0RP80o`22103o07X3
0?l0L`<0o`1[103o06<30?l0G0<0o`1D0P3o04`30?l0A@80o`0m0P3o03D2
0?l0;P80o`0V0P3o01h0=@3o01L0o`0?0?l03`3o00L0o`00003oGP3o0000
o`L00?l?003o5`00oah00?lV003o;P00ocD00?lm003oC000oe@00?mL003o
J`00og<00?n2003oRP00oiT00?nQ003o/000okl00?o?003oe`00onH00?oe
003jo`00lol00=co003Do`00_Ol00;Go002No`00Uol008Oo001ho`00J?l0
05Wo001:o`00>_l002_o000Do`003?l0003o2P00oa400?lQ003o:000ocl0
0?m700800?mG0P00ofH01000ofh00?me003oM@00ogD2003oKP0Y003oGP00
oeL00?lo003o<000o`X01Ol003[o001Qo`00W_l00=Co003ogP00oi400?lN
003<0?l0o`220?l0kP2N0?l0:`3o001?o`00b_l00?nj003o?`0jo`00[_l0
0?oN003oNP000?nL0?l0C03o0:40o`3N0<`0o`2N0?l0F@3o03X0o`050?l0
027o000`o`00Col005Oo001Vo`00K_l01000MOl0=@00K_l006Ko001No`00
Eol004oo0017o`00>?l002So000Io`004Ol01@3o00`0o`0L0?l0:`3o03X0
o`1:0?l0F@3o06P0o`1h0?l0Q`3o09L0o`2V0?l0]@3o0<D0o`3D0?l0h`3o
0?<0o`3j0?l0o`3e0?l0iP3o0=L0o`370?l0^03o0;00o`2Q0?l0T@3o08X0
o`1j0?l0L`3o06<0o`1L0?l0E03o04D0o`0m0?l0=@3o02h0o`0V0?l07P3o
01L0o`0?0?l01`3o00000?mN0080o`L000<0o`l00?lG003o5`000P3o7P00
0`3o9P00obh00?l^00030?le0080ocd00`3oA@020?m<00<0oe@00`3oG004
0?mS00<0of/00`3oL`040?mj0080oh800`3oRP030?nA00<0oiT00P3oX@00
0`3oZ000oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<000000?oo
o`3oool00`3oool0103o0:40o`2I0?l0V@3o09T20?l0T@<0o`2:0`3o0884
0?l0NP<0o`1c0`3o06/40?l0H`<0o`1L0`3o05@30?l0C0<0o`150P3o03d2
0?l0=@80o`0^0P3o02H20?l07P0h0?l05`3o00l0o`0?0?l01`3o0000o`2:
0?l0003o1`00o`l00?lG003o7P00obH00?l^003o=@00ocd00?m5003oC000
oe`00?mS003oL`00ogX00?n:003oT@00oj400?nX003o_`00olL00?oG003o
iP00ooD00?om003[o`00hol00<co0035o`00[_l00:Ko002?o`00Ool0073o
001Qo`00B_l004;o000[o`008ol000co0000o`X00?lA003o:000ocP00?m7
003oE`00ofH00?m^003oQ@00oh`2003oW0800?n[1000ok<0:000oj/00?nS
003oS000ogd00?mN003oA`00oa403?l0057o001ho`00e?l00?oe003oPP00
ocd00?l09P3o0;00e03o0540o`00>?l00<;o003o/`00obP0HOl00=Co003o
V@00obH00?l0J`3o0880o`3e0=@0o`1h0?l0D@3o00`0o`004Ol004Oo001^
o`00OOl009co002So`00Zol4002co`0^002[o`00Xol009co002Do`00S?l0
07go001^o`00G_l005Oo000oo`00>?l0027o000Ao`050?l0303o02<0o`0[
0?l0@P3o04X0o`1Q0?l0L03o07l0o`2?0?l0YP3o0:h0o`350?l0c03o0><0
o`3[0?l0o`3m0?l0m@3o0>H0o`3G0?l0a`3o0;P0o`2X0?l0X@3o0940o`2:
0?l0NP3o07<0o`1S0?l0G03o04`0o`150?l0?@80o`0^0P3o01h20?l03`03
0?l01`3o0000o`000080o`L000<0o`l00?lG003o5`000P3o7P020?lV0080
obh00P3o=@020?lm00<0odD00`3oC0030?mD00<0oe`0103oH`030?m[00<0
og<0103oNP030?n20080ohX00`3oT@030?nI00030?nQ003oool0oooo00<0
oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`040?l0
V@3o0940o`2A0?l0T@<0o`2:0`3o08830?l0NP<0o`1c103o06/40?l0H`<0
o`1L0`3o05@40?l0C080o`150`3o03d20?l0=@80o`0^0P3o02H20?l07P80
o`0G00<0o`0?0?l01`3o00L00`3o0000<`3o1`00o`l00?lG003o7P00obH0
0?l^003o=@00ocd00?m<003oE000oe`00?m[003oL`00oh800?n:003oV@00
ojP00?nh003oa`00oll00?oN003okP00ood00??o003Lo`00e?l00;go002^
o`00W_l008oo001ho`00L?l005Wo001:o`00<ol002_o000Do`001Ol0003o
4@00ob400?lh003oA`00oeL00?m^003oO@00oi@00?nL003o/`00okX00?oA
003of@02003oj0D00?oh02H00?o`003oh@00om400?nc003oX`00ofh00?m?
003o2P0[o`00Ool00<co003oc`00of<0003o>03o05`0l`3o0640o`00<?l0
0<;o003oZ`00oaT0N?l00?om003oE00003So0?l0L`3o0<l0a@3o07l0o`0S
0?l000[o001?o`00K_l00:?o0032o`00dOl00>So003`o`@00?So03X00?3o
003Xo`00hOl00=Wo0032o`00^_l00:_o002Lo`00QOl007go001Vo`00Eol0
03oo000`o`006Ol0017o00D0o`0D0?l0:`3o03X0o`1:0?l0F@3o0700o`1o
0?l0S`3o09h0o`2^0?l0a@3o0=@0o`3S0?l0l`3o0?l0o@3o0>h0o`3N0?l0
c`3o0;l0o`2`0?l0Z03o09T0o`2:0?l0PP3o07<0o`1[0?l0G03o05@0o`15
0?l0?@3o03D0o`0^0?l09P3o01h0o`0G0?l03`3o00L0o`00000oo`3o0000
o`L00P3o3`020?lG00030?lN003o9P00obH000<0obh00P3o=@030?lm0080
odD0103oC0030?mD00<0oe`0103oH`040?m[00<0og<00`3oNP030?n200<0
ohX00`3oT@000`3oV@00oooo0?ooo`030?ooo`4000000@3oool002H0oooo
00<000000?ooo`3oool00`3oool20?l0T@80o`2:103o08820?l0NP@0o`1c
103o06/30?l0H`@0o`1L0`3o05@40?l0C0<0o`150`3o03d20?l0=@80o`0^
0P3o02H20?l07P80o`0G0P3o00l0?03o00L0o`000?l0Z03o0000o`L00?l?
003o5`00oah00?lV003o;P00ocD00?lm003oA@00od`00?mL003oH`00og<0
0?mj003oRP00oiT00?nQ003o/000okl00?o?003ogP00onh00?om003[o`00
hol00<co0035o`00[_l009ko0027o`00Ool006So001Io`00@_l003?o000L
o`005?l0003o2P00oa400?l`003oA`00oeL00?m^003oO@00oi@00?nS003o
^P00olX00?oQ003ol000n?l00?3o003Io`00dOl00<[o0032o`@00;[o02@0
0<[o003Ao`00l?l00?oo003od@00ok<00?m^003o?`0So`00FOl00=co003o
c`00ocD00?l0_`3o0<L0U`3o000Ao`00^_l00?nL00Go002^o`00olL00?no
003o06/0o`3N0=`0o`1I0?l08`3o000oo`00K_l00;?o003Ao`00ool00?oQ
003od@00ol84003o^P0`003o`P00olX00?oA003oj000oo000?So003`o`00
fOl00<[o002co`00Xol008co001mo`00G_l005Oo000ho`00<?l0017o000:
o`0D0?l0703o03<0o`120?l0F@3o06P0o`1o0?l0Q`3o09h0o`2^0?l0a@3o
0<`0o`3S0?l0l`3o0?l0o@3o0>h0o`3N0?l0c`3o0;l0o`2`0?l0X@3o0940
o`2:0?l0NP3o06/0o`1S0?l0G03o04`0o`150P3o03D0103o02H0o`0N0?l0
5`3o01L20?l01`040?l0003oZ000o`L00?l70080o`l00P3o5`020?lN0080
obH00P3o;P020?le00<0ocd00`3oA@040?m<00<0oe@0103oG0030?mS00@0
of/00`3oL`030?mj00<0oh800`3oRP020?nA00D0oooo0@0000010?ooo`00
9P3oool00`000000oooo0?ooo`030?ooo`80o`2:0`3o08830?l0NP@0o`1c
0`3o06/40?l0H`<0o`1L103o05@40?l0C0<0o`150`3o03d30?l0=@80o`0^
0`3o02H20?l07P030?l05`3o00l0o`0?0080o`0703`0o`00003oA`3o0000
o`L00?l?003o5`00oah00?lV003o;P00ocD00?lm003oA@00oe@00?mL003o
J`00og<00?n2003oRP00oiT00?nX003o^000olL00?oG003oiP00ooD00?[o
003So`00e?l00<Go002eo`00W_l008oo001ho`00J?l0057o001:o`00<ol0
02?o0005o`000?l:003o8@00oc000?m7003oGP00ogD00?n<003oX`00okX0
0?o:003oj000ooP00>So003Io`00`_l00;?o002Lo`00U?l007go001eo`00
K_l3001Vo`0S001^o`00MOl008co002Lo`00`_l00>7o003of@00oj<00?m7
00Go001ho`00jol00?m5003o0?d0o`2Q0;D0o`050?l00;?o003oU00Lo`00
c?l00?nA0000oeL0o`2:0=`0o`1h0?l000[o0017o`00/ol00=Wo003oh@00
ol800?nL003oO@00ogD01000ofH0?000ofh00?me003oS000oi@00?n[003o
/`00om400?oI003on000n?l00=Wo003:o`00/ol009co0025o`00MOl005Oo
0017o`00<?l0027o000:o`0<0?l08`3o03<0o`1:0?l0F@3o06P0o`1o0?l0
S`3o0:H0o`2e0?l0a@3o0=`0o`3[0?l0nP3o0?l0m@3o0>H0o`3G0?l0a`3o
0;P0o`2X0?l0V@3o08X0o`1j0?l0L`3o06<0o`1L0?l0C03o04D0o`0m0?l0
=@3o02h0o`0V0?l07P3o01L0o`0?0?l01`3o00000?lh0?l00080o`L000<0
o`l00?lG003o5`000P3o7P020?lV00<0obh00`3o=@030?lm00<0odD0103o
C0040?mD00<0oe`0103oH`030?m[00<0og<0103oNP020?n200<0ohX01@3o
ool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo0P3o0884
0?l0NP<0o`1c0`3o06/40?l0H`@0o`1L103o05@40?l0C0<0o`150`3o03d4
0?l0=@80o`0^0P3o02H30?l07P80o`0G00L0o`0?0?l01`3o00L0o`000?l0
RP3o0000o`L00080o`l003P0oaL00?lN003o9P00obh00?le003oA@00od`0
0?mD003oH`00of/00?mj003oPP00oi400?nQ003o/000okl00?o?003ogP00
onh00?[o003[o`00e?l00<co002eo`00Y_l008oo001oo`00J?l005Wo0012
o`00<ol001Co000<o`000?lA003o8@00ocP00?m7003oIP00ohD00?nD003o
/`00ol800?oX003on000j?l00=Wo002jo`00Zol008co001mo`00G_l004oo
000ho`00:?l001Wo000Ao`@000[o020001Wo000Xo`00Col006Ko002[o`00
fOl00?o2003oQ@05o`00HOl00?o^003oC000o`0V0?<0o`0[0?l00:?o003o
Q@12o`00onh00?lV003o04`0o`3^05T0o`050?l008Go0032o`00omT00?n[
003oIP00odl00?lX003o4@@00?l:03T00?lA003o8@00obP00?lo003oC`00
ofh00?mm003oW000oj/00?o:003of@00ooP00?So003Ao`00`_l00:?o002D
o`00MOl006Ko0017o`00>?l0027o000Ao`0<0?l0503o03<0o`120?l0F@3o
06P0o`1o0?l0S`3o0:H0o`2e0?l0c03o0=`0o`3[0?l0o`3m0?l0kP3o0=h0
o`3?0?l0_`3o0;00o`2Q0?l0T@3o0880o`1c0?l0J`3o05`0o`1D0?l0C03o
03d0o`0e0?l0;P3o02H0o`0N0?l05`3o00l00P3o00L30?l000030?l7003o
3`00o`l00080oaL00`3o7P020?lV0080obh0103o=@030?lm00<0odD0103o
C0040?mD00@0oe`0103oH`030?m[00<0og<00`3oNP030?n200D0oooo0@00
00010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`<0o`1j0`3o07<4
0?l0J`@0o`1S103o05`40?l0E0@0o`1<103o04D30?l0?@<0o`0e0`3o02h3
0?l09P80o`0N0P3o01L20?l03`80o`070`3o0000>`3o1`00o`l00?lG003o
5`00oah00?lV003o;P00ocd00?m5003oC000oe@00?mS003oJ`00ogX00?n:
003oV@00oj400?n`003oa`00omL00?oV003om@00lol00>?o003<o`00_Ol0
0:Ko002Go`00Ool0073o001Io`00B_l003?o000Lo`001Ol0003o2P00ob40
0?lh003oC`00ofH00?n5003oW000ok<00?oA003oj000n?l00>7o0032o`00
Zol008co001eo`00Col003oo000Io`002_l0503o02<0o`0j0?l0BP3o0080
F@3o0P1Q0?l07`1I0?l0D@3o02/0o`0D0?l002So001?o`00/ol00?oh003o
M@0<o`00Y_l00?nX0000o`80o`2h0480o`00Xol00?mm067o003oPP0000;o
0?l0_`2N0?l000[o001eo`00ooP00?nc003oC`00obP05?l002_o001Ao`00
0`1Qo`00>P1Io`00DOl004[o000co`008ol000Go0000o`X00?lX003o?`00
oeh00?me003oW000oj/00?oA003oh@00n?l00>7o0032o`00/ol009Co001m
o`00I_l004oo000ho`008Ol000[o00`0o`0L0?l0<`3o04X0o`1I0?l0L03o
08L0o`2G0?l0[P3o0;d0o`3D0?l0h`3o0?X0o`3o0?D0o`3V0?l0c`3o0;l0
o`2`0?l0X@3o0940o`220?l0NP3o06/0o`1S0?l0E03o04`0o`150?l0=@3o
02h0o`0V0?l07P3o01L20?l03`040?l01`3o000000;o0?l00080o`L00P3o
3`020?lG0080oah00`3o9P030?l^00<0ocD00`3o?@040?m500@0od`0103o
E0040?mL00@0of<00`3oJ`040?mc00<0ogX01@3oool100000040oooo000V
0?ooo`030000003oool0oooo00<0oooo0`3o07<40?l0J`<0o`1S103o05`5
0?l0E0@0o`1<103o04D40?l0?@<0o`0e103o02h20?l09P<0o`0N0P3o01L2
0?l03`80o`070`3o00020?l7000l0?l?003o5`00oah00?lV003o;P00ocD0
0?lm003oA@00od`00?mL003oH`00og<00?mj003oRP00oiT00?nX003o^000
olL00?oN003okP00ood00>_o003Lo`00aOl00:ko002Go`00Qol0073o001Q
o`00@_l003?o000Lo`003?l0003o4@00ob400?lo003oC`00ofh00?mm003o
W000ol800?oA003on000l?l00<[o002jo`00U?l007go001Go`00?ol0017o
0002o`0[0?l0>P3o0640o`1`0?l0U`3o0:H0o`2m0?l0a@3o0`3D0?l07P3<
0?l0]@3o0:H0o`1`0?l0BP3o000Io`00G_l00?3o003o/`0So`00_Ol0003o
C`3o05`0N03o002<o`00ofH0Uol00?l7003c0?l0WP3o02<0o`00/ol00?o`
003oGP00oaT0B_l0073o002Vo`00]Ol00<co0080e?l003T0c?l00<Go002^
o`00Y_l008Oo001`o`00DOl003[o000Do`000?l2003o:000ocl00?mV003o
O@00oj<00?nj003oh@00oo000>So003Ao`00/ol009co001mo`00K_l004oo
000oo`008Ol0017o00`0o`0L0?l0<`3o04X0o`1Q0?l0L03o08L0o`2N0?l0
[P3o0<D0o`3L0?l0j`3o0?l0o@3o0>h0o`3G0?l0a`3o0;P0o`2X0?l0V@3o
08X0o`1j0?l0L`3o06<0o`1D0?l0C03o04D0o`0m0?l0=@3o02h00P3o01h0
1@3o01L0o`0?0?l01`3o00L0o`2`0080o`0000<0o`L00?l?003o3`000`3o
5`030?lN0080obH0103o;P030?le00@0ocd0103oA@040?m<00D0oe@00`3o
G0040?mS00@0of/00P3oL`000`3oNP00oooo0?ooo`030?ooo`4000000@3o
ool002H0oooo00<000000?ooo`3oool00`3oool40?l0J`<0o`1S1@3o05`4
0?l0E0@0o`1<103o04D50?l0?@@0o`0e0`3o02h40?l09P80o`0N0`3o01L2
0?l03`80o`0700<0o`00003oGP3o00000P3o1`00?P3o3`00oaL00?lN003o
9P00obh00?le003o?@00odD00?m<003oG000of<00?mc003oPP00ohX00?nI
003oZ000okl00?o?003ogP00ooD00?[o003So`00c?l00;go002Vo`00Sol0
07So001Qo`00DOl003[o000So`003?l0003o2P00ob400?l`003oC`00ofH0
0?n5003oU000ok<00?oA003ol000l?l00=7o002co`00U?l006ko001?o`00
:?l000[o01`0o`0j0?l0J03o07l0o`2^0?l0a@3o0?<0o`3o0?d0o`3G0?l0
a`3o0;00o`2X0P3o0:407@3o0;00o`2o0?l0kP3c0?l0S`3o0480o`00Aol0
0=Wo003oKP1Qo`00oiT00=@0o`2N0?l008Go003oE`35o`000?m^0?l0iP12
0?l007Go003o^P00odL0DOl008oo003co`00onh00?no003o/000oj400080
ojP003d0okP00?o7003oiP00ood00=co0035o`00Uol007oo001Ao`00>_l0
00co0000o`X00?lh003oE`00ogd00?nD003o^P00omT00?oh003Xo`00b_l0
0;?o002Do`00OOl006Ko001?o`00<?l001Wo000:o`0<0?l08`3o03X0o`1A
0?l0J03o07l0o`2?0?l0YP3o0;d0o`3D0?l0h`3o0?X0o`3o0>h0o`3N0?l0
c`3o0;P0o`2X0?l0V@3o08X0o`1j0?l0L`3o06<0o`1L0?l0C03o04D0o`0m
0?l0=@3o02h0o`0V0?l07P3o01L0o`0?0080o`0700<0o`00003o6@3o0000
0P3o1`020?l?00<0oaL00P3o7P040?lV00<0obh0103o=@050?lm00@0odD0
103oC0040?mD00D0oe`00`3oH`030?m[00030?mc003oool0oooo00<0oooo
0@0000010?ooo`009P3oool3000000<0oooo103o06<40?l0G0@0o`1D1@3o
04`50?l0A@@0o`0m1@3o03D40?l0;P<0o`0V0`3o01h30?l05`80o`0?0P3o
00L01@3o0000o`1c0?l0003o0000o`L00080o`l00440oaL00?lN003o9P00
obh00?le003o?@00odD00?m<003oG000of<00?mc003oPP00oi400?nQ003o
/000okl00?oG003oiP00ood00??o003Lo`00aOl00:ko002Go`00Ool0073o
001Ao`00@_l002?o000Do`000?l:003o6@00ocP00?m7003oIP00ogd00?nL
003oZ`00om400?oh003`o`00b_l00:_o0025o`00K_l003So000Qo`0D0?l0
:`3o0640o`1h0?l0[P3o0<`0o`3o0?d0o`3V0?l0/03o09T0o`150?l09P3[
0?l0c03o0>/0o`3c0?l0j`3o0=`0o`020:h0o`0D0?l0PP3o0;P0N03o01@0
o`00fOl00?me0:ko003oRP00o`3^001^o`00ocP0onh00?l0gP2^0?l009Co
003of@0Do`00N?l00?nh003oPP020:ko00110=co003[o`00lol00=co003<
o`00oaL00?lV003oPP00oiT00?o7003oiP00hol00<co002Go`00N?l004;o
000[o`000?l:003o8@00odl00?m^003oW000oj/00?oI003ol000j?l00=7o
002[o`00W?l007go001Vo`00Aol003So000Io`002_l0503o02<0o`120?l0
D@3o0700o`1o0?l0U`3o0:h0o`350?l0g03o0?<0o`3o0?D0o`3V0?l0c`3o
0;l0o`2X0?l0V@3o08X0o`1j0?l0L`3o06<0o`1L0?l0C03o04D0o`0m0?l0
=@3o02h0o`0V0?l07P3o01L00P3o00l00`3o00L0o`000?l000020?l00080
o`L00P3o3`030?lG00<0oah00`3o9P040?l^00D0ocD0103o?@050?m500D0
od`00`3oE0040?mL00@0of<000<0of/00?ooo`3oool00P3oool200000040
oooo000V0?ooo`030000003oool0oooo00<0oooo00@0o`1S0?l0G03o05`0
o`1L1@3o05@50?l0C0@0o`151P3o03d40?l0=@D0o`0^103o02H30?l07P<0
o`0G0`3o00l20?l01`050?l0003o07<0o`000?l0003o1`000P3o3`00?`3o
5`00oah00?lV003o;P00ocD00?lm003oA@00od`00?mL003oH`00og<00?n2
003oT@00oj400?n`003o_`00omL00?oV003oo@00jol00=Co002mo`00Y_l0
08oo001ho`00HOl004[o000co`005?l000Go0000oaT00?lX003oA`00oeh0
0?me003oS000oj/00?o2003oj000n?l00=Wo002co`00U?l006ko0017o`00
8Ol01@3o03<0o`1Q0?l0Q`3o0;D0o`3S0?l0o`3^0?l0^03o0940o`1L0?l0
9P3o0?D0>_l00?m[003o7P00ocd00?m<00020?mD000H0?lm003oPP00B_l0
0<D0o`3o08X0c03o0002o`00ool0:ol00?mS003o09T005ko003o8@3oV@00
o`1S00`0o`00omT00?l20>_o003oL`000?n[04X0o`3o0:40o`0m0P3o05@0
?`3o04`0o`0^0?l07P0L0?l0>P3o0?l0003o;P00og<00?nA003oc`00onh0
0=Co002^o`00N?l005Wo000So`001Ol0003o:000odl00?me003oW000okX0
0?oQ003oo`00hOl00<;o002[o`00S?l007Go001No`00?ol002So000Ao`05
0?l0703o03<0o`1:0?l0H@3o07P0o`2?0?l0YP3o0;d0o`3D0?l0j`3o0?l0
o@3o0>H0o`3?0?l0_`3o0;00o`2I0?l0RP3o07X0o`1c0?l0H`3o05`0o`1<
0?l0A@3o03d0o`0e0?l0;P3o02H0o`0N0?l05`020?l03`030?l01`3o0000
o`000080o`000P3o1`030?l?00<0oaL00`3o7P040?lV00D0obh0103o=@06
0?lm00@0odD01@3oC0040?mD00@0oe`000<0of<00?ooo`3oool00`3oool1
00000040oooo000V0?ooo`030000003oool0oooo00<0oooo00<0o`1L0?l0
E03o05@00P3o05@50?l0C0D0o`151@3o03d60?l0=@@0o`0^1@3o02H40?l0
7P<0o`0G0`3o00l20?l01`@0o`000P3o1`020?l?002J0?lG003o7P00obH0
0?l^003o=@00ocd00?m5003oC000oe`00?mS003oL`00oh800?n:003oX@00
ok000?no003oe`00onh00?[o003So`00c?l00;Go002Go`00Ool0067o001A
o`00<ol002?o0005o`000?lA003o<000ocl00?mN003oKP00oi@00?nS003o
bP00omT00?So003Io`00^_l009Co001^o`00?ol0027o01@0o`0c0?l0L03o
08l0o`3D0?l0l`3o0?l0a`3o0:P0o`1L0?l03`3<0?l0of<00?mc003oV@00
omL00?oe003Do`00_Ol009ko002Go`00W_l00:Ko003Lo`00onh00?nI001X
0?l0o`3G0480o`00okX0Y_l00:h0o`004Ol0J?l00:ko001Q0?l00;[o057o
003oe`00J?l00?l0o@3o0>h0g03o0:H0o`2N0?l0U`3o09h0o`2m0?l0j`3o
0?l0m@3o0;P0o`2I0?l0A@3o03d0c?l00?l?003oPP00ojP00?o^003co`00
]Ol008oo001Ao`00<ol0003o0P00ob400?mG003oKP00oj<00?nj003oj000
ool00=Wo0032o`00Xol008co001^o`00Eol003oo000Xo`004Ol01@3o02<0
o`0c0?l0D@3o06P0o`1o0?l0WP3o0;D0o`3<0?l0h`3o0?l0o@3o0>h0o`3G
0?l0_`3o0;00o`2I0?l0RP3o07X0o`1c0?l0H`3o05@0o`1<0?l0A@3o03d0
o`0e0?l0;P3o02H0o`0N0?l05`80o`0?0P3o00L0103o0000hol00?l0003o
00020?l700<0o`l00`3o5`040?lN00D0obH0103o;P060?le00D0ocd01@3o
A@050?m<00@0oe@000<0oe`00?ooo`3oool00`3oool100000040oooo000V
0?ooo`030000003oool0oooo00<0oooo00<0o`1D0?l0C03o04`00`3o04`5
0?l0A@D0o`0m1P3o03D60?l0;PD0o`0V103o01h40?l05`<0o`0?0`3o00L4
0?l00080o`L00P3o3`00@@3o5`00oah00?lV003o;P00ocD00?lm003oA@00
od`00?mD003oH`00og<00?mj003oRP00oiT00?n`003o_`00omL00?o^003j
o`00g?l00<Go002^o`00Sol007So001Io`00@_l002_o000Do`000?l:003o
8@00ocP00?m?003oIP00ogd00?nL003o/`00om400?o`003`o`00b_l00:?o
001mo`00Eol0033o0002o`0[0?l0F@3o08l0o`2m0?l0l`3o0?l0e`3o09T0
o`1S0?l00000oaT0ocd00?nA003ogP00jol009ko001Xo`008ol0003o0P00
ocP00?m700800?mG01@00?lh003o4@1Xo`00onh0003o0P3o0<L006Ko02?o
0000o`801@3o08Oo003o0>H002So003oA`3oJ`00>P3o0?l0kP1X0?l0017o
000ho`8005Oo03d004Oo000ho`000_l0@P3o06P0o`2m0?l0j`3o0?l0_`3o
08X0o`0V003oKP3o;P00of/00?nX003ogP00hol00;Go001oo`00DOl002?o
0000o`X00?lh003oGP00ohD00?n[003od@00oo000?3o003Ao`00/ol009co
001mo`00I_l004oo000ho`006Ol000;o01@0o`0[0?l0@P3o0640o`1h0?l0
U`3o0:h0o`3<0?l0h`3o0?X0o`3o0>h0o`3G0?l0_`3o0:P0o`2I0?l0RP3o
07X0o`1[0?l0H`3o05@0o`1<0?l0A@3o03D0o`0^0080o`0V00@0o`0N0?l0
5`3o00l0o`0?0P3o00L0103o0000o`370?l0003o00030?l700<0o`l0103o
5`040?lN00D0obH01P3o;P060?le00D0ocd01@3oA@050?m<00030?mD003o
ool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`03
0?ooo`80o`1<103o04D60?l0?@H0o`0e1P3o02h60?l09PH0o`0N103o01L3
0?l03`<0o`071@3o00020?l70080o`l009L0oaL00?lN003o7P00obH00?l^
003o=@00ocd00?m5003oE000oe`00?m[003oNP00ohX00?nI003oZ000okl0
0?oG003okP00lol00=co002mo`00W_l007oo001Xo`00B_l003?o000Do`00
0?l2003o8@00oc000?m?003oGP00ogd00?nD003o/`00olX00?oX003oo`00
dOl00;?o002<o`00G_l003So000:o`0S0?l0F@3o08L0o`350?l0l`3o0?l0
a`3o09T0o`150:h0o`3o;P00of<00?o7003oo@00W_l006So0005o`000?l`
003oU000ol800>7o0032o`00U?l008Go002<o`00Xol00?oh003oX`1Xo`00
oll00?l0e`00`_l00?oI04X0o`3So`00:`3o003oKP3oe`00BP3o06P0o`00
Xol00?So003oX`00oh`00?n5003oU000ol800?oQ0032o`00I_l0033o03X0
o`1X0?l0e03o0?l0o@3o09T0o`1S0?l0002^o`00og<00?nI003oiP00lol0
0:ko0027o`00@_l002?o0000oaT00?lo003oKP00oh`00?nj003of@00ool0
0>So003:o`00Zol009Co001mo`00G_l004oo000`o`006Ol000;o01@0o`0c
0?l0BP3o06P0o`270?l0YP3o0<D0o`3L0?l0nP3o0?l0kP3o0=L0o`2o0?l0
Z03o09T0o`2:0?l0L`3o06/0o`1L0?l0E03o04D0o`0m0?l0=@3o02h0o`0V
0080o`0N00<0o`0G0?l03`3o00l00P3o00L00`3o0000o`370?l000020?l0
0080o`L0103o3`040?lG00H0oah01P3o9P060?l^00H0ocD01@3o?@050?m5
0080od`01@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0
oooo0P3o04D50?l0?@L0o`0e1P3o02h70?l09PH0o`0N1@3o01L40?l03`@0
o`070P3o00000`00ohD0o`000?l000020?l70080o`l004<0oaL00?lN003o
7P00obH00?l^003o=@00ocd00?m5003oC000oe`00?mS003oL`00oh800?nA
003oZ000okl00?oG003okP00lol00=Co002mo`00Uol007So001Io`00@_l0
02?o0005o`000?lA003o:000ocl00?mG003oKP00oh`00?nS003o^P00omT0
0?oh003`o`00b_l00:?o001mo`00Eol002So00`0o`0j0?l0L03o0:H0o`3L
0?l0o`3V0?l0Z03o06/0o`07003o?`3oH`00ok000?[o002Vo`00B_l0003o
4@00ogD00?oA0032o`00K_l01@3o0480o`2N0?l0_@3o0080o`3V0100h`3o
0640o`00Xol00?lh003oE`1:0?l0W_l0001Vo`00Xol0BP3o0=co00004Ol0
06ko003oX`1ho`00jol00P3oiP00@@2mo`00W_l004;o0000o`X00?m^003o
l000b_l004oo000:o`1X0?l0[P3o0?l0kP3o0:P0o`15003oA`3o=@00og<0
0?nh003okP00e?l009ko001Xo`00<ol000Go0000oc000?mG003oQ@00oj/0
0?oA003ol000l?l00=7o002jo`00W?l008Go001^o`00Eol003oo000Xo`00
2_l0303o02<0o`120?l0H@3o07l0o`2N0?l0_@3o0=`0o`3j0?l0o`3^0?l0
c`3o0;P0o`2X0?l0T@3o0880o`1c0?l0H`3o05`0o`1<0?l0A@3o03d0o`0e
0?l0;P3o02H0o`0N0080o`0G0P3o00l20?l01`80o`0000<01Ol00?l0003o
00000`3o1`050?l?00D0oaL01P3o7P070?lV00H0obh01`3o=@050?lm0080
odD01@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo
0P3o03d60?l0=@L0o`0^203o02H70?l07PH0o`0G1@3o00l40?l01`<0o`00
00<00?n50?l0003o00000P3o1`020?l?0080oaL004l0oah00?lV003o9P00
obh00?le003o?@00od`00?mD003oH`00of/00?mj003oRP00oj400?nh003o
c`00onh00?[o003Do`00]Ol008oo001Xo`00DOl002_o000Do`000?lA003o
8@00ocl00?m?003oKP00ogd00?nL003o/`00om400?oQ003ho`00hOl00;[o
002Do`00I_l003So000:o`0[0?l0H@3o09L0o`3D0?l0o`3^0?l0^03o07<0
o`0G0?m5003oG000okP00?[o002?o`00@_l0003o?`00oh`00=Wo002<o`0<
0?l0H@3o0?l0a`3o07<0@P3o08L0o`3o;P00ocd00?l^002mo`0008Go0700
o`00oi`0ok00003`o`0L0?l00?n[003oj000?ol009co00800?n504<0O`3o
0?l0;P3o03d0o`0^08Oo0012o`00og<00?oG001Qo`000?lo003oS000fOl0
08co0002o`120?l0_@3o0?X0o`3o0940o`1L0:Ko003o5`00ohX00?nh003j
o`00c?l008Oo001Io`007?l0003o4@00odL00?m^003oW000okX00?oQ003o
o`00hOl00<[o002co`00W?l007go001^o`00Col003oo000Qo`002_l0503o
02/0o`1A0?l0L03o09L0o`2e0?l0g03o0?X0o`3o0>H0o`3?0?l0/03o0:40
o`2:0?l0NP3o06/0o`1S0?l0E03o04D0o`0m0?l0=@3o02h0o`0V0080o`0N
00<0o`0G0?l03`3o00l00`3o00L20?l0000400Go003o0000o`000?l000<0
o`L01P3o3`060?lG00L0oah0203o9P070?l^00H0ocD00P3o?@050?ooo`40
00000@3oool002H0oooo00<000000?ooo`3oool00`3oool20?l0=@L0o`0^
2@3o02H80?l07PP0o`0G1P3o00l50?l01`<0o`0000<00?n50?l0003o0000
0`3o1`020?l?00140?lG003o7P00oah00?lV003o;P00ocD00?lm003oA@00
od`00?mL003oH`00og<00?n2003oV@00ok000?o7003oiP00n_l00=Co002^
o`00Qol0067o0012o`007?l0003o0P00oaT00?lh003oC`00ofH00?mm003o
U000oj/00?nj003of@00oo000?3o003Ao`00/ol008co001No`00<?l01@3o
03X0o`1`0?l0[P3o0>/0o`3o0=L0o`2I0?l0?@00oc00ocD00?n:003oiP00
_Ol005Wo0000oa400?n5003oo`00OOl0303o09h0o`3o0<l0O`3o09ko003o
m@00Y_l0003oA`00ohD2003o^P0<003o0P35o`00o`1<003o0P0c0?l0N03o
003o:03[o`0006ko0?m<00006Ol000;o0P00^_l0@P00QOl003oo0:H0o`3o
0?D0WP3o0?m<003ogP00J?l0003o2P00oj<00>So001Vo`000_l0L03o0<`0
o`3o0<l0o`1j0?l03`00oeL0of<00?nQ003oiP00g?l00:Ko001Xo`00<ol0
003o0P00ocP00?mV003oU000ok<00?oI003on000l?l00=7o002jo`00Xol0
08co001eo`00I_l004oo000`o`006Ol01@3o02<0o`120?l0J03o08l0o`2e
0?l0g03o0?X0o`3o0=h0o`370?l0Z03o09T0o`220?l0L`3o06<0o`1L0?l0
C03o04D0o`0m0?l0=@3o02h0o`0V0?l07P80o`0G0P3o00l30?l01`80o`00
00@01Ol00?l0003o0000o`001@3o1`060?l?00P0oaL0203o7P090?lV00H0
obh00`3o=@050?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool0
0`3oool20?l0;PP0o`0V2P3o01h:0?l05`P0o`0?1@3o00L50?l00004003o
Q@3o0000o`000?l00080o`L00`3o3`020?lG002=0?lN003o9P00obh00?le
003o?@00odD00?m<003oE000of/00?mc003oRP00oj400?nh003oe`00ood0
0=co002^o`00Ool0057o000[o`001Ol0003o4@00ocP00?m7003oIP00ogD0
0?nD003oX`00okX00?o:003oj000ooP00>So003:o`00Zol008Go001Go`00
8Ol0503o0540o`2?0?l0e03o0?l0kP3o0;00o`1[0?l0^03o=@00og<00?o7
003Do`00L?l0003o0P00ofh00?oo002<o`0L0?l0WP3o0?l0E0270?l0onh0
08Oo0000oi@00>7o07P0o`3c0?l004oo0002o`00Aol00?o`003ho`3jo`00
03oo0?l0RP3oRP000?nS003obP00ooP00?3o003oA`00o`800?m?0??o001h
o`000?oQ002Do`270?l0o`3G08Oo003om@00W_l0003o<000oh`00<;o001V
o`0[0?l0N03o0?<0o`3o0;l0o`1D0?l05`3o?@00og<00?no003om@00aOl0
08Oo001:o`003?l0003o:000oeh00?n<003oZ`00om400?o`003ho`00hOl0
0<[o002jo`00Xol009Co001eo`00I_l004Oo000ho`004Ol01@3o02/0o`1I
0?l0Q`3o0;D0o`3L0?l0o`3m0?l0e`3o0;P0o`2I0?l0RP3o07<0o`1[0?l0
E03o04`0o`150080o`0e0P3o02H00`3o01h0o`0G0?l05`020?l03`<0o`07
0`3o00000`05o`00o`000?l000020?l000H0o`L0203o3`0:0?lG00T0oah0
203o9P030?l^00D0oooo0@0000010?ooo`009P3oool00`000000oooo0?oo
o`030?ooo`80o`0V2`3o01h<0?l05`X0o`0?203o00L40?l000030?l0E03o
0000o`000080o`000`3o1`020?l?0080oaL00P3o7P00@@3o9P00obh00?le
003o?@00odD00?m<003oG000of/00?mj003oT@00ok000?o?003om@00g?l0
0:Ko001ho`00@_l001co0000oa400?l`003oA`00oeh00?me003oS000oi`0
0?nc003o`P00omT00?oX003oo`00j?l00<[o002[o`00QOl005Oo000Qo`0L
0?l0H@3o09h0o`3S0?l0o`3G0?l0V@3o05@0o`2Q0?lG003oRP00onH00;Go
0012o`000?l`003oZ`00b_l003So06P0o`3o0>H0WP3o0?o7001ho`000?n5
001^o`2^0?l0H@3o073o0000odl00<[o008004Oo00P00?m^001Vo`3o^000
Qol008L0o`3o0;P00?n5003oo`800?m704400?o:0017o`1`0?l0og<008oo
0000oi@005ko09h0o`3o04`0odD00?[o0012o`000?m?003oj000U?l001Wo
05T0o`350?l0o`3G0?l0NP3o01L0oaL00?mS003oX@00onH00=co002Go`00
DOl001Co0000obP00?mN003oQ@00oj/00?oA003oj000ool00>So003Ao`00
`_l00:_o002Lo`00S?l007Go001No`00Aol002So000:o`0L0?l0BP3o07l0
o`2^0?l0h`3o0?l0kP3o0<L0o`2X0?l0T@3o07X0o`1[0?l0G03o04`0o`15
0?l0?@3o03D0o`0^0?l09P020?l07P80o`0G0P3o00l30?l01`T0o`00203o
1`0:0?l?00`0oaL02P3o7P030?lV00D0oooo0@0000010?ooo`001`3oool2
000001d0oooo00<000000?ooo`3oool00`3oool30?l07Pd0o`0G3P3o00l;
0?l01`H0o`0000<0o`1D0?l0003o00000`3o00030?l700<0o`l00P3o5`00
R`3o7P00obH00?l^003o;P00ocD00?lm003oC000oe@00?m[003oNP00oiT0
0?n`003ogP00jol00:Ko001Xo`008ol0003o0P00ocP00?m7003oKP00ogd0
0?nD003oW000ok<00?o2003od@00on400?o`003ho`00j?l00<[o002co`00
QOl005ko000Qo`0S0?l0N03o0<D0o`3o0>h0o`2`0?l0L`3o02h0obh00?mD
003oZ000jol007So0005o`000?me003on000MOl0<`3o0><0o`3o02h0oe`0
0:Ko0000ohD007go0?l0/02G0?l00?m7002Do`2m0?l00?So003o6@3Do`00
_Ol0000oo`120?l00<;o002Do`3Lo`000?oo07P0o`3D0?l001Wo08L0o`3o
_`000?nD0002o`2Go`00g?l0003oO@00Eol0]@3o0?l0J`3o;P00Y_l001Co
0000oj<00>So001?o`0D0?l0U`3o0?l0o@3o09T0o`1506So003o;P00oh80
0?nh003jo`00]Ol006So000Lo`000?lX003oIP00oi@00?nc003od@00onP0
0?oo003`o`00hOl00=7o0032o`00/ol009co002Do`00OOl006ko0017o`00
<?l000;o02/0o`1`0?l0]@3o0?<0o`3o0=h0o`2`0?l0V@3o07X0o`1[0?l0
E03o04`0o`0m0?l0=@3o02h00P3o02H00`3o01h0o`0G0?l05`030?l03`<0
o`07303o000;0?l700h0o`l03@3o5`030?lN00D0oooo0@0000010?ooo`00
2@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo
0`3o01LC0?l03a00o`072@3o00000`3o05@0o`000?l000040?l000@0o`L0
0P3o3`030?lG00190?lN003o9P00obh00?le003o?@00odD00?mD003oH`00
ogX00?nQ003oa`00n_l00:ko001Io`003?l0003o:000odl00?m^003oQ@00
oi@00?n[003o/`00ol800?oA003of@00onP00?oh003ho`00j?l00=7o002j
o`00U?l006Ko000Xo`0S0?l0O`3o0=`0o`3o0=L0o`2I0?l0G03o01L0o`L0
0?mD003o/000g?l0067o0000oaT00?nD003Xo`00Col0F@3o0?l0^01ho`00
okl003[o0000onP0>P3o0480o`1ho`000:?o0?l03`00oh`0o`22003oZ`3<
o`000?o`003o<000Aol0onh007l0o`00olX008Go002So`02000Qo`0k0?o7
00120?l0oe`0003on03o0<l0ojP000Go0000^_l0H@3o0?l0T@00j?l0lol0
04;o0000ofH00?oo0025o`000_l0N03o0?<0o`3o0:40o`1<0?l0/03o5`00
of<00?nQ003oiP00c?l0073o000Do`000?lh003oKP00oi`00?nj003of@00
onP00?oh003ho`00j?l00=Wo003Ao`00`_l00;?o002[o`00U?l008Go001^
o`00Col0027o01`0o`1Q0?l0]@3o0?l0o@3o0<L0o`2I0?l0NP3o06<0o`1D
0?l0A@3o03d00P3o02h0103o02H0o`0N0?l05`3o01L30?l03`@0o`07403o
000@0?l701<0o`l00`3o5`050?ooo`4000000@3oool000T0oooo0P00000D
0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`@0o`0?6`3o00L@
0?l000030?l0E03o0000o`0000H0o`00103o1`030?l?0080oaL00P3o7P00
?`3o9P00obh00?lm003oA@00oe`00?m[003oV@00oll00;go000co`000?lh
003oE`00ohD00?nD003oZ`00ok<00?o2003obP00omT00?oQ003oj000oo00
0?oo003ho`00l?l00>7o003Ao`00Zol009Co0017o`050?l0U`3o0?l0iP3o
0940o`1S0?l0=@3o00L0o`l00?m<003oX@00e?l002_o0000oeh00?o:003:
o`00<?l0WP3o0?l0H`0So`00g?l0003oA`00OOl0o`3m073o0000oi@002So
003oC`00Aol0Q`3o01Co003o7P00DOl0003oo`020;go0080_@3o03l00<;o
0540o`3o03D000;o003Xo`27o`00_@3o067o0000Aol0j`3o0?om0000oj/0
01Wo0?l0kP00ol80olL007So0000odL00?oI002[o`00Aol0D@3o0?<0o`3o
0940o`0m0?l0^03o1`00odD00?mS003o/000ooD007oo0000o`X00?mV003o
U000okX00?oA003oh@00oo000?oh003ho`00l?l00>So003Qo`00fOl00<[o
0032o`00/ol00:_o002Do`00QOl005Oo000`o`0j0?l0c03o0?l0_`3o09T0
o`1[0?l0G03o04D0o`0m0?l0;P3o02H00P3o01h00`3o01L0o`0?0?l03`02
0?l03`@0o`076@3o000J0?l700D0o`l01@3oool100000040oooo00080?oo
o`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`L0o`07:03o00000`3o05@0o`000?l0
000:0?l000D0o`L00P3o3`020?lG000>0?lN003o9P00obh00?lm003oG000
oi400=Co0000o`X00?me003oW000okX00?o2003od@00omT2003oh@04003o
j000oo000?oh003on0800?oo05800?So003`o`00hOl00=7o002jo`00QOl0
033o0;D0o`3o0:40o`1L0?l0=@3o01h0o`000?l?003o=@00ogX00??o0000
o`X00?n<003oh@00dOl004Oo0;d0o`3o03D07?l00<Go0000ogd005Oo0?l0
RP3oT@000?oo000Ao`00oeL0o`3m0?o^00004Ol000;o0<co002G0?l03?l0
07oo00008Ol0]@3o003o>02e0?l00?l2003o4@3o0>h0oh800540o`3Lo`00
0:_o0?l0T@3oZ0000?n<001?o`3j0?l00?nc0?n:002Go`000?mN003oh@00
dOl007go01`0o`3o0>h0o`1[0?l0;P3o0;P0o`000?lV003o?@00of/00?n`
002?o`000?lo003oW000ol800?oI003oh@00oo000?oh0P00ool01000n?l0
0?3o003`o`00j?l2003Qo`0>003Io`00dOl00<;o002jo`00W?l006ko00`0
o`3c0?l0o`2:0?l0G03o03d0o`0^0?l09P3o01h20?l05`80o`0?1@3o00Le
0?l000L0o`L01@3oool100000040oooo00080?ooo`040000003oool0oooo
00000180oooo00@000000?ooo`3oool00000103oool3000000<0oooo<00c
0?lB03?o00L0:ol000D08ol001co0000ohD00?oI003ol005003on0/00?oo
0P00n?l01@00l?l00>So000`o`0<0?l08`3o00<0:`3o0P0[o`006@0<o`00
0?lo003oj000oo000?oh003oo`00hOl009co01`0o`0j0?l00?n[003ol000
dOl005ko003oS000oi`000[o003oW000olX00<[o00`0o`120?l00:?o003o
h@00Zol00P00I_l06`00oj/00>7o002So`00Aol03?l0003:o`00olX00?nL
0><0o`00omT008co003oGP00om400?3o000Qo`0L0?l00?l2003oW000ooP0
0?oo003ho`00l?l00<;o000oo`0S0?l0:`3o03<0o`0302_o000401co000<
o`000?nj003oj0<00?oh2`00ool5003ho`05003`o`00fOl008Go01`0o`0S
0?l01`0[0?lB03<0oc00<ol0103oool200000040oooo00080?ooo`040000
003oool0oooo00000180oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooobl0o`0000<0oe@00?l0003o00004@3o00040?l0
1`0:0?l03`3o01L0o`0e0?l0H`3D0?l000[o001eo`00Xol00<;o003:o`80
0=Wo00@00>7o003Xo`00l?l00?3o0P00n?l2003oo`1B003on000oo000?oQ
003od@00okX00?n<003o<03Lo`00oi400?l^003o5`00o`L00?l0003o00L0
o`0G0?l0L`3c0?l000[o002<o`00hOl00?oA003oA`2mo`00ocD001`0o`35
0?l007go003oE`3oPP00o`2A003oo`00oa4005Oo09Oo003o03d0N?l00:Ko
002N0?l0N?l000`0o`270?l00?lQ01Co0000>?l0W_l003X0o`1h0?l0ok00
09L0o`1Ao`00g03o003oZ`3oT@00o`2X002<o`00odl0onH0002co`3o0880
U`3o001Vo`00hOl00?oA003oO@0Lo`00onh00?le003o5`00okP00?l0003o
00l0o`0G0?l0C03o0940S`3o000oo`00W?l00<;o003Io`00hOl00?3o003h
o`800?oo0P00ooP2003ol00>003oj000on400?oI003of@00olX00?o2003o
X`00ogD03?l00??o003oH`00ocD00?lG003o3`040?l704<0o`001@3oool1
00000040oooo00070?ooo`80000000<0oooo0000000000004P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo703o1`0C
0?l000030?mD003o0000o`0000H0o`001@3o00L20?l03`80o`0G0P3o01h0
PP3o02H0o`0^0?l0?@3o04D0o`1S0?l0L`3o0;00o`3V0:h0o`120?l001Wo
0017o`00OOl009Co002[o`00/ol00<;o003:o`00fOl00>7o003Xo`00l?l0
0?So003on000onP00?oQ003o`P00oj<00?mm003o?`0Lo`00Sol00??o003o
X@00ogX00?lm003o3`00o`0?0?l0E03o0;00e03o04X0o`00>?l00;?o003o
d@00ocP0Ool00?n:00120?l0o`3m000Ao`00okX0Y_l0000Qo`0S0?l0Qol0
00`0o`12o`000;[o003o^P3o08X0D@3o003of@3o0=L0BP3o04[o003oe`00
0?oI057o003om@000;[o000Io`00Zol00?m?000Xo`2?o`000?lQ06P0o`00
`_l07?l00?o?0000j?l0o`3G0640o`00Col00>So003oW000ob40HOl00>_o
003oX@00od`00?nh003o00l0o`1D0?l0NP3o0<L0h`3o07P0o`0<0?l004oo
0025o`00/ol00<[o003Qo`00l?l00?So003on000oo000?oX003oh@00omT0
0?o:003o`P00ok<00?n[003oU000ogd00?m7003o6@1Ao`00_Ol00?oV003o
Z000og<00?mS003oA@00ocd00?l^003o9P020?lN00040?lG003o3`00o`l0
0?l?00D0o`L0703o000L0?l01`D0oooo0@0000010?ooo`007P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo4P3o3`0D
0?l700T0o`0000<0oe@00?l0003o0000103o00040?l01`<0o`0?0P3o01L0
Q`3o01h0o`0V0?l0;P3o03D0o`0m0?l0A@3o05@0o`1S0?l0NP3o0:40o`37
0?X0o`2^0?l0F@3o00`0o`00:?l004oo001^o`00QOl009co002[o`00^_l0
0<;o003Ao`00fOl00>So003ho`00ooP00?oX003od@00okX00?nD003oIP00
obP08ol007oo003Lo`00omL00?nI003oG000oaL00?l03`3o05@0o`2`0=`0
o`1Q0?l001Wo002Do`00onP00?m?05Wo003o^000N03o0?l0_`0j0?l00>So
03[o0012o`00e03o003oX`3oRP00503o0?mL0000Zol0c03o003`o`00<?l0
0?m70?l0X@1oo`000<[o003oQ@00oj<00?lQ003oM@3o0<L0@_l00?l0X@00
hOl0okP00?l0Z0050?l00?o:067o003oV@000?oX0?X0o`120?l006Ko003o
o`00ohD00?l207So003co`00oj400?m<003o/000o`0G0?l0H`3o0:40o`3V
0<`0o`1`0?l0503o000ho`00K_l009co002jo`00fOl00>So003ho`00ooP0
0?oX003of@00om400?o2003o/`00oj/00?nD003oQ@00ofh00?m?003o8@0L
o`00HOl00;Go003oo@00okl00?nI003oNP00of<00?mD003oA@00ocd00?l^
00020?lV00030?lN003o5`00oaL000<0o`l0103o1`0@0?l001@0o`074@3o
00l00`3o01L0oooo0?ooo`030?ooo`4000000@3oool001l0oooo0P000005
0?ooo`030000003oool0oooo00<0oooo00<0oah00?lG003o5`002`3o5`0@
0?l?00/0o`L01P3o00000`3oE000o`000?l000030?l000<0o`070`3o00l2
0?l05`2;0?l07P3o02H0o`0^0?l0;P3o03d0o`150?l0E03o05`0o`1c0?l0
PP3o0:40o`2o0?l0kP3S0?l0YP3o0700o`0c0?l01@3o000Xo`00?ol006Ko
001eo`00S?l009co002co`00^_l00<[o003Qo`00l?l00?oh003oh@00olX0
0?n[003oQ@00oeL00?lQ02?o001`o`00]Ol00?om003oa`00ogX00?m50000
2_l0o`0^0?l0X@3o0?d0S`3o02<0o`00G_l00=7o003oU000o`80]Ol00?mc
003o00l0l`3o000`o`00omT0Uol00?le002e0?l00<;o0?no00270?l000;o
08l0o`2m0?l00?3o08oo0000U?l00?oQ0:H0o`00obP0HOl008oo002eo`00
0?mV01`0o`00ol80]Ol00?l0o@2G0?l00?oh003o<03okP00oah00?l0L`2?
0?l001Wo002co`00ol800?lo03?o002Vo`00onh00?n:003o;P00o`0e0?l0
C03o0940o`3?0>/0o`2V0?l0H@3o01@0o`00:?l005ko002<o`00/ol00=7o
003Xo`00ool00?o`003of@00olX00?nj003o/`00oi`00?n<003oM@00ofH0
0?lo003o:00<o`00>_l007So002eo`00jol00?oV003o_`00oiT00?n2003o
J`00oe`00?mD003oA@00ocd00?l^00020?lV00030?lN003o5`00oaL000<0
o`l00`3o1`0<0?l000/0o`07403o00l=0?l05`030?l07P3oool0oooo00<0
oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`030?lV
003o7P00oah000P0oah03@3o5`0;0?l?00P0o`L0103o00000`3oE000o`00
0?l000020?l000<0o`070P3o00l20?l05`80o`0N08/0o`0V0?l0;P3o03D0
o`0m0?l0A@3o04`0o`1L0?l0J`3o07X0o`2A0?l0/03o0<l0o`3e0=`0o`2V
0?l0N03o0480o`0L0?l0017o000`o`00Aol006Ko001eo`00S?l009co002c
o`00`_l00=Wo003Xo`00ool00?oX003obP00oj/00?n5003oE`00ob407?l0
067o002No`00hol00?oG003oV@00oe@00?nQ003o01L0o`2:0?l0iP2e0?l0
@P3o000`o`00Zol00?o:003o>01Xo`00onH009ko003o06<0N03o0025o`00
ofh0_Ol0067o003j0?l007go003oIP1:o`00>_l0001^o`0[o`00o`2X0?l0
G03oG000ojP00025o`00ool0BP3o03X0o`00Zol00?mm0?nX003o0=L0S`3o
001mo`00oeh0Sol00?lm003o0<L0nP3o0540o`00Col00>7o003oU000oaT0
FOl00<Go003oe`00ogX00?lG003o01L0o`1S0?l0X@3o0>H0g03o09L0o`1A
0?l0503o000Xo`00G_l008Go002[o`00dOl00>So003oo`00onP00?oA003o
`P00oj/00?nL003oS000ogD00?mN003oA`00obP00?l:01co001:o`00Ool0
0:ko003So`00onh00?o7003oZ000oi400?mj003oJ`00oe`00?m<003oA@00
ocd00080obh000@0obH00?lN003o7P00oaL00`3o3`030?l700T0o`00203o
00L;0?l03`d0o`0G2P3o01h00`3o02H0oooo0?ooo`030?ooo`4000000@3o
ool002H0oooo00<000000?ooo`3oool00`3oool00`3o;P00obH00?lV0007
0?lV00X0oah02P3o5`080?l?00H0o`L0103o00000`00QOl0o`000?l00003
0?l01`80o`0?0P3o01L0TP3o01h0o`0V0?l09P3o02h0o`0e0?l0?@3o04D0
o`1D0?l0G03o06/0o`1j0?l0T@3o0:P0o`2o0?l0gP3j0?l0e03o0:h0o`1o
0?l0F@3o03<0o`0D0?l0017o000`o`00Aol005ko001eo`00S?l009co002c
o`00b_l00>7o003ho`00oo000?oA003oZ`00ohD00?mG003o:00<o`00B_l0
07oo0035o`00n_l00?nh003oPP00obh0000Xo`3o06<0o`2X0>/0o`2?0?l0
503o0017o`00fOl00?nj003o4@1Xo`00oll00?l^003o05@0e03o001?o`00
j?l07?l00?oV0000Eol009co002So`00Eol005ko003oM@00?ol0onH00<`0
o`00ocl0:ol0003oGP00oeL00?nS003oW000oeL0o`3V01`0o`00onP00?m?
0=Co003oE000o`2Q0?<0o`1A0?l004Oo003Ao`00oj/00?lh03[o002No`00
ood00?nQ003o;P000?lX0?l0A@3o08X0o`3?0?<0o`2e0?l0N03o03X0o`05
0?l0033o001No`00S?l00;?o003Ao`00l?l00?o`003of@00ol800?nc003o
W000oh`00?m^003oGP00ocl00?l`003o2P0Do`00>_l0067o0027o`00]Ol0
0=co003oo@00omh00?no003oX@00oi400?mj003oJ`00oe`00?mD003oA@00
ocd00?le003o;P00obH00P3o7P020?lG0080o`l00P3o1`030?l0000300D0
o`3o0000o`000080o`001P3o00L80?l03`X0o`0G2P3o01h90?l09P030?l0
;P3oool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000oooo0?oo
o`030?ooo`030?le003o;P00obh000D0obh0203o9P0:0?lN00P0oaL01P3o
3`050?l700<0o`0000<008Go0?l0003o00000`3o00L20?l03`140?l05`3o
01h0o`0N0?l09P3o02h0o`0e0?l0?@3o04D0o`1<0?l0G03o06<0o`1c0?l0
PP3o09T0o`2`0?l0a`3o0>H0nP3o0=@0o`2^0?l0Q`3o0640o`120?l0703o
0002o`006Ol003So001?o`00I_l007go002Do`00Zol00<;o003Io`00l?l0
0?o`003od@00ok<00?n<003oGP00oc001Ol003[o001`o`00[_l00>_o003o
e`00oiT00?lm0000<?l0o`0e0?l0RP3o0>H0_@3o05T0o`004Ol008Go003o
o`00ogd03?l009ko003oa`00Ool00?l0=@3S0?l0@P3o001No`00dOl2003o
W00<002Lo`2G0?l0og<00002o`0co`00N?l0000Xo`2m0?l00?m^0?l0L`2G
o`000?nc0P00W?l0?P00ol800?mN05Wo003So`00oah00?l0e`3o0=h0Q`3o
000:o`00U?l00?oX003oM@00o`80J?l00<co003oe`00ogX00?l?0000Eol0
o`1L0?l0X@3o0>H0g03o0:H0o`1X0?l0<`3o0002o`00>?l006Ko002Do`00
/ol00=Wo003ho`00oo000?oA003o^P00oj<00?n<003oM@00ofH00?m?003o
<000oaT01Ol002?o0012o`00J?l008oo002eo`00g?l00?[o003ogP00olL0
0?nX003oV@00oh800?mc003oH`00oe@00?m<003oA@00ocd00P3o;P00103o
9P00oah00?lG003o5`020?l?00<0o`L00P3o000010050?l0o`000?l0003o
00050?l01`H0o`0?203o01L:0?l07PL0o`0V203o02h00`3o03D0oooo0?oo
o`030?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool0
0`3o?@00ocD00?le00040?le00L0obh0203o9P080?lN00H0oaL01@3o3`04
0?l700<0o`0000<008Go0?l0003o00000P3o00L20?l03`80o`0G04d0o`0N
0?l09P3o02h0o`0e0?l0?@3o04D0o`1<0?l0E03o06<0o`1c0?l0PP3o0940
o`2Q0?l0^03o0<l0o`3^0?<0o`3D0?l0]@3o09L0o`1`0?l0D@3o03<0o`0D
0?l000;o000Qo`00>?l004oo001Vo`00OOl009Co002[o`00b_l00>7o003o
o`00on400?o2003oU000ogD00?lo003o6@0So`00DOl008oo002mo`00ood0
0?o?003oPP00od`0001?o`3o01h0o`2Q0?l0iP2^0?l0H@3o000Io`00I_l0
0?So003o^P00oaT0>_l00>_o003oNP0007go0032o`3o05`0o`2:0?l0T@00
j?l007Go003oQ@270?l003oo03X0o`00oc000?o`003oO@0200Go00100700
o`00ogD00?oX0?nA003oRP00oe`0003o`P00ogd0o`1j0>/0o`0j0?l005ko
002jo`00ol800?mN01Co001Xo`00c?l00?oN003oPP00oah00?l0=@3o05@0
o`2I0?l0e`3[0?l0]@3o07l0o`1:0?l0503o000Qo`00Col007Go002So`00
`_l00>So003on000omT00?o2003oZ`00oi@00?mm003oIP00odL00?lh003o
6@00o`807?l003?o001Io`00N?l009Oo002mo`00g?l00?[o003oiP00oll0
0?nh003oX@00oi400?mj003oJ`00of<00?mD0080odD000D0ocD00?l^003o
9P00obH00?lN00020?lG0080o`l00P3o1`020?l0000300D0o`3o0000o`00
00@0o`071P3o00l60?l05`P0o`0N203o02H70?l0;PH0o`0e00<0o`0m0?oo
o`3oool00`3oool100000040oooo000V0?ooo`030000003oool0oooo00<0
oooo00<0odD00?lm003o?@000`3o?@070?le00L0obh01`3o9P060?lN00D0
oaL0103o3`040?l70080o`0000<008Go0?l0003o00000P3o00L20?l03`13
0?l05`3o01h0o`0N0?l09P3o02h0o`0e0?l0?@3o04D0o`1<0?l0G03o06<0
o`1c0?l0PP3o0940o`2X0?l0_`3o0=L0o`3^0?<0o`3D0?l0_@3o09L0o`1h
0?l0F@3o0480o`0S0?l01@3o000Ao`00:?l003oo001Go`00MOl008co002S
o`00^_l00=Wo003ho`00onP00?o:003oX`00ogd00?m?003o:00<o`00>_l0
073o002Vo`00g?l00?oV003oZ000of/00?l70000?ol0o`1S0?l0/03j0?l0
YP3o04X0o`004Ol007Go003Io`00ol800?mN00Go001Qo`00e?l00?om0002
0;Go000>08Oo001:o`000?mm000ho`00Eol0B_l00?<0o`00ofH00?nS04[o
003L0?l0_Ol0003oKP00Col208L0o`80]@3o0440o`3m0=@0o`1I0?l01@3o
001^o`00dOl00?o:003oIP00o`X0FOl00:ko003om@00ojP00?m50000Aol0
o`0^0?l0L`3o0;00o`3^0=@0o`2N0?l0J03o03<0o`050?l0033o001Go`00
QOl00:_o003Ao`00l?l00?o`003od@00okX00?nL003oQ@00ofh00?mG003o
?`00obP00?l:00co000So`00@_l0067o001oo`00W_l00;go003Lo`00n_l0
0?o^003oc`00okP00?nX003oT@00oh800?mc003oH`00oe`00?m<003oA@00
ocd00?le003o;P00obH00?lN00020?lG0080o`l00P3o1`020?l0000300D0
o`3o0000o`0000<0o`071@3o00l50?l05`H0o`0N1`3o02H70?l0;PH0o`0e
1P3o03d00`3o04D0oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<0
00000?ooo`3oool00`3oool00`3oC000odD00?m500030?m500H0ocd01P3o
=@060?l^00H0obH01P3o7P040?lG00<0o`l0103o1`040?l00080o`070P3o
00l0@P3o01L0o`0N0?l09P3o02H0o`0^0?l0=@3o04D0o`1<0?l0E03o06<0
o`1[0?l0NP3o08X0o`2I0?l0/03o0;l0o`3G0?l0kP3j0?l0g03o0<D0o`2V
0?l0Q`3o0700o`1A0?l0>P3o01`0o`050?l0017o000Xo`00Aol005ko001e
o`00S?l00:_o0032o`00hOl00?oo003oh@00ok<00?nD003oIP00odL00?lA
01Co001Ao`00N?l00;Go003Lo`00omh00?n`003oH`00obH00?l0003o04`0
o`2X0?l0gP2e0?l0O`3o01@0o`008Ol008co0032o`00omT00?n[003oGP80
0?m701800?m^003on000U?l0o`3V003:o`1Qo`000:_o001Vo`0So`00]@3o
0:ko0000olX0YP3o003obP35o`000?nD003ho`00K_l20017o`0o001No`00
Zol00=Wo003o`P00oeL00?lQ04[o001oo`00hol00?oN003oRP00ocd00?mc
003o04`0o`1j0?l0/03o0?D0g03o09h0o`1`0?l0>P3o00`0o`008Ol004oo
001eo`00W?l00<;o003Qo`00ooP00?oQ003o`P00oj<00?n<003oM@00oeL0
0?m7003o:000oa401Ol001co000jo`00DOl0073o002?o`00Y_l00<Go003S
o`00n_l00?o^003oe`00okl00?nX003oV@00ohX00?mj003oJ`00oe`00?mD
003oC000ocd00?le003o;P00obH00080oah000<0oaL00?l?003o3`000P3o
1`00103o0000olL00?l0003o00030?l01`@0o`0?103o01L60?l07PH0o`0V
1P3o02h60?l0=@H0o`0m1@3o04D00`3o04`0oooo0?ooo`030?ooo`400000
0@3oool002H0oooo00<000000?ooo`3oool00`3oool00`3oE000od`00?m<
00020?m<00D0odD01P3o?@060?le00H0obh01@3o9P040?lN00@0oaL00`3o
3`030?l700@0o`000P3o00L20?l03`110?l05`3o01h0o`0V0?l0;P3o03D0
o`0m0?l0A@3o04`0o`1D0?l0H`3o07<0o`1j0?l0RP3o09T0o`2`0?l0_`3o
0=L0o`3^0?X0o`3L0?l0a@3o0:h0o`2?0?l0N03o05T0o`120?l0:`3o00`0
o`002_l0027o000ho`00Col006Ko0025o`00W?l00;[o003Ao`00l?l00?o`
003obP00oj<00?mm003oE`00oc000?l202_o001Io`00Sol00;go003co`00
omL00?nI003oH`00of/0000Io`3o05@0o`2I0?l0gP3S0?l0WP3o05T0o`0L
0?l001Wo001?o`00MOl00P00U?l05000K_l0033o0480o`3[0?l000;o0?o7
0000ofH08`3o0002o`05o`00Q`3o0?oV0000obP002So0?l0J`3oa`00c?l0
03?o0000ocP00?m^0P00oi@0?@00ofh00?m?003o4@0So`00HOl00:Ko003[
o`00oll00?n:003o?@0006ko0?l0E03o06/0o`2Q0?l0gP3[0?l0]@3o08L0
o`1A0?l08`3o000:o`00>?l005ko0025o`00Zol00=7o003`o`00oo000?oA
003o/`00oi`00?mm003oIP00odl00?lh003o6@00o`805?l002_o0012o`00
HOl007So002Go`00[_l00<co003So`00n_l00?o^003oe`00okl00?nX003o
V@00ohX00?mj003oJ`00of<00?mD003oC000odD00?le003o;P000P3o9P00
103o7P00oaL00?l?003o3`020?l700040?l0003oa`00o`000?l000<0o`07
0`3o00l40?l05`@0o`0N1@3o02H60?l0;PH0o`0e1P3o03d50?l0A@@0o`1<
00<0o`1D0?ooo`3oool00`3oool100000040oooo000V0?ooo`030000003o
ool0oooo00<0oooo00<0oe`00?mD003oE0000P3oE0050?m<00@0odD01P3o
?@060?le00@0obh01@3o9P040?lN00<0oaL00`3o3`020?l70080o`0000@0
08Go0?l0003o00L0o`070P3o00l0@03o01L0o`0N0?l09P3o02h0o`0e0?l0
?@3o04D0o`1<0?l0G03o06<0o`1c0?l0PP3o0940o`2Q0?l0/03o0;l0o`3G
0?l0kP3j0?l0h`3o0<`0o`2e0?l0WP3o08L0o`1`0?l0D@3o03X0o`0S0?l0
303o000:o`008Ol003So001?o`00K_l008Go002Lo`00^_l00=Wo003ho`00
on400?o:003oW000ogd00?m?003o<005o`008ol0067o001oo`00_Ol00>?o
003ogP00okP00?mc003oC0000:_o00D0o`3o04D0o`2A0?l0e`3o0?d0a@3o
0:H0o`1h0?l206P0o`0F07l0o`3<0?l0o`2I03<0o`00b_l0W_l0003o<000
Eol0o`3m0:ko0000odL000[o0=`0o`3oo@000?n<000`o`350?l00?o:0?n2
003oZ000c?l007oo0080J?l00400N?l00:Ko003So`00ood00?nh003oT@00
ocD0003oZ`3o04D0o`1<0?l0T@3o0;P0o`3e0><0o`2V0?l0O`3o04X0o`0S
0?l000[o000`o`00G_l008Go002[o`00b_l00?3o003on000om400?nj003o
W000ohD00?mV003oC`00ocP00?lQ003o2P0<o`00:ol003[o001Io`00L?l0
08Oo002No`00_Ol00=Co003[o`00ood00?oV003oe`00okl00?n`003oV@00
ohX00?mj003oL`00of<00?mD003oC000odD00?lm003o=@00obh00?lV003o
7P00oaL00P3o3`000`3o1`00o`000?l000020?l000<0o`070`3o00l30?l0
5`@0o`0N1@3o02H40?l0;PH0o`0e1P3o03d40?l0A@D0o`1<103o05@00`3o
05`0oooo0?ooo`030?ooo`4000000@3oool002H0oooo0`0000030?ooo`04
0?mS003oG000oe`00?mL00@0oe@01@3oC0050?m500D0ocd01@3o=@050?l^
00@0obH00`3o7P030?lG00<0o`l00P3o1`001@3o0000og<00?l0003o0000
o`070080o`0?03l0o`0G0?l07P3o02H0o`0^0?l0=@3o03d0o`150?l0C03o
05`0o`1S0?l0L`3o0880o`2A0?l0X@3o0;00o`2o0?l0e`3o0>H0o`3m0>/0
o`3D0?l0_@3o0:H0o`2?0?l0N03o0640o`1:0?l0:`3o01@0o`000_l001Wo
000`o`00Aol005ko001eo`00U?l00:_o003:o`00j?l00?oh003of@00ok<0
0?nD003oKP00odL00?lQ00Go000co`00HOl008Oo002eo`00hol00?oV003o
^000ohX00?m<003o9P00ooD00?l05`3o05@0o`1j0?l0V@3o0;000P3o0<L0
603o0;00o`2:0?l07P35o`00okP00<co0000o`800?oo02/0o`3o06/0oh80
003oGP008Ol0o`220?m[0000o`800=Wo01`0o`3[0?l0o`1c002[o`3oC000
oi400?n`0080olL003l0ok000?nI003oL`00od`00?lG003o04`0o`0m0?l0
H`3o0940o`2o0?l0kP3L0?l0[P3o07l0o`1I0?l0:`3o00D0o`00:?l004oo
001eo`00W?l00;[o003Qo`00ool00?oQ003o`P00oj/00?n<003oM@00oeh0
0?lo003o:000oa401Ol001co000co`00B_l0067o001ho`00Sol00:Ko002m
o`00e?l00>_o003oo@00onH00?o?003o_`00ok000?nI003oRP00ogX00?mc
003oH`00oe`00?m<003oA@00ocd00?le003o;P00obH00?lN003o5`000P3o
3`000`3o1`00o`000?l000020?l00080o`070`3o00l30?l05`<0o`0N103o
02H50?l0;PD0o`0e1@3o03d50?l0A@@0o`1<1@3o05@30?l0G0030?l0H`3o
ool0oooo0080oooo0P0000010?ooo`009P3oool00`000000oooo0?ooo`03
0?ooo`@0of<0103oG0040?mD00D0od`01@3oA@040?lm00D0ocD0103o;P03
0?lV00<0oah00`3o5`020?l?0080o`L00P3o00000`00G_l0o`000?l01`02
0?l03`0n0?l05`3o01h0o`0V0?l0;P3o03D0o`0m0?l0A@3o04`0o`1L0?l0
H`3o07<0o`220?l0T@3o0:40o`2`0?l0_`3o0<l0o`3V0?l0m@3c0?l0g03o
0<D0o`2e0?l0WP3o08L0o`1`0?l0F@3o0480o`0[0?l0503o0002o`006Ol0
033o0017o`00G_l007Go002Do`00Zol00<[o003`o`00ool00?oA003o^P00
oh`00?me003oA`00oc001Ol001co001Ao`00L?l00:Ko002mo`00n_l00?o^
003o^000oiT00?mS003o;P00ocd0002So`00^_l20032o`0J002jo`00W?l0
oi400?mc003oo@00B_l0003o:000hOl0027o0?l0^000W?l0aOl0003oM@00
Aol0l`3o003oW03[o`000?lX003ho`00:?l0F@3o0?l0o@3o07<0o`1[003o
W000okX2003o`P0o003o/`00oj<0o`0G0?l0;P3o0880o`2I0?l0c`3o0>h0
g03o0;d0o`270?l0L03o03X0o`0L0?l0017o000`o`00G_l007Go002So`00
^_l00>7o003oo`00on400?o:003oX`00oh`00?me003oGP00ocl00?l`003o
4@00o`807?l002_o001:o`00FOl0073o0027o`00W_l00;Go003<o`00hol0
0??o003om@00omh00?o?003o_`00ojP00?nI003oRP00ogX00?mc003oH`00
oe`00?m<003oA@00ocd00?le003o;P00obH00?lN003o5`00o`l00080o`L0
00<0o`00003oZ`3o00000P3o00L30?l03`80o`0G103o01h30?l09P@0o`0^
1@3o03D40?l0?@D0o`151@3o04`40?l0E0@0o`1L0`3o06<00`3o06/0oooo
0?ooo`030?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3o
ool30?m[00@0of<0103oG0040?mD00D0od`0103oA@050?lm00@0ocD00`3o
;P030?lV00<0oah00`3o5`020?l?0080o`L000<0o`00001No`3o00000P3o
00L0?P3o00l0o`0G0?l07P3o02H0o`0^0?l0=@3o03d0o`150?l0C03o05`0
o`1S0?l0L`3o0880o`2:0?l0V@3o0:P0o`2o0?l0c`3o0=h0o`3e0?X0o`3S
0?l0c03o0;d0o`2V0?l0S`3o07P0o`1Q0?l0D@3o03X0o`0S0?l0303o000:
o`008Ol003So001?o`00I_l008Go002Lo`00/ol00=7o003`o`00oo000?oA
003o/`00oi@00?m^003oC`00obP00?l:01co0012o`00J?l008Oo002^o`00
e?l00??o003okP00oll00?nh003oX@00ohX00P3oNP00703oRP00oj400?o?
003co`00Y_l004;o0000ocl00?oI001^o`1Q0?l0o`1S0=Co002No`000?n5
001Go`350?l006ko0?nh0012o`000?n<002jo`00:?l0D@3o0;D0o`3o0?d0
o`370?l0X@3o08X20?l0NP0n0?l0RP3o0:40o`2h0?l0e`3o0>h0j`3o0<`0
o`2V0?l0Q`3o0640o`0j0?l0503o000:o`00<?l005Oo001eo`00U?l00;[o
003Io`00n?l00?oX003od@00ok<00?nD003oO@00ofH00?m?003o<000oaT0
0?l:00co000So`00>_l0057o001Xo`00Ool008oo002Vo`00_Ol00=Co003S
o`00n_l00?o^003ogP00oll00?nh003oZ000oiT00?n:003oNP00og<00?mS
003oG000od`00?m5003o?@00ocD00?l^003o9P00oah00?lG003o3`020?l7
00030?l000006Ol0o`000080o`070P3o00l30?l05`<0o`0N0`3o02H30?l0
;P@0o`0e1@3o03d40?l0A@D0o`1<103o05@40?l0G0<0o`1S103o06/50?oo
o`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool30?mc00<0
of/0103oH`040?mL00@0oe@01@3oC0040?m500@0ocd0103o=@030?l^00<0
obH00P3o7P020?lG0080o`l00P3o1`040?l0000n0?l01`3o00l0o`0G0?l0
7P3o02H0o`0^0?l0=@3o03d0o`150?l0C03o05`0o`1S0?l0L`3o07X0o`2:
0?l0V@3o0:P0o`2h0?l0a`3o0=L0o`3^0?l0o@3c0?l0g03o0<D0o`2e0?l0
WP3o08l0o`1h0?l0H@3o0540o`0j0?l08`3o00`0o`002_l001Wo000`o`00
Aol006Ko001mo`00U?l00;[o003:o`00l?l00?oo003of@00ol800?nL003o
Q@00oeh00?m7003o6@00o`X08ol003[o001Qo`00N?l009Oo002^o`00c?l0
0=Co003[o`020??o000N0>_o003<o`00]Ol0073o0012o`000?l`003oO@00
hOl006ko0540o`3j0?l000[o0?nA001Io`000?nD001eo`1o0?l0o`0m0?o7
003co`00>_l0003oKP00ooP007go000`o`120?l0L03o0;D0o`3<0?l0j`3o
0P3c0?l0>@3S0?l0e03o0;d0o`2^0?l0Q`3o07P0o`1:0?l0>P3o00`0o`00
2_l0033o0017o`00K_l008Go002[o`00`_l00>So003oo`00on400?o:003o
Z`00oi@00?me003oIP00odL00?l`003o6@00o`X05?l002?o000jo`00DOl0
06So001ho`00Sol009ko002eo`00c?l00=co003co`00ood00?oV003oe`00
olL00?nh003oZ000oiT00?n:003oNP00of/00?mS003oE000od`00?m5003o
?@00obh00?lV00020?lN00060?lG003o3`00o`L00?l0003oZ000o`000P3o
00L20?l03`80o`0G0`3o01h30?l09P<0o`0^103o03D40?l0?@@0o`151@3o
04`40?l0E0<0o`1L103o06<40?l0J`80o`1c00<0o`1j0?ooo`3oool00`3o
ool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo0`3oNP03
0?mc00<0of/0103oH`040?mL00@0oe@0103oC0040?m500@0ocd00`3o=@03
0?l^00<0obH00P3o7P020?lG0080o`l00P3o1`030?l0000m0?l01`3o00l0
o`0G0?l05`3o01h0o`0V0?l0;P3o03d0o`150?l0C03o05@0o`1S0?l0J`3o
07X0o`2:0?l0V@3o0:40o`2`0?l0a`3o0=L0o`3V0?l0m@3c0?l0h`3o0<`0
o`2m0?l0YP3o09L0o`1o0?l0L03o05T0o`120?l0<`3o01`0o`050?l0017o
000Qo`00>?l004oo001Vo`00QOl009co002co`00dOl00>So003on000on40
0?o2003oZ`00oh`00?m^003oC`00ocP00?lI003o0P0Do`00<ol004;o001I
o`00J?l0073o000207So000O073o001Qo`00B_l002?o0000oa400?m?003o
X`00n?l007go00`0o`2V0?l0o`2X02/0o`3o^000@_l0003oX`00OOl0H@3o
0?l0J`3oRP00okl008oo0000o`X00?nD003ho`00U?l004Oo000:o`0[0?l0
BP3o06P0o`0307P0o`0j0700o`1X0?l0D@3o0480o`0[0?l0503o0002o`00
8Ol003So001Go`00MOl008co002[o`00b_l00>7o003oo`00on400?o:003o
/`00oi@00?mm003oIP00odl00?lh003o8@00o`X03?l001co000co`00B_l0
05Wo001`o`00Qol009Oo002^o`00_Ol00=Co003So`00n_l00?oe003oiP00
oll00?no003o/000oj400?nA003oPP00ogX00?m[003oH`00oe@00?m<003o
A@00ocD00?l^003o9P00oah00?lG0080o`l000@0o`L00?l0003oZ000o`00
0P3o00L20?l03`80o`0G0P3o01h30?l09P<0o`0^0`3o03D40?l0?@@0o`15
103o04`40?l0E0@0o`1L103o06<30?l0J`<0o`1c0`3o07X50?ooo`400000
0@3oool002H0oooo00<000000?ooo`3oool00`3oool20?n200@0ogX00`3o
L`030?m[00@0of<0103oG0040?mD00@0od`0103oA@030?lm00<0ocD00P3o
;P030?lV0080oah00P3o5`020?l?00040?l7003o0000oi400?l00080o`07
03T0o`0?0?l05`3o01h0o`0V0?l0;P3o03D0o`0m0?l0C03o05@0o`1L0?l0
J`3o07<0o`220?l0T@3o0:40o`2X0?l0^03o0<L0o`3N0?l0kP3o0?d0l`3o
0=`0o`3<0?l0_@3o0:H0o`2G0?l0O`3o0700o`1I0?l0BP3o03<0o`0S0?l0
303o000:o`006Ol0033o0017o`00G_l007go002<o`00Zol00;[o003Qo`00
l?l00?o`003oh@00okX00?n[003oS000ogd00?mN003oC`00oc000?lQ003o
4@00o`800`0<o`008P05o`000?l:003o6@00odL00?mV003o^P00onP00:?o
001No`0[0?l0U`3o0?l0a`3o01L0oe@00=Co000Do`000?n[002<o`0c0?l0
j`3o0?l0E03o5`00omh009Oo000Do`000?mN003o/`00j?l00;[o001Vo`00
Aol001Wo0002o`050?l200`0o`0j00D0o`000_l001Wo000Qo`00?ol004oo
001^o`00OOl009co002[o`00b_l00>7o003oo`00oo000?oA003o^P00oi`0
0?n<003oKP00oeh00?m7003o<000oaT00?l:00co000So`00>_l004[o001Q
o`00L?l008Oo002Go`00[_l00;go003<o`00g?l00??o003oo@00onH00?oG
003oa`00okP00?nX003oV@00oi400?n2003oL`00of/00?mL003oE000odD0
0?lm003o=@00obh00?lV003o7P00oaL00?l?0080o`L00P3o00020?l01`80
o`0?0P3o01L20?l07P<0o`0V0P3o02h30?l0=@<0o`0m103o04D40?l0C0@0
o`1D103o05`40?l0H`<0o`1[0`3o07<30?l0NP<0o`221@3oool100000040
oooo000V0?ooo`030000003oool0oooo00<0oooo0P3oRP030?n200<0ogX0
0`3oL`040?m[00@0of<00`3oG0040?mD00@0od`00`3oA@030?lm00<0ocD0
0P3o;P030?lV0080oah000<0oaL00?l?003o3`000P3o1`00?@3o000004Oo
0?l0003o00L0o`0?0?l05`3o01h0o`0V0?l0;P3o03D0o`0m0?l0A@3o05@0
o`1L0?l0J`3o07<0o`220?l0RP3o09T0o`2X0?l0^03o0<L0o`3G0?l0iP3o
0?D0nP3o0><0o`3D0?l0a@3o0;D0o`2N0?l0S`3o07P0o`1X0?l0D@3o0480
o`0c0?l0703o00D0o`002_l0027o000ho`00Aol005ko001eo`00S?l00:?o
002jo`00dOl00>So003oo`00onP00?oI003o`P00oj/00?nL003oQ@00ogD0
0?mV003oGP00oeL00P00odl09000oeL00?mN003oM@00oh`00?n[003of@00
j?l00:?o001Go`050?l0L03o0>/0o`3o04D0ood00?nQ002eo`001Ol0003o
/`00U?l0703o0<`0o`3o08X005Oo0?n:003Lo`00HOl0003o2P00ofH00?nc
003on000dOl00:_o0025o`00K_l005ko001Go`8004oo03d005Oo001No`00
K_l007Go002<o`00W?l00;?o0032o`00fOl00?3o003on000on400?o:003o
/`00oi`00?n<003oM@00oeh00?m7003o<000ob400?l:00co000Lo`00<ol0
04;o001Io`00J?l007oo002?o`00Y_l00;Go0035o`00g?l00>_o003jo`00
ooD00?oV003oe`00olL00?nh003oZ000oiT00?n:003oNP00og<00?mS003o
G000od`00?m5003o?@00ocD00?l^003o9P00oah00?lG003o3`00o`L00?l0
0000>?l0o`000080o`0700<0o`0?0?l05`3o01L00P3o01h30?l09P80o`0^
0`3o03D30?l0?@<0o`15103o04`40?l0E0<0o`1L103o06<40?l0J`<0o`1c
0`3o07X30?l0PP80o`2:1@3oool100000040oooo000V0?ooo`030000003o
ool0oooo00<0oooo0P3oT@020?n:00@0oh800`3oNP030?mc00@0of/0103o
H`030?mL00<0oe@0103oC0030?m500<0ocd00P3o=@030?l^0080obH00P3o
7P00103o5`00o`l00?l?003o1`030?l0000h0?l01`3o00l0o`0?0?l05`3o
01h0o`0V0?l0;P3o03d0o`150?l0C03o05@0o`1S0?l0J`3o07X0o`220?l0
T@3o0:40o`2`0?l0^03o0<L0o`3G0?l0iP3o0?D0l`3o0><0o`3D0?l0a@3o
0;D0o`2V0?l0S`3o07l0o`1`0?l0F@3o04X0o`0j0?l08`3o01@0o`000_l0
017o000Xo`00?ol004oo001^o`00MOl009Co002So`00^_l00<[o003Qo`00
l?l00?oh003ol000omT00?o:003o^P00ok<4003oZ`0W003o^P00olX00?oX
003oo`00b_l00:_o001No`00:?l0>P3o07l0o`3j0?l0o`2Q01@0o`3oL`00
onh007So0000ob400?nj002So`002_l0U`3o0?l0e`3o04D0oj400?nX003S
o`00Ool002_o0000obP00?mV003oZ`00olX00?oo003Ao`00b_l00;?o002[
o`00Xol00:_o00800;?o03D00<;o003:o`00hOl00?3o003on000oo000?oI
003obP00oj/00?nS003oQ@00ogD00?mN003oC`00ocP00?lX003o4@00o`80
5?l002?o000jo`00B_l0067o001`o`00Ool008oo002Vo`00]Ol00<Go003D
o`00jol00??o003om@00onH00?oG003oa`00okP00?n`003oV@00oi400?n2
003oNP00of/00?mS003oE000od`00?m5003o=@00obh00?lV003o7P00oaL0
0?l?00020?l700050?nA003o0000o`070?l01`3o00l00P3o01L20?l07P80
o`0V0`3o02h20?l0=@<0o`0m0`3o04D40?l0C0<0o`1D0`3o05`40?l0H`@0
o`1[0`3o07<30?l0NP<0o`220`3o08X20?l0T@D0oooo0@0000010?ooo`00
9P3oool00`000000oooo0?ooo`030?ooo`040?nI003oT@00oi400?nA00<0
ohX00`3oPP030?mj00<0og<0103oJ`040?mS00<0oe`00`3oE0040?m<0080
odD00`3o?@020?le0080obh00P3o9P020?lN0080oaL00P3o3`00=`3o1`00
o`000?l03`3o0000o`070?l03`3o01L0o`0N0?l09P3o02h0o`0e0?l0?@3o
04D0o`1D0?l0G03o06<0o`1c0?l0NP3o08X0o`2A0?l0Z03o0;00o`2o0?l0
c`3o0=h0o`3V0?l0o@3j0?l0h`3o0=`0o`350?l0]@3o09h0o`2G0?l0O`3o
07P0o`1Q0?l0D@3o03X0o`0c0?l0503o00`0o`002_l0027o000`o`00Aol0
05Oo001^o`00OOl009Co002Lo`00/ol00;[o003Ao`00fOl00P00l?l01000
ool00?oh003on000ooP2003oo`0U003Xo`00fOl00;[o002So`00I_l004Oo
00`0o`0j0?l0WP3o0=`0o`3o09T0o`1<0?m[003oV@00e?l0057o0000ocP0
0?o2002co`008Ol0H@3o0>/0o`3o09T0o`150?m<003oZ000g?l009ko000j
o`003?l0003oA`00ofH00?nS003obP00omT00?oh003oo`04003ho`0f003o
n000oo000?oQ003of@00olX00?nj003oZ`00oi`00?n5003oO@00oeh00?mG
003o?`00oc000?lI003o2P0<o`005?l003?o000jo`00DOl0067o001ho`00
Ool009Oo002No`00]Ol00<Go003Lo`00hol00?[o003oo@00onH00?oN003o
a`00okl00?n`003oZ000oi400?n:003oNP00og<00?mS003oG000od`00?m5
003o?@00ocD00?l^003o9P00oah00?lG003o3`00o`L00`3o0000103o00L0
o`0?0?l05`3o01L20?l07P80o`0V0P3o02h30?l0=@<0o`0m0P3o04D40?l0
C0<0o`1D0`3o05`40?l0H`@0o`1[0`3o07<30?l0NP<0o`220`3o08X30?l0
T@030?l0V@3oool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000
oooo0?ooo`030?ooo`040?nQ003oV@00oiT00?nI0080oi400`3oRP030?n2
00@0ogX00`3oL`030?m[00@0of<00`3oG0030?mD00<0od`00`3oA@020?lm
00<0ocD00P3o;P020?lV00040?lN003o5`00oaL00?l?0080o`L003L0o`00
000Xo`3o00L0o`070?l03`3o01L0o`0N0?l09P3o03D0o`0m0?l0A@3o04`0
o`1D0?l0H`3o06/0o`1j0?l0PP3o0940o`2I0?l0Z03o0;P0o`370?l0e`3o
0=h0o`3^0?l0o@3c0?l0h`3o0=@0o`350?l0]@3o0:H0o`2G0?l0Q`3o0700
o`1X0?l0D@3o0480o`0c0?l08`3o00`0o`000_l0017o000Xo`00<?l004Oo
001?o`00I_l006ko0025o`00S?l009co002So`00/ol00;[o00@00<;o02P0
0;?o002[o`00U?l008Go001No`00Aol000[o01@0o`1Q0?l0S`3o0>/0o`3o
0<l0o`1D003o`P3oG000oll00;Go000jo`000?m7003obP00/ol0033o0540
o`3<0?l0o`2o0?l0C000`_l0of<00?o?003Lo`00Sol005Wo000Do`000?lA
003oA`00ogD00?n5003oX`00oj/00?nj0`00ol82003o^P0g003oZ`00oj<0
0?nD003oS000ogd00?m^003oGP00odl00?lo003o<000oaT00?lA00Go000<
o`008ol003?o001:o`00DOl006So001`o`00Qol009Oo002Vo`00]Ol00<Go
003Do`00hol00??o003oo@00onh00?oN003oe`00okl00?nh003oZ000oiT0
0?nA003oPP00og<00?m[003oH`00oe@00?m<003oA@00ocD00?l^003o9P00
oah00?lG003o3`00o`L00?l00000fOl0o`000?l01`020?l03`80o`0G00<0
o`0N0?l09P3o02H00P3o02h30?l0=@80o`0m0`3o04D30?l0C0<0o`1D0`3o
05`40?l0H`<0o`1[0`3o07<40?l0NP<0o`220P3o08X30?l0T@<0o`2I00<0
o`2Q0?ooo`3oool00`3oool100000040oooo000V0?ooo`030000003oool0
oooo00<0oooo0`3oX@030?nI0080oi40103oRP030?n200<0ogX00`3oL`04
0?m[00<0of<00`3oG0030?mD00<0od`00P3oA@020?lm0080ocD00P3o;P02
0?lV0080oah00P3o5`000`3o3`00o`L00?l000020?l0000`0?l01`3o00l0
o`0G0?l07P3o02H0o`0^0?l0=@3o03d0o`150?l0E03o05`0o`1S0?l0J`3o
07X0o`220?l0T@3o0:40o`2`0?l0^03o0<L0o`3?0?l0iP3o0>h0o`3m0?<0
o`3S0?l0g03o0<D0o`2m0?l0YP3o09h0o`270?l0O`3o06P0o`1Q0?l0BP3o
0480o`0[0?l0503o00`0o`000_l0017o000Qo`00:?l003oo0017o`00Eol0
05ko0P00K_l2001mo`8008Go02T007go001eo`00I_l005ko0017o`00<?l0
00[o00`0o`1:0?l0J03o0;D0o`3S0?l0o`2h0?l0PP3o04`0od`00?nQ003o
o@00Qol001co0000oeL00?oA002jo`00Aol0:`3o09L0o`3o0?d0o`2A0?l0
9P3o=@00oh800?no003So`00]Ol006So001:o`003?l0003o8@00oc000?mG
003oGP02003oM@0c003oO@00ohD00?n5003oO@00ogD00?m^003oIP00oeh0
0?m?003oA`00ocP00?lX003o6@00oa401Ol000co000So`00:ol004;o001:
o`00HOl006So001oo`00Qol009ko002Vo`00_Ol00<Go003Lo`00hol00??o
003oo@00onh00?oV003oc`00olL00?nh003o/000oiT00?nA003oPP00ogX0
0?m[003oH`00oe`00?mD003oA@00ocd00?le003o9P00oah00080oaL000@0
o`l00?l7003o9P00o`000P3o00L0103o00l0o`0G0?l05`3o01h20?l09P80
o`0^0P3o03D30?l0?@80o`150`3o04`30?l0E0<0o`1L0`3o06<40?l0J`<0
o`1c0`3o07X30?l0PP<0o`2:0`3o09430?l0V@80o`2Q00<0o`2X0?ooo`3o
ool00`3oool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo
0P3oZ0030?nQ00<0oiT00`3oT@030?n:00<0oh800`3oNP040?mc00<0of/0
0`3oH`030?mL00<0oe@00P3oC0020?m500<0ocd00P3o=@020?l^00040?lV
003o7P00oah00?lG0080o`l002l0o`L00?l00000okX0o`000?l01`3o00l0
o`0G0?l07P3o02H0o`0^0?l0=@3o04D0o`1<0?l0E03o05`0o`1[0?l0L`3o
0880o`2:0?l0V@3o0:40o`2`0?l0_`3o0<L0o`3G0?l0iP3o0?D0o`3m0?<0
o`3S0?l0e03o0<`0o`2m0?l0[P3o09h0o`2?0?l0O`3o07P0o`1Q0?l0F@3o
04X0o`0c0?l0:`3o01`0o`0D0?l01@3o000:o`02000Io`04000Xo`00<?l0
03So000oo`@004Oo0P00>?l0:P008Ol001Wo00D0o`0D0?l0@P3o05T0o`2G
0?l0]@3o0?X0o`3o0=L0o`220?l0A@3o=@00of<00?no003Lo`00N?l000co
0000oeh00?oA0032o`00Col0703o08L0o`3[0?l0o`2`0?l0E03o00l0odD0
0?nA003oe`00lol00;Go002?o`00FOl002_o000Do`000?l:003o6@00oc00
0?lh003o?`<00?m70P00ocl0<000ocP00?l`003o8@00oaT00?lA003o2P0<
o`005?l002?o000[o`00@_l004[o001Io`00HOl007So001oo`00Uol009ko
002^o`00_Ol00<co003Do`00jol00??o003oo@00ooD00?oN003oe`00olL0
0?no003o/000oj400?nA003oRP00ogX00?mc003oJ`00oe`00?mD003oC000
ocd00?le003o;P00obH00?lN003o5`00o`l00?l700<0o`0000@0o`070?l0
3`3o01L0o`0G0P3o01h00`3o02H0o`0^0?l0;P020?l0=@<0o`0m0P3o04D2
0?l0C0<0o`1D0`3o05`30?l0H`<0o`1[103o07<30?l0NP<0o`220`3o08X3
0?l0T@<0o`2I0P3o0:420?l0Z0030?l0/03oool0oooo00<0oooo0@000001
0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`80ok000P3oZ0030?nQ
00<0oiT00`3oT@030?n:00<0oh800`3oNP040?mc0080of/0103oH`020?mL
00<0oe@00`3oC0000`3oA@00ocd00?lm00020?le0080obh00P3o9P020?lN
00060?lG003o3`00o`L00?l7003o0000o`150P3o00L20?l05`80o`0V0P3o
03D09@3o04D0o`1<0?l0G03o05`0o`1[0?l0L`3o0880o`2:0?l0V@3o0:40
o`2`0?l0^03o0<L0o`3?0?l0iP3o0>h0o`3m0?X0o`3[0?l0g03o0<`0o`35
0?l0]@3o0:h0o`2G0?l0S`3o07l0o`1h0?l0H@3o0540o`1:0?l0>P3o03<0
o`0S0?l0703o01@0o`0<0?l00P000_l2000:o`80017o0P002_l0;@050?l0
303o01`0o`0[0?l0BP3o05T0o`270?l0WP3o0=`0o`3j0?l0o`2h0?l0T@3o
02H0o`1<0?mD003oT@00ood00;Go001Ao`000?lA003oM@00omT00<[o001V
o`000_l0H@3o0;d0o`3o0>h0o`2A0?l0A@3oC000ocD00?nA003o^000n_l0
0=co002No`00L?l005Wo000jo`00:ol001Co000<o`000?l2003o2P03003o
4@800?l:02<00?l200Go000<o`005?l001co000[o`00<ol004;o001:o`00
FOl0067o001ho`00Ool008oo002Go`00[_l00;Go0035o`00c?l00=co003[
o`00n_l00?om003okP00onH00?o?003oa`00okP00?n`003oX@00oiT00?n:
003oPP00og<00?m[00020?mL000=0?m<003oA@00ocD00?l^003o9P00oah0
0?lG003o3`00o`L00?l0003oA@00o`000?l01`020?l03`040?l05`3o01h0
o`0V0?l09P80o`0^0P3o03D20?l0?@80o`150`3o04`30?l0E080o`1L103o
06<20?l0J`@0o`1c0`3o07X30?l0PP<0o`2:0`3o09430?l0V@80o`2Q0`3o
0:P20?l0/0D0oooo0@0000010?ooo`009P3oool3000000<0oooo0P3o^002
0?n`0080ojP00`3oX@030?nI00<0oi400`3oRP030?n200<0ogX0103oL`02
0?m[00<0of<00`3oG0020?mD00<0od`00P3oA@020?lm0080ocD000@0obh0
0?lV003o9P00oah00P3o5`000`3o3`00o`L00?l700020?l0000V0?l01`3o
00l0o`0G0?l07P3o02H0o`0^0?l0=@3o03d0o`150?l0E03o05`0o`1S0?l0
J`3o07X0o`220?l0T@3o09T0o`2X0?l0/03o0;l0o`370?l0e`3o0=h0o`3^
0?l0m@3j0?l0l`3o0><0o`3D0?l0a@3o0;d0o`2^0?l0YP3o09L0o`2?0?l0
O`3o0700o`1X0?l205T0o`0404X0o`120?l0>P3o03<0o`80:`3o100S0?l0
8@0[0?l0<`3o03X0o`120?l0F@3o06P0o`270?l0WP3o0<`0o`3S0?l0o`3V
0?l0_`3o0880o`1D05T0o`3o=@00og<00?no003[o`00Uol004;o0000oaT0
0?me003of@00b_l006ko000:o`1:0?l0YP3o0?X0o`3o0;P0o`1[0?l05`02
0?mD000:0?nA003o_`00onh00>?o002eo`00W_l007So001Xo`00DOl004;o
0080<ol01@0So`0202_o000_03?o000jo`00@_l0057o001Io`00HOl006So
001ho`00Ool008oo002Go`00Y_l00:ko002mo`00aOl00=co003So`00lol0
0?[o003om@00onh00?oN003oe`00olL00?no003o/000ojP00?nI003oT@00
oh800?mj003oJ`00of<00?mL003oE000odD00?lm003o=@00obh00?lV003o
7P00oaL00?l?003o1`00oe`00?l0003o00L00P3o00l0103o01L0o`0N0?l0
7P3o02H20?l0;P80o`0e0P3o03d20?l0A@<0o`1<0P3o05@30?l0G0<0o`1S
0P3o06/40?l0L`<0o`1j0`3o08830?l0RP<0o`2A0`3o09T20?l0X@<0o`2X
0P3o0;020?l0^0@0oooo0P0000010?ooo`009P3oool00`000000oooo0?oo
o`030?ooo`030?no003o^000okP000<0ok000P3oZ0030?nQ00<0oiT00`3o
T@030?n:00<0oh800`3oNP040?mc0080of/00`3oH`030?mL0080oe@00P3o
C0020?m50080ocd000<0ocD00?l^003o;P000P3o9P020?lN000>0?lG003o
3`00o`L00?l7003ogP00o`000?l01`3o00l0o`0G0?l07P3o02H0o`0^0?l0
=@3o03d20?l0C00M0?l0G03o06<0o`1c0?l0L`3o0880o`2:0?l0V@3o0:40
o`2`0?l0^03o0<L0o`3?0?l0gP3o0>H0o`3e0?l0o@3c0?l0j`3o0=`0o`3D
0?l0a@3o0;d0o`2^0?l0YP3o09h0o`2?0?l0Q`3o07l0o`1h0?l00P1X0?l0
0`1Q0?l0F@3o0540o`040540o`0^05T0o`1Q0?l0J03o07P0o`1o0?l0U`3o
0:H0o`350?l0g03o0?l0m@3o0=h0o`2X0?l0RP3o04D0o`070?lN003oE000
ok000?oV002mo`00N?l002?o0000oc000?n5003of@00dOl007Go000Qo`0[
0?l0O`3o0<`0o`3o0>H0o`2Q0?l0E03o01h0o`L00?m5003oRP00ojP00?oN
003co`00g?l00;Go002Vo`00Qol007oo0080J?l00P1Io`04057o0080FOl0
01`0HOl006So001`o`00N?l007oo0027o`00Uol009ko002Vo`00[_l00;go
0035o`00e?l00=co003[o`00lol00?om003om@00onH00?oN003oc`00olL0
0?nh003o/000oj400?nI003oRP00oh800P3oL`001`3oH`00oe`00?m<003o
C000ocd00?le003o;P000P3o7P000`3o5`00o`l00?l700020?l000040?l0
1`3o00l0o`0?0?l05`80o`0N00<0o`0V0?l0;P3o02h00P3o03D20?l0?@80
o`150P3o04`20?l0E0<0o`1L0`3o06<20?l0J`@0o`1c0`3o07X30?l0PP<0
o`2:0`3o09430?l0V@80o`2Q0`3o0:P30?l0/080o`2h00<0o`2o0?ooo`3o
ool00`3oool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo
0`3o_`020?nh00<0ok000P3oZ0030?nQ00<0oiT00`3oT@030?n:00<0oh80
0`3oNP030?mc00<0of/00P3oH`030?mL0080oe@00P3oC0020?m50080ocd0
0P3o=@00103o;P00obH00?lV003o7P020?lG000]0?l?003o1`00o`0001`0
o`3o0000o`070?l03`3o01L0o`0N0?l09P3o02h0o`0e0?l0?@3o04D0o`1D
0?l0G03o06<0o`1[0?l0NP3o0880o`2:0?l0V@3o0:40o`2X0?l0^03o0;l0
o`3?0?l0e`3o0>H0o`3^0?l0m@3o0?d0l`3o0>/0o`3L0?l0e03o0<`0o`35
0?l0]@3o0:h0o`2V0?l0WP3o09L0o`2?0?l0Q`3o00<0O`3o0P1h0?l207l0
o`0`08L0o`2?0?l0U`3o0:H0o`2e0?l0c03o0=`0o`3o0?d0o`3^0?l0a`3o
0:P0o`1j0?l0E03o00000?n<0?m<003oPP00olL00??o002^o`00HOl001Co
0000ocP00?n<003of@00dOl007go000`o`0S0?l0L03o0;D0o`3o0?d0o`2o
0?l0NP3o03d00=7o0?lN003oE000ogX00?nX003oe`00onh00>_o003Lo`00
_Ol00;Go002No`00Uol00P27o`0207oo0080N?l00P1oo`0208Oo000>08oo
002Go`00W_l00:Ko002^o`00]Ol00<Go003<o`00e?l00=co003[o`00lol0
0?om003om@020?oV000I0?oG003oc`00okl00?nh003oZ000oj400?nA003o
RP00oh800?mj003oJ`00of<00?mL003oE000odD00?lm003o=@00obh00?lV
003o7P00oaL00?l?003o1`00o`00002Lo`020?l01`050?l03`3o01L0o`0N
0?l07P3o02H00P3o02h20?l0=@80o`0m0P3o04D20?l0C080o`1D0`3o05`2
0?l0H`<0o`1[0`3o07<30?l0NP<0o`220`3o08X30?l0T@<0o`2I0P3o0:43
0?l0Z0<0o`2`0P3o0;P20?l0_`030?l0a`3oool0oooo00<0oooo0@000001
0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`80olL00P3o_`030?nh
00<0ok000P3oZ0030?nQ00<0oiT00`3oT@030?n:00<0oh800`3oNP030?mc
00<0of/00P3oH`020?mL0080oe@00P3oC0020?m50080ocd00P3o=@000`3o
;P00obH00?lV00020?lN000>0?lG003o3`00o`L00?l7003o07<0o`000?l0
1`3o00l0o`0G0?l07P3o02H0o`0^0?l0=@3o03d20?l0C00:0?l0G03o06<0
o`1[0?l0L`3o0880o`2:0?l0T@3o09T0o`2X0?l0/080o`2o00/0o`3?0?l0
e`3o0>H0o`3^0?l0m@3o0?d0l`3o0>/0o`3S0?l0g03o0=@0o`020<D0o`04
0;d0o`2e0?l0[P3o0:h0o`H0YP3o03@0[P3o0;D0o`350?l0c03o0=`0o`3S
0?l0o`3m0?l0kP3o0<l0o`2h0?l0RP3o07<0o`0m0?l01`3o=@00ocd00?n2
003oZ000ooD00=Co0027o`00B_l0003o0P00odl00?nD003oh@00dOl008co
000oo`050?l0BP3o08l0o`3D0?l0o`3^0?l0Z03o07X0o`0m0?l05`3o1`00
ocd00?mc003oX@00okP00?oN003okP00lol00>?o003Do`00c?l00;go002e
o`00[_l01P2Vo`004@2^o`00]Ol00;Go002mo`00aOl00<co003Do`00g?l0
0>?o003[o`00lol00?om003om@00onh00?oV003oe`00oll00080okl000X0
ok000?nX003oV@00oi400?n:003oPP00og<00?m[003oH`00oe`00P3oC000
203o?@00ocD00?l^003o9P00oah00?lG003o3`00o`L00P3o0000103o00L0
o`0?0?l03`3o01L20?l07P030?l09P3o02h0o`0^0080o`0e0P3o03d20?l0
A@80o`1<0P3o05@20?l0G080o`1S0`3o06/30?l0L`<0o`1j0`3o08830?l0
RP<0o`2A0`3o09T30?l0X@80o`2X0`3o0;020?l0^080o`2o0`3o0<L50?oo
o`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool20?o?0080
olL00P3o_`030?nh00<0ok000P3oZ0030?nQ00<0oiT00`3oT@030?n:00<0
oh800`3oNP020?mc00<0of/00P3oH`020?mL0080oe@00P3oC0020?m50080
ocd00P3o=@020?l^000R0?lV003o7P00oaL00?lG003o3`00o`L00?l0000j
0?l0o`000?l01`3o00l0o`0G0?l07P3o02H0o`0^0?l0=@3o03d0o`150?l0
E03o05`0o`1S0?l0J`3o07<0o`1j0?l0RP3o0940o`2I0?l0X@3o0:P0o`2`
0?l0_`3o0<L0o`3?0?l0e`80o`3V00D0o`3e0?l0o@3j0?l0l`3o0>/0o`02
0><0o`030=`0o`3D0?l0c03o00H0c03o0380e03o0=`0o`3S0?l0j`3o0?X0
o`3o0?D0o`3V0?l0c`3o0;l0o`2Q0?l0RP3o06<0o`150?l01`00oeh0ocD0
0?mS003oV@00oll00??o002eo`00N?l003?o0000oa400?mG003oW000on40
0=Wo002<o`00Aol000;o0480o`1o0?l0_@3o0?X0o`3o0<L0o`2A0?l0G03o
02h00?3o0?lN003oA@00og<00?n:003o/000okl00?oN003oiP00ood00?[o
0080hol00P3Do`060<co0080e?l000P0g?l00>?o003[o`00jol00??o003j
o`00ood00?oe0080onH000P0omL00?o?003oa`00okl00?n`003oZ000oj40
0?nI0080ohX000@0ogX00?mc003oJ`00of<00P3oE0003`3oA@00ocd00?le
003o;P00obH00?lN003o5`00o`l00?l7003o00000;[o0?l0003o00L0o`0?
0?l05`020?l07P030?l09P3o02h0o`0^0080o`0e00<0o`0m0?l0A@3o04D0
0P3o04`20?l0E0<0o`1L0P3o06<30?l0J`80o`1c0`3o07X30?l0PP<0o`2:
0`3o09430?l0V@<0o`2Q0P3o0:P30?l0/080o`2h0`3o0;l20?l0a`80o`3?
1@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo00<0
omL00?o?003oc`000`3oa`020?no00<0okP00`3o/0020?nX00<0oj400`3o
V@030?nA00<0ohX00`3oPP030?mj0080og<00P3oJ`030?mS0080oe`00P3o
E0020?m<0080odD00P3o?@00103o=@00obh00?lV003o9P020?lN000B0?lG
003o3`00o`L00?l7003o0940o`000?l01`3o00l0o`0G0?l07P3o02H0o`0^
0?l0=@3o03d0o`150?l0C03o05@0o`1L0P3o06/01P3o07X0o`220?l0RP3o
0940o`2I0?l0X@80o`2`00H0o`2o0?l0a`3o0<l0o`3G0?l0gP3o0>H20?l0
kP030?l0m@3o0?d0nP3o00<0l`3o103[0?l20?<0o`0=0?X0o`3o0?d0o`3e
0?l0iP3o0=h0o`370?l0^03o0:40o`2A0?l0J`3o05`0o`0V0?l000020?l^
000W0?m[003oRP00olL00?o^003<o`00W_l005Wo000Lo`000?lQ003oGP00
oj<00?oQ003Io`00W?l005Oo000Io`0S0?l0H@3o09h0o`3D0?l0o`3^0?l0
_`3o08X0o`1S0?l0;P3o00l0o`000?m5003oG000oh800?nA003o/000okP0
0?o?003ogP00onh00?oe003oo@00n_l00080lol0103[o`020??o0080n_l0
00X0ood00?oe003okP00onh00?oV003ogP00omL00?o?003oa`00okl00P3o
/0001P3oX@00oiT00?nA003oRP00oh800?mj0080of/000d0oe`00?mD003o
C000odD00?lm003o=@00obh00?lV003o7P00oaL00?l?003o1`00o`000080
o`070P3o00l0103o01L0o`0N0?l09P3o02H20?l0;P030?l0=@3o03d0o`0m
0080o`150P3o04`20?l0E080o`1L0`3o06<20?l0J`80o`1c0`3o07X30?l0
PP<0o`2:0`3o09430?l0V@<0o`2Q0P3o0:P30?l0/080o`2h0`3o0;l30?l0
a`80o`3?00<0o`3G0?ooo`3oool00`3oool100000040oooo000V0?ooo`03
0000003oool0oooo00<0oooo0P3oe`030?o?00<0olL00P3o_`020?nh00@0
ok000P3oZ0030?nQ00<0oiT00`3oT@030?n:0080oh800`3oNP030?mc0080
of/00P3oH`020?mL0080oe@00P3oC0020?m500030?lm003o=@00ocD00080
obh002@0obH00?lN003o5`00oaL00?l?003o1`00o`00003o>03o0000o`07
0?l03`3o01L0o`0N0?l09P3o02h0o`0e0?l0?@3o04D0o`1<0?l0E03o05`0
o`1S0?l0J`3o07<0o`1j0?l0PP3o08X0o`2A0?l0V@3o0:40o`2X0?l0/03o
0;P0o`2o0?l0a`3o0<l20?l0e`030?l0gP3o0>H0o`3V00<0o`3^0P3o0?D3
0?l0kP0h0?l0iP3o0=h0o`3G0?l0c`3o0;l0o`2`0?l0X@3o0940o`1j0?l0
H`3o04D0o`0^0;d0o`00oc00obh00?mD003oPP00ok000?oN003co`00_Ol0
08Oo001:o`005?l0003o:000ofH00?nS003oj000fOl009co001No`008Ol0
703o0540o`2?0?l0a@3o0?X0o`3o0=L0o`2X0?l0NP3o05@0o`0^000`o`3o
3`00obh00?mD003oH`00oh800?nA003oZ000ok000?o7003oc`00omL00?oN
003oiP030?o^0080ooD00`3okP020?oV000P0?oN003oe`00omL00?o?003o
a`00okl00?nh003o/000ojP00?nQ003oV@00oi400?n:003oPP00ogX00?mc
003oJ`00of<00?mL003oE000od`00?m5003o?@00ocD00?l^003o9P00oah0
0?lG003o3`00o`L00?l?0000>?l20?l01`050?l03`3o01L0o`0N0?l07P3o
02H00P3o02h00`3o03D0o`0m0?l0?@020?l0A@80o`1<0P3o05@20?l0G080
o`1S0P3o06/30?l0L`<0o`1j0P3o08830?l0RP<0o`2A0`3o09T30?l0X@80
o`2X103o0;020?l0^080o`2o0`3o0<L20?l0c`80o`3G00<0o`3N0?ooo`3o
ool00`3oool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo
0P3ogP020?oG0080oll00`3oa`030?no0080okP0103o/0020?nX00<0oj40
0`3oV@030?nA00<0ohX00P3oPP030?mj0080og<00P3oJ`020?mS0080oe`0
0P3oE0020?m<0080odD00P3o?@020?le00060?l^003o9P00oah00?lN003o
5`00o`l00P3o1`00103o0000o`2`0?l01`3o00l20?l05`80o`0V0100o`0^
0?l0=@3o03d0o`150?l0C03o05@0o`1L0?l0H`3o06/0o`1c0?l0NP3o0880
o`2:0?l0T@3o09T0o`2Q0P3o0:P0103o0;00o`2h0?l0_`3o0;l20?l0a`<0
o`3?0P3o0=L20?l0c`80o`3703D0o`2o0?l0^03o0;00o`2X0?l0V@3o08X0
o`1c0?l0J`3o04`0o`0m0?l01`3o0;P0oaL00?l^003oG000ogX00?n`003o
c`00n_l00=Co002Go`00J?l003?o0000o`800?lh003oM@00oj/00?oX003Q
o`00Xol006ko000`o`050?l0>P3o0700o`2N0?l0e03o0?l0o@3o0<l0o`2X
0?l0NP3o05`0o`0^0?l01`3o^000obh00?lm003oG000of/00?n2003oRP00
oj400?nX00020?nh0080olL00`3oc`000`3oe`00oll00?o?00020?o?0080
olL00P3o_`00503o^000ok000?nX003oZ000oj400?nI003oT@00ohX00?n2
003oNP00og<00?m[003oH`00oe`00?mD003oC000odD00?lm003o=@00obh0
0P3o9P020?lG00050?l?003o1`00ok000?l0003o00L00P3o00l01@3o01L0
o`0N0?l09P3o02H0o`0^0080o`0e00<0o`0m0?l0A@3o04D00P3o04`20?l0
E080o`1L0P3o06<30?l0J`80o`1c0`3o07X20?l0PP<0o`2:0`3o09430?l0
V@<0o`2Q0P3o0:P40?l0/080o`2h0`3o0;l20?l0a`80o`3?0`3o0=L20?l0
gPD0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`04
0?oV003ogP00omh00?oN0080omL00P3oc`030?o700<0okl00P3o^0030?n`
00<0ojP00`3oX@030?nI0080oi400`3oRP030?n20080ogX00`3oL`020?m[
0080of<00P3oG0020?mD0080od`000@0odD00?lm003o?@00ocD00P3o;P02
0?lV00050?lN003o5`00o`l00?l?003o1`000P3o00002@3o00L0o`0?0?l0
3`3o01L0o`0N0?l09P3o02h0o`0e0?l0?@020?l0A@80o`1D00@0o`1L0?l0
H`3o06/0o`1c0P3o07X00`3o0880o`2:0?l0T@020?l0V@030?l0X@3o0:P0
o`2X00<0o`2`103o0;P20?l0/080o`2X0P3o09T0=`3o08X0o`220?l0L`3o
06<0o`1D0?l0A@3o02h0o`0G0><0o`3o7P00ocD00?mD003oNP00oiT00?no
003okP00jol00;go0027o`00FOl002?o0000o`X00?lo003oM@00ok<00?oX
003Qo`00Zol006ko000ho`000_l0:`3o0640o`2?0?l0a@3o0>/0o`3o0>H0
o`2o0?l0V@3o07<0o`1<0?l09P3o00L0o`000?lG003o=@00odD00?mL003o
H`00ogX00?n2003oT@00oiT00?nQ003oZ0000`3o/0040?nh00<0ok000P3o
Z0001P3oX@00oiT00?nI003oT@00ohX00?n20080ogX000@0og<00?m[003o
H`00oe`00P3oE0020?m50080ocD000@0obh00?lV003o7P00oaL00P3o3`03
0?l000050?l01`3o00l0o`0G0?l05`3o01h00P3o02H0103o02h0o`0e0?l0
=@3o03d20?l0A@80o`1<0P3o05@20?l0G080o`1S0P3o06/30?l0L`80o`1j
0`3o08830?l0RP80o`2A0`3o09T30?l0X@<0o`2X0`3o0;020?l0^0<0o`2o
0P3o0<L30?l0c`80o`3G0`3o0=h00`3o0>H0oooo0?ooo`030?ooo`400000
0@3oool002H0oooo00<000000?ooo`3oool00`3oool30?oV0080omh00`3o
e`020?o?00<0olL00`3o_`020?nh00<0ok000`3oZ0030?nQ00<0oiT00P3o
T@030?n:00<0oh800P3oNP020?mc0080of/00P3oH`020?mL0080oe@00P3o
C0020?m500030?lm003o=@00ocD00080obh000H0obH00?lN003o5`00oaL0
0?l?003o1`030?l000030?l01`3o00l0o`0?0080o`0N00@0o`0V0?l0;P3o
03D0o`0m0P3o04D0103o04`0o`1D0?l0G03o06<20?l0J`040?l0L`3o07X0
o`1j0?l0PP80o`2:0P3o09470?l0V@80o`2A03L0o`2:0?l0PP3o07X0o`1c
0?l0J`3o06<0o`1<0?l0A@3o02h0o`0?0?l0c`3o5`00obH00?le003oG000
og<00?nQ003o^000onH00?[o0035o`00W_l0073o0012o`005?l0003o8@00
odl00?n5003o/`00onP00>7o002[o`00OOl004Oo000Io`0L0?l0BP3o07P0
o`2V0?l0c03o0?X0o`3o0>H0o`2h0?l0V@3o07<0o`1<0?l0=@3o00l0o`07
0?l0003o5`00ocD00?m5003oE000of<00080og<00P3oPP020?nA00P0oiT0
0P3oT@020?n:00040?n2003oNP00ogX00?mc0080of/000@0of<00?mL003o
E000od`00P3oA@00103o?@00ocD00?l^003o9P020?lN0080o`l0103o0000
0`3o00L0o`0?0?l05`020?l07P040?l09P3o02h0o`0^0?l0=@80o`0m0P3o
04D20?l0C080o`1D0P3o05`20?l0H`80o`1[0P3o07<20?l0NP<0o`220`3o
08X20?l0T@<0o`2I0`3o0:430?l0Z0<0o`2`0P3o0;P30?l0_`80o`370`3o
0<l30?l0e`80o`3N0P3o0>H00`3o0>h0oooo0?ooo`030?ooo`4000000@3o
ool002H0oooo00<000000?ooo`3oool00`3oool20?o^0080onH00`3ogP02
0?oG00<0oll00P3oa`030?no00<0okP00`3o/0030?nX00<0oj400P3oV@03
0?nA00<0ohX00P3oPP020?mj0080og<00`3oJ`020?mS0080oe`000<0oe@0
0?m<003oC0000P3oA@020?lm00040?le003o;P00obh00?lV0080oah000X0
oaL00?l?003o1`00o`L0003o0P2e0?l0o`000?l01`3o00l0o`0G0P3o01h0
103o02H0o`0^0?l0=@3o03D20?l0A@80o`1<00@0o`1D0?l0G03o06<0o`1S
0P3o06/20?l0L`<0o`1j103o08820?l0NP80o`1c03T0o`1[0?l0H`3o05`0
o`1D0?l0A@3o03d0o`0^0?l07P3o00001Ol00?lN003o9P00ocd00?mD003o
L`00oi400?nh003oe`00ood00=co002eo`00Sol0067o000co`001Ol0003o
:000oeL00?n5003o^P00onP00>7o002co`00OOl004oo000Qo`0<0?l0>P3o
06P0o`2G0?l0_@3o0><0o`3o0?D0o`3?0?l0/03o0940o`1[0?l0E03o03D0
o`0V00D0o`00oi`0o`l00?lN003o=@00ocd00?m<003oE0000P3oH`020?mc
0080ogX01@3oPP030?mj0080og<00P3oJ`020?mS00040?mL003oE000od`0
0?m<0080odD00P3o=@002P3o;P00obH00?lN003o7P00oaL00?l?003o1`00
o`00003obP000_l20?l01`030?l03`3o01L0o`0N0080o`0V00<0o`0^0?l0
=@3o03D00P3o03d00`3o04D0o`1<0?l0C0020?l0E080o`1L0P3o06<20?l0
J`80o`1c0`3o07X20?l0PP<0o`2:0P3o09430?l0V@<0o`2Q0`3o0:P30?l0
/080o`2h103o0;l20?l0a`<0o`3?0P3o0=L20?l0gP<0o`3V0P3o0>h50?oo
o`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool20?oe0080
onh00P3oiP020?oN00<0omL00`3oc`020?o700<0okl00`3o^0030?n`00<0
ojP00P3oX@030?nI00<0oi400P3oRP030?n20080ogX00P3oL`020?m[0080
of<00P3oG0020?mD0080od`00P3oA@00103o?@00ocD00?le003o;P020?lV
0080oah000X0oaL00?l?003o1`00o`L00?l0003o0>H0o`000?l01`3o00l0
o`0G0P3o01h0103o02H0o`0^0?l0=@3o03D20?l0?@030?l0A@3o04`0o`1<
0080o`1D0P3o05`40?l0H`80o`1[103o06<0?@3o05`0o`1D0?l0C03o04`0
o`0m0?l0=@3o02H0o`0?0?l0a`3o0?D0o`L00?lG003o=@00odD00?mS003o
L`00oiT00?n`003oe`00onh00>?o0035o`00Uol007So001:o`008ol0003o
2P00ocP00?mV003oS000okX00?oX003Xo`00^_l008co001No`00<?l000;o
02/0o`1A0?l0N03o09h0o`350?l0j`3o0?l0kP3o0=L0o`2`0?l0RP3o07<0
o`1D0?l0A@3o02H0o`0G0?l01`3om@00o`L00?lG003o;P00ocD00?m5003o
C0000P3oE000103oG000of<00?mS003oH`030?m[00@0of<00P3oG0020?mD
0080od`000<0odD00?lm003o?@000P3o=@002P3o;P00obH00?lN003o7P00
oaL00?l?003o1`00o`000?oV003o00020?l01`050?l03`3o01L0o`0N0?l0
7P3o02H00P3o02h20?l0=@040?l0?@3o04D0o`150?l0C080o`1D0P3o05`2
0?l0H`80o`1[0`3o07<20?l0NP<0o`220P3o08X30?l0T@<0o`2I0P3o0:43
0?l0Z0<0o`2`0`3o0;P30?l0_`80o`370`3o0<l20?l0e`<0o`3N0P3o0>H2
0?l0kP80o`3e1@3oool100000040oooo000V0?ooo`030000003oool0oooo
00<0oooo0`3om@020?o^00<0onH00P3ogP030?oG00<0oll00P3oa`030?no
00<0okP00`3o/0030?nX0080oj400`3oV@030?nA0080ohX00P3oPP030?mj
0080og<00P3oJ`020?mS0080oe`00P3oE0000`3oC000odD00?m500020?lm
00030?le003o;P00obh00080obH000P0oah00?lG003o3`00o`l00?l7003o
00008ol00>/0o`80o`0700@0o`0?0?l05`3o01L0o`0N0P3o02H20?l0;P80
o`0e0P3o03d20?l0A@@0o`1<0P3o05@30?l0C080o`150P3o03d0?@3o03D0
o`0^0?l07P3o01L0o`07003o8@3o3`00o`L00?lV003o=@00od`00?mS003o
NP00oi400?n`003oa`00onH00??o003Do`00]Ol008oo001Xo`00@_l001Co
0000oa400?lo003oIP00oi@00?o2003ol000j?l00;[o002<o`00G_l003So
000:o`0L0?l0@P3o0700o`2?0?l0]@3o0=`0o`3j0?l0o`3V0?l0a`3o0:P0
o`2A0?l0L`3o06<0o`150?l0=@3o01h0o`0702/0o`00oeh0o`l00?lG003o
9P00obh00?le003o?@000P3oA@040?m<0080oe@0103oC0020?m50080ocd0
0P3o=@020?l^0080obH000X0oah00?lG003o5`00o`l00?l7003o00000?n<
02<0o`3o0000o`070P3o00l01@3o01L0o`0N0?l09P3o02H0o`0^0080o`0e
0P3o03d00`3o04D0o`1<0?l0C0020?l0E080o`1L0P3o06<20?l0J`80o`1c
0`3o07X20?l0PP80o`2:0`3o09430?l0V@80o`2Q0`3o0:P30?l0/0<0o`2h
0`3o0;l20?l0a`<0o`3?0`3o0=L20?l0gP<0o`3V0P3o0>h20?l0m@030?l0
o@3oool0oooo00<0oooo0@0000010?ooo`009P3oool3000000<0oooo0P3o
o@020?oe00<0onh00P3oiP030?oN0080omL00`3oc`030?o700<0okl00`3o
^0020?n`00@0ojP00P3oX@030?nI00<0oi4000@0ohX00?n2003oPP00oh80
0P3oNP030?mc0080of/00P3oH`020?mL00030?mD003oC000od`00080odD0
00<0ocd00?le003o=@000P3o;P020?lV00040?lN003o5`00o`l00?l?0080
o`L000@0o`000?X0o`3o0000o`000P3o00l20?l05`80o`0N0P3o02H20?l0
;P@0o`0e103o03d30?l0=@80o`0^03d0o`0V0?l07P3o00l0o`070?l0RP3c
0?l0o`L00?l?003o9P00obh00?m5003oE000og<00?mj003oX@00ok000?o?
003oiP00lol00=co002eo`00W_l007So001Ao`00:ol000Go0000ob400?m7
003oM@00oi`00?o2003ol000j?l00;[o002Do`00K_l003oo000Io`0<0?l0
<`3o05T0o`1h0?l0WP3o0;d0o`3L0?l0nP3o0?l0iP3o0;l0o`2`0?l0RP3o
07X0o`1S0?l0E03o03d0o`0^0?l07P3o00l0o`070??o003o0000o`L00080
oah000<0obH00?l^003o=@000`3o=@040?lm00@0ocD00P3o;P020?lV0080
oah00P3o5`020?l?0080o`0000@0n_l00?l01`3o00L0o`070P3o00l01@3o
01L0o`0N0?l09P3o02H0o`0^0080o`0e0P3o03d20?l0A@80o`1<00<0o`1D
0?l0G03o05`00P3o06<20?l0J`<0o`1c0P3o07X20?l0PP80o`2:0`3o0943
0?l0V@80o`2Q103o0:P20?l0/0<0o`2h0`3o0;l30?l0a`<0o`3?0P3o0=L3
0?l0gP80o`3V0P3o0>h20?l0m@<0o`3m103oool200000040oooo000V0?oo
o`030000003oool0oooo00<0oooo00@0n_l00?om003oo@00ood00P3om@02
0?o^00<0onH00`3ogP020?oG00<0oll00`3oa`030?no00<0okP00P3o/003
0?nX00<0oj400P3oV@030?nA0080ohX00P3oPP030?mj0080og<00P3oJ`02
0?mS0080oe`00P3oE0020?m<00030?m5003o?@00ocd00080ocD00P3o;P00
0`3o9P00oah00?lN00020?lG00030?l?003o1`00o`000080>_l00P3o0002
0?l01`80o`0?0P3o01L40?l07PL0o`0V0P3o01h20?l05`80o`0703h0o`1c
04;o003o3`00o`L00?lV003o;P00ocd00?m<003oG000og<00?n2003oV@00
ok000?o7003ogP00ood00>_o003<o`00[_l008Oo001Xo`00@_l002?o0000
o`800?lX003oC`00ogD00?nL003obP00oo000>So0032o`00U?l006ko0017
o`008Ol01@3o02/0o`1:0?l0L03o08l0o`2^0?l0c03o0>/0o`3o0?D0o`3G
0?l0_`3o0:P0o`2I0?l0NP3o06/0o`1D0?l0C03o03D0o`0^0?l07P3o00L0
>P3o0480o`3o0000o`L00?l?0080oaL00P3o7P070?lV00@0oah00P3o5`02
0?l?0080o`L00P3o000203X0o`030?l0003o00L0o`0?0080o`0G00<0o`0N
0?l09P3o02H00P3o02h00`3o03D0o`0m0?l0?@020?l0A@80o`1<0P3o05@2
0?l0G080o`1S0P3o06/20?l0L`80o`1j0P3o08830?l0RP<0o`2A0P3o09T3
0?l0X@<0o`2X0P3o0;030?l0^0<0o`2o0`3o0<L30?l0c`80o`3G0`3o0=h2
0?l0iP<0o`3^0P3o0?D30?l0o@030?X0o`3oool0oooo00<0oooo0@000001
0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`<0n_l00P3oo@030?oe
0080onh00P3oiP040?oN0080omL00`3oc`030?o700<0okl00`3o^0020?n`
00<0ojP00`3oX@020?nI00<0oi400P3oRP020?n200<0ogX00P3oL`020?m[
0080of<00P3oG0020?mD0080od`000<0odD00?lm003o?@000P3o=@020?l^
0080obH00P3o7P000`3o5`00o`l00?l?00020?l70080o`0000<0h`3o0=`0
o`3o08X00`3o00090?l01`80o`000P3L0?l00`3S0?l0o`000?l700020?lG
000i0?lV003o;P00ocd00?m5003oG000of<00?mj003oRP00oj400?n`003o
c`00omh00?om003[o`00c?l00;Go002?o`00N?l0057o000co`003?l0003o
4@00ocP00?mG003oO@00oj<00?o:003ol000j?l00<;o002Lo`00MOl005Oo
000`o`002_l0503o03X0o`1I0?l0N03o09L0o`2e0?l0c03o0>/0o`3o0>h0
o`3N0?l0_`3o0;00o`2A0?l0RP3o07<0o`1S0?l0E03o04D0o`0e0?l0;P3o
01h0o`0G00<0o`0700<0hol00=co003Lo`000P3o00090?l700<0o`000P3L
o`000`3So`00o`070?l000020?l01`80o`0?00<0o`0G0?l07P3o01h00P3o
02H20?l0;P80o`0e00<0o`0m0?l0A@3o04D00P3o04`20?l0E080o`1L0P3o
06<20?l0J`80o`1c0P3o07X20?l0PP<0o`2:0`3o09420?l0V@<0o`2Q0`3o
0:P20?l0/0<0o`2h0`3o0;l30?l0a`<0o`3?0P3o0=L40?l0gP040?l0iP3o
0>h0o`3^0?l0kP<0o`3e0P3o0?d20?X0o`030?<0o`3oool0oooo00<0oooo
0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`80lol00P3j
o`020?om00<0ooD00`3okP020?oV00<0omh00`3oe`030?o?00<0olL00P3o
_`030?nh00<0ok000`3oZ0030?nQ0080oiT00`3oT@020?n:0080oh800P3o
NP030?mc0080of/00P3oH`020?mL0080oe@00P3oC0020?m500030?lm003o
=@00ocD00080obh00P3o9P020?lN0080oaL00`3o3`020?l000030?l7001I
o`00FOl000@0HOl000<00=Wo067o001Qo`000`1Qo`0205Wo00030?l?003o
1`00o`L00080oah003T0obh00?le003o?@00odD00?mD003oH`00og<00?mj
003oT@00oj400?n`003oa`00omh00?oe003co`00g?l00;go002Vo`00Qol0
06So001:o`00:ol000Go0000oaT00?lo003oGP00ohD00?nS003obP00oo00
0>So0032o`00Xol007go001Go`00>?l0017o00`0o`0[0?l0D@3o0700o`27
0?l0YP3o0<D0o`3L0?l0nP3o0?l0kP3o0=L0o`370?l0/03o0:40o`2:0?l0
NP3o06/0o`1L0?l0C03o04D00P3o03D01P3o02H0o`0N0?l05`3o00L0o`00
0?l01`80F@3o101Q0?l00`1:0?l0H@3o0640o`030640o`80F@3o00<0o`07
0?l0003o00000`3o00l20?l05`80o`0N0P3o02H20?l0;P80o`0e00<0o`0m
0?l0A@3o04D00P3o04`20?l0E080o`1L0P3o06<20?l0J`80o`1c0P3o07X3
0?l0PP80o`2:0`3o09420?l0V@<0o`2Q0`3o0:P20?l0/0@0o`2h0P3o0;l3
0?l0a`<0o`3?0`3o0=L30?l0gP80o`3V0`3o0>h20?l0m@<0o`3m0P3j0?l2
0?<0o`D0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?oo
o`030>_o003co`00lol000<0n_l00P3oo@030?oe00<0onh00P3oiP030?oN
00<0omL00`3oc`030?o70080okl0103o^0020?n`00<0ojP00P3oX@030?nI
00<0oi400P3oRP020?n20080ogX00`3oL`020?m[0080of<00P3oG0020?mD
0080od`00P3oA@020?lm0080ocD00`3o;P020?lV0080oah0103o5`040?l?
00@0o`L00`3o3`020?lG0080oah00P3o9P020?le000i0?m5003oC000oe@0
0?mL003oJ`00ogX00?n:003oT@00ojP00?nh003oc`00omh00?om003co`00
e?l00<Go002Vo`00Sol0073o001Io`00<ol001co0000o`X00?lX003oA`00
ofH00?n<003oZ`00om400?o`003Xo`00b_l00:?o0025o`00I_l003oo000Q
o`000_l0703o03X0o`1I0?l0N03o08l0o`2^0?l0a@3o0><0o`3c0?l0o`3^
0?l0gP3o0<L0o`2h0?l0X@3o0940o`220?l0NP3o06<0o`1L0080o`1<00@0
o`0m0?l0=@3o02h0o`0V0P3o01h20?l05`@0o`0?103o00L40?l03`@0o`0G
0P3o01h20?l09P<0o`0^0P3o03D20?l0?@80o`150P3o04`20?l0E080o`1L
0P3o06<20?l0J`80o`1c0P3o07X30?l0PP80o`2:0`3o09420?l0V@<0o`2Q
0`3o0:P20?l0/0@0o`2h0P3o0;l30?l0a`<0o`3?0`3o0=L30?l0gP80o`3V
0`3o0>h20?l0m@<0o`3m0`3j0?l20?<0o`030>/0o`3oool0oooo00<0oooo
0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`80jol00`3c
o`020?[o00<0ood00P3om@030?o^00<0onH00`3ogP030?oG0080oll0103o
a`020?no00<0okP00`3o/0030?nX0080oj400`3oV@030?nA0080ohX00P3o
PP020?mj00<0og<00P3oJ`020?mS0080oe`00`3oE0020?m<0080odD00P3o
?@030?le00<0obh00`3o9P0;0?lN00<0obH004D0obh00?le003o?@00ocd0
0?m5003oC000oe@00?mL003oJ`00og<00?n2003oT@00oiT00?nX003o_`00
oll00?oN003om@00n_l00>?o003<o`00]Ol009ko001oo`00J?l004[o000[
o`003?l0003o4@00oc000?m?003oKP00oh`00?n[003od@00oo000>So003:
o`00Zol008co001Vo`00Aol002So000:o`0D0?l0<`3o0540o`1X0?l0Q`3o
09h0o`2e0?l0e03o0><0o`3j0?l0o`3^0?l0e`3o0<L0o`2h0?l0Z03o09T0
o`2:0?l0NP3o07<0o`1S0?l0G03o05@0o`1<0?l0A@3o03d00P3o03D0103o
02h0o`0V0?l09P3o02H;0?l07P<0o`0V0`3o02h30?l0=@80o`0m0P3o04D2
0?l0C080o`1D0`3o05`20?l0H`80o`1[0P3o07<30?l0NP80o`220P3o08X3
0?l0T@80o`2I0`3o0:430?l0Z0<0o`2`0`3o0;P20?l0_`@0o`370P3o0<l3
0?l0e`<0o`3N0`3o0>H30?l0kP80o`3e0`3o0?d20?X0o`80l`3o0`3[0?l5
0?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool20>?o
0080jol00P3co`030?[o00<0ood00P3om@030?o^00<0onH00`3ogP030?oG
0080oll0103oa`020?no00@0okP00P3o/0030?nX0080oj400`3oV@030?nA
0080ohX00P3oPP030?mj0080og<00`3oJ`020?mS0080oe`00P3oE0030?m<
00<0odD00P3o?@040?le00/0obh00P3o=@020?lm0080odD00440od`00?mD
003oG000of<00?m[003oL`00oh800?n:003oV@00oj400?nh003o_`00omL0
0?oN003oo@00n_l00=co003<o`00]Ol009ko0027o`00L?l0057o000jo`00
7?l000Go0000oaT00?lh003oE`00ogD00?nD003o/`00om400?o`003`o`00
dOl00:_o002<o`00K_l004oo000ho`006Ol01@3o02<0o`0j0?l0F@3o0700
o`270?l0WP3o0;d0o`3<0?l0j`3o0?X0o`3o0>h0o`3N0?l0c`3o0;l0o`2`
0?l0X@3o0940o`2:0?l0NP3o07<0o`1[0?l0H`020?l0E0040?l0C03o04D0
o`0m0?l0?@<0o`0e2`3o02h40?l0=@80o`0m0`3o04D30?l0C080o`1D0P3o
05`20?l0H`<0o`1[0P3o07<20?l0NP<0o`220P3o08X30?l0T@80o`2I0`3o
0:430?l0Z080o`2`103o0;P20?l0_`@0o`370P3o0<l30?l0e`<0o`3N0`3o
0>H30?l0kP80o`3e0`3o0?d20?X0o`<0l`3o0P3[0?l20><0o`D0oooo0@00
00010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`<0hol00P3[o`03
0??o0080n_l00`3oo@030?oe00<0onh00`3oiP020?oN00@0omL00P3oc`03
0?o700<0okl00`3o^0030?n`00<0ojP00P3oX@030?nI00<0oi400P3oRP03
0?n20080ogX00`3oL`020?m[0080of<00`3oG0030?mD00<0od`0103oA@0;
0?lm00<0odD00P3oC000A@3oE000oe`00?mS003oH`00of/00?mc003oPP00
ohX00?nA003oX@00ojP00?nh003oa`00omL00?oV003om@00n_l00>?o003D
o`00_Ol00:Ko002?o`00N?l0067o001:o`00<ol001Co0000o`800?lQ003o
?`00oeh00?mm003oU000ok<00?oA003ol000l?l00=7o002co`00U?l007Go
001Go`00>?l0027o0002o`0L0?l0<`3o04X0o`1X0?l0O`3o09L0o`2^0?l0
a@3o0=`0o`3[0?l0nP3o0?l0m@3o0=h0o`3?0?l0_`3o0;P0o`2X0?l0V@3o
0940o`2:0?l0NP3o07<0o`1[0?l0H`020?l0G0030?l0E03o04`0o`1<00<0
o`152`3o03d40?l0A@<0o`1<0`3o05@30?l0G080o`1S0P3o06/30?l0L`80
o`1j0`3o08820?l0RP<0o`2A0P3o09T30?l0X@<0o`2X0`3o0;030?l0^080
o`2o103o0<L20?l0c`@0o`3G0P3o0=h30?l0iP<0o`3^0`3o0?D20?l0o@<0
nP3o0`3c0?l20>/0o`80h`3o00<0g03o0?ooo`3oool00`3oool100000040
oooo000V0?ooo`030000003oool0oooo00<0oooo0P3Lo`020>?o00<0jol0
0`3co`020?[o00<0ood00`3om@020?o^00@0onH00P3ogP040?oG00<0oll0
0`3oa`020?no00<0okP00`3o/0030?nX00<0oj400`3oV@020?nA00<0ohX0
0P3oPP030?mj0080og<00`3oJ`030?mS00@0oe`0103oE00<0?m<0080oe@0
0P3oG0001`3oH`00of/00?m[003oL`00ogX00?n2003oRP000P3oV@00?`3o
Z000ok000?no003oc`00omh00?oV003oo@00n_l00>?o003Do`00_Ol00:ko
002Go`00Ool006So001Ao`00>_l002?o0005o`000?lA003o<000odL00?mV
003oO@00oi`00?nj003of@00oo000?3o003Ao`00/ol009co001mo`00G_l0
04Oo000Xo`004Ol0303o02<0o`0j0?l0D@3o06P0o`1o0?l0WP3o0:h0o`35
0?l0e03o0>/0o`3j0?l0o`3e0?l0iP3o0=L0o`3?0?l0^03o0;00o`2Q0?l0
V@3o0940o`2:0?l0PP3o07X0o`1c0?l0J`020?l0H`80o`1L0P3o05@<0?l0
C0@0o`1D103o05`30?l0H`<0o`1[0P3o07<30?l0NP80o`220P3o08X30?l0
T@<0o`2I0`3o0:430?l0Z080o`2`103o0;P20?l0_`<0o`370`3o0<l40?l0
e`80o`3N103o0>H20?l0kP<0o`3e0`3o0?d20?X0o`<0l`3o0P3[0?l30><0
o`80g03o1@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0
oooo00<0e?l00=co003Lo`000`3So`020>_o00<0lol00`3jo`020?om00<0
ooD00`3okP030?oV00<0omh0103oe`030?o?00<0olL00`3o_`020?nh00@0
ok000P3oZ0030?nQ00<0oiT00P3oT@040?n:0080oh800`3oNP030?mc00@0
of/0103oH`0=0?mL00<0of<000@0of/00?mc003oL`00ogX00P3oPP00@P3o
RP00oi400?nI003oZ000ok000?nh003oa`00oll00?oN003okP00ood00??o
003So`00e?l00<Go002^o`00W_l008Oo001`o`00HOl004[o000co`005?l0
003o0P00oaT00?l`003oC`00ofH00?n5003oX`00okX00?oI003ol000l?l0
0=7o002jo`00W?l007go001Vo`00Aol0033o000Io`050?l0703o03<0o`1:
0?l0H@3o07P0o`2?0?l0WP3o0;D0o`350?l0g03o0>/0o`3j0?l0o`3e0?l0
iP3o0=h0o`3?0?l0_`3o0;P0o`2`0?l0X@3o09T0o`2A0?l0RP80o`2200@0
o`1j0?l0L`3o06/0o`1[0`3o06<=0?l0G0@0o`1S103o06/30?l0L`80o`1j
0`3o08830?l0RP<0o`2A0`3o09T20?l0X@<0o`2X0`3o0;030?l0^0<0o`2o
0`3o0<L30?l0c`@0o`3G0P3o0=h40?l0iP80o`3^103o0?D20?l0o@<0nP3o
0`3c0?l20>/0o`<0h`3o0P3L0?l00`3D0?l0oooo0?ooo`030?ooo`400000
0@3oool002H0oooo00<000000?ooo`3oool00`3oool20=Co00<0g?l00P3S
o`030>_o00<0lol00`3jo`020?om00@0ooD00P3okP040?oV00<0omh00`3o
e`030?o?00<0olL00`3o_`030?nh00<0ok000`3oZ0030?nQ0080oiT0103o
T@020?n:00@0oh800`3oNP040?mc00L0of/0103oH`050?m[00<0og<004@0
ogX00?n2003oPP00ohX00?nA003oV@00oj400?nX003o/000okP00?no003o
c`00omL00?oV003okP00n_l00??o003So`00e?l00;go002eo`00W_l008oo
001ho`00HOl004[o000jo`008ol000co0000o`X00?lX003o?`00oeL00?m^
003oS000oj<00?o2003of@00ooP00?3o003Io`00^_l00:?o0025o`00K_l0
05Oo000ho`008Ol000[o00`0o`0S0?l0>P3o0540o`1X0?l0O`3o08l0o`2V
0?l0]@3o0<`0o`3D0?l0j`3o0?<0o`3o0?D0o`3^0?l0gP3o0=L0o`370?l0
_`80o`2`0P3o0:420?l0T@040?l0RP3o0880o`1j0?l0NP<0o`1c1@3o06/4
0?l0H`L0o`1[103o07<30?l0NP<0o`220`3o08X30?l0T@<0o`2I0`3o0:43
0?l0Z0<0o`2`0`3o0;P30?l0_`<0o`370`3o0<l30?l0e`<0o`3N103o0>H2
0?l0kP@0o`3e0P3o0?d30?X0o`<0l`3o0`3[0?l20><0o`80g03o0`3D0?l5
0?ooo`4000000@3oool001<0oooo0P0000040?ooo`030000003oool0oooo
0080oooo100000040?ooo`030000003oool0oooo00<0oooo00@0c?l00=Co
003Do`00e?l00P3Lo`030>?o00<0jol00P3co`030?[o00<0ood00`3om@03
0?o^00@0onH00`3ogP030?oG00<0oll00`3oa`030?no00<0okP00`3o/004
0?nX0080oj40103oV@030?nA00<0ohX0103oPP060?mj00T0og<0103oNP03
0?n200160?n:003oT@00oi400?nI003oX@00ojP00?n`003o^000okl00?o7
003oc`00omh00?oV003om@00ood00??o003So`00e?l00<Go002eo`00Y_l0
09Oo001oo`00L?l005Wo0012o`00<ol001co0005o`000?lA003o:000ocl0
0?mN003oM@00oh`00?nS003o`P00omT00?oh003`o`00fOl00;[o002So`00
S?l006ko001Go`00?ol002So000Ao`050?l0703o03<0o`1:0?l0F@3o0700
o`1o0?l0U`3o0:H0o`2m0?l0a@3o0=`0o`3S0?l0l`3o0?l0o@3o0>h0o`3V
0?l0e`3o0<l0o`370?l0_`80o`2`00<0o`2X0?l0X@3o09T00P3o0940103o
08X0o`220?l0PP3o08840?l0NPT0o`1c1P3o07X40?l0PP<0o`2:0`3o0943
0?l0V@<0o`2Q0`3o0:P40?l0/080o`2h103o0;l30?l0a`<0o`3?0`3o0=L3
0?l0gP@0o`3V0`3o0>h30?l0m@<0o`3m0`3j0?l20?<0o`<0j`3o0`3S0?l2
0=`0o`<0e03o00<0c03o0?ooo`3oool00`3oool100000040oooo000B0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`80c?l00`3Do`030=co0080hol00`3[o`03
0??o00<0n_l00`3oo@040?oe0080onh0103oiP030?oN00<0omL00`3oc`04
0?o700<0okl00`3o^0030?n`00<0ojP0103oX@040?nI00<0oi401@3oRP0>
0?n200<0ohX00`3oT@000`3oV@00oj400?nX00020?n`000m0?nh003o_`00
olL00?o?003ogP00onH00?o^003om@00n_l00>_o003Lo`00e?l00<Go002e
o`00Y_l009Oo001oo`00L?l005Wo001:o`00<ol002?o000<o`000?l:003o
8@00ocP00?m?003oIP00ogd00?nD003oZ`00ol800?oI003on000l?l00=Wo
0032o`00Zol008co001eo`00G_l004Oo000`o`006Ol000;o00`0o`0S0?l0
>P3o04X0o`1X0?l0L03o08L0o`2G0?l0[P3o0;D0o`3<0?l0e03o0><0o`3[
0?l0o`3m0?l0m@020?l0iP060?l0e`3o0<l0o`370?l0_`3o0;P0o`2`0P3o
0:P00`3o0:40o`2I0?l0T@020?l0T@<0o`2:3P3o08850?l0RP<0o`2A103o
09T30?l0X@@0o`2X0`3o0;030?l0^0<0o`2o0`3o0<L40?l0c`<0o`3G0`3o
0=h40?l0iP80o`3^103o0?D30?l0o@<0nP3o0`3c0?l20>/0o`<0h`3o0`3L
0?l20=@0o`80c03o00<0a@3o0?ooo`3oool00`3oool100000040oooo000B
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103o
ool3000000<0oooo00@0aOl00<co003<o`00c?l00P3Do`030=co00<0hol0
0`3[o`030??o00<0n_l00`3oo@030?oe00@0onh00`3oiP030?oN00@0omL0
0`3oc`030?o700@0okl00`3o^0030?n`00@0ojP0103oX@040?nI00L0oi40
1`3oRP050?nA00<0oiT00P3oX@00B`3oZ000ok000?nh003o^000okl00?o7
003oc`00omL00?oN003oiP00ooD00?om003jo`00jol00>?o003Do`00aOl0
0;Go002Vo`00Uol008Oo001ho`00J?l0057o0012o`00:ol001co0005o`00
0?lA003o8@00ocP00?m?003oIP00ogd00?nD003oZ`00ol800?oQ003on000
l?l00=Wo0032o`00Zol009Co001mo`00I_l004oo000ho`008Ol000[o00D0
o`0L0?l0<`3o0480o`1I0?l0J03o07P0o`2?0?l0WP3o0:h0o`2m0?l0a@3o
0=@0o`3S0?l0l`3o0?X0o`3o0?d0o`3^0?l0iP3o0=h0o`3G0?l0c`3o0<L0
o`2o0?l0^0020?l0/0030?l0Z03o0:40o`2Q00<0o`2I1@3o09470?l0RPL0
o`2A103o09T40?l0X@<0o`2X103o0;030?l0^0@0o`2o0`3o0<L30?l0c`@0
o`3G0`3o0=h30?l0iP<0o`3^103o0?D30?l0o@<0nP3o0`3c0?l30>/0o`<0
h`3o0P3L0?l30=@0o`80c03o0P350?l40?ooo`8000000@3oool00180oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo0`35o`030<co0080e?l00`3Lo`030>?o00<0
jol00`3co`030?[o00<0ood0103om@030?o^00<0onH0103ogP030?oG00@0
oll00`3oa`030?no00@0okP0103o/0040?nX00H0oj403P3oV@040?nQ0080
ojP00P3o/0000`3o^000okl00?no00020?o?00160?oG003ogP00onH00?o^
003oo@00n_l00??o003[o`00g?l00<co002mo`00]Ol00:Ko002Go`00Qol0
07So001Xo`00FOl004;o000co`008ol000co0000o`X00?lI003o<000odL0
0?mG003oKP00ohD00?nL003o/`00olX00?oQ003on000l?l00=Wo0032o`00
Zol009Co0025o`00K_l005Oo000oo`00:?l001Wo0002o`0<0?l08`3o03<0
o`1:0?l0F@3o0700o`1h0?l0S`3o09L0o`2^0?l0]@3o0<D0o`3<0?l0h`3o
0>/0o`3c0?l0nP3o0?l0m@3o0>h0o`3V0?l0gP3o0=L0o`3?0?l0a`80o`2o
00<0o`2h0?l0/03o0;000P3o0:P40?l0X@h0o`2I1P3o0:430?l0Z0@0o`2`
103o0;P40?l0_`<0o`370`3o0<l40?l0e`@0o`3N0`3o0>H30?l0kP@0o`3e
0`3o0?d30?X0o`<0l`3o0`3[0?l30><0o`80g03o0`3D0?l30<`0o`80a@3o
00<0_@3o0?ooo`3oool00`3oool100000040oooo000B0?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`80_Ol00P35o`030<co00<0e?l00`3Lo`030>?o00<0jol0
0`3co`030?[o00<0ood0103om@030?o^00@0onH00`3ogP040?oG00<0oll0
103oa`040?no00@0okP01@3o/0070?nX00P0oj401@3oZ0030?n`0080okP0
0P3o_`00C03oa`00oll00?o?003oe`00omh00?oV003okP00ooD00?om003j
o`00lol00>?o003Lo`00c?l00<Go002eo`00Y_l009ko002?o`00Ool0073o
001Qo`00DOl003[o000[o`007?l000Go0000o`X00?lQ003o<000odL00?mN
003oM@00ohD00?nL003o/`00olX00?oQ003on000l?l00=Wo003:o`00/ol0
09co0025o`00K_l005Oo0017o`00<?l001Wo000:o`0<0?l0703o02/0o`12
0?l0D@3o0640o`1`0?l0O`3o08l0o`2N0?l0[P3o0;d0o`350?l0e03o0=`0
o`3[0?l0l`3o0?X0o`3o0?d0o`3e0?l0kP3o0>H0o`3N0?l0e`3o0<l20?l0
a`80o`2o0P3o0;P30?l0/0D0o`2X203o0:470?l0Z0@0o`2`103o0;P40?l0
_`@0o`37103o0<l40?l0e`<0o`3N103o0>H30?l0kP@0o`3e0`3o0?d30?X0
o`<0l`3o0`3[0?l30><0o`<0g03o0`3D0?l30<`0o`80a@3o0P2m0?l50?oo
o`4000000@3oool00180oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo0`2mo`03
0<Go0080c?l0103Do`020=co00@0hol00`3[o`030??o00@0n_l00`3oo@03
0?oe00@0onh00`3oiP040?oN00@0omL0103oc`040?o700@0okl01P3o^00A
0?n`00<0okP00P3o_`020?o70080oll000T0omL00?oN003ogP00onH00?o^
003om@00ood00?[o003co`000P3So`00>`3Do`00c?l00;go002eo`00Y_l0
09ko0027o`00Ool0073o001Qo`00DOl004;o000co`007?l000co0000o`80
0?lI003o:000ocl00?m?003oIP00ogD00?n<003oX`00okX00?o:003oh@00
ooP00?3o003Qo`00b_l00;?o002Lo`00S?l007Go001No`00Col003So000X
o`004Ol000;o00`0o`0S0?l0<`3o0480o`1I0?l0H@3o07P0o`1o0?l0S`3o
09h0o`2^0?l0]@3o0<D0o`3<0?l0g03o0><0o`3[0?l0l`3o0080o`3m0P3o
0>h0103o0>H0o`3N0?l0e`3o0=L20?l0c`80o`370P3o0;l30?l0^140o`2`
1@3o0;P40?l0_`D0o`37103o0<l30?l0e`@0o`3N103o0>H40?l0kP<0o`3e
0`3o0?d40?X0o`<0l`3o0`3[0?l40><0o`80g03o0`3D0?l30<`0o`<0a@3o
0P2m0?l00`2e0?l0oooo0?ooo`030?ooo`4000000@3oool001<0oooo0P00
000:0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`80]Ol00P2m
o`030<Go00<0c?l00`3Do`030=co00<0hol0103[o`030??o00@0n_l00`3o
o@040?oe00@0onh00`3oiP040?oN00D0omL0103oc`050?o700H0okl03@3o
^0040?no00<0olL00P3oc`020?oG0080omh000<0onH00?o^003om@000P3o
o@00@`3jo`00jol00>?o003Lo`00e?l00<co002mo`00]Ol00:Ko002No`00
Sol007oo001ho`00J?l005Wo001:o`00>_l002_o000Do`001Ol0003o2P00
oaT00?l`003o?`00oeL00?mV003oO@00oi@00?nS003o^P00olX00?oQ003o
n000l?l00>7o003:o`00/ol00:?o002<o`00MOl006Ko001?o`00?ol002So
000Io`002_l0303o01`0o`0[0?l0>P3o04X0o`1I0?l0J03o07P0o`270?l0
S`3o09h0o`2^0?l0]@3o0<D0o`3<0?l0e03o0=`0o`3[0?l0l`3o0?X0o`3o
0?d00P3o0?D0103o0>h0o`3V0?l0gP3o0=h20?l0e`80o`3?0`3o0<L40?l0
_`d0o`2h1P3o0;l50?l0a`@0o`3?1@3o0=L40?l0gP<0o`3V103o0>h40?l0
m@<0o`3m103j0?l30?<0o`<0j`3o103S0?l30=`0o`<0e03o0`3<0?l20<D0
o`<0_@3o0P2e0?l50?ooo`4000000@3oool002H0oooo00<000000?ooo`3o
ool00`3oool0102^o`00]Ol00;Go002eo`020;go00<0aOl00`3<o`030=Co
00<0g?l0103So`030>_o00<0lol0103jo`040?om00@0ooD00`3okP040?oV
00D0omh01@3oe`050?o?00P0olL01`3o_`060?o700@0oll00P3oe`020?oN
0080onH000<0onh00?oe003oo@000P3jo`020>_o0080g?l003L0c?l00<Go
002eo`00[_l00:Ko002No`00Sol007oo001`o`00J?l005Wo001:o`00>_l0
02_o000Lo`003?l0003o0P00oa400?lX003o>000odL00?mN003oKP00ohD0
0?nD003oZ`00okX00?oA003oh@00ooP00?So003Qo`00b_l00;[o002So`00
U?l007go001^o`00Eol004Oo000ho`008Ol0017o0002o`0<0?l08`3o02/0
o`120?l0BP3o0640o`1X0?l0N03o07l0o`2G0?l0WP3o0080[P3o00P0_@3o
0<D0o`3D0?l0g03o0><0o`3[0?l0l`3o0?X0o`80o`3m00@0o`3e0?l0kP3o
0>H0o`3V0P3o0=h20?l0e`@0o`3?1P3o0<L70?l0_`P0o`371@3o0<l50?l0
e`@0o`3N103o0>H40?l0kP@0o`3e103o0?d40?X0o`<0l`3o0`3[0?l40><0
o`<0g03o0`3D0?l30<`0o`80a@3o0`2m0?l30;D0o`030:h0o`3oool0oooo
00<0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`80
[_l00`2eo`030;go00<0aOl00`3<o`030=Co00<0g?l0103So`030>_o00@0
lol0103jo`030?om00D0ooD0103okP040?oV00D0omh01P3oe`0C0?o?00@0
omL00`3ogP020?oV0080onh004d0ooD00?om003oo@00n_l00??o003[o`00
hol00=co003Do`00c?l00<Go002mo`00[_l00:Ko002No`00Sol008Oo001h
o`00J?l0067o001Ao`00@_l003?o000So`005?l000Go0000o`X00?lI003o
:000ocl00?m?003oGP00ogD00?n5003oU000oj/00?nj003od@00on400?oh
003ho`00hOl00=7o002jo`00Zol009Co0025o`00K_l005ko001?o`00>?l0
02So000Io`002_l01@3o01`0o`0[0?l0>P3o0480o`1A0?l0H@3o0700o`1h
0?l0Q`3o08l0o`2N0?l0YP3o0;D0o`2m0?l0a@3o0<`0o`3D0?l0g03o0><0
o`3[0?l0l`3o0?X0o`020?l0o@030?l0m@3o0>h0o`3^0080o`3V0`3o0=h4
0?l0ea<0o`3?1P3o0=L40?l0gPD0o`3V103o0>h40?l0m@@0o`3m103j0?l4
0?<0o`<0j`3o103S0?l30=`0o`<0e03o0`3<0?l30<D0o`<0_@3o0`2e0?l2
0:h0o`D0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?oo
o`040:Ko002^o`00[_l00:ko0080]Ol0102mo`020<Go00@0c?l00`3Do`03
0=co00@0hol0103[o`040??o00@0n_l00`3oo@050?oe00D0onh01@3oiP06
0?oN0140omL0103ogP040?oV0080onh00P3om@00AP3oo@00n_l00?[o003c
o`00jol00>?o003Lo`00e?l00<co0035o`00_Ol00;Go002^o`00W_l009Oo
002?o`00Ool007So001Xo`00HOl0057o0012o`00>_l002_o000Lo`003?l0
003o0P00oa400?lQ003o>000odL00?mG003oIP00ogD00?n<003oW000oj/0
0?o2003od@00onP00?oh003ho`00hOl00=7o002jo`00Zol009co0025o`00
MOl006Ko001Go`00?ol0033o000Qo`004Ol000;o00`0o`0L0?l0:`3o03X0
o`1:0?l0D@3o0640o`1X0?l0N03o07l0o`2?0?l0U`3o0:H0o`2^0?l20;d0
o`80c03o0P3L0?l00`3S0?l0j`3o0?<0o`020?X0o`030?l0o@3o0?D0o`3e
0080o`3^103o0>H40?l0gQ40o`3G1P3o0=h50?l0iPD0o`3^103o0?D40?l0
o@@0nP3o103c0?l40>/0o`@0h`3o0`3L0?l30=@0o`@0c03o0P350?l30;d0
o`<0]@3o0`2^0?l00`2V0?l0oooo0?ooo`030?ooo`4000000@3oool002H0
oooo00<000000?ooo`3oool00`3oool20:Ko00<0[_l00`2eo`030;go00<0
aOl00`3<o`040=Co00<0g?l0103So`040>_o00@0lol0103jo`050?om00D0
ooD01@3okP080?oV00h0omh01@3oiP030?o^00<0ooD00P3oo@00103jo`00
lol00??o003[o`020>?o00190=co003Do`00c?l00<Go002mo`00]Ol00:ko
002Vo`00Uol008oo0027o`00N?l0073o001Qo`00FOl004[o000jo`00<ol0
02?o000Do`001Ol0003o2P00oaT00?lX003o>000odL00?mG003oKP00ogd0
0?n<003oW000ok<00?o2003od@00onP00?oh003ho`00hOl00=7o0032o`00
Zol009co002<o`00MOl006Ko001Go`00Aol003So000Xo`006Ol000[o00D0
o`0D0?l08`3o03<0o`120?l0BP3o05T0o`1X0?l0L03o07P0o`270?l0S`3o
09h0o`2V0?l0[P3o0;D0o`2m0?l0a@3o0<`0o`3D0?l0g03o0><0o`020>/0
o`030?<0o`3j0?l0nP3o0080o`3m0`3o0?D30?l0kPD0o`3V3P3o0=h70?l0
iPH0o`3^1@3o0?D50?l0o@@0nP3o103c0?l40>/0o`@0h`3o0`3L0?l30=@0
o`@0c03o0`350?l30;d0o`<0]@3o0`2^0?l20:H0o`D0oooo0@0000010?oo
o`009P3oool00`000000oooo0?ooo`030?ooo`0409ko002Vo`00Y_l00:Ko
0080[_l0102eo`030;go00<0aOl0103<o`030=Co00@0g?l0103So`040>_o
00D0lol0103jo`050?om00H0ooD0203okP0<0?oV00H0onh00`3om@030?om
0080n_l00P3co`00@P3[o`00hol00>?o003Lo`00e?l00<co0035o`00_Ol0
0;Go002^o`00Y_l009ko002Go`00Qol007oo001ho`00L?l0067o001Io`00
B_l004;o000co`008ol001Co000<o`000?l2003o4@00ob400?l`003o?`00
odl00?mN003oKP00ohD00?nD003oX`00ok<00?o2003of@00onP00?oh003h
o`00hOl00=7o0032o`00/ol00:?o002<o`00OOl006ko001No`00Col003oo
000`o`008Ol0017o0002o`0<0?l0703o02<0o`0c0?l0@P3o0540o`1I0?l0
J03o0700o`80O`3o00@0S`3o09L0o`2N0?l0YP3o0P2e0?l20<D0o`030<`0
o`3D0?l0g03o0080h`3o00<0j`3o0?<0o`3c0?l00P3j0?l30?l0o@<0o`3e
1P3o0>h<0?l0iPP0o`3^1P3o0?D50?l0o@@0nP3o1@3c0?l40>/0o`@0h`3o
103L0?l30=@0o`@0c03o0`350?l30;d0o`<0]@3o0`2^0?l30:H0o`0309h0
o`3oool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000oooo0?oo
o`030?ooo`80W_l00`2Vo`030:ko00<0]Ol00`2mo`040<Go00@0c?l00`3D
o`040=co00@0hol01@3[o`050??o00D0n_l01P3oo@090?oe00X0onh01`3o
m@030?om00<0n_l00P3co`020>_o0080hol004d0g?l00=Co003<o`00c?l0
0<Go002mo`00]Ol00:ko002Vo`00W_l009Oo002?o`00Qol007So001`o`00
J?l005Wo001Ao`00@_l003[o000[o`007?l001Co0005o`000?l:003o6@00
obP00?lh003oA`00oeL00?mV003oM@00ohD00?nD003oX`00ok<00?o2003o
f@00onP00?oh003ho`00j?l00=7o0032o`00/ol00:?o002Do`00QOl006ko
001No`00Col003oo000`o`008Ol001Wo000:o`050?l0503o02<0o`0[0?l0
>P3o0480o`1A0?l0F@3o06P0o`1`0?l0N03o08L0o`2?0?l0U`3o09h0o`2V
0?l0[P3o0;D0o`2m0?l0a@3o0<`0o`020=@0o`030=`0o`3S0?l0h`3o0080
j`3o0P3c0?l30?X0o`<0o`3m1`3o0?D:0?l0kPT0o`3e1P3o0?d50?X0o`D0
l`3o103[0?l50><0o`@0g03o0`3D0?l40<`0o`<0a@3o102m0?l30;D0o`<0
[P3o0`2V0?l209h0o`D0oooo0@0000010?ooo`009P3oool00`000000oooo
0?ooo`030?ooo`0409Oo002No`00W_l009ko00<0Y_l00`2^o`030;Go00@0
_Ol00`35o`040<co00@0e?l0103Lo`050>?o00@0jol01P3co`060?[o00T0
ood02P3om@070?om00<0n_l00`3co`020>_o0080hol00P3Lo`020=Co0005
0<co0035o`00_Ol00;Go002^o`000P2Vo`00?@2Go`00Sol008Oo001oo`00
N?l0073o001Qo`00FOl0057o0012o`00>_l002_o000Lo`005?l000Go0000
o`800?lA003o8@00oc000?lo003oC`00oeh00?m^003oO@00oh`00?nL003o
Z`00okX00?o:003of@00onP00?oh003ho`00j?l00=Wo0032o`00/ol00:?o
002Do`00QOl007Go001Vo`00Eol004Oo000ho`00<?l0027o000Ao`000_l0
303o01@0o`0S0?l0:`3o03X0o`120?l0D@3o05T0o`1X0?l0L03o07P0o`1o
0?l00P2?0?l0102N0?l0YP3o0:h0o`2^0?l20;d0o`040<D0o`3<0?l0e03o
0=@0o`80g03o0P3S0?l20>/0o`<0l`3o0`3j0?l70?l0o@X0o`3e2@3o0?d6
0?X0o`D0l`3o1@3[0?l50><0o`@0g03o103D0?l40<`0o`<0a@3o102m0?l3
0;D0o`<0[P3o0`2V0?l309h0o`0309L0o`3oool0oooo00<0oooo0@000001
0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`80Uol00`2No`030:Ko
00@0[_l00`2eo`040;go00<0aOl0103<o`040=Co00D0g?l01@3So`050>_o
00L0lol02@3jo`090?om00P0n_l00`3co`030>_o00<0hol00P3Lo`00103D
o`00c?l00<co0035o`020;go00150;Go002^o`00Y_l009ko002Go`00Sol0
08Oo001oo`00N?l0073o001Xo`00FOl0057o001:o`00>_l003?o000So`00
7?l000co0005o`000?l:003o6@00obP00?l`003o?`00odl00?mN003oKP00
ogd00?n<003oW000oj/00?nj003obP00omT00?oX003on000n?l00>So003I
o`00b_l00;[o002[o`00W?l008co001mo`00K_l005ko001?o`00?ol0033o
000Qo`006Ol000[o00D0o`0<0?l0703o02/0o`0c0?l0@P3o04X0o`1A0?l0
H@3o06P0o`1`0?l0N03o07l0o`270?l0U`3o0080WP3o00@0YP3o0:h0o`2e
0?l0_@3o0P350?l00`3<0?l0e03o0=@0o`020=`0o`<0h`3o0P3[0?l40?<0
o`P0nP3o203o0?d:0?X0o`L0l`3o1@3[0?l50><0o`@0g03o1@3D0?l40<`0
o`<0a@3o102m0?l30;D0o`@0[P3o0`2V0?l309h0o`80U`3o1@3oool10000
0040oooo000V0?ooo`030000003oool0oooo00<0oooo00@0Sol009Oo002G
o`00Uol00`2No`030:Ko00@0[_l00`2eo`040;go00@0aOl0103<o`050=Co
00D0g?l01@3So`070>_o00X0lol0203jo`080??o00@0jol00P3So`030=co
0080e?l00P3<o`001P35o`00_Ol00;go002eo`00[_l00:Ko0080W_l004D0
Uol008oo0027o`00Ool007So001`o`00HOl005Wo001Ao`00B_l003[o000c
o`008ol001co000<o`001Ol0003o2P00oa400?lQ003o<000ocP00?m7003o
E`00ofH00?me003oQ@00oh`00?nL003oZ`00okX00?o:003of@00onP00?oh
003ho`00j?l00=Wo003:o`00^_l00:_o002Lo`00S?l007go001^o`00I_l0
05Oo0017o`00>?l002So000Io`004Ol000;o00D0o`0D0?l0703o02/0o`0c
0?l0@P3o04X0o`1A0?l0F@3o06P0o`1`0?l0N03o07l0o`270?l0S`3o09L0
o`2N0?l00P2V0?l01@2^0?l0]@3o0;d0o`2m0?l0a@3o0080c03o0P3D0?l3
0=`0o`80h`3o103[0?l80?<0o`P0nP3o2P3c0?l70>/0o`D0h`3o1@3L0?l5
0=@0o`@0c03o10350?l40;d0o`<0]@3o0`2^0?l40:H0o`<0WP3o0`2G0?l0
0`2?0?l0oooo0?ooo`030?ooo`4000000@3oool002H0oooo0`0000030?oo
o`80Sol00`2Go`0309ko00@0Y_l00`2^o`040;Go00@0_Ol01035o`050<co
00D0e?l01@3Lo`070>?o00X0jol02P3co`070>_o00@0hol00`3Lo`020=Co
00<0c?l000<0aOl00;go002mo`000P2eo`00BP2^o`00Y_l009ko002No`00
Uol008oo0027o`00Ool007So001`o`00J?l005Wo001Ao`00B_l004;o000c
o`00:ol002?o000Do`003?l0003o0P00o`X00?lI003o:000oc000?lo003o
C`00oeL00?mV003oM@00ohD00?nD003oX`00ok<00?nj003obP00omT00?oX
003on000n?l00>So003Io`00b_l00;[o002[o`00W?l008co0025o`00MOl0
06Ko001Go`00Aol003oo000`o`008Ol001Wo000:o`000_l0303o01@0o`0S
0?l0:`3o03X0o`120?l0BP3o0540o`1Q0?l0J03o0700o`1h0?l0O`3o08L0
o`2?0?l0U`3o0P2N0?l01@2V0?l0[P3o0;D0o`2e0?l0_@3o0080a@3o0P3<
0?l30=@0o`<0g03o103S0?l70>/0o`T0l`3o2`3[0?l70><0o`D0g03o1@3D
0?l50<`0o`@0a@3o102m0?l40;D0o`<0[P3o0`2V0?l409h0o`<0U`3o0P2?
0?l40?ooo`8000000@3oool002H0oooo00<000000?ooo`3oool00`3oool4
08oo00<0Uol00`2No`040:Ko00@0[_l0102eo`040;go00@0aOl01P3<o`05
0=Co00H0g?l02P3So`0;0>_o00L0hol0103Lo`040=Co0080c?l00P35o`02
0;go0080]Ol000<0[_l00:Ko002No`000P2Go`00@@2?o`00Qol007oo001h
o`00L?l006So001Qo`00FOl0057o001:o`00@_l003?o000[o`008ol001Co
000<o`001Ol0003o2P00oa400?lQ003o<000ocP00?m7003oE`00oeh00?m^
003oO@00oh`00?nD003oX`00ok<00?o2003od@00omT00?oX003on000n?l0
0>So003Io`00b_l00;[o002co`00Xol009Co0025o`00MOl006ko001No`00
Col004Oo000ho`00:?l0027o000Ao`002_l01@3o00`0o`0L0?l08`3o03<0
o`0j0?l0@P3o04X0o`1A0?l0F@3o0080J03o0P1h0?l208L0o`0608l0o`2G
0?l0WP3o09h0o`2V0?l0[P3o0P2e0?l20;d0o`80a@3o0P3<0?l40=@0o`@0
g03o1`3S0?l:0>/0o`X0h`3o1`3L0?l50=@0o`H0c03o10350?l40;d0o`@0
]@3o102^0?l30:H0o`@0WP3o0`2G0?l308l0o`0308L0o`3oool0oooo00<0
oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`80Qol0
0`2?o`0309Oo00@0W_l0102Vo`040:ko00@0]Ol0102mo`050<Go00H0c?l0
1P3Do`0:0=co00d0hol01`3Lo`040=Co00<0c?l00`35o`020;go0080]Ol0
00@0[_l00:Ko002Vo`00W_l00P2Go`00A@2?o`00Qol007oo001ho`00L?l0
06So001Qo`00FOl0057o001:o`00@_l003[o000co`008ol001co000Do`00
1Ol0003o0P00oa400?lI003o:000oc000?lo003oA`00oeL00?mV003oKP00
ogd00?n<003oW000oj<00?nc003o`P00om400?oQ003oj000ooP00?So003X
o`00fOl00<[o0032o`00/ol00:?o002Do`00S?l007go001^o`00G_l005Oo
0017o`00>?l0033o000Qo`006Ol000[o0002o`0<0?l0503o01`0o`0[0?l0
<`3o03X0o`120?l0BP3o05T0o`1Q0?l0J03o0700o`0207P0o`0407l0o`27
0?l0S`3o09L0o`80WP3o0P2V0?l00`2^0?l0]@3o0;D0o`020;d0o`<0a@3o
0`3<0?l40=@0o`L0g03o3@3S0?l90=`0o`L0e03o1P3<0?l40<D0o`D0_@3o
102e0?l40:h0o`@0YP3o0`2N0?l409L0o`<0S`3o0P270?l50?ooo`400000
0@3oool002H0oooo00<000000?ooo`3oool00`3oool408Oo00<0Sol00`2G
o`0409ko00@0Y_l0102^o`050;Go00D0_Ol01@35o`060<co00X0e?l03`3L
o`070=Co00@0c?l00P35o`030;go0080]Ol00P2^o`020:Ko000509ko002G
o`00Uol008oo0027o`000P1oo`00>P1ho`00L?l006So001Qo`00FOl0057o
001:o`00@_l003[o000[o`008ol001co000Do`001Ol0003o0P00o`X00?lI
003o8@00oc000?lh003oA`00odl00?mN003oIP00ogD00?n5003oS000oi`0
0?n[003o^P00ol800?oA003oh@00onP00?oh003ho`00j?l00=Wo003Ao`00
`_l00;?o002[o`00W?l008co001mo`00MOl006Ko001No`00Col003oo000h
o`00:?l0027o000Ao`002_l000;o00`0o`0D0?l202<0o`0:03<0o`0j0?l0
@P3o04X0o`1A0?l0F@3o0640o`1X0?l0L03o07P0o`80O`3o0P2?0?l209L0
o`0309h0o`2V0?l0YP3o0080[P3o0P2e0?l30;d0o`80a@3o103<0?l70=@0
o`l0g03o2@3D0?l70<`0o`D0a@3o1@2m0?l50;D0o`@0[P3o102V0?l309h0
o`@0U`3o0`2?0?l308L0o`0307l0o`3oool0oooo00<0oooo0@0000010?oo
o`009P3oool00`000000oooo0?ooo`030?ooo`80Ool00`27o`0408oo00<0
Uol0102No`040:Ko00D0[_l0102eo`060;go00H0aOl02@3<o`0C0=Co00H0
c?l01035o`030;go0080]Ol00P2^o`020:Ko0080W_l000@0Uol008oo002?
o`00Qol00P1oo`00B01ho`00L?l006So001Qo`00FOl0057o001:o`00@_l0
03[o000co`00:ol002?o000Do`003?l000Go0000o`800?lA003o6@00obP0
0?l`003o?`00odL00?mG003oGP00ofh00?me003oQ@00oi@00?nL003oZ`00
okX00?o2003od@00on400?o`003on000n?l00>So003Qo`00dOl00<;o002c
o`00Zol009co002<o`00QOl007Go001^o`00G_l004oo0017o`00>?l0033o
000Qo`006Ol0017o0002o`050?l0303o01`0o`0S0?l0:`3o03<0o`0j0?l0
@P3o04X0o`1A0?l0F@3o0640o`1X0?l0L03o07P0o`80O`3o00@0Q`3o08l0
o`2G0?l0U`3o0P2N0?l20:H0o`80[P3o0P2e0?l30;d0o`@0a@3o1P3<0?lC
0=@0o`T0c03o1P350?l50;d0o`D0]@3o1@2^0?l40:H0o`@0WP3o0`2G0?l4
08l0o`<0Q`3o0P1o0?l50?ooo`4000000@3oool002H0oooo00<000000?oo
o`3oool00`3oool407oo00<0Qol00`2?o`0409Oo00@0W_l01@2Vo`050:ko
00D0]Ol01`2mo`070<Go01H0c?l01P35o`030;go00<0]Ol00P2^o`030:Ko
0080W_l000<0Uol008oo002?o`000P27o`000`1oo`00N?l0073o000206So
0015067o001Io`00DOl004[o0012o`00>_l003?o000[o`008ol001Co000<
o`001Ol0003o0P00oa400?lI003o8@00oc000?lh003o?`00odl00?mG003o
IP00ofh00?mm003oS000oi@00?nS003oZ`00okX00?o:003od@00on400?o`
003on000n?l00>So003Qo`00dOl00<;o002jo`00Zol00:?o002Do`00QOl0
07go001^o`00I_l005Oo001?o`00?ol003So000Xo`008Ol0017o000:o`00
0_l01@3o01@0o`0L0?l08`3o02/0o`0c0?l0>P3o0480o`1:0?l0D@3o05T0
o`1Q0?l0J03o0080L03o00@0N03o07l0o`270?l0Q`3o0P2?0?l00`2G0?l0
WP3o09h0o`030:H0o`80[P3o0`2e0?l30;d0o`H0a@3o5@3<0?l80<D0o`L0
_@3o1@2e0?l50:h0o`D0YP3o102N0?l309L0o`@0S`3o0`270?l307l0o`03
07P0o`3oool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000oooo
0?ooo`030?ooo`0307So001oo`00Ool00080Ool01027o`0308oo00@0Uol0
1@2No`040:Ko00H0[_l01P2eo`080;go01P0aOl01P2mo`030;Go00<0[_l0
0`2Vo`0209ko0080Uol00P2?o`001@27o`00Ool007oo001ho`00L?l00080
J?l004L0HOl005Wo001Ao`00B_l004;o000jo`00<ol002_o000So`007?l0
01Co000<o`000?l2003o2P00oa400?lI003o:000oc000?lh003oA`00odl0
0?mN003oIP00ogD00?mm003oS000oi@00?nS003o/`00okX00?o:003od@00
on400?o`003on000n?l00>So003Qo`00dOl00<[o002jo`00Zol00:?o002D
o`00S?l007go001eo`00I_l005ko001?o`00Aol003So000`o`00:?l001Wo
000Ao`002_l01@3o00`0o`0D0?l0703o02<0o`0[0?l0<`3o03X0o`120?l0
BP3o0540o`1I0?l0H@3o06P0o`020700o`0407P0o`1o0?l0O`3o08L0o`80
S`3o0P2G0?l209h0o`<0YP3o0`2^0?l30;D0o`H0_@3o60350?l80;d0o`H0
]@3o1@2^0?l50:H0o`@0WP3o1@2G0?l308l0o`@0Q`3o0`1o0?l207P0o`D0
oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`@0N?l0
0`1oo`0408Oo00@0Sol0102Go`0509ko00D0Y_l01P2^o`070;Go01/0_Ol0
1P2eo`030:ko00<0Y_l00P2No`0209Oo0080Sol00P27o`0207oo0080N?l0
00<0L?l006So001Qo`000P1Io`00A@1Ao`00B_l004;o000jo`00<ol002_o
000So`007?l001Co000<o`000?l2003o2P00oa400?lI003o8@00oc000?lh
003o?`00odl00?mG003oIP00ofh00?me003oQ@00oh`00?nL003oX`00ok<0
0?o2003obP00omT00?oQ003ol000ooP00?So003`o`00hOl00=7o003:o`00
^_l00;?o002So`00W?l008co0025o`00MOl006ko001No`00Eol004Oo000o
o`00>?l002So000Qo`006Ol0017o000:o`050?l0303o01@0o`0L0?l08`3o
02/0o`0c0?l0>P3o0480o`1:0?l0D@3o05T0o`020640o`0406P0o`1`0?l0
N03o07P0o`80O`3o0P270?l208l0o`80U`3o0P2N0?l30:H0o`<0[P3o1P2e
0?lK0;d0o`L0]@3o1P2^0?l50:H0o`D0WP3o102G0?l408l0o`@0Q`3o0`1o
0?l407P0o`D0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`03
0?ooo`80L?l00`1ho`0407oo00@0Qol0102?o`0509Oo00D0W_l01@2Vo`08
0:ko00/0]Ol02P2mo`090;Go00D0[_l00`2Vo`0309ko0080Uol00P2?o`02
08Oo0080Ool00P1ho`02073o000306So001Qo`00FOl00080DOl00P12o`00
=@0jo`00<ol002_o000So`007?l001Co000<o`001Ol0003o2P00oa400?lI
003o8@00obP00?l`003o?`00odL00?mG003oGP00ofH00?me003oO@00ohD0
0?nD003oW000oj/00?nc003o`P00olX00?oI003oh@00oo000?oh003ho`00
l?l00>7o003Io`00b_l00<;o002co`00Zol009co002Do`00QOl007go001^
o`00I_l005ko001?o`00Aol003So000`o`00:?l0027o0080017o00`000;o
00D0o`0<0?l0503o01`0o`0S0?l0:`3o03<0o`0j0?l0@P3o04X0o`1A0?l2
05T0o`040640o`1X0?l0L03o0700o`80N03o0P1o0?l208L0o`80S`3o0P2G
0?l309h0o`<0YP3o1@2^0?l90;D0o`X0_@3o2`2e0?l80:h0o`D0YP3o1@2N
0?l509L0o`@0S`3o10270?l407l0o`<0N03o0P1`0?l50?ooo`4000000@3o
ool002H0oooo00<000000?ooo`3oool00`3oool3073o00@0N?l0101oo`04
08Oo00D0Sol0102Go`0609ko00L0Y_l02P2^o`0@0;Go00L0[_l01@2Vo`03
09ko00<0Uol00P2?o`0208Oo0080Ool00P1ho`02073o0080J?l000<0HOl0
05Wo001Ao`000P1:o`00A@12o`00>_l003?o000[o`008ol001co000Do`00
3?l000Go0000o`800?l:003o4@00oaT00?lX003o<000ocP00?lo003oC`00
oeL00?mN003oKP00ogD00?mm003oS000oi@00?nS003oZ`00ok<00?o2003o
bP00omT00?oQ003ol000ooP00?So003`o`00hOl00=Wo003:o`00`_l00;?o
002[o`00W?l009Co002<o`00OOl007Go001Vo`00G_l005Oo0017o`00?ol0
03So000Xo`008Ol001Wo000Ao`002_l000;o00D0o`0<0?l0503o01`0o`0S
0?l0:`3o03<0o`0j0?l0@P3o04X0o`020540o`0405T0o`1Q0?l0J03o06P0
o`80L03o0P1h0?l207l0o`80Q`3o0P2?0?l309L0o`<0WP3o1@2V0?l60:h0
oa40]@3o2P2^0?l70:H0o`H0WP3o102G0?l508l0o`@0Q`3o101o0?l407P0
o`<0L03o1@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0
oooo00<0J?l0073o001`o`000P1`o`0307So00D0Ool01027o`0508oo00H0
Uol01P2No`090:Ko01H0[_l01P2Vo`0409ko00<0Uol00`2?o`0208Oo0080
Ool00P1ho`02073o0080J?l00P1Qo`000`1Io`00DOl004[o000204;o000k
03[o000co`00:ol002?o000Lo`005?l000co0005o`000?l2003o2P00oa40
0?lI003o8@00obP00?lh003o?`00odL00?m?003oGP00ofH00?m^003oM@00
ohD00?n<003oW000oj<00?n[003o^P00ol800?oA003of@00onP00?o`003o
n000n?l00?3o003Qo`00fOl00<[o0032o`00^_l00:_o002So`00U?l008co
0025o`00MOl006ko001Vo`00Eol004oo0017o`00?ol0033o000Xo`008Ol0
01Wo000Ao`002_l00P050?l201@0o`808`3o00@0:`3o03<0o`0j0?l0@P3o
0P1:0?l0101A0?l0F@3o0640o`1Q0?l206P0o`80L03o0P1h0?l207l0o`80
Q`3o0`2?0?l309L0o`@0WP3o1P2V0?lF0:h0o`T0YP3o1P2N0?l609L0o`D0
S`3o10270?l407l0o`@0N03o101`0?l00`1X0?l0oooo0?ooo`030?ooo`40
00000@3oool002H0oooo00<000000?ooo`3oool00`3oool306So00<0L?l0
101ho`0507oo00D0Qol01@2?o`0709Oo00P0W_l06P2Vo`0509ko00@0Uol0
102?o`0208Oo0080Ool00P1ho`02073o0080J?l00P1Qo`0205Wo0003057o
001:o`00@_l00080>_l000D0<ol002_o000So`007?l001Co000200co000`
00Go0000o`X00?lA003o6@00ob400?lX003o<000ocP00?lo003oC`00oeL0
0?mN003oIP00ogD00?mm003oQ@00oh`00?nL003oX`00ok<00?nj003o`P00
om400?oI003oj000oo000?oh003ho`00l?l00>7o003Io`00dOl00<;o002j
o`00Zol00:?o002Lo`00S?l008Go001mo`00K_l006Ko001No`00Eol004Oo
000oo`00>?l0033o0P008Ol01P004Ol000[o0002o`050?l0303o01@0o`80
703o0P0[0?l01P0c0?l0>P3o0480o`120?l0BP3o0540o`80F@3o0P1Q0?l2
06P0o`80L03o0P1h0?l207l0o`80Q`3o102?0?l409L0o`D0WP3o6P2V0?l8
09h0o`L0U`3o1@2?0?l508L0o`@0O`3o101h0?l40700o`<0J03o1@3oool1
00000040oooo000V0?ooo`030000003oool0oooo00<0oooo101Xo`04073o
00D0N?l01@1oo`0508Oo00H0Sol01`2Go`0=09ko00P0Y_l02P2No`0509Oo
00<0Sol01027o`0207oo0080N?l00`1`o`000`1Xo`00HOl0067o000205Wo
0080DOl000<0B_l004;o000jo`000P0co`00100[o`008ol001co000Do`02
00co00800?l202d00?l:003o4@00ob400?lQ003o<000ocP00?lo003oA`00
odl00?mG003oIP00ofh00?me003oO@00oh`00?nD003oW000oj/00?nc003o
^P00olX00?oA003of@00onP00?o`003on000n?l00?3o003Qo`00fOl00=7o
0032o`00^_l00;?o002So`00W?l009Co0025o`00OOl007Go001^o`00G_l0
05Oo001?o`00Aol00P00>?l02000:?l0027o000Io`004Ol000[o0002o`05
0?l0303o0P0D0?l202<0o`0602/0o`0c0?l0>P3o03X0o`120?l0BP3o0P1A
0?l205T0o`80H@3o00@0J03o0700o`1`0?l0L03o0P1h0?l207l0o`@0Q`3o
0`2?0?l509L0o`X0WP3o202V0?l=09h0o`L0U`3o1P2?0?l508L0o`D0O`3o
101h0?l40700o`@0J03o00<0H@3o0?ooo`3oool00`3oool100000040oooo
000V0?ooo`<000000`3oool2067o00@0J?l0101`o`0507So00D0Ool01P27
o`0708oo00X0Uol04@2No`0809Oo00D0Sol00`27o`0307oo0080N?l00`1`
o`0206So0080HOl000<0FOl0057o001Ao`000P1:o`001P12o`00>_l003?o
000co`00:ol002?o00807?l003l05?l000co0005o`000?l2003o2P00oa40
0?lI003o8@00obP00?l`003o>000ocl00?m7003oE`00oeh00?mV003oKP00
ogD00?n5003oS000oi@00?nL003oZ`00ok<00?nj003obP00om400?oI003o
j000oo000?oh003ho`00l?l00>So003Io`00dOl00<[o002jo`00/ol00:_o
002Lo`00U?l008co001mo`00MOl006ko001Vo`00G_l004oo0017o`00?ol0
03So000`o`00:?l0027o000Io`004Ol000[o0002o`050?l0303o01@0o`0L
0?l00P0S0?l01@0[0?l0<`3o03X0o`0j0?l0@P3o0080BP3o0P1A0?l00`1I
0?l0H@3o0640o`0206P0o`<0L03o0P1h0?l307l0o`<0Q`3o1@2?0?l809L0
oa40WP3o2P2G0?l708l0o`H0Q`3o1@1o0?l407P0o`@0L03o101X0?l30640
o`@0oooo0P0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`@0
HOl0101Xo`05073o00D0N?l01@1oo`0708Oo00P0Sol0602Go`0708oo00@0
Qol0101oo`0207So00<0L?l00P1Xo`02067o0080FOl00P1Ao`00101:o`00
@_l004;o000jo`0203?o000i02_o000So`007?l001co000Do`003?l000Go
0000o`800?l:003o4@00oaT00?lQ003o:000oc000?lh003o?`00odL00?m?
003oE`00oeh00?m^003oM@00ogd00?n5003oS000oi`00?nS003oZ`00ok<0
0?o2003obP00om400?oQ003oj000oo000?oh003ho`00l?l00>So003Io`00
dOl00<[o002jo`00/ol00:_o002So`00U?l008co0025o`00OOl007Go001V
o`00G_l005Oo001?o`00Aol003oo0080033o0P008Ol2000Ao`8000;o00@0
1@3o00`0o`0D0?l0703o0P0S0?l0100[0?l0<`3o03X0o`0j0?l20480o`03
04X0o`1A0?l0D@3o0080F@3o0P1Q0?l206P0o`<0L03o0P1h0?l407l0o`@0
Q`3o1`2?0?lH09L0o`P0S`3o1`270?l507l0o`D0N03o101`0?l506P0o`<0
H@3o00<0F@3o0?ooo`3oool00`3oool100000040oooo000V0?ooo`030000
003oool0oooo00<0oooo0P1Io`04067o00@0J?l01@1`o`0507So00H0Ool0
2027o`0N08oo00D0Qol0101oo`0407So00<0L?l00P1Xo`03067o0080FOl0
00<0DOl004[o001:o`000P12o`001@0jo`00<ol003?o000[o`008ol00080
7?l000@05?l000co0005o`000?l20P00o`X0>000oa400?lI003o8@00obP0
0?l`003o>000ocl00?m7003oE`00oeh00?mV003oKP00ogD00?mm003oQ@00
oi@00?nL003oX`00oj/00?nj003o`P00olX00?oA003oh@00onP00?o`003o
n000n?l00?3o003Xo`00fOl00=7o003:o`00`_l00;?o002[o`00Xol009co
002<o`00QOl007go001eo`00K_l006Ko001Go`00Col004Oo000oo`00>?l0
033o000Xo`008Ol001Wo000Ao`002_l000;o0P050?l01P0<0?l0503o01`0
o`0L0?l08`3o02/0o`80<`3o00<0>P3o0480o`120?l00P1:0?l00`1A0?l0
F@3o05T0o`030640o`80J03o0`1`0?l407P0o`@0O`3o1@270?lN08l0o`P0
Q`3o1P1o0?l507P0o`@0L03o1@1X0?l40640o`80F@3o1@3oool100000040
oooo000V0?ooo`030000003oool0oooo00<0oooo101Io`04067o00@0J?l0
1P1`o`0607So00L0Ool02P27o`0@08oo00P0Qol01P1oo`0307So00<0L?l0
0`1Xo`03067o0080FOl00P1Ao`0204[o000504;o000jo`00>_l003?o000[
o`000P0So`0201co000401Co000<o`001Ol0003o0P800?l:03T00?lA003o
6@00ob400?lX003o<000ocP00?lo003oA`00odl00?mG003oGP00ofH00?me
003oO@00ohD00?n<003oU000oi`00?nS003o/`00okX00?o2003obP00omT0
0?oQ003oj000oo000?oh003ho`00l?l00>So003Qo`00dOl00<[o0032o`00
^_l00:_o002So`00W?l009Co002<o`00QOl007Go001^o`00I_l005ko001G
o`00Col004Oo000oo`00>?l0033o000Xo`008Ol001Wo000Ao`002_l00P00
0_l010050?l0303o01@0o`0L0?l202<0o`80:`3o00@0<`3o03X0o`0j0?l0
@P3o0P1:0?l20540o`80F@3o0`1Q0?l306P0o`<0L03o0`1h0?l607l0o`P0
Q`3o3`2?0?l;08L0o`L0O`3o1P1h0?l60700o`@0J03o101Q0?l405T0o`D0
oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`03057o
001Io`00FOl00080FOl01@1Qo`0506So00D0L?l01`1ho`0907oo01P0Qol0
1`1oo`0407So00@0L?l00`1Xo`03067o0080FOl00P1Ao`0204[o0080@_l0
0P0jo`00100co`00:ol002_o000So`0201co000l01Co000<o`001Ol000Go
0000o`800?l:003o4@00oaT00?lQ003o:000oc000?lh003o?`00odL00?m?
003oE`00oeh00?mV003oKP00ogD00?mm003oQ@00oh`00?nD003oW000oj/0
0?nc003o^P00ol800?o:003of@00on400?oX003ol000ooP00?So003`o`00
j?l00>7o003Ao`00b_l00<;o002jo`00/ol00:?o002Lo`00U?l008co0025
o`00OOl007Go001^o`00G_l005Oo001?o`00Aol003oo000ho`00<?l002So
0P008Ol010006Ol0017o000:o`000_l200D0o`0500`0o`0D0?l0703o01`0
o`0S0?l00P0[0?l00`0c0?l0>P3o03X0o`020480o`80BP3o0P1A0?l205T0
o`<0H@3o0`1X0?l40700o`@0N03o1`1o0?lH08L0o`T0O`3o1`1h0?l50700
o`D0J03o1@1Q0?l405T0o`030540o`3oool0oooo00<0oooo0@0000010?oo
o`009P3oool00`000000oooo0?ooo`030?ooo`<0DOl0101Io`05067o00H0
J?l01P1`o`0807So01h0Ool01P1ho`04073o00<0J?l0101Qo`0205Wo0080
DOl00P1:o`0204;o0080>_l00P0co`0202_o000502?o000Lo`005?l001Co
000<o`000P05o`001000o`800?l:003o4@00oaT2003o8@0e003o:000oc00
0?lh003o?`00odL00?m?003oE`00oeh00?mV003oKP00ogD00?mm003oS000
oi@00?nL003oX`00oj/00?nc003o^P00ol800?oA003of@00on400?oX003o
l000ool00?So003`o`00j?l00>7o003Io`00b_l00<;o002jo`00/ol00:_o
002So`00W?l008co0025o`00OOl007Go001^o`00I_l005ko001Go`00Col0
04Oo000oo`00>?l0033o000Xo`008Ol00P006Ol010004Ol000[o0002o`05
0?l200`0o`80503o00@0703o02<0o`0[0?l0:`3o0P0c0?l203X0o`80@P3o
0P1:0?l20540o`80F@3o101Q0?l306P0o`@0L03o1P1h0?lN07l0o`P0N03o
1P1`0?l606P0o`D0H@3o101I0?l30540o`D0oooo0@0000010?ooo`009P3o
ool00`000000oooo0?ooo`030?ooo`D0DOl01@1Io`05067o00H0J?l01`1`
o`0;07So0100Ool02@1ho`05073o00@0J?l00`1Qo`0305Wo0080DOl00`1:
o`0204;o0080>_l00P0co`00100[o`008ol002?o000Lo`0201Co000500co
0005o`001Ol0003o0P00o`X00P00oa40=000oaT00?lQ003o:000oc000?lh
003o?`00odL00?m?003oE`00oeh00?mV003oKP00ogD00?mm003oQ@00oh`0
0?nD003oW000oj<00?n[003o/`00okX00?o:003od@00omT00?oQ003oj000
oo000?oo003ho`00l?l00>So003Qo`00fOl00=7o0032o`00^_l00;?o002[
o`00Xol009co002Do`00S?l008Go001eo`00K_l006Ko001No`00Eol004oo
0017o`00?ol2000ho`04000`o`00:?l0027o000Io`80017o00<000[o0002
o`050?l00P0<0?l00`0D0?l0703o01`0o`0202<0o`0302/0o`0c0?l0<`3o
0080>P3o0P120?l304X0o`80D@3o0`1I0?l30640o`@0J03o1@1`0?l907P0
oa00O`3o2`1h0?l70700o`H0J03o1@1Q0?l505T0o`@0D@3o00<0BP3o0?oo
o`3oool00`3oool100000040oooo000V0?ooo`030000003oool0oooo00<0
oooo0P1:o`05057o00D0FOl01P1Qo`0606So00T0L?l06P1ho`06073o00D0
J?l0101Qo`0305Wo0080DOl00`1:o`0204;o00<0>_l000<0<ol002_o000[
o`000P0So`00100Lo`005?l001Co000<o`0200Go0008003o0P00o`X00?lA
003o4@00oaT00?lQ003o:000oc02003o>00a003o?`00odL00?m?003oE`00
oeh00?mV003oKP00ogD00?mm003oQ@00oh`00?nD003oW000oj<00?nc003o
^P00ol800?o:003od@00omT00?oQ003oj000oo000?oo003ho`00l?l00>So
003Qo`00fOl00=7o003:o`00`_l00;?o002[o`00Xol009co002Do`00S?l0
08Go001mo`00MOl006ko001Vo`00G_l005Oo001?o`00Aol003oo000ho`02
000`o`04000Xo`008Ol001Wo000Ao`8000[o00@000;o00D0o`0<0?l0303o
0P0D0?l00`0L0?l08`3o02<0o`0202/0o`0403<0o`0j0?l0>P3o03X0o`80
@P3o0`1:0?l20540o`<0F@3o101Q0?l506P0o`H0L03o6P1h0?l90700o`H0
J03o1P1Q0?l505T0o`@0D@3o0`1:0?l50?ooo`4000000@3oool002H0oooo
00<000000?ooo`3oool00`3oool404[o00D0DOl01@1Io`07067o00L0J?l0
401`o`0307So00h0L?l01P1Xo`04067o00@0FOl00P1Ao`0304[o00<0@_l0
0P0jo`0203?o0080:ol00P0So`00100Lo`005?l001Co000<o`0200Go0006
003o0P00o`X00?l:003o4@00oaT00?lQ0P00obP01P00oc000?lh003o?`00
odL00?m?003oE`800?mN02P00?mV003oKP00ogD00?mm003oQ@00oh`00?nD
003oX`00oj/00?nc003o^P00ol800?o:003od@00omT00?oQ003oj000oo00
0?oo003ho`00l?l00>So003Qo`00fOl00=7o003:o`00`_l00;[o002co`00
Xol009co002Do`00S?l008Go001mo`00MOl006ko001Vo`00G_l005Oo0P00
Col01@00Aol003oo000ho`00<?l002So0080027o00D001Wo000Ao`002_l0
00[o0002o`0200D0o`0400`0o`0D0?l0503o01`0o`808`3o0P0[0?l203<0
o`80>P3o0`120?l204X0o`<0D@3o101I0?l40640o`H0J03o3@1`0?l407P0
oa00L03o1`1X0?l70640o`D0F@3o1@1A0?l404X0o`D0oooo0@0000010?oo
o`009P3oool00`000000oooo0?ooo`030?ooo`0304;o001:o`00B_l000<0
B_l01@1Ao`0605Wo00L0HOl02`1Xo`0D073o00P0J?l01@1Qo`0405Wo00<0
DOl00`1:o`0304;o0080>_l00P0co`0202_o00808ol00P0Lo`0201Co0005
00co0005o`001Ol0003o0P00o`X00P00oa401`00oaT00?lQ003o:000obP0
0?l`003o>000ocl00P00odL0<000odl00?mG003oGP00ofH00?m^003oM@00
ogd00?n5003oS000oi@00?nL003oX`00oj/00?nc003o^P00ol800?o:003o
d@00omT00?oQ003oj000oo000?oo003ho`00l?l00>So003Qo`00fOl00=7o
003:o`00`_l00;[o002co`00Zol00:?o002Lo`00U?l008co0025o`00OOl0
07Go001^o`00I_l005ko001Go`00Col004Oo000oo`8003So00H0033o000X
o`008Ol0027o000Io`004Ol2000:o`040002o`050?l0303o00`0o`80503o
0P0L0?l202<0o`80:`3o0P0c0?l203X0o`<0@P3o0`1:0?l30540o`@0F@3o
1@1Q0?l806P0oa@0L03o2`1X0?l70640o`H0F@3o101A0?l604X0o`030480
o`3oool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000oooo0?oo
o`030?ooo`<0@_l01@1:o`06057o00H0FOl02@1Qo`0M06So00L0HOl0101I
o`04057o00<0B_l00`12o`0203[o00<0<ol00P0[o`0202?o00807?l00P0D
o`00100<o`001Ol000Go0000o`82003o2P05003o4@00oaT00?lI003o8@00
obP00P00oc001@00ocP00?lo003oA`00odl00?mG00800?mN02T00?mV003o
KP00ogD00?mm003oQ@00oh`00?nD003oW000oj<00?n[003o/`00okX00?o2
003obP00om400?oI003oh@00onP00?o`003oo`00n?l00?3o003Xo`00hOl0
0=Wo003Ao`00b_l00<;o002jo`00/ol00:_o002So`00W?l009Co002<o`00
QOl007go001eo`00K_l006Ko001No`02001Go`04001?o`00Aol003oo000h
o`80033o00H002So000Qo`006Ol001Wo000Ao`002_l20002o`801@3o00<0
303o01@0o`0D0?l00P0L0?l202<0o`80:`3o0P0c0?l303X0o`<0@P3o0`1:
0?l40540o`@0F@3o1`1Q0?lM06P0o`T0H@3o1P1I0?l50540o`H0BP3o0`12
0?l50?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool5
04;o00D0B_l01`1Ao`0705Wo00`0HOl03`1Xo`0:067o00D0FOl01@1Ao`03
04[o00<0@_l00`0jo`0203?o00<0:ol00P0So`0201co00805?l000@03?l0
00Go0005o`000?l20P00o`X01@00oa400?lI003o6@00ob400?lX00800?l`
00<00?lh003o?`00odL00P00odl02000oeL00?mN003oIP00ofh00?me003o
O@00ohD00?n<0P00oi@07000oi`00?nS003oZ`00ok<00?nj003o`P00olX0
0?oA003of@00on400?o`003on000ool00?So003`o`00j?l00>7o003Io`00
dOl00<[o0032o`00^_l00;?o002[o`00Xol009co002Do`00S?l20025o`80
07Go00H006ko001Vo`00G_l005Oo001?o`00Aol2000oo`06000ho`00<?l0
02So000Xo`008Ol001Wo0P004Ol2000:o`040002o`050?l01@3o00`0o`80
503o0P0L0?l202<0o`<0:`3o0P0c0?l303X0o`<0@P3o0`1:0?l50540o`D0
F@3o2P1Q0?l?06P0o``0H@3o1`1I0?l60540o`H0BP3o10120?l00`0j0?l0
oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool0
0`3oool203[o00H0@_l01@1:o`07057o00X0FOl06@1Qo`0805Wo00D0DOl0
101:o`0304;o00<0>_l00`0co`0202_o00808ol00P0Lo`0201Co00803?l0
0P05o`000`00o`800?l:003o2P02003o4@06003o6@00ob400?lX003o:000
oc000?lh0P00ocl00`00odL00?m?003oE`02003oGP0Q003oIP00ofh00?me
003oO@00ohD00?n<003oU000oi`00?nS003oZ`00ok<00?nj003o`P00olX0
0?oA003of@00on400?oX003ol000ooP00?oo003ho`00l?l00>So003Qo`00
fOl00=7o003:o`00`_l00;[o002co`00Zol00:?o008009co00P009Co002<
o`00QOl007go001eo`00K_l006Ko001No`8005Oo00<004oo0017o`00?ol0
0P00>?l01@00<?l002So000Qo`008Ol001Wo0080017o00<000[o0002o`00
0_l00P050?l200`0o`80503o0P0L0?l202<0o`80:`3o0`0c0?l303X0o`<0
@P3o101:0?l50540o`L0F@3o6P1Q0?l:05T0o`L0D@3o1@1:0?l60480o`80
>P3o1@3oool100000040oooo000V0?ooo`<000000`3oool403[o00H0@_l0
1P1:o`08057o0100FOl01@1Qo`0>05Wo00H0DOl0101:o`0404;o00<0>_l0
0`0co`0202_o00<08ol00P0Lo`0201Co00803?l00P05o`001000o`800?l:
003o2P00oa42003o6@04003o8@00obP00?lX003o<0800?lh00T00?lo003o
A`00odl00?m?003oE`00oeh00?mV003oKP00ogD00P00ogd05000ohD00?n<
003oU000oi`00?nS003oZ`00ok<00?nj003o`P00olX00?oA003of@00on40
0?oX003ol000ooP00?oo003ho`00l?l00>So0P00hOl03P00fOl00=7o003:
o`00`_l00;[o002co`00Zol00:?o002Lo`00U?l008co0025o`00OOl007Go
0P00K_l01000I_l005ko001Go`00Col20017o`04000oo`00>?l0033o000`
o`8002So00@0027o000Io`004Ol0017o0P002_l00`000_l01@3o00D0o`02
00`0o`80503o0P0L0?l302<0o`80:`3o0`0c0?l303X0o`@0@P3o101:0?l6
0540o`d0F@3o1P1Q0?l@05T0o`P0D@3o1P1:0?l50480o`D0>P3o103oool2
00000040oooo000V0?ooo`030000003oool0oooo00<0oooo00<0<ol003[o
000jo`000`0jo`0604;o00P0B_l02P1Ao`0G05Wo00P0DOl01P1:o`0404;o
00<0>_l00`0co`0302_o00808ol00`0Lo`0201Co00803?l00P05o`02003o
0P04003o2P00oa400?lA003o6@800?lQ00D00?lX003o<000oc000?lh003o
?`02003oA`09003oC`00oeL00?mN003oGP00ofH00?m^003oM@00ogd00?n5
00800?n<01000?nD003oW000oj<00?n[003o/`00okX00?o2003obP00om40
0?oI003oh@00onP00?o`003on000ool00?So0P00l?l03P00j?l00>7o003I
o`00dOl00<[o0032o`00^_l00;?o002[o`00Xol009co002Do`00S?l008Go
0P00OOl01000MOl006ko001Vo`00G_l2001Go`05001?o`00Aol003oo000o
o`00>?l00P00<?l01000:?l0027o000Qo`006Ol2000Ao`03000:o`000_l0
00;o00801@3o0P0<0?l201@0o`<0703o0P0S0?l302/0o`<0<`3o0`0j0?l4
0480o`D0BP3o2@1A0?lG05T0o`X0D@3o201:0?l50480o`H0>P3o00<0<`3o
0?ooo`3oool00`3oool100000040oooo000V0?ooo`030000003oool0oooo
00<0oooo0`0co`0603[o00L0@_l0201:o`0Q057o00H0B_l01@12o`0403[o
00<0<ol00`0[o`0302?o00807?l00P0Do`0200co00801Ol00P00o`82003o
2P03003o4@00oaT00?lI00800?lQ00@00?lX003o<000oc000?lh0P00ocl0
1`00odL00?m?003oE`00oeL00?mN003oIP00ofh00P00ogD01P00ogd00?n5
003oS000oi@00?nL003oX`800?n[00/00?nc003o^P00ol800?o:003od@00
omT00?oQ003oj000oo000?oh003oo`02003ho`0;003`o`00j?l00>7o003I
o`00dOl00<[o0032o`00^_l00;?o002[o`00Xol00P00W?l01000U?l008co
0025o`00OOl2001eo`04001^o`00I_l005ko001Go`8004oo00@004Oo000o
o`00>?l003So0P00<?l01000:?l0027o000Io`006Ol2000Ao`8000[o0P00
0_l200D0o`80303o0P0D0?l201`0o`<08`3o0`0[0?l303<0o`@0>P3o1012
0?l704X0ob40D@3o201:0?l70480o`H0>P3o0`0c0?l50?ooo`4000000@3o
ool002H0oooo00<000000?ooo`3oool00`3oool503?o00L0>_l01`12o`0;
04[o01D0DOl0201:o`0604;o00@0>_l0100co`0302_o00<08ol00`0Lo`02
01Co00803?l00P05o`02003o0P800?l:0P00oa400`00oaT00?lQ003o8@02
003o:005003o<000ocP00?lh003o?`00odL00P00odl01`00oeL00?mN003o
IP00ofH00?m^003oM@00ogd00P00ohD01@00oh`00?nD003oW000oj<00?n[
00800?nc00X00?nj003o`P00olX00?oA003of@00on400?oX003ol000ooP0
0?oo0P00n?l02@00l?l00>So003Qo`00fOl00=7o003:o`00`_l00;[o002c
o`02002[o`05002So`00W?l009Co002<o`00QOl00P00OOl00`00MOl006ko
001Vo`02001No`05001Go`00Col004Oo0017o`00?ol00P00>?l01000<?l0
02So000Xo`008Ol2000Io`80017o0P002_l20002o`801@3o0P0<0?l201@0
o`<0703o0`0S0?l302/0o`@0<`3o100j0?l50480o`T0BP3o5@1A0?l;04X0
o`L0@P3o1`0j0?l503<0o`D0oooo0@0000010?ooo`009P3oool00`000000
oooo0?ooo`030?ooo`80:ol01P0co`0603[o00X0@_l07`1:o`0704;o00D0
>_l0100co`0302_o00<08ol00`0Lo`0301Co00803?l00P05o`02003o0P80
0?l:0P00oa400`00oaT00?lQ003o8@02003o:004003o<000ocP00?lh003o
?`800?m700H00?m?003oE`00oeh00?mN003oIP00ofh2003oM@03003oO@00
ohD00?n<00800?nD00D00?nL003oX`00oj/00?nc003o^P02003o`P08003o
bP00om400?oI003oh@00onP00?o`003on000ool2003ho`07003`o`00j?l0
0>7o003Io`00dOl00<[o0032o`02002jo`05002co`00Zol00:?o002Lo`00
U?l00P00S?l00`00QOl007go001eo`02001^o`06001Vo`00G_l005Oo001G
o`00Col004Oo0P00?ol2000ho`04000`o`00:?l002So000Qo`8001Wo0P00
4Ol2000:o`8000;o0P050?l200`0o`<0503o0`0L0?l302<0o`<0:`3o100c
0?l503X0o`H0@P3o801:0?l:0480o`H0>P3o1P0c0?l202/0o`D0oooo0@00
00010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`@0:ol01P0co`08
03[o00`0@_l04`1:o`0904;o00H0>_l01@0co`0302_o00<08ol0100Lo`02
01Co00803?l00`05o`02003o0P800?l:0P00oa42003o6@03003o8@00obP0
0?lX00800?l`00@00?lh003o?`00ocl00?m70P00odl01P00oeL00?mN003o
IP00ofH00?m^003oM@800?mm00<00?n5003oS000oi@00P00oi`01@00oj<0
0?n[003o/`00okX00?o200800?o:00L00?oA003of@00on400?oX003ol000
ooP00?oo00800?So00H00?3o003Xo`00hOl00=Wo003Ao`00b_l20032o`05
002jo`00/ol00:_o002So`00W?l00P00U?l00`00S?l008Go001mo`02001e
o`05001^o`00I_l005ko001No`00Eol00P00Col01000Aol003oo000oo`00
>?l2000`o`8002So00<0027o000Io`006Ol00P004Ol2000:o`8000;o0P05
0?l300`0o`80503o0`0L0?l402<0o`<0:`3o1@0c0?l603X0o`T0@P3o4`1:
0?l<0480o`L0>P3o1`0c0?l402/0o`D0oooo0@0000010?ooo`009P3oool0
0`000000oooo0?ooo`030?ooo`H0:ol01`0co`0903[o01l0@_l0200jo`05
03?o00@0:ol00`0So`0401co00805?l00`0<o`0300Go00800?l20P00o`X2
003o4@800?lI00<00?lQ003o:000obP00P00oc001000ocP00?lo003o?`00
odL2003oC`05003oE`00oeh00?mN003oIP00ofh00P00ogD01`00ogd00?n5
003oS000oh`00?nD003oW000oj<00P00oj/01000ok<00?nj003o`P00olX2
003od@05003of@00on400?oX003ol000ooP00P00ool01P00n?l00?3o003X
o`00hOl00=Wo003Ao`800<[o00@00<;o002jo`00/ol00:_o0P00Xol00`00
W?l009Co002<o`020025o`05001mo`00MOl006ko001^o`00I_l00P00G_l0
1000Eol004oo0017o`00Aol2000oo`04000ho`00<?l0033o000Xo`80027o
0P006Ol2000Ao`8000[o0P000_l300D0o`<0303o0P0D0?l401`0o`<08`3o
100[0?l503<0o`L0>P3o80120?l903X0o`H0<`3o1P0[0?l00`0S0?l0oooo
0?ooo`030?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3o
ool202?o00L0:ol0200co`0<03[o0180@_l02P0jo`0603?o00D0:ol00`0S
o`0401co00<05?l00`0<o`0200Go00800?l20`00o`X2003o4@800?lI00<0
0?lQ003o:000obP00P00oc02003o>004003o?`00odL00?m7003oC`800?mG
00D00?mN003oIP00ofH00?m^003oM@02003oO@07003oQ@00oh`00?nD003o
U000oi`00?nS003oZ`02003o/`04003o^P00ol800?o:003od@800?oI00@0
0?oQ003oj000oo000?oh0P00ool01@00n?l00?3o003Xo`00hOl00=Wo0080
0=7o00@00<[o0032o`00^_l00;?o0P00Zol00`00Xol009co002Do`02002<
o`050025o`00OOl007Go001eo`00K_l00P00I_l01000G_l005Oo001?o`00
Col20017o`03000oo`00>?l003So0080033o00<002So000Qo`008Ol00P00
6Ol2000Ao`8000[o0`000_l200D0o`<0303o0`0D0?l301`0o`@08`3o100[
0?l603<0o`X0>P3o4`120?l<03X0o`P0<`3o1P0[0?l302<0o`D0oooo0@00
00010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`D08ol01`0[o`09
03?o0200>_l01`0co`0502_o00@08ol0100Lo`0301Co00<03?l00P05o`03
003o0P<00?l:0P00oa42003o6@800?lQ00<00?lX003o<000oc000P00ocP0
1000ocl00?m7003oA`00odl2003oE`800?mN00D00?mV003oKP00ogD00?me
003oO@02003oQ@07003oS000oi@00?nL003oW000oj<00?n[003o/`02003o
^P04003o`P00olX00?oA003of@800?oQ00<00?oX003ol000ooP00P00ool0
1000n?l00?3o003Xo`00hOl2003Io`03003Ao`00b_l00<;o00800;[o00<0
0;?o002[o`00Xol00P00W?l01P00U?l008co0025o`00QOl007go001eo`80
06ko00@006Ko001No`00G_l005Oo0P00Col20017o`04000oo`00>?l003So
000`o`8002So0P008Ol2000Io`80017o0`002_l30002o`801@3o0`0<0?l3
01@0o`@0703o100S0?l502/0o`L0<`3o800j0?l903<0o`L0:`3o1@0S0?l5
0?ooo`4000000@3oool002H0oooo00<000000?ooo`3oool00`3oool702?o
00T0:ol0300co`0B03[o00X0<ol01`0[o`0402?o00@07?l0100Do`0200co
00<01Ol00`00o`82003o2P800?lA0`00oaT2003o8@03003o:000oc000?l`
00800?lh0P00ocl00`00odL00?m?003oC`02003oE`04003oGP00ofH00?mV
003oKP800?me00H00?mm003oQ@00oh`00?n<003oU000oi`2003oX`03003o
Z`00ok<00?nj00800?o200<00?o:003od@00omT00P00on400`00onP00?o`
003on002003oo`04003ho`00l?l00>So003Qo`800=Wo00<00=7o003:o`00
`_l00P00^_l00`00/ol00:_o002So`02002Lo`05002Do`00S?l008co0025
o`00OOl00P00MOl01000K_l006Ko001Vo`00G_l2001Go`03001?o`00Aol0
04Oo008003oo0P00>?l00`00<?l002So000Xo`02000Qo`8001Wo0`004Ol2
000:o`<000;o0P050?l300`0o`@0503o100L0?l402<0o`L0:`3o2P0c0?lB
03X0o``0<`3o2@0[0?l602<0o`0301`0o`3oool0oooo00<0oooo0@000001
0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`<07?l01`0So`0:02_o
0200<ol01`0[o`0602?o00@07?l0100Do`0300co00<01Ol00P00o`83003o
2P800?lA0`00oaT2003o8@800?lX00<00?l`003o>000ocP00P00ocl2003o
A`04003oC`00oeL00?mG003oGP800?mV00@00?m^003oM@00ogD00?mm0P00
ohD01@00oh`00?nD003oU000oi`00?nS00800?n[00<00?nc003o^P00ol80
0P00olX01`00om400?oI003oh@00on400?oX003ol000ooP00P00ool00`00
n?l00?3o003Xo`02003Qo`03003Io`00dOl00<[o00800<;o00H00;[o002c
o`00Zol00:_o002So`00W?l2002Do`05002<o`00QOl007go001mo`00MOl0
0P00K_l00`00I_l005ko001No`02001Go`03001?o`00Aol004Oo008003oo
00<003So000`o`00<?l00P00:?l2000Qo`<001Wo0P004Ol3000:o`8000;o
0`050?l300`0o`@0503o100L0?l502<0o`P0:`3o800c0?l902/0o`P08`3o
0`0L0?l50?ooo`4000000@3oool001<0oooo0P0000040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`H07?l0200So`0<02_o01@0<ol02P0[o`0602?o00D07?l0100D
o`0300co00<01Ol00`00o`83003o2P800?lA0P00oaT3003o8@800?lX0P00
oc000`00ocP00?lo003o?`02003oA`800?m?00<00?mG003oGP00oeh00P00
ofH01@00ofh00?me003oM@00ogd00?n500800?n<00D00?nD003oW000oi`0
0?nS003oZ`02003o/`07003o^P00ol800?o:003obP00om400?oI003oh@02
003oj007003ol000ooP00?oo003oo`00n?l00?3o003Xo`02003Qo`07003I
o`00dOl00<[o003:o`00`_l00;[o002co`02002[o`05002So`00W?l009co
002Do`00S?l00P00QOl01000OOl007Go001eo`00K_l2001Vo`8005ko00<0
05Oo001?o`00Col00P00Aol00`00?ol003So000ho`02000`o`8002So0P00
8Ol3000Io`80017o0`002_l30002o`<01@3o0`0<0?l401@0o`D0703o1P0S
0?l:02/0oa@0<`3o300[0?l802<0o`H0703o1@3oool100000040oooo000B
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`0301Co000Lo`007?l000D07?l02P0S
o`0Q02_o00P08ol01@0Lo`0501Co00<03?l00`05o`04003o0P800?l:0`00
oa42003o6@<00?lQ0P00obP2003o<003003o>000ocl00?lo00800?m70P00
odl2003oE`04003oGP00ofH00?mV003oKP800?me00@00?mm003oQ@00ohD0
0?n<0P00oi@01@00oi`00?nS003oX`00oj/00?nc00800?nj00H00?o2003o
bP00om400?oA003of@00on42003oj007003ol000ooP00?oo003oo`00n?l0
0?3o003Xo`02003Qo`06003Io`00dOl00<[o003:o`00`_l00;[o0P00/ol0
1@00Zol00:?o002So`00W?l009Co008008co00@008Go001mo`00OOl007Go
0P00K_l2001Vo`03001No`00Eol005Oo008004oo00<004Oo000oo`00?ol0
0P00>?l2000`o`8002So0`008Ol2000Io`<0017o0P002_l40002o`<01@3o
0`0<0?l501@0o`D0703o1`0S0?lR02/0o`T08`3o200L0?l00`0D0?l0oooo
0?ooo`030?ooo`4000000@3oool00180oooo00@000000?ooo`3oool00000
1`3oool5000000@0oooo0`0000030?ooo`<05?l02@0Lo`0;02?o01L0:ol0
2@0So`0701co00D05?l0100<o`0300Go00<00?l20`00o`X3003o4@800?lI
0P00ob43003o:0800?l`0P00ocP2003o?`03003oA`00odl00?m?00800?mG
0P00oeh00`00ofH00?m^003oKP02003oM@04003oO@00ohD00?n5003oS080
0?nD00D00?nL003oX`00oj/00?n[003o/`02003o^P06003o`P00olX00?oA
003od@00omT00?oQ0P00onP01P00oo000?oh003oo`00ool00?So003`o`80
0>So00H00>7o003Io`00dOl00=7o003:o`00`_l2002jo`05002co`00Zol0
0:?o002So`00W?l00P00U?l01000S?l008Go0025o`00OOl2001eo`03001^
o`00I_l006Ko008005ko0P00Eol00`00Col004Oo0017o`02000oo`8003So
0P00<?l2000Xo`<0027o0P006Ol3000Ao`<000[o0`000_l300D0o`@0303o
1@0D0?l601`0o`X08`3o5`0[0?l;02<0o`P0703o100D0?l40?ooo`800000
0@3oool00180oooo00@000000?ooo`3oool000001`3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo00<0oooo1P0Do`0:01co02<0
8ol0200Lo`0501Co00D03?l00`05o`03003o0P@00?l:0P00oa43003o6@80
0?lQ0`00obP2003o<0800?lh0P00ocl00`00odL00?m?003oC`02003oE`80
0?mN0P00ofH01000ofh00?me003oM@00ogd2003oQ@800?n<00D00?nD003o
W000oi`00?nS003oZ`02003o/`05003o^P00ol800?o2003obP00om400P00
omT01@00on400?oX003oj000oo000?oh00800?oo00H00?So003`o`00j?l0
0>So003Qo`00fOl2003Ao`05003:o`00`_l00<;o002jo`00/ol00P00Zol0
1000Xol009co002Lo`00U?l2002<o`030025o`00OOl007go008007Go00<0
06ko001Vo`00I_l00P00G_l00`00Eol004oo001?o`020017o`8003oo0P00
>?l2000`o`<002So0P008Ol3000Io`80017o10002_l30002o`<01@3o1@0<
0?l501@0o`L0703o900S0?l901`0o`L0503o1@3oool100000040oooo000B
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`030?ooo`0300co000Do`005?l000H05?l02`0L
o`0J02?o00T07?l01`0Do`0400co00@01Ol01000o`83003o2P<00?lA0`00
oaT2003o8@<00?lX0P00oc02003o>0800?lo0P00odL2003oC`800?mG00<0
0?mN003oIP00ofH00P00ofh2003oM@04003oO@00ohD00?n5003oS0800?nD
00@00?nL003oX`00oj<00?n[0P00ok<01@00okX00?o2003o`P00olX00?oA
00800?oI00D00?oQ003oj000oo000?o`003on002003oo`05003ho`00l?l0
0>So003Xo`00hOl00P00fOl01@00dOl00<[o0032o`00`_l00;[o00800;?o
00@00:_o002So`00Xol009co0P00U?l01000S?l008Go0025o`00OOl2001e
o`8006ko00<006Ko001No`00G_l00P00Eol2001?o`8004Oo0P00?ol2000h
o`80033o0`00:?l2000Qo`<001Wo0`004Ol3000:o`<000;o1@050?l400`0
o`H0503o2P0L0?lJ02<0o`/0703o200D0?l00`0<0?l0oooo0?ooo`030?oo
o`4000000@3oool00180oooo00@000000?ooo`3oool000002@3oool20000
00D0oooo00<000000?ooo`3oool00`3oool400co00T05?l04@0Lo`0602?o
00l07?l0200Do`0500co00@01Ol01000o`83003o2P@00?lA0P00oaT3003o
8@<00?lX0P00oc02003o>0800?lo0P00odL2003oC`800?mG0P00oeh00`00
ofH00?m^003oKP02003oM@03003oO@00ohD00?n500800?n<00@00?nD003o
W000oi`00?nS0P00oj/01000ok<00?nj003o^P00ol82003obP05003od@00
omT00?oI003oh@00onP00P00oo001@00ooP00?oo003oo`00n?l00?3o0080
0>So00@00>7o003Io`00fOl00=7o0P00b_l01000`_l00;[o002jo`00/ol2
002[o`04002So`00W?l009Co002Do`8008co00<008Go001mo`00OOl00P00
MOl00`00K_l006Ko001Vo`02001No`8005Oo0P00Col20017o`8003oo0P00
>?l2000`o`<002So0`008Ol2000Io`@0017o0`002_l40002o`@01@3o1@0<
0?l701@0oa00703o1P0S0?lA01`0o`T0503o100<0?l50?ooo`4000000@3o
ool001<0oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool600co00`05?l07@0Lo`0901Co00H03?l01005o`04
003o0P@00?l:0`00oa43003o6@<00?lQ0P00obP3003o<0800?lh0P00ocl2
003oA`800?m?0P00oeL2003oGP800?mV0P00ofh00`00ogD00?mm003oO@02
003oQ@03003oS000oi@00?nD00800?nL00@00?nS003oZ`00oj/00?nc0P00
okX01@00ol800?o:003obP00om400?oI00800?oQ00@00?oX003ol000oo00
0?oh0P00ool01@00n?l00?3o003Xo`00j?l00>7o00800=Wo00@00=7o003:
o`00b_l00<;o0P00^_l01000/ol00:_o002[o`00Xol2002Lo`03002Do`00
S?l008co008008Go00<007go001eo`00MOl00P00K_l2001Vo`8005ko0P00
Eol2001?o`8004Oo0P00?ol2000ho`80033o0`00:?l3000Qo`<001Wo0`00
4Ol3000:o`@000;o1@050?l600`0o`T0503o7@0L0?l;01@0o`L0303o1@3o
ool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo00<01Ol0
00co000<o`001`0<o`0>01Co01007?l0300Do`0700co00D01Ol01@00o`83
003o2P<00?lA1000oaT2003o8@<00?lX0`00oc02003o>0800?lo0P00odL2
003oC`800?mG0P00oeh2003oIP800?m^0P00ogD00`00ogd00?n5003oQ@02
003oS003003oU000oi`00?nL00800?nS00@00?n[003o/`00ok<00?nj0P00
ol801000olX00?oA003od@00omT2003oh@04003oj000oo000?o`003on080
0?oo00@00?So003`o`00l?l00>So0P00hOl01000fOl00=7o003Ao`00b_l2
0032o`04002jo`00/ol00:_o002[o`800:?o00<009co002Do`00U?l00P00
S?l00`00QOl007go001mo`02001eo`8006ko0P00I_l2001No`8005Oo0P00
Col20017o`8003oo0P00>?l3000`o`<002So0P008Ol4000Io`<0017o0`00
2_l50002o`D01@3o1`0<0?l<01@0oa00703o3@0D0?l:00`0o`0300D0o`3o
ool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000oooo0?ooo`03
0?ooo`@01Ol02P0<o`0R01Co00P03?l01P05o`05003o0P@00?l:0`00oa43
003o6@<00?lQ0`00obP3003o<0800?lh0`00ocl2003oA`800?m?0P00oeL2
003oGP800?mV0P00ofh00`00ogD00?mm003oO@02003oQ@800?n<00@00?nD
003oW000oi`00?nS0P00oj/2003o/`04003o^P00ol800?o2003obP800?oA
00@00?oI003oh@00on400?oX0P00oo001000ooP00?oo003oo`00n?l2003`
o`04003Xo`00hOl00>7o003Io`800=7o00@00<[o0032o`00`_l00;[o0P00
/ol00`00Zol00:?o002So`02002Lo`03002Do`00S?l008co008008Go00<0
07go001eo`00MOl00P00K_l2001Vo`8005ko0P00Eol2001?o`8004Oo0`00
?ol2000ho`<0033o0P00:?l3000Qo`@001Wo0`004Ol4000:o`D000;o1P05
0?l800`0ob80503o2P0<0?l400D0o`D0oooo0@0000010?ooo`009P3oool0
0`000000oooo0?ooo`030?ooo`L01Ol03@0<o`0F01Co00/03?l01P05o`05
003o0PD00?l:1000oa43003o6@<00?lQ0`00obP3003o<0800?lh0P00ocl3
003oA`800?m?0P00oeL2003oGP800?mV0P00ofh2003oM@03003oO@00ohD0
0?n500800?n<0P00oi@00`00oi`00?nS003oX`02003oZ`04003o/`00okX0
0?nj003o`P800?o:0P00om401000omT00?oQ003oh@00onP2003ol004003o
n000ool00?oo003ho`800?3o00@00>So003Qo`00hOl00=Wo0P00dOl00`00
b_l00<;o0032o`02002jo`04002co`00Zol00:_o002So`8009co0P00U?l2
002<o`030025o`00OOl007go008007Go0P00K_l2001Vo`8005ko0P00Eol2
001?o`<004Oo0P00?ol2000ho`<0033o0`00:?l3000Qo`<001Wo10004Ol5
000:o`@000;o1`050?l;00`0oaH0503o3@0<0?l700D0o`D0oooo0@000001
0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`03003o0P05o`001Ol0
00P01Ol09P0<o`0800Go00D00?l21@00o`X4003o4@@00?lI0`00ob43003o
:0<00?l`0P00ocP3003o?`800?m70P00odl2003oE`800?mN0P00ofH2003o
KP800?me0P00ogd2003oQ@800?n<00<00?nD003oW000oi`00P00oj<00`00
oj/00?nc003o/`02003o^P04003o`P00olX00?o:003od@800?oI0P00on40
1000onP00?o`003ol000ooP2003oo`04003ho`00l?l00?3o003Xo`800>7o
00<00=Wo003Ao`00dOl00P00b_l01000`_l00;[o002jo`00/ol2002[o`80
0:?o00<009co002Do`00U?l00P00S?l20025o`8007go00<007Go001^o`00
K_l00P00I_l3001No`8005Oo0P00Col20017o`<003oo0P00>?l3000`o`<0
02So0`008Ol4000Io`@0017o1@002_l50002o`P01@3o9P0<0?l:00D0o`03
0002o`3oool0oooo00<0oooo0@0000010?ooo`009P3oool00`000000oooo
0?ooo`030?ooo`@00?l23005o`0K00co00X01Ol01P00o`86003o2P@00?lA
1000oaT3003o8@<00?lX0`00oc03003o>0800?lo0`00odL2003oC`800?mG
0P00oeh3003oIP800?m^00<00?me003oO@00ogd00P00ohD2003oS0800?nD
0P00oi`00`00oj<00?n[003oZ`02003o/`03003o^P00ol800?o200800?o:
00@00?oA003of@00omT00?oQ0P00onP2003ol004003on000ool00?oo003h
o`800?3o00<00>So003Qo`00hOl00P00fOl00`00dOl00<[o003:o`020032
o`03002jo`00/ol00;?o00800:_o00<00:?o002Lo`00W?l00P00U?l00`00
S?l008Go0025o`02001mo`8007Go0P00K_l2001Vo`8005ko0`00Eol2001?
o`<004Oo0P00?ol3000ho`<0033o0`00:?l3000Qo`@001Wo10004Ol5000:
o`H000;o2P050?lL00`0o``01@3o10000_l50?ooo`4000000@3oool002H0
oooo00<000000?ooo`3oool00`3oool7003o0Q001Ol03@0<o`0>00Go00L0
0?l21P00o`X4003o4@@00?lI1000ob43003o:0<00?l`0`00ocP3003o?`80
0?m70P00odl3003oE`800?mN0P00ofH2003oKP800?me0P00ogd2003oQ@80
0?n<0P00oi@00`00oi`00?nS003oX`02003oZ`800?nc00@00?nj003o`P00
ol800?o:0P00om42003of@03003oh@00onP00?oX00800?o`00@00?oh003o
o`00ool00?So0P00l?l2003Xo`04003Qo`00fOl00=Wo003Ao`800<[o0P00
`_l00`00^_l00;?o002co`02002[o`800:?o00<009co002Do`00U?l00P00
S?l20025o`8007go0P00MOl2001^o`8006Ko0P00G_l2001Go`<004oo0P00
Aol3000oo`<003So0`00<?l3000Xo`<0027o10006Ol5000Ao`D000[o2000
0_l>00D0o`d0303o40050?l70002o`D0oooo0@0000010?ooo`009P3oool0
0`000000oooo0?ooo`030?ooo`/00?l28P05o`09003o0PH00?l:1@00oa44
003o6@@00?lQ1000obP3003o<0<00?lh0P00ocl3003oA`<00?m?0P00oeL2
003oGP800?mV0P00ofh2003oM@800?mm0P00ohD2003oS0800?nD0P00oi`2
003oX`03003oZ`00ok<00?nc00800?nj0P00ol800`00olX00?oA003od@02
003of@04003oh@00onP00?oX003ol0800?oh0P00ool00`00n?l00?3o003`
o`02003Xo`03003Qo`00fOl00=Wo00800=7o00<00<[o0032o`00`_l00P00
^_l00`00/ol00:_o002[o`02002So`8009co0P00U?l2002<o`8008Go0P00
OOl2001eo`8006ko0P00I_l2001No`8005Oo0`00Col30017o`8003oo0`00
>?l3000`o`@002So10008Ol4000Io`D0017o1P002_l80002ob<01@3o2P00
0_l00`002_l0oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<00000
0?ooo`3oool00`3oool3003o2Ph00?l25`05o`0;003o0PL00?l:1@00oa45
003o6@@00?lQ1000obP3003o<0<00?lh0`00ocl2003oA`<00?m?0P00oeL2
003oGP<00?mV0P00ofh2003oM@800?mm0P00ohD2003oS0800?nD0P00oi`0
0`00oj<00?n[003oZ`02003o/`800?nj00<00?o2003obP00olX00P00om40
0`00omT00?oQ003oh@02003oj003003ol000ooP00?oh00800?oo00<00?So
003`o`00l?l00P00j?l00`00hOl00=Wo003Io`02003Ao`03003:o`00`_l0
0<;o00800;[o0P00/ol00`00Zol00:?o002So`02002Lo`8009Co0P00S?l2
0025o`8007go0P00MOl2001^o`8006Ko0`00G_l2001Go`<004oo0P00Aol3
000oo`<003So0`00<?l4000Xo`@0027o10006Ol6000Ao`L000[o2`000_lG
00D0o`h000;o0`002_l50?ooo`4000000@3oool002H0oooo00<000000?oo
o`3oool00`3oool7003o2RP00?l22000o`X6003o4@D00?lI1000ob44003o
:0<00?l`1000ocP2003o?`<00?m70`00odl2003oE`800?mN0`00ofH2003o
KP800?me0P00ogd2003oQ@800?n<0P00oi@2003oW0800?nS0P00oj/2003o
/`03003o^P00ol800?o200800?o:0P00om400`00omT00?oQ003oh@02003o
j003003ol000ooP00?oh00800?oo00<00?So003`o`00l?l00P00j?l2003Q
o`03003Io`00dOl00=7o00800<[o0P00`_l00`00^_l00;?o002co`02002[
o`800:?o0P00W?l2002Do`8008co0P00QOl2001mo`8007Go0P00K_l2001V
o`<005ko0P00Eol3001?o`<004Oo0P00?ol4000ho`<0033o1000:?l4000Q
o`@001Wo1P004Ol8000:obT000;o1`002_l50?ooo`4000000@3oool002H0
oooo0`0000030?ooo`/00?l:8000o`8:003o2PH00?lA1@00oaT5003o8@@0
0?lX0`00oc03003o>0<00?lo0`00odL3003oC`<00?mG0P00oeh2003oIP<0
0?m^0P00ogD2003oO@800?n50P00oh`2003oU0800?nL0P00oj<2003oZ`03
003o/`00okX00?nj00800?o20P00olX00`00om400?oI003of@02003oh@80
0?oX00<00?o`003on000ooP00P00ool00`00n?l00?3o003`o`02003Xo`80
0>7o00<00=Wo003Ao`00dOl00P00b_l20032o`800;[o00<00;?o002[o`00
Zol00P00Xol2002Lo`8009Co0P00S?l20025o`8007go0P00MOl3001^o`80
06Ko0P00G_l3001Go`<004oo0P00Aol3000oo`@003So0`00<?l4000Xo`D0
027o1@006Ol6000Ao`X000[o80000_l;000:o`@0oooo0P0000010?ooo`00
9P3oool00`000000oooo0?ooo`030?ooo`800?lA4000o`XB003o0Pd00?l:
1`00oa46003o6@D00?lQ1000obP4003o<0<00?lh0`00ocl3003oA`<00?m?
0P00oeL3003oGP800?mV0`00ofh2003oM@800?mm0P00ohD2003oS0800?nD
0P00oi`2003oX`800?n[0P00ok<2003o^P800?o200<00?o:003od@00om40
0P00omT2003oh@800?oX00<00?o`003on000ooP00P00ool2003ho`03003`
o`00j?l00>So00800>7o0P00fOl00`00dOl00<[o003:o`020032o`800;[o
0P00/ol2002[o`800:?o0P00W?l2002Do`8008co0P00QOl2001mo`8007Go
0P00K_l3001Vo`<005ko0P00Eol3001?o`<004Oo0`00?ol3000ho`@0033o
1000:?l5000Qo`H001Wo1`004Ol=000:oa8000;o3`002_l3000Ao`D0oooo
0@0000010?ooo`009P3oool00`000000oooo0?ooo`030?ooo`H00?lA9`00
o`X9003o4@H00?lI1@00ob45003o:0<00?l`1000ocP3003o?`<00?m70`00
odl3003oE`800?mN0`00ofH2003oKP800?me0`00ogd2003oQ@800?n<0P00
oi@2003oW0800?nS0P00oj/2003o/`800?nj00<00?o2003obP00olX00P00
om42003of@800?oQ00<00?oX003ol000oo000P00ooP2003oo`800?So00<0
0?3o003Xo`00j?l00P00hOl2003Io`800=7o00<00<[o0032o`00`_l00P00
^_l2002co`800:_o0P00Xol2002Lo`8009Co0P00S?l20025o`8007go0`00
MOl2001^o`<006Ko0P00G_l3001Go`<004oo0`00Aol3000oo`<003So1000
<?l5000Xo`D0027o1P006Ol8000AobP000[o1P004Ol50?ooo`4000000@3o
ool002H0oooo00<000000?ooo`3oool00`3oool;003o4Ad00?l:2`00oa46
003o6@H00?lQ1000obP5003o<0<00?lh1000ocl3003oA`<00?m?0`00oeL3
003oGP800?mV0P00ofh3003oM@800?mm0P00ohD2003oS0800?nD0P00oi`2
003oX`800?n[0P00ok<2003o^P800?o20P00olX2003od@800?oI0P00on40
0`00onP00?o`003ol002003on0800?oo0P00n?l00`00l?l00>So003Xo`02
003Qo`800=Wo0P00dOl2003:o`800<;o00<00;[o002co`00/ol00P00Zol2
002So`8009co0`00U?l2002<o`8008Go0P00OOl3001eo`8006ko0P00I_l3
001No`<005Oo0`00Col30017o`@003oo0`00>?l4000`o`D002So1@008Ol7
000Io`/0017o7@002_l;000Ao`D0oooo0@0000010?ooo`009P3oool00`00
0000oooo0?ooo`030?ooo`03003o6@00oa400?lA00l00?lA3`00o`X?003o
4@L00?lI1P00ob45003o:0D00?l`0`00ocP4003o?`<00?m70`00odl3003o
E`<00?mN0P00ofH3003oKP800?me0P00ogd3003oQ@800?n<0P00oi@2003o
W0800?nS0P00oj/2003o/`800?nj0P00ol82003obP800?oA0P00omT00`00
on400?oX003oj002003ol0800?oh0P00ool2003ho`800?3o00<00>So003Q
o`00hOl00P00fOl2003Ao`800<[o0P00`_l2002jo`800;?o0P00Zol2002S
o`8009co0P00U?l2002<o`8008Go0`00OOl2001eo`<006ko0P00I_l3001N
o`<005Oo0`00Col30017o`@003oo0`00>?l5000`o`D002So1@008Ol8000I
o`l0017o3`002_lA000Ao`03000Io`3oool0oooo00<0oooo0@0000010?oo
o`009P3oool00`000000oooo0?ooo`030?ooo`D00?lI9P00oa4:003o6@H0
0?lQ1@00obP5003o<0@00?lh1000ocl3003oA`<00?m?0`00oeL3003oGP80
0?mV0`00ofh2003oM@<00?mm0P00ohD2003oS0800?nD0`00oi`2003oX`80
0?n[0P00ok<2003o^P800?o20P00olX2003od@03003of@00on400?oQ0080
0?oX0P00oo02003on0800?oo0P00n?l2003`o`800>So00<00>7o003Io`00
fOl00P00dOl2003:o`800<;o0P00^_l2002co`800:_o0P00Xol2002Lo`<0
09Co0P00S?l20025o`<007go0P00MOl3001^o`8006Ko0`00G_l3001Go`<0
04oo0`00Aol4000oo`@003So1@00<?l5000Xo`H0027o2@006OlW000Ao`D0
01Wo1@3oool100000040oooo000V0?ooo`030000003oool0oooo00<0oooo
2@00oaTN003o4@/00?lI1`00ob46003o:0@00?l`1@00ocP3003o?`@00?m7
0`00odl3003oE`<00?mN0`00ofH2003oKP<00?me0P00ogd3003oQ@800?n<
0P00oi@2003oW0800?nS0P00oj/2003o/`800?nj0P00ol82003obP800?oA
0P00omT2003oh@800?oX0P00oo02003on0800?oo0P00n?l2003`o`800>So
0P00hOl00`00fOl00=7o003Ao`02003:o`800<;o0P00^_l2002co`800:_o
0`00Xol2002Lo`8009Co0P00S?l30025o`8007go0`00MOl2001^o`<006Ko
0`00G_l3001Go`<004oo1000Aol3000oo`@003So1@00<?l6000Xo`L0027o
2`006OlM000Ao`X001Wo1@3oool100000040oooo000V0?ooo`030000003o
ool0oooo00<0oooo4P00oaT=003o4@l00?lI2000ob46003o:0D00?l`1@00
ocP4003o?`<00?m71000odl3003oE`<00?mN0`00ofH3003oKP800?me0P00
ogd3003oQ@800?n<0P00oi@3003oW0800?nS0P00oj/2003o/`800?nj0P00
ol82003obP800?oA0P00omT2003oh@800?oX0P00oo02003on0800?oo0P00
n?l2003`o`800>So0P00hOl2003Io`800=7o0P00b_l20032o`800;[o0P00
/ol2002[o`800:?o0P00W?l3002Do`8008co0P00QOl3001mo`8007Go0`00
K_l3001Vo`<005ko0`00Eol4001?o`<004Oo1000?ol5000ho`D0033o1P00
:?l8000Qo`l001Wo3@004OlB000Io`D0oooo0@0000010?ooo`009P3oool0
0`000000oooo0?ooo`030?ooo`<00?lQ9`00oaT9003o8@L00?lX1@00oc05
003o>0D00?lo0`00odL3003oC`@00?mG0`00oeh3003oIP800?m^0`00ogD3
003oO@800?n50P00oh`3003oU0800?nL0P00oj<2003oZ`<00?nc0P00okX2
003o`P800?o:0P00om42003of@800?oQ0P00onP2003ol0800?oh0P00ool2
003ho`800?3o0P00j?l2003Qo`800=Wo0P00dOl2003:o`800<;o0P00^_l2
002co`800:_o0`00Xol2002Lo`8009Co0`00S?l20025o`<007go0`00MOl2
001^o`<006Ko0`00G_l4001Go`<004oo0`00Aol5000oo`@003So1P00<?l6
000Xo`X0027o9`006Ol3000Qo`D0oooo0@0000010?ooo`009P3oool00`00
0000oooo0?ooo`030?ooo`P00?lQ7P00oaT;003o8@L00?lX1P00oc05003o
>0@00?lo1000odL4003oC`<00?mG0`00oeh3003oIP<00?m^0P00ogD3003o
O@<00?n50P00oh`2003oU0<00?nL0P00oj<2003oZ`800?nc0`00okX2003o
`P800?o:0P00om42003of@800?oQ0P00onP2003ol0800?oh0P00ool2003h
o`800?3o0P00j?l2003Qo`800=Wo0P00dOl2003:o`800<;o0P00^_l3002c
o`800:_o0P00Xol2002Lo`<009Co0P00S?l30025o`8007go0`00MOl3001^
o`<006Ko0`00G_l3001Go`@004oo1000Aol4000oo`D003So1P00<?l7000X
o`/0027o7P006Ol8000Qo`D0oooo0@0000010?ooo`009P3oool00`000000
oooo0?ooo`030?ooo`l00?lQ3`00oaT?003o8@P00?lX1`00oc05003o>0@0
0?lo1000odL4003oC`@00?mG0`00oeh3003oIP<00?m^0`00ogD2003oO@<0
0?n50P00oh`3003oU0800?nL0P00oj<3003oZ`800?nc0P00okX2003o`P80
0?o:0`00om42003of@800?oQ0P00onP2003ol0800?oh0P00ool2003ho`80
0?3o0P00j?l2003Qo`800=Wo0P00dOl2003:o`<00<;o0P00^_l2002co`80
0:_o0`00Xol2002Lo`8009Co0`00S?l30025o`8007go0`00MOl3001^o`<0
06Ko0`00G_l4001Go`@004oo1000Aol4000oo`D003So1P00<?l8000Xoa00
027o3`006Ol?000Qo`D0oooo0@0000010?ooo`009P3oool00`000000oooo
0?ooo`030?ooo`03003o:000ob400?lQ02H00?lQ2P00obP7003o<0D00?lh
1@00ocl4003oA`@00?m?1000oeL3003oGP<00?mV0`00ofh3003oM@<00?mm
0P00ohD3003oS0800?nD0`00oi`2003oX`800?n[0`00ok<2003o^P800?o2
0P00olX2003od@<00?oI0P00on42003oj0800?o`0P00ooP2003oo`800?So
0P00l?l2003Xo`800>7o0P00fOl3003Ao`800<[o0P00`_l2002jo`800;?o
0`00Zol2002So`8009co0`00U?l2002<o`<008Go0`00OOl3001eo`<006ko
0`00I_l3001No`@005Oo1000Col40017o`@003oo1P00>?l7000`o`T002So
:@008Ol00`00:?l0oooo0?ooo`030?ooo`4000000@3oool002H0oooo00<0
00000?ooo`3oool00`3oool5003o:2000?lQ2`00obP7003o<0H00?lh1P00
ocl4003oA`@00?m?1000oeL3003oGP<00?mV1000ofh2003oM@<00?mm0`00
ohD2003oS0<00?nD0P00oi`3003oX`800?n[0P00ok<3003o^P800?o20P00
olX2003od@800?oI0P00on43003oj0800?o`0P00ooP2003oo`800?So0P00
l?l2003Xo`<00>7o0P00fOl2003Ao`800<[o0P00`_l3002jo`800;?o0P00
Zol2002So`<009co0`00U?l2002<o`<008Go0`00OOl2001eo`@006ko0`00
I_l3001No`@005Oo1000Col40017o`D003oo1P00>?l8000`o`/002So8000
8Ol5000Xo`D0oooo0@0000010?ooo`009P3oool3000000<0oooo3000obPB
003o8@l00?lX2000oc06003o>0H00?lo1000odL5003oC`<00?mG1000oeh4
003oIP<00?m^0`00ogD2003oO@<00?n50`00oh`2003oU0<00?nL0P00oj<3
003oZ`800?nc0P00okX3003o`P800?o:0P00om42003of@800?oQ0`00onP2
003ol0800?oh0P00ool2003ho`800?3o0P00j?l3003Qo`800=Wo0P00dOl2
003:o`<00<;o0P00^_l2002co`800:_o0`00Xol2002Lo`<009Co0`00S?l2
0025o`<007go0`00MOl3001^o`@006Ko0`00G_l4001Go`@004oo1@00Aol5
000oo`H003So2000<?l@000Xoa80027o3000:?l40?ooo`8000000@3oool0
02H0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`4000000@3oool002H0
oooo00<000000?ooo`3oool0o`3ooolA0?ooo`4000000@3oool002H0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo01`0oooo0@0000010?ooo`009P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`4000000@3o
ool002H0ooooo`00000E00000040oooo003o0?oooc`0oooo003o0?oooc`0
oooo003o0?oooc`0oooo003o0?oooc`0oooo003o0?oooc`0oooo003o0?oo
oc`0oooo003o0?oooc`0oooo003o0?oooc`0oooo0000\
\>"], "Graphics",
  CellLabel->"From (V5.2 on byblis2) In[3]:=",
  Evaluatable->False,
  ImageSize->{315, 315},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{540, 633},
WindowMargins->{{118, Automatic}, {Automatic, 101}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "mtrott7", "Texts"}, \
"TitleOfBox1.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
PrivateNotebookOptions->{"ShortBoxForm"->False},
CellLabelAutoDelete->False,
ShowCellTags->False,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "NoCodePrintout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["Input", "NoCodePrintout"],
    CellMargins->{{39, 0}, {4, 6}},
    CellOpen->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageSize->{Automatic, 160},
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Special Styles", "Section"],
  
  Cell[StyleData["GraphicsTitle"],
    CellMargins->{{12, Inherited}, {20, 40}},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["IntroductionSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["NSDLMetaDataSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["NSDLMetaData"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AltTag"],
    CellMargins->{{12, 10}, {7, 7}},
    CellFrameLabels->{{
      Cell[ "AT", "Text", FontColor -> RGBColor[ 0, 0.299992, 0.299992]], 
          Inherited}, {Inherited, Inherited}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["AltTag", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GraphicsCount"],
    CellMargins->{{12, 10}, {7, 7}},
    CellFrameLabels->{{
      Cell[ "CG", "Text", FontColor -> GrayLevel[ 0.2]], Inherited}, {
        Inherited, Inherited}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["GC", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrivateInput"],
    CellFrame->{{6, 0}, {0, 0}},
    CellMargins->{{50, 4}, {2, 6}},
    CellBracketOptions->{"Thickness"->2,
    "Color"->RGBColor[0, 0.299992, 0.299992]},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0, 0.299992, 0.299992],
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    SpellingOptions->{"AlwaysStop"->{}},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["PrivateInput", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TraditionalFormEquation"],
    CellMargins->{{85, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->{"OutputGrouping", 50},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Above,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Plain"],
  
  Cell[StyleData["TraditionalFormEquation", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["TraditionalFormEquation", "WebSite"],
    CellMargins->{{56, 10}, {5, 7}}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{59, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{108, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{158, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 110, 4, 61, "Section"],

Cell[CellGroupData[{
Cell[1911, 61, 30, 0, 45, "Subsection"],
Cell[1944, 63, 435, 10, 68, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2416, 78, 31, 0, 29, "Subsection"],

Cell[CellGroupData[{
Cell[2472, 82, 112, 4, 42, "Subsubsection"],
Cell[2587, 88, 448, 12, 68, "Text"],

Cell[CellGroupData[{
Cell[3060, 104, 59, 1, 27, "Input"],
Cell[3122, 107, 60, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[3219, 113, 67, 1, 27, "Input"],
Cell[3289, 116, 93, 2, 28, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3431, 124, 54, 0, 42, "Subsubsection"],
Cell[3488, 126, 454, 17, 50, "Text"],

Cell[CellGroupData[{
Cell[3967, 147, 451, 11, 27, "Input"],
Cell[4421, 160, 1317, 42, 27, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5799, 209, 63, 0, 29, "Subsection"],

Cell[CellGroupData[{
Cell[5887, 213, 117, 3, 42, "Subsubsection"],
Cell[6007, 218, 265, 10, 32, "Text"],

Cell[CellGroupData[{
Cell[6297, 232, 88, 2, 40, "Input"],
Cell[6388, 236, 67, 2, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[6492, 243, 172, 4, 40, "Input"],
Cell[6667, 249, 67, 2, 49, "Output"]
}, Closed]],
Cell[6749, 254, 169, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[6943, 262, 60, 1, 27, "Input"],
Cell[7006, 265, 47, 0, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[7090, 270, 142, 3, 27, "Input"],
Cell[7235, 275, 66, 1, 27, "Output"]
}, Closed]],
Cell[7316, 279, 270, 10, 32, "Text"],

Cell[CellGroupData[{
Cell[7611, 293, 212, 5, 27, "Input"],
Cell[7826, 300, 148, 2, 43, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[8011, 307, 122, 3, 27, "Input"],
Cell[8136, 312, 175, 3, 43, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[8348, 320, 176, 5, 27, "Input"],
Cell[8527, 327, 175, 3, 43, "Output"]
}, Closed]],
Cell[8717, 333, 389, 10, 50, "Text"],

Cell[CellGroupData[{
Cell[9131, 347, 889, 23, 59, "Input"],
Cell[10023, 372, 854, 23, 43, "Output"]
}, Closed]],
Cell[10892, 398, 270, 9, 32, "Text"],

Cell[CellGroupData[{
Cell[11187, 411, 204, 6, 27, "Input"],
Cell[11394, 419, 274, 7, 43, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[11705, 431, 630, 17, 27, "Input"],
Cell[12338, 450, 612, 16, 75, "Output"]
}, Closed]],
Cell[12965, 469, 473, 13, 68, "Text"],

Cell[CellGroupData[{
Cell[13463, 486, 542, 15, 27, "Input"],
Cell[14008, 503, 346, 8, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[14391, 516, 61, 1, 27, "Input"],
Cell[14455, 519, 155, 4, 57, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14659, 529, 55, 0, 42, "Subsubsection"],
Cell[14717, 531, 161, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[14903, 540, 81, 2, 27, "Input"],
Cell[14987, 544, 60, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[15084, 550, 570, 16, 27, "Input"],
Cell[15657, 568, 342, 9, 27, "Output"]
}, Closed]],
Cell[16014, 580, 193, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[16232, 589, 96, 2, 27, "Input"],
Cell[16331, 593, 28, 0, 27, "Output"]
}, Closed]],
Cell[16374, 596, 237, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[16636, 606, 615, 15, 43, "Input"],
Cell[17254, 623, 637, 20, 62, "Output"]
}, Closed]],
Cell[17906, 646, 988, 32, 50, "Text"],

Cell[CellGroupData[{
Cell[18919, 682, 117, 3, 40, "Input"],
Cell[19039, 687, 60, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[19136, 693, 729, 20, 61, "Input"],
Cell[19868, 715, 440, 12, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[20345, 732, 98, 2, 27, "Input"],
Cell[20446, 736, 61, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[20544, 742, 714, 18, 40, "Input"],
Cell[21261, 762, 459, 12, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21769, 780, 102, 3, 42, "Subsubsection"],
Cell[21874, 785, 152, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[22051, 792, 86, 2, 27, "Input"],
Cell[22140, 796, 60, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[22237, 802, 1028, 28, 43, "Input"],
Cell[23268, 832, 405, 10, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[23722, 848, 107, 3, 42, "Subsubsection"],
Cell[23832, 853, 384, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[24241, 865, 1070, 29, 82, "Input"],
Cell[25314, 896, 538, 16, 58, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[25913, 919, 161, 5, 46, "Subsection"],

Cell[CellGroupData[{
Cell[26099, 928, 40, 0, 42, "Subsubsection"],
Cell[26142, 930, 1840, 54, 107, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[28019, 989, 35, 0, 42, "Subsubsection"],
Cell[28057, 991, 488, 12, 86, "Text"],

Cell[CellGroupData[{
Cell[28570, 1007, 129, 3, 27, "Input"],
Cell[28702, 1012, 251, 7, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[28990, 1024, 120, 3, 27, "Input"],
Cell[29113, 1029, 364, 10, 29, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[29514, 1044, 152, 4, 29, "Input"],
Cell[29669, 1050, 457, 13, 46, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[30163, 1068, 274, 7, 27, "Input"],
Cell[30440, 1077, 1031, 26, 45, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[31520, 1109, 35, 0, 42, "Subsubsection"],
Cell[31558, 1111, 471, 11, 86, "Text"],

Cell[CellGroupData[{
Cell[32054, 1126, 165, 4, 27, "Input"],
Cell[32222, 1132, 305, 9, 41, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[32564, 1146, 161, 4, 27, "Input"],
Cell[32728, 1152, 713, 21, 41, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33490, 1179, 35, 0, 42, "Subsubsection"],
Cell[33528, 1181, 713, 21, 86, "Text"],

Cell[CellGroupData[{
Cell[34266, 1206, 160, 4, 27, "Input"],
Cell[34429, 1212, 276, 8, 44, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[34742, 1225, 156, 4, 27, "Input"],
Cell[34901, 1231, 276, 8, 44, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[35214, 1244, 272, 7, 27, "Input"],
Cell[35489, 1253, 1320, 36, 80, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[36846, 1294, 456, 12, 27, "Input"],
Cell[37305, 1308, 514, 14, 44, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[37856, 1327, 215, 6, 27, "Input"],
Cell[38074, 1335, 121, 3, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[38244, 1344, 34, 0, 42, "Subsubsection"],
Cell[38281, 1346, 347, 11, 50, "Text"],

Cell[CellGroupData[{
Cell[38653, 1361, 99, 2, 27, "Input"],
Cell[38755, 1365, 305, 8, 46, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[39097, 1378, 222, 6, 27, "Input"],
Cell[39322, 1386, 733, 19, 44, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[40104, 1411, 34, 0, 42, "Subsubsection"],
Cell[40141, 1413, 356, 13, 50, "Text"],

Cell[CellGroupData[{
Cell[40522, 1430, 141, 3, 27, "Input"],
Cell[40666, 1435, 60, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[40763, 1441, 925, 23, 29, "Input"],
Cell[41691, 1466, 772, 18, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[42512, 1490, 38, 0, 42, "Subsubsection"],
Cell[42553, 1492, 838, 33, 68, "Text"],

Cell[CellGroupData[{
Cell[43416, 1529, 175, 4, 27, "Input"],
Cell[43594, 1535, 275, 7, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[43906, 1547, 323, 9, 27, "Input"],
Cell[44232, 1558, 132, 3, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[44401, 1566, 364, 9, 27, "Input"],
Cell[44768, 1577, 122, 3, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[44927, 1585, 364, 9, 27, "Input"],
Cell[45294, 1596, 146, 4, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[45477, 1605, 365, 9, 27, "Input"],
Cell[45845, 1616, 417, 12, 37, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[46299, 1633, 632, 17, 43, "Input"],
Cell[46934, 1652, 255, 8, 53, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[47226, 1665, 562, 14, 27, "Input"],
Cell[47791, 1681, 253, 7, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[48081, 1693, 365, 9, 27, "Input"],
Cell[48449, 1704, 330, 9, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[48816, 1718, 632, 17, 43, "Input"],
Cell[49451, 1737, 330, 9, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[49818, 1751, 429, 11, 43, "Input"],
Cell[50250, 1764, 275, 7, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[50574, 1777, 33, 0, 42, "Subsubsection"],
Cell[50610, 1779, 253, 8, 50, "Text"],

Cell[CellGroupData[{
Cell[50888, 1791, 356, 11, 29, "Input"],
Cell[51247, 1804, 28, 0, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[51312, 1809, 518, 15, 29, "Input"],
Cell[51833, 1826, 244, 7, 29, "Output"]
}, Closed]],
Cell[52092, 1836, 131, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[52248, 1843, 4605, 120, 386, "Input"],
Cell[56856, 1965, 31, 0, 27, "Output"]
}, Closed]],
Cell[56902, 1968, 818, 31, 68, "Text"],

Cell[CellGroupData[{
Cell[57745, 2003, 260, 7, 27, "Input"],
Cell[58008, 2012, 31, 0, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[58076, 2017, 312, 9, 27, "Input"],
Cell[58391, 2028, 31, 0, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[58459, 2033, 519, 13, 27, "Input"],
Cell[58981, 2048, 205, 6, 29, "Output"]
}, Closed]],
Cell[59201, 2057, 237, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[59463, 2066, 96, 2, 27, "Input"],
Cell[59562, 2070, 97, 2, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[59696, 2077, 248, 6, 27, "Input"],
Cell[59947, 2085, 28, 0, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[60024, 2091, 54, 0, 42, "Subsubsection"],
Cell[60081, 2093, 484, 11, 86, "Text"],

Cell[CellGroupData[{
Cell[60590, 2108, 219, 6, 40, "Input"],
Cell[60812, 2116, 220, 6, 41, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[61069, 2127, 34, 0, 27, "Input"],
Cell[61106, 2129, 1619, 47, 126, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[62762, 2181, 64, 1, 27, "Input"],
Cell[62829, 2184, 896, 28, 62, "Output"]
}, Closed]],
Cell[63740, 2215, 345, 9, 51, "Text"],

Cell[CellGroupData[{
Cell[64110, 2228, 117, 3, 40, "Input"],
Cell[64230, 2233, 118, 3, 41, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[64385, 2241, 46, 0, 27, "Input"],
Cell[64434, 2243, 1803, 47, 73, "Output"]
}, Closed]],
Cell[66252, 2293, 193, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[66470, 2303, 105, 2, 27, "Input"],
Cell[66578, 2307, 333, 10, 29, "Output"]
}, Closed]],
Cell[66926, 2320, 293, 9, 50, "Text"],

Cell[CellGroupData[{
Cell[67244, 2333, 460, 13, 43, "Input"],
Cell[67707, 2348, 434, 13, 53, "Output"]
}, Closed]],
Cell[68156, 2364, 157, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[68338, 2373, 64, 1, 27, "Input"],
Cell[68405, 2376, 422, 13, 53, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[68876, 2395, 37, 0, 42, "Subsubsection"],
Cell[68916, 2397, 514, 17, 68, "Text"],

Cell[CellGroupData[{
Cell[69455, 2418, 2859, 71, 170, "Input"],
Cell[72317, 2491, 3999, 107, 166, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[76353, 2603, 63, 1, 27, "Input"],
Cell[76419, 2606, 2169, 59, 116, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[78625, 2670, 67, 1, 27, "Input"],
Cell[78695, 2673, 613, 19, 62, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[79369, 2699, 144, 5, 29, "Subsection"],

Cell[CellGroupData[{
Cell[79538, 2708, 42, 0, 42, "Subsubsection"],
Cell[79583, 2710, 124, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[79732, 2717, 195, 5, 27, "Input"],
Cell[79930, 2724, 357, 10, 46, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[80324, 2739, 62, 1, 27, "Input"],
Cell[80389, 2742, 108, 3, 46, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[80534, 2750, 245, 7, 27, "Input"],
Cell[80782, 2759, 14395, 316, 1597, "Output"]
}, Closed]],
Cell[95192, 3078, 647, 22, 68, "Text"],
Cell[95842, 3102, 91, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[95958, 3108, 280, 8, 27, "Input"],
Cell[96241, 3118, 367, 10, 47, "Output"]
}, Closed]],
Cell[96623, 3131, 64, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[96712, 3135, 242, 6, 52, "Input"],
Cell[96957, 3143, 84, 2, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[97090, 3151, 40, 0, 42, "Subsubsection"],
Cell[97133, 3153, 171, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[97329, 3162, 117, 3, 27, "Input"],
Cell[97449, 3167, 82, 2, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[97568, 3174, 177, 5, 28, "Input"],
Cell[97748, 3181, 82, 2, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[97867, 3188, 322, 9, 27, "Input"],
Cell[98192, 3199, 676, 18, 43, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[98917, 3223, 41, 0, 42, "Subsubsection"],
Cell[98961, 3225, 179, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[99165, 3234, 181, 5, 52, "Input"],
Cell[99349, 3241, 439, 13, 41, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[99825, 3259, 301, 9, 52, "Input"],
Cell[100129, 3270, 624, 18, 41, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[100802, 3294, 43, 0, 42, "Subsubsection"],
Cell[100848, 3296, 169, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[101042, 3305, 252, 7, 52, "Input"],
Cell[101297, 3314, 900, 24, 48, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[102234, 3343, 244, 7, 52, "Input"],
Cell[102481, 3352, 484, 12, 44, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[103002, 3369, 220, 6, 52, "Input"],
Cell[103225, 3377, 564, 16, 44, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[103838, 3399, 40, 0, 42, "Subsubsection"],
Cell[103881, 3401, 184, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[104090, 3410, 280, 8, 54, "Input"],
Cell[104373, 3420, 480, 14, 44, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[104902, 3440, 47, 0, 42, "Subsubsection"],
Cell[104952, 3442, 203, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[105180, 3451, 154, 4, 43, "Input"],
Cell[105337, 3457, 60, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[105434, 3463, 186, 5, 43, "Input"],
Cell[105623, 3470, 802, 22, 57, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[106474, 3498, 45, 0, 42, "Subsubsection"],
Cell[106522, 3500, 193, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[106740, 3509, 243, 7, 45, "Input"],
Cell[106986, 3518, 155, 4, 41, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[107178, 3527, 253, 7, 48, "Input"],
Cell[107434, 3536, 294, 9, 61, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[107777, 3551, 40, 0, 42, "Subsubsection"],
Cell[107820, 3553, 165, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[108010, 3562, 283, 8, 44, "Input"],
Cell[108296, 3572, 48, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[108381, 3578, 315, 9, 50, "Input"],
Cell[108699, 3589, 73, 2, 44, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[108809, 3596, 450, 12, 48, "Input"],
Cell[109262, 3610, 77, 2, 44, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[109376, 3617, 476, 13, 48, "Input"],
Cell[109855, 3632, 99, 3, 44, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[110003, 3641, 42, 0, 42, "Subsubsection"],
Cell[110048, 3643, 254, 5, 68, "Text"],

Cell[CellGroupData[{
Cell[110327, 3652, 392, 11, 29, "Input"],
Cell[110722, 3665, 222, 5, 39, "Message"],
Cell[110947, 3672, 15656, 323, 1005, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[126640, 4000, 169, 5, 27, "Input"],
Cell[126812, 4007, 222, 5, 39, "Message"],
Cell[127037, 4014, 328, 9, 27, "Output"]
}, Closed]],
Cell[127380, 4026, 173, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[127578, 4036, 214, 6, 27, "Input"],
Cell[127795, 4044, 780, 20, 59, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[128624, 4070, 55, 0, 42, "Subsubsection"],
Cell[128682, 4072, 467, 13, 68, "Text"],

Cell[CellGroupData[{
Cell[129174, 4089, 338, 9, 27, "Input"],
Cell[129515, 4100, 412, 11, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[129964, 4116, 753, 20, 29, "Input"],
Cell[130720, 4138, 823, 23, 33, "Output"]
}, Closed]],
Cell[131558, 4164, 373, 10, 50, "Text"],

Cell[CellGroupData[{
Cell[131956, 4178, 718, 19, 29, "Input"],
Cell[132677, 4199, 967, 25, 53, "Output"]
}, Closed]],
Cell[133659, 4227, 135, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[133819, 4234, 156, 5, 27, "Input"],
Cell[133978, 4241, 188, 5, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[134203, 4251, 156, 5, 27, "Input"],
Cell[134362, 4258, 735, 21, 33, "Output"]
}, Closed]],
Cell[135112, 4282, 373, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[135510, 4294, 607, 16, 36, "Input"],
Cell[136120, 4312, 252, 6, 39, "Message"],
Cell[136375, 4320, 214, 6, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[136638, 4332, 44, 0, 42, "Subsubsection"],
Cell[136685, 4334, 251, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[136961, 4344, 145, 3, 27, "Input"],
Cell[137109, 4349, 108, 3, 41, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[137254, 4357, 145, 3, 27, "Input"],
Cell[137402, 4362, 385, 12, 52, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[137824, 4379, 148, 3, 27, "Input"],
Cell[137975, 4384, 433, 14, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[138445, 4403, 148, 3, 27, "Input"],
Cell[138596, 4408, 385, 12, 52, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[139018, 4425, 181, 5, 27, "Input"],
Cell[139202, 4432, 78, 2, 41, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[139329, 4440, 33, 0, 42, "Subsubsection"],
Cell[139365, 4442, 165, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[139555, 4451, 605, 17, 67, "Input"],
Cell[140163, 4470, 101140, 1661, 205, 100970, 1656, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[241340, 6136, 1309, 32, 98, "Input"],
Cell[242652, 6170, 229252, 3761, 323, 229090, 3756, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

