(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     48634,       1681]*)
(*NotebookOutlinePosition[     49263,       1703]*)
(*  CellTagsIndexPosition[     49219,       1699]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->12],

Cell[StyleData[All, "Condensed"],
  PageWidth->WindowWidth,
  CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->8],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->5,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "NoCodePrintout"],
  PageWidth->PaperWidth,
  CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->5,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 11},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["Title", "Presentation"],
  CellMargins->{{24, 10}, {20, 40}},
  LineSpacing->{1, 0},
  FontSize->44],

Cell[StyleData["Title", "Condensed"],
  CellMargins->{{8, 10}, {4, 8}},
  FontSize->20],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{2, 10}, {12, 30}},
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->24],

Cell[StyleData["Subtitle", "Presentation"],
  CellMargins->{{24, 10}, {20, 20}},
  LineSpacing->{1, 0},
  FontSize->36],

Cell[StyleData["Subtitle", "Condensed"],
  CellMargins->{{8, 10}, {4, 4}},
  FontSize->14],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {12, 8}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Presentation"],
  CellMargins->{{24, 10}, {20, 20}},
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["Subsubtitle", "Condensed"],
  CellMargins->{{8, 10}, {8, 8}},
  FontSize->12],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {12, 8}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 7},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Presentation"],
  CellMargins->{{40, 10}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["Section", "Condensed"],
  CellMargins->{{18, Inherited}, {6, 12}},
  FontSize->12],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{13, 0}, {7, 22}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Presentation"],
  CellMargins->{{36, 10}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->22],

Cell[StyleData["Subsection", "Condensed"],
  CellMargins->{{16, Inherited}, {6, 12}},
  FontSize->12],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 22}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Presentation"],
  CellMargins->{{34, 10}, {11, 26}},
  LineSpacing->{1, 0},
  FontSize->18],

Cell[StyleData["Subsubsection", "Condensed"],
  CellMargins->{{17, Inherited}, {6, 12}},
  FontSize->10],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{9, 0}, {7, 14}},
  FontSize->11]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  Hyphenation->True,
  LineSpacing->{1, 3},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5},
  FontSize->16],

Cell[StyleData["Text", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1},
  FontSize->11],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->0.5,
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  DefaultNewInlineCellStyle->"None",
  Hyphenation->True,
  LineSpacing->{1, 3},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"SmallText",
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["SmallText", "Presentation"],
  CellMargins->{{24, 10}, {8, 8}},
  LineSpacing->{1, 5},
  FontSize->12],

Cell[StyleData["SmallText", "Condensed"],
  CellMargins->{{8, 10}, {5, 5}},
  LineSpacing->{1, 2},
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->0.5,
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Mathematica",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{72, Inherited}, {8, 10}},
  LineSpacing->{1, 0},
  FontSize->16],

Cell[StyleData["Input", "Condensed"],
  CellMargins->{{40, 10}, {2, 3}},
  FontSize->11],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9],

Cell[StyleData["Input", "NoCodePrintout"],
  CellMargins->{{39, 0}, {4, 6}},
  CellOpen->False,
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9]
}, Open  ]],

Cell[StyleData["InputOnly"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Mathematica",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{47, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->None,
  FormatType->InputForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{72, Inherited}, {10, 8}},
  LineSpacing->{1, 0},
  FontSize->16],

Cell[StyleData["Output", "Condensed"],
  CellMargins->{{41, Inherited}, {3, 2}},
  FontSize->11],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->None,
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSize->11,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->16],

Cell[StyleData["Message", "Condensed"],
  CellMargins->{{41, Inherited}, {Inherited, Inherited}},
  FontSize->11],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->7,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->None,
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->16],

Cell[StyleData["Print", "Condensed"],
  CellMargins->{{41, Inherited}, {Inherited, Inherited}},
  FontSize->11],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  LanguageCategory->None,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageSize->{Automatic, 160},
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->10],

Cell[StyleData["Graphics", "Presentation"],
  ImageMargins->{{62, Inherited}, {Inherited, 0}}],

Cell[StyleData["Graphics", "Condensed"],
  ImageMargins->{{38, Inherited}, {Inherited, 0}},
  Magnification->0.6],

Cell[StyleData["Graphics", "Printout"],
  ImageMargins->{{30, Inherited}, {Inherited, 0}},
  Magnification->0.8]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  LanguageCategory->None,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->12],

Cell[StyleData["CellLabel", "Condensed"],
  FontSize->9],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Special Styles", "Section"],

Cell[StyleData["GraphicsTitle"],
  CellMargins->{{12, Inherited}, {20, 40}},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  LineSpacing->{1, 11},
  LanguageCategory->"NaturalLanguage",
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["IntroductionSection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 7},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[StyleData["CodeSection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 7},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->GrayLevel[0.500008]],

Cell[StyleData["NSDLMetaDataSection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 7},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->GrayLevel[0.500008]],

Cell[StyleData["SideBarGraphics"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 7},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->GrayLevel[0.500008]],

Cell[StyleData["NSDLMetaData"],
  CellMargins->{{12, 10}, {7, 7}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  Hyphenation->True,
  LineSpacing->{1, 3},
  CounterIncrements->"Text"],

Cell[CellGroupData[{

Cell[StyleData["AltTag"],
  CellMargins->{{12, 10}, {7, 7}},
  CellFrameLabels->{{
    Cell[ "AT", "Text", FontColor -> RGBColor[ 0, 0.299992, 0.299992]], 
        Inherited}, {Inherited, Inherited}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  Hyphenation->True,
  LineSpacing->{1, 3},
  CounterIncrements->"Text"],

Cell[StyleData["AltTag", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->0.5,
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GraphicsCount"],
  CellMargins->{{12, 10}, {7, 7}},
  CellFrameLabels->{{
    Cell[ "CG", "Text", FontColor -> GrayLevel[ 0.2]], Inherited}, {
      Inherited, Inherited}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  Hyphenation->True,
  LineSpacing->{1, 3},
  CounterIncrements->"Text",
  FontFamily->"Courier",
  FontColor->GrayLevel[0]],

Cell[StyleData["GC", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->0.5,
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SideBarAltTag"],
  CellMargins->{{12, 10}, {7, 7}},
  CellFrameLabels->{{
    Cell[ "SBAT", "Text", FontColor -> RGBColor[ 0.8, 0.1, 0.1]], 
        Inherited}, {Inherited, Inherited}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  Hyphenation->True,
  LineSpacing->{1, 3},
  CounterIncrements->"Text"],

Cell[StyleData["SideBarAltTag", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->0.5,
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SideBarGraphicsLink"],
  CellMargins->{{12, 10}, {7, 7}},
  CellFrameLabels->{{
    Cell[ "SBL", "Text", FontColor -> RGBColor[ 0.0, 0.0, 0.6]], Inherited}, {
      Inherited, Inherited}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  Hyphenation->True,
  LineSpacing->{1, 3},
  CounterIncrements->"Text"],

Cell[StyleData["SideBarGraphicsLink", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->0.5,
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["PrivateInput"],
  CellFrame->{{6, 0}, {0, 0}},
  CellMargins->{{50, 4}, {2, 6}},
  CellBracketOptions->{"Thickness"->2,
  "Color"->RGBColor[0, 0.299992, 0.299992]},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0, 0.299992, 0.299992],
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->None,
  SpellingOptions->{"AlwaysStop"->{}},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["PrivateInput", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Section"],

Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[StyleData["SO10"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "Printout"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "EnhancedPrintout"],
  StyleMenuListing->None,
  FontFamily->"Futura",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["InlineFormula"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  ScriptLevel->1,
  SingleLetterItalics->True],

Cell[StyleData["InlineFormula", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5},
  FontSize->16],

Cell[StyleData["InlineFormula", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1},
  FontSize->11],

Cell[StyleData["InlineFormula", "Printout"],
  CellMargins->{{2, 0}, {6, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{42, Inherited}, {Inherited, Inherited}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Presentation"],
  LineSpacing->{1, 5},
  FontSize->16],

Cell[StyleData["DisplayFormula", "Condensed"],
  LineSpacing->{1, 1},
  FontSize->11],

Cell[StyleData["DisplayFormula", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  Hyphenation->False,
  LanguageCategory->"Formula",
  ScriptLevel->1,
  FontFamily->"Courier"],

Cell[StyleData["Program", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5},
  FontSize->16],

Cell[StyleData["Program", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1},
  FontSize->11],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{2, 0}, {6, 6}},
  FontSize->9]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Outline Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Outline1"],
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 50},
  ParagraphIndent->-38,
  CounterIncrements->"Outline1",
  FontSize->18,
  FontWeight->"Bold",
  CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],

Cell[StyleData["Outline1", "Printout"],
  CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline2"],
  CellMargins->{{59, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 60},
  ParagraphIndent->-27,
  CounterIncrements->"Outline2",
  FontSize->15,
  FontWeight->"Bold",
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "A", "Z"], #]&)}],

Cell[StyleData["Outline2", "Printout"],
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "A", "Z"], #]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline3"],
  CellMargins->{{108, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 70},
  ParagraphIndent->-21,
  CounterIncrements->"Outline3",
  FontSize->12,
  CounterBoxOptions->{CounterFunction:>Identity}],

Cell[StyleData["Outline3", "Printout"],
  CounterBoxOptions->{CounterFunction:>Identity}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline4"],
  CellMargins->{{158, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 80},
  ParagraphIndent->-18,
  CounterIncrements->"Outline4",
  FontSize->10,
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "a", "z"], #]&)}],

Cell[StyleData["Outline4", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Presentation"],
  FontSize->16],

Cell[StyleData["Hyperlink", "Condensed"],
  FontSize->11],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Presentation"],
  FontSize->16],

Cell[StyleData["MainBookLink", "Condensed"],
  FontSize->11],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Presentation"],
  FontSize->16],

Cell[StyleData["AddOnsLink", "Condensed"],
  FontSize->11],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Presentation"],
  FontSize->16],

Cell[StyleData["RefGuideLink", "Condensed"],
  FontSize->11],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Presentation"],
  FontSize->16],

Cell[StyleData["GettingStartedLink", "Condensed"],
  FontSize->11],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Presentation"],
  FontSize->16],

Cell[StyleData["OtherInformationLink", "Condensed"],
  FontSize->11],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  DefaultNewInlineCellStyle->"None",
  LanguageCategory->"NaturalLanguage",
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  DefaultNewInlineCellStyle->"None",
  LanguageCategory->"NaturalLanguage",
  StyleMenuListing->None,
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Section"],

Cell["\<\
The cells below define styles useful for making placeholder objects \
in palette templates.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Placeholder"],
  Placeholder->True,
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[0.890623, 0.864698, 0.384756],
  TagBoxOptions->{Editable->False,
  Selectable->False,
  StripWrapperBoxes->False}],

Cell[StyleData["Placeholder", "Presentation"]],

Cell[StyleData["Placeholder", "Condensed"]],

Cell[StyleData["Placeholder", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PrimaryPlaceholder"],
  StyleMenuListing->None,
  DrawHighlighted->True,
  FontSlant->"Italic",
  Background->RGBColor[0.912505, 0.891798, 0.507774],
  TagBoxOptions->{Editable->False,
  Selectable->False,
  StripWrapperBoxes->False}],

Cell[StyleData["PrimaryPlaceholder", "Presentation"]],

Cell[StyleData["PrimaryPlaceholder", "Condensed"]],

Cell[StyleData["PrimaryPlaceholder", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  Hyphenation->False,
  AutoItalicWords->{},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12,
  Background->GrayLevel[1]],

Cell[StyleData["InputForm"],
  InputAutoReplacements->{},
  AllowInlineCells->False,
  Hyphenation->False,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{0.6, 1},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  InputAutoReplacements->{
    "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
      ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
      Inherited},
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  InputAutoReplacements->{
    "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
      ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
      Inherited},
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  LanguageCategory->"Formula",
  ScriptLevel->1,
  StyleMenuListing->None],

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  Background->RGBColor[1, 0.749996, 0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell["Automatic Styles", "Section"],

Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],

Cell[StyleData["UnmatchedBracket"],
  StyleMenuListing->None,
  FontColor->RGBColor[0.760006, 0.330007, 0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell["Misc Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["TitleCell1"],
  ShowCellBracket->False,
  CellMargins->{{-2, 0}, {-5, 0}},
  CellLabelMargins->{{0, 0}, {0, 0}},
  CellFrameMargins->False,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  Background->RGBColor[0.796078, 0.4, 0],
  ButtonBoxOptions->{ButtonFrame->"None"}],

Cell[StyleData["TitleCell1", "Printout"],
  CellMargins->{{0, 0}, {0, 0}}],

Cell[StyleData["TitleCell1", "WebSite"],
  CellMargins->{{-2, 0}, {-5, -2}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TitleCell2"],
  ShowCellBracket->False,
  CellMargins->{{-6, 0}, {0, 0}},
  CellFrameMargins->2,
  StyleMenuListing->None,
  FontSize->14,
  FontSlant->"Italic",
  FontColor->GrayLevel[0.666667],
  Background->GrayLevel[0],
  ButtonBoxOptions->{ButtonFrame->"None"}],

Cell[StyleData["TitleCell2", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->0.5,
  FontSize->7],

Cell[StyleData["TitleCell2", "WebSite"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->0.5,
  FontSize->7]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{664, 665},
WindowMargins->{{55, Automatic}, {36, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 51, "Subtitle"],
Cell[1816, 55, 193, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[2034, 63, 42, 0, 75, "Section"],
Cell[2079, 65, 140, 3, 38, 31, 0, "StyleData", "All", "Working"],
Cell[2222, 70, 146, 3, 38, 36, 0, "StyleData", "All", "Presentation"],
Cell[2371, 75, 141, 3, 38, 33, 0, "StyleData", "All", "Condensed"],
Cell[2515, 80, 186, 4, 34, 32, 0, "StyleData", "All", "Printout"],
Cell[2704, 86, 192, 4, 34, 38, 0, "StyleData", "All", "NoCodePrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2933, 95, 35, 0, 45, "Section"],
Cell[2971, 97, 101, 3, 32, "Text"],
Cell[3075, 102, 426, 11, 38, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3538, 118, 38, 0, 45, "Section"],

Cell[CellGroupData[{
Cell[3601, 122, 1102, 26, 121, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[4706, 150, 116, 3, 70, 40, 0, "StyleData", "Title", "Presentation"],
Cell[4825, 155, 87, 2, 70, 37, 0, "StyleData", "Title", "Condensed"],
Cell[4915, 159, 88, 2, 70, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5040, 166, 1046, 24, 67, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[6089, 192, 119, 3, 70, 43, 0, "StyleData", "Subtitle", "Presentation"],
Cell[6211, 197, 90, 2, 70, 40, 0, "StyleData", "Subtitle", "Condensed"],
Cell[6304, 201, 90, 2, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6431, 208, 1048, 24, 56, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[7482, 234, 122, 3, 70, 46, 0, "StyleData", "Subsubtitle", \
"Presentation"],
Cell[7607, 239, 93, 2, 70, 43, 0, "StyleData", "Subsubtitle", "Condensed"],
Cell[7703, 243, 93, 2, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7833, 250, 1090, 26, 48, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[8926, 278, 118, 3, 70, 42, 0, "StyleData", "Section", "Presentation"],
Cell[9047, 283, 98, 2, 70, 39, 0, "StyleData", "Section", "Condensed"],
Cell[9148, 287, 89, 2, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9274, 294, 1055, 25, 43, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[10332, 321, 121, 3, 70, 45, 0, "StyleData", "Subsection", \
"Presentation"],
Cell[10456, 326, 101, 2, 70, 42, 0, "StyleData", "Subsection", "Condensed"],
Cell[10560, 330, 91, 2, 70, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10688, 337, 999, 23, 42, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[11690, 362, 124, 3, 70, 48, 0, "StyleData", "Subsubsection", \
"Presentation"],
Cell[11817, 367, 104, 2, 70, 45, 0, "StyleData", "Subsubsection", \
"Condensed"],
Cell[11924, 371, 94, 2, 70, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12067, 379, 39, 0, 45, "Section"],

Cell[CellGroupData[{
Cell[12131, 383, 786, 18, 44, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[12920, 403, 115, 3, 56, 39, 0, "StyleData", "Text", "Presentation"],
Cell[13038, 408, 109, 3, 42, 36, 0, "StyleData", "Text", "Condensed"],
Cell[13150, 413, 110, 3, 40, 35, 0, "StyleData", "Text", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13297, 421, 259, 8, 39, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[13559, 431, 118, 3, 68, 44, 0, "StyleData", "SmallText", \
"Presentation"],
Cell[13680, 436, 113, 3, 68, 41, 0, "StyleData", "SmallText", "Condensed"],
Cell[13796, 441, 114, 3, 68, 40, 0, "StyleData", "SmallText", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13959, 450, 42, 0, 45, "Section"],
Cell[14004, 452, 364, 6, 86, "Text"],

Cell[CellGroupData[{
Cell[14393, 462, 551, 16, 42, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[14947, 480, 122, 3, 56, 40, 0, "StyleData", "Input", "Presentation"],
Cell[15072, 485, 88, 2, 36, 37, 0, "StyleData", "Input", "Condensed"],
Cell[15163, 489, 130, 3, 38, 36, 0, "StyleData", "Input", "Printout"],
Cell[15296, 494, 155, 4, 19, 42, 0, "StyleData", "Input", "NoCodePrintout"]
}, Open  ]],
Cell[15466, 501, 489, 14, 38, 28, 0, "StyleData", "InputOnly", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[15980, 519, 484, 14, 42, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[16467, 535, 123, 3, 52, 41, 0, "StyleData", "Output", "Presentation"],
Cell[16593, 540, 96, 2, 33, 38, 0, "StyleData", "Output", "Condensed"],
Cell[16692, 544, 86, 2, 35, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16815, 551, 547, 16, 38, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[17365, 569, 139, 3, 42, 42, 0, "StyleData", "Message", "Presentation"],
Cell[17507, 574, 113, 2, 36, 39, 0, "StyleData", "Message", "Condensed"],
Cell[17623, 578, 138, 3, 31, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17798, 586, 528, 15, 38, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[18329, 603, 137, 3, 42, 40, 0, "StyleData", "Print", "Presentation"],
Cell[18469, 608, 111, 2, 36, 37, 0, "StyleData", "Print", "Condensed"],
Cell[18583, 612, 109, 2, 33, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18729, 619, 537, 16, 34, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[19269, 637, 94, 1, 34, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[19366, 640, 113, 2, 27, 40, 0, "StyleData", "Graphics", "Condensed"],
Cell[19482, 644, 112, 2, 31, 39, 0, "StyleData", "Graphics", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19631, 651, 154, 5, 35, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[19788, 658, 60, 1, 38, 44, 0, "StyleData", "CellLabel", "Presentation"],
Cell[19851, 661, 56, 1, 35, 41, 0, "StyleData", "CellLabel", "Condensed"],
Cell[19910, 664, 130, 4, 33, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20089, 674, 33, 0, 45, "Section"],
Cell[20125, 676, 266, 8, 122, 32, 0, "StyleData", "GraphicsTitle", "All"],
Cell[20394, 686, 1129, 27, 69, 38, 0, "StyleData", "IntroductionSection", \
"All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[21526, 715, 1128, 27, 69, 30, 0, "StyleData", "CodeSection", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[22657, 744, 1136, 27, 69, 38, 0, "StyleData", "NSDLMetaDataSection", \
"All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[23796, 773, 1132, 27, 69, 34, 0, "StyleData", "SideBarGraphics", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[24931, 802, 794, 18, 44, 31, 0, "StyleData", "NSDLMetaData", "All",
  CounterIncrements->"Text"],

Cell[CellGroupData[{
Cell[25750, 824, 928, 21, 44, 25, 0, "StyleData", "AltTag", "All",
  CounterIncrements->"Text"],
Cell[26681, 847, 111, 3, 40, 37, 0, "StyleData", "AltTag", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26829, 855, 968, 23, 40, 32, 0, "StyleData", "GraphicsCount", "All",
  CounterIncrements->"Text"],
Cell[27800, 880, 107, 3, 40, 33, 0, "StyleData", "GC", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27944, 888, 929, 21, 41, 32, 0, "StyleData", "SideBarAltTag", "All",
  CounterIncrements->"Text"],
Cell[28876, 911, 118, 3, 40, 44, 0, "StyleData", "SideBarAltTag", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29031, 919, 932, 21, 44, 38, 0, "StyleData", "SideBarGraphicsLink", \
"All",
  CounterIncrements->"Text"],
Cell[29966, 942, 124, 3, 40, 50, 0, "StyleData", "SideBarGraphicsLink", \
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30127, 950, 738, 20, 38, 31, 0, "StyleData", "PrivateInput", "All",
  CounterIncrements->"Input"],
Cell[30868, 972, 137, 3, 38, 43, 0, "StyleData", "PrivateInput", "Printout"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[31054, 981, 36, 0, 45, "Section"],
Cell[31093, 983, 121, 3, 30, "Text"],
Cell[31217, 988, 92, 3, 36, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[31312, 993, 69, 2, 38, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[31384, 997, 70, 2, 38, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[31457, 1001, 115, 4, 36, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[31575, 1007, 116, 4, 38, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[31694, 1013, 114, 4, 38, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[31811, 1019, 116, 4, 38, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[31930, 1025, 184, 5, 36, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[32117, 1032, 185, 5, 37, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[32305, 1039, 183, 5, 37, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[32491, 1046, 185, 5, 37, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[32679, 1053, 119, 4, 37, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[32801, 1059, 120, 4, 38, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[32924, 1065, 118, 4, 38, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[33045, 1071, 120, 4, 38, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[33190, 1079, 138, 5, 35, 23, 0, "StyleData", "SO10", "All",
  StyleMenuListing->None],
Cell[33331, 1086, 149, 5, 70, 35, 0, "StyleData", "SO10", "Printout",
  StyleMenuListing->None],
Cell[33483, 1093, 154, 5, 70, 43, 0, "StyleData", "SO10", "EnhancedPrintout",
  StyleMenuListing->None]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33686, 1104, 43, 0, 45, "Section"],

Cell[CellGroupData[{
Cell[33754, 1108, 244, 6, 38, 32, 0, "StyleData", "InlineFormula", "All"],
Cell[34001, 1116, 124, 3, 70, 48, 0, "StyleData", "InlineFormula", \
"Presentation"],
Cell[34128, 1121, 118, 3, 70, 45, 0, "StyleData", "InlineFormula", \
"Condensed"],
Cell[34249, 1126, 93, 2, 70, 44, 0, "StyleData", "InlineFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34379, 1133, 370, 8, 38, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[34752, 1143, 88, 2, 70, 49, 0, "StyleData", "DisplayFormula", \
"Presentation"],
Cell[34843, 1147, 85, 2, 70, 46, 0, "StyleData", "DisplayFormula", \
"Condensed"],
Cell[34931, 1151, 61, 1, 70, 45, 0, "StyleData", "DisplayFormula", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[35029, 1157, 224, 7, 50, 26, 0, "StyleData", "Program", "All"],
Cell[35256, 1166, 118, 3, 70, 42, 0, "StyleData", "Program", "Presentation"],
Cell[35377, 1171, 112, 3, 70, 39, 0, "StyleData", "Program", "Condensed"],
Cell[35492, 1176, 86, 2, 70, 38, 0, "StyleData", "Program", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[35627, 1184, 33, 0, 45, "Section"],

Cell[CellGroupData[{
Cell[35685, 1188, 264, 7, 49, 27, 0, "StyleData", "Outline1", "All",
  CounterIncrements->"Outline1"],
Cell[35952, 1197, 100, 1, 70, 39, 0, "StyleData", "Outline1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36089, 1203, 290, 8, 42, 27, 0, "StyleData", "Outline2", "All",
  CounterIncrements->"Outline2"],
Cell[36382, 1213, 126, 2, 70, 39, 0, "StyleData", "Outline2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36545, 1220, 232, 6, 41, 27, 0, "StyleData", "Outline3", "All",
  CounterIncrements->"Outline3"],
Cell[36780, 1228, 89, 1, 70, 39, 0, "StyleData", "Outline3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36906, 1234, 269, 7, 39, 27, 0, "StyleData", "Outline4", "All",
  CounterIncrements->"Outline4"],
Cell[37178, 1243, 39, 0, 70, 39, 0, "StyleData", "Outline4", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[37266, 1249, 35, 0, 45, "Section"],
Cell[37304, 1251, 184, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[37513, 1259, 302, 8, 38, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[37818, 1269, 60, 1, 70, 44, 0, "StyleData", "Hyperlink", \
"Presentation"],
Cell[37881, 1272, 57, 1, 70, 41, 0, "StyleData", "Hyperlink", "Condensed"],
Cell[37941, 1275, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[38079, 1281, 104, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[38208, 1288, 316, 8, 38, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[38527, 1298, 63, 1, 70, 47, 0, "StyleData", "MainBookLink", \
"Presentation"],
Cell[38593, 1301, 60, 1, 70, 44, 0, "StyleData", "MainBookLink", \
"Condensed"],
Cell[38656, 1304, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38819, 1312, 337, 9, 37, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[39159, 1323, 61, 1, 70, 45, 0, "StyleData", "AddOnsLink", \
"Presentation"],
Cell[39223, 1326, 58, 1, 70, 42, 0, "StyleData", "AddOnsLink", "Condensed"],
Cell[39284, 1329, 124, 3, 70, 41, 0, "StyleData", "AddOnsLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39445, 1337, 341, 9, 37, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[39789, 1348, 63, 1, 70, 47, 0, "StyleData", "RefGuideLink", \
"Presentation"],
Cell[39855, 1351, 60, 1, 70, 44, 0, "StyleData", "RefGuideLink", \
"Condensed"],
Cell[39918, 1354, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[40081, 1362, 328, 8, 38, 37, 0, "StyleData", "GettingStartedLink", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[40412, 1372, 69, 1, 70, 53, 0, "StyleData", "GettingStartedLink", \
"Presentation"],
Cell[40484, 1375, 66, 1, 70, 50, 0, "StyleData", "GettingStartedLink", \
"Condensed"],
Cell[40553, 1378, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[40722, 1386, 332, 8, 38, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[41057, 1396, 71, 1, 70, 55, 0, "StyleData", "OtherInformationLink", \
"Presentation"],
Cell[41131, 1399, 68, 1, 70, 52, 0, "StyleData", "OtherInformationLink", \
"Condensed"],
Cell[41202, 1402, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[41385, 1411, 49, 0, 45, "Section"],
Cell[41437, 1413, 199, 6, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[41639, 1421, 198, 6, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[41840, 1429, 127, 4, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[42004, 1438, 33, 0, 45, "Section"],
Cell[42040, 1440, 121, 3, 32, "Text"],
Cell[42164, 1445, 226, 5, 38, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[42393, 1452, 295, 7, 38, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[42691, 1461, 400, 9, 38, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[43094, 1472, 387, 9, 38, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[43484, 1483, 401, 9, 38, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[43922, 1497, 37, 0, 45, "Section"],
Cell[43962, 1499, 115, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[44102, 1506, 238, 7, 38, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[44343, 1515, 46, 0, 70, 46, 0, "StyleData", "Placeholder", \
"Presentation"],
Cell[44392, 1517, 43, 0, 70, 43, 0, "StyleData", "Placeholder", "Condensed"],
Cell[44438, 1519, 42, 0, 70, 42, 0, "StyleData", "Placeholder", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[44517, 1524, 250, 7, 54, 37, 0, "StyleData", "PrimaryPlaceholder", "All",
  
  StyleMenuListing->None],
Cell[44770, 1533, 53, 0, 70, 53, 0, "StyleData", "PrimaryPlaceholder", \
"Presentation"],
Cell[44826, 1535, 50, 0, 70, 50, 0, "StyleData", "PrimaryPlaceholder", \
"Condensed"],
Cell[44879, 1537, 49, 0, 54, 49, 0, "StyleData", "PrimaryPlaceholder", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[44977, 1543, 36, 0, 45, "Section"],
Cell[45016, 1545, 305, 5, 68, "Text"],
Cell[45324, 1552, 336, 11, 37, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[45663, 1565, 157, 5, 37, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[45823, 1572, 151, 5, 37, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[45977, 1579, 292, 7, 37, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[46272, 1588, 363, 9, 38, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[46638, 1599, 115, 3, 32, "Text"],
Cell[46756, 1604, 104, 3, 38, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[46863, 1609, 104, 2, 54, 36, 0, "StyleData", "InlineCellEditing", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[47004, 1616, 35, 0, 45, "Section"],
Cell[47042, 1618, 330, 6, 68, "Text"],
Cell[47375, 1626, 109, 2, 38, 35, 0, "StyleData", "UnmatchedBracket", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[47521, 1633, 30, 0, 45, "Section"],

Cell[CellGroupData[{
Cell[47576, 1637, 308, 9, 22, 29, 0, "StyleData", "TitleCell1", "All",
  StyleMenuListing->None],
Cell[47887, 1648, 74, 1, 27, 41, 0, "StyleData", "TitleCell1", "Printout"],
Cell[47964, 1651, 76, 1, 20, 40, 0, "StyleData", "TitleCell1", "WebSite"]
}, Closed]],

Cell[CellGroupData[{
Cell[48077, 1657, 282, 9, 39, 29, 0, "StyleData", "TitleCell2", "All",
  StyleMenuListing->None],
Cell[48362, 1668, 115, 3, 37, 41, 0, "StyleData", "TitleCell2", "Printout"],
Cell[48480, 1673, 114, 3, 37, 40, 0, "StyleData", "TitleCell2", "WebSite"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

