(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    175487,       6019]*)
(*NotebookOutlinePosition[    176351,       6049]*)
(*  CellTagsIndexPosition[    176307,       6045]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The Euler Phi Function", "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["History", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
L. Euler used the number of integers not exceeding n and beeing \
relativ prime to n 
to prove Fermats (little) theorem in 1760. The symbol \\Phi was introduced by \
C. F. 
Gauss  in 1801. J. J. Sylvetser introduced the name \"totient' function in \
1879.
(He called the integers i, i<=n and prime to n the totitives of n.

Group theoretically Phi(r) is the number of generators of a cyclic group of \
order n.\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["some definitions for typesetting", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
DivisorSum[f_,d_,n_Integer?Positive]:=
Plus @@ ( Function[d,f] /@  Divisors[n])\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
DivisorProduct1[f_,d_,n_Integer?Positive]:=
Times @@ ( Rest[Function[d,f] /@  Divisors[n]])\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Clear[PrimeFactorProduct]
PrimeFactorProduct[f_,d_,n_Integer?(#>=1&)]:=
Times @@ ( Function[d,f] /@  
         ( First /@ FactorInteger[n]  ))\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Clear[PrimeFactorSum]
PrimeFactorSum[f_,d_,n_Integer?(#>=1&)]:=
Plus @@ ( Function[d,f] /@  
         ( First /@ FactorInteger[n]  ))\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["PropertySum[f_,{d_,l_List}]:=Plus @@ (Function[d,f] /@ l)", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["ReducedResidueSystem[n_]:=Select[Range[n],GCD[#,n]==1&]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["The Euler \\Phi function is defined by ", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
EulerPhi[1] = 1

EulerPhi[n] = # of positive integers which are 
              less then n and relative prime to n\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["This definition can be rewritten as be written as:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["EulerPhi[n] == n PrimeFactorProduct[1-1/d,d,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Group theoretically \\Phi(n) is the number of generators of a \
cyclic group of order n. \
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Particular Cases", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Table[EulerPhi[n],{n,1,12}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Here a graphical visualization of the first 1000 values:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Table[EulerPhi[n],{n,1,2000}],
         PlotStyle->{PointSize[0.001]}];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.0147151 0.000294596 [
[(500)] .2619 .01472 0 2 Msboxa
[(1000)] .5 .01472 0 2 Msboxa
[(1500)] .7381 .01472 0 2 Msboxa
[(2000)] .97619 .01472 0 2 Msboxa
[(500)] .01131 .16201 1 0 Msboxa
[(1000)] .01131 .30931 1 0 Msboxa
[(1500)] .01131 .45661 1 0 Msboxa
[(2000)] .01131 .60391 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .01472 m
.2619 .02097 L
s
P
[(500)] .2619 .01472 0 2 Mshowa
p
.002 w
.5 .01472 m
.5 .02097 L
s
P
[(1000)] .5 .01472 0 2 Mshowa
p
.002 w
.7381 .01472 m
.7381 .02097 L
s
P
[(1500)] .7381 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(2000)] .97619 .01472 0 2 Mshowa
p
.001 w
.07143 .01472 m
.07143 .01847 L
s
P
p
.001 w
.11905 .01472 m
.11905 .01847 L
s
P
p
.001 w
.16667 .01472 m
.16667 .01847 L
s
P
p
.001 w
.21429 .01472 m
.21429 .01847 L
s
P
p
.001 w
.30952 .01472 m
.30952 .01847 L
s
P
p
.001 w
.35714 .01472 m
.35714 .01847 L
s
P
p
.001 w
.40476 .01472 m
.40476 .01847 L
s
P
p
.001 w
.45238 .01472 m
.45238 .01847 L
s
P
p
.001 w
.54762 .01472 m
.54762 .01847 L
s
P
p
.001 w
.59524 .01472 m
.59524 .01847 L
s
P
p
.001 w
.64286 .01472 m
.64286 .01847 L
s
P
p
.001 w
.69048 .01472 m
.69048 .01847 L
s
P
p
.001 w
.78571 .01472 m
.78571 .01847 L
s
P
p
.001 w
.83333 .01472 m
.83333 .01847 L
s
P
p
.001 w
.88095 .01472 m
.88095 .01847 L
s
P
p
.001 w
.92857 .01472 m
.92857 .01847 L
s
P
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .16201 m
.03006 .16201 L
s
P
[(500)] .01131 .16201 1 0 Mshowa
p
.002 w
.02381 .30931 m
.03006 .30931 L
s
P
[(1000)] .01131 .30931 1 0 Mshowa
p
.002 w
.02381 .45661 m
.03006 .45661 L
s
P
[(1500)] .01131 .45661 1 0 Mshowa
p
.002 w
.02381 .60391 m
.03006 .60391 L
s
P
[(2000)] .01131 .60391 1 0 Mshowa
p
.001 w
.02381 .04417 m
.02756 .04417 L
s
P
p
.001 w
.02381 .07363 m
.02756 .07363 L
s
P
p
.001 w
.02381 .10309 m
.02756 .10309 L
s
P
p
.001 w
.02381 .13255 m
.02756 .13255 L
s
P
p
.001 w
.02381 .19147 m
.02756 .19147 L
s
P
p
.001 w
.02381 .22093 m
.02756 .22093 L
s
P
p
.001 w
.02381 .25039 m
.02756 .25039 L
s
P
p
.001 w
.02381 .27985 m
.02756 .27985 L
s
P
p
.001 w
.02381 .33877 m
.02756 .33877 L
s
P
p
.001 w
.02381 .36823 m
.02756 .36823 L
s
P
p
.001 w
.02381 .39769 m
.02756 .39769 L
s
P
p
.001 w
.02381 .42715 m
.02756 .42715 L
s
P
p
.001 w
.02381 .48607 m
.02756 .48607 L
s
P
p
.001 w
.02381 .51553 m
.02756 .51553 L
s
P
p
.001 w
.02381 .54499 m
.02756 .54499 L
s
P
p
.001 w
.02381 .57445 m
.02756 .57445 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
.001 w
.02429 .01501 Mdot
.02476 .01501 Mdot
.02524 .0153 Mdot
.02571 .0153 Mdot
.02619 .01589 Mdot
.02667 .0153 Mdot
.02714 .01648 Mdot
.02762 .01589 Mdot
.0281 .01648 Mdot
.02857 .01589 Mdot
.02905 .01766 Mdot
.02952 .01589 Mdot
.03 .01825 Mdot
.03048 .01648 Mdot
.03095 .01707 Mdot
.03143 .01707 Mdot
.0319 .01943 Mdot
.03238 .01648 Mdot
.03286 .02002 Mdot
.03333 .01707 Mdot
.03381 .01825 Mdot
.03429 .01766 Mdot
.03476 .0212 Mdot
.03524 .01707 Mdot
.03571 .02061 Mdot
.03619 .01825 Mdot
.03667 .02002 Mdot
.03714 .01825 Mdot
.03762 .02296 Mdot
.0381 .01707 Mdot
.03857 .02355 Mdot
.03905 .01943 Mdot
.03952 .02061 Mdot
.04 .01943 Mdot
.04048 .02179 Mdot
.04095 .01825 Mdot
.04143 .02532 Mdot
.0419 .02002 Mdot
.04238 .02179 Mdot
.04286 .01943 Mdot
.04333 .0265 Mdot
.04381 .01825 Mdot
.04429 .02709 Mdot
.04476 .02061 Mdot
.04524 .02179 Mdot
.04571 .0212 Mdot
.04619 .02827 Mdot
.04667 .01943 Mdot
.04714 .02709 Mdot
.04762 .02061 Mdot
.0481 .02414 Mdot
.04857 .02179 Mdot
.04905 .03003 Mdot
.04952 .02002 Mdot
.05 .0265 Mdot
.05048 .02179 Mdot
.05095 .02532 Mdot
.05143 .02296 Mdot
.0519 .0318 Mdot
.05238 .01943 Mdot
.05286 .03239 Mdot
.05333 .02355 Mdot
.05381 .02532 Mdot
.05429 .02414 Mdot
.05476 .02886 Mdot
.05524 .02061 Mdot
.05571 .03416 Mdot
.05619 .02414 Mdot
.05667 .02768 Mdot
.05714 .02179 Mdot
.05762 .03534 Mdot
.0581 .02179 Mdot
.05857 .03593 Mdot
.05905 .02532 Mdot
.05952 .0265 Mdot
.06 .02532 Mdot
.06048 .03239 Mdot
.06095 .02179 Mdot
.06143 .03769 Mdot
.0619 .02414 Mdot
.06238 .03062 Mdot
.06286 .0265 Mdot
.06333 .03887 Mdot
.06381 .02179 Mdot
.06429 .03357 Mdot
.06476 .02709 Mdot
.06524 .03121 Mdot
.06571 .0265 Mdot
.06619 .04064 Mdot
.06667 .02179 Mdot
.06714 .03593 Mdot
.06762 .02768 Mdot
.0681 .03239 Mdot
.06857 .02827 Mdot
.06905 .03593 Mdot
.06952 .02414 Mdot
.07 .043 Mdot
.07048 .02709 Mdot
.07095 .03239 Mdot
.07143 .0265 Mdot
.0719 .04417 Mdot
.07238 .02414 Mdot
.07286 .04476 Mdot
.07333 .02886 Mdot
.07381 .02886 Mdot
.07429 .03003 Mdot
.07476 .04594 Mdot
.07524 .02532 Mdot
.07571 .04653 Mdot
.07619 .0265 Mdot
.07667 .03593 Mdot
.07714 .02886 Mdot
.07762 .04771 Mdot
.0781 .02532 Mdot
.07857 .04064 Mdot
.07905 .03121 Mdot
.07952 .03593 Mdot
.08 .0318 Mdot
.08048 .043 Mdot
.08095 .02414 Mdot
.08143 .04712 Mdot
.0819 .03239 Mdot
.08238 .03828 Mdot
.08286 .03239 Mdot
.08333 .04417 Mdot
.08381 .02532 Mdot
.08429 .05183 Mdot
.08476 .03357 Mdot
.08524 .03946 Mdot
.08571 .02886 Mdot
.08619 .05301 Mdot
.08667 .0265 Mdot
.08714 .04653 Mdot
.08762 .03416 Mdot
.0881 .03593 Mdot
.08857 .03357 Mdot
.08905 .05478 Mdot
.08952 .02768 Mdot
.09 .05537 Mdot
.09048 .02886 Mdot
.09095 .04182 Mdot
.09143 .03534 Mdot
.0919 .05007 Mdot
.09238 .02886 Mdot
.09286 .04771 Mdot
.09333 .03593 Mdot
.09381 .03946 Mdot
.09429 .03593 Mdot
.09476 .05832 Mdot
.09524 .0265 Mdot
.09571 .0589 Mdot
.09619 .03593 Mdot
.09667 .043 Mdot
.09714 .03239 Mdot
.09762 .05007 Mdot
.0981 .02886 Mdot
.09857 .06067 Mdot
.09905 .03769 Mdot
.09952 .04535 Mdot
.1 .03357 Mdot
.10048 .0536 Mdot
.10095 .03062 Mdot
.10143 .06244 Mdot
.1019 .03828 Mdot
.10238 .03828 Mdot
.10286 .03887 Mdot
.10333 .06362 Mdot
.10381 .02886 Mdot
.10429 .06067 Mdot
.10476 .03357 Mdot
.10524 .04653 Mdot
.10571 .03946 Mdot
.10619 .06539 Mdot
.10667 .03121 Mdot
.10714 .05007 Mdot
.10762 .03828 Mdot
.1081 .04889 Mdot
.10857 .04064 Mdot
.10905 .06715 Mdot
.10952 .02886 Mdot
.11 .06774 Mdot
.11048 .03593 Mdot
.11095 .05007 Mdot
.11143 .04064 Mdot
.1119 .05714 Mdot
.11238 .03239 Mdot
.11286 .06185 Mdot
.11333 .04182 Mdot
.11381 .04653 Mdot
.11429 .03593 Mdot
.11476 .07069 Mdot
.11524 .03357 Mdot
.11571 .07128 Mdot
.11619 .043 Mdot
.11667 .043 Mdot
.11714 .03946 Mdot
.11762 .07246 Mdot
.1181 .03239 Mdot
.11857 .07305 Mdot
.11905 .03828 Mdot
.11952 .0536 Mdot
.12 .04417 Mdot
.12048 .06421 Mdot
.12095 .03357 Mdot
.12143 .06185 Mdot
.1219 .04476 Mdot
.12238 .0536 Mdot
.12286 .043 Mdot
.12333 .06774 Mdot
.12381 .02886 Mdot
.12429 .07658 Mdot
.12476 .04535 Mdot
.12524 .05596 Mdot
.12571 .04594 Mdot
.12619 .06421 Mdot
.12667 .03593 Mdot
.12714 .06774 Mdot
.12762 .04653 Mdot
.1281 .05714 Mdot
.12857 .03828 Mdot
.12905 .07128 Mdot
.12952 .03593 Mdot
.13 .08012 Mdot
.13048 .043 Mdot
.13095 .05007 Mdot
.13143 .04771 Mdot
.1319 .08129 Mdot
.13238 .03593 Mdot
.13286 .08188 Mdot
.13333 .04064 Mdot
.13381 .05007 Mdot
.13429 .04771 Mdot
.13476 .08306 Mdot
.13524 .03593 Mdot
.13571 .06892 Mdot
.13619 .04889 Mdot
.13667 .06067 Mdot
.13714 .043 Mdot
.13762 .08483 Mdot
.1381 .03357 Mdot
.13857 .08542 Mdot
.13905 .04712 Mdot
.13952 .06244 Mdot
.14 .05007 Mdot
.14048 .06421 Mdot
.14095 .03828 Mdot
.14143 .07835 Mdot
.1419 .05007 Mdot
.14238 .06303 Mdot
.14286 .04417 Mdot
.14333 .08836 Mdot
.14381 .03593 Mdot
.14429 .07953 Mdot
.14476 .05183 Mdot
.14524 .05242 Mdot
.14571 .05242 Mdot
.14619 .09013 Mdot
.14667 .03946 Mdot
.14714 .07835 Mdot
.14762 .043 Mdot
.1481 .06421 Mdot
.14857 .05301 Mdot
.14905 .0919 Mdot
.14952 .03828 Mdot
.15 .07599 Mdot
.15048 .04653 Mdot
.15095 .06656 Mdot
.15143 .0536 Mdot
.1519 .09367 Mdot
.15238 .03593 Mdot
.15286 .09426 Mdot
.15333 .05242 Mdot
.15381 .05714 Mdot
.15429 .05478 Mdot
.15476 .07363 Mdot
.15524 .04064 Mdot
.15571 .09602 Mdot
.15619 .05537 Mdot
.15667 .06774 Mdot
.15714 .043 Mdot
.15762 .0972 Mdot
.1581 .04182 Mdot
.15857 .09779 Mdot
.15905 .05596 Mdot
.15952 .05714 Mdot
.16 .05007 Mdot
.16048 .08542 Mdot
.16095 .043 Mdot
.16143 .09485 Mdot
.1619 .04771 Mdot
.16238 .07128 Mdot
.16286 .05714 Mdot
.16333 .10074 Mdot
.16381 .03946 Mdot
.16429 .08306 Mdot
.16476 .05714 Mdot
.16524 .06774 Mdot
.16571 .05832 Mdot
.16619 .09249 Mdot
.16667 .03828 Mdot
.16714 .08895 Mdot
.16762 .0589 Mdot
.1681 .07363 Mdot
.16857 .05714 Mdot
.16905 .08542 Mdot
.16952 .043 Mdot
.17 .10486 Mdot
.17048 .05007 Mdot
.17095 .07481 Mdot
.17143 .05007 Mdot
.1719 .10604 Mdot
.17238 .043 Mdot
.17286 .10663 Mdot
.17333 .06067 Mdot
.17381 .05714 Mdot
.17429 .06067 Mdot
.17476 .10781 Mdot
.17524 .04535 Mdot
.17571 .0972 Mdot
.17619 .05242 Mdot
.17667 .07717 Mdot
.17714 .0536 Mdot
.17762 .09956 Mdot
.1781 .04653 Mdot
.17857 .08542 Mdot
.17905 .06244 Mdot
.17952 .07835 Mdot
.18 .06185 Mdot
.18048 .09602 Mdot
.18095 .03828 Mdot
.18143 .11193 Mdot
.1819 .06303 Mdot
.18238 .07835 Mdot
.18286 .06362 Mdot
.18333 .09249 Mdot
.18381 .043 Mdot
.18429 .1137 Mdot
.18476 .06067 Mdot
.18524 .0807 Mdot
.18571 .05242 Mdot
.18619 .10309 Mdot
.18667 .04653 Mdot
.18714 .10133 Mdot
.18762 .06421 Mdot
.1881 .06656 Mdot
.18857 .06539 Mdot
.18905 .11665 Mdot
.18952 .04771 Mdot
.19 .11723 Mdot
.19048 .05007 Mdot
.19095 .07835 Mdot
.19143 .06185 Mdot
.1919 .11841 Mdot
.19238 .04889 Mdot
.19286 .0972 Mdot
.19333 .06656 Mdot
.19381 .07128 Mdot
.19429 .06715 Mdot
.19476 .12018 Mdot
.19524 .043 Mdot
.19571 .11547 Mdot
.19619 .06774 Mdot
.19667 .07953 Mdot
.19714 .05714 Mdot
.19762 .09956 Mdot
.1981 .05007 Mdot
.19857 .12254 Mdot
.19905 .06656 Mdot
.19952 .08542 Mdot
.2 .05714 Mdot
.20048 .10663 Mdot
.20095 .05007 Mdot
.20143 .1243 Mdot
.2019 .06185 Mdot
.20238 .07363 Mdot
.20286 .06892 Mdot
.20333 .1137 Mdot
.20381 .04653 Mdot
.20429 .12607 Mdot
.20476 .05714 Mdot
.20524 .08895 Mdot
.20571 .07069 Mdot
.20619 .12725 Mdot
.20667 .05242 Mdot
.20714 .08542 Mdot
.20762 .07128 Mdot
.2081 .08895 Mdot
.20857 .07128 Mdot
.20905 .12902 Mdot
.20952 .043 Mdot
.21 .11841 Mdot
.21048 .06421 Mdot
.21095 .09131 Mdot
.21143 .07246 Mdot
.2119 .10663 Mdot
.21238 .05007 Mdot
.21286 .13138 Mdot
.21333 .07305 Mdot
.21381 .07835 Mdot
.21429 .06185 Mdot
.21476 .13255 Mdot
.21524 .0536 Mdot
.21571 .12077 Mdot
.21619 .07363 Mdot
.21667 .07835 Mdot
.21714 .06421 Mdot
.21762 .12077 Mdot
.2181 .05242 Mdot
.21857 .13491 Mdot
.21905 .06185 Mdot
.21952 .09485 Mdot
.22 .07481 Mdot
.22048 .11723 Mdot
.22095 .0536 Mdot
.22143 .11134 Mdot
.2219 .07128 Mdot
.22238 .09602 Mdot
.22286 .06774 Mdot
.22333 .13786 Mdot
.22381 .043 Mdot
.22429 .13845 Mdot
.22476 .07658 Mdot
.22524 .09602 Mdot
.22571 .07599 Mdot
.22619 .10899 Mdot
.22667 .05596 Mdot
.22714 .12077 Mdot
.22762 .07717 Mdot
.2281 .08542 Mdot
.22857 .06421 Mdot
.22905 .14139 Mdot
.22952 .05714 Mdot
.23 .14198 Mdot
.23048 .06774 Mdot
.23095 .0807 Mdot
.23143 .07835 Mdot
.2319 .13138 Mdot
.23238 .05714 Mdot
.23286 .14375 Mdot
.23333 .06185 Mdot
.23381 .08895 Mdot
.23429 .07128 Mdot
.23476 .14493 Mdot
.23524 .05714 Mdot
.23571 .11841 Mdot
.23619 .08012 Mdot
.23667 .10192 Mdot
.23714 .07128 Mdot
.23762 .14669 Mdot
.2381 .05007 Mdot
.23857 .13255 Mdot
.23905 .0807 Mdot
.23952 .10309 Mdot
.24 .08129 Mdot
.24048 .09956 Mdot
.24095 .05714 Mdot
.24143 .14905 Mdot
.2419 .08188 Mdot
.24238 .09956 Mdot
.24286 .06656 Mdot
.24333 .15023 Mdot
.24381 .05007 Mdot
.24429 .15082 Mdot
.24476 .0807 Mdot
.24524 .08542 Mdot
.24571 .08306 Mdot
.24619 .152 Mdot
.24667 .05714 Mdot
.24714 .13138 Mdot
.24762 .06892 Mdot
.2481 .10663 Mdot
.24857 .08306 Mdot
.24905 .13845 Mdot
.24952 .06067 Mdot
.25 .12077 Mdot
.25048 .07128 Mdot
.25095 .10663 Mdot
.25143 .08483 Mdot
.2519 .15553 Mdot
.25238 .05242 Mdot
.25286 .14198 Mdot
.25333 .08542 Mdot
.25381 .09249 Mdot
.25429 .07953 Mdot
.25476 .12784 Mdot
.25524 .06244 Mdot
.25571 .15789 Mdot
.25619 .08542 Mdot
.25667 .11016 Mdot
.25714 .06421 Mdot
.25762 .15907 Mdot
.2581 .06185 Mdot
.25857 .14669 Mdot
.25905 .07835 Mdot
.25952 .08542 Mdot
.26 .08542 Mdot
.26048 .13845 Mdot
.26095 .06303 Mdot
.26143 .16142 Mdot
.2619 .07363 Mdot
.26238 .11252 Mdot
.26286 .08836 Mdot
.26333 .1626 Mdot
.26381 .05714 Mdot
.26429 .13255 Mdot
.26476 .07953 Mdot
.26524 .10663 Mdot
.26571 .08895 Mdot
.26619 .16437 Mdot
.26667 .05242 Mdot
.26714 .14198 Mdot
.26762 .09013 Mdot
.2681 .11016 Mdot
.26857 .09013 Mdot
.26905 .13491 Mdot
.26952 .06421 Mdot
.27 .15023 Mdot
.27048 .07835 Mdot
.27095 .11606 Mdot
.27143 .07128 Mdot
.2719 .16791 Mdot
.27238 .06421 Mdot
.27286 .16849 Mdot
.27333 .09131 Mdot
.27381 .08542 Mdot
.27429 .0919 Mdot
.27476 .15612 Mdot
.27524 .06185 Mdot
.27571 .16378 Mdot
.27619 .07599 Mdot
.27667 .11723 Mdot
.27714 .07835 Mdot
.27762 .15612 Mdot
.2781 .06656 Mdot
.27857 .13962 Mdot
.27905 .09249 Mdot
.27952 .11959 Mdot
.28 .09367 Mdot
.28048 .13845 Mdot
.28095 .05714 Mdot
.28143 .1738 Mdot
.2819 .09426 Mdot
.28238 .12077 Mdot
.28286 .09013 Mdot
.28333 .14198 Mdot
.28381 .05714 Mdot
.28429 .17556 Mdot
.28476 .09485 Mdot
.28524 .12077 Mdot
.28571 .07363 Mdot
.28619 .16319 Mdot
.28667 .06656 Mdot
.28714 .15259 Mdot
.28762 .09602 Mdot
.2881 .09956 Mdot
.28857 .09602 Mdot
.28905 .17851 Mdot
.28952 .06774 Mdot
.29 .16319 Mdot
.29048 .07128 Mdot
.29095 .10899 Mdot
.29143 .0972 Mdot
.2919 .18028 Mdot
.29238 .06892 Mdot
.29286 .14669 Mdot
.29333 .09779 Mdot
.29381 .11016 Mdot
.29429 .0972 Mdot
.29476 .18205 Mdot
.29524 .05714 Mdot
.29571 .18264 Mdot
.29619 .08542 Mdot
.29667 .12666 Mdot
.29714 .08542 Mdot
.29762 .14434 Mdot
.2981 .07128 Mdot
.29857 .1844 Mdot
.29905 .09485 Mdot
.29952 .12784 Mdot
.3 .0807 Mdot
.30048 .15966 Mdot
.30095 .07128 Mdot
.30143 .16791 Mdot
.3019 .09956 Mdot
.30238 .09956 Mdot
.30286 .10074 Mdot
.30333 .18735 Mdot
.30381 .06421 Mdot
.30429 .1738 Mdot
.30476 .08306 Mdot
.30524 .1302 Mdot
.30571 .09956 Mdot
.30619 .18912 Mdot
.30667 .06774 Mdot
.30714 .12784 Mdot
.30762 .10192 Mdot
.3081 .13138 Mdot
.30857 .09249 Mdot
.30905 .19088 Mdot
.30952 .06185 Mdot
.31 .19147 Mdot
.31048 .08895 Mdot
.31095 .13138 Mdot
.31143 .10309 Mdot
.3119 .14434 Mdot
.31238 .07363 Mdot
.31286 .19324 Mdot
.31333 .09956 Mdot
.31381 .1137 Mdot
.31429 .08542 Mdot
.31476 .17733 Mdot
.31524 .07128 Mdot
.31571 .19501 Mdot
.31619 .10486 Mdot
.31667 .10899 Mdot
.31714 .08542 Mdot
.31762 .19619 Mdot
.3181 .07481 Mdot
.31857 .19678 Mdot
.31905 .08542 Mdot
.31952 .13138 Mdot
.32 .10604 Mdot
.32048 .17026 Mdot
.32095 .07128 Mdot
.32143 .16201 Mdot
.3219 .10663 Mdot
.32238 .12077 Mdot
.32286 .10663 Mdot
.32333 .1844 Mdot
.32381 .05714 Mdot
.32429 .20031 Mdot
.32476 .10663 Mdot
.32524 .13845 Mdot
.32571 .10781 Mdot
.32619 .16319 Mdot
.32667 .07599 Mdot
.32714 .16319 Mdot
.32762 .0972 Mdot
.3281 .13845 Mdot
.32857 .09013 Mdot
.32905 .20326 Mdot
.32952 .07717 Mdot
.33 .20385 Mdot
.33048 .09249 Mdot
.33095 .1137 Mdot
.33143 .09956 Mdot
.3319 .20502 Mdot
.33238 .07835 Mdot
.33286 .18558 Mdot
.33333 .08542 Mdot
.33381 .12077 Mdot
.33429 .11016 Mdot
.33476 .20679 Mdot
.33524 .07835 Mdot
.33571 .16791 Mdot
.33619 .10899 Mdot
.33667 .14198 Mdot
.33714 .09602 Mdot
.33762 .20856 Mdot
.3381 .06185 Mdot
.33857 .20915 Mdot
.33905 .11193 Mdot
.33952 .12784 Mdot
.34 .11134 Mdot
.34048 .14198 Mdot
.34095 .07835 Mdot
.34143 .19619 Mdot
.3419 .11252 Mdot
.34238 .14552 Mdot
.34286 .09249 Mdot
.34333 .19147 Mdot
.34381 .07128 Mdot
.34429 .21268 Mdot
.34476 .1137 Mdot
.34524 .12077 Mdot
.34571 .10663 Mdot
.34619 .21386 Mdot
.34667 .0807 Mdot
.34714 .1844 Mdot
.34762 .09013 Mdot
.3481 .14787 Mdot
.34857 .10309 Mdot
.34905 .21563 Mdot
.34952 .07835 Mdot
.35 .17498 Mdot
.35048 .10133 Mdot
.35095 .14905 Mdot
.35143 .1137 Mdot
.3519 .19854 Mdot
.35238 .06656 Mdot
.35286 .21799 Mdot
.35333 .11606 Mdot
.35381 .12077 Mdot
.35429 .11665 Mdot
.35476 .17733 Mdot
.35524 .0807 Mdot
.35571 .20326 Mdot
.35619 .11723 Mdot
.35667 .15141 Mdot
.35714 .08542 Mdot
.35762 .22093 Mdot
.3581 .07835 Mdot
.35857 .20561 Mdot
.35905 .10899 Mdot
.35952 .12313 Mdot
.36 .11841 Mdot
.36048 .19147 Mdot
.36095 .08306 Mdot
.36143 .22329 Mdot
.3619 .0972 Mdot
.36238 .15259 Mdot
.36286 .11841 Mdot
.36333 .20915 Mdot
.36381 .07128 Mdot
.36429 .15612 Mdot
.36476 .11959 Mdot
.36524 .15494 Mdot
.36571 .12018 Mdot
.36619 .22624 Mdot
.36667 .07128 Mdot
.36714 .19501 Mdot
.36762 .11547 Mdot
.3681 .15612 Mdot
.36857 .12077 Mdot
.36905 .17969 Mdot
.36952 .07953 Mdot
.37 .22859 Mdot
.37048 .09956 Mdot
.37095 .15789 Mdot
.37143 .09956 Mdot
.3719 .21268 Mdot
.37238 .08542 Mdot
.37286 .23036 Mdot
.37333 .12254 Mdot
.37381 .1137 Mdot
.37429 .11841 Mdot
.37476 .20915 Mdot
.37524 .08542 Mdot
.37571 .23213 Mdot
.37619 .09956 Mdot
.37667 .14198 Mdot
.37714 .10663 Mdot
.37762 .23331 Mdot
.3781 .08542 Mdot
.37857 .18912 Mdot
.37905 .1243 Mdot
.37952 .15966 Mdot
.38 .10899 Mdot
.38048 .20208 Mdot
.38095 .07363 Mdot
.38143 .23566 Mdot
.3819 .12313 Mdot
.38238 .16201 Mdot
.38286 .1137 Mdot
.38333 .19147 Mdot
.38381 .07835 Mdot
.38429 .23743 Mdot
.38476 .12607 Mdot
.38524 .14434 Mdot
.38571 .09956 Mdot
.38619 .23861 Mdot
.38667 .08895 Mdot
.38714 .20561 Mdot
.38762 .12666 Mdot
.3881 .12784 Mdot
.38857 .12725 Mdot
.38905 .21975 Mdot
.38952 .09013 Mdot
.39 .24097 Mdot
.39048 .08542 Mdot
.39095 .16555 Mdot
.39143 .12784 Mdot
.3919 .24214 Mdot
.39238 .08895 Mdot
.39286 .19147 Mdot
.39333 .12784 Mdot
.39381 .14198 Mdot
.39429 .12902 Mdot
.39476 .22682 Mdot
.39524 .07128 Mdot
.39571 .22093 Mdot
.39619 .11841 Mdot
.39667 .16319 Mdot
.39714 .1137 Mdot
.39762 .19854 Mdot
.3981 .09131 Mdot
.39857 .24627 Mdot
.39905 .1302 Mdot
.39952 .16908 Mdot
.4 .10663 Mdot
.40048 .21268 Mdot
.40095 .08542 Mdot
.40143 .22682 Mdot
.4019 .13138 Mdot
.40238 .13727 Mdot
.40286 .13138 Mdot
.40333 .24921 Mdot
.40381 .07835 Mdot
.40429 .23154 Mdot
.40476 .10899 Mdot
.40524 .17026 Mdot
.40571 .13255 Mdot
.40619 .22682 Mdot
.40667 .09249 Mdot
.40714 .17026 Mdot
.40762 .12077 Mdot
.4081 .17262 Mdot
.40857 .13255 Mdot
.40905 .25275 Mdot
.40952 .07835 Mdot
.41 .25334 Mdot
.41048 .1137 Mdot
.41095 .1738 Mdot
.41143 .12077 Mdot
.4119 .20561 Mdot
.41238 .09013 Mdot
.41286 .23743 Mdot
.41333 .13491 Mdot
.41381 .14198 Mdot
.41429 .10899 Mdot
.41476 .25628 Mdot
.41524 .09485 Mdot
.41571 .25687 Mdot
.41619 .13491 Mdot
.41667 .13255 Mdot
.41714 .11723 Mdot
.41762 .25805 Mdot
.4181 .09249 Mdot
.41857 .25864 Mdot
.41905 .11134 Mdot
.41952 .17733 Mdot
.42 .12784 Mdot
.42048 .21268 Mdot
.42095 .09602 Mdot
.42143 .21033 Mdot
.4219 .12077 Mdot
.42238 .1738 Mdot
.42286 .13786 Mdot
.42333 .26159 Mdot
.42381 .07128 Mdot
.42429 .25393 Mdot
.42476 .13845 Mdot
.42524 .17969 Mdot
.42571 .13845 Mdot
.42619 .19854 Mdot
.42667 .09602 Mdot
.42714 .20915 Mdot
.42762 .13727 Mdot
.4281 .18087 Mdot
.42857 .10899 Mdot
.42905 .24804 Mdot
.42952 .0972 Mdot
.43 .26571 Mdot
.43048 .12077 Mdot
.43095 .14198 Mdot
.43143 .13962 Mdot
.4319 .26689 Mdot
.43238 .08542 Mdot
.43286 .26748 Mdot
.43333 .1137 Mdot
.43381 .15612 Mdot
.43429 .14139 Mdot
.43476 .26866 Mdot
.43524 .09956 Mdot
.43571 .2174 Mdot
.43619 .14198 Mdot
.43667 .17498 Mdot
.43714 .12077 Mdot
.43762 .2445 Mdot
.4381 .0807 Mdot
.43857 .24804 Mdot
.43905 .14198 Mdot
.43952 .1844 Mdot
.44 .13138 Mdot
.44048 .19147 Mdot
.44095 .09956 Mdot
.44143 .27278 Mdot
.4419 .14375 Mdot
.44238 .18676 Mdot
.44286 .10899 Mdot
.44333 .27396 Mdot
.44381 .08895 Mdot
.44429 .27455 Mdot
.44476 .12784 Mdot
.44524 .15141 Mdot
.44571 .14493 Mdot
.44619 .27573 Mdot
.44667 .09956 Mdot
.44714 .23743 Mdot
.44762 .11841 Mdot
.4481 .1738 Mdot
.44857 .14552 Mdot
.44905 .25864 Mdot
.44952 .10192 Mdot
.45 .22447 Mdot
.45048 .12784 Mdot
.45095 .17026 Mdot
.45143 .14669 Mdot
.4519 .26218 Mdot
.45238 .08542 Mdot
.45286 .25982 Mdot
.45333 .13255 Mdot
.45381 .16319 Mdot
.45429 .14669 Mdot
.45476 .22682 Mdot
.45524 .10309 Mdot
.45571 .28162 Mdot
.45619 .14787 Mdot
.45667 .19147 Mdot
.45714 .09956 Mdot
.45762 .2828 Mdot
.4581 .09956 Mdot
.45857 .25628 Mdot
.45905 .14905 Mdot
.45952 .15612 Mdot
.46 .14905 Mdot
.46048 .2445 Mdot
.46095 .09956 Mdot
.46143 .28515 Mdot
.4619 .11841 Mdot
.46238 .19501 Mdot
.46286 .15023 Mdot
.46333 .26218 Mdot
.46381 .08542 Mdot
.46429 .22682 Mdot
.46476 .15082 Mdot
.46524 .19501 Mdot
.46571 .14669 Mdot
.46619 .2881 Mdot
.46667 .08542 Mdot
.46714 .23743 Mdot
.46762 .15141 Mdot
.4681 .19736 Mdot
.46857 .152 Mdot
.46905 .20326 Mdot
.46952 .09956 Mdot
.47 .29046 Mdot
.47048 .13138 Mdot
.47095 .19854 Mdot
.47143 .12313 Mdot
.4719 .29164 Mdot
.47238 .10663 Mdot
.47286 .27396 Mdot
.47333 .15141 Mdot
.47381 .14198 Mdot
.47429 .13845 Mdot
.47476 .2934 Mdot
.47524 .10663 Mdot
.47571 .26925 Mdot
.47619 .12077 Mdot
.47667 .2009 Mdot
.47714 .12784 Mdot
.47762 .29517 Mdot
.4781 .10663 Mdot
.47857 .23861 Mdot
.47905 .15494 Mdot
.47952 .17969 Mdot
.48 .15553 Mdot
.48048 .25511 Mdot
.48095 .09013 Mdot
.48143 .28869 Mdot
.4819 .14198 Mdot
.48238 .20208 Mdot
.48286 .15612 Mdot
.48333 .24097 Mdot
.48381 .09249 Mdot
.48429 .2993 Mdot
.48476 .14434 Mdot
.48524 .1844 Mdot
.48571 .12784 Mdot
.48619 .30047 Mdot
.48667 .11016 Mdot
.48714 .25864 Mdot
.48762 .15789 Mdot
.4881 .15612 Mdot
.48857 .15612 Mdot
.48905 .30224 Mdot
.48952 .11016 Mdot
.49 .27396 Mdot
.49048 .1137 Mdot
.49095 .20561 Mdot
.49143 .15907 Mdot
.4919 .30401 Mdot
.49238 .10899 Mdot
.49286 .24568 Mdot
.49333 .14669 Mdot
.49381 .17733 Mdot
.49429 .14198 Mdot
.49476 .28692 Mdot
.49524 .08542 Mdot
.49571 .30637 Mdot
.49619 .15612 Mdot
.49667 .20915 Mdot
.49714 .13845 Mdot
.49762 .24804 Mdot
.4981 .11134 Mdot
.49857 .30813 Mdot
.49905 .16142 Mdot
.49952 .20561 Mdot
.5 .13255 Mdot
.50048 .22682 Mdot
.50095 .11252 Mdot
.50143 .2881 Mdot
.5019 .16201 Mdot
.50238 .17026 Mdot
.50286 .1626 Mdot
.50333 .29046 Mdot
.50381 .09956 Mdot
.50429 .31167 Mdot
.50476 .13255 Mdot
.50524 .21268 Mdot
.50571 .14434 Mdot
.50619 .31285 Mdot
.50667 .10663 Mdot
.50714 .21268 Mdot
.50762 .16319 Mdot
.5081 .21268 Mdot
.50857 .16437 Mdot
.50905 .31461 Mdot
.50952 .09013 Mdot
.51 .3152 Mdot
.51048 .14198 Mdot
.51095 .19147 Mdot
.51143 .16555 Mdot
.5119 .25039 Mdot
.51238 .11016 Mdot
.51286 .29046 Mdot
.51333 .16555 Mdot
.51381 .18794 Mdot
.51429 .13491 Mdot
.51476 .31815 Mdot
.51524 .1137 Mdot
.51571 .31874 Mdot
.51619 .15023 Mdot
.51667 .17026 Mdot
.51714 .14198 Mdot
.51762 .29753 Mdot
.5181 .11606 Mdot
.51857 .32051 Mdot
.51905 .12784 Mdot
.51952 .21858 Mdot
.52 .16791 Mdot
.52048 .27632 Mdot
.52095 .1137 Mdot
.52143 .22682 Mdot
.5219 .16849 Mdot
.52238 .21975 Mdot
.52286 .16791 Mdot
.52333 .32345 Mdot
.52381 .08542 Mdot
.52429 .32404 Mdot
.52476 .16908 Mdot
.52524 .20561 Mdot
.52571 .15612 Mdot
.52619 .26218 Mdot
.52667 .10899 Mdot
.52714 .27985 Mdot
.52762 .16378 Mdot
.5281 .22211 Mdot
.52857 .13727 Mdot
.52905 .32699 Mdot
.52952 .11723 Mdot
.53 .32758 Mdot
.53048 .14198 Mdot
.53095 .17969 Mdot
.53143 .15612 Mdot
.5319 .29753 Mdot
.53238 .11841 Mdot
.53286 .32934 Mdot
.53333 .13962 Mdot
.53381 .1844 Mdot
.53429 .17026 Mdot
.53476 .31167 Mdot
.53524 .11959 Mdot
.53571 .26218 Mdot
.53619 .17262 Mdot
.53667 .22565 Mdot
.53714 .13845 Mdot
.53762 .3046 Mdot
.5381 .09956 Mdot
.53857 .31285 Mdot
.53905 .1738 Mdot
.53952 .21622 Mdot
.54 .1738 Mdot
.54048 .22682 Mdot
.54095 .12077 Mdot
.54143 .33465 Mdot
.5419 .16555 Mdot
.54238 .20915 Mdot
.54286 .14198 Mdot
.54333 .33583 Mdot
.54381 .09956 Mdot
.54429 .33641 Mdot
.54476 .17556 Mdot
.54524 .1844 Mdot
.54571 .17498 Mdot
.54619 .33759 Mdot
.54667 .12077 Mdot
.54714 .29046 Mdot
.54762 .13255 Mdot
.5481 .23036 Mdot
.54857 .16319 Mdot
.54905 .33936 Mdot
.54952 .11841 Mdot
.55 .24097 Mdot
.55048 .15259 Mdot
.55095 .22682 Mdot
.55143 .17733 Mdot
.5519 .34113 Mdot
.55238 .09956 Mdot
.55286 .30931 Mdot
.55333 .17733 Mdot
.55381 .19854 Mdot
.55429 .17851 Mdot
.55476 .27632 Mdot
.55524 .12077 Mdot
.55571 .34348 Mdot
.55619 .16319 Mdot
.55667 .23389 Mdot
.55714 .12784 Mdot
.55762 .32227 Mdot
.5581 .10899 Mdot
.55857 .34525 Mdot
.55905 .17969 Mdot
.55952 .19147 Mdot
.56 .18028 Mdot
.56048 .28692 Mdot
.56095 .12313 Mdot
.56143 .34702 Mdot
.5619 .14669 Mdot
.56238 .21268 Mdot
.56286 .18087 Mdot
.56333 .3152 Mdot
.56381 .11016 Mdot
.56429 .28103 Mdot
.56476 .17969 Mdot
.56524 .23743 Mdot
.56571 .18205 Mdot
.56619 .32581 Mdot
.56667 .09956 Mdot
.56714 .30106 Mdot
.56762 .18264 Mdot
.5681 .23743 Mdot
.56857 .15612 Mdot
.56905 .28339 Mdot
.56952 .12666 Mdot
.57 .33288 Mdot
.57048 .15612 Mdot
.57095 .23979 Mdot
.57143 .14434 Mdot
.5719 .3535 Mdot
.57238 .12784 Mdot
.57286 .35409 Mdot
.57333 .1844 Mdot
.57381 .15612 Mdot
.57429 .17498 Mdot
.57476 .32581 Mdot
.57524 .12784 Mdot
.57571 .33288 Mdot
.57619 .14669 Mdot
.57667 .23743 Mdot
.57714 .15966 Mdot
.57762 .35704 Mdot
.5781 .12784 Mdot
.57857 .2881 Mdot
.57905 .16791 Mdot
.57952 .24332 Mdot
.58 .1844 Mdot
.58048 .30813 Mdot
.58095 .09956 Mdot
.58143 .35939 Mdot
.5819 .18676 Mdot
.58238 .22211 Mdot
.58286 .18735 Mdot
.58333 .28574 Mdot
.58381 .1137 Mdot
.58429 .32699 Mdot
.58476 .1738 Mdot
.58524 .2445 Mdot
.58571 .15141 Mdot
.58619 .36234 Mdot
.58667 .1302 Mdot
.58714 .29046 Mdot
.58762 .1844 Mdot
.5881 .19854 Mdot
.58857 .18912 Mdot
.58905 .36411 Mdot
.58952 .12077 Mdot
.59 .34466 Mdot
.59048 .12784 Mdot
.59095 .24804 Mdot
.59143 .18912 Mdot
.5919 .36587 Mdot
.59238 .13138 Mdot
.59286 .29517 Mdot
.59333 .17026 Mdot
.59381 .20561 Mdot
.59429 .19088 Mdot
.59476 .33288 Mdot
.59524 .10899 Mdot
.59571 .36823 Mdot
.59619 .19147 Mdot
.59667 .25039 Mdot
.59714 .16319 Mdot
.59762 .29753 Mdot
.5981 .13138 Mdot
.59857 .34466 Mdot
.59905 .19147 Mdot
.59952 .22682 Mdot
.6 .14434 Mdot
.60048 .31874 Mdot
.60095 .13255 Mdot
.60143 .37177 Mdot
.6019 .19324 Mdot
.60238 .20561 Mdot
.60286 .1844 Mdot
.60333 .37294 Mdot
.60381 .1137 Mdot
.60429 .35173 Mdot
.60476 .15612 Mdot
.60524 .22682 Mdot
.60571 .17733 Mdot
.60619 .37471 Mdot
.60667 .12784 Mdot
.60714 .26218 Mdot
.60762 .19501 Mdot
.6081 .25511 Mdot
.60857 .19501 Mdot
.60905 .37648 Mdot
.60952 .10899 Mdot
.61 .37707 Mdot
.61048 .15612 Mdot
.61095 .25511 Mdot
.61143 .19619 Mdot
.6119 .26925 Mdot
.61238 .13491 Mdot
.61286 .37884 Mdot
.61333 .19678 Mdot
.61381 .21975 Mdot
.61429 .15612 Mdot
.61476 .35409 Mdot
.61524 .13138 Mdot
.61571 .34466 Mdot
.61619 .19736 Mdot
.61667 .20797 Mdot
.61714 .17026 Mdot
.61762 .36116 Mdot
.6181 .12784 Mdot
.61857 .38237 Mdot
.61905 .16201 Mdot
.61952 .25864 Mdot
.62 .19854 Mdot
.62048 .32934 Mdot
.62095 .12077 Mdot
.62143 .30931 Mdot
.6219 .19854 Mdot
.62238 .261 Mdot
.62286 .1844 Mdot
.62333 .38532 Mdot
.62381 .09956 Mdot
.62429 .35409 Mdot
.62476 .20031 Mdot
.62524 .26218 Mdot
.62571 .19854 Mdot
.62619 .27396 Mdot
.62667 .13845 Mdot
.62714 .33288 Mdot
.62762 .2009 Mdot
.6281 .25864 Mdot
.62857 .16319 Mdot
.62905 .36823 Mdot
.62952 .13727 Mdot
.63 .3647 Mdot
.63048 .16319 Mdot
.63095 .20326 Mdot
.63143 .17969 Mdot
.6319 .39062 Mdot
.63238 .13845 Mdot
.63286 .39121 Mdot
.63333 .16555 Mdot
.63381 .22682 Mdot
.63429 .20326 Mdot
.63476 .39239 Mdot
.63524 .13962 Mdot
.63571 .31638 Mdot
.63619 .20385 Mdot
.63667 .22682 Mdot
.63714 .17026 Mdot
.63762 .39416 Mdot
.6381 .1137 Mdot
.63857 .39474 Mdot
.63905 .1844 Mdot
.63952 .26807 Mdot
.64 .20502 Mdot
.64048 .26925 Mdot
.64095 .14198 Mdot
.64143 .39651 Mdot
.6419 .18558 Mdot
.64238 .26925 Mdot
.64286 .15612 Mdot
.64333 .39769 Mdot
.64381 .12077 Mdot
.64429 .39828 Mdot
.64476 .20561 Mdot
.64524 .21268 Mdot
.64571 .20679 Mdot
.64619 .39946 Mdot
.64667 .14198 Mdot
.64714 .29753 Mdot
.64762 .16791 Mdot
.6481 .24804 Mdot
.64857 .20326 Mdot
.64905 .36823 Mdot
.64952 .14198 Mdot
.65 .32345 Mdot
.65048 .17733 Mdot
.65095 .27278 Mdot
.65143 .20856 Mdot
.6519 .40299 Mdot
.65238 .10899 Mdot
.65286 .40358 Mdot
.65333 .20915 Mdot
.65381 .23743 Mdot
.65429 .20915 Mdot
.65476 .3211 Mdot
.65524 .12784 Mdot
.65571 .40535 Mdot
.65619 .20797 Mdot
.65667 .27514 Mdot
.65714 .14198 Mdot
.65762 .37118 Mdot
.6581 .14198 Mdot
.65857 .38591 Mdot
.65905 .19619 Mdot
.65952 .22211 Mdot
.66 .21033 Mdot
.66048 .35056 Mdot
.66095 .14552 Mdot
.66143 .3753 Mdot
.6619 .17026 Mdot
.66238 .27632 Mdot
.66286 .19147 Mdot
.66333 .38237 Mdot
.66381 .12784 Mdot
.66429 .33052 Mdot
.66476 .21268 Mdot
.66524 .27867 Mdot
.66571 .21268 Mdot
.66619 .38591 Mdot
.66667 .12077 Mdot
.66714 .35409 Mdot
.66762 .19854 Mdot
.6681 .25039 Mdot
.66857 .21386 Mdot
.66905 .33288 Mdot
.66952 .14669 Mdot
.67 .39062 Mdot
.67048 .1844 Mdot
.67095 .27985 Mdot
.67143 .16555 Mdot
.6719 .41537 Mdot
.67238 .14787 Mdot
.67286 .39416 Mdot
.67333 .19147 Mdot
.67381 .1844 Mdot
.67429 .21563 Mdot
.67476 .41713 Mdot
.67524 .14198 Mdot
.67571 .40712 Mdot
.67619 .17498 Mdot
.67667 .28339 Mdot
.67714 .18794 Mdot
.67762 .4189 Mdot
.6781 .14905 Mdot
.67857 .30931 Mdot
.67905 .21268 Mdot
.67952 .26925 Mdot
.68 .19854 Mdot
.68048 .36116 Mdot
.68095 .11841 Mdot
.68143 .42126 Mdot
.6819 .21799 Mdot
.68238 .28574 Mdot
.68286 .2174 Mdot
.68333 .33995 Mdot
.68381 .12077 Mdot
.68429 .39651 Mdot
.68476 .21858 Mdot
.68524 .28692 Mdot
.68571 .17733 Mdot
.68619 .38944 Mdot
.68667 .14669 Mdot
.68714 .3647 Mdot
.68762 .20326 Mdot
.6881 .22682 Mdot
.68857 .21975 Mdot
.68905 .38591 Mdot
.68952 .15141 Mdot
.69 .42656 Mdot
.69048 .15612 Mdot
.69095 .28928 Mdot
.69143 .22093 Mdot
.6919 .40358 Mdot
.69238 .14198 Mdot
.69286 .34466 Mdot
.69333 .20561 Mdot
.69381 .24804 Mdot
.69429 .20326 Mdot
.69476 .42951 Mdot
.69524 .12313 Mdot
.69571 .40123 Mdot
.69619 .22211 Mdot
.69667 .29046 Mdot
.69714 .19147 Mdot
.69762 .34702 Mdot
.6981 .15141 Mdot
.69857 .39651 Mdot
.69905 .22329 Mdot
.69952 .26218 Mdot
.7 .17969 Mdot
.70048 .36116 Mdot
.70095 .15259 Mdot
.70143 .43363 Mdot
.7019 .22211 Mdot
.70238 .22682 Mdot
.70286 .20915 Mdot
.70333 .43481 Mdot
.70381 .12784 Mdot
.70429 .4354 Mdot
.70476 .15612 Mdot
.70524 .29046 Mdot
.70571 .22447 Mdot
.70619 .43658 Mdot
.70667 .15494 Mdot
.70714 .29753 Mdot
.70762 .22565 Mdot
.7081 .29635 Mdot
.70857 .22624 Mdot
.70905 .43834 Mdot
.70952 .12784 Mdot
.71 .39769 Mdot
.71048 .19501 Mdot
.71095 .26925 Mdot
.71143 .21622 Mdot
.7119 .33524 Mdot
.71238 .15612 Mdot
.71286 .4407 Mdot
.71333 .22682 Mdot
.71381 .24804 Mdot
.71429 .17969 Mdot
.71476 .44188 Mdot
.71524 .14434 Mdot
.71571 .44247 Mdot
.71619 .22859 Mdot
.71667 .24097 Mdot
.71714 .1844 Mdot
.71762 .42126 Mdot
.7181 .15789 Mdot
.71857 .44424 Mdot
.71905 .1844 Mdot
.71952 .30106 Mdot
.72 .21268 Mdot
.72048 .33288 Mdot
.72095 .15612 Mdot
.72143 .3588 Mdot
.7219 .23036 Mdot
.72238 .30106 Mdot
.72286 .23036 Mdot
.72333 .41065 Mdot
.72381 .1137 Mdot
.72429 .44777 Mdot
.72476 .22211 Mdot
.72524 .30342 Mdot
.72571 .20915 Mdot
.72619 .35645 Mdot
.72667 .15612 Mdot
.72714 .38591 Mdot
.72762 .23213 Mdot
.7281 .27867 Mdot
.72857 .1844 Mdot
.72905 .45072 Mdot
.72952 .14198 Mdot
.73 .45131 Mdot
.73048 .19854 Mdot
.73095 .22682 Mdot
.73143 .23331 Mdot
.7319 .45249 Mdot
.73238 .15612 Mdot
.73286 .45307 Mdot
.73333 .18912 Mdot
.73381 .26218 Mdot
.73429 .23389 Mdot
.73476 .45425 Mdot
.73524 .15966 Mdot
.73571 .32581 Mdot
.73619 .20326 Mdot
.73667 .30813 Mdot
.73714 .20208 Mdot
.73762 .45602 Mdot
.7381 .13255 Mdot
.73857 .42833 Mdot
.73905 .23566 Mdot
.73952 .30813 Mdot
.74 .23154 Mdot
.74048 .31167 Mdot
.74095 .16201 Mdot
.74143 .41537 Mdot
.7419 .21268 Mdot
.74238 .31049 Mdot
.74286 .19147 Mdot
.74333 .45956 Mdot
.74381 .14198 Mdot
.74429 .42951 Mdot
.74476 .23743 Mdot
.74524 .25039 Mdot
.74571 .23743 Mdot
.74619 .43893 Mdot
.74667 .14434 Mdot
.74714 .38591 Mdot
.74762 .1844 Mdot
.7481 .29046 Mdot
.74857 .23861 Mdot
.74905 .46309 Mdot
.74952 .16319 Mdot
.75 .36823 Mdot
.75048 .20561 Mdot
.75095 .31403 Mdot
.75143 .23861 Mdot
.7519 .42126 Mdot
.75238 .12784 Mdot
.75286 .46545 Mdot
.75333 .23979 Mdot
.75381 .26925 Mdot
.75429 .21975 Mdot
.75476 .3753 Mdot
.75524 .16555 Mdot
.75571 .44365 Mdot
.75619 .24097 Mdot
.75667 .30106 Mdot
.75714 .15612 Mdot
.75762 .44247 Mdot
.7581 .16555 Mdot
.75857 .46898 Mdot
.75905 .24097 Mdot
.75952 .25511 Mdot
.76 .24214 Mdot
.76048 .35409 Mdot
.76095 .16319 Mdot
.76143 .47075 Mdot
.7619 .19147 Mdot
.76238 .28574 Mdot
.76286 .24097 Mdot
.76333 .47193 Mdot
.76381 .14198 Mdot
.76429 .38001 Mdot
.76476 .24332 Mdot
.76524 .31874 Mdot
.76571 .22682 Mdot
.76619 .4737 Mdot
.76667 .12784 Mdot
.76714 .40712 Mdot
.76762 .22093 Mdot
.7681 .3211 Mdot
.76857 .22211 Mdot
.76905 .38237 Mdot
.76952 .16319 Mdot
.77 .47605 Mdot
.77048 .21268 Mdot
.77095 .32227 Mdot
.77143 .19854 Mdot
.7719 .47723 Mdot
.77238 .16791 Mdot
.77286 .40358 Mdot
.77333 .24627 Mdot
.77381 .22682 Mdot
.77429 .24568 Mdot
.77476 .44954 Mdot
.77524 .16908 Mdot
.77571 .47959 Mdot
.77619 .19854 Mdot
.77667 .29753 Mdot
.77714 .21268 Mdot
.77762 .48077 Mdot
.7781 .15612 Mdot
.77857 .38709 Mdot
.77905 .22682 Mdot
.77952 .31285 Mdot
.78 .24804 Mdot
.78048 .41419 Mdot
.78095 .13727 Mdot
.78143 .46014 Mdot
.7819 .24804 Mdot
.78238 .32227 Mdot
.78286 .24921 Mdot
.78333 .34466 Mdot
.78381 .14198 Mdot
.78429 .48489 Mdot
.78476 .23154 Mdot
.78524 .29753 Mdot
.78571 .20326 Mdot
.78619 .48607 Mdot
.78667 .17026 Mdot
.78714 .41772 Mdot
.78762 .25039 Mdot
.7881 .26453 Mdot
.78857 .22682 Mdot
.78905 .48784 Mdot
.78952 .17026 Mdot
.79 .48843 Mdot
.79048 .17026 Mdot
.79095 .32934 Mdot
.79143 .22682 Mdot
.7919 .4896 Mdot
.79238 .17262 Mdot
.79286 .35409 Mdot
.79333 .25039 Mdot
.79381 .26218 Mdot
.79429 .25275 Mdot
.79476 .49137 Mdot
.79524 .14198 Mdot
.79571 .49196 Mdot
.79619 .25334 Mdot
.79667 .33288 Mdot
.79714 .21268 Mdot
.79762 .36823 Mdot
.7981 .1738 Mdot
.79857 .49373 Mdot
.79905 .22682 Mdot
.79952 .33288 Mdot
.8 .20561 Mdot
.80048 .42479 Mdot
.80095 .16555 Mdot
.80143 .46839 Mdot
.8019 .23743 Mdot
.80238 .26925 Mdot
.80286 .25511 Mdot
.80333 .49667 Mdot
.80381 .14198 Mdot
.80429 .45072 Mdot
.80476 .20326 Mdot
.80524 .33641 Mdot
.80571 .25628 Mdot
.80619 .47429 Mdot
.80667 .17498 Mdot
.80714 .33995 Mdot
.80762 .25687 Mdot
.8081 .33288 Mdot
.80857 .25511 Mdot
.80905 .46722 Mdot
.80952 .13255 Mdot
.81 .46014 Mdot
.81048 .21975 Mdot
.81095 .31167 Mdot
.81143 .25805 Mdot
.8119 .40358 Mdot
.81238 .17026 Mdot
.81286 .50257 Mdot
.81333 .25864 Mdot
.81381 .29046 Mdot
.81429 .20797 Mdot
.81476 .45661 Mdot
.81524 .17733 Mdot
.81571 .50433 Mdot
.81619 .24097 Mdot
.81667 .26925 Mdot
.81714 .21268 Mdot
.81762 .50551 Mdot
.8181 .17733 Mdot
.81857 .5061 Mdot
.81905 .21033 Mdot
.81952 .34231 Mdot
.82 .22682 Mdot
.82048 .4354 Mdot
.82095 .1738 Mdot
.82143 .40358 Mdot
.8219 .261 Mdot
.82238 .31167 Mdot
.82286 .26159 Mdot
.82333 .48136 Mdot
.82381 .12784 Mdot
.82429 .49785 Mdot
.82476 .25393 Mdot
.82524 .29753 Mdot
.82571 .26218 Mdot
.82619 .41065 Mdot
.82667 .17969 Mdot
.82714 .43893 Mdot
.82762 .26218 Mdot
.8281 .34584 Mdot
.82857 .19854 Mdot
.82905 .48136 Mdot
.82952 .17733 Mdot
.83 .51317 Mdot
.83048 .20915 Mdot
.83095 .27867 Mdot
.83143 .25982 Mdot
.8319 .51435 Mdot
.83238 .18087 Mdot
.83286 .51494 Mdot
.83333 .20326 Mdot
.83381 .30106 Mdot
.83429 .24804 Mdot
.83476 .47429 Mdot
.83524 .17969 Mdot
.83571 .36823 Mdot
.83619 .26571 Mdot
.83667 .34938 Mdot
.83714 .22682 Mdot
.83762 .51789 Mdot
.8381 .14198 Mdot
.83857 .49314 Mdot
.83905 .26453 Mdot
.83952 .35056 Mdot
.84 .26689 Mdot
.84048 .36116 Mdot
.84095 .15612 Mdot
.84143 .48607 Mdot
.8419 .26748 Mdot
.84238 .35056 Mdot
.84286 .21268 Mdot
.84333 .52142 Mdot
.84381 .15612 Mdot
.84429 .52201 Mdot
.84476 .26807 Mdot
.84524 .27396 Mdot
.84571 .26866 Mdot
.84619 .47429 Mdot
.84667 .1844 Mdot
.84714 .39651 Mdot
.84762 .2174 Mdot
.8481 .35409 Mdot
.84857 .26925 Mdot
.84905 .52496 Mdot
.84952 .17498 Mdot
.85 .42244 Mdot
.85048 .22682 Mdot
.85095 .35409 Mdot
.85143 .2445 Mdot
.8519 .50257 Mdot
.85238 .14669 Mdot
.85286 .52731 Mdot
.85333 .24804 Mdot
.85381 .3046 Mdot
.85429 .26925 Mdot
.85476 .42479 Mdot
.85524 .1844 Mdot
.85571 .52908 Mdot
.85619 .24804 Mdot
.85667 .3211 Mdot
.85714 .19147 Mdot
.85762 .4955 Mdot
.8581 .1844 Mdot
.85857 .53085 Mdot
.85905 .27278 Mdot
.85952 .26925 Mdot
.86 .27278 Mdot
.86048 .45661 Mdot
.86095 .18676 Mdot
.86143 .53262 Mdot
.8619 .20326 Mdot
.86238 .35998 Mdot
.86286 .27396 Mdot
.86333 .50964 Mdot
.86381 .16319 Mdot
.86429 .42951 Mdot
.86476 .27455 Mdot
.86524 .33288 Mdot
.86571 .24097 Mdot
.86619 .50964 Mdot
.86667 .15141 Mdot
.86714 .40358 Mdot
.86762 .27514 Mdot
.8681 .36116 Mdot
.86857 .27573 Mdot
.86905 .42715 Mdot
.86952 .1844 Mdot
.87 .53792 Mdot
.87048 .23743 Mdot
.87095 .36352 Mdot
.87143 .22211 Mdot
.8719 .4955 Mdot
.87238 .1738 Mdot
.87286 .53969 Mdot
.87333 .27632 Mdot
.87381 .24097 Mdot
.87429 .25864 Mdot
.87476 .54086 Mdot
.87524 .18912 Mdot
.87571 .54145 Mdot
.87619 .22447 Mdot
.87667 .3647 Mdot
.87714 .24097 Mdot
.87762 .49196 Mdot
.8781 .17026 Mdot
.87857 .43658 Mdot
.87905 .27867 Mdot
.87952 .36705 Mdot
.88 .26218 Mdot
.88048 .46722 Mdot
.88095 .15612 Mdot
.88143 .54499 Mdot
.8819 .25982 Mdot
.88238 .36823 Mdot
.88286 .25039 Mdot
.88333 .41772 Mdot
.88381 .16319 Mdot
.88429 .50257 Mdot
.88476 .27867 Mdot
.88524 .3647 Mdot
.88571 .22682 Mdot
.88619 .54793 Mdot
.88667 .19147 Mdot
.88714 .46014 Mdot
.88762 .28162 Mdot
.8881 .27396 Mdot
.88857 .28103 Mdot
.88905 .52024 Mdot
.88952 .19147 Mdot
.89 .51435 Mdot
.89048 .1844 Mdot
.89095 .37177 Mdot
.89143 .2828 Mdot
.8919 .55147 Mdot
.89238 .1844 Mdot
.89286 .43893 Mdot
.89333 .25628 Mdot
.89381 .31167 Mdot
.89429 .28339 Mdot
.89476 .52731 Mdot
.89524 .15612 Mdot
.89571 .55383 Mdot
.89619 .28339 Mdot
.89667 .33995 Mdot
.89714 .2445 Mdot
.89762 .446 Mdot
.8981 .1844 Mdot
.89857 .50375 Mdot
.89905 .28515 Mdot
.89952 .3753 Mdot
.9 .22211 Mdot
.90048 .47782 Mdot
.90095 .19501 Mdot
.90143 .52378 Mdot
.9019 .28574 Mdot
.90238 .29753 Mdot
.90286 .26218 Mdot
.90333 .55854 Mdot
.90381 .15612 Mdot
.90429 .54676 Mdot
.90476 .22682 Mdot
.90524 .37766 Mdot
.90571 .28692 Mdot
.90619 .52378 Mdot
.90667 .19501 Mdot
.90714 .38237 Mdot
.90762 .27867 Mdot
.9081 .37884 Mdot
.90857 .2881 Mdot
.90905 .47429 Mdot
.90952 .15612 Mdot
.91 .56266 Mdot
.91048 .23743 Mdot
.91095 .3647 Mdot
.91143 .2881 Mdot
.9119 .45307 Mdot
.91238 .19736 Mdot
.91286 .56443 Mdot
.91333 .28928 Mdot
.91381 .32581 Mdot
.91429 .20326 Mdot
.91476 .56561 Mdot
.91524 .1844 Mdot
.91571 .5662 Mdot
.91619 .29046 Mdot
.91667 .30931 Mdot
.91714 .24804 Mdot
.91762 .56738 Mdot
.9181 .19854 Mdot
.91857 .56797 Mdot
.91905 .23154 Mdot
.91952 .33288 Mdot
.92 .29164 Mdot
.92048 .48843 Mdot
.92095 .19854 Mdot
.92143 .41065 Mdot
.9219 .27396 Mdot
.92238 .35409 Mdot
.92286 .2881 Mdot
.92333 .57091 Mdot
.92381 .14198 Mdot
.92429 .54499 Mdot
.92476 .26218 Mdot
.92524 .38591 Mdot
.92571 .2934 Mdot
.92619 .46014 Mdot
.92667 .19854 Mdot
.92714 .49196 Mdot
.92762 .26925 Mdot
.9281 .38591 Mdot
.92857 .22682 Mdot
.92905 .57445 Mdot
.92952 .2009 Mdot
.93 .52142 Mdot
.93048 .24097 Mdot
.93095 .31167 Mdot
.93143 .29517 Mdot
.9319 .57622 Mdot
.93238 .19854 Mdot
.93286 .54617 Mdot
.93333 .23861 Mdot
.93381 .31167 Mdot
.93429 .29517 Mdot
.93476 .57798 Mdot
.93524 .17969 Mdot
.93571 .46486 Mdot
.93619 .29635 Mdot
.93667 .38591 Mdot
.93714 .25511 Mdot
.93762 .54499 Mdot
.9381 .16555 Mdot
.93857 .54263 Mdot
.93905 .28869 Mdot
.93952 .3918 Mdot
.94 .26925 Mdot
.94048 .36823 Mdot
.94095 .20208 Mdot
.94143 .55677 Mdot
.9419 .29753 Mdot
.94238 .39298 Mdot
.94286 .24097 Mdot
.94333 .58329 Mdot
.94381 .17026 Mdot
.94429 .58388 Mdot
.94476 .2993 Mdot
.94524 .31167 Mdot
.94571 .27396 Mdot
.94619 .53792 Mdot
.94667 .1844 Mdot
.94714 .50257 Mdot
.94762 .24097 Mdot
.9481 .39533 Mdot
.94857 .30047 Mdot
.94905 .55913 Mdot
.94952 .20561 Mdot
.95 .47193 Mdot
.95048 .25864 Mdot
.95095 .35645 Mdot
.95143 .30106 Mdot
.9519 .58859 Mdot
.95238 .15612 Mdot
.95286 .58918 Mdot
.95333 .29753 Mdot
.95381 .33288 Mdot
.95429 .30224 Mdot
.95476 .42951 Mdot
.95524 .20561 Mdot
.95571 .55559 Mdot
.95619 .27396 Mdot
.95667 .39887 Mdot
.95714 .21268 Mdot
.95762 .5662 Mdot
.9581 .20561 Mdot
.95857 .54499 Mdot
.95905 .30342 Mdot
.95952 .3211 Mdot
.96 .30401 Mdot
.96048 .50964 Mdot
.96095 .20326 Mdot
.96143 .5391 Mdot
.9619 .24568 Mdot
.96238 .39651 Mdot
.96286 .27867 Mdot
.96333 .59566 Mdot
.96381 .17733 Mdot
.96429 .47429 Mdot
.96476 .26925 Mdot
.96524 .4024 Mdot
.96571 .28692 Mdot
.96619 .59743 Mdot
.96667 .15612 Mdot
.96714 .51317 Mdot
.96762 .30637 Mdot
.9681 .40358 Mdot
.96857 .29753 Mdot
.96905 .48136 Mdot
.96952 .20915 Mdot
.97 .59978 Mdot
.97048 .26218 Mdot
.97095 .35409 Mdot
.97143 .24804 Mdot
.9719 .54499 Mdot
.97238 .20797 Mdot
.97286 .60155 Mdot
.97333 .30813 Mdot
.97381 .26925 Mdot
.97429 .30813 Mdot
.97476 .60273 Mdot
.97524 .20561 Mdot
.97571 .60332 Mdot
.97619 .25039 Mdot
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005P0000fB000`400?l00000o`00003oo`3ooomQ
0?ooo`00o`3ooomQ0?ooo`00o`3ooomQ0?ooo`00o`3ooomQ0?ooo`00o`3ooomQ0?ooo`00o`3ooomQ
0?ooo`00I03oool4000000D0oooo0`0000050?ooo`<00000<P3oool6000000@0oooo0`0000050?oo
o`<000001@3oool3000002h0oooo1P0000030?ooo`@000001@3oool3000000D0oooo0`00000^0?oo
o`H00000103oool3000000D0oooo0`0000050?ooo`<000000`3oool006P0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000=@3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`00000a0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000;`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000<0oooo001X0?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`070?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000@0oooo0@0000010?ooo`40oooo001X0?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0^0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool100000040oooo0@3oool006@0oooo100000030?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`03
0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0;`3oool200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo0@0000010?ooo`40oooo001T0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0<03oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool10000
0040oooo0@3oool006@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000003D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000<@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`00000^0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000030?ooo`00I03oool4000000@0oooo100000040?ooo`@00000<`3oool3000000D0oooo
100000040?ooo`@00000103oool4000002l0oooo0`0000050?ooo`@00000103oool4000000@0oooo
1000000^0?ooo`D00000103oool4000000@0oooo100000040?ooo`@000000`3oool00?l0ooooH@3o
ool00?l0ooooH@3oool00?l0ooooH@3oool00?l0ooooH@3oool002<0oooo00<000000?ooo`3oool0
o`3ooolk0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooc/0oooo000S0?ooo`030000003oool0
oooo0?l0oooo>`3oool002<0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`008`3oool00`000000
oooo0?ooo`3o0?oooc/0oooo000L0?ooool00000?00000090?ooo`008`3oool00`000000oooo0000
0008000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`008`3oool0
10000000oooo0?ooo`3oool;000003`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03P3oool002<0oooo00<00000
0?ooo`3oool00`3oool@000000030?ooo`000000oooo0?l0oooo9@3oool002<0oooo00<000000?oo
o`3oool0103oool200000080oooo00<000000?ooo`3oool01@0000002P3oool00000000000000000
oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo0?l0oooo6`3oool002<0oooo
00<000000?ooo`3oool01P3oool2000000030?ooo`000000000000H00000103oool2000000030?oo
o`000000oooo00800000o`3ooolO0?ooo`008`3oool00`000000oooo0?ooo`080?ooo`80000000@0
oooo000000000000oooo0P0000000`3oool0000000000005000000030?ooo`000000000000800000
00<0oooo0000000000000`000000103oool000000?ooo`00003o0?oooa@0oooo000S0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool200000080oooo1@0000020?ooo`800000
0P3oool010000000oooo0?ooo`3oool3000000@0oooo0P0000030?ooo`030000003oool0oooo0?l0
oooo2@3oool002<0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0103oool200000?l0
oooo4P3oool002<0oooo0`00000<0?ooo`8000000P3oool2000000<0oooo0P0000040?ooo`D00000
00H0oooo0000003oool000000?ooo`0000020?ooo`8000000P3oool200000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0nP3oool0
02<0oooo00<000000?ooo`3oool03P3oool3000000040?ooo`000000oooo00000080oooo0P000000
0`3oool000000?ooo`020?ooo`030000003oool00000008000000`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<000000P3oool00`000000oooo0?ooo`3o0?ooo`80oooo000S
0?ooo`030000003oool0oooo0140oooo00D000000?ooo`000000oooo000000020?ooo`8000001P3o
ool00`000000oooo00000002000000@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`0200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0000003f0?ooo`008`3o
ool00`000000oooo0?ooo`0A0?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`8000001P3o
ool4000000H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`03000000T0oooo
00D000000?ooo`3oool0oooo0000003_0?ooo`008`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`80000000D0oooo00000000
0000oooo000000060?ooo`80000000<0oooo0000003oool01@3oool3000000040?ooo`000000oooo
000000@0oooo00<000000?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`3K0?ooo`008`3oool00`000000oooo0?ooo`0D0?ooo`80000000<0oooo0000
003oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool000000080oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`3b0?ooo`008`3oool00`000000oooo0?ooo`0F0?ooo`80
00000P3oool00`000000oooo00000002000000<0oooo0P0000000`3oool000000?ooo`080?ooo`<0
000000D0oooo0000003oool0oooo000000020?ooo`<000000P3oool00`000000oooo000000060?oo
o`8000000P3oool3000000P0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`3F0?oo
o`008`3oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool2000000L0oooo00D000000?ooo`00
0000oooo000000060?ooo`D000001P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00P0oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0=80oooo000S0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0B0?ooo`800000303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0>D0oooo000S0?ooo`030000003oool0oooo01/0oooo0P0000020?ooo`030000003oool0oooo
00D0oooo00D000000?ooo`000000oooo000000070?ooo`050000003oool0oooo0000003oool00`00
00000`3oool000000?ooo`020?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo
00P000000?ooo`3oool0oooo0000003oool000000?ooo`8000000`3oool00`000000oooo00000006
0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`2k0?ooo`008`3oool3000001d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000d0oooo0`00000>0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P00003K0?ooo`008`3oool00`000000
oooo0?ooo`0O0?ooo`040000003oool0oooo0?ooo`<000002@3oool4000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000200000080oooo00@000000?oo
o`000000oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo00L0oooo0P000000
1@3oool00000000000000000oooo008000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`000000203oool00`000000oooo0?ooo`2g0?ooo`008`3oool00`000000oooo0?oo
o`0P0?ooo`800000203oool00`000000oooo0?ooo`0E0?ooo`040000003oool0000000000100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3?0?ooo`008`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
0003000000<0oooo00<000000?ooo`3oool0103oool2000000@0oooo0`0000030?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool0oooo0`0000030?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000000P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2L0?ooo`008`3oool00`000000oooo0?ooo`0S0?ooo`800000
1P3oool00`000000oooo0?ooo`090?ooo`8000001`3oool00`000000oooo0?ooo`060?ooo`<00000
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`090?ooo`<000001@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2P0?ooo`008`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool3000000P0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000140oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0:P0oooo
000S0?ooo`030000003oool0oooo02H0oooo0P0000000`3oool000000?ooo`040?ooo`030000003o
ool0oooo00T0oooo0`00000@0?ooo`@000000P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`000000oooo0000002l0?ooo`008`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000d0oooo0P00
000=0?ooo`<0000000<0oooo0000000000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000203oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool02P3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`1l0?ooo`008`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0B0?ooo`8000003@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0;<0oooo
000S0?ooo`<00000;03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool04`3oool010000000oooo0000000000080?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0/@3oool002<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`800000
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00@000000?ooo`000000
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo0P0000050?oo
o`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00H0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool0oooo07<0oooo000S0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`0000001`3o
ool00`000000oooo0?ooo`090?ooo`040000003oool00000000001L0oooo00<000000?ooo`3oool0
4P3oool200000080oooo0P0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
S`3oool002<0oooo00<000000?ooo`3oool0<03oool01`000000oooo0?ooo`3oool000000?ooo`00
00008P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
0000103oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0000000C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo05d0oooo000S0?ooo`030000003oool0oooo0380
oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?oo
o`8000005`3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0>0?ooo`040000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo06X0oooo000S0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool00`3oool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`<000002`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo0P00
000<0?ooo`8000000P3oool01P000000oooo0?ooo`000000oooo000000/0oooo00<000000?ooo`3o
ool0403oool2000000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo06X0oooo000S0?ooo`030000003oool0oooo03D0oooo0P00000`0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`000000703oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0IP3oool002<0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo0P0000000`3oool00000
0?ooo`080?ooo`030000003oool0oooo00/0oooo100000070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`0000001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0100000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`040000003oool0oooo000000`0oooo0P00000=0?ooo`050000003oool0
oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0n0?ooo`008`3oool00`000000oooo0?ooo`0h
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo0`000002
0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`00000000002`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0280oooo00@000000?ooo`00000000001@3oool00`000000oooo
0?ooo`1o0?ooo`008`3oool3000003X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02X0oooo0P0000000`3oool000000?ooo`0:0?ooo`030000003o
ool0oooo00`0oooo0P00000=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0480oooo000S0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0080000000@0oooo0000003oool000006P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo04/0oooo000S0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`0000050?ooo`8000003@3oool2000001d0oooo00<000000?ooo`0000003@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo0P00000K0?ooo`040000003o
ool00000000007/0oooo000S0?ooo`030000003oool0oooo03h0oooo0`0000050?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00001`3oool2000000/0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo100000090?ooo`030000003oool0oooo008000000P3oool020000000
oooo0?ooo`000000oooo0000003oool000000`3oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`060000003oool000000000003o
ool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0N0?ooo`008`3oool00`000000oooo0?ooo`100?ooo`8000001P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool07P3oool3
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0=@3oool002<0oooo00<000000?ooo`3oool0@P3oool2
000000L0oooo00<000000?ooo`3oool05P3oool200000200oooo0`00000@0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`000000K@3oool002<0oooo00<000000?ooo`3oool0@`3oool20000
00`0oooo00<000000?ooo`3oool04`3oool2000001T0oooo00<000000?ooo`3oool0103oool30000
01L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00800000<`3oool00`000000oooo0?ooo`0`0?ooo`002P3oool4000000D0oooo0`0000050?ooo`<0
00001@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00@0oooo0P00000J0?ooo`80
0000503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P000000103oool0
00000?ooo`0000090?ooo`8000002`3oool3000000T0oooo0P0000000`3oool000000?ooo`070?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`050000003oool0
00000?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo0P00
000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P00000=0?ooo`050000003o
ool0oooo0?ooo`0000004`3oool000h0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`00000Q0?oo
o`8000006P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0F@3oool000h0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo0`0000190?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`000000203oool00`000000oooo0000000A0?ooo`050000003oool0oooo0?ooo`0000004@3o
ool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo0000003oool02`3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P00000Q0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`0000007@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02/0oooo000>0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04X0oooo00@000000?ooo`3o
ool000008`3oool00`000000oooo0?ooo`0R0?ooo`<000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?oo
o`800000303oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01X0oooo000:0?ooo`@0
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02<0oooo0P00000@0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0903oool2000004l0oooo000:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0H0?oo
o`800000303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool200000140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool3000000D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo000:0?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo04l0oooo0P0000050?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool04@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000001`0oooo
00<000000?ooo`000000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo02<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0;P3oool000X0oooo100000040?ooo`@00000103oool4000000D0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0
oooo0P00000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0V0?ooo`8000000P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0180
oooo000S0?ooo`030000003oool0oooo0580oooo0P00000F0?ooo`030000003oool0oooo00l0oooo
0P00000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool3000001@0oooo
00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000280oooo00@000000?ooo`00
000000007P3oool00`000000oooo0?ooo`0K0?ooo`008`3oool00`000000oooo0?ooo`1C0?ooo`80
00001`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo0P0000080?ooo`8000003@3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo01d0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`030?oo
o`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01L0oooo000S0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo0P00000L0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0<P3oool002<0oooo00<000000?ooo`3oool0E`3oool2000000T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`D000004`3oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P00000[0?oo
o`008`3oool3000005T0oooo0P00000?0?ooo`030000003oool0oooo01/0oooo0P00000Z0?ooo`<0
00007`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0000002D0oooo000S0?ooo`030000
003oool0oooo05X0oooo0P0000060?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
:P3oool2000000d0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0R0?ooo`008`3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000603o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo1000000;0?ooo`050000003o
ool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0:0?ooo`800000403oool00`000000oooo
0?ooo`0I0?ooo`80000000@0oooo00000000000000007@3oool002<0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
6@3oool01@000000oooo0?ooo`3oool0000002h0oooo0P0000030?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180
oooo000S0?ooo`030000003oool0oooo05l0oooo0P0000060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0000000P0oooo
00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0
oooo0P0000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000:P3oool010000000oooo000000000003
0?ooo`800000403oool002<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo000000h0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01l0oooo0P0000000`3oool000000?ooo`0;0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool0000002X0oooo00<0
00000?ooo`3oool0403oool002<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G
0?ooo`800000403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo0`000002
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0503oool002<0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool09`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0=P3oool002<0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo02H0oooo0P00000K0?ooo`030000003oool0oooo01<0oooo0`00000D0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@P3oool002<0oooo0`00001W0?ooo`80
00002P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`070?ooo`@000001P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0V0?ooo`00
8`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P00000=0?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo
000000080?ooo`8000003`3oool010000000oooo0?ooo`3oool3000000030?ooo`000000oooo00<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0200000080oooo0P0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
00L0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01d0oooo000S0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`1O0?ooo`008`3oool00`000000oooo0?ooo`1/0?ooo`8000001`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo03<0oooo100000020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0P0?ooo`008`3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0000001J0?ooo`008`3oool00`000000oooo0?ooo`1_0?ooo`8000001`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000J0?ooo`800000
0P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo0`00000?0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01/0oooo000S0?ooo`030000003oool0oooo0740oooo0P00000K0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00P0oooo1000000@0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`0000000000
403oool010000000oooo0?ooo`3oool2000001T0oooo000S0?ooo`030000003oool0oooo0800oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo
0P00000h0?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo000S0?ooo`030000003oool0oooo07@0oooo
0P0000070?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0@0?ooo`040000003oool00000000000l0oooo00<000000?ooo`3oool00`3oool20000
0180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`008`3oool3000009L0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0000000K0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool03P3oool002<0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo00P0oooo0P000000103oool000000?ooo`0000040?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool06P3oool002<0oooo00<000000?ooo`3oool0
N@3oool2000000T0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0V0?ooo`04
0000003oool0oooo000003L0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool002<0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0?03oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo02/0oooo000S0?ooo`03
0000003oool0oooo08@0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`040000003oool0oooo
000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo000000090?ooo`8000000P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo000S0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0k0?ooo`040000003oool00000
000003T0oooo000S0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool01@00
0000oooo0?ooo`3oool0000000P0oooo0P000000103oool000000?ooo`00000D0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`00000@0?ooo`008`3oool00`000000oooo
0?ooo`210?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo
0P0000070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`00000F0?ooo`008`3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0M0?ooo`030000003oool0000003l0oooo
0`00000`0?ooo`008`3oool3000009`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0M0?ooo`8000004@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00`0oooo00@0
00000?ooo`00000000001@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo
000S0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0400oooo0`00000Y0?ooo`008`3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01`0oooo0P00000G0?ooo`030000003oool0oooo02P0oooo0`00000B
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08T0oooo0P0000030?oo
o`030000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`00000P0?ooo`8000000P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06`3oool4000000030?ooo`000000
oooo00<0oooo00<000000?ooo`3oool06@3oool002<0oooo00<000000?ooo`3oool0R`3oool20000
08/0oooo0P00000P0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`130?ooo`<00000703oool002<0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool04`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0100
oooo00000`3oool0000000000004000000@0oooo0`0000050?ooo`<000001@3oool3000000D0oooo
00<000000?ooo`3oool0S`3oool2000001P0oooo00<000000?ooo`3oool0;@3oool2000000T0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0Q0?ooo`8000005`3oool000@0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2A0?ooo`800000303oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool07P3oool01000
0000oooo0?ooo`00000B0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo0P00000g0?ooo`030000003oool0oooo00h0oooo0P00000@0?ooo`00103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0`00002E0?ooo`800000
203oool2000003h0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0
oooo0000000E0?ooo`030000003oool0oooo00T0oooo0P0000030?ooo`030000003oool0oooo01L0
oooo00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`2F0?ooo`800000403oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
05@0oooo00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2H0?ooo`8000006@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0D03oool000@0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0Q0?ooo`8000000P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00080oooo0`0000050?ooo`@00000103o
ool4000000@0oooo100000050?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`1d0?ooo`008`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0
oooo00P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool08@3oool002<0oooo00<000000?ooo`3oool0WP3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`180?ooo`008`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo
00H0oooo0P0000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo0P0000020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01D0oooo000S0?ooo`030000003oool0oooo0:40oooo0P00000c0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0@`3oool002<0oooo0`00002S0?ooo`800000:03oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09`3oool002<0oooo00<0
00000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0?`3oool002<0oooo00<000000?ooo`3oool0YP3oool2000002X0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0l0?ooo`008`3oool00`000000oooo0?ooo`36
0?ooo`030000003oool0oooo03@0oooo0`00000j0?ooo`008`3oool00`000000oooo0?ooo`2Z0?oo
o`800000203oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool2
000001D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`008`3oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0F0?ooo`008`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0a0?ooo`008`3oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01@3oool200000340oooo
000S0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo03T0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`0R0?ooo`008`3oool300000;80oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo0P00000A0?ooo`030000003oool0oooo01T0oooo000S
0?ooo`030000003oool0oooo0;<0oooo0P00000@0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool0:03oool002<0oooo00<000000?ooo`3oool0]@3oool2000000l0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02H0oooo000S0?ooo`03
0000003oool0oooo0;H0oooo0P00001K0?ooo`8000009@3oool002<0oooo00<000000?ooo`3oool0
^@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01d0oooo0P00000[0?ooo`030000
003oool0oooo02<0oooo000S0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0e0?ooo`8000000P3oool00`000000oooo0?ooo`0J0?ooo`008`3o
ool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo04`0oooo000S0?ooo`030000003oool0
oooo0;d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool06@3oool002<0oooo00<000000?ooo`3oool0_P3oool20000
00X0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0000000H0?ooo`008`3oool00`000000
oooo0?ooo`300?ooo`800000303oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0180oooo000S0?ooo`<0
0000`P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0503oool002<0oooo00<000000?ooo`3oool0``3oool2000000/0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3o
ool0703oool200000180oooo000S0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo000S0?ooo`030000003o
ool0oooo0=X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01l0oooo000S0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0B`3oool0
02<0oooo00<000000?ooo`3oool0bP3oool2000001@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo02/0oooo000S0?ooo`030000003oool0oooo0</0
oooo00<000000?ooo`3oool0K03oool002<0oooo00<000000?ooo`3oool0c@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0e0?ooo`008`3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo000S
0?ooo`<00000d@3oool00`000000oooo0?ooo`0;0?ooo`8000009@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01@0oooo000S0?ooo`030000003oool0oooo0=<0oooo00<000000?oo
o`3oool0I03oool002<0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0;03oool002<0oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0X0?ooo`008`3oool00`000000oooo0?ooo`3G0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0DP3oool002<0oooo00<000000?ooo`3oool0f03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool09P3oool0
02<0oooo00<000000?ooo`3oool0fP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
04d0oooo00000`3oool0000000000004000000<0oooo100000050?ooo`<000001@3oool3000000D0
oooo00<000000?ooo`3oool0g03oool2000001D0oooo00<000000?ooo`3oool0A03oool000@0oooo
00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0=d0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0R0?ooo`00103oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02
0?ooo`<00000gP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0<P3oool000@0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool000@0oooo00<00000
0?ooo`3oool00`3oool4000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0hP3oool2000003T0oooo00<0
00000?ooo`3oool06P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0?80oooo00@000000?ooo`3oool000005@3oool00`000000oooo
0?ooo`0/0?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0>D0
oooo0P00001C0?ooo`000P3oool3000000D0oooo100000040?ooo`@00000103oool4000000D0oooo
00<000000?ooo`3oool0iP3oool2000000`0oooo00<000000?ooo`3oool01P3oool010000000oooo
0?ooo`00000C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool09@3oool002<0oooo00<000000?ooo`3oool0jP3oool2000000d0oooo00<0
00000?ooo`000000:`3oool00`000000oooo0?ooo`0@0?ooo`008`3oool00`000000oooo0?ooo`3o
0?oooc/0oooo000S0?ooo`<00000k@3oool200000100oooo00<000000?ooo`3oool0>03oool002<0
oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0
oooo000S0?ooo`030000003oool0oooo0?00oooo0`00000;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0M0?ooo`008`3oool00`000000oooo0?oo
o`3c0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0^0?ooo`008`3oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo03d0oooo000S0?oo
o`030000003oool0oooo0?H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool002<0oooo00<000000?ooo`3o
ool0m`3oool2000001P0oooo00<000000?ooo`3oool09P3oool002<0oooo00<000000?ooo`3oool0
o`3oool70?ooo`800000703oool00`000000oooo0?ooo`0C0?ooo`008`3oool00`000000oooo0?oo
o`3k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0403oool002<0oooo00<00000
0?ooo`3oool0o03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02T0oooo000S0?oo
o`<00000oP3oool00`000000oooo0?ooo`0i0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooo`40
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0
oooo000S0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`0>0?ooo`800000
9P3oool002<0oooo00<000000?ooo`3oool0o`3oool40?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool09`3oool002<0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0
oooo03<0oooo000S0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`0b0?oo
o`008`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0G0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo0P00000J0?ooo`030000
003oool0oooo0180oooo000S0?ooo`030000003oool0oooo0?l0oooo7`3oool00`000000oooo0?oo
o`0I0?ooo`008`3oool300000?l0oooo3@3oool2000000D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`008`3oool0
0`000000oooo0?ooo`3o0?oooc/0oooo000S0?ooo`030000003oool0oooo0?l0oooo403oool20000
02T0oooo000S0?ooo`030000003oool0oooo0?l0oooo7`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01@0oooo000S0?ooo`030000003oool0oooo0?l0oooo4`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01H0oooo000S0?ooo`030000003oool0oooo0?l0oooo5P3o
ool00`000000oooo0?ooo`0R0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooaH0oooo0P00000=
0?ooo`030000003oool0oooo01<0oooo000S0?ooo`030000003oool0oooo0?l0oooo603oool00`00
0000oooo0?ooo`0P0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3o
ool07P3oool002<0oooo0`00003o0?oooa`0oooo00<000000?ooo`3oool0703oool002<0oooo00<0
00000?ooo`3oool0o`3ooolM0?ooo`030000003oool0oooo01/0oooo000S0?ooo`030000003oool0
oooo0?l0oooo>`3oool002<0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`030000003oool0oooo
01P0oooo000S0?ooo`030000003oool0oooo0?l0oooo8`3oool00`000000oooo0?ooo`0E0?ooo`00
8`3oool00`000000oooo0?ooo`3o0?oooc/0oooo000S0?ooo`030000003oool0oooo0?l0oooo9P3o
ool00`000000oooo0?ooo`0B0?ooo`0000<0oooo000000000000100000040?ooo`<000001@3oool3
000000D0oooo0`0000050?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0A
0?ooo`000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0o`3ooolX0?ooo`8000004@3oool000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooo`<00000o`3ooolZ0?ooo`030000003oool0oooo00h0oooo00040?ooo`80
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo>`3oool0
00D0oooo0P0000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3o
oolk0?ooo`001P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0
oooo>`3oool000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo0?l0oooo>`3oool000030?ooo`000000000000<00000103oool40000
00@0oooo100000040?ooo`@000001@3oool00`000000oooo0?ooo`3o0?oooc/0oooo003o0?ooof40
oooo003o0?ooof40oooo003o0?ooof40oooo0000\
\>"],
  ImageRangeCache->{{{0, 351.5}, {216.5, 0}} -> {-239.902, -249.132, 8.34543, \
13.4897}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Relations to other functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["EulerPhi expressed through other numer theoretical functions", \
"Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["EulerPhi[n] == Sum[Floor[1/GCD[j,n]],{j,n}] ", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
EulerPhi[n] == Det[ Table[Which[j===n,i,
                                IntegerQ[i/j],1,
                                True,0],
                          {i,n},{j,n}] ]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
EulerPhi[n] == Sum[
DivisorProduct1[1-1/d Sum[Exp[2Pi I j i/d],
                         {i,0,d-1}],d,n],
                {j,n-1}] //N\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["EulerPhi[n]==n/DivisorSum[MoebiusMu[d]^2/EulerPhi[d],d,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["EulerPhi[n] ==DivisorSum[d MoebiusMu[n/d],d,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Relations to other number theoretical functions", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sum[Floor[n/i] EulerPhi[i],{i,n}] == 1/2(n^2+n)", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Sum[GCD[n,i],{i,n}] == 
Plus @@ (# EulerPhi[n/#]& /@ Divisors[n])\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sum[GCD[n,i],{i,n}] == DivisorSum[d EulerPhi[n/d],d,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sum[1/GCD[n,i],{i,n}] == 1/n DivisorSum[d EulerPhi[d],d,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Det[Table[GCD[i,j],{i,n},{j,n}]] == 
    Product[EulerPhi[i],{i,n}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
P. K. Menon (1965)  proved the following relation to the divisor \
sigma function:\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
EulerPhi[n] DivisorSigma[0,n] ==
PropertySum[GCD[d-1,n],{d,ReducedResidueSystem[n]}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Let  Core denote the core of n (Wigert32), that is the greatest \
squarefree divisor of n, \
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Core[n_]:=PrimeFactorProduct[d,d,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["then we have the following identities:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["EulerPhi[n] == n EulerPhi[Core[n]]/Core[n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Core[n] == DivisorSum[Abs[MoebiusMu[d]] EulerPhi[d],d,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
 PropertySum[GCD[d-1,n],{d,ReducedResidueSystem[n]}],
  EulerPhi[n] DivisorSigma[0,n]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Brauer-Rademacher Identity (A. Brauer1926)", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
EulerPhi[r] *PropertySum[d/EulerPhi[d] MoebiusMu[r/d],
{d,Select[Divisors[r],GCD[#,n]==1&]}] ==
MoebiusMu[r] *PropertySum[d  MoebiusMu[r/d],
                          d,Divisors[GCD[n,r]]]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Relations to Ramanujan sums", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
RamanujanSum[n_,m_]:=PropertySum[Exp[2Pi I d m/n],
                    {d,ReducedResidueSystem[n]}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
RamanujanSum[n,m] == 
EulerPhi[n] MoebiusMu[n/GCD[n,m]]/EulerPhi[n/GCD[n,m]]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Functional  Equations", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["sum properties", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[" for n>1", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["DivisorSum[EulerPhi[d],d,n]  ==  n", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["If[n>2,Mod[EulerPhi[n],2]==0]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["DivisorSum[(-1)^(n/d-1) EulerPhi[d],d,n] == n", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["For positive integer r we have additionally:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Sum[EulerPhi[i^r] Sum[j^(r-1),{j,n/i}],{i,n}] ==
Sum[i^r,{i,n}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["multiplication formulas", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
The function EulerPhi is a multiplicative function, this \
means:\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["If[GCD[n,m]==1,EulerPhi[n] EulerPhi[m] == EulerPhi[m n] ] ", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
In the case that n amd m have a common nontrivail factor this \
generalizes to:\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
EulerPhi[n] EulerPhi[m] == 
EulerPhi[m n] EulerPhi[GCD[n,m]]/GCD[n,m]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Iterated EulerPhi", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["For n>2 it always ends with the number 1; here visualized:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Show[Graphics[{Thickness[0.0001],Line /@ 
Array[MapIndexed[{#1,-First[#2]}&,
            FixedPointList[EulerPhi,#]]&,200]}],
      PlotRange->All];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0190237 0.00478583 0.668719 0.0654004 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
p
p
.0001 w
.02381 .60332 m
.02381 .53792 L
s
.0286 .60332 m
.02381 .53792 L
.02381 .47252 L
s
.03338 .60332 m
.0286 .53792 L
.02381 .47252 L
.02381 .40712 L
s
.03817 .60332 m
.0286 .53792 L
.02381 .47252 L
.02381 .40712 L
s
.04295 .60332 m
.03817 .53792 L
.0286 .47252 L
.02381 .40712 L
.02381 .34172 L
s
.04774 .60332 m
.0286 .53792 L
.02381 .47252 L
.02381 .40712 L
s
.05252 .60332 m
.04774 .53792 L
.0286 .47252 L
.02381 .40712 L
.02381 .34172 L
s
.05731 .60332 m
.03817 .53792 L
.0286 .47252 L
.02381 .40712 L
.02381 .34172 L
s
.0621 .60332 m
.04774 .53792 L
.0286 .47252 L
.02381 .40712 L
.02381 .34172 L
s
.06688 .60332 m
.03817 .53792 L
.0286 .47252 L
.02381 .40712 L
.02381 .34172 L
s
.07167 .60332 m
.06688 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.07645 .60332 m
.03817 .53792 L
.0286 .47252 L
.02381 .40712 L
.02381 .34172 L
s
.08124 .60332 m
.07645 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.08603 .60332 m
.04774 .53792 L
.0286 .47252 L
.02381 .40712 L
.02381 .34172 L
s
.09081 .60332 m
.05731 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.0956 .60332 m
.05731 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.10038 .60332 m
.0956 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.10517 .60332 m
.04774 .53792 L
.0286 .47252 L
.02381 .40712 L
.02381 .34172 L
s
.10995 .60332 m
.10517 .53792 L
.04774 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.11474 .60332 m
.05731 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.11953 .60332 m
.07645 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.12431 .60332 m
.06688 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.1291 .60332 m
.12431 .53792 L
.06688 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.13388 .60332 m
.05731 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.13867 .60332 m
.11474 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.14346 .60332 m
.07645 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.14824 .60332 m
.10517 .53792 L
.04774 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.15303 .60332 m
.07645 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.15781 .60332 m
.15303 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.1626 .60332 m
.05731 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.16738 .60332 m
.1626 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.17217 .60332 m
.0956 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.17696 .60332 m
.11474 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.18174 .60332 m
.0956 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.18653 .60332 m
.13388 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.19131 .60332 m
.07645 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.1961 .60332 m
.19131 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.20089 .60332 m
.10517 .53792 L
.04774 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.20567 .60332 m
.13388 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.21046 .60332 m
.0956 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.21524 .60332 m
.21046 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.22003 .60332 m
.07645 .53792 L
.03817 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.22481 .60332 m
.22003 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.2296 .60332 m
.11474 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.23439 .60332 m
.13388 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.23917 .60332 m
.12431 .53792 L
.06688 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.24396 .60332 m
.23917 .53792 L
.12431 .47252 L
.06688 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.24874 .60332 m
.0956 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.25353 .60332 m
.22003 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.25832 .60332 m
.11474 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.2631 .60332 m
.17217 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.26789 .60332 m
.13388 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.27267 .60332 m
.26789 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.27746 .60332 m
.10517 .53792 L
.04774 .47252 L
.0286 .40712 L
.02381 .34172 L
.02381 .27632 L
s
.28224 .60332 m
.21046 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.28703 .60332 m
.13388 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.29182 .60332 m
.19131 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.2966 .60332 m
.15303 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.30139 .60332 m
.2966 .53792 L
.15303 .47252 L
.07645 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.30617 .60332 m
.0956 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.31096 .60332 m
.30617 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.31575 .60332 m
.1626 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.32053 .60332 m
.19131 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.32532 .60332 m
.17217 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.3301 .60332 m
.24874 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.33489 .60332 m
.11474 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.33967 .60332 m
.33489 .53792 L
.11474 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.34446 .60332 m
.17217 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.34925 .60332 m
.2296 .53792 L
.11474 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.35403 .60332 m
.13388 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.35882 .60332 m
.35403 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.3636 .60332 m
.13388 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.36839 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.37318 .60332 m
.19131 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.37796 .60332 m
.21046 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.38275 .60332 m
.19131 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.38753 .60332 m
.30617 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.39232 .60332 m
.13388 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.3971 .60332 m
.39232 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.40189 .60332 m
.17217 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.40668 .60332 m
.27746 .53792 L
.10517 .47252 L
.04774 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.41146 .60332 m
.21046 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.41625 .60332 m
.41146 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.42103 .60332 m
.13388 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.42582 .60332 m
.32532 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.43061 .60332 m
.22003 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.43539 .60332 m
.28703 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.44018 .60332 m
.21046 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.44496 .60332 m
.44018 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.44975 .60332 m
.13388 .53792 L
.05731 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.45453 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.45932 .60332 m
.2296 .53792 L
.11474 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.46411 .60332 m
.30617 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.46889 .60332 m
.23917 .53792 L
.12431 .47252 L
.06688 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.47368 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.47846 .60332 m
.17217 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.48325 .60332 m
.47846 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.48804 .60332 m
.22003 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.49282 .60332 m
.30617 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.49761 .60332 m
.21046 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.50239 .60332 m
.49761 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.50718 .60332 m
.17217 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.51196 .60332 m
.50718 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.51675 .60332 m
.24874 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.52154 .60332 m
.24874 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.52632 .60332 m
.26789 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.53111 .60332 m
.52632 .53792 L
.26789 .47252 L
.13388 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.53589 .60332 m
.19131 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.54068 .60332 m
.53589 .53792 L
.19131 .47252 L
.07645 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.54547 .60332 m
.21046 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.55025 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.55504 .60332 m
.24874 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.55982 .60332 m
.55504 .53792 L
.24874 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.56461 .60332 m
.19131 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.56939 .60332 m
.44018 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.57418 .60332 m
.28703 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.57897 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.58375 .60332 m
.2966 .53792 L
.15303 .47252 L
.07645 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.58854 .60332 m
.47846 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.59332 .60332 m
.17217 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.59811 .60332 m
.54547 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.6029 .60332 m
.30617 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.60768 .60332 m
.40189 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.61247 .60332 m
.30617 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.61725 .60332 m
.49761 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.62204 .60332 m
.19131 .53792 L
.07645 .47252 L
.03817 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.62682 .60332 m
.62204 .53792 L
.19131 .47252 L
.07645 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.63161 .60332 m
.32532 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.6364 .60332 m
.42103 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.64118 .60332 m
.24874 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.64597 .60332 m
.64118 .53792 L
.24874 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.65075 .60332 m
.21046 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.65554 .60332 m
.53589 .53792 L
.19131 .47252 L
.07645 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.66033 .60332 m
.33489 .53792 L
.11474 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.66511 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.6699 .60332 m
.32532 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.67468 .60332 m
.6699 .53792 L
.32532 .47252 L
.17217 .40712 L
.0956 .34172 L
.05731 .27632 L
.03817 .21092 L
.0286 .14552 L
.02381 .08012 L
.02381 .01472 L
s
.67947 .60332 m
.2296 .53792 L
.11474 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.68425 .60332 m
.67947 .53792 L
.2296 .47252 L
.11474 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.68904 .60332 m
.24874 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.69383 .60332 m
.45932 .53792 L
.2296 .47252 L
.11474 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.69861 .60332 m
.35403 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.7034 .60332 m
.59332 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.70818 .60332 m
.24874 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.71297 .60332 m
.55504 .53792 L
.24874 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.71776 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.72254 .60332 m
.42103 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.72733 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.73211 .60332 m
.72733 .53792 L
.3636 .47252 L
.13388 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.7369 .60332 m
.21046 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.74168 .60332 m
.7369 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.74647 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.75126 .60332 m
.47846 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.75604 .60332 m
.30617 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.76083 .60332 m
.59332 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.76561 .60332 m
.24874 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.7704 .60332 m
.76561 .53792 L
.24874 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.77519 .60332 m
.39232 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.77997 .60332 m
.51675 .53792 L
.24874 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.78476 .60332 m
.32532 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.78954 .60332 m
.65075 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.79433 .60332 m
.27746 .53792 L
.10517 .47252 L
.04774 .40712 L
.0286 .34172 L
.02381 .27632 L
.02381 .21092 L
s
.79911 .60332 m
.79433 .53792 L
.27746 .47252 L
.10517 .40712 L
.04774 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.8039 .60332 m
.40189 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.80869 .60332 m
.40189 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.81347 .60332 m
.41146 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.81826 .60332 m
.81347 .53792 L
.41146 .47252 L
.21046 .40712 L
.0956 .34172 L
.05731 .27632 L
.03817 .21092 L
.0286 .14552 L
.02381 .08012 L
.02381 .01472 L
s
.82304 .60332 m
.24874 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.82783 .60332 m
.76561 .53792 L
.24874 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.83262 .60332 m
.32532 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.8374 .60332 m
.53589 .53792 L
.19131 .47252 L
.07645 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.84219 .60332 m
.42103 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.84697 .60332 m
.84219 .53792 L
.42103 .47252 L
.13388 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.85176 .60332 m
.28703 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.85654 .60332 m
.59332 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.86133 .60332 m
.40189 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.86612 .60332 m
.57418 .53792 L
.28703 .47252 L
.13388 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.8709 .60332 m
.44018 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.87569 .60332 m
.8709 .53792 L
.44018 .47252 L
.21046 .40712 L
.0956 .34172 L
.05731 .27632 L
.03817 .21092 L
.0286 .14552 L
.02381 .08012 L
.02381 .01472 L
s
.88047 .60332 m
.24874 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.88526 .60332 m
.88047 .53792 L
.24874 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.89005 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.89483 .60332 m
.59332 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.89962 .60332 m
.44018 .53792 L
.21046 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.9044 .60332 m
.70818 .53792 L
.24874 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.90919 .60332 m
.30617 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.91397 .60332 m
.78476 .53792 L
.32532 .47252 L
.17217 .40712 L
.0956 .34172 L
.05731 .27632 L
.03817 .21092 L
.0286 .14552 L
.02381 .08012 L
.02381 .01472 L
s
.91876 .60332 m
.45932 .53792 L
.2296 .47252 L
.11474 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.92355 .60332 m
.53589 .53792 L
.19131 .47252 L
.07645 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.92833 .60332 m
.3636 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.93312 .60332 m
.92833 .53792 L
.3636 .47252 L
.13388 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.9379 .60332 m
.32532 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.94269 .60332 m
.9379 .53792 L
.32532 .47252 L
.17217 .40712 L
.0956 .34172 L
.05731 .27632 L
.03817 .21092 L
.0286 .14552 L
.02381 .08012 L
.02381 .01472 L
s
.94748 .60332 m
.47846 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.95226 .60332 m
.47846 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.95705 .60332 m
.42103 .53792 L
.13388 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.96183 .60332 m
.95705 .53792 L
.42103 .47252 L
.13388 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.96662 .60332 m
.30617 .53792 L
.0956 .47252 L
.05731 .40712 L
.03817 .34172 L
.0286 .27632 L
.02381 .21092 L
.02381 .14552 L
s
.9714 .60332 m
.96662 .53792 L
.30617 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
.97619 .60332 m
.40189 .53792 L
.17217 .47252 L
.0956 .40712 L
.05731 .34172 L
.03817 .27632 L
.0286 .21092 L
.02381 .14552 L
.02381 .08012 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005P0000fB000`400?l00000o`00003oo`3ooomQ
0?ooo`00o`3ooomQ0?ooo`00o`3ooomQ0?ooo`00o`3ooomQ0?ooo`00o`3ooomQ0?ooo`00203oool0
0`000000oooo0?ooo`3o0?oooeH0oooo00080?ooo`030000003oool0oooo0?l0ooooEP3oool000P0
oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeH0oooo
00080?ooo`030000003oool0oooo0?l0ooooEP3oool000P0oooo00<000000?ooo`3oool0o`3ooomF
0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeH0oooo00080?ooo`030000003oool0oooo0?l0
ooooEP3oool000P0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00203oool00`000000oooo0?oo
o`3o0?oooeH0oooo00080?ooo`030000003oool0oooo0?l0ooooEP3oool000P0oooo00<000000?oo
o`3oool0o`3ooomF0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeH0oooo00080?ooo`030000
003oool0oooo0?l0ooooEP3oool000P0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00203oool0
0`000000oooo0?ooo`3o0?oooeH0oooo00080?ooo`030000003oool0oooo0?l0ooooEP3oool000P0
oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeH0oooo
00080?ooo`030000003oool0oooo0?l0ooooEP3oool000P0oooo00<000000?ooo`3oool0o`3ooomF
0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeH0oooo00080?ooo`030000003oool0oooo0?l0
ooooEP3oool000P0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00203oool00`000000oooo0?oo
o`3o0?oooeH0oooo00080?ooo`030000003oool0oooo0?l0ooooEP3oool000P0oooo00<000000?oo
o`3oool0o`3ooomF0?ooo`00203oool00`000000oooo0?ooo`3o0?oooeH0oooo00080?ooo`030000
003oool0oooo0?l0ooooEP3oool000P0oooo0P00003o0?oooeL0oooo00080?ooo`800000o`3ooomG
0?ooo`00203oool200000?l0ooooE`3oool000P0oooo0P00003o0?oooeL0oooo00080?ooo`800000
o`3ooomG0?ooo`00203oool200000?l0ooooE`3oool000P0oooo0P00003o0?oooeL0oooo00080?oo
o`800000o`3ooomG0?ooo`00203oool200000?l0ooooE`3oool000P0oooo0P00003o0?oooeL0oooo
00080?ooo`800000o`3ooomG0?ooo`00203oool200000?l0ooooE`3oool000P0oooo00<000000?oo
o`000000o`3ooomF0?ooo`00203oool00`000000oooo0000003o0?oooeH0oooo00080?ooo`030000
003oool000000?l0ooooEP3oool000P0oooo00<000000?ooo`000000o`3ooomF0?ooo`00203oool0
0`000000oooo0000003o0?oooeH0oooo00080?ooo`030000003oool000000?l0ooooEP3oool000P0
oooo00<000000?ooo`000000o`3ooomF0?ooo`00203oool00`000000oooo0000003o0?oooeH0oooo
00080?ooo`030000003oool000000?l0ooooEP3oool000P0oooo00@000000?ooo`3oool00000o`3o
oomE0?ooo`00203oool010000000oooo0?ooo`00003o0?oooeD0oooo00080?ooo`80000000<0oooo
0000003oool0o`3ooomD0?ooo`00203oool2000000030?ooo`000000oooo0?l0ooooE03oool000P0
oooo0P0000000`3oool000000?ooo`3o0?oooe@0oooo00080?ooo`80000000<0oooo0000003oool0
o`3ooomD0?ooo`00203oool2000000030?ooo`000000oooo0?l0ooooE03oool000P0oooo0P000000
0`3oool000000?ooo`3o0?oooe@0oooo00080?ooo`8000000P3oool00`000000oooo0?ooo`3o0?oo
oe80oooo00080?ooo`8000000P3oool00`000000oooo0?ooo`3o0?oooe80oooo00080?ooo`800000
0P3oool00`000000oooo0?ooo`3o0?oooe80oooo00080?ooo`8000000P3oool00`000000oooo0?oo
o`3o0?oooe80oooo00080?ooo`8000000P3oool00`000000oooo0?ooo`3o0?oooe80oooo00080?oo
o`8000000P3oool00`000000oooo0?ooo`3o0?oooe80oooo00080?ooo`050000003oool000000?oo
o`000000o`3ooomD0?ooo`00203oool01@000000oooo0000003oool000000?l0ooooE03oool000P0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`3o0?oooe40oooo00080?ooo`030000
003oool000000080oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00203oool00`000000oooo0000
00020?ooo`030000003oool0oooo0?l0ooooD@3oool000P0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`3o0?oooe40oooo00080?ooo`030000003oool000000080oooo00<000000?oo
o`3oool0o`3ooomA0?ooo`00203oool00`000000oooo000000030?ooo`030000003oool0oooo0?l0
ooooD03oool000P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`3o0?oooe00oooo
00080?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooom@0?ooo`00203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0?l0ooooC`3oool000P0oooo0P00
00000`3oool000000?ooo`020?ooo`030000003oool0oooo0?l0ooooC`3oool000P0oooo0P000000
0`3oool000000?ooo`020?ooo`030000003oool0oooo0?l0ooooC`3oool000P0oooo0P0000000`3o
ool000000?ooo`020?ooo`030000003oool0oooo0?l0ooooC`3oool000P0oooo0P0000000`3oool0
00000?ooo`030?ooo`030000003oool0oooo0?l0ooooCP3oool000P0oooo0P0000000`3oool00000
0?ooo`030?ooo`030000003oool0oooo0?l0ooooCP3oool000P0oooo0P0000000`3oool000000?oo
o`030?ooo`030000003oool0oooo0?l0ooooCP3oool000P0oooo0P0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0o`3ooom=0?ooo`00203oool200000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?ooodd0oooo00080?ooo`8000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooC@3oool000P0oooo0P0000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00203oool200000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oood`0oooo00080?ooo`8000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooC03oool000P0oooo00D000000?oo
o`000000oooo000000050?ooo`030000003oool0oooo0?l0ooooC03oool000P0oooo00D000000?oo
o`000000oooo000000060?ooo`030000003oool0oooo0?l0ooooB`3oool000P0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooB`3oool000P0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0
ooooB`3oool000P0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?l0ooooBP3oool000P0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0ooooBP3oool000P0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooB@3oool000P0oooo00@000000?oo
o`00000000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooB@3oool0
00P0oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0?l0ooooB03oool000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0ooooB03oool000P0oooo00<000000?ooo`3oool00P0000020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom70?ooo`00203oool200000003
0?ooo`00000000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooodH0
oooo00080?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0?l0ooooAP3oool000P0oooo0P0000000`3oool00000000000020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3ooom50?ooo`00203oool2000000040?ooo`000000
oooo00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooodD0oooo0008
0?ooo`80000000@0oooo0000003oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?l0ooooA03oool000P0oooo0P000000103oool000000?ooo`0000020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooom30?ooo`00203oool200000080oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo@`3oool0
00P0oooo0P0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`3o0?oood80oooo00080?ooo`8000000P3oool00`000000oooo000000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00203oool200000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0
oooo@@3oool000P0oooo0P0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`3o0?oood00oooo00080?ooo`8000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooom00?ooo`00
203oool01@000000oooo0000003oool000000080oooo00@000000?ooo`3oool00000303oool00`00
0000oooo0?ooo`3o0?ooocl0oooo00080?ooo`050000003oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`00000<0?ooo`030000003oool0oooo0?l0oooo?P3oool000P0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3oooln0?ooo`00203oool00`000000oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooocd0oooo00080?oo
o`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00203oool00`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0?l0oooo?03oool000P0oooo00<000000?ooo`0000000P3oool2000000<0oooo00@000000?oo
o`3oool000003@3oool200000?l0oooo?03oool000P0oooo00@000000?ooo`00000000000P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool00000000000d0oooo0`00003o0?ooocX0oooo0008
0?ooo`040000003oool0000000000080oooo0P0000040?ooo`030000003oool0000000800000303o
ool010000000oooo00000000003o0?ooocP0oooo00080?ooo`040000003oool0oooo00000080oooo
0P0000040?ooo`060000003oool000000000003oool00000303oool2000000030?ooo`000000oooo
0?l0oooo=P3oool000P0oooo00<000000?ooo`3oool00P0000020?ooo`800000103oool01P000000
oooo000000000000oooo000000d0oooo00@000000?ooo`0000000000o`3ooole0?ooo`00203oool2
000000030?ooo`00000000000080oooo0`0000040?ooo`060000003oool000000000003oool00000
3@3oool00`000000oooo0?ooo`0200000?l0oooo<`3oool000P0oooo0P0000000`3oool000000000
00020?ooo`<000001@3oool2000000040?ooo`000000oooo000000d0oooo00@000000?ooo`3oool0
oooo0P00003o0?oooc40oooo00080?ooo`80000000<0oooo0000000000000P3oool010000000oooo
0000000000050?ooo`80000000@0oooo0000003oool000003@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?l0oooo;P3oool000P0oooo0P000000103oool000000?ooo`0000020?oo
o`<000001P3oool01@000000oooo0?ooo`000000oooo00800000303oool00`000000oooo0?ooo`02
0?ooo`800000o`3oool^0?ooo`00203oool2000000040?ooo`000000oooo00000080oooo00@00000
0?ooo`00000000001P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool200000?l0oooo;03oool000P0oooo0P000000103oool000000?oo
o`0000020?ooo`050000003oool000000?ooo`0000001P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00X0oooo0P0000050?ooo`800000o`3ooolZ0?ooo`00203oool200000080
oooo00<000000?ooo`0000000P3oool010000000oooo0000000000060?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0oooo9`3oool000P0oooo0P0000020?ooo`030000003oool000000080oooo00D000000?oo
o`000000oooo000000060?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`040?ooo`800000o`3ooolW0?ooo`00203oool200000080oooo00<00000
0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00@000000?ooo`3oool0
00000`3oool2000000`0oooo00<000000?ooo`3oool01@3oool200000?l0oooo9@3oool000P0oooo
0P0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`000000oooo000000060?oo
o`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?ooob80oooo00080?ooo`8000000P3oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000001P3oool200000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo0P00
003o0?ooob80oooo00080?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000001P3oool00`000000oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`800000o`3ooolP0?ooo`00
203oool01@000000oooo0000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo000000060?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo0P00003o0?oooah0oooo00080?ooo`05
0000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo0P00000:0?ooo`030000003oool0oooo0?l0oooo6`3oool000P0oooo00<00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000060?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool2000000`0
oooo00<000000?ooo`3oool0203oool200000?l0oooo6`3oool000P0oooo00<000000?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool000000080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo0P00003o0?oooaT0oooo00080?ooo`03
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo0P00003o0?oooaL0oooo
00080?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`80000000D0oooo00000000
0000oooo000000060?ooo`<000002P3oool2000000`0oooo0P00003o0?oooaD0oooo00080?ooo`03
0000003oool000000080oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00P0000050?ooo`P000001P3oool5000000P0oooo0P00000<0?ooo`@00000o`3ooolA0?oo
o`00203oool010000000oooo0000000000020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`00000000000`3oool00`000000oooo0?ooo`03000000@0oooo2@0000060?ooo`L000001P3oool2
000000d0oooo1000003o0?ooo`h0oooo00080?ooo`040000003oool0000000000080oooo0P000004
0?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`04000000<0oooo00<00000
0?ooo`0000001`0000060?ooo`X000000`3oool3000000d0oooo1@00003o0?ooo`X0oooo00080?oo
o`040000003oool0oooo00000080oooo0P0000040?ooo`080000003oool000000000003oool00000
0?ooo`0000040?ooo`030000003oool0000000<0oooo0P0000000`3oool000000?ooo`0200000004
0?ooo`0000000000000000H0oooo0`0000020?ooo`L000000P3oool2000000h0oooo1@00003o0?oo
o`L0oooo00080?ooo`030000003oool0oooo008000000P3oool2000000@0oooo00P000000?ooo`00
000000000?ooo`000000oooo000000@0oooo00@000000?ooo`00000000000`3oool01@000000oooo
000000000000oooo008000000P3oool3000000D0oooo0`0000030?ooo`X000003`3oool600000?l0
oooo0`3oool000P0oooo0P0000000`3oool00000000000020?ooo`<00000103oool020000000oooo
000000000000oooo0000003oool00000103oool00`000000oooo0?ooo`0200000080oooo00<00000
0?ooo`3oool00P000000103oool000000000003oool5000000@0oooo100000040?ooo`<000000P3o
ool4000000l0oooo1P00003o0?ooo`00203oool2000000030?ooo`00000000000080oooo0`000005
0?ooo`80000000H0oooo0000003oool000000?ooo`0000040?ooo`040000003oool0oooo0?ooo`80
000000<0oooo0000003oool00P3oool2000000030?ooo`000000000000L000000`3oool4000000D0
oooo100000020?ooo`@000003P3oool700000?/0oooo00080?ooo`80000000<0oooo000000000000
0P3oool010000000oooo0000000000050?ooo`80000000H0oooo0000003oool000000?ooo`000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool010000000oooo0?ooo`3o
ool4000000030?ooo`0000000000008000000P3oool4000000L0oooo0`0000000`3oool000000000
0005000000`0oooo0`000000103oool0000000000000003h0?ooo`00203oool2000000040?ooo`00
0000oooo00000080oooo0`0000060?ooo`050000003oool0oooo0000003oool00`0000040?ooo`80
00000`3oool3000000@0oooo0P0000030?ooo`<000000`3oool:000000L0oooo1P0000020?ooo`@0
00002`3oool3000000030?ooo`000000000000800000m03oool000P0oooo0P000000103oool00000
0?ooo`0000020?ooo`040000003oool00000000000H0oooo00@000000?ooo`3oool000000P3oool2
000000D0oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P0000030?ooo`<000000`3oool7
000000030?ooo`000000000000T0oooo100000040?ooo`D000002@3oool300000080oooo0`00003a
0?ooo`00203oool2000000040?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo0000
00060?ooo`040000003oool0oooo00000080oooo0P0000050?ooo`030000003oool0oooo00<0oooo
0P0000050?ooo`800000103oool2000000@0oooo1P000000103oool000000000000000090?ooo`@0
00001P3oool4000000P0oooo100000000`3oool000000000000200000>d0oooo00080?ooo`800000
0P3oool00`000000oooo000000020?ooo`040000003oool00000000000H0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`8000001@3oool2000000050?ooo`0000000000
0000003oool00P00000;0?ooo`<000001`3oool4000000P0oooo0`0000020?ooo`<00000jP3oool0
00P0oooo0P0000020?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo00000006
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`8000001@3oool2000000D0oooo0`0000040?ooo`T000002`3oool4000000P0oooo1@00
00060?ooo`<000000P3oool300000>L0oooo00080?ooo`8000000P3oool00`000000oooo00000002
0?ooo`060000003oool0oooo0000003oool000001P3oool010000000oooo0?ooo`0000030?ooo`80
00001@3oool2000000D0oooo0`0000050?ooo`8000001@3oool3000000D0oooo2@00000:0?ooo`H0
00002@3oool4000000D0oooo0`0000020?ooo`@00000h`3oool000P0oooo0P0000020?ooo`040000
003oool0oooo00000080oooo00D000000?ooo`000000oooo000000060?ooo`8000000P3oool01000
0000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000006
0?ooo`030000003oool0oooo00<0oooo100000050?ooo`@000000P3oool3000000/0oooo0P000000
103oool0000000000000000:0?ooo`D000000`3oool3000000<0oooo0`00003P0?ooo`00203oool2
00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000H0
oooo0P0000020?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo0?ooo`030?oo
o`040000003oool00000000000D0oooo0P0000050?ooo`D000001@3oool3000000<0oooo0`00000:
0?ooo`8000000P3oool4000000/0oooo100000020?ooo`<000000`3oool400000=`0oooo00080?oo
o`8000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool00000
1P3oool00`000000oooo000000020?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo008000001@3oool2000000D0oooo0P0000000`3oool0
0000000000060?ooo`8000000`3oool4000000T0oooo0`0000030?ooo`<00000303oool400000004
0?ooo`0000000000000000@0oooo0`00003I0?ooo`00203oool01@000000oooo0000003oool00000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000060?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool0oooo0P0000050?ooo`8000001@3oool00`000000oooo0?ooo`02000000H0oooo
0`0000030?ooo`@000002@3oool2000000@0oooo1000000<0?ooo`L00000103oool400000=D0oooo
00080?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`3oool2
000000H0oooo00<000000?ooo`3oool00`3oool2000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`8000000P3oool2000000H0oooo0`0000030?ooo`D00000203oool2
000000H0oooo0`00000>0?ooo`D000001@3oool300000=80oooo00080?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
1P3oool00`000000oooo000000020?ooo`060000003oool0oooo0?ooo`000000oooo0P0000050?oo
o`8000001@3oool010000000oooo0?ooo`3oool2000000D0oooo0P0000050?ooo`8000000P3oool3
000000D0oooo100000020?ooo`L000001P3oool3000000H0oooo1000000>0?ooo`D00000103oool4
00000<h0oooo00080?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P0000050?ooo`800000
0`3oool2000000D0oooo1@0000020?ooo`8000000P3oool3000000H0oooo0P0000080?ooo`<00000
3`3oool5000000@0oooo0`00003;0?ooo`00203oool00`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool01000
0000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool2000000D0oooo0P00
00050?ooo`8000000`3oool2000000D0oooo0P0000000`3oool00000000000020?ooo`8000000`3o
ool3000000D0oooo0P0000090?ooo`@000003P3oool6000000<0oooo100000370?ooo`00203oool0
0`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo0P0000050?ooo`80000000@0oooo000000000000oooo0P0000020?ooo`03
0000003oool0oooo00<00000103oool2000000@0oooo100000030?ooo`@000000`3oool500000080
oooo100000000`3oool000000000000@00000080oooo3@0000070?ooo`H000002`3oool?00000<80
oooo00080?ooo`030000003oool000000080oooo0P0000030?ooo`030000003oool0oooo00800000
0P3oool00`000000oooo0?ooo`03000000@0oooo300000020?ooo`D000000P3oool2000000@0oooo
<00000030?oooa00000000<0oooo0000000000002@0000070?oooa400000^`3oool000P0oooo00@0
00000?ooo`00000000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<00000
00@0oooo0000003oool0oooo100000030?ooo`T0000000@0oooo00000000000000000P3oool90000
00@0oooo=P0000050?oooa/00000103ooolB00000;@0oooo00080?ooo`040000003oool000000000
0080oooo0P0000040?ooo`030000003oool0000000<0000000<0oooo0000003oool00P3oool40000
0080oooo2P0000020?ooo`l000000`3oool2000000030?ooo`000000000003H000000P3ooolE0000
00030?ooo`000000000000L000000P3ooolB00000:d0oooo00080?ooo`040000003oool0oooo0000
0080oooo0`0000040?ooo`030000003oool0000000D000000`3oool00`000000oooo000000030000
00030?ooo`000000oooo00@0000000<0oooo0000000000000P0000000`3oool00000000000060000
00030?ooo`000000000000H0000000D0oooo00000000000000000?ooo`04000000030?ooo`000000
00000180000000<0oooo0000000000009P0000000`3oool000000000000@000000030?ooo`000000
000001X00000Y@3oool000P0oooo00<000000?ooo`3oool00P0000020?ooo`8000001@3oool20000
00040?ooo`00000000000?ooo`8000000`3oool00`000000oooo0?ooo`0500000080oooo1@000000
0`3oool0000000000004000000030?ooo`000000000000<000000P3oool;000000<0oooo10000002
0?oooaH0000000<0oooo0000000000009@0000020?oooc000000W@3oool000P0oooo0P0000000`3o
ool00000000000020?ooo`<00000103oool01`000000oooo000000000000oooo0000003oool00P00
00030?ooo`060000003oool0oooo0?ooo`000000oooo0P0000030?ooo`030000003oool0oooo0080
000000<0oooo0000000000000`0000030?ooo`@00000103oool:000000@0oooo0`0000040?ooocD0
00000P3oool:00000080oooo2P0000000`3oool000000000000T000009@0oooo00080?ooo`800000
00<0oooo0000000000000P3oool00`000000oooo000000050?ooo`80000000<0oooo0000003oool0
1@0000020?ooo`8000000P3oool2000000050?ooo`00000000000000003oool00P0000020?ooo`@0
000000<0oooo0000000000000P0000020?ooo`H000000P3oool=00000080oooo100000040?ooo`X0
000000<0oooo0000000000005P0000000`3oool000000000000C000000030?ooo`000000000001<0
00001@3ooolT000008`0oooo00080?ooo`80000000@0oooo0000003oool000000P3oool3000000D0
oooo0P000000103oool000000?ooo`3oool2000000030?ooo`00000000000080oooo00@000000?oo
o`3oool0oooo1P0000000`3oool00000000000030?ooo`<000000P3oool5000000030?ooo`000000
000000@000000P3oool6000000030?ooo`000000000000H0000000<0oooo0000000000000P000005
0?ooo`T000000`3ooolI000000030?ooo`000000000002P000002P3ooolB000000030?ooo`000000
000000d00000P`3oool000P0oooo0P000000103oool000000?ooo`0000020?ooo`040000003oool0
0000000000D0oooo0P000000103oool000000?ooo`3oool200000080oooo00@000000?ooo`3oool0
0000103oool3000000040?ooo`00000000000?ooo`8000000`3oool300000080oooo400000000`3o
ool000000000000<000000040?ooo`0000000000000000L0oooo2@0000000`3oool0000000000016
000000d0oooo5`0000000`3oool0000000000006000007/0oooo00080?ooo`80000000@0oooo0000
003oool000000P3oool010000000oooo0000000000060?ooo`040000003oool0oooo00000080oooo
0P0000020?ooo`80000000<0oooo0000003oool0103oool200000080oooo0P0000000`3oool00000
000000030?ooo`<000000P3oool8000000040?ooo`00000000000?ooo`@000000`3oool500000003
0?ooo`000000000000X000001P3ooolK000000030?ooo`000000000000D0000000<0oooo00000000
00005@0000020?ooo`P000000P3ooolA000000`0oooo5P0000020?ooo`T00000LP3oool000P0oooo
0P0000020?ooo`030000003oool000000080oooo00@000000?ooo`00000000001P3oool010000000
oooo0?ooo`0000020?ooo`8000000`3oool4000000D0oooo00@000000?ooo`3oool0oooo10000005
0?ooo`8000000P3oool00`000000oooo00000009000000030?ooo`0000000000008000000`3oool5
00000080oooo100000000`3oool0000000000005000000D0oooo0`0000000`3oool000000000000P
00000080oooo8P0000020?oooa@00000203ooolE000000D0oooo2000001Z0?ooo`00203oool20000
0080oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool2000000@0oooo0`00
00050?ooo`D000000P3oool9000000<0oooo0`0000040?ooo`D000000P3oool4000000030?ooo`00
0000000000D00000103oool300000080oooo9@0000000`3oool000000000000R00000080oooo5P00
00040?oooaH000001P3oool900000640oooo00080?ooo`8000000P3oool00`000000oooo00000002
0?ooo`030000003oool0oooo008000001P3oool200000080oooo00D000000?ooo`3oool0oooo0000
00050?ooo`8000001@3oool3000000@0oooo0`0000050?ooo`D000000`3oool900000080oooo1@00
00030?ooo`H000000P3oool400000080oooo1@0000040?ooo`<000000`3ooolj000000030?ooo`00
0000000000P0000000<0oooo0000000000001`0000000`3oool000000000000;000000030?ooo`00
0000000000P0000000<0oooo000000000000100000000`3oool000000000000@000000D0oooo2000
001I0?ooo`00203oool200000080oooo00<000000?ooo`0000000P3oool01P000000oooo0?ooo`00
0000oooo000000H0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000D0
oooo100000040?ooo`<000001@3oool5000000<0oooo100000000`3oool000000000000200000080
oooo0P000000103oool000000000000000030?ooo`H000000`3oool400000080oooo1@0000030?oo
o`@000000`3oool@00000080oooo4@0000000`3oool000000000000500000080oooo400000000`3o
ool0000000000008000000<0oooo5P0000030?ooo`d000000P3oool6000000030?ooo`0000000000
00`000000`3oool900000500oooo00080?ooo`8000000P3oool010000000oooo0?ooo`0000020?oo
o`060000003oool0oooo0000003oool000001P3oool200000080oooo00@000000?ooo`3oool0oooo
0P0000050?ooo`8000001@3oool010000000oooo0000000000040?ooo`<000001@3oool5000000@0
oooo100000020?ooo`<0000000D0oooo00000000000000000?ooo`04000000030?ooo`0000000000
00H000000`3oool500000080oooo1@0000020?ooo`<000000`3oool4000000030?ooo`0000000000
00/000000P3ooolB00000080oooo1`0000020?oooa0000000P3oool:000000<0oooo5@0000060?oo
o`X0000000<0oooo0000000000001@0000020?oooa40000000<0oooo0000000000001P0000180?oo
o`00203oool200000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000
oooo000000H0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`3oool2000000H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000D0oooo0P0000040?ooo`800000
00@0oooo00000000000000001@3oool3000000<0oooo0`0000000`3oool00000000000030?ooo`<0
000000@0oooo000000000000oooo1P0000040?ooo`@000000P3oool5000000040?ooo`0000000000
000000@0oooo100000020?ooo`D000000P3oool6000000<0oooo2@0000020?oooa4000000P3oool8
000000030?ooo`000000000000D0000000<0oooo0000000000002`0000020?ooo`T0000000<0oooo
000000000000200000090?ooo`l000000P3ooolL000003l0oooo00080?ooo`050000003oool00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000H0oooo0P00
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`800000103oool01@000000
oooo0?ooo`3oool0000000H0oooo0P0000040?ooo`80000000@0oooo00000000000000001P3oool2
000000<0oooo1P0000040?ooo`D000000P3oool6000000D0oooo100000000`3oool0000000000007
000000D0oooo0`0000040?ooo`@000000`3oool5000000@0oooo2P0000000`3oool000000000000A
00000080oooo1`0000020?oooaH000000P3oool800000080oooo2P0000070?ooo`l000000`3oool7
000000030?ooo`000000000001<00000=`3oool000P0oooo00D000000?ooo`000000oooo00000003
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000001P3oool00`000000oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`<000000`3oool010000000
oooo0?ooo`3oool2000000D0oooo100000030?ooo`80000000@0oooo00000000000000001P3oool3
00000080oooo1`0000050?ooo`@000000`3oool6000000D0oooo100000000`3oool0000000000006
000000D0oooo100000030?ooo`H000000`3oool600000080oooo600000020?ooo`H000000`3oool7
00000080oooo8P0000000`3oool0000000000007000000L0oooo1P0000000`3oool0000000000008
000000030?ooo`000000000000@00000103ooolE000002h0oooo00080?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
1P3oool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?oo
o`030000003oool0000000<0oooo0P0000030?ooo`8000001@3oool4000000<0oooo0P000000103o
ool000000000000000060?ooo`@000000P3oool2000000040?ooo`0000000000000000H0oooo1000
00030?ooo`H000001P3oool4000000030?ooo`000000000000H000001@3oool3000000@0oooo1`00
00030?ooo`H000000P3oool@00000080oooo1`0000020?ooo`L000000`3oool7000000<0oooo2000
00000`3oool000000000000G00000080oooo200000050?ooo`H000000`3oool@000000H0oooo5000
000V0?ooo`00203oool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
0P3oool01P000000oooo0?ooo`3oool000000?ooo`8000001@3oool4000000<0oooo00<000000?oo
o`3oool00P3oool2000000D0oooo100000030?ooo`80000000<0oooo0000000000000P0000050?oo
o`@000000P3oool3000000030?ooo`0000000000008000001@3oool4000000@0oooo1P0000060?oo
o`P0000000<0oooo0000000000000`0000030?ooo`@000000`3oool900000080oooo1`0000000`3o
ool000000000000?00000080oooo200000030?ooo`L000000P3oool8000000<0oooo1`0000020?oo
oa40000000<0oooo0000000000001P0000000`3oool0000000000007000000<0oooo1`0000030?oo
oa000000203ooolE000001`0oooo00080?ooo`030000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`040000003o
ool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool40000
00<0oooo0P0000000`3oool0000000000002000000D0oooo1@0000020?ooo`80000000<0oooo0000
000000000`0000050?ooo`D000000`3oool7000000H0oooo3P0000030?ooo`@000000`3oool40000
00030?ooo`000000000000<000000P3ooolI00000080oooo2P0000030?ooo`L0000000<0oooo0000
000000001`0000020?ooo`P000000`3oool7000000030?ooo`000000000000H000000P3oool80000
00030?ooo`000000000000L000000P3oool6000000<0oooo1`0000020?ooo`X00000203ooolF0000
0180oooo00080?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool2000000D0oooo0P000000103oool000000000003o
ool200000080oooo00<000000?ooo`3oool00`0000040?ooo`80000000@0oooo000000000000oooo
100000030?ooo`@000000`3oool6000000030?ooo`000000000000T0000000<0oooo000000000000
6@0000030?ooo`T00000103ooolF00000080oooo1@0000000`3oool0000000000007000000030?oo
o`000000000000L0000000<0oooo000000000000100000000`3oool000000000000200000080oooo
1@0000000`3oool0000000000004000000@0oooo100000030?ooo`P000000`3oool6000000H0oooo
1@0000030?ooo`H000001@3oool5000000<0oooo1`0000030?ooo`@000001P3oool4000000H0oooo
2000000;0?ooo`T0000000<0oooo0000000000001`00000<0?ooo`00203oool00`000000oooo0000
00020?ooo`8000000P3oool200000080oooo0P000000103oool000000000003oool4000000<0oooo
3@0000000`3oool0000000000005000000040?ooo`00000000000?oooe40000000<0oooo00000000
0000900000050?ooo`l000001@3oool4000000030?ooo`000000000000@000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P0000030?ooo`040000003oool0oooo0000
00/0oooo0`0000020?ooo`040000003oool0oooo000000T0oooo0P0000060?ooo`<000001P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000`0
oooo00080?ooo`050000003oool000000000003oool00P0000020?ooo`<0000000<0oooo00000000
00000P0000000`3oool0000000000005000000030?ooo`000000oooo01P0000000<0oooo00000000
0000O00000000`3oool0000000000004000000030?ooo`000000000000H000001@3oool<000000D0
oooo00<000000?ooo`3oool0103oool2000000050?ooo`000000oooo0?ooo`0000003P3oool30000
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo000000070?ooo`8000001@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000`0oooo
00080?ooo`050000003oool000000000003oool00`0000000`3oool0000000000002000000030?oo
o`00000000000080000000<0oooo0000003oool01P0000020?ooo`/0000000<0oooo000000000000
T@0000040?ooo`T00000103oool4000000030?ooo`000000000000H00000203oool200000080oooo
00<000000?ooo`3oool03P3oool4000000T0oooo00@000000?ooo`3oool000001P3oool010000000
oooo0000000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool01@00
0000oooo0?ooo`3oool0000000l0oooo00D000000?ooo`3oool0oooo000000050?ooo`050000003o
ool0oooo0?ooo`000000303oool000P0oooo00D000000?ooo`00000000000?ooo`03000000030?oo
o`00000000000080000000<0oooo000000000000100000020?ooo`<0000000<0oooo000000000000
2@0000000`3oool000000000000:000000030?ooo`000000000000/0000000D0oooo000000000000
00000?ooo`1l000000<0oooo300000000`3oool0000000000003000000030?ooo`000000000000@0
00001P3oool400000100oooo00<000000?ooo`3oool0100000060?ooo`050000003oool0oooo0?oo
o`0000001@3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00P0oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000l0oooo00D000000?ooo`3oool0oooo
000000050?ooo`050000003oool0oooo0?ooo`000000303oool000P0oooo00<000000?ooo`000000
0`0000000`3oool0000000000002000000040?ooo`00000000000?ooo`80000000L0oooo00000000
000000000?ooo`000000oooo00L0000000<0oooo0000000000001@0000020?ooo`/000000`3ooonG
000000030?ooo`000000000000T0000000<0oooo0000000000001@000000103oool000000?ooo`3o
ool2000000l0oooo00@000000?ooo`3oool000000`3oool3000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`030000
003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`050000003oool0oooo0?oo
o`0000001@3oool01@000000oooo0?ooo`3oool0000000`0oooo00080?ooo`80000000@0oooo0000
00000000oooo1@0000000`3oool000000?ooo`04000000030?ooo`000000000000<0000000<0oooo
0000000000000P3oool6000000030?ooo`000000000000<0000000<0oooo0000000000001@000000
0`3oool0000000000003000000<0ooooVP0000000`3oool000000000000?000000040?ooo`000000
0000000000h0oooo00@000000?ooo`3oool000001@3oool3000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`800000203oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo00000100oooo00@000000?ooo`3oool000001P3oool01000
0000oooo0?ooo`00000<0?ooo`00203oool2000000040?ooo`00000000000?ooo`@0000000D0oooo
0000003oool000000?ooo`02000000050?ooo`000000oooo0000003oool00`0000000`3oool00000
000000020?ooo`<0000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000P0
00000P3oool500000080oooo5@0000020?ooog/0000000<0oooo0000000000001P0000020?oooa<0
0000303oool010000000oooo0?ooo`0000080?ooo`<00000103oool01@000000oooo0?ooo`3oool0
000000H0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo00000100oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`00000<0?oo
o`00203oool2000000040?ooo`00000000000?ooo`80000000@0oooo00000000000000000P3oool0
1@000000oooo000000000000oooo00<0000000<0oooo00000000000010000000103oool000000?oo
o`3oool500000080oooo0P0000020?ooo`T000000P3oool600000080oooo5@0000020?ooo``00000
00<0oooo0000000000005`0000000`3oool000000000001O000000<0oooo3`0000080?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0000
00H0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`3oool00000403oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo000000`0
oooo00080?ooo`80000000<0oooo0000003oool00P0000000`3oool000000000000200000080oooo
00@000000?ooo`00000000000P3oool00`000000oooo00000008000000<0oooo0`000000103oool0
00000000003oool2000000<0oooo5@0000000`3oool000000000000E000000030?ooo`0000000000
00L000000P3ooomR000000030?ooo`000000000001T000000P3oool=000000@0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`020?ooo`@0000000<0oooo0000003oool01@3oool0
0`000000oooo0?ooo`030?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo00000100oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`00000<0?ooo`00
203oool2000000030?ooo`000000oooo0080000000<0oooo0000000000000P0000030?ooo`@00000
00<0oooo0000000000000P3oool3000000030?ooo`000000000000800000103oool2000000030?oo
o`000000000000@0000000<0oooo0000000000000`0000020?ooo`P0000000<0oooo000000000000
1@0000000`3oool000000000000E00000080oooo2`0000000`3oool000000000000e000000030?oo
o`000000000004h0000000<0oooo0000000000000`0000020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01@3oool3000000H0oooo00<000000?ooo`3oool01@3oool3000000T0oooo
00@000000?ooo`3oool00000403oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo
000000`0oooo00080?ooo`80000000<0oooo0000003oool00P0000000`3oool00000000000030000
0080oooo0P0000001P3oool00000000000000000oooo00000080oooo0P0000020?ooo`80000000<0
oooo0000003oool00P3oool00`000000oooo00000008000000030?ooo`000000oooo00<000000P3o
ool8000000030?ooo`000000000000H000000P3oool;000000030?ooo`000000000000P0000000<0
oooo0000000000009@0000000`3oool000000000000F000000030?ooo`000000000004H0000000<0
oooo0000000000004@0000070?ooo`030000003oool0oooo00L0oooo100000030?ooo`030000003o
ool0oooo00L0oooo0P0000080?ooo`040000003oool0oooo00000100oooo00@000000?ooo`3oool0
00001P3oool010000000oooo0?ooo`00000<0?ooo`00203oool2000000050?ooo`00000000000?oo
o`0000000P3oool4000000<0oooo1@0000000`3oool000000?ooo`020?ooo`8000000P3oool40000
00<0oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`00000000000080000000<0oooo
0000003oool00`0000020?ooo`D0000000D0oooo00000000000000000?ooo`07000000030?ooo`00
0000oooo00`0000000<0oooo0000000000002@000000103oool000000000000000020?ooo`@00000
00<0oooo000000000000700000020?oooc/0000000<0oooo000000000000=00000030?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool0oooo100000090?ooo`040000003oool000000000
00H0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`050000003oool0oooo0?ooo`0000001@3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00080?ooo`80000000D0oooo000000000000oooo
000000020?ooo`D000000P3oool2000000030?ooo`00000000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool00000008000000P3oool010000000oooo0?ooo`3oool40000
0080oooo100000020?ooo`030000003oool0000000l000000`3oool4000000030?ooo`0000000000
00L0000000<0oooo0000000000000P0000000`3oool000000000000<00000080ooooV@0000080?oo
o`8000001@3oool3000000L0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`050000003oool0
oooo0?ooo`0000003`3oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`00203oool2000000050?ooo`00000000000?ooo`0000000P3oool200000004
0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0oooo
00@000000P3oool6000000<0oooo100000000`3oool000000?ooo`0300000080oooo00<000000?oo
o`3oool04@0000020?ooo`l000000P3oool;000000030?ooo`000000000000@000000P3ooolA0000
00030?ooo`000000000004/0000000<0oooo000000000000>00000040?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool00`0000040?ooo`030000003oool0oooo00<0oooo0P0000020?oo
o`050000003oool0oooo0?ooo`0000003`3oool01@000000oooo0?ooo`3oool0000000D0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`00203oool2000000040?ooo`00000000000?ooo`800000
0P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`0000020?ooo`04
0000003oool000000?ooo`8000000`3oool00`000000oooo00000003000000<0oooo00<000000?oo
o`0000000P0000020?ooo`<000000P3oool00`000000oooo0?ooo`0500000080oooo1P0000020?oo
o`<0000000D0oooo00000000000000000?ooo`05000000030?ooo`000000000000D000000`3oool;
000000030?ooo`000000000000<000000P3ooolB000000030?ooo`000000000000l000000`3ooolT
00000080ooooC`0000020?ooo`050000003oool0oooo0?ooo`0000001@3oool3000000030?ooo`00
0000oooo00H0oooo0`0000030?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo
000000050?ooo`050000003oool0oooo0?ooo`0000002`3oool000P0oooo0P000000103oool00000
0000003oool200000080oooo00L000000?ooo`00000000000?ooo`000000oooo0080000000<0oooo
0000003oool00P0000020?ooo`80000000@0oooo00000000000000000`3oool00`000000oooo0000
0002000000@0oooo00@000000?ooo`00000000000P3oool00`000000oooo00000002000000030?oo
o`000000oooo0080oooo1@0000020?ooo`80000000L0oooo00000000000000000?ooo`000000oooo
00<0000000@0oooo000000000000oooo1@0000000`3oool0000000000007000000030?ooo`000000
000000/000000P3oool:000000030?ooo`000000000000d0000000<0oooo00000000000040000002
0?ooo`P0000000<0oooo000000000000K00000070?ooo`<00000203oool200000080oooo00<00000
0?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`00203oool2000000040?ooo`00000000000?ooo`8000000P3oool02@000000oooo
0?ooo`000000oooo0000003oool000000?ooo`04000000050?ooo`000000oooo0?ooo`0000000P3o
ool3000000<0oooo0P0000000`3oool00000000000040?ooo`030000003oool0000000<0000000<0
oooo0000000000001@0000000`3oool000000?ooo`02000000050?ooo`00000000000000003oool0
0P0000020?ooo`d0000000<0oooo0000000000001@0000000`3oool0000000000005000000030?oo
o`000000000000/0000000<0oooo000000000000200000030?ooo`h000000P3ooomG000000030?oo
o`000000000003<0000000<0oooo0000003oool00`0000050?ooo`030000003oool0000000800000
3`3oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`00203oool01@000000oooo0000003oool000000080oooo00@000000?ooo`3oool000000P3oool2
0000000<0?ooo`00000000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0P000002
0?ooo`<000000`3oool00`000000oooo00000002000000@0oooo0P0000002@3oool0000000000000
0000oooo0000003oool000000?ooo`03000000060?ooo`000000oooo0?ooo`000000oooo0`000002
0?ooo`<0000000<0oooo0000000000000P0000020?ooo`P000000P3oool500000080oooo1P000000
103oool000000?ooo`3oool?000000030?ooo`000000000000H0000000<0oooo0000000000003000
00000`3oool000000000002B000000<0oooo00<000000?ooo`3oool00P00000?0?ooo`040000003o
ool0oooo000000H0oooo00@000000?ooo`3oool000002`3oool000P0oooo00D000000?ooo`000000
oooo000000020?ooo`80000000@0oooo000000000000oooo0P0000020?ooo`030000003oool0oooo
00<0000000<0oooo0000003oool00P0000001@3oool000000?ooo`000000oooo008000000P3oool3
000000040?ooo`0000000000000000<0oooo0P000000203oool00000000000000000oooo0000003o
ool000000P3oool3000000<0oooo1`0000020?ooo`80000000@0oooo00000000000000000`3oool6
000000@0oooo1P0000020?ooo`L000000`3oool6000000030?ooo`000000000000H0000000<0oooo
0000000000001@0000000`3oool0000000000007000000030?ooo`0000000000038000000P3ooolS
000000030?ooo`000000000004D000003@3oool010000000oooo0?ooo`0000060?ooo`040000003o
ool0oooo000000/0oooo00080?ooo`040000003oool000000?ooo`80000000@0oooo000000000000
oooo0P0000001P3oool000000?ooo`000000oooo00000080oooo0`0000000`3oool000000?ooo`02
000000030?ooo`000000oooo00<0000000D0oooo00000000000000000?ooo`02000000040?ooo`00
0000000000000080oooo00@000000?ooo`000000oooo1@000000103oool000000000003oool40000
00<0oooo1`0000020?ooo`L000000P3oool7000000<0oooo1`0000020?ooo`P000000P3ooolJ0000
00030?ooo`000000000000l0000000<0oooo000000000000V00000060?ooo`040000003oool0oooo
000000H0oooo00@000000?ooo`3oool000002`3oool000P0oooo00@000000?ooo`000000oooo0P00
0000103oool000000000003oool200000080oooo0P0000000`3oool00000000000020?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`80000000<0oooo0000000000000P3oool01000
0000oooo0?ooo`0000020?ooo`D000000P3oool700000080oooo00<000000?ooo`00000010000000
0`3oool000000?ooo`0700000080oooo200000020?ooo`80000000<0oooo0000000000000P000003
0?ooo`H0000000<0oooo0000000000001`0000030?ooo`/0000000<0oooo0000000000000`000000
0`3oool000000000000600000080oooo;P0000000`3oool0000000000007000000030?ooo`000000
000001X0000000<0oooo0000000000001P0000000`3oool000000000001?000000030?ooo`000000
oooo00D0oooo00@000000?ooo`3oool000002`3oool000P0oooo00@000000?ooo`000000oooo0P00
00000`3oool000000?ooo`02000000050?ooo`000000oooo0000003oool00`0000020?ooo`060000
003oool000000?ooo`000000oooo0P0000020?ooo`060000003oool000000?ooo`000000oooo0P00
00020?ooo`060000003oool000000?ooo`000000oooo0P0000020?ooo`040000003oool000000?oo
o`@0000000@0oooo000000000000oooo1@0000030?ooo`P0000000<0oooo0000000000000`000000
1@3oool00000000000000000oooo00T0000000<0oooo0000000000001P0000020?ooom`000000P3o
ool00`000000oooo0?ooo`090?ooo`00203oool010000000oooo0000003oool2000000030?ooo`00
0000oooo0080000000D0oooo0000003oool000000?ooo`02000000030?ooo`000000oooo00800000
00<0oooo0000003oool00P0000000`3oool000000?ooo`02000000030?ooo`000000oooo00800000
00<0oooo0000003oool00P0000000`3oool000000?ooo`02000000030?ooo`000000oooo00800000
00<0oooo0000003oool00P0000000`3oool000000?ooo`02000000030?ooo`000000oooo00@00000
00<0oooo0000003oool00P0000000`3oool000000?ooo`02000000030?ooo`000000000000@00000
00@0oooo000000000000oooo1P000000103oool000000000003oool6000000040?ooo`0000000000
0?ooo`H0000000@0oooo000000000000oooo1P0000000`3oool0000000000004000000040?ooo`00
000000000?ooo`T0000000<0oooo0000000000001`0000000`3oool0000000000007000000030?oo
o`000000000000L0000000<0oooo000000000000A`0000000`3oool0000000000007000000030?oo
o`000000000004L000002@3oool00?l0ooooH@3oool00?l0ooooH@3oool00?l0ooooH@3oool00?l0
ooooH@3oool00?l0ooooH@3oool00001\
\>"],
  ImageRangeCache->{{{0, 351.5}, {216.5, 0}} -> {-4.33197, -10.225, 0.745605, \
0.0545614}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fermat's little theorem", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["If[GCD[a,b]===1,Mod[a^EulerPhi[b],b]==1]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Generalized Fermat's little theorem (T. Klove 76), k is a positive \
integer:\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
If[ GCD[a^k,b]===1 && GCD[a^(k+1),b]===1,
    Mod[a^(EulerPhi[b]+k),b]==Mod[a^k,b] ]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Asymptotics", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sum[EulerPhi[i],{i,n}] ---> 3 n^2/Pi^2 + O[ n Log[n] ]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sum[EulerPhi[i]/i,{i,n}] ---> 6 n/Pi^2 +O[Log[n]]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Sum[1/EulerPhi[i],{i,n}] --->
         Zeta[2] Zeta[3]/Zeta[6] Log[n] + const +O[Log[n]/n]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["With the exceptions of n=2 and n=6 we have:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sqrt[n] <= EulerPhi[n] <= (n-1)", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Associated Functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Jordan's J function, Sternecks H function", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
C. Jordan (1870) introduced the function J_k(n) which gives the \
number of different sets of k (equal or distinct) positive integers <=n, all \
of whose gcd is prime to n. 
R. D. von Sterneck proposed 1902 a function which can be shown to be \
equaivalent to Jordans fuction. von Sternecks function is defined as the sum \
of the products of EulerPhi applied to all factors of the set of k positive \
integers which least common multiply is n. (E. Cohen introduced 1949 a \
function which is also equivalent to Jordan's function.)

This definition can be rewritten in the following form:\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["JordanJ[k_,n_] := n^k PrimeFactorProduct[1-1/p^k,p,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["If k=1 we are back to the EulerPhi function:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["JordanJ[1,n] == EulerPhi[n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["The JordanJ function is also a multiplicative function:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
If[GCD[n,m]==1,
  JordanJ[k,n m] == JordanJ[k,n] JordanJ[k,m]]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
JordanJ[k,n m] == JordanJ[k,n] JordanJ[k,m] GCD[n,m]^k/
                  JordanJ[k,GCD[n,m]]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["The JordanJ function has the following properties:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
JordanJ[k+1,n] == 
DivisorSum[d^k JordanJ[k,n/d] EulerPhi[d],d,n]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["JordanJ[k,n] == DivisorSum[d^k MoebiusMu[n/d],d,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
JordanJ[k,n] JordanJ[k,m] == 
PropertySum[JordanJ[k,n m/d^2] MoebiusMu[d] d^k,  
            {d,Divisors[ GCD[n,m] ]}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["DivisorSum[JordanJ[k,d],d,n] == n^k  ", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sum[Floor[n/i] JordanJ[k,i],{i,n}] == Sum[i^k,{i,n}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
JordanJ[k,n] == EulerPhi[n] MoebiusMu[n/GCD[n,k]]/
                EulerPhi[n/GCD[n,k]]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
The following analog of the Brauer-Rademacher identity holds:\
\>", \
"Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
JordanJ[k,r] *PropertySum[d^k/JordanJ[k,d] MoebiusMu[r/d],
{d,Select[Divisors[r],GCD[#,n]==1&]}] ==
MoebiusMu[r] *PropertySum[d^k  MoebiusMu[r/d],
                          d,Divisors[GCD[n,r]]]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["JordanJ ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "can be generalized in the form (Rao1961, Rao1963):"
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["RaoPhi[k_,s_,n_] := n^k PrimeFactorProduct[1-s/p^k,p,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["This is also a multiplicative function. ", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Schemmel's Phi function", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
V. Schemmel introduced 1969 the function of the number of k \
consecutive numbers each <n and relative prime to n:\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
SchemmelPhi[k_,n_]:=
Power[#[[1]],#[[2]]-1] (#[[1]]-k)& /@ FactorInteger[n]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["It is a multiplicative function.", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Fleck's Phi function", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["A. Fleck introduced 1914 the following function:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
FleckPhi[k_,n_]:=Times @@ Apply[
Function[{p,a},Sum[EulerPhi[p^(a-i)] (-1)^i *
                   Binomial[k,i],{i,0,a}]],
FactorInteger[n],{1}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["It has the following properties:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["FleckPhi[0,n] == EulerPhi[n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["FleckPhi[-1,n] == n", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["FleckPhi[-2,n] == DivisorSigma[1,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Thacker's Phi function", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
A. Thacker introduced 1850 the function Phi_k(n) of the sum of the \
k-th powers of all numbers relativ prime to n and <=n:\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
ThackerPhi[k_,n_]:=
PropertySum[ d^k,{d,ReducedResidueSystem[n]}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["For k=1 this reduces to the EulerPhi function:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["ThackerPhi[0,n] == EulerPhi[n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
We have the following properties for the ThackerPhi function:\
\>", \
"Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
DivisorSum[Binomial[n,d]^k ThackerPhi[k,d],d,n]  ==
Sum[i^k,{i,n}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Nagel's Phi function", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
T. Nagel (1923) defined \\Theta(k,n) as the number of integers a  \
<=n , with the property:
gcd(a,n)=gcd(k-a,n)=1:   \
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
NagelTheta[k_,n_]:=
Select[Range[n],GCD[#,n]==1 && GCD[k-#,n]==1&]  // Length\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Then we have the following representation for NagelTheta (E. \
Cohen58)\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
NagelTheta[k,n]==
EulerPhi[n] PropertySum[MoebiusMu[d]/EulerPhi[d],{d, 
                        Select[Divisors[n],GCD[#,k]==1&]}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Dedekind function", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Dedekind's function Psi(k,n) is defined by:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
DedekindPsi[k_,n_]:=
DivisorSum[d^k Abs[MoebiusMu[n/d]],d,n]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["we have the following relation to Jordan's J function:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["DedekindPsi[k,n] == JordanJ[2k,n]/JordanJ[k,n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Klee's T function", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "Klee generalized Euler's Phi function in the following way:\n",
  StyleBox["KleePhi",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "_k(n) gives the number of integers i so that 1<=i<=n and gcd(i,n) is not \
divisible by the r-th power of any prime:"
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
KleePhi[k_,n_]:=
Select[GCD[Range[n],n],
       #==1 || FreeQ[Transpose[FactorInteger[#]][[2]],
                     _?(#>=k&)]&  ] // Length\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Then T_k(n) is a multiplicative function with the property:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
KleePhi[k,n] == 
n Plus @@ (MoebiusMu[#]/#^k & /@
          Select[Divisors[n],Head[#^(1/k)]===Integer&])\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
KleePhi[k,n] == 
n PropertySum[MoebiusMu[d]/d^k,
      {d,Select[Divisors[n],Head[#^(1/k)]===Integer&]}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["KleePhi",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "_k(n) has the following asymptotic:"
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sum[KleePhi[k,i],{i,n}] --> n^2/(2 Zeta[2 k]) + O[n]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Applications", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Public-Key encryption", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Euler's Phi function plays an important role in cryptography. The \
point is first that it is nearly impossible to factor big (>100 digits) \
integers in a finite time. Second Euler Phi comes into play. To calculate \
EulerPhi(n) one needs the prime factors of n which are hard to get. On the \
other hand one cannot guess the value of Phi(n) because it oscillates between \
0 and n.

lim sup EulerPhi[n+1]/EulerPhin] = Infinity   as n-> Infinity

lim inf EulerPhi[n+1]/EulerPhin] = Infinity   as n-> Infinity

For a detailed description see Schroeder84.
\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Farey sequences", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
J. Farey (1816) investigated the ordered series of all fractions \
p/q  0<p/q<=1, gcd(p,q)=1with denominators q not exceeding n. The length of \
this series is  \
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sum[EulerPhi[i],{i,n}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Here a visualization of the Farey fractions. The order is \
proportinal to the radius:\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Show[Graphics[{PointSize[0.001],
MapIndexed[
Point[#2[[1]] {Cos[N[2Pi #1]],Sin[N[2Pi #1]]}]&,
N @ Table[Union[Flatten[Table[i/j,{j,n},{i,0,j}]]],{n,100}],{2}]}],
PlotRange->All, AspectRatio->Automatic];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["number of tuples for a given sum", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Euler's Phi function comes up in a couple of enumeruation problems \
(see Brualdi70).
For instance the number of s-tuples of nonnegative intergers with the \
property

Sum[x[i],{i,0,s-1}] == s 

is given by:\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["1/s DivisorSum[Binomial[2d-1,d] EulerPhi[s/d],d,s]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generating Function", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["For Re[s]>1 we have:", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sum[EulerPhi[n]/n^s,{n,1,Infinity}]==Zeta[s-1]/Zeta[s]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Sum[EulerPhi[n]/ x^n/(1-x^n),{n,1,Infinity}]==x", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
A. Brauer, H. Rademacher Jber. Deutsch. Math. Verein. 35, 94 Suppl. \
(1926)
R. A. Brualdi, M. Newman J. Res. Nat. Standards Sect. B 74, 37 (1970) 
E. Cohen Duke math. J. 16, 85 (1949)
E. Cohen Duke Math. J. 25, 401 (1958)
L. E. Dickson: History of the Theory of Numbers, v.I, Chelsea, New York 1952
L. Euler Novi Comm. Ac. Petrop. 8, 74, (1760/1761)
L. Euler Comm. Arith. 1, 274 (1760)
L. Euler Comm. Arith. 2, 524 (1761)
A. Fleck Sitzungsber. Berlin Math. Gesell. 13, 161 (1914)
C. F. Gauss Disquisitiones Arithmeticae, 1801
R. R. Hall J. Lond. Math. Soc. 2, 139 (1970)
G. H. Hardy, E. M. Wright: An Introduction to the Theory of Numbers,
           Clarendon Press, Oxford 1993
V. L. Klee Am. Math. Monthly 55, 358 (1948)
T. Kl\\ove  Portug. Math. 35, 111 (1976)
P. K. Menon J. Indian Math. Soc. 29, 1555 (1965)
K. N. Rao Math. Student 29, 121 (1961)
K. N. Rao Math. Student 34, 87 (1963)
V. Schemmel J. f\\\"ur Math. 70, 191 (1869)
M. R. Schroeder: Number Theory in Science and Communication, Springer, Berlin \
1984
R. Sivaramakrishnan: Classical Theory of Arithmetic Functions, 
Marcel Dekker, New York 1989
R. Sivaramakrishnan Nieuw Archief voor Wiskunde 4, 175 (1986), 8, 169 (1990)
S. Wigert Ark. Mat. Astron. Fys. 22B, 1 (1932)
T. Nagel Skrifter Nosrke Videnskaps-Akademi (Oslo) Math.-Nat. Klasse I, n13, \
23 (1923)
\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{785, 714},
WindowMargins->{{Automatic, 78}, {Automatic, 96}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 75, 1, 95, "Section"],

Cell[CellGroupData[{
Cell[1876, 58, 66, 1, 37, "Subsubsection"],
Cell[1945, 61, 468, 12, 149, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2450, 78, 91, 1, 28, "Subsubsection"],
Cell[2544, 81, 138, 4, 53, "Input"],
Cell[2685, 87, 150, 4, 53, "Input"],
Cell[2838, 93, 201, 6, 91, "Input"],
Cell[3042, 101, 192, 6, 91, "Input"],
Cell[3237, 109, 108, 1, 34, "Input"],
Cell[3348, 112, 106, 1, 34, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3491, 118, 66, 1, 37, "Subsection"],
Cell[3560, 121, 89, 1, 39, "Text"],
Cell[3652, 124, 173, 6, 91, "Input"],
Cell[3828, 132, 100, 1, 39, "Text"],
Cell[3931, 135, 97, 1, 34, "Input"],
Cell[4031, 138, 147, 4, 39, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4215, 147, 72, 1, 37, "Subsection"],
Cell[4290, 150, 78, 1, 34, "Input"],
Cell[4371, 153, 106, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4502, 158, 139, 4, 53, "Input"],
Cell[4644, 164, 84220, 2851, 228, 40181, 2303, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[88913, 3021, 84, 1, 37, "Subsection"],

Cell[CellGroupData[{
Cell[89022, 3026, 121, 2, 37, "Subsubsection"],
Cell[89146, 3030, 95, 1, 34, "Input"],
Cell[89244, 3033, 230, 6, 91, "Input"],
Cell[89477, 3041, 193, 6, 91, "Input"],
Cell[89673, 3049, 108, 1, 34, "Input"],
Cell[89784, 3052, 97, 1, 34, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[89918, 3058, 106, 1, 37, "Subsubsection"],
Cell[90027, 3061, 98, 1, 34, "Input"],
Cell[90128, 3064, 124, 4, 53, "Input"],
Cell[90255, 3070, 105, 1, 34, "Input"],
Cell[90363, 3073, 109, 1, 34, "Input"],
Cell[90475, 3076, 126, 4, 53, "Input"],
Cell[90604, 3082, 140, 4, 39, "Text"],
Cell[90747, 3088, 143, 4, 53, "Input"],
Cell[90893, 3094, 149, 4, 39, "Text"],
Cell[91045, 3100, 86, 1, 34, "Input"],
Cell[91134, 3103, 88, 1, 39, "Text"],
Cell[91225, 3106, 93, 1, 34, "Input"],
Cell[91321, 3109, 107, 1, 34, "Input"],
Cell[91431, 3112, 144, 4, 53, "Input"],
Cell[91578, 3118, 92, 1, 39, "Text"],
Cell[91673, 3121, 247, 6, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[91957, 3132, 86, 1, 37, "Subsubsection"],
Cell[92046, 3135, 158, 4, 53, "Input"],
Cell[92207, 3141, 135, 4, 53, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[92391, 3151, 77, 1, 37, "Subsection"],

Cell[CellGroupData[{
Cell[92493, 3156, 73, 1, 37, "Subsubsection"],
Cell[92569, 3159, 58, 1, 39, "Text"],
Cell[92630, 3162, 85, 1, 34, "Input"],
Cell[92718, 3165, 80, 1, 34, "Input"],
Cell[92801, 3168, 96, 1, 34, "Input"],
Cell[92900, 3171, 94, 1, 39, "Text"],
Cell[92997, 3174, 122, 4, 53, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[93156, 3183, 82, 1, 37, "Subsubsection"],
Cell[93241, 3186, 123, 4, 39, "Text"],
Cell[93367, 3192, 109, 1, 34, "Input"],
Cell[93479, 3195, 137, 4, 39, "Text"],
Cell[93619, 3201, 128, 4, 53, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[93784, 3210, 76, 1, 37, "Subsubsection"],
Cell[93863, 3213, 108, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[93996, 3218, 207, 6, 91, "Input"],
Cell[94206, 3226, 68035, 2307, 228, 25136, 1773, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[162290, 5539, 82, 1, 37, "Subsubsection"],
Cell[162375, 5542, 91, 1, 34, "Input"],
Cell[162469, 5545, 135, 4, 39, "Text"],
Cell[162607, 5551, 143, 4, 53, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[162799, 5561, 67, 1, 37, "Subsection"],
Cell[162869, 5564, 105, 1, 34, "Input"],
Cell[162977, 5567, 100, 1, 34, "Input"],
Cell[163080, 5570, 149, 4, 53, "Input"],
Cell[163232, 5576, 93, 1, 39, "Text"],
Cell[163328, 5579, 82, 1, 34, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[163447, 5585, 76, 1, 37, "Subsection"],

Cell[CellGroupData[{
Cell[163548, 5590, 100, 1, 37, "Subsubsection"],
Cell[163651, 5593, 646, 12, 193, "Text"],
Cell[164300, 5607, 104, 1, 34, "Input"],
Cell[164407, 5610, 94, 1, 39, "Text"],
Cell[164504, 5613, 78, 1, 34, "Input"],
Cell[164585, 5616, 105, 1, 39, "Text"],
Cell[164693, 5619, 121, 4, 53, "Input"],
Cell[164817, 5625, 152, 4, 53, "Input"],
Cell[164972, 5631, 100, 1, 39, "Text"],
Cell[165075, 5634, 124, 4, 53, "Input"],
Cell[165202, 5640, 101, 1, 34, "Input"],
Cell[165306, 5643, 177, 5, 72, "Input"],
Cell[165486, 5650, 88, 1, 34, "Input"],
Cell[165577, 5653, 103, 1, 34, "Input"],
Cell[165683, 5656, 146, 4, 53, "Input"],
Cell[165832, 5662, 121, 4, 39, "Text"],
Cell[165956, 5668, 253, 6, 91, "Input"],
Cell[166212, 5676, 191, 6, 39, "Text"],
Cell[166406, 5684, 106, 1, 34, "Input"],
Cell[166515, 5687, 90, 1, 39, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[166642, 5693, 82, 1, 37, "Subsubsection"],
Cell[166727, 5696, 172, 4, 61, "Text"],
Cell[166902, 5702, 134, 4, 53, "Input"],
Cell[167039, 5708, 82, 1, 39, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[167158, 5714, 79, 1, 37, "Subsubsection"],
Cell[167240, 5717, 98, 1, 39, "Text"],
Cell[167341, 5720, 203, 6, 91, "Input"],
Cell[167547, 5728, 82, 1, 39, "Text"],
Cell[167632, 5731, 79, 1, 34, "Input"],
Cell[167714, 5734, 70, 1, 34, "Input"],
Cell[167787, 5737, 86, 1, 34, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[167910, 5743, 81, 1, 37, "Subsubsection"],
Cell[167994, 5746, 181, 4, 61, "Text"],
Cell[168178, 5752, 124, 4, 53, "Input"],
Cell[168305, 5758, 96, 1, 39, "Text"],
Cell[168404, 5761, 81, 1, 34, "Input"],
Cell[168488, 5764, 121, 4, 39, "Text"],
Cell[168612, 5770, 125, 4, 53, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[168774, 5779, 79, 1, 37, "Subsubsection"],
Cell[168856, 5782, 176, 5, 61, "Text"],
Cell[169035, 5789, 136, 4, 53, "Input"],
Cell[169174, 5795, 129, 4, 39, "Text"],
Cell[169306, 5801, 189, 5, 72, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[169532, 5811, 76, 1, 37, "Subsubsection"],
Cell[169611, 5814, 93, 1, 39, "Text"],
Cell[169707, 5817, 119, 4, 53, "Input"],
Cell[169829, 5823, 104, 1, 39, "Text"],
Cell[169936, 5826, 97, 1, 34, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[170070, 5832, 76, 1, 37, "Subsubsection"],
Cell[170149, 5835, 323, 8, 83, "Text"],
Cell[170475, 5845, 200, 6, 91, "Input"],
Cell[170678, 5853, 109, 1, 39, "Text"],
Cell[170790, 5856, 164, 5, 72, "Input"],
Cell[170957, 5863, 163, 5, 72, "Input"],
Cell[171123, 5870, 175, 6, 39, "Text"],
Cell[171301, 5878, 103, 1, 34, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[171453, 5885, 68, 1, 37, "Subsection"],

Cell[CellGroupData[{
Cell[171546, 5890, 80, 1, 37, "Subsubsection"],
Cell[171629, 5893, 613, 15, 259, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[172279, 5913, 74, 1, 37, "Subsubsection"],
Cell[172356, 5916, 219, 5, 61, "Text"],
Cell[172578, 5923, 73, 1, 34, "Input"],
Cell[172654, 5926, 144, 4, 39, "Text"],
Cell[172801, 5932, 261, 7, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[173099, 5944, 91, 1, 37, "Subsubsection"],
Cell[173193, 5947, 265, 10, 149, "Text"],
Cell[173461, 5959, 101, 1, 34, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[173611, 5966, 75, 1, 37, "Subsection"],
Cell[173689, 5969, 70, 1, 39, "Text"],
Cell[173762, 5972, 105, 1, 34, "Input"],
Cell[173870, 5975, 98, 1, 34, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[174005, 5981, 66, 1, 37, "Subsection"],
Cell[174074, 5984, 1385, 31, 589, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

