(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28403,        864]*)
(*NotebookOutlinePosition[     50696,       1314]*)
(*  CellTagsIndexPosition[     50566,       1306]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Elementary Functions", "Title",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[CellGroupData[{

Cell["Trigonometric and Hyperbolic Functions", "Section",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[GridBox[{
        {
          RowBox[{
            StyleBox["Sin",
              "MInput"], 
            StyleBox["[",
              "MInput"], 
            StyleBox["z",
              FontFamily->"Times",
              FontSlant->"Italic",
              FontTracking->"Plain"], 
            StyleBox["]",
              "MInput"]}], 
          RowBox[{
            StyleBox["sin",
              FontFamily->"Times",
              FontVariations->{"CompatibilityType"->0}], 
            RowBox[{
              StyleBox["(",
                "Traditional",
                FontFamily->"Times",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox["z",
                "Traditional",
                FontFamily->"Times",
                FontWeight->"Plain",
                FontSlant->"Italic",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox[")",
                "Traditional",
                FontFamily->"Times",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}]}]}]}
        },
      ColumnWidths->0.5,
      ColumnAlignments->{Left, Right}]], "FunctionName",
  PageBreakWithin->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"Sin", "[", "z", "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"2", "\[ImaginaryI]"}]], " ", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", "z"}]], "-", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], 
          ")"}]}]}]], "FunctionDescription"],

Cell["Equations", "SubsectionOpen",
  ShowGroupOpenCloseIcon->False,
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[CellGroupData[{

Cell["Series representations", "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[
        z] \[Equal] \[Sum]\+\(k = 0\)\%\[Infinity]\(\((\(-1\))\)\^k\ z\^\(2\ \
k + 1\)\)\/\(\((2\ k + 1)\)!\)\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[
          z] \[Equal] \[Pi]\ \(\[Sum]\+\(k = 0\)\%\[Infinity]\((\(-1\))\)\^k\ \
\((2\ k + z\/\[Pi])\)\ \((\(1\/\(k!\)\) Pochhammer[z\/\[Pi], k])\)\^3\) /; \ 
      Abs[z] < \[Pi]\/2\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Integral representations", "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] \[Integral]\_0\%z Cos[t] \[DifferentialD]t\)], 
  "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Product representations", "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] 
      z\ \(\[Product]\+\(k = 1\)\%\[Infinity]\((1 - z\^2\/\(\[Pi]\^2\ k\^2\))
            \)\)\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] 
      z \(\[Product]\+\(k = \(-\[Infinity]\)\)\%\[Infinity] If[
            k \[NotEqual] 0, \ 
            \((1 - z\/\(\[Pi]\ k\))\)\ \[ExponentialE]\^\(z\/\(\[Pi]\ k\)\), 
            1]\)\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell["HypergeometricPFQ and MeijerG representations", "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] 
      z\ HypergeometricPFQ[{}, {3\/2}, \(-\(z\^2\/4\)\)]\)], "DisplayFormula",\

  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[
        z] \[Equal] \@\[Pi]\ \ \ MeijerG[{{}, {}}, {{1\/\(\(\ \)\(2\)\)}, \
{0}}, z\/\(\(\ \)\(2\)\), 1\/\(\(\ \)\(2\)\)]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[
        z] \[Equal] \(\(\@\[Pi]\)\(\ \)\)\/2\ z\ MeijerG[{{}, {}}, {{0}, {\(-\
\(1\/2\)\)}}, z\^2\/4]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[
        z] \[Equal] \(\(\@\(\[Pi]\ z\^2\)\)\(\ \)\)\/z\ MeijerG[{{}, {}}, {{1\
\/2}, {0}}, z\^2\/4]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[
          z] \[Equal] \@\(\(\[Pi]\)\(\ \)\)\ \ MeijerG[{{}, {}}, {{1\/2}, \
{0}}, z\^2\/4] /; Re[z] > 0\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Functional relations", "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[\(-z\)] \[Equal] \(-Sin[z]\)\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z + m\ \[Pi]] \[Equal] \(\((\(-1\))\)\^m\) Sin[z] /; 
      m \[Element] Integers\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[2\ z]\^2 \[Equal] 4\ \((1 - Sin[z]\^2)\)\ Sin[z]\^2\)], 
  "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z\_1 + z\_2]\^4 - 
        2\ \((Sin[z\_1]\^2 + Sin[z\_2]\^2 - 
              2\ Sin[z\_1]\^2\ Sin[z\_2]\^2)\)\ Sin[z\_1 + z\_2]\^2 + 
        \((Sin[z\_1]\^2 - Sin[z\_2]\^2)\)\^2 \[Equal] 0\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] 
        2\^\(n - 1\)\ \(\[Product]\+\(k = 0\)\%\(n - 1\)Sin[\(\[Pi]\ k + \
z\)\/n]\) /; n \[Element] Integers \[And] n > 0\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] 
        n\ Sin[z\/n]\ \(\[Product]\+\(k = 1\)\%\(Floor[n\/2]\)\((1 - 
                Sin[z\/n]\^2\/Sin[\(4\ k\ \[Pi]\)\/\(2\ n\)]\^2)\)\) /; \(n - \
1\)\/2 \[Element] Integers\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z]\^\(2  n\) \[Equal] 
        2\^\(\(-2\)\ n\)\ Binomial[2\ n, n] + 
          2\^\(1 - 2\ n\)\ \(\[Sum]\+\(k = 0\)\%\(n - 1\)\((\(-1\))\)\^\(k - \
n\)\ Binomial[2\ n, k]\ Cos[2\ \((n - k)\)\ z]\) /; 
      n \[Element] Integers \[And] n > 0\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z]\^\(2  n + 1\) \[Equal] 
        2\^\(\(-2\) n\)\ \(\[Sum]\+\(k = 0\)\%n\(\((\(-1\))\)\^\(k - n\)\) 
              Binomial[2  n + 1, k]\ Sin[\((2\ n - 2\ k\  + 1)\)\ z]\) /; 
      n \[Element] Integers \[And] n \[GreaterEqual] 0\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Special relations", "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[x] \[LessEqual] x /; 
      x\  \[GreaterEqual] 0 \[And] \ x \[Element] Reals\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[n\ z]\/Sin[z] \[Equal] \[Sum]\+\(j = 0\)\%n\ \[Product]\+\(k = \
1\)\%n If[k \[Equal] j, 1, 
              Sin[z + \[Theta]\_j - \[Theta]\_k]\/Sin[\[Theta]\_j - \
\[Theta]\_k]] /; 
      n \[Element] Integers \[And] 
        n \[GreaterEqual] 
          0 \[And] \[Theta]\_j \[NotEqual] \[Theta]\_k\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Differential equations for which the function is ",
  StyleBox["a",
    FontSlant->"Italic"],
  " solution"
}], "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["w", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "z", "]"}], "+", \(w\ [z]\)}], 
        "\[Equal]", "0"}], " ", "/;", 
      " ", \(w[z] \[Equal] Sin[z]\)}]], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["w", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "z", "]"}], "+", \(a\ w[z]\), 
          "+", "b"}], "\[Equal]", "0"}], " ", "/;", 
      " ", \(w[z] \[Equal] \(-\(b\/a\)\) + C[2]\ Cos[\@a\ z] + 
          C[1]\ Sin[\@a\ z]\)}]], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Asymptotics", "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Tilde] z\ HypergeometricPFQ[{}, {3\/2}, \(-\(z\^2\/4\)\)] /; 
        z -> 0\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Tilde] z \((1 + O[z\^2])\) /; z -> 0\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Tilde] Sin[z] /; Abs[z] -> \[Infinity]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Tilde] Sin[z] \((1 + O[1\/z])\) /; 
        Abs[z] -> \[Infinity]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Derivatives and indefinite integrals", "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(\[PartialD]\_z Sin[z] \[Equal] Cos[z]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(\[PartialD]\_{z, n}Sin[z] \[Equal] Sin[z + \(\[Pi]\ n\)\/2] /; 
      n \[Element] Integers \[And] n > 0\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[PartialD]\_{z, n}f[Sin[z]]\), "\[Equal]", 
        RowBox[{\(\[Sum]\+\(m = 1\)\%n\), 
          RowBox[{\(1\/\(m!\)\), 
            RowBox[{"(", 
              RowBox[{\(\[Sum]\+\(j = 0\)\%\(m - 1\)\), 
                
                RowBox[{\(Binomial[m, j]\), 
                  " ", \((\[Sum]\+\(i = 0\)\%\(m - j\)\((\(-1\))\)\^i\ 2\^\(j \
- m\)\ Sin[z]\^j\ \((2\ i + j - m)\)\^n\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \
\[ImaginaryI]\ \((j + m + n)\)\ \[Pi]\)\ \[ExponentialE]\^\(\[ImaginaryI]\ z\ \
\((m - 2\ i - j)\)\)\ Binomial[m - j, i])\), " ", 
                  RowBox[{
                    SuperscriptBox["f", 
                      TagBox[\((m)\),
                        Derivative],
                      MultilineFunction->None], "[", \(Sin[z]\), "]"}]}]}], 
              ")"}]}]}]}], 
      "/;", \(n \[Element] Integers \[And] n > 0\)}]], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[PartialD]\_{z, n}f[Sin[z]]\), "\[Equal]", 
        RowBox[{\(\[Sum]\+\(m = 1\)\%n\), 
          FractionBox[
            
            RowBox[{\((\[PartialD]\_{y, n}\((Sin[y] - Sin[z])\)\^m \
/. \[InvisibleSpace]{y \[Rule] z})\), " ", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((m)\),
                    Derivative],
                  MultilineFunction->None], "[", \(Sin[z]\), 
                "]"}]}], \(m!\)]}]}], 
      "/;", \(n \[Element] Integers \[And] n > 0\)}]], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(\[Integral]Sin[z] \[DifferentialD]z \[Equal] \(-Cos[
          z]\)\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(\[Integral]\(z\^\(\[Alpha] - 1\)\) 
          Sin[z] \[DifferentialD]z \[Equal] \(-\(1\/2\)\)\ \[ImaginaryI]\ \((\
\(-\((\(-\[ImaginaryI]\)\ z)\)\^\(-\[Alpha]\)\)\ z\^\[Alpha]\ Gamma[\[Alpha], \
\(-\[ImaginaryI]\)\ z] + \((\[ImaginaryI]\ z)\)\^\(-\[Alpha]\)\ z\^\[Alpha]\ \
Gamma[\[Alpha], \[ImaginaryI]\ z])\)\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorems", "Subsection"],

Cell[CellGroupData[{

Cell["Fourier sine transformation", "Subsubsection"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        FormBox[
          RowBox[{
            RowBox[{
              RowBox[{
                OverscriptBox[
                  StyleBox["f",
                    FontWeight->"Plain"], "\[Wedge]"], "(", "y", ")"}], 
              "\[Equal]", 
              RowBox[{\(\[Integral]\+0\%\[Infinity]\), 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontWeight->"Plain"], "(", "x", ")"}], \(sin(x\ y)\), 
                  \(\[DifferentialD]x\)}]}]}], "\[DoubleLeftRightArrow]", 
            " ", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain"], "(", "x", ")"}], "\[Equal]", 
              RowBox[{\(2\/\[Pi]\), 
                RowBox[{\(\[Integral]\+0\%\[Infinity]\), 
                  RowBox[{
                    RowBox[{
                      OverscriptBox[
                        StyleBox["f",
                          FontWeight->"Plain"], "\[Wedge]"], "(", "y", ")"}], 
                    \(sin(x\ y)\), \(\(\[DifferentialD]y\)\(.\)\)}]}]}]}]}],
          "TraditionalForm"]}], TraditionalForm]], "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{

Cell["The law of sines", "Subsubsection"],

Cell[TextData[{
  "For a triangle in the Euclidean plane with edges ",
  Cell[BoxData[
      \(TraditionalForm\`a, \ b, \ c\)]],
  " and opposite angles \[Alpha], \[Beta], \[Gamma]  the following holds: "
}], "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\(sin(\[Alpha])\)\/a \[Equal] \(sin(\[Beta])\)\/b \[Equal] 
      \(\(\(sin(\[Gamma])\)\/c\)\(.\)\)\)], "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{

Cell["Logistic Equation Solution", "Subsubsection"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y\_n \[Equal] \(sin\^2\)(\((c\ \(2\^n\) 
                mod\ 1)\) \[Pi])\)]],
  " is a closed form for the chaos-exhibiting logistic equation ",
  Cell[BoxData[
      \(TraditionalForm\`y\_\(n + 1\) \[Equal] 
        4 \(\(\( y\_n\)(1 - y\_n)\)\(.\)\)\)]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Weierstrass-Riemann function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalOmega](x)\)]]
}], "Subsubsection"],

Cell[TextData[{
  "Weierstrass-Riemann function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalOmega](x)\)]],
  ",  which is continuous everywhere but not differentiable at a dense set of \
points, has the following representation:  "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
          \(\[CapitalOmega](x) \[Equal] 
              \[Sum]\+\(k = 1\)\%\[Infinity]\( sin(k\^2\ \[Pi]\ x)\)\/\(k\^2\ \
\[Pi]\) \[Equal] 
              \(\[Pi]\/\(4  q\^2\)\) 
                \(\[Sum]\+\(k = 1\)\%\(q - 1\)\(sin(\(k\^2\ p\ \[Pi]\)\/q)\)/
                    \(\(sin\^2\)(\(k\ \[Pi]\)\/\(2\ q\))\)\)\), "/;", 
            RowBox[{\(x \[Equal] p\/q\), 
              StyleBox["\[And]",
                SpanMaxSize->1], "p"}]}], ",", 
          \(q \[Element] \[DoubleStruckCapitalN] \[And] 
            gcd(p, q) \[Equal] 1. \)}]}], TraditionalForm]], "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{

Cell["Coriolis Force ", "Subsubsection"],

Cell[TextData[{
  "The closed form solution of the vector equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{\(\[PartialD]\^2\), " ", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold"], "(", "t", ")"}]}], 
            \(\[PartialD]t\^2\)], "\[Equal]", 
          RowBox[{
            StyleBox["g",
              FontWeight->"Bold"], "-", 
            RowBox[{"2", 
              StyleBox["\[Omega]",
                FontWeight->"Bold"], "\[Times]", 
              FractionBox[
                RowBox[{"\[PartialD]", " ", 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold"], "(", "t", ")"}]}], 
                \(\[PartialD]t\)]}]}]}], TraditionalForm]]],
  ", describing the movement of a mass point  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold"], "(", "t", ")"}], TraditionalForm]]],
  " under the gravitational force  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"m", " ", 
          StyleBox["g",
            FontWeight->"Bold"]}], TraditionalForm]]],
  "  and the Coriolis force ",
  Cell[BoxData[
      FormBox[
        RowBox[{"2", "m", " ", 
          StyleBox["\[Omega]",
            FontWeight->"Bold"], "\[Times]", 
          FractionBox[
            RowBox[{"\[PartialD]", " ", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold"], "(", "t", ")"}]}], \(\[PartialD]t\)]}]
          , TraditionalForm]]],
  "and initial conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold"], "(", "t", ")"}], "\[Equal]", 
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold"], \(\(0\)\(\ \ \)\)]}], TraditionalForm]]],
  "and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[PartialD]", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold"], "(", "t", ")"}]}], "/", 
            \(\[PartialD]t\)}], \( | \_\(t \[Equal] 0\)\), 
          RowBox[{"\[Equal]", 
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold"], "0"]}]}], TraditionalForm]]],
  ",  is given by  "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold"], "(", "t", ")"}], "\[Equal]", 
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold"], "0"], "+", 
          RowBox[{
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold"], "0"], "t"}], "+", 
          RowBox[{
            StyleBox["g",
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], \(t\^2\/2\)}], "-", 
          RowBox[{
            StyleBox["\[Omega]",
              FontWeight->"Bold"], "\[Times]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                \(\(2 \(\( sin\^2\)(\[Omega]\ t)\)\)\/\(2  \[Omega]\^2\)\), 
                  SubscriptBox[
                    StyleBox["v",
                      FontWeight->"Bold"], "0"]}], "+", 
                RowBox[{
                \(\(2  \[Omega]\ t - 
                        sin(2  \[Omega]\ t)\)\/\(4  \[Omega]\^3\)\), 
                  StyleBox["g",
                    FontWeight->"Bold"]}]}], ")"}]}], "+", "   ", 
          "\[IndentingNewLine]", 
          "                                            ", 
          RowBox[{
            StyleBox["\[Omega]",
              FontWeight->"Bold"], "\[Times]", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["\[Omega]",
                    FontWeight->"Bold"], "\[Times]", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                      \(\(2  \[Omega]\ t - 
                              sin(2  \[Omega]\ t)\)\/\(2  \[Omega]\^3\)\), 
                        SubscriptBox[
                          StyleBox["v",
                            FontWeight->"Bold"], "0"]}], "+", 
                      RowBox[{
                      \(\(2  \[Omega]\^2\ t\^2 - 
                              2 \(\( sin\^2\)(\[Omega]\ t)
                                  \)\)\/\(4  \[Omega]\^4\)\), 
                        StyleBox["g",
                          FontWeight->"Bold"]}]}], ")"}]}], ")"}], "."}]}]}]}]
        , TraditionalForm]], "DisplayFormula"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Historical Information", "Subsection"],

Cell["\<\
K. Ptolemaeus; Brahmagupta (c. 630); R.de Chesters (1140) \
translated Abu Ja'far Muhammed ibn Musa al-Khwarizme's works and used the \
word \"sine\" (in Latin, \"sinus\"; al-Khwarisme's name is the source of the \
word \"algorithm\"); J.M. Regiomontanus (1464) and A. D\[UDoubleDot]rer \
(1525); F. Maurolyco (1555) used the notation \"sinus\"; E. Gunter (1624) \
used the notation \"sin\"; I. Newton (1665) found a series expansion for sin; \
L. Euler (1734) found a product representation; T. Simpson (1750).\
\>", 
  "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Applications", "Subsection"],

Cell["\<\
Encountered often in mathematics and the natural sciences.\
\>", 
  "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Connections to other Functions", "Subsection"],

Cell[CellGroupData[{

Cell["Within Group", "Subsubsection"],

Cell[BoxData[
    \(Sin[z] \[Equal] \(-\[ImaginaryI]\)\ Sinh[\[ImaginaryI]\ z]\)], 
  "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sinh[z] \[Equal] \(-\[ImaginaryI]\)\ Sin[\[ImaginaryI]\ z]\)], 
  "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] Cos[\[Pi]\/2 - z]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Cos[z] \[Equal] Sin[\[Pi]\/2 - z]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z]\^2 + Cos[z]\^2 \[Equal] 1\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] 
      \((\(-1\))\)\^Floor[Re[z]\/\[Pi]]\ \((1 - 
            \((\((\(-1\))\)\^\(Floor[Re[z]\/\[Pi]] + \
Floor[\(-\(Re[z]\/\[Pi]\)\)]\) + 1)\)\ UnitStep[
                \(-Im[z]\)])\)\ \@\(1 - Cos[z]\^2\)\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Cos[z] \[Equal] 
      \((\(-1\))\)\^Floor[Re[z]\/\[Pi] + 1\/2]\ \((1 + 
            \((\((\(-1\))\)\^\(Floor[Re[z]\/\[Pi] - 1\/2] + \
Floor[\(-\(Re[z]\/\[Pi]\)\) - 1\/2]\) - 1)\)\ UnitStep[
                \(-Im[z]\)])\)\ \@\(1 - Sin[z]\^2\)\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Csc[z] \[Equal] 1\/Sin[z]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] 1\/Csc[z]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Between Groups", "Subsubsection"],

Cell[BoxData[
    \(Sin[z] \[Equal] \@\(\(\[Pi]\ z\)\/2\)\ BesselJ[1\/2, z]\)], 
  "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] \@\(\(\[Pi]\ z\)\/2\)\ BesselY[\(-\(1\/2\)\), z]\)], 
  "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] 
      \(\[ExponentialE]\^\(\[ImaginaryI]\ z\) - \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ z\)\)\/\(2\ \[ImaginaryI]\)\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[ArcSin[z]] \[Equal] z\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(ArcSin[Sin[z]] \[Equal] 
      \((\(-1\))\)\^Floor[Re[z]\/\[Pi] - 1\/2]\ \((\((1 + 
                  \((\(-1\))\)\^\(Floor[Re[z]\/\[Pi] + 1\/2] - \
Ceiling[Re[z]\/\[Pi] + 1\/2]\))\)\ UnitStep[\(-Im[z]\)] - 1)\)\ \((z - 
            \[Pi]\ Floor[Re[z]\/\[Pi] - 1\/2] + 
            1\/2\ \[Pi]\ \((1 + 
                  \((\(-1\))\)\^\(Floor[Re[z]\/\[Pi] + 1\/2] - \
Ceiling[Re[z]\/\[Pi] + 1\/2]\))\)\ UnitStep[\(-Im[z]\)] - \[Pi])\)\)], 
  "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Between Posters", "Subsubsection"],

Cell[BoxData[
    \(Sin[z] \[Equal] EllipticE[z, 1] /; \ 
      Abs[Re[z]] \[LessEqual] \[Pi]\/2\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] 
      WeierstrassSigma[\@\(2\/3\)\ z, {3, 
            1}]\ \@\(3\/2\)\ \[ExponentialE]\^\(-\(z\^2\/6\)\)\)], \
"DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] JacobiSN[z, 0]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] JacobiSD[z, 0]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] 
      1\/2\ \@\[Pi]\ Limit[
          \((\(-1\))\)\^n\/\(4\^n\ \(n!\)\)\ HermiteH[2\ n + 1, 
              z\/\(2\ \@n\)], n \[Rule] \[Infinity]]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[
        z] \[Equal] \@\(\(\[Pi]\ z\)\/2\)\ StruveH[\(-\(1\/\(\(2\)\(\ \
\)\)\)\), z]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[\@a\ z] \[Equal] MathieuS[a, 0, z]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[z] \[Equal] Limit[MathieuS[a, q, z\/\@a], a \[Rule] \[Infinity]] /; 
      Element[q, Reals]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[\@a\ z] \[Equal] \(-\(1\/\@a\)\) 
        MathieuCPrime[a, 0, z]\)], "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[
          z] \[Equal] \(-Limit[\(1\/\@a\) MathieuCPrime[a, q, z\/\@a], 
            a \[Rule] \[Infinity]]\) /; Element[q, Reals]\)], "DisplayFormula",\

  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[BoxData[
    \(Sin[\[Pi]\ z] \[Equal] \[Pi]\/\(Gamma[z]\ Gamma[1 - z]\)\)], \
"DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell["Copyright 1999 Wolfram Research, Inc., All Rights Reserved.", 
  "Copyright"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
ScreenStyleEnvironment->"Brackets",
Evaluator->"Local",
WindowSize->{785, 754},
WindowMargins->{{203, Automatic}, {Automatic, 84}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
Magnification->1.25,
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Elliptic"->{
    Cell[1776, 53, 85, 1, 122, "Title",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[1886, 58, 105, 1, 95, "Section",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[4562, 138, 116, 2, 30, "SubsectionOpen",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[4703, 144, 95, 1, 37, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[4801, 147, 204, 4, 71, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5008, 153, 276, 5, 58, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5321, 163, 97, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5421, 166, 151, 3, 50, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5609, 174, 96, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5708, 177, 201, 4, 58, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5912, 183, 297, 6, 58, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6246, 194, 118, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6367, 197, 165, 4, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6535, 203, 216, 4, 45, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6754, 209, 196, 4, 51, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6953, 215, 194, 4, 52, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7150, 221, 198, 4, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7385, 230, 93, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7481, 233, 122, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7606, 237, 175, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7784, 242, 148, 3, 31, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7935, 247, 284, 5, 56, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[8222, 254, 229, 4, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[8454, 260, 283, 5, 78, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[8740, 267, 336, 6, 86, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9079, 275, 326, 5, 82, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9442, 285, 90, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9535, 288, 171, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9709, 293, 392, 8, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[10138, 306, 195, 6, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[10336, 314, 351, 9, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[10690, 325, 422, 10, 45, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11149, 340, 84, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11236, 343, 175, 3, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11414, 348, 135, 2, 31, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11552, 352, 137, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11692, 356, 164, 3, 45, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11893, 364, 109, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[12005, 367, 127, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[12135, 371, 194, 3, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[12332, 376, 966, 20, 176, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[13301, 398, 628, 15, 97, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[13932, 415, 157, 3, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[14092, 420, 400, 6, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23430, 710, 151, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23584, 715, 151, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23738, 720, 123, 2, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23864, 724, 123, 2, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23990, 728, 122, 2, 31, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24115, 732, 311, 6, 76, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24429, 740, 332, 6, 76, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24764, 748, 115, 2, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24882, 752, 115, 2, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25076, 761, 148, 3, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25227, 766, 157, 3, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25387, 771, 223, 4, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25613, 777, 115, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25731, 781, 527, 10, 157, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26338, 798, 166, 3, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26507, 803, 214, 5, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26724, 810, 120, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26847, 814, 120, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26970, 818, 252, 5, 53, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27225, 825, 179, 4, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27407, 831, 128, 2, 35, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27538, 835, 186, 3, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27727, 840, 158, 3, 51, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27888, 845, 226, 5, 51, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[28117, 852, 148, 3, 46, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]},
  "Jacobi"->{
    Cell[1776, 53, 85, 1, 122, "Title",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[1886, 58, 105, 1, 95, "Section",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[4562, 138, 116, 2, 30, "SubsectionOpen",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[4703, 144, 95, 1, 37, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[4801, 147, 204, 4, 71, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5008, 153, 276, 5, 58, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5321, 163, 97, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5421, 166, 151, 3, 50, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5609, 174, 96, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5708, 177, 201, 4, 58, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5912, 183, 297, 6, 58, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6246, 194, 118, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6367, 197, 165, 4, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6535, 203, 216, 4, 45, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6754, 209, 196, 4, 51, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6953, 215, 194, 4, 52, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7150, 221, 198, 4, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7385, 230, 93, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7481, 233, 122, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7606, 237, 175, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7784, 242, 148, 3, 31, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7935, 247, 284, 5, 56, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[8222, 254, 229, 4, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[8454, 260, 283, 5, 78, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[8740, 267, 336, 6, 86, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9079, 275, 326, 5, 82, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9442, 285, 90, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9535, 288, 171, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9709, 293, 392, 8, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[10138, 306, 195, 6, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[10336, 314, 351, 9, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[10690, 325, 422, 10, 45, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11149, 340, 84, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11236, 343, 175, 3, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11414, 348, 135, 2, 31, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11552, 352, 137, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11692, 356, 164, 3, 45, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11893, 364, 109, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[12005, 367, 127, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[12135, 371, 194, 3, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[12332, 376, 966, 20, 176, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[13301, 398, 628, 15, 97, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[13932, 415, 157, 3, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[14092, 420, 400, 6, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23430, 710, 151, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23584, 715, 151, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23738, 720, 123, 2, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23864, 724, 123, 2, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23990, 728, 122, 2, 31, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24115, 732, 311, 6, 76, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24429, 740, 332, 6, 76, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24764, 748, 115, 2, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24882, 752, 115, 2, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25076, 761, 148, 3, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25227, 766, 157, 3, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25387, 771, 223, 4, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25613, 777, 115, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25731, 781, 527, 10, 157, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26338, 798, 166, 3, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26507, 803, 214, 5, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26724, 810, 120, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26847, 814, 120, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26970, 818, 252, 5, 53, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27225, 825, 179, 4, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27407, 831, 128, 2, 35, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27538, 835, 186, 3, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27727, 840, 158, 3, 51, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27888, 845, 226, 5, 51, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[28117, 852, 148, 3, 46, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]},
  "JacobiSN"->{
    Cell[1776, 53, 85, 1, 122, "Title",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[1886, 58, 105, 1, 95, "Section",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[4562, 138, 116, 2, 30, "SubsectionOpen",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[4703, 144, 95, 1, 37, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[4801, 147, 204, 4, 71, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5008, 153, 276, 5, 58, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5321, 163, 97, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5421, 166, 151, 3, 50, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5609, 174, 96, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5708, 177, 201, 4, 58, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[5912, 183, 297, 6, 58, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6246, 194, 118, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6367, 197, 165, 4, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6535, 203, 216, 4, 45, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6754, 209, 196, 4, 51, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[6953, 215, 194, 4, 52, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7150, 221, 198, 4, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7385, 230, 93, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7481, 233, 122, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7606, 237, 175, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7784, 242, 148, 3, 31, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[7935, 247, 284, 5, 56, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[8222, 254, 229, 4, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[8454, 260, 283, 5, 78, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[8740, 267, 336, 6, 86, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9079, 275, 326, 5, 82, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9442, 285, 90, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9535, 288, 171, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[9709, 293, 392, 8, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[10138, 306, 195, 6, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[10336, 314, 351, 9, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[10690, 325, 422, 10, 45, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11149, 340, 84, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11236, 343, 175, 3, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11414, 348, 135, 2, 31, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11552, 352, 137, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11692, 356, 164, 3, 45, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[11893, 364, 109, 1, 28, "Subsubsection",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[12005, 367, 127, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[12135, 371, 194, 3, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[12332, 376, 966, 20, 176, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[13301, 398, 628, 15, 97, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[13932, 415, 157, 3, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[14092, 420, 400, 6, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23430, 710, 151, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23584, 715, 151, 3, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23738, 720, 123, 2, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23864, 724, 123, 2, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[23990, 728, 122, 2, 31, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24115, 732, 311, 6, 76, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24429, 740, 332, 6, 76, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24764, 748, 115, 2, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[24882, 752, 115, 2, 48, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25076, 761, 148, 3, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25227, 766, 157, 3, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25387, 771, 223, 4, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25613, 777, 115, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[25731, 781, 527, 10, 157, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26338, 798, 166, 3, 43, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26507, 803, 214, 5, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26724, 810, 120, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26847, 814, 120, 2, 30, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[26970, 818, 252, 5, 53, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27225, 825, 179, 4, 60, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27407, 831, 128, 2, 35, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27538, 835, 186, 3, 49, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27727, 840, 158, 3, 51, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[27888, 845, 226, 5, 51, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
    Cell[28117, 852, 148, 3, 46, "DisplayFormula",
      CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Elliptic", 29148, 885},
  {"Jacobi", 36283, 1024},
  {"JacobiSN", 43420, 1163}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 85, 1, 122, "Title",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[CellGroupData[{
Cell[1886, 58, 105, 1, 95, "Section",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[1994, 61, 2070, 60, 30, "FunctionName",
  PageBreakWithin->False],
Cell[4067, 123, 492, 13, 45, "FunctionDescription"],
Cell[4562, 138, 116, 2, 30, "SubsectionOpen",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],

Cell[CellGroupData[{
Cell[4703, 144, 95, 1, 37, "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[4801, 147, 204, 4, 71, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[5008, 153, 276, 5, 58, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[5321, 163, 97, 1, 28, "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[5421, 166, 151, 3, 50, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[5609, 174, 96, 1, 28, "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[5708, 177, 201, 4, 58, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[5912, 183, 297, 6, 58, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[6246, 194, 118, 1, 28, "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[6367, 197, 165, 4, 49, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[6535, 203, 216, 4, 45, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[6754, 209, 196, 4, 51, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[6953, 215, 194, 4, 52, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[7150, 221, 198, 4, 49, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[7385, 230, 93, 1, 28, "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[7481, 233, 122, 2, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[7606, 237, 175, 3, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[7784, 242, 148, 3, 31, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[7935, 247, 284, 5, 56, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[8222, 254, 229, 4, 60, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[8454, 260, 283, 5, 78, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[8740, 267, 336, 6, 86, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[9079, 275, 326, 5, 82, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[9442, 285, 90, 1, 28, "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[9535, 288, 171, 3, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[9709, 293, 392, 8, 60, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[10138, 306, 195, 6, 28, "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[10336, 314, 351, 9, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[10690, 325, 422, 10, 45, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[11149, 340, 84, 1, 28, "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[11236, 343, 175, 3, 49, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[11414, 348, 135, 2, 31, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[11552, 352, 137, 2, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[11692, 356, 164, 3, 45, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[11893, 364, 109, 1, 28, "Subsubsection",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[12005, 367, 127, 2, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[12135, 371, 194, 3, 43, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[12332, 376, 966, 20, 176, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[13301, 398, 628, 15, 97, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[13932, 415, 157, 3, 48, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[14092, 420, 400, 6, 48, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[14529, 431, 30, 0, 37, "Subsection"],

Cell[CellGroupData[{
Cell[14584, 435, 52, 0, 46, "Subsubsection"],
Cell[14639, 437, 1196, 30, 69, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[15872, 472, 41, 0, 46, "Subsubsection"],
Cell[15916, 474, 216, 5, 61, "Text"],
Cell[16135, 481, 163, 3, 48, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[16335, 489, 51, 0, 46, "Subsubsection"],
Cell[16389, 491, 325, 8, 57, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[16751, 504, 135, 4, 46, "Subsubsection"],
Cell[16889, 510, 252, 6, 61, "Text"],
Cell[17144, 518, 667, 15, 76, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[17848, 538, 40, 0, 46, "Subsubsection"],
Cell[17891, 540, 2352, 72, 92, "Text"],
Cell[20246, 614, 2237, 58, 109, "DisplayFormula"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22532, 678, 44, 0, 37, "Subsection"],
Cell[22579, 680, 538, 9, 127, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[23154, 694, 34, 0, 37, "Subsection"],
Cell[23191, 696, 85, 3, 39, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[23313, 704, 52, 0, 37, "Subsection"],

Cell[CellGroupData[{
Cell[23390, 708, 37, 0, 46, "Subsubsection"],
Cell[23430, 710, 151, 3, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[23584, 715, 151, 3, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[23738, 720, 123, 2, 43, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[23864, 724, 123, 2, 43, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[23990, 728, 122, 2, 31, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[24115, 732, 311, 6, 76, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[24429, 740, 332, 6, 76, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[24764, 748, 115, 2, 48, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[24882, 752, 115, 2, 48, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[25034, 759, 39, 0, 46, "Subsubsection"],
Cell[25076, 761, 148, 3, 60, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[25227, 766, 157, 3, 60, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[25387, 771, 223, 4, 49, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[25613, 777, 115, 2, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[25731, 781, 527, 10, 157, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}]
}, Closed]],

Cell[CellGroupData[{
Cell[26295, 796, 40, 0, 46, "Subsubsection"],
Cell[26338, 798, 166, 3, 43, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[26507, 803, 214, 5, 60, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[26724, 810, 120, 2, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[26847, 814, 120, 2, 30, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[26970, 818, 252, 5, 53, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[27225, 825, 179, 4, 60, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[27407, 831, 128, 2, 35, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[27538, 835, 186, 3, 49, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[27727, 840, 158, 3, 51, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[27888, 845, 226, 5, 51, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[28117, 852, 148, 3, 46, "DisplayFormula",
  CellTags->{"Elliptic", "Jacobi", "JacobiSN"}],
Cell[28268, 857, 83, 1, 76, "Copyright"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

