(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1572797,      80300]*)
(*NotebookOutlinePosition[   1574089,      80341]*)
(*  CellTagsIndexPosition[   1574045,      80337]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematical ",
    FontSlant->"Italic"],
  "Functions"
}], "Title"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
In the 18th and 19th centuries, scientists discovered that the \
solutions of some important physical problems\[LongDash]including the orbital \
motion of planets, the oscillatory motion of suspended chains, and the \
calculation of the gravitational potential of nearly spherical bodies\
\[LongDash]could not be described in a closed form using only the elementary \
functions. Even in the realm of pure mathematics, some quantities, such as \
the circumference of an arbitrary ellipse, could not be expressed with \
elementary functions alone; solutions to these problems could only be \
expressed as infinite series, in integral form, or as solutions of \
differential equations. \
\>", "Text"],

Cell[TextData[{
  "However, the same special function that provided the answer to a \
particular problem often reappeared in other contexts. Those ",
  StyleBox["special functions ",
    FontSlant->"Italic"],
  "(or",
  StyleBox[" special functions of mathematical physics",
    FontSlant->"Italic"],
  ") that cropped up the most frequently in scientific calculations were \
given names and notations that have come into common usage: Bessel functions, \
Struve functions, Mathieu functions, the spherical harmonics, the gamma and \
beta functions, the Jacobi functions, and most of the others appearing on \
this series of posters."
}], "Text"],

Cell["\<\
In the second half of the 19th century mathematicians also began to \
investigate these special functions from a purely theoretical perspective. \
Alternative representations\[LongDash]differential equations, series, \
integrals, continued fractions, and other forms\[LongDash]were found for \
many. Important publications on the topic at the turn of the century include \
the four-volume masterpiece on the elliptic functions by Jules Tannery and J. \
Molk (published 1893\[Dash]1902), containing hundreds of pages of collected \
formulas; Isaac Todhunter\[CloseCurlyQuote]s treatise on Laplace, \
Lam\[EAcute], and Bessel functions (1875); Eduard Heine\[CloseCurlyQuote]s \
treatise on spherical harmonics (1881); and Albert \
Wangerin\[CloseCurlyQuote]s work on the same topic (1904).\
\>", "Text"],

Cell["\<\
Large tables with numerical values for the special functions also \
began to appear, along with three-dimensional \[OpenCurlyDoubleQuote]graphs\
\[CloseCurlyDoubleQuote] made of wood or plaster\[LongDash]marvels of \
precision sculpting\[LongDash]showing the behavior of functions such as the \
Weierstrass elliptic function \[WeierstrassP] and the Jacobi functions. Many \
of these models are still on display in math departments throughout the \
world, and the graphics on this poster can be thought of as their modern, \
computer-drafted counterparts. \
\>", "Text"],

Cell[TextData[{
  "In the 1960s, mathematicians such as J. D. Talman, N. J. Vilenkin, I. M. \
Gelfand, M. A. Naimark, and others, building on ideas of \[CapitalEAcute]lie \
",
  "Cartan circa 1930 and Eugene P. Wigner circa",
  " 1955, used group theory to create a new perspective on the special \
functions. They found that many special functions are intimately related to \
representations of certain Lie groups. For example, Jacobi polynomials, \
Legendre polynomials, and spherical harmonics are intimately related to \
representations of SU(2) and SO(3), the group of rotations in three \
dimensions. Similarly, Bessel functions are intimately related to ",
  Cell[BoxData[
      \(TraditionalForm\`E\_2\)],
    FormatType->StandardForm],
  ", the group of rigid motions in two dimensions. The group-theoretical \
approach unified the treatment of special functions, giving new insights \
about their interrelationships and limiting behaviors. "
}], "Text"],

Cell["\<\
W. Miller in the 1960s and 1970s investigated the relations between \
the factorization of differential operators and special functions. This \
approach leads to a categorization of special functions by how each arises \
from the application of the separation of variables method to linear partial \
differential equations in various coordinate systems.\
\>", "Text"],

Cell["\<\
Today, special functions are the subject of an independent field of \
mathematical study. Important work continues there, including work to unify \
hypergeometric and elliptic functions through Painlev\[EAcute] transcendents \
and to investigate semiclassical orthogonal polynomials. However, special \
functions are also of considerable interest throughout the wider realm of \
mathematics.\
\>", "Text"],

Cell[TextData[{
  "Polylogarithm functions appear in algebraic ",
  StyleBox["K",
    FontSlant->"Italic"],
  "-theory and in hyperbolic geometry."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Meijer ",
  StyleBox["G ",
    FontSlant->"Italic"],
  "functions play an important role in statistics."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Hypergeometric functions are the cornerstone of powerful \
algorithmic summation procedures such as the W-Z method, named for Herbert S. \
Wilf and Doron Zeilberger; they also play an important role in algebraic \
geometry for dealing with polynomial systems.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Elliptic functions are used in quickly converging perturbation \
expansions of celestial mechanics problems and in exactly solvable models of \
chaotic systems.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Weierstrass \[WeierstrassP] functions appear in the solitonic \
solutions of nonlinear partial differential equations and in investigations \
of the transcendence and algebraic independence of numbers. \
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Additionally, generalizations of the classical special functions, such as \
",
  StyleBox["q-",
    FontSlant->"Italic"],
  "analogs of special functions, are the building blocks for quantum groups, \
Hopf algebras of braid groups, and related topics. The ",
  StyleBox["q",
    FontSlant->"Italic"],
  "-analog of a special function reduces to the function itself as ",
  Cell[BoxData[
      \(TraditionalForm\`q \[Rule] 1\)],
    FormatType->StandardForm],
  "; that is, the ",
  StyleBox["q",
    FontSlant->"Italic"],
  "-sine function approaches the usual sine, and so on. "
}], "Text"],

Cell["\<\
The special functions also maintain their fundamental importance in \
science. Two important examples here are the zeta function and its close \
relatives, which are crucial ingredients in modern quantum field theories, \
and the polylogarithm, often used to express results of Feynman diagram \
calculations. \
\>", "Text"],

Cell[TextData[{
  "The symbiosis between physics and the special functions of mathematics \
remains just as important today as in past centuries. For example, the 6-J \
and 3-J symbols shown on the ",
  StyleBox["Hypergeometric Functions",
    FontWeight->"Bold"],
  " panel were first used by Eugene Wigner and Giulio Racah, both theoretical \
physicists who developed the functions in the first half of the twentieth \
century to study angular momenta in quantum mechanics. Their contribution is \
only one comparatively recent instance in the long history of exchange \
between the worlds of mathematics and physics."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Role of Mathematical Handbooks", "Section"],

Cell["\<\
As knowledge of the special functions grew, so did the need for \
comprehensive mathematical handbooks containing collections of formulas, \
tables, and specific values to be used by scientists and engineers in their \
calculations.\
\>", "Text"],

Cell[TextData[{
  "Donald E. Knuth notes in \[OpenCurlyDoubleQuote]Computers and Typesetting\
\[CloseCurlyDoubleQuote] (see his collection ",
  StyleBox["Digital Typography",
    FontSlant->"Italic"],
  ", 1999) that mathematical tables and computers were linked conceptually \
before there even ",
  StyleBox["were",
    FontSlant->"Italic"],
  " computers. Charles Babbage, who designed but was unable to build the \
\[OpenCurlyDoubleQuote]difference engine,\[CloseCurlyDoubleQuote] planned a \
printing device allowing the machine to generate large tables automatically. \
A Swedish publisher named Georg Scheutz and his son Edvard later built a \
difference engine that could set type. In 1857 the Scheutzes produced a \
mechanically generated table of common logarithms to five decimal places for \
the integers from 1 to 10000; each value took about thirty seconds to \
calculate."
}], "Text"],

Cell[TextData[{
  StyleBox["Funktionentafeln mit Formeln und Kurven",
    FontSlant->"Italic"],
  ", the first modern handbook of special functions\[LongDash]that is, one \
containing graphs, formulas, and numerical tables\[LongDash]was published in \
1909 by Eugene Jahnke and Fritz Emde. The first text dealing comprehensively \
with most of the named special functions was E. T. Whittaker and G. N. Watson\
\[CloseCurlyQuote]s ",
  StyleBox["A Course of Modern Analysis",
    FontSlant->"Italic"],
  ", 2nd Edition (1915). This popular text consisted of two parts; Part I is \
a textbook of complex analysis, while Part II is a handbook of special \
functions."
}], "Text"],

Cell[TextData[{
  "In 1939, orthogonal polynomials were given their first detailed treatment \
by G\[AAcute]bor Szeg\[ODoubleDot]. This work was followed in 1943 by Wilhelm \
Magnus and Fritz Oberhettinger\[CloseCurlyQuote]s ",
  StyleBox["Formeln und Lehrs\[ADoubleDot]tze f\[UDoubleDot]r die speziellen \
Funktionen der Mathematischen Physik",
    FontSlant->"Italic"],
  ", the most complete collection of formulas involving special functions yet \
prepared. "
}], "Text"],

Cell[TextData[{
  "The massive Batemen Manuscript Project\[LongDash]the editing for \
posthumous publication of Harry Bateman\[CloseCurlyQuote]s accumulated notes \
on special functions, which he stored in shoe boxes\[LongDash]was carried out \
by Arthur Erd\[EAcute]lyi, Magnus, Oberhettinger, and Francesco Tricomi, \
culminating in 1953 with the classic three-volume work ",
  StyleBox["Higher Transcendental Functions",
    FontSlant->"Italic"],
  ". This monumental collection contains not only formulas, but also \
derivations, proofs, and historical remarks. (Along with the contents of ",
  StyleBox["Higher Transcendental Functions",
    FontSlant->"Italic"],
  ", Bateman\[CloseCurlyQuote]s shoe boxes also held enough material for a \
two-volume set of integral transform tables.)"
}], "Text"],

Cell[TextData[{
  "In ",
  StyleBox["Higher Transcendental Functions",
    FontSlant->"Italic"],
  " Erd\[EAcute]lyi introduced a new emphasis on the importance of \
hypergeometric functions as an underlying, unifying basis for the development \
of many of the categories of special functions. Although ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[InvisiblePostfixScriptBase]\_2\) \(\(\(\
\[NegativeThinSpace]\)\(F\)\)\_1\)\)\)],
    FormatType->StandardForm],
  " had been extensively studied since the time of Gauss, mathematicians were \
slow to appreciate the importance of the generalized hypergeometric ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[InvisiblePostfixScriptBase]\_p\) \(\(\(\
\[NegativeThinSpace]\)\(F\)\)\_q\)\)\)],
    FormatType->StandardForm],
  " and to recognize the many relations between hypergeometric functions and \
the special functions encountered most frequently. Another innovation in ",
  StyleBox["Higher Transcendental Functions",
    FontSlant->"Italic"],
  " was the inclusion of number-theoretical functions."
}], "Text"],

Cell[TextData[{
  "Application of the electronic computer resulted in many massive volumes \
containing hundreds of pages of tables for Bessel functions, elliptic \
integrals, Legendre functions, and so on. An important handbook containing \
graphs, formulas, and computer-generated numerical data was assembled by \
Milton Abramowitz and Irene Stegun and was published in 1964 by the National \
Bureau of Standards as the ",
  StyleBox["Handbook of Mathematical Functions with Formulas, Graphs, and",
    FontSlant->"Italic"],
  " ",
  StyleBox["Mathematical Tables",
    FontSlant->"Italic"],
  ". Individual chapters were compiled by various authors, leading to a \
certain unevenness in the quality of the material and its presentation. \
Nevertheless, the ",
  StyleBox["Handbook of Mathematical Functions",
    FontSlant->"Italic"],
  " remains a standard reference and is still in widespread use. "
}], "Text"],

Cell[TextData[{
  "Ironically, the computer, which led to the creation of such mammoth \
numeric tables, is now eliminating the need for them. The ready availability \
of computer processing time and technical software now allows technical users \
to calculate the values of any needed function without recourse to reference \
works. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can calculate every special function on this poster to extremely high \
precision. Additionally, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can symbolically and numerically calculate values for integrals or other \
operations and transformations involving these functions, providing far more \
information than any single handbook could possibly tabulate."
}], "Text"],

Cell[TextData[{
  "For many special functions, such as Jacobi, Weierstrass, and Mathieu \
functions with complex arguments, there are no closed forms known. In such \
cases printed handbooks can usually give only the first few terms of the \
function\[CloseCurlyQuote]s series expansion. However, the algorithms \
implemented in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " calculate as many terms of the appropriate series as needed to achieve a \
given precision."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Defining a Function", "Section"],

Cell[TextData[{
  "The ",
  StyleBox["function",
    FontSlant->"Italic"],
  " is one of the most important and fundamental concepts in mathematics. \
Although the ancients were familiar with elementary functions such as sine \
and the square root, the abstract concept of the function appeared only in \
the Middle Ages. It was developed in the 17th and 18th centuries by some of \
the leading figures in mathematics, including Pierre de Fermat, Ren\[EAcute] \
Descartes, Isaac Newton, Gottfried von Leibniz (who first used the term ",
  StyleBox["function",
    FontSlant->"Italic"],
  "), Johann Bernoulli, and Leonhard Euler. "
}], "Text",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`f : X \[RightTeeArrow] Y\)],
    FormatType->StandardForm],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`y = f(x), \ \ x \[Element] X, \ y \[Element] Y\)],
    FormatType->StandardForm],
  " is the mapping from some set ",
  Cell[BoxData[
      \(TraditionalForm\`X\)],
    FormatType->StandardForm],
  " into another set ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)],
    FormatType->StandardForm],
  " as directed by some rule or formula. The function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)],
    FormatType->StandardForm],
  " provides some correspondence between each element ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] X\)],
    FormatType->StandardForm],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`X\)],
    FormatType->StandardForm],
  " is the ",
  StyleBox["domain ",
    FontSlant->"Italic"],
  "of its definition, and some unique element ",
  Cell[BoxData[
      \(TraditionalForm\`y \[Element] Y\)],
    FormatType->StandardForm],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)],
    FormatType->StandardForm],
  " is the ",
  StyleBox["range",
    FontSlant->"Italic"],
  " of its definition. The element ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] X\)],
    FormatType->StandardForm],
  " is called the ",
  StyleBox["argument",
    FontSlant->"Italic"],
  " of the function, or the ",
  StyleBox["independent variable",
    FontSlant->"Italic"],
  ", and the element ",
  Cell[BoxData[
      \(TraditionalForm\`y \[Element] Y\)],
    FormatType->StandardForm],
  " is called the ",
  StyleBox["value",
    FontSlant->"Italic"],
  " of the function, or the ",
  StyleBox["image of the element ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\)],
    FormatType->StandardForm,
    FontSlant->"Italic"],
  StyleBox[" under",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f\)],
    FormatType->StandardForm],
  ". This definition is very broad, since it places no restrictions on the \
nature of the sets ",
  Cell[BoxData[
      \(TraditionalForm\`X\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)],
    FormatType->StandardForm],
  ". For the mathematical functions we describe on this poster, the sets ",
  Cell[BoxData[
      \(TraditionalForm\`X\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)],
    FormatType->StandardForm],
  " consist of numbers or tensor products of numbers. "
}], "Text",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`X \[SubsetEqual] \[DoubleStruckCapitalR]\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y \[SubsetEqual] \[DoubleStruckCapitalR]\)],
    FormatType->StandardForm],
  ", where \[DoubleStruckCapitalR] designates the set of real numbers, then \
the function ",
  Cell[BoxData[
      \(TraditionalForm\`f : X \[RightTeeArrow] Y\)],
    FormatType->StandardForm],
  " is a ",
  StyleBox["real function",
    FontSlant->"Italic"],
  "; if ",
  Cell[BoxData[
      \(TraditionalForm\`X \[SubsetEqual] \[DoubleStruckCapitalC]\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y \[SubsetEqual] \[DoubleStruckCapitalC]\)],
    FormatType->StandardForm],
  ", with \[DoubleStruckCapitalC] the set of complex numbers, then ",
  Cell[BoxData[
      \(TraditionalForm\`f : X \[RightTeeArrow] Y\)],
    FormatType->StandardForm],
  " is a ",
  StyleBox["complex function",
    FontSlant->"Italic"],
  " or a ",
  StyleBox["complex-valued function of a complex variable",
    FontSlant->"Italic"],
  ". If the argument ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\({z\_1, \ z\_2, \[Ellipsis], 
            z\_n}\)\(\[Element]\)\)\)],
    FormatType->StandardForm],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`X \[SubsetEqual] \[DoubleStruckCapitalC]\^n\)],
    FormatType->StandardForm],
  ", then the function is a ",
  StyleBox["complex function of several variables",
    FontSlant->"Italic"],
  "; finally, if the values ",
  Cell[BoxData[
      \(TraditionalForm\`y = {w\_1, w\_2, \[Ellipsis], w\_m} \[Element] 
          Y \[SubsetEqual] \[DoubleStruckCapitalC]\^m\)],
    FormatType->StandardForm],
  ", the function is a ",
  StyleBox["vector-valued function",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  "How can the mapping of ",
  Cell[BoxData[
      \(TraditionalForm\`X\)],
    FormatType->StandardForm],
  " onto ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)],
    FormatType->StandardForm],
  " be specified? There are many ways of doing so."
}], "Text"],

Cell[TextData[{
  "In an explicit form using formulas, such as ",
  Cell[BoxData[
      \(TraditionalForm\`w = \@\(cos(z)\)\)],
    FormatType->StandardForm],
  "."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}},
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "In an implicit form as the solution of some equation, differential \
equation, or functional equation. For example, the Airy functions ",
  Cell[BoxData[
      \(TraditionalForm\`Ai(z)\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Bi(z)\)],
    FormatType->StandardForm],
  " are defined as solutions of a differential equation: ",
  Cell[BoxData[
      \(TraditionalForm\`w = f(z)\)],
    FormatType->StandardForm],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(w\^\[DoublePrime] - z\ w = 0\)\)\)],
    FormatType->StandardForm],
  "."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}},
  FontColor->GrayLevel[0]],

Cell["\<\
Using distinct formulas or rules on different domains, such \
as\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}},
  AutoStyleOptions->{"UnmatchedBracketStyle"->None},
  FontColor->GrayLevel[0]],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{\(\[Theta](x)\), "=", 
            RowBox[{"{", GridBox[{
                  {\(\(1\)\(,\)\), \(\(\ \)\(\(x > 0\)\(,\)\)\)},
                  {\(\(0\)\(,\)\), \(\(\ \)\(x < 0. \)\)}
                  }]}]}],
          SpanMaxSize->Infinity], TraditionalForm]],
    FormatType->StandardForm]
}], "DisplayFormula",
  AutoStyleOptions->{"UnmatchedBracketStyle"->None},
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "By description of the correspondence. For example, the ",
  StyleBox["Dirichlet function",
    FontSlant->"Italic"],
  " is defined as ",
  Cell[BoxData[
      \(TraditionalForm\`D(x) = 1\)],
    FormatType->StandardForm],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm],
  " is a rational number and ",
  Cell[BoxData[
      \(TraditionalForm\`D(x) = 0\)],
    FormatType->StandardForm],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm],
  " is an irrational number."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}},
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "In the form of a definite algorithm for determining the value, such as \
that used to calculate the value of the Meijer ",
  StyleBox["G ",
    FontSlant->"Italic"],
  "function,"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}},
  FontColor->GrayLevel[0]],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(G\_\(p, q\)\%\(m, n\)\), "(", 
          RowBox[{"z", "\[VerticalSeparator]", 
            RowBox[{GridBox[{
                  {\(\(a\_1\)\(,\)\), \(\(a\_2\)\(,\)\)},
                  {\(\(b\_1\)\(,\)\), \(\(b\_2\)\(,\)\)}
                  }], GridBox[{
                  {\(\(...\)\(,\)\), \(a\_p\)},
                  {\(\(...\)\(,\)\), \(b\_q\)}
                  }]}]}], ")"}], TraditionalForm]],
    Evaluatable->False,
    PageBreakWithin->False,
    FormatType->StandardForm],
  ". "
}], "DisplayFormula",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "In the form of a recurrence relation, which defines some values of the \
function in terms of other values of the same function. For example, the \
Fibonacci series defines each value ",
  Cell[BoxData[
      \(TraditionalForm\`F\_n\)],
    FormatType->StandardForm],
  " as the sum of ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(n - 1\)\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(n - 2\)\)],
    FormatType->StandardForm],
  ", starting with ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1 = \(F\_2 = \ 1\)\)],
    FormatType->StandardForm],
  "."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Often there are many equivalent ways to describe a given function. For \
example, the ",
  StyleBox["unit step function",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](x)\)],
    FormatType->StandardForm],
  " described above (",
  StyleBox["UnitStep", "MR"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ") can also be represented as the single formula ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](x) = \((\@x\^2 + x)\)/2  x\)],
    FormatType->StandardForm],
  ". Similarly, the Dirichlet function ",
  Cell[BoxData[
      \(TraditionalForm\`D(x)\)],
    FormatType->StandardForm],
  " can also be expressed as the double limit "
}], "Text",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    FormBox[
      RowBox[{\(D(x)\), "=", 
        RowBox[{
          UnderscriptBox["lim", \(m \[Rule] \[Infinity]\),
            LimitsPositioning->False], "\[ThinSpace]", 
          RowBox[{
            UnderscriptBox["lim", \(n \[Rule] \[Infinity]\),
              LimitsPositioning->False], 
            "\[ThinSpace]", \(\(\(cos\^\(2  
                      n\)\)(\(m!\)\ \[Pi]\ x)\)\(.\)\)}]}]}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "Frequently, the ",
  StyleBox["special functions and constants treated on this poster were first \
defined by some special description of the correspondence between ",
    ScriptLevel->0],
  Cell[BoxData[
      \(TraditionalForm\`X\)],
    FormatType->StandardForm],
  StyleBox[" and ",
    ScriptLevel->0],
  Cell[BoxData[
      \(TraditionalForm\`Y\)],
    FormatType->StandardForm],
  StyleBox[", and only later were the exact formulas for their \
representations found. For example, the number ",
    ScriptLevel->0],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)],
    FormatType->StandardForm],
  " was first defined as the ratio of the length of a \
circle\[CloseCurlyQuote]s circumference to its diameter, but later an \
extraordinary number of formulas for its representation were found (see the \
information box for ",
  StyleBox["Pi", "MR"],
  " for examples). Another interesting example is the ",
  StyleBox["PrimePi", "MR"],
  " function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi](n)\)],
    FormatType->StandardForm],
  ", which is defined as the number of primes less than or equal to ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  ". Surprisingly, despite the erratic distribution of the prime numbers, \
there is a simple closed-form representation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi](n)\)],
    FormatType->StandardForm],
  ":"
}], "Text",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    \(TraditionalForm\`\[Pi](
        n) = \[Sum]\+\(k = 2\)\%n\(\(\(\( 
                    sin\^2\) \((\(\[Pi] \(\((k - 1)\)!\)\)\^2\
\[NegativeThickSpace]/k)\)\)\/\(\(sin\^2\) \((\[Pi]/
                    k)\)\)\)\(.\)\)\)], "DisplayFormula",
  FormatType->StandardForm]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Analytic Function",
    FontWeight->"Bold"],
  "s"
}], "Section"],

Cell[TextData[{
  "Most of the mathematical functions on this poster belong to the class of \
",
  StyleBox["analytic functions",
    FontSlant->"Italic"],
  " of one or several complex variables. The theory of analytic functions \
originated in the 19th century, mainly due to the work of Augustin-Louis \
Cauchy, Bernhard Riemann, and Karl Weierstrass. There are different methods \
of determining whether a function is analytic; we can demonstrate the \
existence of derivatives with respect to a complex variable (the approach of \
Cauchy and Riemann) or show how to represent the function by power series \
(the approach of Weierstrass). The latter approach lets us make this \
following definition."
}], "Text",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  StyleBox["Definition A. ",
    FontWeight->"Bold"],
  "An analytic function is a mathematical function ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " that can be locally represented by a power series. ",
  StyleBox["See \[OpenCurlyDoubleQuote]",
    ScriptLevel->0],
  "Power Series and Generalizations\[CloseCurlyDoubleQuote] ",
  "in the essay ",
  StyleBox["Series",
    FontWeight->"Bold"],
  " on this panel for more on series representations."
}], "Text",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "The class of analytic functions is large and also closed with respect to \
the fundamental operations of arithmetic, algebra, and analysis \
(differentiation and integration). Analytic functions have a remarkable \
uniqueness property: if two analytical functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(z)\)],
    FormatType->StandardForm],
  " are defined over a region ",
  Cell[BoxData[
      \(TraditionalForm\`G\)],
    FormatType->StandardForm],
  " and coincide throughout some arbitrarily small neighborhood around any \
point in ",
  Cell[BoxData[
      \(TraditionalForm\`G\)],
    FormatType->StandardForm],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(z)\)],
    FormatType->StandardForm],
  " coincide over all of ",
  Cell[BoxData[
      \(TraditionalForm\`G\)],
    FormatType->StandardForm],
  ". This result justifies the procedure of analytical continuation; the \
uniqueness property allows for only one possible analytic function that \
extends another beyond the original region but agrees with it completely \
inside that region. See ",
  StyleBox["Analytic Continuation",
    FontWeight->"Bold"],
  " on this panel for more information on the usefulness of this property."
}], "Text",
  FontColor->GrayLevel[0]],

Cell["\<\
If we use the approach of Cauchy and Riemann, we arrive at an \
equivalent definition.\
\>", "Text",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  StyleBox["Definition B.",
    FontWeight->"Bold"],
  " ",
  "An analytic function is the",
  " mathematically differentiable function ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  "; that is, the function for which the following limit exists independent \
of the direction ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\ z\)],
    FormatType->StandardForm],
  " approaches to zero:"
}], "Text",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    FormBox[
      RowBox[{\(lim\+\(\[CapitalDelta]\ z \[Rule] 0\)\(f \((z + \
\[CapitalDelta]\ z)\) - f \((z)\)\)\/\(\[CapitalDelta]\ z\)\), "=", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\^\[Prime]\),
              ScriptLevel->0], "(", 
            StyleBox["z",
              ScriptLevel->0], 
            StyleBox[")",
              ScriptLevel->0]}], 
          StyleBox[".",
            ScriptLevel->0]}]}], TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "To establish the analyticity of a function at the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = x + \[ImaginaryI]\ \ y\)],
    FormatType->StandardForm],
  ", it has been shown that satisfying the Cauchy-Riemann equation is a \
necessary and sufficient condition:"
}], "Text",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(\[PartialD]\/\[PartialD]x\) \(u(x, 
                y)\) = \(\[PartialD]\/\[PartialD]y\) \(v(x, y)\)\), ";", 
          RowBox[{
            RowBox[{
            Cell["     "], \(\[PartialD]\/\[PartialD]y\), \(u(x, y)\)}], 
            "=", \(\(-\(\[PartialD]\/\[PartialD]x\)\) \(v(x, y)\)\)}]}], 
        ","}], TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y) = Re(f(x + \[ImaginaryI]\ y))\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v(x, y) = Im(f(x + \[ImaginaryI]\ y))\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[TextData[{
  "If a function is analytic over the whole complex plane it is called an ",
  StyleBox["entire function",
    FontSlant->"Italic"],
  ". For example, any polynomial is an entire function; the exponential \
function ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)],
    FormatType->StandardForm],
  " is also entire. Taylor series expansions of entire functions have an \
infinite radius of convergence. "
}], "Text",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "If the analytic function is not entire, it has ",
  StyleBox["singular points",
    FontSlant->"Italic"],
  ". These points play a very important role, since they accumulate the most \
important information about the behavior of the whole analytic function. For \
example, if an analytic function has no singular points, either on the finite \
part of the complex plane or at infinity, then it must be simply a constant. \
A nonconstant entire function has a singular point at infinity, which is \
either a ",
  StyleBox["pole of order ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm,
    FontSlant->"Italic"],
  " for a polynomial of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  " or an ",
  StyleBox["essential",
    FontSlant->"Italic"],
  " singular point for other entire functions such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)],
    FormatType->StandardForm],
  ". "
}], "Text",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "Isolated singular points can be divided into two classes: ",
  StyleBox["simple singular points, ",
    FontSlant->"Italic"],
  "which include poles and essential singular points, and ",
  StyleBox["branch points",
    FontSlant->"Italic"],
  ", the points at which branch cuts originate. See",
  StyleBox[" Branch Cuts and Branch Points ",
    FontWeight->"Bold"],
  "on this panel for more information",
  "."
}], "Text",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "In the neighborhood of a pole, an analytic function can be expanded into a \
Laurent series whose principal part contains only a finite number of terms. \
Conversely, in the neighborhood of an essential singular point, the principal \
part of the corresponding Laurent series expansion has an infinite number of \
terms. If we approach a pole from any direction, the limit value of an \
analytic function will tend to infinity. For example, ",
  Cell[BoxData[
      \(TraditionalForm\`tan(z)\)],
    FormatType->StandardForm],
  " has a pole of first order (a ",
  StyleBox["simple pole",
    FontSlant->"Italic"],
  ") at the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = \[Pi]/2\)],
    FormatType->StandardForm],
  ", where it can be expanded into the Laurent series"
}], "Text",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    \(TraditionalForm\`tan(z) = 
      1\/\(z - \[Pi]/2\) + \(z - \[Pi]/2\)\/3 + \((z - \[Pi]/2)\)\^3\/45 + \(\
\(\[CenterEllipsis]\)\(\ \)\(.\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontFamily->"Janson Text"],

Cell[TextData[{
  "However, approaching an essential singular point can give different limit \
values depending on the direction of approach\[LongDash]so many different \
values, in fact, that for any complex number we choose, we can find a \
sequence approaching the singular point that gives that limit. For example, \
there is no general limit value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)],
    FormatType->StandardForm],
  " at infinity, which is its essential singular point, but if ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] \(+\[Infinity]\)\)],
    FormatType->StandardForm],
  " the corresponding limit is equal to ",
  Cell[BoxData[
      \(TraditionalForm\`\(+\[Infinity]\)\)],
    FormatType->StandardForm],
  ", if ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] \(-\[Infinity]\)\)],
    FormatType->StandardForm],
  " it is equal to ",
  Cell[BoxData[
      \(TraditionalForm\`0\)],
    FormatType->StandardForm],
  ", and if ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] \(\[PlusMinus]\[ImaginaryI]\)\
\ \ \[Infinity]\)],
    FormatType->StandardForm],
  " then it does not exist."
}], "Text",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "In the neighborhood of a branch point the analytic function can be \
expanded into Puiseux series. For example, ",
  Cell[BoxData[
      \(TraditionalForm\`\(cos\^\(-1\)\)(z)\)],
    FormatType->StandardForm],
  " can be expanded near ",
  "the branch point",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(-1\)\)],
    FormatType->StandardForm],
  " into the Puiseux series "
}], "Text",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    \(TraditionalForm\`\(\(\(cos\^\(-1\)\)(
        z) = \[Pi] - \(\@2\) \(\@\(z + 
                1\)\) \(\[Sum]\+\(k = \
0\)\%\[Infinity]\(\((1/2)\)\_k\/\(\(2\^k\) \((2  k + 
                        1)\) \(k!\)\)\) \((z + 1)\)\^k\)\)\(,\)\)\)], \
"DisplayFormula",
  FormatType->StandardForm,
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\(tan\^\(-1\)\)(z)\)],
    FormatType->StandardForm],
  " can be expanded near the branch point ",
  Cell[BoxData[
      \(TraditionalForm\`z = \[ImaginaryI]\)],
    FormatType->StandardForm],
  " into the Puiseux series "
}], "Text",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(tan\^\(-1\)\)(z)\), "=", 
        RowBox[{
          StyleBox[\(\[ImaginaryI]\/2\),
            ScriptLevel->0], " ", 
          RowBox[{
            RowBox[{
              StyleBox["(",
                ScriptLevel->0], 
              RowBox[{
                StyleBox[\(log \((2)\)\),
                  ScriptLevel->0], 
                StyleBox["-",
                  ScriptLevel->0], 
                StyleBox[\(log \((\[ImaginaryI]\ \ z + 1)\)\),
                  ScriptLevel->0], 
                StyleBox["-",
                  ScriptLevel->0], 
                RowBox[{
                  UnderoverscriptBox[
                    StyleBox["\[Sum]",
                      ScriptLevel->0], \(k = 1\), "\[Infinity]"], 
                  RowBox[{\(\((\[ImaginaryI]/2)\)\^k\/k\), 
                    StyleBox[\(\((z - \[ImaginaryI])\)\^k\),
                      ScriptLevel->0]}]}]}], ")"}], "."}]}]}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "Some analytic functions have a ",
  StyleBox["natural boundary",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "for the region of analyticity. For example, the real axis ",
  Cell[BoxData[
      \(TraditionalForm\`Im(z) = 0\)],
    FormatType->StandardForm],
  " is the natural boundary of the region of analyticity for the ",
  StyleBox["KleinInvariantJ", "MR"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["J",
            FontFamily->"Times"], "(", "z", ")"}], TraditionalForm]],
    FormatType->StandardForm],
  "."
}], "Text",
  FontColor->GrayLevel[0]],

Cell[TextData[{
  "Some analytic functions can have singular points where they accumulate \
different combinations of the behaviors mentioned above. For example, the \
point ",
  Cell[BoxData[
      \(TraditionalForm\`z = \[Infinity]\)],
    FormatType->StandardForm],
  " behaves like an essential singular point for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma](z)\)],
    FormatType->StandardForm],
  ", since ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma](z)\)],
    FormatType->StandardForm],
  " has a single pole at every negative integer on the real axis, and \
therefore every neighborhood of infinity\[LongDash]that is, the area outside \
the circle ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] = R\)],
    FormatType->StandardForm],
  " for arbitrarily large ",
  Cell[BoxData[
      \(TraditionalForm\`R\)],
    FormatType->StandardForm],
  "\[LongDash]must contain an infinite number of poles."
}], "Text",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Series", "Title"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "There are three major techniques for representing an arbitrary function ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " as an infinite sum of simpler functions. The first is the ",
  StyleBox["power series",
    FontSlant->"Italic"],
  " expansion and its two important generalizations, the ",
  StyleBox["Laurent series",
    FontSlant->"Italic"],
  " and the ",
  StyleBox["Puiseux series",
    FontSlant->"Italic"],
  ". The second is the ",
  StyleBox["Dirichlet series",
    FontSlant->"Italic"],
  ", and the third is the ",
  StyleBox["Fourier series",
    FontSlant->"Italic"],
  ". These representations provide convenient, very general methods for \
studying a wide range of functions. "
}], "Text"],

Cell[TextData[{
  "The terms of a power series expansion include power functions in the form \
",
  Cell[BoxData[
      \(TraditionalForm\`\((z - z\_0)\)\^k\)],
    FormatType->StandardForm],
  "; the terms in a Dirichlet series include exponential functions in the \
form ",
  Cell[BoxData[
      \(TraditionalForm\`exp(\(-\[Lambda]\_k\) s)\)],
    FormatType->StandardForm],
  ". The Fourier series usually provide expansions in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`cos(k\ x)\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`sin(k\ x)\)],
    FormatType->StandardForm],
  ", although expansions are possible in terms of other orthogonal systems of \
functions, such as the orthogonal polynomials. With each of these methods, we \
can express an enormous number of nonelementary functions in terms of only \
simple elementary functions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Power Series and Generalizations", "Section"],

Cell[CellGroupData[{

Cell["The Taylor Series", "Subsection"],

Cell[TextData[{
  "The Taylor series, first investigated by Brook Taylor in 1715, gives us \
the following expansion for an arbitrary function ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " at a finite point ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \ \ \ \)\(f(
          z)\  \[LeftRightArrow] \ \[Sum]\+\(k = 0\)\%\[Infinity]\(\( c\_k\) \
\((z - z\_0)\)\)\^k\ \ \ \ \ where\ \ \ \ \ \ c\_k = \(\(f\^\((k)\)\) \
\((z\_0)\)\)\/\(k!\)\ , 
    k \[Element] \(\(\[DoubleStruckCapitalN]\)\(.\)\)\)\)\)], "DisplayFormula",\

  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "The sign \[LeftRightArrow] means that the Taylor series should not be \
taken as purely equal to ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  ", since it may not converge everywhere on the complex plane. The series \
converges absolutely in some disk of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)],
    FormatType->StandardForm],
  " centered on ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`R\)],
    FormatType->StandardForm],
  " is called the ",
  StyleBox["radius of convergence",
    FontSlant->"Italic"],
  ". For most functions, we can find ",
  Cell[BoxData[
      \(TraditionalForm\`R\)],
    FormatType->StandardForm],
  " using the ",
  StyleBox["Cauchy-Hadamard theorem",
    FontSlant->"Italic"],
  ", which states that"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \ \ \ \)\(R = \(lim\&_\)\+\(k \[Rule] \
\[Infinity]\)\(\(1\/\@\[LeftBracketingBar]c\_k\[RightBracketingBar]\%k\)\(.\)\
\)\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "There are then three possible cases for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)],
    FormatType->StandardForm],
  ": either ",
  StyleBox["R",
    FontSlant->"Italic"],
  " is infinite, ",
  StyleBox["R",
    FontSlant->"Italic"],
  " is zero, or else ",
  StyleBox["R",
    FontSlant->"Italic"],
  " is some finite positive number greater than zero."
}], "Text"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0\)],
    FormatType->StandardForm],
  ", this series converges only at the point ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  ", and the Taylor series offers little analytical benefit. For example, the \
series ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(k = 0\)\%\[Infinity]\( 
            k!\) \((z - z\_0)\)\^k\)],
    FormatType->StandardForm,
    FontWeight->"Plain"],
  " has no disk of convergence around ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  ", since the ",
  Cell[BoxData[
      \(TraditionalForm\`\(k!\)\)],
    FormatType->StandardForm],
  " coefficient makes terms grow infinitely large no matter how small ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z - z\_0\[RightBracketingBar]\)],
    
    FormatType->StandardForm],
  " becomes."
}], "Text"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`R = \[Infinity]\)],
    FormatType->StandardForm],
  ", the series converges in the entire plane. In such cases it either \
represents an entire transcendental function\[LongDash]as, for example, the \
series ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(k = 0\)\%\[Infinity]\((z - 
              z\_0)\)/\(k!\)\)],
    FormatType->StandardForm],
  " does for the exponential function ",
  Cell[BoxData[
      \(TraditionalForm\`exp(z - z\_0)\)],
    FormatType->StandardForm],
  "\[LongDash]or else, if it contains only a finite number of terms, \
represents a polynomial. "
}], "Text"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`0 < R < \[Infinity]\)],
    FormatType->StandardForm],
  ", the sum of the series defines a regular analytic function having at \
least one singular point on the circle ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z - z\_0\[RightBracketingBar] = 
        R\)],
    FormatType->StandardForm],
  ". There may be finitely or infinitely many singular points on the circle, \
but there must be at least one. The power series ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 1\)\%\[Infinity]\((\((z - z\_0)\)\^k/
              k)\) = \(-\(log(z\_0 + 1 - z)\)\)\)],
    FormatType->StandardForm],
  ", for example, has only one singular point, at ",
  Cell[BoxData[
      \(TraditionalForm\`z = z\_0 + 1\)],
    FormatType->StandardForm],
  ". Other power series have dense sets of singular points on the circle, \
such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(k!\)\)],
    FormatType->StandardForm],
  ", which has an infinite number of singular points on the unit circle, the \
edge of its natural region of analyticity. The same holds true, with the same \
region of analyticity, for the series representation of the logarithm of the \
",
  StyleBox["InverseEllipticNomeQ", "MR"],
  ","
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["log",
            FontFamily->"Times"], " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox[
                    StyleBox["q",
                      FontFamily->"Times"], \(-1\)], \((z)\)}], "16"], "z"}], 
            ")"}]}], 
        "=", \(\[Sum]\+\(k = 1\)\%\[Infinity]\(\( 
              log(\((\(1 + z\^\(2  k\)\)\/\(1 + z\^\(2  k + 1\)\))\)\^8)\)\(.\
\)\)\)}], TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm],

Cell["\<\
Inside its region of convergence, we can exchange the sign \
\[LeftRightArrow] for = in the first formula of this section.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Manipulating Power Series", "Subsection"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(z)\)\(=\)\)\)],
    FormatType->StandardForm],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 0\)\%\[Infinity]\( a\_k\) z\^k\)],
    FormatType->StandardForm,
    FontWeight->"Plain"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(g(z)\)\(=\)\)\)],
    FormatType->StandardForm],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 0\)\%\[Infinity]\( b\_k\) z\^k\)],
    FormatType->StandardForm,
    FontWeight->"Plain"],
  " converge for ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] < r\_1\)],
    
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] < r\_2\)],
    
    FormatType->StandardForm],
  " respectively. Then for ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] < r = 
        min(r\_1, r\_2)\)],
    FormatType->StandardForm],
  " we can manipulate the series in the following ways:"
}], "Text"],

Cell[BoxData[{
    \(TraditionalForm\`f(z) \[PlusMinus] 
        g(z\ )\[AlignmentMarker] = \[Sum]\+\(k = 0\)\%\[Infinity]\((a\_k \
\[PlusMinus] b\_k)\) 
            z\^k\ \ \ \ where\ \ \ \ \[LeftBracketingBar]z\
\[RightBracketingBar] < 
        r, \[IndentingNewLine]\(f(z)\) \(g(
          z)\)\[AlignmentMarker] = \[Sum]\+\(k = \
0\)\%\[Infinity]\((\[Sum]\+\(n = 0\)\%k\( a\_n\) b\_\(k - n\))\) 
            z\^k\ \ \ \ where\ \ \ \ \[LeftBracketingBar]z\
\[RightBracketingBar] < 
        r, \[IndentingNewLine]\(f \((z)\)\)\^n\[AlignmentMarker]\
\[AlignmentMarker] = \[Sum]\+\(k = 0\)\%\[Infinity]\( p\_k\) 
          z\^k\ \ \ \ where\ \), "\[IndentingNewLine]", 
    \(TraditionalForm\`p\_0 = a\_0\%n, a\_0 \[NotEqual] 0, 
    p\_k = \(1\/\(\(a\_0\) 
              k\)\) \(\[Sum]\+\(j = 1\)\%k\((n\ j - k + j)\) \(a\_j\) 
            p\_\(k - j\)\), 
    k \[Element] \(\[DoubleStruckCapitalN]\^+\), \[LeftBracketingBar]z\
\[RightBracketingBar] < 
      r\_1, \[IndentingNewLine]\(f \((z)\)\)\/\(g \((z)\)\)\[AlignmentMarker] \
= \(\[Sum]\+\(k = 0\)\%\[Infinity]\( q\_k\) 
            z\^k\ \ \ where\ \ \ a\_k = \[Sum]\+\(n = 0\)\%k\( b\_n\) 
            q\_\(k - n\)\), \[IndentingNewLine]\(\[DifferentialD]f \
\((z)\)\)\/\[DifferentialD]z\[AlignmentMarker] = \[Sum]\+\(k = 1\)\%\
\[Infinity]\( a\_k\) 
            k\ z\^\(k - 1\)\ \ \ \ where\ \ \ \ \[LeftBracketingBar]z\
\[RightBracketingBar] < 
        r\_1, \[IndentingNewLine]\[Integral]\(f(
            z)\) \[DifferentialD]z\[AlignmentMarker] = \[Sum]\+\(k = 0\)\%\
\[Infinity]\( a\_k\) 
            z\^\(k + 1\)\/\(k + 1\)\ \ \ \ where\ \ \ \ \[LeftBracketingBar]z\
\[RightBracketingBar] < \(\(r\_1\)\(.\)\)\)}], "DisplayFormula",
  CellMargins->{{83.3125, Inherited}, {Inherited, Inherited}},
  TextAlignment->AlignmentMarker,
  FormatType->StandardForm]
}, Closed]],

Cell[CellGroupData[{

Cell["Composition of Power Series", "Subsection",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    FormBox[
      RowBox[{\(g(
            f(z))\[AlignmentMarker] = \(\[Sum]\+\(k = 0\)\%\[Infinity]\( 
                      u\_k\) z\^k\ \  /; \ \ a\_0 = 0\)\), 
        ",", \(\[LeftBracketingBar]z\[RightBracketingBar] < r\_1\), 
        ",", \(\[LeftBracketingBar]f(z)\[RightBracketingBar] < r\_2\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(u\_k\), "\[AlignmentMarker]", "=", 
          
          RowBox[{\(\[Sum]\+\(n\_1 + 2  n\_2 + \[CenterEllipsis] + k\ n\_k = 
                  k\)\), 
            
            RowBox[{\((n\_1 + \[CenterEllipsis] + n\_k; n\_1, \[Ellipsis], 
                n\_k)\), \(b\_\(n\_1 + \[CenterEllipsis] + 
                    n\_k\)\), \(a\_1\%\(n\_1\)\), \(a\_2\%\(n\_2\)\), 
              SubsuperscriptBox[
                StyleBox[
                  RowBox[{"\[CenterEllipsis]", 
                    StyleBox["a",
                      FontSlant->"Italic"]}]], "k", \(n\_k\)]}]}]}], ",", 
        "\[IndentingNewLine]", \(u\_0\[AlignmentMarker] = b\_0\), ",", 
        "\[IndentingNewLine]", \(u\_1\[AlignmentMarker] = \(a\_1\) b\_1\), 
        ",", "\[IndentingNewLine]", \(u\_\(\(2\)\(\[AlignmentMarker]\)\)\
\[AlignmentMarker] = \(a\_1\%2\) b\_2 + \(a\_2\) b\_1\), ",", 
        "\[IndentingNewLine]", \(u\_3\[AlignmentMarker] = \(a\_3\) b\_1 + 
            2 \( a\_1\) \(a\_2\) b\_2\), ",", \(\(+a\_1\%3\) b\_3\), ",", 
        "\[IndentingNewLine]", \(u\_4\[AlignmentMarker] = \(a\_4\) b\_1 + 
            2 \( a\_1\) \(a\_3\) b\_2 + \(a\_2\%2\) b\_2 + 
            3 \( a\_1\%3\) \(a\_2\) b\_3 + \(a\_1\%4\) b\_4\), ",", 
        "\[IndentingNewLine]", "\[AlignmentMarker]   ", 
        "\[VerticalEllipsis]"}], TraditionalForm]], "DisplayFormula",
  TextAlignment->AlignmentMarker,
  FormatType->StandardForm,
  ZeroWidthTimes->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Inversion of Power Series", "Subsection"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(f\^\(-1\)\)(w)\), "\[AlignmentMarker]", "=", 
          RowBox[{
            RowBox[{\(\[Sum]\+\(k = 1\)\%\[Infinity]\), 
              
              RowBox[{\(v\_k\), \(w\^k\), Cell[
                "   where   "], \(f(\(f\^\(-1\)\)(w))\)}]}], "=", "w"}]}], 
        ",", \(a\_0 = \ 0\), ",", \(a\_1 \[NotEqual] \ 0\), ",", 
        "     ", \(v\_k\[AlignmentMarker] = \[Sum]\+\(S\_k\)\(\(n\_1!\)\/\(k\ \
a\_1\%k\)\) \((k + n\_1 + n\_2 + \[CenterEllipsis] + n\_k - 1; k - 1, n\_1, 
                n\_2, \[Ellipsis], 
                n\_k)\) \(\((\(-\(a\_2\/a\_1\)\))\)\^n\_2\) \(\
\[CenterEllipsis] \((\(-\(a\_k\/a\_1\)\))\)\)\^n\_k\)}], 
      TraditionalForm]], "DisplayFormula",
  CellMargins->{{60, Inherited}, {Inherited, Inherited}},
  FormatType->StandardForm],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`S\_k = \(n\_2 + 
            2  n\_3 + \[CenterEllipsis] + \((k - 1)\) n\_k = k - 1\)\)],
    FormatType->StandardForm],
  ". Then"
}], "Text"],

Cell[BoxData[{
    \(TraditionalForm\`v\_1\[AlignmentMarker] = 
      1/a\_\(\(1\)\(,\)\)\), "\[IndentingNewLine]", 
    \(TraditionalForm\`v\_2\[AlignmentMarker] = \(-a\_2\)/
        a\_1\%3, \[IndentingNewLine]v\_3\[AlignmentMarker] = \((2 
               a\_2\%2 - \(a\_1\) a\_3)\)/
        a\_1\%5, \[IndentingNewLine]v\_4\[AlignmentMarker] = \((\(-5\) 
              a\_2\%3 - 5 \( a\_1\) \(a\_2\) a\_3 + \(a\_1\%2\) a\_4)\)/
        a\_1\%7, \[IndentingNewLine]v\_5\[AlignmentMarker] = \((14\ a\_2\%4 - 
            21\ a\_1\ a\_2\%2\ a\_3 + 3\ a\_1\%2\ a\_3\%2 + 
            6\ a\_1\%2\ a\_2\ a\_4 - a\_1\%3\ a\_5)\)/
        a\_1\%9\), "\[IndentingNewLine]", 
    \(TraditionalForm\`\[VerticalEllipsis]\ \[AlignmentMarker]\)}], \
"DisplayFormula",
  CellMargins->{{106, Inherited}, {Inherited, Inherited}},
  TextAlignment->AlignmentMarker,
  FormatType->StandardForm]
}, Closed]],

Cell[CellGroupData[{

Cell["Laurent Series", "Subsection"],

Cell[TextData[{
  "The Laurent series, first ",
  "studied by Pierre Laurent in 1843, gives the following expansion for the \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " around a finite point ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \ \ \ \)\(f(
          z)\  \[LeftRightArrow] \ \[Sum]\+\(k = \(-\[Infinity]\)\)\%\
\[Infinity]\(\( c\_k\) \((z - z\_0)\)\)\^k\ \ \ \ where\ \ \ \ c\_k = 
      1\/\(2  \[Pi]\ \[ImaginaryI]\)\ \(\[Integral]\_\(C\_\[Rho]\)\(\(f \((t)\
\)\)\/\((t - z\_0)\)\^\(k + 1\)\) \[DifferentialD]t\), \ \ \ k \[Element] \
\[DoubleStruckCapitalZ], \)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\[Rho]\)],
    FormatType->StandardForm],
  " is the circle ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]t - 
            z\_0\[RightBracketingBar] = \[Rho]\)],
    FormatType->StandardForm],
  " with radius ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho], \ r < \[Rho] < R\)],
    FormatType->StandardForm],
  ". Here ",
  Cell[BoxData[
      \(TraditionalForm\`R\)],
    FormatType->StandardForm],
  " is the radius of convergence of its ",
  StyleBox["regular part ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 0\)\%\[Infinity]\(\( c\_k\)(z - \
z\_0)\)\^k\)],
    FormatType->StandardForm,
    FontWeight->"Plain"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\)],
    FormatType->StandardForm],
  " is the radius of convergence of its ",
  StyleBox["principal part",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = \(-\[Infinity]\)\)\%\(-1\)\(\(c\_k\)(z \
- z\_0)\)\^k = \[Sum]\+\(k = 1\)\%\[Infinity]\(\( c\_\(-k\)\)(z - \
z\_0)\)\^\(-k\)\)],
    FormatType->StandardForm,
    FontWeight->"Plain"],
  ". The coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(-1\)\)],
    FormatType->StandardForm],
  " of the ",
  Cell[BoxData[
      \(TraditionalForm\`\((z - z\_0)\)\^\(-1\)\)],
    FormatType->StandardForm],
  " term is called the ",
  StyleBox["residue",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`r < R\)],
    FormatType->StandardForm],
  ", then the Laurent series converges absolutely in the ring  ",
  Cell[BoxData[
      \(TraditionalForm\`r < \[LeftBracketingBar]z - 
            z\_0\[RightBracketingBar] < R\)],
    FormatType->StandardForm],
  ", where its sum defines an analytic function. If ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)],
    FormatType->StandardForm],
  " and the principal part includes only a finite number of terms (that is, \
if ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k = 0\)],
    FormatType->StandardForm,
    FontWeight->"Plain"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`k < \(-n\) < 0\)],
    FormatType->StandardForm],
  " for some ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Element] \(\[DoubleStruckCapitalN]\^+\)\)],
    FormatType->StandardForm],
  "), then ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " has a",
  StyleBox[" pole of order ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm,
    FontSlant->"Italic"],
  " at the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = z\_0\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[TextData[{
  "For example, the f",
  "unction ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(cot(z)\),
          ScriptLevel->0], TraditionalForm]],
    FormatType->StandardForm],
  " has a pole of order 1 (also called a ",
  StyleBox["simple pole",
    FontSlant->"Italic"],
  ") at the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)],
    FormatType->StandardForm],
  ", since it has only one term in the principal part of its Laurent series \
expansion:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`cot(
        z) = \(1\/z + \[Sum]\+\(k = 1\)\%\[Infinity]\(\(\(\((\(-1\))\)\^k\) \
\(2\^\(2  k\)\) B\_\(2  k\)\)\/\(\((2  k)\)!\)\) z\^\(2  k - 1\) = 
        1\/z - z\/3 - 
          z\^3\/45 + \(\(\[CenterEllipsis]\)\(.\)\)\)\)], "DisplayFormula",
  FormatType->StandardForm],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)],
    FormatType->StandardForm],
  " and the principal part includes an infinite number of terms, this \
analytic function has an ",
  StyleBox["essential singularity",
    FontSlant->"Italic"],
  " at the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = z\_0\)],
    FormatType->StandardForm],
  ". For example, the sum ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(k = \(-\[Infinity]\)\)\%0 \
z\^k/\(\((\(-k\))\)!\) = exp(1/z)\)],
    FormatType->StandardForm],
  " has an essential singularity at the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)],
    FormatType->StandardForm],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Puiseux Series", "Subsection"],

Cell[TextData[{
  "Puiseux series, first studied by Victor-Alexandre Puiseux in 1850, expand \
",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " around a finite point ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          z) \[LeftRightArrow] \[Sum]\+\(k = \
\(-\[Infinity]\)\)\%\[Infinity]\( c\_k\) \(\(\[CurlyPhi]\_k\)(z - z\_0)\)\)],
    FormatType->StandardForm],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CurlyPhi]\_k\)(w)\)],
    FormatType->StandardForm],
  " usually chosen as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CurlyPhi]\_k\)(z) = w\^\(k/m\)\)],
    FormatType->StandardForm],
  ". (Other choices for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[CurlyPhi]\_k\)(z)\)\(\ \)\)\)],
    FormatType->StandardForm],
  "are possible through the use of iterated logarithms of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[CurlyPhi]\_k\)(w)\), "=", 
          RowBox[{\(w\^\(k/m\)\), 
            RowBox[{
              SuperscriptBox["log", 
                AdjustmentBox["r",
                  BoxMargins->{{0.166667, -0.166667}, {0, 0}}]], "(", "w", 
              ")"}]}]}], TraditionalForm]],
    FormatType->StandardForm],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[CurlyPhi]\_k\)(w)\)\(=\)\)\)],
    FormatType->StandardForm],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(w\^\(k/m\)\), 
          RowBox[{
            SuperscriptBox["log", 
              AdjustmentBox["r",
                BoxMargins->{{0.166667, -0.166667}, {0, 0}}]], "(", "w", 
            ")"}], 
          RowBox[{
            SuperscriptBox["log", 
              AdjustmentBox["s",
                BoxMargins->{{0.166667, -0.166667}, {0, 0}}]], 
            "(", \(log(w)\), ")"}]}], TraditionalForm]],
    FormatType->StandardForm],
  ", and so on.) Choosing ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CurlyPhi]\_k\)(z) = w\^\(k/m\)\)],
    FormatType->StandardForm],
  " gives us"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \ \ \ \)\(f(
        z)\  \[LeftRightArrow] \ \[Sum]\+\(k = \
\(-\[Infinity]\)\)\%\[Infinity]\(\(\(\( c\_k\) \((z - z\_0)\)\)\^\(k/
                m\)\)\(.\)\)\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "If this series contains only a finite number of nonzero coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)],
    FormatType->StandardForm],
  " with negative indices ",
  Cell[BoxData[
      \(TraditionalForm\`k\)],
    FormatType->StandardForm],
  ", the point ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  " is an ",
  StyleBox["algebraic branch point",
    FontSlant->"Italic"],
  " of order ",
  Cell[BoxData[
      \(TraditionalForm\`m - 1\)],
    FormatType->StandardForm],
  "; otherwise it is a ",
  StyleBox["transcendental branch point",
    FontSlant->"Italic"],
  ", such as the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)],
    FormatType->StandardForm],
  " for the function ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(exp(1/z)\)\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell["\<\
The Puiseux series are widely used for describing solutions of \
differential equations near singular points and, in particular, for \
representations of elementary and special functions near their singular \
points. The named elementary functions can have rather complicated behavior \
near their singular points; the following examples show that such behavior \
can be studied using their expansions in Puiseux series.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 1",
    FontWeight->"Bold"],
  ". The point ",
  Cell[BoxData[
      \(TraditionalForm\`z = 1\)],
    FormatType->StandardForm],
  " is an algebraic branch point of order 1 for the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(cos\^\(-1\)\)(z)\)],
    FormatType->StandardForm],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\((\@\(1 - z\)/\@\(z - 1\))\) \(log(
          z + \@\(z - 1\)\ \@\(z + 1\))\)\)],
    FormatType->StandardForm],
  ", which has for its main branch at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 1\)],
    FormatType->StandardForm],
  " the Puiseux representation"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(cos\^\(-1\)\)(z)\), "=", " ", 
        RowBox[{
          RowBox[{\(\@2\), " ", \(\@\(1 - z\)\), " ", 
            RowBox[{\(\[Sum]\+\(k = 0\)\%\[Infinity]\), 
              RowBox[{
                FractionBox[
                  RowBox[{\(\((\(-1\))\)\^k\), " ", 
                    TagBox[\(\((1\/2)\)\_k\),
                      Pochhammer], 
                    " ", \(\((z - 1)\)\^k\)}], \(2\^k\ \((2\ k + 
                        1)\)\ \(k!\)\)], "    ", "where", 
                "   ", \(\[LeftBracketingBar]z - 
                    1\[RightBracketingBar]\)}]}]}], "<", "1."}]}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "A related representation occurs near the branch point ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(-1\)\)],
    FormatType->StandardForm],
  ". Near the branch point ",
  Cell[BoxData[
      \(TraditionalForm\`z = \[Infinity]\)],
    FormatType->StandardForm],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(cos\^\(-1\)\)(z)\)],
    FormatType->StandardForm],
  " can be expanded through the following series:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(cos\^\(-1\)\)(z)\), "=", 
        RowBox[{\(\[Pi]\/2\), "-", 
          RowBox[{\(\(\(z\)\(\ \)\)\/\(2\ \@\(-z\^2\)\)\), 
            RowBox[{"(", 
              RowBox[{\(log(\(-4\)\ z\^2)\), "-", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{\(\[Sum]\+\(k = 1\)\%\[Infinity]\), 
                    FractionBox[
                      RowBox[{" ", 
                        RowBox[{
                          TagBox[\(\((1\/2)\)\_k\),
                            Pochhammer], 
                          " ", \(z\^\(\(-2\)\ k\)\)}]}], \(k\ \(k!\)\)]}]}]}],
               ")"}]}]}]}], TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] > 1\)],
    FormatType->StandardForm],
  ", which shows that ",
  Cell[BoxData[
      \(TraditionalForm\`\(cos\^\(-1\)\)(z)\)],
    FormatType->StandardForm],
  " has a logarithmic-type singularity that can provide infinitely many \
values depending on the direction of approach."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2",
    FontWeight->"Bold"],
  ". The Puiseux series for ",
  Cell[BoxData[
      \(TraditionalForm\`z\^z\)],
    FormatType->StandardForm],
  " near the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)],
    FormatType->StandardForm],
  " includes powers of logarithmic functions:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`z\^z = \[Sum]\+\(k = 0\)\%\[Infinity]\(\(\(\( 
                    z\^k\) \(log\^k\) \((z)\)\)\/\(k!\)\)\(.\)\)\)], \
"DisplayFormula",
  FormatType->StandardForm,
  FontFamily->"Janson Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["Example 3",
    FontWeight->"Bold"],
  ". The Puiseux series for ",
  Cell[BoxData[
      \(TraditionalForm\`\(log\^2\)(log(z))\)],
    FormatType->StandardForm],
  " near the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)],
    FormatType->StandardForm],
  " coincides with this function."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4",
    FontWeight->"Bold"],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`W(z)\)],
    FormatType->StandardForm],
  " is the ",
  StyleBox["ProductLog", "MR"],
  " function, the Puiseux series for the function ",
  Cell[BoxData[
      \(TraditionalForm\`W(1/z)\)],
    FormatType->StandardForm],
  " near the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = \[Infinity]\)],
    FormatType->StandardForm],
  " has a more complicated structure involving iterated logarithms:"
}], "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{\(W(z)\), "=", "\[AlignmentMarker]", 
        RowBox[{\(log(z)\), "-", \(log(log(z))\), "+", 
          RowBox[{\(\[Sum]\+\(n = 1\)\%\[Infinity]\), 
            
            RowBox[{\(\((\(-1\))\)\^\(n - 1\)\/\(\(log\^n\) \((z)\)\)\), "  ",
               
              RowBox[{\(\[Sum]\+\(k = 1\)\%n\), 
                FractionBox[
                  RowBox[{
                    SubsuperscriptBox[
                      TagBox["S",
                        StirlingS1], "n", \((n - k + 1)\)], 
                    " ", \(log\^k\), \((log \((z)\))\)}], \(k!\)]}]}]}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[\(\(=\)\(\[AlignmentMarker]\)\(\(log(z)\)\(-\)\(log(
            log(z))\)\(+\)\(\(log \((log \((z)\))\)\)\/\(log \((z)\)\)\)\(+\)\
\(\(\(\ \)\(\(log\^2\) \((log \((z)\))\) - 
                log \((log \((z)\))\)\)\)\/\(2 \( 
                    log\^2\) \((z)\)\)\)\(+\)\(\[CenterEllipsis]\)\(\ \)\)\), 
      TraditionalForm]}], "DisplayFormula",
  CellMargins->{{134, Inherited}, {Inherited, Inherited}},
  TextAlignment->AlignmentMarker,
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] \
\[GreaterGreater] 1\)],
    FormatType->StandardForm],
  ". The inverses of simple functions tend to have a more complicated \
structure in their series expansions than the associated direct functions, \
and ",
  StyleBox["ProductLog", "MR"],
  " is no exception."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Dirichlet Series ", "Section"],

Cell[TextData[{
  "Dirichlet series for the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " take",
  StyleBox[" the form",
    FontWeight->"Plain"]
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(f(
        z) \[LeftRightArrow] \[Sum]\+\(k = 0\)\%\[Infinity]\( 
              a\_k\) \(\(exp(\(-\[Lambda]\_k\) 
                z)\)\(.\)\)\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "If all the exponents ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_k > 0\)],
    FormatType->StandardForm],
  ", the Dirichlet series converges in some open half-plane ",
  Cell[BoxData[
      \(TraditionalForm\`Re(z) > c\)],
    FormatType->StandardForm],
  ". In this case, for many Dirichlet series the abscissa of absolute \
convergence ",
  Cell[BoxData[
      \(TraditionalForm\`c\)],
    FormatType->StandardForm],
  " is"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`c = 
      lim\+\(k \[Rule] \[Infinity]\)\(\(\(log \((\[LeftBracketingBar]a\_k\
\[RightBracketingBar])\)\)\/\[Lambda]\_k\)\(.\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "In the more general case ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[LeftBracketingBar]\[Lambda]\_0\
\[RightBracketingBar] \[LessEqual] \[LeftBracketingBar]\[Lambda]\_1\
\[RightBracketingBar] \[LessEqual] \[Ellipsis]\)],
    FormatType->StandardForm],
  ", the Dirichlet series absolutely converges in some open convex domain. In \
both cases, the sum of the Dirichlet series is an analytic function in the \
domain of convergence."
}], "Text"],

Cell[TextData[{
  StyleBox["Examples",
    FontWeight->"Bold"],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_k = 2  k\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_k = 1\)],
    FormatType->StandardForm],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`a\_k = \((\(-1\))\)\^k\)],
    FormatType->StandardForm],
  " we have, respectively, the Dirichlet series"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(\[Sum]\+\(k = 0\)\%\[Infinity] \
\[ExponentialE]\^\(\(-2\) k\ z\)\[AlignmentMarker] = \(\(\[ExponentialE]\^z\) \
\(csch(z)\)\)\/2, \ \ \[Sum]\+\(k = 0\)\%\[Infinity]\(\((\(-1\))\)\^k\) \
\[ExponentialE]\^\(\(-2\) k\ z\)\[AlignmentMarker] = \(-\(\(\[ExponentialE]\^\
\(\(\ \)\(z\)\)\ \(sech(z)\)\)\/2\)\)\ \ \ \ when\ \ \ \ \(Re(z)\) > 
        0. \)\)\)], "DisplayFormula",
  TextAlignment->Center,
  TextJustification->0,
  FormatType->StandardForm],

Cell[TextData[{
  "In the case ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_k = log(k)\)],
    FormatType->StandardForm],
  ", we have the ",
  StyleBox["ordinary Dirichlet series",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(
          s) \[LeftRightArrow] \[Sum]\+\(k = 1\)\%\[Infinity]\((a\_k/
              k\^s)\)\)\(,\)\)\)],
    FormatType->StandardForm,
    FontWeight->"Plain"],
  " which in its simplest case (",
  Cell[BoxData[
      \(TraditionalForm\`a\_k = 1, \ Re(s) > 1\)],
    FormatType->StandardForm],
  ") is the Riemann zeta function  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta](
          z) = \[Sum]\+\(k = 1\)\%\[Infinity]\((1/k\^z)\)\)],
    FormatType->StandardForm,
    FontWeight->"Plain"],
  ".  Other interesting examples of Dirichlet series include the series for \
elliptic theta functions. For instance, if ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_k\), "=", 
          RowBox[{\(1\/2\), 
            StyleBox[\(q\^\(k\^2\)\),
              ScriptLevel->0]}]}], TraditionalForm]],
    FormatType->StandardForm,
    FontWeight->"Plain"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_k = \(\[MinusPlus]\(2\ k\ \[ImaginaryI]\)\
\)\)],
    FormatType->StandardForm],
  ", we have the representations"
}], "Text",
  ZeroWidthTimes->True],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            StyleBox[\(\[Sum]\+\(k = 1\)\%\[Infinity]\),
              ScriptLevel->0], 
            RowBox[{
              StyleBox[\(q\^\(k\^2\)\),
                ScriptLevel->0], 
              RowBox[{
                StyleBox["cos",
                  ScriptLevel->0], "(", 
                StyleBox[\(2\ k\ s\),
                  ScriptLevel->0], 
                StyleBox[")",
                  ScriptLevel->0]}]}]}], 
          StyleBox[
            RowBox[{
              StyleBox["\[AlignmentMarker]",
                ScriptLevel->0], "\[AlignmentMarker]"}]], "=", 
          RowBox[{
            RowBox[{
              RowBox[{\(1\/2\), 
                RowBox[{
                  StyleBox[\(\[Sum]\+\(k = 1\)\%\[Infinity]\),
                    ScriptLevel->0], 
                  RowBox[{
                    StyleBox[\(q\^\(k\^2\)\),
                      ScriptLevel->0], 
                    SuperscriptBox["\[ExponentialE]", 
                      StyleBox[\(2\ k\ \[ImaginaryI]\ s\),
                        ScriptLevel->0]]}]}]}], "+", 
              RowBox[{\(1\/2\), 
                RowBox[{
                  StyleBox[\(\[Sum]\+\(k = 1\)\%\[Infinity]\),
                    ScriptLevel->0], 
                  RowBox[{
                    StyleBox[\(q\^\(k\^2\)\),
                      ScriptLevel->0], 
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{
                        RowBox[{"-", 
                          StyleBox["2",
                            ScriptLevel->0]}], " ", 
                        StyleBox["k",
                          ScriptLevel->0], " ", "\[ImaginaryI]", " ", 
                        "s"}]]}]}]}]}], 
            "\[AlignmentMarker]\[AlignmentMarker]", "=", 
            RowBox[{
              RowBox[{
                StyleBox[
                  FractionBox[
                    RowBox[{
                      RowBox[{
                        StyleBox[\(\[CurlyTheta]\_3\),
                          ScriptLevel->0], 
                        RowBox[{"(", 
                          RowBox[{"s", 
                            StyleBox[",",
                              ScriptLevel->0], 
                            StyleBox["q",
                              ScriptLevel->0]}], 
                          StyleBox[")",
                            ScriptLevel->0]}]}], 
                      StyleBox["-",
                        ScriptLevel->0], 
                      StyleBox["1",
                        ScriptLevel->0], 
                      StyleBox[" ",
                        ScriptLevel->0]}], "2"],
                  ScriptLevel->0], "      ", 
                StyleBox["when",
                  "Text"], 
                StyleBox[
                  RowBox[{
                    StyleBox["    ",
                      "Text"], 
                    "  "}]], \(\[LeftBracketingBar]q\[RightBracketingBar]\)}],
               "<", "1.", " "}]}]}]}], TraditionalForm]], "DisplayFormula",
  TextAlignment->Center,
  FormatType->StandardForm,
  ZeroWidthTimes->True,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier Series ", "Section"],

Cell[CellGroupData[{

Cell["Discrete Fourier Series", "Subsection"],

Cell[TextData[{
  "Define ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_k\)(x)}, \ 
      k \[Element] \[DoubleStruckCapitalN], \)],
    FormatType->StandardForm],
  " as a ",
  StyleBox["system of functions",
    FontSlant->"Italic"],
  " defined on an interval ",
  Cell[BoxData[
      \(TraditionalForm\`\((a, b)\)\)],
    FormatType->StandardForm],
  ". If "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Integral]\+a\%b\(\( \[Psi]\_m\)(x)\) \(\(\[Psi]\_n\)(
              x)\) \[DifferentialD]x\), "=", 
        RowBox[{
          StyleBox["{",
            ShowAutoStyles->False,
            SpanMinSize->3,
            SpanMaxSize->Infinity], GridBox[{
              {\(\(0\)\(,\)\), \(\(m \[NotEqual] n\)\(,\)\)},
              {\(\(1\)\(,\)\), \(\(m = n\)\(,\)\)}
              }]}]}], TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm],

Cell[TextData[{
  "then the system ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_k\)(x)}\)],
    FormatType->StandardForm],
  " is an ",
  StyleBox["orthonormal system",
    FontSlant->"Italic"],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\((a, b)\)\)],
    FormatType->StandardForm],
  ". The ",
  StyleBox["Fourier series",
    FontSlant->"Italic"],
  " of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)],
    FormatType->StandardForm],
  " for this system is the series ",
  StyleBox["of the form",
    FontWeight->"Plain"]
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{\(f(
              x) \[LeftRightArrow] \[Sum]\+\(k = 0\)\%\[Infinity]\( 
                    c\_k\) \(\(\[Psi]\_k\)(x)\)\), ",", 
          RowBox[{
            RowBox[{Cell["    where    "], " ", \(c\_k\)}], 
            "=", \(\[Integral]\_a\%b\( f(t)\) \(\(\[Psi]\_k\)(
                  t)\) \[DifferentialD]t\)}], 
          ",", \(k \[Element] \(\(\[DoubleStruckCapitalN]\)\(.\)\)\)}]}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "Under some additional conditions (such as piecewise differentiability), \
this series with ",
  StyleBox["Fourier coefficients",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)],
    FormatType->StandardForm],
  " converges to ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)],
    FormatType->StandardForm],
  " at the points of continuity of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)],
    FormatType->StandardForm],
  ", and to ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/2\) \((f(x + 0) + f(x - 0))\)\)],
    FormatType->StandardForm],
  " at the points of discontinuity of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)],
    FormatType->StandardForm],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x \[PlusMinus] 0)\), "=", 
          
          StyleBox[\(\(\(\(lim\)\(\ \)\)\+\(\[CurlyEpsilon] \[Rule] \
\(+0\)\)\) \(f(x \[PlusMinus] \[CurlyEpsilon])\)\),
            ScriptLevel->0]}], TraditionalForm]],
    FormatType->StandardForm],
  ")."
}], "Text"],

Cell[TextData[{
  "The best-known examples of orthogonal systems are the orthogonal \
polynomials and the trigonometric system including ",
  Cell[BoxData[
      \(TraditionalForm\`cos(k\ x)\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`sin(k\ x)\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell["The series expansion by trigonometric system ", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(f(x) \[LeftRightArrow] 
      a\_0\/2 + \[Sum]\+\(k = 1\)\%\[Infinity]\( a\_k\) \(cos(
              k\ x)\) + \(b\_k\) \(sin(k\ x)\)\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k \[Element] \[DoubleStruckCapitalN]\)],
    FormatType->StandardForm],
  " and"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`a\_k = \(1\/\[Pi]\) \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\( 
              f(t)\) \(cos(
              k\ t)\) \[DifferentialD]t\), \ \ \ \ \ \ \ \ b\_k = \
\(1\/\[Pi]\) \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\( f(t)\) \(sin(
              k\ t)\) \[DifferentialD]t\), \)], "DisplayFormula",
  FormatType->StandardForm],

Cell[TextData[{
  "first appeared in an 1807 paper of Joseph Fourier, where he used a similar \
expansion on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 2  \[Pi])\)\)],
    FormatType->StandardForm],
  ", although Leonhard Euler had discovered the formulas for Fourier \
coefficients in 1777."
}], "Text"],

Cell[TextData[{
  "An arbitrary interval ",
  Cell[BoxData[
      \(TraditionalForm\`\((a, b)\)\)],
    FormatType->StandardForm],
  " can be transformed into the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\[Pi]\), \[Pi])\)\)],
    FormatType->StandardForm],
  " by the change of variable ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \(x(b - a)\)/\((2\ \[Pi])\) + \((a + b)\)/
            2\)],
    FormatType->StandardForm],
  ". This allows the following Fourier series expansion of absolutely \
integrable functions on an arbitrary interval ",
  Cell[BoxData[
      \(TraditionalForm\`\((a, b)\)\)],
    FormatType->StandardForm],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(f(x) \[LeftRightArrow] 
      a\_0\/2 + \[Sum]\+\(k = 1\)\%\[Infinity]\( a\_k\) \(cos(
              k\ \((x - \(a + b\)\/2)\) \(2  \[Pi]\)\/\(b - a\))\) + \(\(b\_k\
\) \(sin(k\ \((x - \(a + b\)\/2)\) \(2  \[Pi]\)\/\(b - a\))\)\(\ \)\)\)\)\)], \
"DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k \[Element] \[DoubleStruckCapitalN]\)],
    FormatType->StandardForm],
  " and"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`a\_k = \(2\/\(b - a\)\) \(\[Integral]\_a\%b\( f(
              t)\) \(cos(
              k\ \((t - \(a + b\)\/2)\) \(2  \[Pi]\)\/\(b - a\))\) \
\[DifferentialD]t\), \ 
    b\_k = \(2\/\(b - a\)\) \(\[Integral]\_a\%b\( f(t)\) \(sin(
              k\ \((t - \(a + b\)\/2)\) \(2  \[Pi]\)\/\(b - a\))\) \(\(\
\[DifferentialD]t\)\(.\)\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontFamily->"Janson Text",
  FontWeight->"Plain"],

Cell[TextData[{
  "The coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_k \[Rule] 0, b\_k \[Rule] 0\)],
    FormatType->StandardForm],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`k \[Rule] \[Infinity]\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[TextData[{
  "In the internal points ",
  Cell[BoxData[
      \(TraditionalForm\`x, \ \ a < x < b, \)],
    FormatType->StandardForm],
  " where the piecewise-differentiable function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)],
    FormatType->StandardForm],
  " is continuous, the sum of the previous Fourier series is equal to ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)],
    FormatType->StandardForm],
  " and we can change the symbol \[LeftRightArrow] to =. At the points of \
discontinuity, this sum is equal to ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/2\) \((f(x + 0) + f(x - 0))\)\)],
    FormatType->StandardForm],
  ". Outside the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\((a, b)\)\)],
    FormatType->StandardForm],
  ", this sum is a periodic function with the period ",
  Cell[BoxData[
      \(TraditionalForm\`b - a\)],
    FormatType->StandardForm],
  ", but the behavior of this sum is not necessarily related to the actual \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)],
    FormatType->StandardForm],
  " outside the interval of expansion."
}], "Text"],

Cell[TextData[{
  StyleBox["Example",
    FontWeight->"Bold"],
  ". Let ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = x\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((a, b)\) = \((\(-1\), 1)\)\)],
    FormatType->StandardForm],
  ". Then "
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`a\_k = 0, \ 
    b\_k = 2\ \(sin \((k\ \[Pi])\)\)\/\(k\^2\ \[Pi]\^2\) - \(2\ cos \((k\ \
\[Pi])\)\)\/\(k\ \[Pi]\), k \[Element] \[DoubleStruckCapitalN], 
    f(x) \[LeftRightArrow] \[Sum]\+\(k = 1\)\%\[Infinity]\((\(2\ sin \((k\ \
\[Pi])\)\)\/\(k\^2\ \[Pi]\^2\) - \(2\ cos \((k\ \[Pi])\)\)\/\(k\ \[Pi]\))\)\ \
\(sin(k\ \[Pi]\ x)\) = \(\(\(\[ImaginaryI]\)\(\ \)\)\/\[Pi]\) \(\(log(\
\[ExponentialE]\^\(\(-\[Pi]\)\ \[ImaginaryI]\ x\))\)\(.\)\)\)], \
"DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "Inspection shows that the Fourier sum ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[ImaginaryI]\)\(\ \)\)\/\[Pi]\) \(log(\
\[ExponentialE]\^\(\(-\[Pi]\)\ \[ImaginaryI]\ x\))\)\)],
    FormatType->StandardForm,
    FontWeight->"Plain"],
  " has period 2 and coincides with ",
  Cell[BoxData[
      \(TraditionalForm\`x\)],
    FormatType->StandardForm],
  " on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-1\), 1)\)\)],
    FormatType->StandardForm],
  ". But at the endpoint ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)],
    FormatType->StandardForm],
  " the Fourier sum is equal to 0, since we are evaluating "
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Sum]\+\(k = 1\)\%\[Infinity]\(\((\(2\ sin \((k\ \
\[Pi])\)\)\/\(k\^2\ \[Pi]\^2\) - \(2\ cos \((k\ \[Pi])\)\)\/\(k\ \[Pi]\))\)\(\
\ \)\(sin(k\ \[Pi])\)\(\ \)\)\)], "DisplayFormula",
  FormatType->StandardForm],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`sin(k\ \[Pi]) = 0\)],
    FormatType->StandardForm],
  ". This result coincides with "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(1\/2\), 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(\(\(lim\)\(\ \)\)\+\(x \[Rule] 1 - 0\)\),
                  ScriptLevel->0], 
                AdjustmentBox[\(\(\(\[ImaginaryI]\)\(\ \)\)\/\[Pi]\),
                  BoxMargins->{{0.111111, -0.111111}, {0, 
                  0}}], \(log(\[ExponentialE]\^\(\(-\[Pi]\)\ \[ImaginaryI]\ x\
\))\)}], "+", 
              RowBox[{
                StyleBox[\(\(\(lim\)\(\ \)\)\+\(x \[Rule] 1 + 0\)\),
                  ScriptLevel->0], 
                AdjustmentBox[\(\(\(\[ImaginaryI]\)\(\ \)\)\/\[Pi]\),
                  BoxMargins->{{0.111111, -0.111111}, {0, 
                  0}}], \(log(\[ExponentialE]\^\(\(-\[Pi]\)\ \[ImaginaryI]\ x\
\))\)}]}], ")"}]}], "=", \(\(1\/2\) \(\((1 - 1)\)\(.\)\)\)}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm]
}, Closed]],

Cell[CellGroupData[{

Cell["The Fourier Integral", "Subsection"],

Cell[TextData[{
  "The ",
  StyleBox["Fourier integral",
    FontSlant->"Italic"],
  " is the continuous analogue of a Fourier series, defined as"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`f(
        x) \[LeftRightArrow] \[Integral]\_0\%\[Infinity]\((\(a(t)\)\ \(cos(
                  t\ x)\) + \(b(t)\)\ \(sin(t\ x)\))\) \[DifferentialD]t, 
    a(t) = \(1\/\[Pi]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
              f(\[Tau])\)\ \(cos(t\ \[Tau])\) \[DifferentialD]\[Tau]\), 
    b(t) = \(1\/\[Pi]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
              f(\[Tau])\)\ \(sin(
              t\ \[Tau])\) \(\(\[DifferentialD]\[Tau]\)\(.\)\)\)\)], \
"DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "These formulas can be derived from the Fourier series expansion of the \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)],
    FormatType->StandardForm],
  " on interval ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-l\), l)\)\)],
    FormatType->StandardForm],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`l \[Rule] \[Infinity]\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[TextData[{
  "The substitution of ",
  Cell[BoxData[
      \(TraditionalForm\`a(t)\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b(t)\)],
    FormatType->StandardForm],
  " gives the Fourier integral formulas"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(f(
            x) \[LeftRightArrow] \(1\/\[Pi]\) \(\[Integral]\_0\%\[Infinity]\(\
\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(\[Tau])\)\ \(cos(
                    t\ \((x - \[Tau])\))\) \[DifferentialD]\[Tau] \
\[DifferentialD]t\)\)\), "=", 
        RowBox[{\(1\/\[Pi]\), 
          StyleBox[\(\(\(lim\)\(\ \)\)\+\(N \[Rule] \[Infinity]\)\),
            
            ScriptLevel->
              0], \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
                f(\[Tau])\)\ \(\(sin \((N\ \((x - \[Tau])\))\)\)\/\(x - \
\[Tau]\)\) \(\(\[DifferentialD]\[Tau]\)\(.\)\)\)}]}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell["\<\
The first definition above can be rewritten in exponential form \
leading to Fourier transforms and inverse Fourier transforms:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["f",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox[\((x)\),
              FontFamily->"Times"]}], 
          StyleBox["\[LeftRightArrow]",
            FontFamily->"Times"], 
          StyleBox[
            RowBox[{\(1\/\@\(2  \[Pi]\)\), 
              RowBox[{\(\[Integral]\+\(-\[Infinity]\)\%\[Infinity]\), 
                RowBox[{
                  OverscriptBox[
                    StyleBox["f",
                      FontWeight->"Plain"], 
                    "^"], \((t)\), \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ t\
\ x\)\), \(\[DifferentialD]t\)}]}]}],
            FontFamily->"Times"]}], 
        StyleBox[",",
          FontFamily->"Times"], 
        StyleBox["    ",
          FontFamily->"Times"], 
        RowBox[{
          StyleBox[
            RowBox[{
              OverscriptBox[
                StyleBox["f",
                  FontWeight->"Plain"], "^"], \((t)\)}],
            FontFamily->"Times"], 
          StyleBox["=",
            FontFamily->"Times"], 
          RowBox[{
            StyleBox[\(1\/\@\(2  \[Pi]\)\),
              FontFamily->"Times"], 
            RowBox[{
              StyleBox[\(\[Integral]\+\(-\[Infinity]\)\%\[Infinity]\),
                ScriptLevel->0,
                FontFamily->"Times"], 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times",
                  FontWeight->"Plain"], 
                StyleBox[\((\[Tau])\),
                  FontFamily->"Times"], 
                StyleBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ t\ \[Tau]\)\),
                  FontFamily->"Times"], 
                StyleBox[\(\(\[DifferentialD]\[Tau]\)\(.\)\),
                  FontFamily->"Times"]}]}]}]}]}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "For more information on these transforms, see the information box about \
the ",
  StyleBox["Exp", "MR"],
  " function. If the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)],
    FormatType->StandardForm],
  " is absolutely integrable on the real axis, we have the equality "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(1\/2\) \((f(x + 0) + f(x - 0))\)\), "=", 
        RowBox[{
          StyleBox[\(\(\(lim\)\(\ \)\)\+\(N \[Rule] \[Infinity]\)\),
            ScriptLevel->0], \(1\/\@\(2  \[Pi]\)\), 
          RowBox[{\(\[Integral]\+\(-N\)\%N\), 
            RowBox[{
              RowBox[{
                OverscriptBox[
                  StyleBox["f",
                    FontWeight->"Plain"], "^"], "(", "t", 
                ")"}], \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ t\ x\)\), \
\(\(\[DifferentialD]t\)\(.\)\)}]}]}]}], TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Branch Cuts and Branch Points", "Title"],

Cell[TextData[{
  "Many of the functions on this poster have ",
  StyleBox["branch cuts",
    FontSlant->"Italic"],
  ", lines in the complex domain where the function is discontinuous. To \
understand what branch cuts are and why they are necessary, we can start with \
an analogy from real numbers. The graph of the complete inverse sine \
function, part of which is shown in red below, is simply the graph of ",
  Cell[BoxData[
      \(TraditionalForm\`y = sin(x)\)],
    FormatType->StandardForm],
  " reflected along the line ",
  Cell[BoxData[
      \(TraditionalForm\`y = x\)],
    FormatType->StandardForm],
  ". "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.222222 0.111111 0.222222 0.111111 [
[.22222 -0.0125 -3.53125 -7 ]
[.22222 -0.0125 3.53125 0 ]
[.44444 -0.0125 -3.5625 -7 ]
[.44444 -0.0125 3.5625 0 ]
[.66667 -0.0125 -3.46875 -7 ]
[.66667 -0.0125 3.46875 0 ]
[.88889 -0.0125 -3.4375 -7 ]
[.88889 -0.0125 3.4375 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .22222 -7.0625 -3.5 ]
[-0.0125 .22222 0 3.5 ]
[-0.0125 .44444 -7.125 -3.5 ]
[-0.0125 .44444 0 3.5 ]
[-0.0125 .66667 -6.9375 -3.5 ]
[-0.0125 .66667 0 3.5 ]
[-0.0125 .88889 -6.875 -3.5 ]
[-0.0125 .88889 0 3.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22222 0 m
.22222 .00625 L
s
gsave
.22222 -0.0125 -64.5312 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.44444 0 m
.44444 .00625 L
s
gsave
.44444 -0.0125 -64.5625 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -64.4688 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.88889 0 m
.88889 .00625 L
s
gsave
.88889 -0.0125 -64.4375 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.11111 0 m
.11111 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38889 0 m
.38889 .00375 L
s
.5 0 m
.5 .00375 L
s
.55556 0 m
.55556 .00375 L
s
.61111 0 m
.61111 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .22222 m
.00625 .22222 L
s
gsave
-0.0125 .22222 -68.0625 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .44444 m
.00625 .44444 L
s
gsave
-0.0125 .44444 -68.125 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .66667 m
.00625 .66667 L
s
gsave
-0.0125 .66667 -67.9375 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .88889 m
.00625 .88889 L
s
gsave
-0.0125 .88889 -67.875 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05556 m
.00375 .05556 L
s
0 .11111 m
.00375 .11111 L
s
0 .16667 m
.00375 .16667 L
s
0 .27778 m
.00375 .27778 L
s
0 .33333 m
.00375 .33333 L
s
0 .38889 m
.00375 .38889 L
s
0 .5 m
.00375 .5 L
s
0 .55556 m
.00375 .55556 L
s
0 .61111 m
.00375 .61111 L
s
0 .72222 m
.00375 .72222 L
s
0 .77778 m
.00375 .77778 L
s
0 .83333 m
.00375 .83333 L
s
0 .94444 m
.00375 .94444 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.22222 .99375 m
.22222 1 L
s
.44444 .99375 m
.44444 1 L
s
.66667 .99375 m
.66667 1 L
s
.88889 .99375 m
.88889 1 L
s
.125 Mabswid
.05556 .99625 m
.05556 1 L
s
.11111 .99625 m
.11111 1 L
s
.16667 .99625 m
.16667 1 L
s
.27778 .99625 m
.27778 1 L
s
.33333 .99625 m
.33333 1 L
s
.38889 .99625 m
.38889 1 L
s
.5 .99625 m
.5 1 L
s
.55556 .99625 m
.55556 1 L
s
.61111 .99625 m
.61111 1 L
s
.72222 .99625 m
.72222 1 L
s
.77778 .99625 m
.77778 1 L
s
.83333 .99625 m
.83333 1 L
s
.94444 .99625 m
.94444 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .22222 m
1 .22222 L
s
.99375 .44444 m
1 .44444 L
s
.99375 .66667 m
1 .66667 L
s
.99375 .88889 m
1 .88889 L
s
.125 Mabswid
.99625 .05556 m
1 .05556 L
s
.99625 .11111 m
1 .11111 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .38889 m
1 .38889 L
s
.99625 .5 m
1 .5 L
s
.99625 .55556 m
1 .55556 L
s
.99625 .61111 m
1 .61111 L
s
.99625 .72222 m
1 .72222 L
s
.99625 .77778 m
1 .77778 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .94444 m
1 .94444 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
0 .12119 m
.00942 .11763 L
.01975 .11461 L
.02496 .11343 L
.03053 .11243 L
.03323 .11205 L
.03578 .11175 L
.03825 .11151 L
.04057 .11134 L
.0419 .11126 L
.04311 .11121 L
.04447 .11116 L
.04521 .11114 L
.04592 .11113 L
.0466 .11112 L
.04733 .11111 L
.04864 .11112 L
.04944 .11112 L
.05019 .11114 L
.05087 .11116 L
.0516 .11118 L
.05283 .11123 L
.05418 .1113 L
.0569 .11149 L
.05943 .11173 L
.06178 .112 L
.06759 .11289 L
.07289 .11396 L
.08481 .11725 L
.09522 .12112 L
.10485 .12549 L
.12665 .138 L
.16788 .17002 L
.20751 .20756 L
.24973 .24945 L
.29035 .28616 L
.31098 .30184 L
.33355 .31583 L
.34397 .32103 L
.3551 .32562 L
.36561 .329 L
.37515 .33124 L
.38024 .33211 L
.38303 .33249 L
.38563 .33278 L
.38804 .33299 L
.39023 .33314 L
.39149 .33321 L
.39267 .33326 L
.39393 .3333 L
Mistroke
.3953 .33332 L
.39601 .33333 L
.39678 .33333 L
.39751 .33333 L
.39818 .33332 L
.39944 .3333 L
.40078 .33326 L
.40223 .3332 L
.40357 .33312 L
.40663 .3329 L
.40928 .33263 L
.4117 .33233 L
.41713 .33147 L
.4222 .33043 L
.42757 .32909 L
.43721 .32605 L
.45903 .31634 L
.47951 .30391 L
.49872 .28974 L
.53939 .25368 L
.58265 .21088 L
.62431 .17119 L
.66438 .13965 L
.68501 .12734 L
.69647 .12189 L
.70702 .11782 L
.7178 .11463 L
.72348 .11335 L
.72947 .11231 L
.73199 .11197 L
.73469 .11167 L
.73724 .11144 L
.73956 .11129 L
.74098 .11122 L
.74229 .11117 L
.74297 .11115 L
.74372 .11113 L
.74451 .11112 L
.74525 .11111 L
.74661 .11111 L
.74785 .11113 L
.74921 .11116 L
.7499 .11119 L
.75065 .11122 L
.7533 .11136 L
.7548 .11147 L
.75618 .11159 L
.76142 .1122 L
.76617 .11297 L
.77121 .114 L
Mistroke
.78168 .11685 L
.7932 .12106 L
.8136 .13115 L
.83552 .1454 L
.87883 .18166 L
.92055 .22241 L
.96067 .26166 L
1 .29522 L
Mfstroke
gsave
.88889 .33333 -73.8125 -7.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15.375 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.438 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
72.125 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.562 9.000 moveto
(@) show
80.250 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.000 9.000 moveto
(D) show
84.625 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.12119 0 m
.11708 .01111 L
s
.11708 .01111 m
.11402 .02222 L
s
.11402 .02222 m
.11204 .03333 L
s
.11204 .03333 m
.11116 .04444 L
s
.11116 .04444 m
.11139 .05556 L
s
.11139 .05556 m
.11273 .06667 L
s
.11273 .06667 m
.11516 .07778 L
s
.11516 .07778 m
.11866 .08889 L
s
.11866 .08889 m
.1232 .1 L
s
.1232 .1 m
.12873 .11111 L
s
.12873 .11111 m
.13519 .12222 L
s
.13519 .12222 m
.14252 .13333 L
s
.14252 .13333 m
.15064 .14444 L
s
.15064 .14444 m
.15948 .15556 L
s
.15948 .15556 m
.16895 .16667 L
s
.16895 .16667 m
.17895 .17778 L
s
.17895 .17778 m
.18939 .18889 L
s
.18939 .18889 m
.20015 .2 L
s
.20015 .2 m
.21113 .21111 L
s
.21113 .21111 m
.22222 .22222 L
s
.22222 .22222 m
.23331 .23333 L
s
.23331 .23333 m
.2443 .24444 L
s
.2443 .24444 m
.25506 .25556 L
s
.25506 .25556 m
.26549 .26667 L
s
.26549 .26667 m
.27549 .27778 L
s
.27549 .27778 m
.28496 .28889 L
s
.28496 .28889 m
.2938 .3 L
s
.2938 .3 m
.30193 .31111 L
s
.30193 .31111 m
.30926 .32222 L
s
.30926 .32222 m
.31572 .33333 L
s
.31572 .33333 m
.32125 .34444 L
s
.32125 .34444 m
.32578 .35556 L
s
.32578 .35556 m
.32928 .36667 L
s
.32928 .36667 m
.33172 .37778 L
s
.33172 .37778 m
.33305 .38889 L
s
.33305 .38889 m
.33329 .4 L
s
.33329 .4 m
.33241 .41111 L
s
.33241 .41111 m
.33043 .42222 L
s
.33043 .42222 m
.32737 .43333 L
s
.32737 .43333 m
.32326 .44444 L
s
.32326 .44444 m
.31813 .45556 L
s
.31813 .45556 m
.31206 .46667 L
s
.31206 .46667 m
.30508 .47778 L
s
.30508 .47778 m
.29727 .48889 L
s
.29727 .48889 m
.28872 .5 L
s
.28872 .5 m
.2795 .51111 L
s
.2795 .51111 m
.26971 .52222 L
s
.26971 .52222 m
.25944 .53333 L
s
.25944 .53333 m
.24881 .54444 L
s
.24881 .54444 m
.2379 .55556 L
s
.2379 .55556 m
.22684 .56667 L
s
.22684 .56667 m
.21574 .57778 L
s
.21574 .57778 m
.20469 .58889 L
s
.20469 .58889 m
.19383 .6 L
s
.19383 .6 m
.18325 .61111 L
s
.18325 .61111 m
.17305 .62222 L
s
.17305 .62222 m
.16335 .63333 L
s
.16335 .63333 m
.15424 .64444 L
s
.15424 .64444 m
.1458 .65556 L
s
.1458 .65556 m
.13813 .66667 L
s
.13813 .66667 m
.1313 .67778 L
s
.1313 .67778 m
.12538 .68889 L
s
.12538 .68889 m
.12043 .7 L
s
.12043 .7 m
.11649 .71111 L
s
.11649 .71111 m
.11361 .72222 L
s
.11361 .72222 m
.11181 .73333 L
s
.11181 .73333 m
.11112 .74444 L
s
.11112 .74444 m
.11154 .75556 L
s
.11154 .75556 m
.11306 .76667 L
s
.11306 .76667 m
.11568 .77778 L
s
.11568 .77778 m
.11935 .78889 L
s
.11935 .78889 m
.12406 .8 L
s
.12406 .8 m
.12975 .81111 L
s
.12975 .81111 m
.13636 .82222 L
s
.13636 .82222 m
.14383 .83333 L
s
.14383 .83333 m
.15208 .84444 L
s
.15208 .84444 m
.16103 .85556 L
s
.16103 .85556 m
.1706 .86667 L
s
.1706 .86667 m
.18068 .87778 L
s
.18068 .87778 m
.19118 .88889 L
s
.19118 .88889 m
.20198 .9 L
s
.20198 .9 m
.21299 .91111 L
s
.21299 .91111 m
.22409 .92222 L
s
.22409 .92222 m
.23517 .93333 L
s
.23517 .93333 m
.24612 .94444 L
s
.24612 .94444 m
.25684 .95556 L
s
.25684 .95556 m
.26721 .96667 L
s
.26721 .96667 m
.27712 .97778 L
s
.27712 .97778 m
.28649 .98889 L
s
.28649 .98889 m
.29522 1 L
s
gsave
.33333 .88889 -73.8125 -7.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15.375 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(x) show
67.250 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(=) show
71.938 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
78.375 9.000 moveto
(@) show
80.125 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
83.000 9.000 moveto
(D) show
84.625 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
0 0 m
1 1 L
s
gsave
.77778 .88889 -68.9688 -7.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15.375 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.125 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
67.438 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(=) show
72.188 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
74.938 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  FormatType->StandardForm,
  ImageSize->{121, 121},
  ImageMargins->{{125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001i0000NA000`40O003h00ONGoo001iOol007Uo
o`00NGoo000OOol2000GOol2000HOol00`00Oomoo`0EOol3000<Ool001moo`03001oo`0001Moo`03
001oogoo01Eoo`<001Ioo`03001oo`0000aoo`007goo00<007oo000067oo00<007ooOol05Woo00<0
07ooOol05Goo00<007ooOol02goo000POol2000GOol2000aOol00`00Oomoo`0:Ool007Uoo`0027oo
00<07`0000002`0000=l00000000G`000Goo0008Ool00`0001moo`0:Ool00g`0Oomoo`09Ool00`00
Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`09Ool10001Ool000Qoo`03001o
o`0O00Yoo`03O01oogoo05moo`40005oo`0027oo00@007ooOol07`Uoo`03O01oogoo05moo`40005o
o`0027oo00D007ooOomoo`0O00Moo`03O01oogoo061oo`40005oo`0027oo00<007ooOol00Woo00<0
7gooOol017oo00=l07ooOol0H7oo0@000Goo0008Ool00`00Oomoo`03Ool00`0OOomoo`03Ool00g`0
Oomoo`1POol10001Ool000Qoo`03001oogoo00Aoo`0301moogoo00=oo`03O01oogoo05moo`40005o
o`0027oo00<007ooOol01Goo00<07gooOol00Woo00=l07ooOol0Ggoo0@000Goo0008Ool00`00Oomo
o`06Ool01@0OOomoogooO000HGoo0@000Goo0008Ool00`00Oomoo`07Ool0100OOomoog`0HGoo0@00
0Goo0008Ool00`00Oomoo`08Ool0100OOomoog`0H7oo0@000Goo0008Ool01000Oomoogoo100017oo
00<07gooO000@goo0`006Woo0@000Goo0008Ool40004Ool30002Ool00`0OO01oo`0oOol30003Ool5
000EOol10001Ool000Qoo`03001oogoo00Qoo`<0000301ml07oo03]oo`<000]oo`03001oogoo019o
o`40005oo`0027oo00<007ooOol02goo00<0000OO000>Woo00<007ooOol03Goo0P004Woo0@000Goo
0008Ool00`00Oomoo`0=Ool00`0OO01oo`0fOol2000BOol2000@Ool10001Ool000Qoo`03001oogoo
00ioo`0301ml07oo03Aoo`03001oogoo01Aoo`03001oogoo00eoo`40005oo`0027oo00<007ooOol0
3goo00<07gooOol0<Woo00<007ooOol05Woo00<007ooOol037oo0@000Goo0008Ool00`00Oomoo`0@
Ool00`0OOomoo`0_Ool2000JOol00`00Oomoo`0;Ool10001Ool000Qoo`03001oogoo015oo`0301mo
ogoo02eoo`03001oogoo01]oo`03001oogoo00Yoo`40005oo`0027oo00<007ooOol04Woo00<07goo
Ool0:goo00<007ooOol07Goo00<007ooOol02Goo0@000Goo0008Ool00`00Oomoo`0COol00`0OOomo
o`0YOol00`00Oomoo`0OOol00`00Oomoo`08Ool10001Ool000Qoo`03001oogoo01Aoo`0301moogoo
02Moo`03001oogoo025oo`03001oogoo00Moo`40005oo`000Woo0P0017oo00<007ooOol05Goo00<0
7gooOol09Goo00<007ooOol08goo00<007ooOol01Woo0@000Goo0002Ool00`00Ool00003Ool2000G
Ool00`0OOomoo`0SOol00`00Oomoo`0UOol00`00Oomoo`05Ool10001Ool0009oo`03001oo`0000=o
o`03001oogoo01Moo`0301moogoo025oo`03001oogoo02Moo`03001oogoo00Aoo`40005oo`000goo
0P000goo00<007ooOol067oo00<07gooOol07goo00<007ooOol0:Goo00<007ooOol00goo0@000Goo
0008Ool00`00Oomoo`0IOol00`0OOomoo`0MOol00`00Oomoo`0[Ool00`00Oomoo`02Ool10001Ool0
00Qoo`03001oogoo01Yoo`0301moogoo01]oo`03001oogoo02eoo`05001oogooOol00001Ool000Qo
o`03001oogoo01]oo`0301moogoo01Uoo`03001oogoo02moo`04001oogoo0001Ool000Qoo`03001o
ogoo01aoo`0301moogoo01Moo`03001oogoo035oo`03001oo`00005oo`0027oo00<007ooOol07Goo
00<07`00Ool057oo0P00=Goo0P000Goo0008Ool00`00Oomoo`0NOol00`0O001oo`0BOol00`00Oomo
o`0fOol10001Ool000Qoo`03001oogoo01ioo`04O0007`00000?Ool2000iOol10001Ool000Qoo`03
001oogoo01moo`04O0007goo000<Ool2000kOol10001Ool000Qoo`03001oogoo01moo`04O01oo`0O
Ool30008Ool00`00Oomoo`0TOol00`00Oomoo`0=Ool01@00Oomoogoo00000Woo0@000Goo0008Ool0
0`00Oomoo`0POol00g`0Ool07`03Ool8000XOol00`00Oomoo`05Ool200000goo00000002Ool30000
1Goo001oogoo00000Goo0008Ool00`00Oomoo`0QOol00g`0Ool07`0aOol20004Ool01000Oomoogoo
0P0000=oo`0000000P0000Aoo`00Ool0009oo`40005oo`0027oo00<007ooOol08Goo00Al07ooOol0
7cUoo`03001oogoo00Aoo`05001oogooOol00002Ool10001Ool000Qoo`03001oogoo025oo`05O01o
ogooOol07`0iOol2000;Ool10001Ool000Qoo`03001oogoo029oo`05O01oogooOol07`15Ool10001
Ool000Qoo`03001oogoo029oo`03O01oogoo009oo`0301moogoo049oo`40005oo`0027oo00<007oo
Ool08Woo00=l07ooOol00goo00<07gooOol0@Goo0@000Goo0008Ool00`00Oomoo`0ROol00g`0Oomo
o`04Ool00`0OOomoo`10Ool10001Ool000Qoo`03001oogoo029oo`03O01oogoo00Eoo`0301moogoo
03moo`40005oo`0027oo00<007ooOol08Woo00=l07ooOol01Woo00<07gooOol0?Woo0@000Goo0008
Ool00`00Oomoo`0ROol00g`0Oomoo`07Ool00`0OOomoo`0mOol10001Ool000Qoo`03001oogoo025o
o`03O01oogoo00Uoo`0301moogoo03aoo`40005oo`000Woo0P0017oo00<007ooOol08Goo00=l07oo
Ool02Woo00<07gooOol0>goo0@000Goo0003Ool00`00Oomoo`02Ool2000ROol00g`0Oomoo`0;Ool0
0`0OOomoo`0jOol10001Ool000Aoo`05001oogooOol0000ROol00g`0Oomoo`0=Ool00`0OOomoo`0i
Ool10001Ool000=oo`8000=oo`03001oogoo021oo`03O01oogoo00ioo`0301moogoo03Qoo`40005o
o`0027oo00<007ooOol07goo00=l07ooOol047oo00<07gooOol0=goo0@000Goo0008Ool00`00Oomo
o`0NOol00g`0Oomoo`0BOol00`0OOomoo`0fOol10001Ool000Qoo`03001oogoo01ioo`03O01oogoo
01=oo`0301moogoo03Eoo`40005oo`0027oo00<007ooOol07Goo00=l07ooOol05Goo00<07gooOol0
=7oo0@000Goo0008Ool00`00Oomoo`0LOol00g`0Oomoo`0GOol00`0OOomoo`0cOol10001Ool000Qo
o`03001oogoo01]oo`03O01oogoo01Uoo`0301moogoo039oo`40005oo`0027oo00<007ooOol06Woo
00=l07ooOol06goo00<07gooOol0<Goo0@000Goo0008Ool00`00Oomoo`0JOol00g`0Oomoo`0LOol0
0`0OOomoo`0`Ool10001Ool000Qoo`03001oogoo01Uoo`03O01oogoo01ioo`0301moogoo02moo`40
005oo`0027oo00<007ooOol05goo0W`08Woo00<07gooOol0;Woo0@000Goo0008Ool00`00Oomoo`0F
Ool00g`0Oomoo`0SOol00`0OOomoo`0]Ool10001Ool000Qoo`03001oogoo01Eoo`03O01oogoo02Eo
o`0301moogoo02aoo`40005oo`0027oo00<007ooOol05Goo00=l07ooOol09Woo00<07gooOol0:goo
0@000Goo0008Ool00`00Oomoo`0DOol00g`0Oomoo`0XOol00`0OOomoo`0ZOol10001Ool000Qoo`03
001oogoo019oo`9l02aoo`0301moogoo02Uoo`40005oo`0027oo00<007ooOol04Goo00=l07ooOol0
;Goo00<07gooOol0:7oo0@000Goo0008Ool00`00Oomoo`0@Ool00g`0Oomoo`0_Ool00`0OOomoo`0W
Ool10001Ool000Qoo`03001oogoo011oo`03O01oogoo031oo`0301moogoo02Ioo`40005oo`0027oo
00<007ooOol03goo00=l07ooOol0<Woo00<07gooOol09Goo0@000Goo0008Ool00`00Oomoo`0>Ool0
0g`0Oomoo`0dOol00`0OOomoo`0TOol10001Ool000Qoo`03001oogoo00eoo`03O01oogoo03Ioo`03
01moogoo02=oo`40005oo`000goo00<007ooOol00Woo0P003Goo00=l07ooOol0>7oo00<07gooOol0
8Woo0@000Goo0002Ool30003Ool00`00Oomoo`0<Ool00g`0Oomoo`0iOol00`0OOomoo`0QOol10001
Ool000Aoo`05001oogooOol0000>Ool00g`0Oomoo`0jOol00`0OOomoo`0POol10001Ool000Qoo`03
001oogoo00]oo`03O01oogoo03aoo`0301moogoo01moo`40005oo`0027oo00<007ooOol02Woo00=l
07ooOol0?Woo00<07gooOol07Woo0@000Goo0008Ool00`00Oomoo`0:Ool00g`0Oomoo`0oOol00`0O
Oomoo`0MOol10001Ool000Qoo`03001oogoo00Yoo`03O01oogoo041oo`0301moogoo01aoo`40005o
o`0027oo00<007ooOol02Woo00=l07ooOol0@Goo00<07gooOol06goo0@000Goo0008Ool00`00Oomo
o`09Ool00g`0Oomoo`13Ool00`0OOomoo`0JOol10001Ool000Qoo`03001oogoo00Uoo`03O01oogoo
04Aoo`0301moogoo01Uoo`40005oo`0027oo00<007ooOol02Goo00=l07ooOol0AGoo00<07gooOol0
67oo0@000Goo0008Ool00`00Oomoo`0:Ool00g`0Oomoo`15Ool00`0OOomoo`0GOol10001Ool000Qo
o`03001oogoo00Yoo`03O01oogoo04Ioo`0301moogoo01Ioo`40005oo`0027oo00<007ooOol02Woo
00=l07ooOol0Agoo00<07gooOol05Goo0@000Goo0008Ool00`00Oomoo`0:Ool00g`0Oomoo`18Ool0
0`0OOomoo`0DOol10001Ool000Qoo`03001oogoo00]oo`03O01oogoo04Qoo`0301moogoo01=oo`40
005oo`0027oo00<007ooOol02goo00=l07ooOol0BGoo00<07gooOol04Woo0@000Goo0008Ool00`00
Oomoo`0;Ool00g`0Oomoo`1:Ool00`0OOomoo`0AOol10001Ool000Qoo`03001oogoo00aoo`03O01o
ogoo04Yoo`0301moogoo011oo`40005oo`0027oo00<007ooOol03Goo00=l07ooOol0BWoo00<07goo
Ool03goo0@000Goo0008Ool00`00Oomoo`0>Ool00g`0Oomoo`1:Ool00`0OOomoo`0>Ool10001Ool0
00Qoo`03001oogoo00moo`03O01oogoo04Yoo`0301moogoo00eoo`40005oo`0027oo00<007ooOol0
3goo00=l07ooOol0Bgoo00<07gooOol037oo0@000Goo0008Ool00`00Oomoo`0@Ool00g`0Oomoo`1;
Ool00`0OOomoo`0;Ool10001Ool0009oo`<000=oo`03001oogoo015oo`03O01oogoo01=oo`05O01o
og`0Ooml000ROol00`0OOomoo`0>Ool00`0OOomoo`0:Ool10001Ool0009oo`03001oo`0000=oo`80
01=oo`9l00=oo`9l00Moo`9l0003Ooml07`0009oo`03O01oogoo009l02=oo`0301moogoo00Eoo`80
7`Moo`0301moogoo00Uoo`40005oo`000goo00<007ooOol00Woo00<007ooOol057oo00El07ooOomo
og`000Aoo`04O01oogooOol2O0000gooO01l0002O00017ooO01l07`08Woo0P0O0goo00<07gooOol0
0Woo00<07gooOol01Woo00<07gooOol027oo0@000Goo0004Ool01@00Oomoogoo00005goo00=l07oo
Ool027oo00=l07ooOol017oo00El07ooOomoog`003Ioo`0301moogoo00Moo`40005oo`0027oo00<0
07ooOol05Goo00=l07ooOol02Goo0W`0@7oo00<07gooOol01Woo0@000Goo0008Ool00`00Oomoo`0F
Ool00g`0Oomoo`1;Ool00`0OOomoo`05Ool10001Ool000Qoo`03001oogoo01Moo`03O01oogoo04]o
o`0301moogoo00Aoo`40005oo`0027oo00<007ooOol067oo0W`0C7oo00<07gooOol00goo0@000Goo
0008Ool00`00Oomoo`0JOol00g`0Oomoo`1:Ool00`0OOomoo`02Ool10001Ool000Qoo`03001oogoo
01Yoo`03O01oogoo04]oo`0501moogooOol00001Ool000Qoo`03001oogoo01]oo`03O01oogoo04]o
o`0401moogoo0001Ool000Qoo`03001oogoo01aoo`03O01oogoo04]oo`0301moo`00005oo`0027oo
00<007ooOol07Goo00=l07ooOol0Bgoo0@0O0@000Goo0008OolQ00000g`00000001;000101l1Ool0
0001\
\>"],
  ImageRangeCache->{{{0, 120}, {120, 0}} -> {-2.6884, -2.6884, 0.0808213, \
0.0808213}}],

Cell[TextData[{
  "Because each ",
  Cell[BoxData[
      \(TraditionalForm\`x\)],
    FormatType->StandardForm],
  " value in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) \[LessEqual] x \[LessEqual] 1\)],
    FormatType->StandardForm],
  " corresponds to an infinite number of ",
  Cell[BoxData[
      \(TraditionalForm\`y\)],
    FormatType->StandardForm],
  " values such that ",
  Cell[BoxData[
      \(TraditionalForm\`y = \(sin\^\(-1\)\)(x)\)],
    FormatType->StandardForm],
  ", the complete arcsine function is ",
  StyleBox["one-to-many",
    FontSlant->"Italic"],
  " or ",
  StyleBox["multivalued",
    FontSlant->"Italic"],
  ". But ",
  Cell[BoxData[
      \(TraditionalForm\`\(sin\^\(-1\)\)(x)\)],
    FormatType->StandardForm],
  " can be divided into a set of one-to-one functions, each one covering some \
segment of the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)],
    FormatType->StandardForm],
  " axis \[Pi] units long in which ",
  Cell[BoxData[
      \(TraditionalForm\`x\)],
    FormatType->StandardForm],
  " ranges from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)],
    FormatType->StandardForm],
  " to 1. By convention the ",
  StyleBox["principal value",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`\(sin\^\(-1\)\)(x)\)],
    FormatType->StandardForm],
  " is taken to fall within the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]y\[RightBracketingBar] < \[Pi]/
          2\)],
    FormatType->StandardForm],
  ", but any of the other possible one-to-one functions also fulfills the \
definition ",
  Cell[BoxData[
      \(TraditionalForm\`x = sin(\(sin\^\(-1\)\)(x))\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[TextData[{
  "We will use a similar argument to discuss the branch cut of the logarithm \
function ",
  Cell[BoxData[
      \(TraditionalForm\`ln(z)\)],
    FormatType->StandardForm],
  ", and again we begin by examining its inverse function, ",
  Cell[BoxData[
      \(TraditionalForm\`exp(z) = \[ExponentialE]\^z\)],
    FormatType->StandardForm],
  ". This is a periodic function for complex ",
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm],
  ", since ",
  Cell[BoxData[
      \(TraditionalForm\`exp(z)\)],
    FormatType->StandardForm],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`exp(
        z + \[ExponentialE]\^\(2\ k\ \[Pi]\ \[ImaginaryI]\))\)],
    FormatType->StandardForm],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`k \[Element] \[DoubleStruckCapitalZ]\)],
    FormatType->StandardForm],
  ". The periodic nature of the function can be shown with a parametric plot \
of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)],
    FormatType->StandardForm],
  " for points from the strip ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < Re(z) < 5\)],
    FormatType->StandardForm],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < Im(z) \[LessEqual] 10  \[Pi]\)],
    FormatType->StandardForm],
  ". (We do not let the real part of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm],
  " go all the way to ",
  Cell[BoxData[
      \(TraditionalForm\`\(+\[Infinity]\)\)],
    FormatType->StandardForm],
  ", since any additional values would fall outside the volume of the plot; \
similarly, letting ",
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm],
  " become any smaller than ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\)\)],
    FormatType->StandardForm],
  " would only affect the plot on a microscopic scale.)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot3D[
        Evaluate[{Re[\[ExponentialE]\^\(z\_r + \[ImaginaryI]\ z\_i\)], 
            Im[\[ExponentialE]\^\(z\_r + \[ImaginaryI]\ z\_i\)], 
            z\_i}], {z\_r, \(-5\), 5}, {z\_i, 0, 10\ \[Pi]}];\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.60465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.292974 1.61275 -0.00810073 1.61275 [
[.48828 1.59761 -5.33184 0 ]
[.48828 1.59761 5.29316 7 ]
[.67974 1.55091 -3.44554 0 ]
[.67974 1.55091 3.61696 7 ]
[.87851 1.50242 -3.40092 0 ]
[.87851 1.50242 3.78658 7 ]
[.07615 1.38898 -5.65966 0 ]
[.07615 1.38898 4.96534 7 ]
[.19833 1.48483 -3.69518 0 ]
[.19833 1.48483 3.36732 7 ]
[.31213 1.57411 -3.69894 0 ]
[.31213 1.57411 3.48856 7 ]
[.06561 .22899 -7.0625 -2.1245 ]
[.06561 .22899 0 4.8755 ]
[.04174 .5334 -9.9375 -2.2303 ]
[.04174 .5334 0 4.7697 ]
[.01509 .87335 -9.9375 -2.34908 ]
[.01509 .87335 0 4.65092 ]
[-0.01485 1.25546 -9.9375 -2.48337 ]
[-0.01485 1.25546 0 4.51663 ]
[ 0 0 0 0 ]
[ 1 1.60465 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.37715 1.60465 m
1 1.45231 L
s
.48836 1.57745 m
.48839 1.56737 L
s
gsave
.48828 1.59761 -66.3318 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.67925 1.53076 m
.67901 1.52068 L
s
gsave
.67974 1.55091 -64.4455 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.87743 1.48229 m
.87689 1.47222 L
s
gsave
.87851 1.50242 -64.4009 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.52597 1.56825 m
.52596 1.5622 L
s
.56387 1.55898 m
.56382 1.55293 L
s
.60204 1.54964 m
.60196 1.5436 L
s
.6405 1.54024 m
.64039 1.53419 L
s
.71829 1.52121 m
.71811 1.51517 L
s
.75763 1.51159 m
.75741 1.50555 L
s
.79726 1.5019 m
.79701 1.49585 L
s
.83719 1.49213 m
.8369 1.48609 L
s
.45101 1.58659 m
.45107 1.58054 L
s
.41395 1.59565 m
.41403 1.5896 L
s
.91797 1.47237 m
.91761 1.46633 L
s
.95883 1.46238 m
.95843 1.45634 L
s
.25 Mabswid
0 1.30791 m
.37715 1.60465 L
s
.07747 1.36886 m
.07813 1.3588 L
s
gsave
.07615 1.38898 -66.6597 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.19926 1.46469 m
.19973 1.45462 L
s
gsave
.19833 1.48483 -64.6952 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31272 1.55396 m
.31302 1.54389 L
s
gsave
.31213 1.57411 -64.6989 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.10254 1.38859 m
.10291 1.38255 L
s
.12724 1.40803 m
.12759 1.40199 L
s
.1516 1.42719 m
.15192 1.42115 L
s
.1756 1.44607 m
.1759 1.44003 L
s
.22259 1.48305 m
.22285 1.47701 L
s
.2456 1.50115 m
.24584 1.49511 L
s
.26828 1.519 m
.2685 1.51295 L
s
.29066 1.5366 m
.29085 1.53056 L
s
.05203 1.34884 m
.05245 1.34281 L
s
.02621 1.32853 m
.02665 1.3225 L
s
.33449 1.57109 m
.33465 1.56504 L
s
.35596 1.58798 m
.3561 1.58194 L
s
.25 Mabswid
.08437 .22162 m
0 1.30791 L
s
.08437 .22162 m
.09375 .21793 L
s
gsave
.06561 .22899 -68.0625 -6.1245 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.06069 .52652 m
.07017 .52308 L
s
gsave
.04174 .5334 -70.9375 -6.2303 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.03424 .86705 m
.04382 .8639 L
s
gsave
.01509 .87335 -70.9375 -6.34908 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.00451 1.24983 m
.01419 1.24702 L
s
gsave
-0.01485 1.25546 -70.9375 -6.48337 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.125 Mabswid
.07984 .28002 m
.08548 .27784 L
s
.0752 .33967 m
.08085 .33752 L
s
.07047 .40061 m
.07613 .39848 L
s
.06563 .46288 m
.07131 .46078 L
s
.05564 .59159 m
.06133 .58956 L
s
.05047 .65812 m
.05618 .65612 L
s
.04518 .72617 m
.0509 .72421 L
s
.03978 .7958 m
.04551 .79387 L
s
.02858 .93999 m
.03433 .93813 L
s
.02278 1.01467 m
.02855 1.01286 L
s
.01684 1.09116 m
.02262 1.08939 L
s
.01075 1.16952 m
.01654 1.16779 L
s
.25 Mabswid
.08437 .22162 m
0 1.30791 L
s
0 1.30791 m
.37715 1.60465 L
s
.37715 1.60465 m
.39749 .5732 L
s
.39749 .5732 m
.08437 .22162 L
s
.64829 0 m
.92355 .39114 L
s
.92355 .39114 m
1 1.45231 L
s
1 1.45231 m
.67666 1.11531 L
s
.67666 1.11531 m
.64829 0 L
s
.08437 .22162 m
0 1.30791 L
s
0 1.30791 m
.67666 1.11531 L
s
.67666 1.11531 m
.64829 0 L
s
.64829 0 m
.08437 .22162 L
s
.39749 .5732 m
.92355 .39114 L
s
.92355 .39114 m
1 1.45231 L
s
1 1.45231 m
.37715 1.60465 L
s
.37715 1.60465 m
.39749 .5732 L
s
0 0 m
1 0 L
1 1.60465 L
0 1.60465 L
closepath
clip
newpath
.5 Mabswid
.43491 .55285 m .39618 .63975 L .34046 .58377 L p .827 .064 .822 r
F P
0 g
s
.43984 .62108 m .39618 .63975 L p .54182 .54785 L .82 .063 .816 r
F P
0 g
s
.39618 .63975 m .43491 .55285 L .54182 .54785 L p .82 .063 .816 r
F P
0 g
s
.54182 .54785 m .54642 .57745 L .43984 .62108 L p .82 .063 .816 r
F P
0 g
s
.63064 .53921 m .54642 .57745 L p .6446 .51631 L .817 .061 .807 r
F P
0 g
s
.54642 .57745 m .54182 .54785 L .6446 .51631 L p .817 .061 .807 r
F P
0 g
s
.34046 .58377 m .30912 .5557 L p .43491 .55285 L .827 .064 .822 r
F P
0 g
s
.6446 .51631 m .65494 .52912 L .63064 .53921 L p .817 .061 .807 r
F P
0 g
s
.53098 .47817 m .54182 .54785 L .43491 .55285 L p .804 .067 .834 r
F P
0 g
s
.54182 .54785 m .53098 .47817 L .59437 .45406 L p .8 .064 .818 r
F P
0 g
s
.59437 .45406 m .6446 .51631 L .54182 .54785 L p .8 .064 .818 r
F P
0 g
s
.72826 .49516 m .65494 .52912 L p .72957 .4604 L .819 .059 .795 r
F P
0 g
s
.65494 .52912 m .6446 .51631 L .72957 .4604 L p .819 .059 .795 r
F P
0 g
s
.30912 .5557 m .33792 .5321 L .43491 .55285 L p .827 .064 .822 r
F P
0 g
s
.46488 .48558 m .43491 .55285 L .33792 .5321 L p .814 .069 .844 r
F P
0 g
s
.43491 .55285 m .46488 .48558 L .53098 .47817 L p .804 .067 .834 r
F P
0 g
s
.6446 .51631 m .59437 .45406 L .64617 .41483 L p .803 .06 .799 r
F P
0 g
s
.64617 .41483 m .72957 .4604 L .6446 .51631 L p .803 .06 .799 r
F P
0 g
s
.72957 .4604 m .76535 .47995 L .72826 .49516 L p .819 .059 .795 r
F P
0 g
s
.33792 .5321 m .30912 .5557 L .28783 .53494 L p .838 .064 .822 r
F P
0 g
s
.8211 .45465 m .76535 .47995 L p .78441 .38532 L .823 .057 .783 r
F P
0 g
s
.76535 .47995 m .72957 .4604 L .78441 .38532 L p .823 .057 .783 r
F P
0 g
s
.43754 .80627 m .39253 .82482 L p .54272 .7341 L .827 .065 .826 r
F P
0 g
s
.39253 .82482 m .4324 .73998 L .54272 .7341 L p .827 .065 .826 r
F P
0 g
s
.4324 .73998 m .39253 .82482 L .33497 .77064 L p .835 .066 .832 r
F P
0 g
s
.78441 .38532 m .92517 .41359 L .8211 .45465 L p .823 .057 .783 r
F P
0 g
s
.54272 .7341 m .54746 .76302 L .43754 .80627 L p .827 .065 .826 r
F P
0 g
s
.72957 .4604 m .64617 .41483 L .67872 .3641 L p .811 .056 .78 r
F P
0 g
s
.67872 .3641 m .78441 .38532 L .72957 .4604 L p .811 .056 .78 r
F P
0 g
s
.28783 .53494 m .24421 .49655 L p .33792 .5321 L .838 .064 .822 r
F P
0 g
s
.24421 .49655 m .26426 .48935 L .33792 .5321 L p .838 .064 .822 r
F P
0 g
s
.4053 .47687 m .33792 .5321 L .26426 .48935 L p .831 .069 .846 r
F P
0 g
s
.33792 .5321 m .4053 .47687 L .46488 .48558 L p .814 .069 .844 r
F P
0 g
s
.52419 .43454 m .53098 .47817 L .46488 .48558 L p .777 .072 .862 r
F P
0 g
s
.53098 .47817 m .52419 .43454 L .56304 .41523 L p .773 .067 .835 r
F P
0 g
s
.56304 .41523 m .59437 .45406 L .53098 .47817 L p .773 .067 .835 r
F P
0 g
s
.59437 .45406 m .56304 .41523 L .59455 .38663 L p .779 .061 .805 r
F P
0 g
s
.59455 .38663 m .64617 .41483 L .59437 .45406 L p .779 .061 .805 r
F P
0 g
s
.90328 .37915 m .92517 .41359 L p .79972 .29938 L .831 .054 .771 r
F P
0 g
s
.92517 .41359 m .78441 .38532 L .79972 .29938 L p .831 .054 .771 r
F P
0 g
s
.63436 .72483 m .54746 .76302 L p .6488 .70228 L .824 .063 .815 r
F P
0 g
s
.54746 .76302 m .54272 .7341 L .6488 .70228 L p .824 .063 .815 r
F P
0 g
s
.48363 .44352 m .46488 .48558 L .4053 .47687 L p .791 .076 .881 r
F P
0 g
s
.46488 .48558 m .48363 .44352 L .52419 .43454 L p .777 .072 .862 r
F P
0 g
s
.64617 .41483 m .59455 .38663 L .61402 .35111 L p .793 .055 .776 r
F P
0 g
s
.61402 .35111 m .67872 .3641 L .64617 .41483 L p .793 .055 .776 r
F P
0 g
s
.33497 .77064 m .30256 .74376 L p .4324 .73998 L .835 .066 .832 r
F P
0 g
s
.6488 .70228 m .65945 .71481 L .63436 .72483 L p .824 .063 .815 r
F P
0 g
s
.79972 .29938 m .84924 .29589 L .90328 .37915 L p .831 .054 .771 r
F P
0 g
s
.78441 .38532 m .67872 .3641 L .68669 .30736 L p .823 .052 .762 r
F P
0 g
s
.68669 .30736 m .79972 .29938 L .78441 .38532 L p .823 .052 .762 r
F P
0 g
s
.26426 .48935 m .24421 .49655 L .22942 .4823 L p .85 .064 .818 r
F P
0 g
s
.26426 .48935 m .36083 .45467 L .4053 .47687 L p .831 .069 .846 r
F P
0 g
s
.44721 .44252 m .4053 .47687 L .36083 .45467 L p .818 .077 .887 r
F P
0 g
s
.4053 .47687 m .44721 .44252 L .48363 .44352 L p .791 .076 .881 r
F P
0 g
s
.53155 .66595 m .54272 .7341 L .4324 .73998 L p .809 .069 .845 r
F P
0 g
s
.54272 .7341 m .53155 .66595 L .59701 .64137 L p .806 .065 .827 r
F P
0 g
s
.59701 .64137 m .6488 .70228 L .54272 .7341 L p .806 .065 .827 r
F P
0 g
s
.73514 .68083 m .65945 .71481 L p .73655 .64659 L .825 .061 .803 r
F P
0 g
s
.65945 .71481 m .6488 .70228 L .73655 .64659 L p .825 .061 .803 r
F P
0 g
s
.51999 .40757 m .52419 .43454 L .48363 .44352 L p .733 .081 .907 r
F P
0 g
s
.52419 .43454 m .51999 .40757 L .54371 .39127 L p .733 .072 .86 r
F P
0 g
s
.54371 .39127 m .56304 .41523 L .52419 .43454 L p .733 .072 .86 r
F P
0 g
s
.56304 .41523 m .54371 .39127 L .56285 .36931 L p .746 .063 .813 r
F P
0 g
s
.56285 .36931 m .59455 .38663 L .56304 .41523 L p .746 .063 .813 r
F P
0 g
s
.22942 .4823 m .17636 .43473 L p .26426 .48935 L .85 .064 .818 r
F P
0 g
s
.17636 .43473 m .22553 .43135 L .26426 .48935 L p .85 .064 .818 r
F P
0 g
s
.36083 .45467 m .26426 .48935 L .22553 .43135 L p .851 .068 .838 r
F P
0 g
s
.49521 .41752 m .48363 .44352 L .44721 .44252 L p .751 .089 .945 r
F P
0 g
s
.48363 .44352 m .49521 .41752 L .51999 .40757 L p .733 .081 .907 r
F P
0 g
s
.59455 .38663 m .56285 .36931 L .57456 .34319 L p .767 .054 .769 r
F P
0 g
s
.57456 .34319 m .61402 .35111 L .59455 .38663 L p .767 .054 .769 r
F P
0 g
s
.30256 .74376 m .33224 .7207 L .4324 .73998 L p .835 .066 .832 r
F P
0 g
s
.4633 .67421 m .4324 .73998 L .33224 .7207 L p .821 .071 .856 r
F P
0 g
s
.4324 .73998 m .4633 .67421 L .53155 .66595 L p .809 .069 .845 r
F P
0 g
s
.6488 .70228 m .59701 .64137 L .65051 .60196 L p .808 .061 .807 r
F P
0 g
s
.65051 .60196 m .73655 .64659 L .6488 .70228 L p .808 .061 .807 r
F P
0 g
s
.67872 .3641 m .61402 .35111 L .61837 .31217 L p .812 .05 .749 r
F P
0 g
s
.61837 .31217 m .68669 .30736 L .67872 .3641 L p .812 .05 .749 r
F P
0 g
s
.73655 .64659 m .77345 .66573 L .73514 .68083 L p .825 .061 .803 r
F P
0 g
s
.53186 .37658 m .54371 .39127 L .51999 .40757 L p .676 .079 .894 r
F P
0 g
s
.54371 .39127 m .53186 .37658 L .54348 .35872 L p .701 .065 .823 r
F P
0 g
s
.54348 .35872 m .56285 .36931 L .54371 .39127 L p .701 .065 .823 r
F P
0 g
s
.51742 .39101 m .51999 .40757 L .49521 .41752 L p .664 .095 .974 r
F P
0 g
s
.51999 .40757 m .51742 .39101 L .53186 .37658 L p .676 .079 .894 r
F P
0 g
s
.61402 .35111 m .57456 .34319 L .57702 .31509 L p .796 .046 .73 r
F P
0 g
s
.57702 .31509 m .61837 .31217 L .61402 .35111 L p .796 .046 .73 r
F P
0 g
s
.56285 .36931 m .54348 .35872 L .55055 .33837 L p .734 .052 .761 r
F P
0 g
s
.55055 .33837 m .57456 .34319 L .56285 .36931 L p .734 .052 .761 r
F P
0 g
s
.33224 .7207 m .30256 .74376 L .28054 .7237 L p .846 .067 .833 r
F P
0 g
s
.36083 .45467 m .42032 .43331 L .44721 .44252 L p .818 .077 .887 r
F P
0 g
s
.47302 .42137 m .44721 .44252 L .42032 .43331 L p .79 .092 .962 r
F P
0 g
s
.44721 .44252 m .47302 .42137 L .49521 .41752 L p .751 .089 .945 r
F P
0 g
s
.51383 .31955 m .51366 .31956 L .51363 .3082 L p .774 0 .5 r
F P
0 g
s
.51363 .3082 m .51378 .30815 L .51383 .31955 L p .774 0 .5 r
F P
0 g
s
.51411 .31953 m .51383 .31955 L .51378 .30815 L p .774 0 .5 r
F P
0 g
s
.51378 .30815 m .51403 .30806 L .51411 .31953 L p .774 0 .5 r
F P
0 g
s
.51457 .31949 m .51411 .31953 L .51403 .30806 L p .775 0 .5 r
F P
0 g
s
.51403 .30806 m .51443 .30791 L .51457 .31949 L p .775 0 .5 r
F P
0 g
s
.83103 .64043 m .77345 .66573 L p .7933 .57206 L .83 .058 .789 r
F P
0 g
s
.77345 .66573 m .73655 .64659 L .7933 .57206 L p .83 .058 .789 r
F P
0 g
s
.51532 .31944 m .51457 .31949 L .51443 .30791 L p .776 0 .5 r
F P
0 g
s
.51443 .30791 m .5151 .30766 L .51532 .31944 L p .776 0 .5 r
F P
0 g
s
.51657 .31935 m .51532 .31944 L .5151 .30766 L p .777 0 .5 r
F P
0 g
s
.5151 .30766 m .51619 .30726 L .51657 .31935 L p .777 0 .5 r
F P
0 g
s
.51862 .31921 m .51657 .31935 L .51619 .30726 L p .779 0 .5 r
F P
0 g
s
.51619 .30726 m .51801 .30659 L .51862 .31921 L p .779 0 .5 r
F P
0 g
s
.522 .31897 m .51862 .31921 L .51801 .30659 L p .782 0 .5 r
F P
0 g
s
.51801 .30659 m .521 .30549 L .522 .31897 L p .782 0 .5 r
F P
0 g
s
.4351 1.00341 m .38864 1.02179 L p .54368 .9326 L .835 .067 .837 r
F P
0 g
s
.38864 1.02179 m .42972 .93946 L .54368 .9326 L p .835 .067 .837 r
F P
0 g
s
.42972 .93946 m .38864 1.02179 L .32912 .96977 L p .843 .069 .844 r
F P
0 g
s
.57456 .34319 m .55055 .33837 L .55197 .31686 L p .775 .041 .706 r
F P
0 g
s
.55197 .31686 m .57702 .31509 L .57456 .34319 L p .775 .041 .706 r
F P
0 g
s
.52758 .31858 m .522 .31897 L .521 .30549 L p .79 .005 .525 r
F P
0 g
s
.521 .30549 m .52593 .30368 L .52758 .31858 L p .79 .005 .525 r
F P
0 g
s
.50232 .40157 m .49521 .41752 L .47302 .42137 L p .675 .111 1 r
F P
0 g
s
.49521 .41752 m .50232 .40157 L .51742 .39101 L p .664 .095 .974 r
F P
0 g
s
.22553 .43135 m .33842 .42358 L .36083 .45467 L p .851 .068 .838 r
F P
0 g
s
.42032 .43331 m .36083 .45467 L .33842 .42358 L p .853 .075 .874 r
F P
0 g
s
.53679 .31793 m .52758 .31858 L .52593 .30368 L p .802 .013 .566 r
F P
0 g
s
.52593 .30368 m .53407 .30068 L .53679 .31793 L p .802 .013 .566 r
F P
0 g
s
.53168 .35227 m .54348 .35872 L .53186 .37658 L p .647 .066 .832 r
F P
0 g
s
.54348 .35872 m .53168 .35227 L .53595 .33544 L p .696 .05 .75 r
F P
0 g
s
.53595 .33544 m .55055 .33837 L .54348 .35872 L p .696 .05 .75 r
F P
0 g
s
.52462 .36762 m .53186 .37658 L .51742 .39101 L p .601 .087 .934 r
F P
0 g
s
.53186 .37658 m .52462 .36762 L .53168 .35227 L p .647 .066 .832 r
F P
0 g
s
.51382 .33099 m .51365 .33096 L .51366 .31956 L p .651 .014 .569 r
F P
0 g
s
.51366 .31956 m .51383 .31955 L .51382 .33099 L p .651 .014 .569 r
F P
0 g
s
.55197 .31686 m .53679 .31793 L .53407 .30068 L p .813 .022 .612 r
F P
0 g
s
.53407 .30068 m .54752 .29573 L .55197 .31686 L p .813 .022 .612 r
F P
0 g
s
.51408 .33105 m .51382 .33099 L .51383 .31955 L p .652 .014 .571 r
F P
0 g
s
.51383 .31955 m .51411 .31953 L .51408 .33105 L p .652 .014 .571 r
F P
0 g
s
.51453 .33114 m .51408 .33105 L .51411 .31953 L p .654 .015 .573 r
F P
0 g
s
.51411 .31953 m .51457 .31949 L .51453 .33114 L p .654 .015 .573 r
F P
0 g
s
.55055 .33837 m .53595 .33544 L .53679 .31793 L p .75 .036 .678 r
F P
0 g
s
.53679 .31793 m .55197 .31686 L .55055 .33837 L p .75 .036 .678 r
F P
0 g
s
.51526 .33128 m .51453 .33114 L .51457 .31949 L p .658 .015 .577 r
F P
0 g
s
.51457 .31949 m .51532 .31944 L .51526 .33128 L p .658 .015 .577 r
F P
0 g
s
.51646 .33152 m .51526 .33128 L .51532 .31944 L p .664 .017 .583 r
F P
0 g
s
.51532 .31944 m .51657 .31935 L .51646 .33152 L p .664 .017 .583 r
F P
0 g
s
.51844 .33192 m .51646 .33152 L .51657 .31935 L p .672 .019 .593 r
F P
0 g
s
.51657 .31935 m .51862 .31921 L .51844 .33192 L p .672 .019 .593 r
F P
0 g
s
.5217 .33258 m .51844 .33192 L .51862 .31921 L p .685 .021 .606 r
F P
0 g
s
.51862 .31921 m .522 .31897 L .5217 .33258 L p .685 .021 .606 r
F P
0 g
s
.52708 .33366 m .5217 .33258 L .522 .31897 L p .703 .025 .626 r
F P
0 g
s
.522 .31897 m .52758 .31858 L .52708 .33366 L p .703 .025 .626 r
F P
0 g
s
.53595 .33544 m .52708 .33366 L .52758 .31858 L p .725 .03 .65 r
F P
0 g
s
.52758 .31858 m .53679 .31793 L .53595 .33544 L p .725 .03 .65 r
F P
0 g
s
.57702 .31509 m .55197 .31686 L .54752 .29573 L p .823 .031 .657 r
F P
0 g
s
.52708 .33366 m .53595 .33544 L .53168 .35227 L p .658 .048 .738 r
F P
0 g
s
.51585 .38089 m .51742 .39101 L .50232 .40157 L p .613 .113 1 r
F P
0 g
s
.51742 .39101 m .51585 .38089 L .52462 .36762 L p .601 .087 .934 r
F P
0 g
s
.61837 .31217 m .57702 .31509 L .56977 .28754 L p .83 .039 .696 r
F P
0 g
s
.54752 .29573 m .56977 .28754 L .57702 .31509 L p .823 .031 .657 r
F P
0 g
s
.53168 .35227 m .5245 .34835 L .52708 .33366 L p .658 .048 .738 r
F P
0 g
s
.5217 .33258 m .52708 .33366 L .5245 .34835 L p .624 .045 .726 r
F P
0 g
s
.5245 .34835 m .53168 .35227 L .52462 .36762 L p .591 .068 .84 r
F P
0 g
s
.5245 .34835 m .52014 .34597 L .5217 .33258 L p .624 .045 .726 r
F P
0 g
s
.51844 .33192 m .5217 .33258 L .52014 .34597 L p .598 .043 .717 r
F P
0 g
s
.52014 .34597 m .51749 .34452 L .51844 .33192 L p .598 .043 .717 r
F P
0 g
s
.51646 .33152 m .51844 .33192 L .51749 .34452 L p .579 .042 .71 r
F P
0 g
s
.51749 .34452 m .51588 .34364 L .51646 .33152 L p .579 .042 .71 r
F P
0 g
s
.51526 .33128 m .51646 .33152 L .51588 .34364 L p .566 .041 .706 r
F P
0 g
s
.51588 .34364 m .51491 .34311 L .51526 .33128 L p .566 .041 .706 r
F P
0 g
s
.51453 .33114 m .51526 .33128 L .51491 .34311 L p .557 .04 .702 r
F P
0 g
s
.51491 .34311 m .51431 .34279 L .51453 .33114 L p .557 .04 .702 r
F P
0 g
s
.51408 .33105 m .51453 .33114 L .51431 .34279 L p .552 .04 .7 r
F P
0 g
s
.68669 .30736 m .61837 .31217 L .60668 .27396 L p .835 .045 .726 r
F P
0 g
s
.56977 .28754 m .60668 .27396 L .61837 .31217 L p .83 .039 .696 r
F P
0 g
s
.51431 .34279 m .51396 .34259 L .51408 .33105 L p .552 .04 .7 r
F P
0 g
s
.51382 .33099 m .51408 .33105 L .51396 .34259 L p .549 .04 .699 r
F P
0 g
s
.51396 .34259 m .51374 .34247 L .51382 .33099 L p .549 .04 .699 r
F P
0 g
s
.51365 .33096 m .51382 .33099 L .51374 .34247 L p .547 .04 .698 r
F P
0 g
s
.51374 .34247 m .51361 .3424 L .51365 .33096 L p .547 .04 .698 r
F P
0 g
s
.52022 .36216 m .52462 .36762 L .51585 .38089 L p .595 .095 .976 r
F P
0 g
s
.52462 .36762 m .52022 .36216 L .5245 .34835 L p .591 .068 .84 r
F P
0 g
s
.52014 .34597 m .5245 .34835 L .52022 .36216 L p .569 .069 .845 r
F P
0 g
s
.7933 .57206 m .93858 .59977 L .83103 .64043 L p .83 .058 .789 r
F P
0 g
s
.54368 .9326 m .54857 .96069 L .4351 1.00341 L p .835 .067 .837 r
F P
0 g
s
.52022 .36216 m .51754 .35884 L .52014 .34597 L p .569 .069 .845 r
F P
0 g
s
.51749 .34452 m .52014 .34597 L .51754 .35884 L p .57 .07 .849 r
F P
0 g
s
.42032 .43331 m .45674 .42023 L .47302 .42137 L p .79 .092 .962 r
F P
0 g
s
.48882 .40842 m .47302 .42137 L .45674 .42023 L p .724 .121 1 r
F P
0 g
s
.47302 .42137 m .48882 .40842 L .50232 .40157 L p .675 .111 1 r
F P
0 g
s
.79972 .29938 m .68669 .30736 L .6681 .25135 L p .838 .05 .748 r
F P
0 g
s
.60668 .27396 m .6681 .25135 L .68669 .30736 L p .835 .045 .726 r
F P
0 g
s
.50666 .39183 m .50232 .40157 L .48882 .40842 L p .645 .145 1 r
F P
0 g
s
.50232 .40157 m .50666 .39183 L .51585 .38089 L p .613 .113 1 r
F P
0 g
s
.51754 .35884 m .51591 .35683 L .51749 .34452 L p .57 .07 .849 r
F P
0 g
s
.51588 .34364 m .51749 .34452 L .51591 .35683 L p .57 .07 .85 r
F P
0 g
s
.73655 .64659 m .65051 .60196 L .68418 .55125 L p .817 .057 .786 r
F P
0 g
s
.68418 .55125 m .7933 .57206 L .73655 .64659 L p .817 .057 .786 r
F P
0 g
s
.51591 .35683 m .51493 .3556 L .51588 .34364 L p .57 .07 .85 r
F P
0 g
s
.51491 .34311 m .51588 .34364 L .51493 .3556 L p .57 .07 .851 r
F P
0 g
s
.51585 .38089 m .51489 .37473 L .52022 .36216 L p .595 .095 .976 r
F P
0 g
s
.51754 .35884 m .52022 .36216 L .51489 .37473 L p .602 .102 1 r
F P
0 g
s
.51493 .3556 m .51433 .35486 L .51491 .34311 L p .57 .07 .851 r
F P
0 g
s
.51431 .34279 m .51491 .34311 L .51433 .35486 L p .57 .07 .851 r
F P
0 g
s
.51489 .37473 m .51585 .38089 L .50666 .39183 L p .635 .135 1 r
F P
0 g
s
.51433 .35486 m .51396 .35441 L .51431 .34279 L p .57 .07 .851 r
F P
0 g
s
.51396 .34259 m .51431 .34279 L .51396 .35441 L p .57 .07 .852 r
F P
0 g
s
.51396 .35441 m .51374 .35414 L .51396 .34259 L p .57 .07 .852 r
F P
0 g
s
.51374 .34247 m .51396 .34259 L .51374 .35414 L p .57 .07 .852 r
F P
0 g
s
.51374 .35414 m .51361 .35397 L .51374 .34247 L p .57 .07 .852 r
F P
0 g
s
.51361 .3424 m .51374 .34247 L .51361 .35397 L p .57 .07 .852 r
F P
0 g
s
.51361 .35397 m .51353 .35387 L .51361 .3424 L p .57 .07 .852 r
F P
0 g
s
.28054 .7237 m .23537 .68697 L p .33224 .7207 L .846 .067 .833 r
F P
0 g
s
.23537 .68697 m .25607 .67992 L .33224 .7207 L p .846 .067 .833 r
F P
0 g
s
.40175 .66669 m .33224 .7207 L .25607 .67992 L p .839 .072 .858 r
F P
0 g
s
.33224 .7207 m .40175 .66669 L .4633 .67421 L p .821 .071 .856 r
F P
0 g
s
.51489 .37473 m .5143 .37098 L .51754 .35884 L p .602 .102 1 r
F P
0 g
s
.51591 .35683 m .51754 .35884 L .5143 .37098 L p .608 .108 1 r
F P
0 g
s
.33842 .42358 m .40714 .41886 L .42032 .43331 L p .853 .075 .874 r
F P
0 g
s
.45674 .42023 m .42032 .43331 L .40714 .41886 L p .851 .089 .944 r
F P
0 g
s
.5143 .37098 m .51395 .3687 L .51591 .35683 L p .608 .108 1 r
F P
0 g
s
.51493 .3556 m .51591 .35683 L .51395 .3687 L p .612 .112 1 r
F P
0 g
s
.84924 .29589 m .79972 .29938 L .77098 .21348 L p .84 .052 .762 r
F P
0 g
s
.6681 .25135 m .77098 .21348 L .79972 .29938 L p .838 .05 .748 r
F P
0 g
s
.50666 .39183 m .50931 .38589 L .51489 .37473 L p .635 .135 1 r
F P
0 g
s
.5143 .37098 m .51489 .37473 L .50931 .38589 L p .656 .156 1 r
F P
0 g
s
.51395 .3687 m .51373 .36732 L .51493 .3556 L p .612 .112 1 r
F P
0 g
s
.51433 .35486 m .51493 .3556 L .51373 .36732 L p .614 .114 1 r
F P
0 g
s
.51373 .36732 m .5136 .36648 L .51433 .35486 L p .614 .114 1 r
F P
0 g
s
.51396 .35441 m .51433 .35486 L .5136 .36648 L p .615 .115 1 r
F P
0 g
s
.5136 .36648 m .51352 .36597 L .51396 .35441 L p .615 .115 1 r
F P
0 g
s
.51374 .35414 m .51396 .35441 L .51352 .36597 L p .616 .116 1 r
F P
0 g
s
.51352 .36597 m .51348 .36566 L .51374 .35414 L p .616 .116 1 r
F P
0 g
s
.51361 .35397 m .51374 .35414 L .51348 .36566 L p .617 .117 1 r
F P
0 g
s
.51348 .36566 m .51345 .36548 L .51361 .35397 L p .617 .117 1 r
F P
0 g
s
.51353 .35387 m .51361 .35397 L .51345 .36548 L p .617 .117 1 r
F P
0 g
s
.51345 .36548 m .51343 .36536 L .51353 .35387 L p .617 .117 1 r
F P
0 g
s
.48882 .40842 m .49846 .40052 L .50666 .39183 L p .645 .145 1 r
F P
0 g
s
.50931 .38589 m .50666 .39183 L .49846 .40052 L p .685 .185 1 r
F P
0 g
s
.80554 .22511 m .84924 .29589 L p .77098 .21348 L .84 .052 .762 r
F P
0 g
s
.50931 .38589 m .51092 .38228 L .5143 .37098 L p .656 .156 1 r
F P
0 g
s
.51395 .3687 m .5143 .37098 L .51092 .38228 L p .67 .17 1 r
F P
0 g
s
.45674 .42023 m .47896 .41225 L .48882 .40842 L p .724 .121 1 r
F P
0 g
s
.49846 .40052 m .48882 .40842 L .47896 .41225 L p .663 .163 1 r
F P
0 g
s
.51092 .38228 m .51189 .38009 L .51395 .3687 L p .67 .17 1 r
F P
0 g
s
.51373 .36732 m .51395 .3687 L .51189 .38009 L p .678 .178 1 r
F P
0 g
s
.51189 .38009 m .51249 .37876 L .51373 .36732 L p .678 .178 1 r
F P
0 g
s
.5136 .36648 m .51373 .36732 L .51249 .37876 L p .681 .181 1 r
F P
0 g
s
.49846 .40052 m .50433 .39571 L .50931 .38589 L p .685 .185 1 r
F P
0 g
s
.51092 .38228 m .50931 .38589 L .50433 .39571 L p .699 .199 1 r
F P
0 g
s
.51249 .37876 m .51285 .37795 L .5136 .36648 L p .681 .181 1 r
F P
0 g
s
.51352 .36597 m .5136 .36648 L .51285 .37795 L p .681 .181 1 r
F P
0 g
s
.51285 .37795 m .51307 .37746 L .51352 .36597 L p .681 .181 1 r
F P
0 g
s
.51348 .36566 m .51352 .36597 L .51307 .37746 L p .682 .182 1 r
F P
0 g
s
.51307 .37746 m .5132 .37716 L .51348 .36566 L p .682 .182 1 r
F P
0 g
s
.51345 .36548 m .51348 .36566 L .5132 .37716 L p .681 .181 1 r
F P
0 g
s
.5132 .37716 m .51328 .37698 L .51345 .36548 L p .681 .181 1 r
F P
0 g
s
.51343 .36536 m .51345 .36548 L .51328 .37698 L p .681 .181 1 r
F P
0 g
s
.51328 .37698 m .51333 .37687 L .51343 .36536 L p .681 .181 1 r
F P
0 g
s
.50433 .39571 m .50789 .39279 L .51092 .38228 L p .699 .199 1 r
F P
0 g
s
.51189 .38009 m .51092 .38228 L .50789 .39279 L p 1 0 .5 r
F P
0 g
s
.40714 .41886 m .4489 .41598 L .45674 .42023 L p .851 .089 .944 r
F P
0 g
s
.47896 .41225 m .45674 .42023 L .4489 .41598 L p .823 .115 1 r
F P
0 g
s
.47896 .41225 m .49248 .4074 L .49846 .40052 L p .663 .163 1 r
F P
0 g
s
.50433 .39571 m .49846 .40052 L .49248 .4074 L p .881 0 .5 r
F P
0 g
s
.52455 .62325 m .53155 .66595 L .4633 .67421 L p .78 .075 .875 r
F P
0 g
s
.53155 .66595 m .52455 .62325 L .56467 .60334 L p .777 .069 .846 r
F P
0 g
s
.56467 .60334 m .59701 .64137 L .53155 .66595 L p .777 .069 .846 r
F P
0 g
s
.50789 .39279 m .51006 .39101 L .51189 .38009 L p 1 0 .5 r
F P
0 g
s
.51249 .37876 m .51189 .38009 L .51006 .39101 L p 1 0 .5 r
F P
0 g
s
.51006 .39101 m .51137 .38993 L .51249 .37876 L p 1 0 .5 r
F P
0 g
s
.51285 .37795 m .51249 .37876 L .51137 .38993 L p 1 0 .5 r
F P
0 g
s
.51137 .38993 m .51217 .38928 L .51285 .37795 L p 1 0 .5 r
F P
0 g
s
.51307 .37746 m .51285 .37795 L .51217 .38928 L p 1 0 .5 r
F P
0 g
s
.22553 .43135 m .17636 .43473 L .10569 .36604 L p .862 .062 .808 r
F P
0 g
s
.51217 .38928 m .51266 .38888 L .51307 .37746 L p 1 0 .5 r
F P
0 g
s
.5132 .37716 m .51307 .37746 L .51266 .38888 L p 1 0 .5 r
F P
0 g
s
.51266 .38888 m .51295 .38864 L .5132 .37716 L p 1 0 .5 r
F P
0 g
s
.51328 .37698 m .5132 .37716 L .51295 .38864 L p 1 0 .5 r
F P
0 g
s
.51295 .38864 m .51313 .3885 L .51328 .37698 L p 1 0 .5 r
F P
0 g
s
.51333 .37687 m .51328 .37698 L .51313 .3885 L p 1 0 .5 r
F P
0 g
s
.51313 .3885 m .51324 .38841 L .51333 .37687 L p 1 0 .5 r
F P
0 g
s
.49248 .4074 m .5007 .40444 L .50433 .39571 L p .881 0 .5 r
F P
0 g
s
.50789 .39279 m .50433 .39571 L .5007 .40444 L p .968 0 .5 r
F P
0 g
s
.59701 .64137 m .56467 .60334 L .59723 .57431 L p .783 .063 .813 r
F P
0 g
s
.59723 .57431 m .65051 .60196 L .59701 .64137 L p .783 .063 .813 r
F P
0 g
s
.10569 .36604 m .07537 .33747 L p .22553 .43135 L .862 .062 .808 r
F P
0 g
s
.07537 .33747 m .22964 .36768 L .22553 .43135 L p .862 .062 .808 r
F P
0 g
s
.33842 .42358 m .22553 .43135 L .22964 .36768 L p .873 .064 .821 r
F P
0 g
s
.4489 .41598 m .47426 .41424 L .47896 .41225 L p .823 .115 1 r
F P
0 g
s
.49248 .4074 m .47896 .41225 L .47426 .41424 L p .5 0 .5 r
F P
0 g
s
.5007 .40444 m .5057 .40265 L .50789 .39279 L p .968 0 .5 r
F P
0 g
s
.51006 .39101 m .50789 .39279 L .5057 .40265 L p .976 0 .5 r
F P
0 g
s
.5057 .40265 m .50873 .40156 L .51006 .39101 L p .976 0 .5 r
F P
0 g
s
.51137 .38993 m .51006 .39101 L .50873 .40156 L p .972 0 .5 r
F P
0 g
s
.50873 .40156 m .51057 .4009 L .51137 .38993 L p .972 0 .5 r
F P
0 g
s
.51217 .38928 m .51137 .38993 L .51057 .4009 L p .968 0 .5 r
F P
0 g
s
.91608 .56567 m .93858 .59977 L p .80929 .48675 L .838 .055 .777 r
F P
0 g
s
.93858 .59977 m .7933 .57206 L .80929 .48675 L p .838 .055 .777 r
F P
0 g
s
.51057 .4009 m .51168 .4005 L .51217 .38928 L p .968 0 .5 r
F P
0 g
s
.51266 .38888 m .51217 .38928 L .51168 .4005 L p .966 0 .5 r
F P
0 g
s
.51168 .4005 m .51236 .40026 L .51266 .38888 L p .966 0 .5 r
F P
0 g
s
.51295 .38864 m .51266 .38888 L .51236 .40026 L p .964 0 .5 r
F P
0 g
s
.51236 .40026 m .51277 .40011 L .51295 .38864 L p .964 0 .5 r
F P
0 g
s
.51313 .3885 m .51295 .38864 L .51277 .40011 L p .963 0 .5 r
F P
0 g
s
.51277 .40011 m .51302 .40002 L .51313 .3885 L p .963 0 .5 r
F P
0 g
s
.51324 .38841 m .51313 .3885 L .51302 .40002 L p .962 0 .5 r
F P
0 g
s
.51302 .40002 m .51317 .39997 L .51324 .38841 L p .962 0 .5 r
F P
0 g
s
.47426 .41424 m .48965 .41318 L .49248 .4074 L p .5 0 .5 r
F P
0 g
s
.5007 .40444 m .49248 .4074 L .48965 .41318 L p .669 0 .5 r
F P
0 g
s
.63833 .92264 m .54857 .96069 L p .65327 .90054 L .832 .065 .825 r
F P
0 g
s
.54857 .96069 m .54368 .9326 L .65327 .90054 L p .832 .065 .825 r
F P
0 g
s
.48265 .63304 m .4633 .67421 L .40175 .66669 L p .796 .079 .897 r
F P
0 g
s
.4633 .67421 m .48265 .63304 L .52455 .62325 L p .78 .075 .875 r
F P
0 g
s
.22964 .36768 m .34231 .38975 L .33842 .42358 L p .873 .064 .821 r
F P
0 g
s
.40714 .41886 m .33842 .42358 L .34231 .38975 L p .891 .069 .844 r
F P
0 g
s
.48965 .41318 m .499 .41254 L .5007 .40444 L p .669 0 .5 r
F P
0 g
s
.5057 .40265 m .5007 .40444 L .499 .41254 L p .733 0 .5 r
F P
0 g
s
.499 .41254 m .50466 .41215 L .5057 .40265 L p .733 0 .5 r
F P
0 g
s
.50873 .40156 m .5057 .40265 L .50466 .41215 L p .754 0 .5 r
F P
0 g
s
.50466 .41215 m .5081 .41191 L .50873 .40156 L p .754 0 .5 r
F P
0 g
s
.51057 .4009 m .50873 .40156 L .5081 .41191 L p .763 0 .5 r
F P
0 g
s
.5081 .41191 m .51019 .41177 L .51057 .4009 L p .763 0 .5 r
F P
0 g
s
.51168 .4005 m .51057 .4009 L .51019 .41177 L p .768 0 .5 r
F P
0 g
s
.51019 .41177 m .51145 .41168 L .51168 .4005 L p .768 0 .5 r
F P
0 g
s
.51236 .40026 m .51168 .4005 L .51145 .41168 L p .77 0 .5 r
F P
0 g
s
.51145 .41168 m .51222 .41163 L .51236 .40026 L p .77 0 .5 r
F P
0 g
s
.51277 .40011 m .51236 .40026 L .51222 .41163 L p .771 0 .5 r
F P
0 g
s
.51222 .41163 m .51269 .41159 L .51277 .40011 L p .771 0 .5 r
F P
0 g
s
.51302 .40002 m .51277 .40011 L .51269 .41159 L p .772 0 .5 r
F P
0 g
s
.51269 .41159 m .51297 .41158 L .51302 .40002 L p .772 0 .5 r
F P
0 g
s
.51317 .39997 m .51302 .40002 L .51297 .41158 L p .772 0 .5 r
F P
0 g
s
.51297 .41158 m .51314 .41156 L .51317 .39997 L p .772 0 .5 r
F P
0 g
s
.34231 .38975 m .41001 .403 L .40714 .41886 L p .891 .069 .844 r
F P
0 g
s
.4489 .41598 m .40714 .41886 L .41001 .403 L p .922 .077 .887 r
F P
0 g
s
.41001 .403 m .45083 .411 L .4489 .41598 L p .922 .077 .887 r
F P
0 g
s
.47426 .41424 m .4489 .41598 L .45083 .411 L p .954 .09 .95 r
F P
0 g
s
.45083 .411 m .4755 .41583 L .47426 .41424 L p .954 .09 .95 r
F P
0 g
s
.48965 .41318 m .47426 .41424 L .4755 .41583 L p .5 0 .5 r
F P
0 g
s
.4755 .41583 m .49043 .41875 L .48965 .41318 L p .5 0 .5 r
F P
0 g
s
.499 .41254 m .48965 .41318 L .49043 .41875 L p .5 0 .5 r
F P
0 g
s
.49043 .41875 m .49948 .42053 L .499 .41254 L p .5 0 .5 r
F P
0 g
s
.50466 .41215 m .499 .41254 L .49948 .42053 L p .555 0 .5 r
F P
0 g
s
.49948 .42053 m .50496 .4216 L .50466 .41215 L p .555 0 .5 r
F P
0 g
s
.5081 .41191 m .50466 .41215 L .50496 .4216 L p .595 .002 .512 r
F P
0 g
s
.50496 .4216 m .50828 .42225 L .5081 .41191 L p .595 .002 .512 r
F P
0 g
s
.51019 .41177 m .5081 .41191 L .50828 .42225 L p .619 .007 .536 r
F P
0 g
s
.50828 .42225 m .5103 .42265 L .51019 .41177 L p .619 .007 .536 r
F P
0 g
s
.51145 .41168 m .51019 .41177 L .5103 .42265 L p .631 .01 .549 r
F P
0 g
s
.5103 .42265 m .51152 .42288 L .51145 .41168 L p .631 .01 .549 r
F P
0 g
s
.51222 .41163 m .51145 .41168 L .51152 .42288 L p .638 .011 .556 r
F P
0 g
s
.51152 .42288 m .51226 .42303 L .51222 .41163 L p .638 .011 .556 r
F P
0 g
s
.51269 .41159 m .51222 .41163 L .51226 .42303 L p .642 .012 .561 r
F P
0 g
s
.51226 .42303 m .51271 .42312 L .51269 .41159 L p .642 .012 .561 r
F P
0 g
s
.51297 .41158 m .51269 .41159 L .51271 .42312 L p .645 .013 .563 r
F P
0 g
s
.51271 .42312 m .51298 .42317 L .51297 .41158 L p .645 .013 .563 r
F P
0 g
s
.51314 .41156 m .51297 .41158 L .51298 .42317 L p .646 .013 .565 r
F P
0 g
s
.51298 .42317 m .51315 .4232 L .51314 .41156 L p .646 .013 .565 r
F P
0 g
s
.65051 .60196 m .59723 .57431 L .61736 .5385 L p .797 .056 .782 r
F P
0 g
s
.61736 .5385 m .68418 .55125 L .65051 .60196 L p .797 .056 .782 r
F P
0 g
s
.51306 .43483 m .5132 .4349 L .51315 .4232 L p .54 .039 .696 r
F P
0 g
s
.51315 .4232 m .51298 .42317 L .51306 .43483 L p .54 .039 .696 r
F P
0 g
s
.51284 .43471 m .51306 .43483 L .51298 .42317 L p .539 .039 .695 r
F P
0 g
s
.51298 .42317 m .51271 .42312 L .51284 .43471 L p .539 .039 .695 r
F P
0 g
s
.51248 .43452 m .51284 .43471 L .51271 .42312 L p .539 .039 .694 r
F P
0 g
s
.51271 .42312 m .51226 .42303 L .51248 .43452 L p .539 .039 .694 r
F P
0 g
s
.51187 .4342 m .51248 .43452 L .51226 .42303 L p .538 .038 .691 r
F P
0 g
s
.51226 .42303 m .51152 .42288 L .51187 .4342 L p .538 .038 .691 r
F P
0 g
s
.32912 .96977 m .29557 .9443 L p .42972 .93946 L .843 .069 .844 r
F P
0 g
s
.51088 .43367 m .51187 .4342 L .51152 .42288 L p .537 .037 .687 r
F P
0 g
s
.51152 .42288 m .5103 .42265 L .51088 .43367 L p .537 .037 .687 r
F P
0 g
s
.50924 .43279 m .51088 .43367 L .5103 .42265 L p .536 .036 .68 r
F P
0 g
s
.5103 .42265 m .50828 .42225 L .50924 .43279 L p .536 .036 .68 r
F P
0 g
s
.50654 .43136 m .50924 .43279 L .50828 .42225 L p .533 .033 .666 r
F P
0 g
s
.50828 .42225 m .50496 .4216 L .50654 .43136 L p .533 .033 .666 r
F P
0 g
s
.50209 .42898 m .50654 .43136 L .50496 .4216 L p .527 .027 .636 r
F P
0 g
s
.50496 .4216 m .49948 .42053 L .50209 .42898 L p .527 .027 .636 r
F P
0 g
s
.49473 .42506 m .50209 .42898 L .49948 .42053 L p .512 .012 .562 r
F P
0 g
s
.49948 .42053 m .49043 .41875 L .49473 .42506 L p .512 .012 .562 r
F P
0 g
s
.65327 .90054 m .66425 .91272 L .63833 .92264 L p .832 .065 .825 r
F P
0 g
s
.48256 .41858 m .49473 .42506 L .49043 .41875 L p .5 0 .5 r
F P
0 g
s
.49043 .41875 m .4755 .41583 L .48256 .41858 L p .5 0 .5 r
F P
0 g
s
.80929 .48675 m .86048 .48332 L .91608 .56567 L p .838 .055 .777 r
F P
0 g
s
.7933 .57206 m .68418 .55125 L .69248 .49458 L p .83 .053 .767 r
F P
0 g
s
.69248 .49458 m .80929 .48675 L .7933 .57206 L p .83 .053 .767 r
F P
0 g
s
.25607 .67992 m .23537 .68697 L .22005 .67319 L p .86 .066 .828 r
F P
0 g
s
.25607 .67992 m .35576 .646 L .40175 .66669 L p .839 .072 .858 r
F P
0 g
s
.44502 .63308 m .40175 .66669 L .35576 .646 L p .824 .081 .903 r
F P
0 g
s
.40175 .66669 m .44502 .63308 L .48265 .63304 L p .796 .079 .897 r
F P
0 g
s
.4624 .40783 m .48256 .41858 L .4755 .41583 L p 1 .057 .786 r
F P
0 g
s
.4755 .41583 m .45083 .411 L .4624 .40783 L p 1 .057 .786 r
F P
0 g
s
.51319 .44656 m .51328 .44666 L .5132 .4349 L p .57 .07 .852 r
F P
0 g
s
.5132 .4349 m .51306 .43483 L .51319 .44656 L p .57 .07 .852 r
F P
0 g
s
.51306 .4464 m .51319 .44656 L .51306 .43483 L p .57 .07 .852 r
F P
0 g
s
.51306 .43483 m .51284 .43471 L .51306 .4464 L p .57 .07 .852 r
F P
0 g
s
.51283 .44613 m .51306 .4464 L .51284 .43471 L p .57 .07 .852 r
F P
0 g
s
.51284 .43471 m .51248 .43452 L .51283 .44613 L p .57 .07 .852 r
F P
0 g
s
.51246 .44568 m .51283 .44613 L .51248 .43452 L p .57 .07 .852 r
F P
0 g
s
.51248 .43452 m .51187 .4342 L .51246 .44568 L p .57 .07 .852 r
F P
0 g
s
.51185 .44494 m .51246 .44568 L .51187 .4342 L p .57 .07 .851 r
F P
0 g
s
.51187 .4342 m .51088 .43367 L .51185 .44494 L p .57 .07 .851 r
F P
0 g
s
.77098 .21348 m .79286 .20543 L .80554 .22511 L p .84 .052 .762 r
F P
0 g
s
.51085 .44373 m .51185 .44494 L .51088 .43367 L p .57 .07 .85 r
F P
0 g
s
.51088 .43367 m .50924 .43279 L .51085 .44373 L p .57 .07 .85 r
F P
0 g
s
.50919 .44172 m .51085 .44373 L .50924 .43279 L p .569 .069 .846 r
F P
0 g
s
.50924 .43279 m .50654 .43136 L .50919 .44172 L p .569 .069 .846 r
F P
0 g
s
.53216 .86635 m .54368 .9326 L .42972 .93946 L p .816 .071 .857 r
F P
0 g
s
.54368 .9326 m .53216 .86635 L .59982 .84128 L p .812 .068 .838 r
F P
0 g
s
.59982 .84128 m .65327 .90054 L .54368 .9326 L p .812 .068 .838 r
F P
0 g
s
.50644 .43841 m .50919 .44172 L .50654 .43136 L p .567 .067 .833 r
F P
0 g
s
.50654 .43136 m .50209 .42898 L .50644 .43841 L p .567 .067 .833 r
F P
0 g
s
.74247 .87879 m .66425 .91272 L p .744 .84522 L .833 .062 .811 r
F P
0 g
s
.66425 .91272 m .65327 .90054 L .744 .84522 L p .833 .062 .811 r
F P
0 g
s
.52021 .59682 m .52455 .62325 L .48265 .63304 L p .733 .085 .923 r
F P
0 g
s
.52455 .62325 m .52021 .59682 L .54471 .57986 L p .733 .074 .872 r
F P
0 g
s
.54471 .57986 m .56467 .60334 L .52455 .62325 L p .733 .074 .872 r
F P
0 g
s
.4289 .38999 m .4624 .40783 L .45083 .411 L p .981 .061 .806 r
F P
0 g
s
.45083 .411 m .41001 .403 L .4289 .38999 L p .981 .061 .806 r
F P
0 g
s
.56467 .60334 m .54471 .57986 L .56449 .55733 L p .747 .064 .821 r
F P
0 g
s
.56449 .55733 m .59723 .57431 L .56467 .60334 L p .747 .064 .821 r
F P
0 g
s
.22005 .67319 m .16503 .62752 L p .25607 .67992 L .86 .066 .828 r
F P
0 g
s
.16503 .62752 m .21584 .62421 L .25607 .67992 L p .86 .066 .828 r
F P
0 g
s
.35576 .646 m .25607 .67992 L .21584 .62421 L p .861 .07 .85 r
F P
0 g
s
.50191 .43293 m .50644 .43841 L .50209 .42898 L p .555 .055 .773 r
F P
0 g
s
.50209 .42898 m .49473 .42506 L .50191 .43293 L p .555 .055 .773 r
F P
0 g
s
.51336 .45838 m .51337 .45849 L .51328 .44666 L p .618 .118 1 r
F P
0 g
s
.51328 .44666 m .51319 .44656 L .51336 .45838 L p .618 .118 1 r
F P
0 g
s
.51333 .4582 m .51336 .45838 L .51319 .44656 L p .618 .118 1 r
F P
0 g
s
.51319 .44656 m .51306 .4464 L .51333 .4582 L p .618 .118 1 r
F P
0 g
s
.51328 .45789 m .51333 .4582 L .51306 .4464 L p .619 .119 1 r
F P
0 g
s
.51306 .4464 m .51283 .44613 L .51328 .45789 L p .619 .119 1 r
F P
0 g
s
.5132 .45738 m .51328 .45789 L .51283 .44613 L p .619 .119 1 r
F P
0 g
s
.51283 .44613 m .51246 .44568 L .5132 .45738 L p .619 .119 1 r
F P
0 g
s
.51306 .45655 m .5132 .45738 L .51246 .44568 L p .621 .121 1 r
F P
0 g
s
.51246 .44568 m .51185 .44494 L .51306 .45655 L p .621 .121 1 r
F P
0 g
s
.51285 .45518 m .51306 .45655 L .51185 .44494 L p .622 .122 1 r
F P
0 g
s
.51185 .44494 m .51085 .44373 L .51285 .45518 L p .622 .122 1 r
F P
0 g
s
.49441 .42387 m .50191 .43293 L .49473 .42506 L p 1 0 .5 r
F P
0 g
s
.49473 .42506 m .48256 .41858 L .49441 .42387 L p 1 0 .5 r
F P
0 g
s
.51248 .45291 m .51285 .45518 L .51085 .44373 L p .623 .123 1 r
F P
0 g
s
.51085 .44373 m .50919 .44172 L .51248 .45291 L p .623 .123 1 r
F P
0 g
s
.51189 .44917 m .51248 .45291 L .50919 .44172 L p .619 .119 1 r
F P
0 g
s
.50919 .44172 m .50644 .43841 L .51189 .44917 L p .619 .119 1 r
F P
0 g
s
.37295 .36018 m .4289 .38999 L .41001 .403 L p .922 .06 .802 r
F P
0 g
s
.41001 .403 m .34231 .38975 L .37295 .36018 L p .922 .06 .802 r
F P
0 g
s
.49461 .60758 m .48265 .63304 L .44502 .63308 L p .751 .093 .966 r
F P
0 g
s
.48265 .63304 m .49461 .60758 L .52021 .59682 L p .733 .085 .923 r
F P
0 g
s
.51353 .4703 m .51348 .4704 L .51337 .45849 L p .681 .181 1 r
F P
0 g
s
.51337 .45849 m .51336 .45838 L .51353 .4703 L p .681 .181 1 r
F P
0 g
s
.51361 .47012 m .51353 .4703 L .51336 .45838 L p .68 .18 1 r
F P
0 g
s
.51336 .45838 m .51333 .4582 L .51361 .47012 L p .68 .18 1 r
F P
0 g
s
.59723 .57431 m .56449 .55733 L .57659 .53073 L p .77 .055 .774 r
F P
0 g
s
.57659 .53073 m .61736 .5385 L .59723 .57431 L p .77 .055 .774 r
F P
0 g
s
.51375 .46982 m .51361 .47012 L .51333 .4582 L p .679 .179 1 r
F P
0 g
s
.51333 .4582 m .51328 .45789 L .51375 .46982 L p .679 .179 1 r
F P
0 g
s
.51397 .46934 m .51375 .46982 L .51328 .45789 L p .678 .178 1 r
F P
0 g
s
.51328 .45789 m .5132 .45738 L .51397 .46934 L p .678 .178 1 r
F P
0 g
s
.5109 .44297 m .51189 .44917 L .50644 .43841 L p 1 0 .5 r
F P
0 g
s
.50644 .43841 m .50191 .43293 L .5109 .44297 L p 1 0 .5 r
F P
0 g
s
.51433 .46853 m .51397 .46934 L .5132 .45738 L p .675 .175 1 r
F P
0 g
s
.5132 .45738 m .51306 .45655 L .51433 .46853 L p .675 .175 1 r
F P
0 g
s
.48196 .40882 m .49441 .42387 L .48256 .41858 L p 1 .03 .648 r
F P
0 g
s
.48256 .41858 m .4624 .40783 L .48196 .40882 L p 1 .03 .648 r
F P
0 g
s
.51494 .46721 m .51433 .46853 L .51306 .45655 L p 1 0 .5 r
F P
0 g
s
.51306 .45655 m .51285 .45518 L .51494 .46721 L p 1 0 .5 r
F P
0 g
s
.29557 .9443 m .32619 .92191 L .42972 .93946 L p .843 .069 .844 r
F P
0 g
s
.46161 .87555 m .42972 .93946 L .32619 .92191 L p .828 .074 .87 r
F P
0 g
s
.42972 .93946 m .46161 .87555 L .53216 .86635 L p .816 .071 .857 r
F P
0 g
s
.65327 .90054 m .59982 .84128 L .65515 .80175 L p .815 .063 .816 r
F P
0 g
s
.65515 .80175 m .744 .84522 L .65327 .90054 L p .815 .063 .816 r
F P
0 g
s
.51594 .46503 m .51494 .46721 L .51285 .45518 L p 1 0 .5 r
F P
0 g
s
.51285 .45518 m .51248 .45291 L .51594 .46503 L p 1 0 .5 r
F P
0 g
s
.68418 .55125 m .61736 .5385 L .62187 .49931 L p .818 .051 .753 r
F P
0 g
s
.62187 .49931 m .69248 .49458 L .68418 .55125 L p .818 .051 .753 r
F P
0 g
s
.51758 .46142 m .51594 .46503 L .51248 .45291 L p 1 0 .5 r
F P
0 g
s
.51248 .45291 m .51189 .44917 L .51758 .46142 L p 1 0 .5 r
F P
0 g
s
.50926 .43272 m .5109 .44297 L .50191 .43293 L p 1 0 .5 r
F P
0 g
s
.50191 .43293 m .49441 .42387 L .50926 .43272 L p 1 0 .5 r
F P
0 g
s
.51368 .4823 m .51357 .48239 L .51348 .4704 L p 1 0 .5 r
F P
0 g
s
.51348 .4704 m .51353 .4703 L .51368 .4823 L p 1 0 .5 r
F P
0 g
s
.51386 .48215 m .51368 .4823 L .51353 .4703 L p 1 0 .5 r
F P
0 g
s
.51353 .4703 m .51361 .47012 L .51386 .48215 L p 1 0 .5 r
F P
0 g
s
.51416 .48192 m .51386 .48215 L .51361 .47012 L p 1 0 .5 r
F P
0 g
s
.51361 .47012 m .51375 .46982 L .51416 .48192 L p 1 0 .5 r
F P
0 g
s
.51465 .48152 m .51416 .48192 L .51375 .46982 L p 1 0 .5 r
F P
0 g
s
.51375 .46982 m .51397 .46934 L .51465 .48152 L p 1 0 .5 r
F P
0 g
s
.51547 .48087 m .51465 .48152 L .51397 .46934 L p 1 0 .5 r
F P
0 g
s
.51397 .46934 m .51433 .46853 L .51547 .48087 L p 1 0 .5 r
F P
0 g
s
.52031 .45547 m .51758 .46142 L .51189 .44917 L p 1 0 .5 r
F P
0 g
s
.51189 .44917 m .5109 .44297 L .52031 .45547 L p 1 0 .5 r
F P
0 g
s
.51681 .4798 m .51547 .48087 L .51433 .46853 L p 1 0 .5 r
F P
0 g
s
.51433 .46853 m .51494 .46721 L .51681 .4798 L p 1 0 .5 r
F P
0 g
s
.744 .84522 m .78208 .86385 L .74247 .87879 L p .833 .062 .811 r
F P
0 g
s
.27871 .30997 m .37295 .36018 L .34231 .38975 L p .89 .06 .798 r
F P
0 g
s
.34231 .38975 m .22964 .36768 L .27871 .30997 L p .89 .06 .798 r
F P
0 g
s
.51902 .47804 m .51681 .4798 L .51494 .46721 L p 1 0 .5 r
F P
0 g
s
.51494 .46721 m .51594 .46503 L .51902 .47804 L p 1 0 .5 r
F P
0 g
s
.46121 .38375 m .48196 .40882 L .4624 .40783 L p 1 .046 .729 r
F P
0 g
s
.4624 .40783 m .4289 .38999 L .46121 .38375 L p 1 .046 .729 r
F P
0 g
s
.52266 .47513 m .51902 .47804 L .51594 .46503 L p 1 0 .5 r
F P
0 g
s
.51594 .46503 m .51758 .46142 L .52266 .47513 L p 1 0 .5 r
F P
0 g
s
.53247 .56546 m .54471 .57986 L .52021 .59682 L p .673 .081 .906 r
F P
0 g
s
.54471 .57986 m .53247 .56546 L .54448 .54695 L p .7 .066 .83 r
F P
0 g
s
.54448 .54695 m .56449 .55733 L .54471 .57986 L p .7 .066 .83 r
F P
0 g
s
.51379 .49439 m .51364 .49444 L .51357 .48239 L p .96 0 .5 r
F P
0 g
s
.51357 .48239 m .51368 .4823 L .51379 .49439 L p .96 0 .5 r
F P
0 g
s
.51405 .4943 m .51379 .49439 L .51368 .4823 L p .96 0 .5 r
F P
0 g
s
.51368 .4823 m .51386 .48215 L .51405 .4943 L p .96 0 .5 r
F P
0 g
s
.51446 .49415 m .51405 .4943 L .51386 .48215 L p .959 0 .5 r
F P
0 g
s
.51386 .48215 m .51416 .48192 L .51446 .49415 L p .959 0 .5 r
F P
0 g
s
.50654 .41569 m .50926 .43272 L .49441 .42387 L p 1 .015 .574 r
F P
0 g
s
.49441 .42387 m .48196 .40882 L .50654 .41569 L p 1 .015 .574 r
F P
0 g
s
.51515 .49391 m .51446 .49415 L .51416 .48192 L p .957 0 .5 r
F P
0 g
s
.51416 .48192 m .51465 .48152 L .51515 .49391 L p .957 0 .5 r
F P
0 g
s
.52482 .4456 m .52031 .45547 L .5109 .44297 L p 1 0 .5 r
F P
0 g
s
.5109 .44297 m .50926 .43272 L .52482 .4456 L p 1 0 .5 r
F P
0 g
s
.51629 .49351 m .51515 .49391 L .51465 .48152 L p .954 0 .5 r
F P
0 g
s
.51465 .48152 m .51547 .48087 L .51629 .49351 L p .954 0 .5 r
F P
0 g
s
.51816 .49286 m .51629 .49351 L .51547 .48087 L p .949 0 .5 r
F P
0 g
s
.51547 .48087 m .51681 .4798 L .51816 .49286 L p .949 0 .5 r
F P
0 g
s
.52869 .47031 m .52266 .47513 L .51758 .46142 L p 1 0 .5 r
F P
0 g
s
.51758 .46142 m .52031 .45547 L .52869 .47031 L p 1 0 .5 r
F P
0 g
s
.51755 .5806 m .52021 .59682 L .49461 .60758 L p .659 .099 .993 r
F P
0 g
s
.52021 .59682 m .51755 .5806 L .53247 .56546 L p .673 .081 .906 r
F P
0 g
s
.61736 .5385 m .57659 .53073 L .57914 .50217 L p .8 .047 .733 r
F P
0 g
s
.57914 .50217 m .62187 .49931 L .61736 .5385 L p .8 .047 .733 r
F P
0 g
s
.52125 .49178 m .51816 .49286 L .51681 .4798 L p .941 0 .5 r
F P
0 g
s
.51681 .4798 m .51902 .47804 L .52125 .49178 L p .941 0 .5 r
F P
0 g
s
.56449 .55733 m .54448 .54695 L .55178 .526 L p .735 .053 .764 r
F P
0 g
s
.55178 .526 m .57659 .53073 L .56449 .55733 L p .735 .053 .764 r
F P
0 g
s
.52634 .49 m .52125 .49178 L .51902 .47804 L p .929 0 .5 r
F P
0 g
s
.51902 .47804 m .52266 .47513 L .52634 .49 L p .929 0 .5 r
F P
0 g
s
.32619 .92191 m .29557 .9443 L .27275 .92508 L p .856 .069 .845 r
F P
0 g
s
.35576 .646 m .4172 .62509 L .44502 .63308 L p .824 .081 .903 r
F P
0 g
s
.47167 .61237 m .44502 .63308 L .4172 .62509 L p .794 .097 .986 r
F P
0 g
s
.44502 .63308 m .47167 .61237 L .49461 .60758 L p .751 .093 .966 r
F P
0 g
s
.53476 .48705 m .52634 .49 L .52266 .47513 L p .912 0 .5 r
F P
0 g
s
.52266 .47513 m .52869 .47031 L .53476 .48705 L p .912 0 .5 r
F P
0 g
s
.51384 .50655 m .51367 .50656 L .51364 .49444 L p .774 0 .5 r
F P
0 g
s
.51364 .49444 m .51379 .49439 L .51384 .50655 L p .774 0 .5 r
F P
0 g
s
.51413 .50653 m .51384 .50655 L .51379 .49439 L p .774 0 .5 r
F P
0 g
s
.51379 .49439 m .51405 .4943 L .51413 .50653 L p .774 0 .5 r
F P
0 g
s
.53867 .46235 m .52869 .47031 L .52031 .45547 L p 1 0 .5 r
F P
0 g
s
.52031 .45547 m .52482 .4456 L .53867 .46235 L p 1 0 .5 r
F P
0 g
s
.51461 .50649 m .51413 .50653 L .51405 .4943 L p .775 0 .5 r
F P
0 g
s
.51405 .4943 m .51446 .49415 L .51461 .50649 L p .775 0 .5 r
F P
0 g
s
.84163 .83862 m .78208 .86385 L p .80281 .77147 L .838 .059 .797 r
F P
0 g
s
.78208 .86385 m .744 .84522 L .80281 .77147 L p .838 .059 .797 r
F P
0 g
s
.51539 .50644 m .51461 .50649 L .51446 .49415 L p .776 0 .5 r
F P
0 g
s
.51446 .49415 m .51515 .49391 L .51539 .50644 L p .776 0 .5 r
F P
0 g
s
.51667 .50636 m .51539 .50644 L .51515 .49391 L p .778 0 .5 r
F P
0 g
s
.51515 .49391 m .51629 .49351 L .51667 .50636 L p .778 0 .5 r
F P
0 g
s
.51879 .50621 m .51667 .50636 L .51629 .49351 L p .78 0 .5 r
F P
0 g
s
.51629 .49351 m .51816 .49286 L .51879 .50621 L p .78 0 .5 r
F P
0 g
s
.52229 .50598 m .51879 .50621 L .51816 .49286 L p .783 0 .5 r
F P
0 g
s
.51816 .49286 m .52125 .49178 L .52229 .50598 L p .783 0 .5 r
F P
0 g
s
.42687 1.15257 m .3845 1.23185 L .32287 1.18239 L p .853 .071 .857 r
F P
0 g
s
.43249 1.2137 m .3845 1.23185 L p .54471 1.1446 L .844 .07 .85 r
F P
0 g
s
.3845 1.23185 m .42687 1.15257 L .54471 1.1446 L p .844 .07 .85 r
F P
0 g
s
.57659 .53073 m .55178 .526 L .55326 .5039 L p .778 .041 .707 r
F P
0 g
s
.55326 .5039 m .57914 .50217 L .57659 .53073 L p .778 .041 .707 r
F P
0 g
s
.52806 .50559 m .52229 .50598 L .52125 .49178 L p .792 .004 .521 r
F P
0 g
s
.52125 .49178 m .52634 .49 L .52806 .50559 L p .792 .004 .521 r
F P
0 g
s
.53231 .42922 m .52482 .4456 L .50926 .43272 L p 1 .011 .557 r
F P
0 g
s
.50926 .43272 m .50654 .41569 L .53231 .42922 L p 1 .011 .557 r
F P
0 g
s
.50195 .59196 m .49461 .60758 L .47167 .61237 L p .668 .116 1 r
F P
0 g
s
.49461 .60758 m .50195 .59196 L .51755 .5806 L p .659 .099 .993 r
F P
0 g
s
.21584 .62421 m .33253 .6166 L .35576 .646 L p .861 .07 .85 r
F P
0 g
s
.4172 .62509 m .35576 .646 L .33253 .6166 L p .863 .078 .89 r
F P
0 g
s
.53757 .50496 m .52806 .50559 L .52634 .49 L p .804 .012 .562 r
F P
0 g
s
.52634 .49 m .53476 .48705 L .53757 .50496 L p .804 .012 .562 r
F P
0 g
s
.54866 .48219 m .53476 .48705 L .52869 .47031 L p .898 .008 .541 r
F P
0 g
s
.52869 .47031 m .53867 .46235 L .54866 .48219 L p .898 .008 .541 r
F P
0 g
s
.53229 .54062 m .54448 .54695 L .53247 .56546 L p .644 .068 .839 r
F P
0 g
s
.54448 .54695 m .53229 .54062 L .5367 .52312 L p .695 .05 .752 r
F P
0 g
s
.5367 .52312 m .55178 .526 L .54448 .54695 L p .695 .05 .752 r
F P
0 g
s
.525 .55667 m .53247 .56546 L .51755 .5806 L p .595 .089 .947 r
F P
0 g
s
.53247 .56546 m .525 .55667 L .53229 .54062 L p .644 .068 .839 r
F P
0 g
s
.42637 .34165 m .46121 .38375 L .4289 .38999 L p .938 .052 .76 r
F P
0 g
s
.4289 .38999 m .37295 .36018 L .42637 .34165 L p .938 .052 .76 r
F P
0 g
s
.51383 .51876 m .51366 .51873 L .51367 .50656 L p .651 .014 .569 r
F P
0 g
s
.51367 .50656 m .51384 .50655 L .51383 .51876 L p .651 .014 .569 r
F P
0 g
s
.55326 .5039 m .53757 .50496 L .53476 .48705 L p .817 .022 .609 r
F P
0 g
s
.53476 .48705 m .54866 .48219 L .55326 .5039 L p .817 .022 .609 r
F P
0 g
s
.51411 .51881 m .51383 .51876 L .51384 .50655 L p .652 .014 .571 r
F P
0 g
s
.51384 .50655 m .51413 .50653 L .51411 .51881 L p .652 .014 .571 r
F P
0 g
s
.51456 .5189 m .51411 .51881 L .51413 .50653 L p .654 .015 .573 r
F P
0 g
s
.51413 .50653 m .51461 .50649 L .51456 .5189 L p .654 .015 .573 r
F P
0 g
s
.55178 .526 m .5367 .52312 L .53757 .50496 L p .752 .036 .678 r
F P
0 g
s
.53757 .50496 m .55326 .5039 L .55178 .526 L p .752 .036 .678 r
F P
0 g
s
.51532 .51904 m .51456 .5189 L .51461 .50649 L p .658 .015 .577 r
F P
0 g
s
.51461 .50649 m .51539 .50644 L .51532 .51904 L p .658 .015 .577 r
F P
0 g
s
.51656 .51928 m .51532 .51904 L .51539 .50644 L p .663 .017 .583 r
F P
0 g
s
.51539 .50644 m .51667 .50636 L .51656 .51928 L p .663 .017 .583 r
F P
0 g
s
.51861 .51967 m .51656 .51928 L .51667 .50636 L p .672 .018 .592 r
F P
0 g
s
.51667 .50636 m .51879 .50621 L .51861 .51967 L p .672 .018 .592 r
F P
0 g
s
.50201 .38725 m .50654 .41569 L .48196 .40882 L p 1 .035 .676 r
F P
0 g
s
.48196 .40882 m .46121 .38375 L .50201 .38725 L p 1 .035 .676 r
F P
0 g
s
.52198 .52031 m .51861 .51967 L .51879 .50621 L p .685 .021 .605 r
F P
0 g
s
.51879 .50621 m .52229 .50598 L .52198 .52031 L p .685 .021 .605 r
F P
0 g
s
.52754 .52137 m .52198 .52031 L .52229 .50598 L p .703 .025 .624 r
F P
0 g
s
.52229 .50598 m .52806 .50559 L .52754 .52137 L p .703 .025 .624 r
F P
0 g
s
.5367 .52312 m .52754 .52137 L .52806 .50559 L p .726 .03 .649 r
F P
0 g
s
.52806 .50559 m .53757 .50496 L .5367 .52312 L p .726 .03 .649 r
F P
0 g
s
.17929 .30317 m .23673 .2876 L p .22964 .36768 L .873 .059 .795 r
F P
0 g
s
.23673 .2876 m .27871 .30997 L .22964 .36768 L p .873 .059 .795 r
F P
0 g
s
.22964 .36768 m .07537 .33747 L .17929 .30317 L p .873 .059 .795 r
F P
0 g
s
.55521 .44913 m .53867 .46235 L .52482 .4456 L p .96 .015 .576 r
F P
0 g
s
.52482 .4456 m .53231 .42922 L .55521 .44913 L p .96 .015 .576 r
F P
0 g
s
.57914 .50217 m .55326 .5039 L .54866 .48219 L p .828 .031 .656 r
F P
0 g
s
.52754 .52137 m .5367 .52312 L .53229 .54062 L p .656 .048 .739 r
F P
0 g
s
.51593 .57068 m .51755 .5806 L .50195 .59196 L p .618 .118 1 r
F P
0 g
s
.51755 .5806 m .51593 .57068 L .525 .55667 L p .595 .089 .947 r
F P
0 g
s
.62187 .49931 m .57914 .50217 L .57166 .47414 L p .837 .039 .697 r
F P
0 g
s
.54866 .48219 m .57166 .47414 L .57914 .50217 L p .828 .031 .656 r
F P
0 g
s
.53229 .54062 m .52487 .53678 L .52754 .52137 L p .656 .048 .739 r
F P
0 g
s
.52198 .52031 m .52754 .52137 L .52487 .53678 L p .622 .045 .727 r
F P
0 g
s
.57166 .47414 m .54866 .48219 L .53867 .46235 L p .888 .022 .611 r
F P
0 g
s
.52487 .53678 m .53229 .54062 L .525 .55667 L p .587 .069 .845 r
F P
0 g
s
.53867 .46235 m .55521 .44913 L .57166 .47414 L p .888 .022 .611 r
F P
0 g
s
.52487 .53678 m .52036 .53444 L .52198 .52031 L p .622 .045 .727 r
F P
0 g
s
.51861 .51967 m .52198 .52031 L .52036 .53444 L p .596 .044 .718 r
F P
0 g
s
.52036 .53444 m .51763 .53302 L .51861 .51967 L p .596 .044 .718 r
F P
0 g
s
.51656 .51928 m .51861 .51967 L .51763 .53302 L p .577 .042 .711 r
F P
0 g
s
.51763 .53302 m .51596 .53216 L .51656 .51928 L p .577 .042 .711 r
F P
0 g
s
.51532 .51904 m .51656 .51928 L .51596 .53216 L p .565 .041 .706 r
F P
0 g
s
.51596 .53216 m .51496 .53163 L .51532 .51904 L p .565 .041 .706 r
F P
0 g
s
.51456 .5189 m .51532 .51904 L .51496 .53163 L p .557 .041 .703 r
F P
0 g
s
.51496 .53163 m .51435 .53132 L .51456 .5189 L p .557 .041 .703 r
F P
0 g
s
.51411 .51881 m .51456 .5189 L .51435 .53132 L p .552 .04 .7 r
F P
0 g
s
.69248 .49458 m .62187 .49931 L .6098 .4608 L p .843 .046 .729 r
F P
0 g
s
.57166 .47414 m .6098 .4608 L .62187 .49931 L p .837 .039 .697 r
F P
0 g
s
.51435 .53132 m .51397 .53112 L .51411 .51881 L p .552 .04 .7 r
F P
0 g
s
.51383 .51876 m .51411 .51881 L .51397 .53112 L p .548 .04 .699 r
F P
0 g
s
.51397 .53112 m .51375 .53101 L .51383 .51876 L p .548 .04 .699 r
F P
0 g
s
.51366 .51873 m .51383 .51876 L .51375 .53101 L p .546 .04 .698 r
F P
0 g
s
.51375 .53101 m .51361 .53094 L .51366 .51873 L p .546 .04 .698 r
F P
0 g
s
.52045 .55131 m .525 .55667 L .51593 .57068 L p .597 .097 .987 r
F P
0 g
s
.525 .55667 m .52045 .55131 L .52487 .53678 L p .587 .069 .845 r
F P
0 g
s
.52036 .53444 m .52487 .53678 L .52045 .55131 L p .57 .07 .849 r
F P
0 g
s
.80281 .77147 m .9529 .79848 L .84163 .83862 L p .838 .059 .797 r
F P
0 g
s
.54471 1.1446 m .54976 1.17168 L .43249 1.2137 L p .844 .07 .85 r
F P
0 g
s
.52045 .55131 m .51768 .54806 L .52036 .53444 L p .57 .07 .849 r
F P
0 g
s
.51763 .53302 m .52036 .53444 L .51768 .54806 L p .57 .07 .851 r
F P
0 g
s
.4172 .62509 m .45484 .61228 L .47167 .61237 L p .794 .097 .986 r
F P
0 g
s
.488 .59968 m .47167 .61237 L .45484 .61228 L p .718 .127 1 r
F P
0 g
s
.47167 .61237 m .488 .59968 L .50195 .59196 L p .668 .116 1 r
F P
0 g
s
.80929 .48675 m .69248 .49458 L .67332 .43858 L p .846 .05 .752 r
F P
0 g
s
.6098 .4608 m .67332 .43858 L .69248 .49458 L p .843 .046 .729 r
F P
0 g
s
.50644 .58241 m .50195 .59196 L .488 .59968 L p .652 .152 1 r
F P
0 g
s
.50195 .59196 m .50644 .58241 L .51593 .57068 L p .618 .118 1 r
F P
0 g
s
.54481 .40188 m .53231 .42922 L .50654 .41569 L p .968 .031 .653 r
F P
0 g
s
.50654 .41569 m .50201 .38725 L .54481 .40188 L p .968 .031 .653 r
F P
0 g
s
.51768 .54806 m .516 .54608 L .51763 .53302 L p .57 .07 .851 r
F P
0 g
s
.51596 .53216 m .51763 .53302 L .516 .54608 L p .57 .07 .852 r
F P
0 g
s
.6098 .4608 m .57166 .47414 L .55521 .44913 L p .879 .034 .669 r
F P
0 g
s
.744 .84522 m .65515 .80175 L .69001 .75117 L p .824 .059 .794 r
F P
0 g
s
.69001 .75117 m .80281 .77147 L .744 .84522 L p .824 .059 .794 r
F P
0 g
s
.516 .54608 m .51498 .54488 L .51596 .53216 L p .57 .07 .852 r
F P
0 g
s
.51496 .53163 m .51596 .53216 L .51498 .54488 L p .57 .07 .852 r
F P
0 g
s
.51593 .57068 m .51494 .56464 L .52045 .55131 L p .597 .097 .987 r
F P
0 g
s
.51768 .54806 m .52045 .55131 L .51494 .56464 L p .604 .104 1 r
F P
0 g
s
.51498 .54488 m .51436 .54415 L .51496 .53163 L p .57 .07 .852 r
F P
0 g
s
.51435 .53132 m .51496 .53163 L .51436 .54415 L p .57 .07 .852 r
F P
0 g
s
.51494 .56464 m .51593 .57068 L .50644 .58241 L p .64 .14 1 r
F P
0 g
s
.51436 .54415 m .51398 .54371 L .51435 .53132 L p .57 .07 .852 r
F P
0 g
s
.51397 .53112 m .51435 .53132 L .51398 .54371 L p .57 .07 .852 r
F P
0 g
s
.51398 .54371 m .51375 .54344 L .51397 .53112 L p .57 .07 .852 r
F P
0 g
s
.51375 .53101 m .51397 .53112 L .51375 .54344 L p .57 .07 .852 r
F P
0 g
s
.51375 .54344 m .51362 .54328 L .51375 .53101 L p .57 .07 .852 r
F P
0 g
s
.51361 .53094 m .51375 .53101 L .51362 .54328 L p .57 .07 .852 r
F P
0 g
s
.51362 .54328 m .51353 .54318 L .51361 .53094 L p .57 .07 .852 r
F P
0 g
s
.27275 .92508 m .22593 .89031 L p .32619 .92191 L .856 .069 .845 r
F P
0 g
s
.22593 .89031 m .24731 .88347 L .32619 .92191 L p .856 .069 .845 r
F P
0 g
s
.39796 .86941 m .32619 .92191 L .24731 .88347 L p .848 .075 .873 r
F P
0 g
s
.32619 .92191 m .39796 .86941 L .46161 .87555 L p .828 .074 .87 r
F P
0 g
s
.51494 .56464 m .51433 .56096 L .51768 .54806 L p .604 .104 1 r
F P
0 g
s
.516 .54608 m .51768 .54806 L .51433 .56096 L p .609 .109 1 r
F P
0 g
s
.55521 .44913 m .58275 .42714 L .6098 .4608 L p .879 .034 .669 r
F P
0 g
s
.58275 .42714 m .55521 .44913 L .53231 .42922 L p .924 .031 .653 r
F P
0 g
s
.53231 .42922 m .54481 .40188 L .58275 .42714 L p .924 .031 .653 r
F P
0 g
s
.33253 .6166 m .40355 .61198 L .4172 .62509 L p .863 .078 .89 r
F P
0 g
s
.45484 .61228 m .4172 .62509 L .40355 .61198 L p .859 .093 .965 r
F P
0 g
s
.51433 .56096 m .51397 .55873 L .516 .54608 L p .609 .109 1 r
F P
0 g
s
.51498 .54488 m .516 .54608 L .51397 .55873 L p .613 .113 1 r
F P
0 g
s
.86048 .48332 m .80929 .48675 L .77976 .40134 L p .849 .053 .767 r
F P
0 g
s
.67332 .43858 m .77976 .40134 L .80929 .48675 L p .846 .05 .752 r
F P
0 g
s
.50644 .58241 m .50917 .57659 L .51494 .56464 L p .64 .14 1 r
F P
0 g
s
.51433 .56096 m .51494 .56464 L .50917 .57659 L p .66 .16 1 r
F P
0 g
s
.51397 .55873 m .51375 .55738 L .51498 .54488 L p .613 .113 1 r
F P
0 g
s
.51436 .54415 m .51498 .54488 L .51375 .55738 L p .615 .115 1 r
F P
0 g
s
.51375 .55738 m .51361 .55655 L .51436 .54415 L p .615 .115 1 r
F P
0 g
s
.51398 .54371 m .51436 .54415 L .51361 .55655 L p .616 .116 1 r
F P
0 g
s
.51361 .55655 m .51353 .55605 L .51398 .54371 L p .616 .116 1 r
F P
0 g
s
.51375 .54344 m .51398 .54371 L .51353 .55605 L p .616 .116 1 r
F P
0 g
s
.51353 .55605 m .51348 .55575 L .51375 .54344 L p .616 .116 1 r
F P
0 g
s
.51362 .54328 m .51375 .54344 L .51348 .55575 L p .617 .117 1 r
F P
0 g
s
.51348 .55575 m .51345 .55557 L .51362 .54328 L p .617 .117 1 r
F P
0 g
s
.51353 .54318 m .51362 .54328 L .51345 .55557 L p .617 .117 1 r
F P
0 g
s
.51345 .55557 m .51343 .55546 L .51353 .54318 L p .617 .117 1 r
F P
0 g
s
.488 .59968 m .49796 .59194 L .50644 .58241 L p .652 .152 1 r
F P
0 g
s
.50917 .57659 m .50644 .58241 L .49796 .59194 L p .69 .19 1 r
F P
0 g
s
.81547 .41293 m .86048 .48332 L p .77976 .40134 L .849 .053 .767 r
F P
0 g
s
.50917 .57659 m .51083 .57306 L .51433 .56096 L p .66 .16 1 r
F P
0 g
s
.51397 .55873 m .51433 .56096 L .51083 .57306 L p .673 .173 1 r
F P
0 g
s
.45484 .61228 m .4778 .60447 L .488 .59968 L p .718 .127 1 r
F P
0 g
s
.49796 .59194 m .488 .59968 L .4778 .60447 L p .666 .166 1 r
F P
0 g
s
.49437 .33939 m .50201 .38725 L .46121 .38375 L p .937 .045 .727 r
F P
0 g
s
.46121 .38375 m .42637 .34165 L .49437 .33939 L p .937 .045 .727 r
F P
0 g
s
.67332 .43858 m .6098 .4608 L .58275 .42714 L p .87 .042 .712 r
F P
0 g
s
.51083 .57306 m .51184 .57091 L .51397 .55873 L p .673 .173 1 r
F P
0 g
s
.51375 .55738 m .51397 .55873 L .51184 .57091 L p .679 .179 1 r
F P
0 g
s
.51184 .57091 m .51246 .5696 L .51375 .55738 L p .679 .179 1 r
F P
0 g
s
.51361 .55655 m .51375 .55738 L .51246 .5696 L p .681 .181 1 r
F P
0 g
s
.49796 .59194 m .50402 .58723 L .50917 .57659 L p .69 .19 1 r
F P
0 g
s
.51083 .57306 m .50917 .57659 L .50402 .58723 L p .697 .197 1 r
F P
0 g
s
.36715 .2701 m .42637 .34165 L .37295 .36018 L p .9 .055 .774 r
F P
0 g
s
.37295 .36018 m .27871 .30997 L .36715 .2701 L p .9 .055 .774 r
F P
0 g
s
.51246 .5696 m .51283 .56881 L .51361 .55655 L p .681 .181 1 r
F P
0 g
s
.51353 .55605 m .51361 .55655 L .51283 .56881 L p .682 .182 1 r
F P
0 g
s
.51283 .56881 m .51305 .56833 L .51353 .55605 L p .682 .182 1 r
F P
0 g
s
.51348 .55575 m .51353 .55605 L .51305 .56833 L p .682 .182 1 r
F P
0 g
s
.51305 .56833 m .51319 .56804 L .51348 .55575 L p .682 .182 1 r
F P
0 g
s
.51345 .55557 m .51348 .55575 L .51319 .56804 L p .681 .181 1 r
F P
0 g
s
.51319 .56804 m .51327 .56786 L .51345 .55557 L p .681 .181 1 r
F P
0 g
s
.51343 .55546 m .51345 .55557 L .51327 .56786 L p .681 .181 1 r
F P
0 g
s
.51327 .56786 m .51332 .56776 L .51343 .55546 L p .681 .181 1 r
F P
0 g
s
.50402 .58723 m .50771 .58437 L .51083 .57306 L p .697 .197 1 r
F P
0 g
s
.51184 .57091 m .51083 .57306 L .50771 .58437 L p 1 0 .5 r
F P
0 g
s
.40355 .61198 m .44672 .60916 L .45484 .61228 L p .859 .093 .965 r
F P
0 g
s
.4778 .60447 m .45484 .61228 L .44672 .60916 L p .817 .119 1 r
F P
0 g
s
.4778 .60447 m .49178 .59971 L .49796 .59194 L p .666 .166 1 r
F P
0 g
s
.50402 .58723 m .49796 .59194 L .49178 .59971 L p .888 0 .5 r
F P
0 g
s
.52493 .82479 m .53216 .86635 L .46161 .87555 L p .784 .078 .89 r
F P
0 g
s
.53216 .86635 m .52493 .82479 L .56642 .80424 L p .78 .072 .858 r
F P
0 g
s
.56642 .80424 m .59982 .84128 L .53216 .86635 L p .78 .072 .858 r
F P
0 g
s
.50771 .58437 m .50995 .58263 L .51184 .57091 L p 1 0 .5 r
F P
0 g
s
.51246 .5696 m .51184 .57091 L .50995 .58263 L p 1 0 .5 r
F P
0 g
s
.50995 .58263 m .51131 .58158 L .51246 .5696 L p 1 0 .5 r
F P
0 g
s
.51283 .56881 m .51246 .5696 L .51131 .58158 L p 1 0 .5 r
F P
0 g
s
.51131 .58158 m .51213 .58094 L .51283 .56881 L p 1 0 .5 r
F P
0 g
s
.51305 .56833 m .51283 .56881 L .51213 .58094 L p 1 0 .5 r
F P
0 g
s
.21584 .62421 m .16503 .62752 L .09168 .56093 L p .873 .063 .817 r
F P
0 g
s
.51213 .58094 m .51263 .58055 L .51305 .56833 L p 1 0 .5 r
F P
0 g
s
.51319 .56804 m .51305 .56833 L .51263 .58055 L p 1 0 .5 r
F P
0 g
s
.51263 .58055 m .51293 .58031 L .51319 .56804 L p 1 0 .5 r
F P
0 g
s
.51327 .56786 m .51319 .56804 L .51293 .58031 L p 1 0 .5 r
F P
0 g
s
.51293 .58031 m .51312 .58017 L .51327 .56786 L p 1 0 .5 r
F P
0 g
s
.51332 .56776 m .51327 .56786 L .51312 .58017 L p 1 0 .5 r
F P
0 g
s
.51312 .58017 m .51323 .58008 L .51332 .56776 L p 1 0 .5 r
F P
0 g
s
.49178 .59971 m .50028 .59682 L .50402 .58723 L p .888 0 .5 r
F P
0 g
s
.50771 .58437 m .50402 .58723 L .50028 .59682 L p .962 0 .5 r
F P
0 g
s
.59982 .84128 m .56642 .80424 L .60009 .77481 L p .787 .064 .822 r
F P
0 g
s
.60009 .77481 m .65515 .80175 L .59982 .84128 L p .787 .064 .822 r
F P
0 g
s
.58275 .42714 m .62889 .39029 L .67332 .43858 L p .87 .042 .712 r
F P
0 g
s
.62889 .39029 m .58275 .42714 L .54481 .40188 L p .898 .041 .704 r
F P
0 g
s
.09168 .56093 m .06016 .53329 L p .21584 .62421 L .873 .063 .817 r
F P
0 g
s
.06016 .53329 m .21987 .5629 L .21584 .62421 L p .873 .063 .817 r
F P
0 g
s
.33253 .6166 m .21584 .62421 L .21987 .5629 L p .884 .066 .831 r
F P
0 g
s
.44672 .60916 m .47294 .60746 L .4778 .60447 L p .817 .119 1 r
F P
0 g
s
.49178 .59971 m .4778 .60447 L .47294 .60746 L p .503 0 .5 r
F P
0 g
s
.56584 .35589 m .54481 .40188 L .50201 .38725 L p .922 .042 .709 r
F P
0 g
s
.50201 .38725 m .49437 .33939 L .56584 .35589 L p .922 .042 .709 r
F P
0 g
s
.50028 .59682 m .50544 .59507 L .50771 .58437 L p .962 0 .5 r
F P
0 g
s
.50995 .58263 m .50771 .58437 L .50544 .59507 L p .971 0 .5 r
F P
0 g
s
.50544 .59507 m .50857 .594 L .50995 .58263 L p .971 0 .5 r
F P
0 g
s
.51131 .58158 m .50995 .58263 L .50857 .594 L p .969 0 .5 r
F P
0 g
s
.50857 .594 m .51047 .59335 L .51131 .58158 L p .969 0 .5 r
F P
0 g
s
.51213 .58094 m .51131 .58158 L .51047 .59335 L p .966 0 .5 r
F P
0 g
s
.92975 .76485 m .9529 .79848 L p .81953 .68708 L .847 .057 .784 r
F P
0 g
s
.9529 .79848 m .80281 .77147 L .81953 .68708 L p .847 .057 .784 r
F P
0 g
s
.51047 .59335 m .51162 .59296 L .51213 .58094 L p .966 0 .5 r
F P
0 g
s
.51263 .58055 m .51213 .58094 L .51162 .59296 L p .964 0 .5 r
F P
0 g
s
.51162 .59296 m .51232 .59272 L .51263 .58055 L p .964 0 .5 r
F P
0 g
s
.51293 .58031 m .51263 .58055 L .51232 .59272 L p .963 0 .5 r
F P
0 g
s
.51232 .59272 m .51275 .59258 L .51293 .58031 L p .963 0 .5 r
F P
0 g
s
.51312 .58017 m .51293 .58031 L .51275 .59258 L p .962 0 .5 r
F P
0 g
s
.51275 .59258 m .51301 .59249 L .51312 .58017 L p .962 0 .5 r
F P
0 g
s
.51323 .58008 m .51312 .58017 L .51301 .59249 L p .962 0 .5 r
F P
0 g
s
.51301 .59249 m .51316 .59244 L .51323 .58008 L p .962 0 .5 r
F P
0 g
s
.47294 .60746 m .48885 .60642 L .49178 .59971 L p .503 0 .5 r
F P
0 g
s
.50028 .59682 m .49178 .59971 L .48885 .60642 L p .674 0 .5 r
F P
0 g
s
.54481 .40188 m .56584 .35589 L .62889 .39029 L p .898 .041 .704 r
F P
0 g
s
.64257 1.13386 m .54976 1.17168 L p .65804 1.11233 L .84 .067 .837 r
F P
0 g
s
.54976 1.17168 m .54471 1.1446 L .65804 1.11233 L p .84 .067 .837 r
F P
0 g
s
.4816 .8355 m .46161 .87555 L .39796 .86941 L p .801 .083 .914 r
F P
0 g
s
.46161 .87555 m .4816 .8355 L .52493 .82479 L p .784 .078 .89 r
F P
0 g
s
.21987 .5629 m .33646 .58452 L .33253 .6166 L p .884 .066 .831 r
F P
0 g
s
.40355 .61198 m .33253 .6166 L .33646 .58452 L p .904 .071 .856 r
F P
0 g
s
.48885 .60642 m .49851 .60579 L .50028 .59682 L p .674 0 .5 r
F P
0 g
s
.50544 .59507 m .50028 .59682 L .49851 .60579 L p .733 0 .5 r
F P
0 g
s
.77976 .40134 m .67332 .43858 L .62889 .39029 L p .864 .048 .741 r
F P
0 g
s
.49851 .60579 m .50437 .60541 L .50544 .59507 L p .733 0 .5 r
F P
0 g
s
.50857 .594 m .50544 .59507 L .50437 .60541 L p .753 0 .5 r
F P
0 g
s
.50437 .60541 m .50792 .60518 L .50857 .594 L p .753 0 .5 r
F P
0 g
s
.51047 .59335 m .50857 .594 L .50792 .60518 L p .763 0 .5 r
F P
0 g
s
.50792 .60518 m .51008 .60504 L .51047 .59335 L p .763 0 .5 r
F P
0 g
s
.51162 .59296 m .51047 .59335 L .51008 .60504 L p .767 0 .5 r
F P
0 g
s
.51008 .60504 m .51139 .60495 L .51162 .59296 L p .767 0 .5 r
F P
0 g
s
.51232 .59272 m .51162 .59296 L .51139 .60495 L p .77 0 .5 r
F P
0 g
s
.51139 .60495 m .51218 .6049 L .51232 .59272 L p .77 0 .5 r
F P
0 g
s
.51275 .59258 m .51232 .59272 L .51218 .6049 L p .771 0 .5 r
F P
0 g
s
.51218 .6049 m .51266 .60487 L .51275 .59258 L p .771 0 .5 r
F P
0 g
s
.51301 .59249 m .51275 .59258 L .51266 .60487 L p .772 0 .5 r
F P
0 g
s
.51266 .60487 m .51295 .60485 L .51301 .59249 L p .772 0 .5 r
F P
0 g
s
.51316 .59244 m .51301 .59249 L .51295 .60485 L p .772 0 .5 r
F P
0 g
s
.51295 .60485 m .51313 .60484 L .51316 .59244 L p .772 0 .5 r
F P
0 g
s
.33646 .58452 m .40648 .59751 L .40355 .61198 L p .904 .071 .856 r
F P
0 g
s
.44672 .60916 m .40355 .61198 L .40648 .59751 L p .936 .08 .902 r
F P
0 g
s
.40648 .59751 m .4487 .60534 L .44672 .60916 L p .936 .08 .902 r
F P
0 g
s
.47294 .60746 m .44672 .60916 L .4487 .60534 L p .951 .091 .953 r
F P
0 g
s
.4487 .60534 m .47421 .61007 L .47294 .60746 L p .951 .091 .953 r
F P
0 g
s
.48885 .60642 m .47294 .60746 L .47421 .61007 L p .5 0 .5 r
F P
0 g
s
.47421 .61007 m .48965 .61293 L .48885 .60642 L p .5 0 .5 r
F P
0 g
s
.49851 .60579 m .48885 .60642 L .48965 .61293 L p .5 0 .5 r
F P
0 g
s
.48965 .61293 m .499 .61466 L .49851 .60579 L p .5 0 .5 r
F P
0 g
s
.50437 .60541 m .49851 .60579 L .499 .61466 L p .56 0 .5 r
F P
0 g
s
.499 .61466 m .50467 .61571 L .50437 .60541 L p .56 0 .5 r
F P
0 g
s
.50792 .60518 m .50437 .60541 L .50467 .61571 L p .598 .003 .515 r
F P
0 g
s
.50467 .61571 m .50811 .61635 L .50792 .60518 L p .598 .003 .515 r
F P
0 g
s
.51008 .60504 m .50792 .60518 L .50811 .61635 L p .62 .008 .538 r
F P
0 g
s
.50811 .61635 m .51019 .61674 L .51008 .60504 L p .62 .008 .538 r
F P
0 g
s
.51139 .60495 m .51008 .60504 L .51019 .61674 L p .632 .01 .55 r
F P
0 g
s
.51019 .61674 m .51146 .61697 L .51139 .60495 L p .632 .01 .55 r
F P
0 g
s
.51218 .6049 m .51139 .60495 L .51146 .61697 L p .639 .011 .557 r
F P
0 g
s
.51146 .61697 m .51222 .61711 L .51218 .6049 L p .639 .011 .557 r
F P
0 g
s
.51266 .60487 m .51218 .6049 L .51222 .61711 L p .643 .012 .561 r
F P
0 g
s
.51222 .61711 m .51269 .6172 L .51266 .60487 L p .643 .012 .561 r
F P
0 g
s
.51295 .60485 m .51266 .60487 L .51269 .6172 L p .645 .013 .563 r
F P
0 g
s
.51269 .6172 m .51297 .61725 L .51295 .60485 L p .645 .013 .563 r
F P
0 g
s
.51313 .60484 m .51295 .60485 L .51297 .61725 L p .646 .013 .565 r
F P
0 g
s
.51297 .61725 m .51314 .61728 L .51313 .60484 L p .646 .013 .565 r
F P
0 g
s
.65515 .80175 m .60009 .77481 L .62092 .73874 L p .803 .058 .788 r
F P
0 g
s
.62092 .73874 m .69001 .75117 L .65515 .80175 L p .803 .058 .788 r
F P
0 g
s
.48134 .25771 m .49437 .33939 L .42637 .34165 L p .901 .051 .755 r
F P
0 g
s
.42637 .34165 m .36715 .2701 L .48134 .25771 L p .901 .051 .755 r
F P
0 g
s
.51305 .62972 m .51319 .62979 L .51314 .61728 L p .54 .039 .696 r
F P
0 g
s
.51314 .61728 m .51297 .61725 L .51305 .62972 L p .54 .039 .696 r
F P
0 g
s
.51282 .62961 m .51305 .62972 L .51297 .61725 L p .539 .039 .695 r
F P
0 g
s
.51297 .61725 m .51269 .6172 L .51282 .62961 L p .539 .039 .695 r
F P
0 g
s
.51244 .62942 m .51282 .62961 L .51269 .6172 L p .539 .039 .694 r
F P
0 g
s
.51269 .6172 m .51222 .61711 L .51244 .62942 L p .539 .039 .694 r
F P
0 g
s
.51182 .6291 m .51244 .62942 L .51222 .61711 L p .538 .038 .691 r
F P
0 g
s
.51222 .61711 m .51146 .61697 L .51182 .6291 L p .538 .038 .691 r
F P
0 g
s
.32287 1.18239 m .2881 1.1586 L p .42687 1.15257 L .853 .071 .857 r
F P
0 g
s
.5108 .62859 m .51182 .6291 L .51146 .61697 L p .537 .037 .687 r
F P
0 g
s
.51146 .61697 m .51019 .61674 L .5108 .62859 L p .537 .037 .687 r
F P
0 g
s
.5091 .62773 m .5108 .62859 L .51019 .61674 L p .536 .036 .68 r
F P
0 g
s
.51019 .61674 m .50811 .61635 L .5091 .62773 L p .536 .036 .68 r
F P
0 g
s
.50631 .62632 m .5091 .62773 L .50811 .61635 L p .533 .033 .666 r
F P
0 g
s
.50811 .61635 m .50467 .61571 L .50631 .62632 L p .533 .033 .666 r
F P
0 g
s
.5017 .624 m .50631 .62632 L .50467 .61571 L p .528 .028 .638 r
F P
0 g
s
.50467 .61571 m .499 .61466 L .5017 .624 L p .528 .028 .638 r
F P
0 g
s
.49409 .62016 m .5017 .624 L .499 .61466 L p .514 .014 .571 r
F P
0 g
s
.499 .61466 m .48965 .61293 L .49409 .62016 L p .514 .014 .571 r
F P
0 g
s
.65804 1.11233 m .66938 1.12408 L .64257 1.13386 L p .84 .067 .837 r
F P
0 g
s
.4815 .61382 m .49409 .62016 L .48965 .61293 L p .5 0 .5 r
F P
0 g
s
.48965 .61293 m .47421 .61007 L .4815 .61382 L p .5 0 .5 r
F P
0 g
s
.81953 .68708 m .87251 .68373 L .92975 .76485 L p .847 .057 .784 r
F P
0 g
s
.80281 .77147 m .69001 .75117 L .69866 .69472 L p .838 .055 .773 r
F P
0 g
s
.69866 .69472 m .81953 .68708 L .80281 .77147 L p .838 .055 .773 r
F P
0 g
s
.24731 .88347 m .22593 .89031 L .21004 .87711 L p .871 .068 .84 r
F P
0 g
s
.24731 .88347 m .35034 .85048 L .39796 .86941 L p .848 .075 .873 r
F P
0 g
s
.44267 .83672 m .39796 .86941 L .35034 .85048 L p .832 .084 .922 r
F P
0 g
s
.39796 .86941 m .44267 .83672 L .4816 .8355 L p .801 .083 .914 r
F P
0 g
s
.47421 .61007 m .4487 .60534 L .46065 .6033 L p 1 .056 .779 r
F P
0 g
s
.46065 .6033 m .4815 .61382 L .47421 .61007 L p 1 .056 .779 r
F P
0 g
s
.51319 .64227 m .51327 .64237 L .51319 .62979 L p .57 .07 .852 r
F P
0 g
s
.51319 .62979 m .51305 .62972 L .51319 .64227 L p .57 .07 .852 r
F P
0 g
s
.51305 .64211 m .51319 .64227 L .51305 .62972 L p .57 .07 .852 r
F P
0 g
s
.51305 .62972 m .51282 .62961 L .51305 .64211 L p .57 .07 .852 r
F P
0 g
s
.51281 .64185 m .51305 .64211 L .51282 .62961 L p .57 .07 .851 r
F P
0 g
s
.51282 .62961 m .51244 .62942 L .51281 .64185 L p .57 .07 .851 r
F P
0 g
s
.51243 .64141 m .51281 .64185 L .51244 .62942 L p .57 .07 .851 r
F P
0 g
s
.51244 .62942 m .51182 .6291 L .51243 .64141 L p .57 .07 .851 r
F P
0 g
s
.62889 .39029 m .70703 .32788 L .77976 .40134 L p .864 .048 .741 r
F P
0 g
s
.70703 .32788 m .62889 .39029 L .56584 .35589 L p .88 .048 .738 r
F P
0 g
s
.5118 .64069 m .51243 .64141 L .51182 .6291 L p .57 .07 .85 r
F P
0 g
s
.51182 .6291 m .5108 .62859 L .5118 .64069 L p .57 .07 .85 r
F P
0 g
s
.77976 .40134 m .8024 .39342 L .81547 .41293 L p .849 .053 .767 r
F P
0 g
s
.51076 .6395 m .5118 .64069 L .5108 .62859 L p .57 .07 .848 r
F P
0 g
s
.5108 .62859 m .5091 .62773 L .51076 .6395 L p .57 .07 .848 r
F P
0 g
s
.27569 .27536 m .35442 .25472 L p .27871 .30997 L .879 .056 .781 r
F P
0 g
s
.35442 .25472 m .36715 .2701 L .27871 .30997 L p .879 .056 .781 r
F P
0 g
s
.27871 .30997 m .23673 .2876 L .27569 .27536 L p .879 .056 .781 r
F P
0 g
s
.50904 .63754 m .51076 .6395 L .5091 .62773 L p .569 .069 .844 r
F P
0 g
s
.5091 .62773 m .50631 .62632 L .50904 .63754 L p .569 .069 .844 r
F P
0 g
s
.53281 1.08068 m .54471 1.1446 L .42687 1.15257 L p .823 .074 .872 r
F P
0 g
s
.54471 1.1446 m .53281 1.08068 L .60283 1.0551 L p .818 .07 .851 r
F P
0 g
s
.60283 1.0551 m .65804 1.11233 L .54471 1.1446 L p .818 .07 .851 r
F P
0 g
s
.50621 .6343 m .50904 .63754 L .50631 .62632 L p .566 .066 .829 r
F P
0 g
s
.50631 .62632 m .5017 .624 L .50621 .6343 L p .566 .066 .829 r
F P
0 g
s
.75031 1.09029 m .66938 1.12408 L p .75197 1.05757 L .841 .064 .822 r
F P
0 g
s
.66938 1.12408 m .65804 1.11233 L .75197 1.05757 L p .841 .064 .822 r
F P
0 g
s
.52045 .79906 m .52493 .82479 L .4816 .8355 L p .733 .088 .941 r
F P
0 g
s
.52493 .82479 m .52045 .79906 L .54578 .78136 L p .734 .077 .885 r
F P
0 g
s
.54578 .78136 m .56642 .80424 L .52493 .82479 L p .734 .077 .885 r
F P
0 g
s
.42599 .58582 m .46065 .6033 L .4487 .60534 L p 1 .063 .813 r
F P
0 g
s
.4487 .60534 m .40648 .59751 L .42599 .58582 L p 1 .063 .813 r
F P
0 g
s
.56642 .80424 m .54578 .78136 L .56624 .75825 L p .749 .066 .83 r
F P
0 g
s
.56624 .75825 m .60009 .77481 L .56642 .80424 L p .749 .066 .83 r
F P
0 g
s
.21004 .87711 m .15292 .83371 L p .24731 .88347 L .871 .068 .84 r
F P
0 g
s
.15292 .83371 m .20549 .83049 L .24731 .88347 L p .871 .068 .84 r
F P
0 g
s
.35034 .85048 m .24731 .88347 L .20549 .83049 L p .872 .073 .864 r
F P
0 g
s
.50152 .62894 m .50621 .6343 L .5017 .624 L p .555 .055 .775 r
F P
0 g
s
.5017 .624 m .49409 .62016 L .50152 .62894 L p .555 .055 .775 r
F P
0 g
s
.51336 .65492 m .51337 .65503 L .51327 .64237 L p .618 .118 1 r
F P
0 g
s
.51327 .64237 m .51319 .64227 L .51336 .65492 L p .618 .118 1 r
F P
0 g
s
.51332 .65474 m .51336 .65492 L .51319 .64227 L p .618 .118 1 r
F P
0 g
s
.51319 .64227 m .51305 .64211 L .51332 .65474 L p .618 .118 1 r
F P
0 g
s
.51327 .65444 m .51332 .65474 L .51305 .64211 L p .618 .118 1 r
F P
0 g
s
.51305 .64211 m .51281 .64185 L .51327 .65444 L p .618 .118 1 r
F P
0 g
s
.51319 .65394 m .51327 .65444 L .51281 .64185 L p .619 .119 1 r
F P
0 g
s
.51281 .64185 m .51243 .64141 L .51319 .65394 L p .619 .119 1 r
F P
0 g
s
.51305 .65313 m .51319 .65394 L .51243 .64141 L p .62 .12 1 r
F P
0 g
s
.51243 .64141 m .5118 .64069 L .51305 .65313 L p .62 .12 1 r
F P
0 g
s
.8024 .39342 m .77976 .40134 L .70703 .32788 L p .859 .052 .761 r
F P
0 g
s
.51283 .65178 m .51305 .65313 L .5118 .64069 L p .621 .121 1 r
F P
0 g
s
.5118 .64069 m .51076 .6395 L .51283 .65178 L p .621 .121 1 r
F P
0 g
s
.49376 .62007 m .50152 .62894 L .49409 .62016 L p .518 .018 .588 r
F P
0 g
s
.49409 .62016 m .4815 .61382 L .49376 .62007 L p .518 .018 .588 r
F P
0 g
s
.51245 .64957 m .51283 .65178 L .51076 .6395 L p .622 .122 1 r
F P
0 g
s
.51076 .6395 m .50904 .63754 L .51245 .64957 L p .622 .122 1 r
F P
0 g
s
.60168 .27752 m .56584 .35589 L .49437 .33939 L p .894 .048 .742 r
F P
0 g
s
.49437 .33939 m .48134 .25771 L .60168 .27752 L p .894 .048 .742 r
F P
0 g
s
.51183 .6459 m .51245 .64957 L .50904 .63754 L p .618 .118 1 r
F P
0 g
s
.50904 .63754 m .50621 .6343 L .51183 .6459 L p .618 .118 1 r
F P
0 g
s
.36808 .55662 m .42599 .58582 L .40648 .59751 L p .938 .062 .811 r
F P
0 g
s
.40648 .59751 m .33646 .58452 L .36808 .55662 L p .938 .062 .811 r
F P
0 g
s
.56584 .35589 m .60168 .27752 L .70703 .32788 L p .88 .048 .738 r
F P
0 g
s
.49396 .81071 m .4816 .8355 L .44267 .83672 L p .752 .098 .989 r
F P
0 g
s
.4816 .8355 m .49396 .81071 L .52045 .79906 L p .733 .088 .941 r
F P
0 g
s
.51353 .66766 m .51348 .66776 L .51337 .65503 L p .68 .18 1 r
F P
0 g
s
.51337 .65503 m .51336 .65492 L .51353 .66766 L p .68 .18 1 r
F P
0 g
s
.51362 .66748 m .51353 .66766 L .51336 .65492 L p .68 .18 1 r
F P
0 g
s
.51336 .65492 m .51332 .65474 L .51362 .66748 L p .68 .18 1 r
F P
0 g
s
.60009 .77481 m .56624 .75825 L .57877 .73115 L p .773 .056 .78 r
F P
0 g
s
.57877 .73115 m .62092 .73874 L .60009 .77481 L p .773 .056 .78 r
F P
0 g
s
.51376 .66719 m .51362 .66748 L .51332 .65474 L p .679 .179 1 r
F P
0 g
s
.51332 .65474 m .51327 .65444 L .51376 .66719 L p .679 .179 1 r
F P
0 g
s
.51399 .66672 m .51376 .66719 L .51327 .65444 L p .678 .178 1 r
F P
0 g
s
.51327 .65444 m .51319 .65394 L .51399 .66672 L p .678 .178 1 r
F P
0 g
s
.51081 .63985 m .51183 .6459 L .50621 .6343 L p .591 .091 .957 r
F P
0 g
s
.50621 .6343 m .50152 .62894 L .51081 .63985 L p .591 .091 .957 r
F P
0 g
s
.51437 .66594 m .51399 .66672 L .51319 .65394 L p .675 .175 1 r
F P
0 g
s
.51319 .65394 m .51305 .65313 L .51437 .66594 L p .675 .175 1 r
F P
0 g
s
.48088 .60534 m .49376 .62007 L .4815 .61382 L p 1 .027 .636 r
F P
0 g
s
.4815 .61382 m .46065 .6033 L .48088 .60534 L p 1 .027 .636 r
F P
0 g
s
.76236 .33015 m .8024 .39342 L p .70703 .32788 L .859 .052 .761 r
F P
0 g
s
.51499 .66464 m .51437 .66594 L .51305 .65313 L p .668 .168 1 r
F P
0 g
s
.51305 .65313 m .51283 .65178 L .51499 .66464 L p .668 .168 1 r
F P
0 g
s
.2881 1.1586 m .31972 1.13702 L .42687 1.15257 L p .853 .071 .857 r
F P
0 g
s
.45981 1.09092 m .42687 1.15257 L .31972 1.13702 L p .836 .077 .886 r
F P
0 g
s
.42687 1.15257 m .45981 1.09092 L .53281 1.08068 L p .823 .074 .872 r
F P
0 g
s
.65804 1.11233 m .60283 1.0551 L .66012 1.01554 L p .822 .065 .826 r
F P
0 g
s
.66012 1.01554 m .75197 1.05757 L .65804 1.11233 L p .822 .065 .826 r
F P
0 g
s
.51602 .66251 m .51499 .66464 L .51283 .65178 L p 1 0 .5 r
F P
0 g
s
.51283 .65178 m .51245 .64957 L .51602 .66251 L p 1 0 .5 r
F P
0 g
s
.69001 .75117 m .62092 .73874 L .62561 .69935 L p .824 .051 .757 r
F P
0 g
s
.62561 .69935 m .69866 .69472 L .69001 .75117 L p .824 .051 .757 r
F P
0 g
s
.51773 .65899 m .51602 .66251 L .51245 .64957 L p 1 0 .5 r
F P
0 g
s
.51245 .64957 m .51183 .6459 L .51773 .65899 L p 1 0 .5 r
F P
0 g
s
.50912 .62982 m .51081 .63985 L .50152 .62894 L p 1 0 .5 r
F P
0 g
s
.50152 .62894 m .49376 .62007 L .50912 .62982 L p 1 0 .5 r
F P
0 g
s
.51369 .68049 m .51358 .68058 L .51348 .66776 L p 1 0 .5 r
F P
0 g
s
.51348 .66776 m .51353 .66766 L .51369 .68049 L p 1 0 .5 r
F P
0 g
s
.51388 .68035 m .51369 .68049 L .51353 .66766 L p 1 0 .5 r
F P
0 g
s
.51353 .66766 m .51362 .66748 L .51388 .68035 L p 1 0 .5 r
F P
0 g
s
.51419 .68012 m .51388 .68035 L .51362 .66748 L p 1 0 .5 r
F P
0 g
s
.51362 .66748 m .51376 .66719 L .51419 .68012 L p 1 0 .5 r
F P
0 g
s
.5147 .67973 m .51419 .68012 L .51376 .66719 L p 1 0 .5 r
F P
0 g
s
.51376 .66719 m .51399 .66672 L .5147 .67973 L p 1 0 .5 r
F P
0 g
s
.51554 .6791 m .5147 .67973 L .51399 .66672 L p 1 0 .5 r
F P
0 g
s
.51399 .66672 m .51437 .66594 L .51554 .6791 L p 1 0 .5 r
F P
0 g
s
.52055 .65316 m .51773 .65899 L .51183 .6459 L p 1 0 .5 r
F P
0 g
s
.51183 .6459 m .51081 .63985 L .52055 .65316 L p 1 0 .5 r
F P
0 g
s
.51692 .67805 m .51554 .6791 L .51437 .66594 L p 1 0 .5 r
F P
0 g
s
.51437 .66594 m .51499 .66464 L .51692 .67805 L p 1 0 .5 r
F P
0 g
s
.75197 1.05757 m .79131 1.07557 L .75031 1.09029 L p .841 .064 .822 r
F P
0 g
s
.27045 .50739 m .36808 .55662 L .33646 .58452 L p .903 .061 .806 r
F P
0 g
s
.33646 .58452 m .21987 .5629 L .27045 .50739 L p .903 .061 .806 r
F P
0 g
s
.51921 .67633 m .51692 .67805 L .51499 .66464 L p 1 0 .5 r
F P
0 g
s
.51499 .66464 m .51602 .66251 L .51921 .67633 L p 1 0 .5 r
F P
0 g
s
.4594 .58079 m .48088 .60534 L .46065 .6033 L p 1 .046 .73 r
F P
0 g
s
.46065 .6033 m .42599 .58582 L .4594 .58079 L p 1 .046 .73 r
F P
0 g
s
.52298 .67348 m .51921 .67633 L .51602 .66251 L p 1 0 .5 r
F P
0 g
s
.51602 .66251 m .51773 .65899 L .52298 .67348 L p 1 0 .5 r
F P
0 g
s
.53313 .76733 m .54578 .78136 L .52045 .79906 L p .669 .084 .92 r
F P
0 g
s
.54578 .78136 m .53313 .76733 L .54555 .74813 L p .698 .068 .838 r
F P
0 g
s
.54555 .74813 m .56624 .75825 L .54578 .78136 L p .698 .068 .838 r
F P
0 g
s
.51381 .69342 m .51365 .69347 L .51358 .68058 L p .96 0 .5 r
F P
0 g
s
.51358 .68058 m .51369 .68049 L .51381 .69342 L p .96 0 .5 r
F P
0 g
s
.51407 .69333 m .51381 .69342 L .51369 .68049 L p .96 0 .5 r
F P
0 g
s
.51369 .68049 m .51388 .68035 L .51407 .69333 L p .96 0 .5 r
F P
0 g
s
.5145 .69319 m .51407 .69333 L .51388 .68035 L p .959 0 .5 r
F P
0 g
s
.51388 .68035 m .51419 .68012 L .5145 .69319 L p .959 0 .5 r
F P
0 g
s
.50631 .61315 m .50912 .62982 L .49376 .62007 L p 1 .012 .559 r
F P
0 g
s
.49376 .62007 m .48088 .60534 L .50631 .61315 L p 1 .012 .559 r
F P
0 g
s
.51521 .69295 m .5145 .69319 L .51419 .68012 L p .958 0 .5 r
F P
0 g
s
.51419 .68012 m .5147 .67973 L .51521 .69295 L p .958 0 .5 r
F P
0 g
s
.52521 .64351 m .52055 .65316 L .51081 .63985 L p 1 0 .5 r
F P
0 g
s
.51081 .63985 m .50912 .62982 L .52521 .64351 L p 1 0 .5 r
F P
0 g
s
.51639 .69256 m .51521 .69295 L .5147 .67973 L p .956 0 .5 r
F P
0 g
s
.5147 .67973 m .51554 .6791 L .51639 .69256 L p .956 0 .5 r
F P
0 g
s
.51832 .69192 m .51639 .69256 L .51554 .6791 L p .952 0 .5 r
F P
0 g
s
.51554 .6791 m .51692 .67805 L .51832 .69192 L p .952 0 .5 r
F P
0 g
s
.52922 .66878 m .52298 .67348 L .51773 .65899 L p 1 0 .5 r
F P
0 g
s
.51773 .65899 m .52055 .65316 L .52922 .66878 L p 1 0 .5 r
F P
0 g
s
.5177 .78325 m .52045 .79906 L .49396 .81071 L p .653 .103 1 r
F P
0 g
s
.52045 .79906 m .5177 .78325 L .53313 .76733 L p .669 .084 .92 r
F P
0 g
s
.62092 .73874 m .57877 .73115 L .58141 .70214 L p .805 .047 .736 r
F P
0 g
s
.58141 .70214 m .62561 .69935 L .62092 .73874 L p .805 .047 .736 r
F P
0 g
s
.52152 .69087 m .51832 .69192 L .51692 .67805 L p .946 0 .5 r
F P
0 g
s
.51692 .67805 m .51921 .67633 L .52152 .69087 L p .946 0 .5 r
F P
0 g
s
.56624 .75825 m .54555 .74813 L .5531 .72654 L p .736 .054 .769 r
F P
0 g
s
.5531 .72654 m .57877 .73115 L .56624 .75825 L p .736 .054 .769 r
F P
0 g
s
.52679 .68913 m .52152 .69087 L .51921 .67633 L p .935 0 .5 r
F P
0 g
s
.51921 .67633 m .52298 .67348 L .52679 .68913 L p .935 0 .5 r
F P
0 g
s
.31972 1.13702 m .2881 1.1586 L .26443 1.14038 L p .867 .072 .859 r
F P
0 g
s
.35034 .85048 m .41388 .83014 L .44267 .83672 L p .832 .084 .922 r
F P
0 g
s
.47023 .81656 m .44267 .83672 L .41388 .83014 L p .796 .102 1 r
F P
0 g
s
.44267 .83672 m .47023 .81656 L .49396 .81071 L p .752 .098 .989 r
F P
0 g
s
.53549 .68625 m .52679 .68913 L .52298 .67348 L p .92 0 .5 r
F P
0 g
s
.52298 .67348 m .52922 .66878 L .53549 .68625 L p .92 0 .5 r
F P
0 g
s
.51386 .70641 m .51368 .70643 L .51365 .69347 L p .774 0 .5 r
F P
0 g
s
.51365 .69347 m .51381 .69342 L .51386 .70641 L p .774 0 .5 r
F P
0 g
s
.51416 .70639 m .51386 .70641 L .51381 .69342 L p .774 0 .5 r
F P
0 g
s
.51381 .69342 m .51407 .69333 L .51416 .70639 L p .774 0 .5 r
F P
0 g
s
.53954 .66099 m .52922 .66878 L .52055 .65316 L p 1 0 .5 r
F P
0 g
s
.52055 .65316 m .52521 .64351 L .53954 .66099 L p 1 0 .5 r
F P
0 g
s
.51465 .70636 m .51416 .70639 L .51407 .69333 L p .775 0 .5 r
F P
0 g
s
.51407 .69333 m .5145 .69319 L .51465 .70636 L p .775 0 .5 r
F P
0 g
s
.85295 1.05047 m .79131 1.07557 L p .81298 .9849 L .847 .061 .806 r
F P
0 g
s
.79131 1.07557 m .75197 1.05757 L .81298 .9849 L p .847 .061 .806 r
F P
0 g
s
.51545 .70631 m .51465 .70636 L .5145 .69319 L p .776 0 .5 r
F P
0 g
s
.5145 .69319 m .51521 .69295 L .51545 .70631 L p .776 0 .5 r
F P
0 g
s
.51678 .70623 m .51545 .70631 L .51521 .69295 L p .778 0 .5 r
F P
0 g
s
.51521 .69295 m .51639 .69256 L .51678 .70623 L p .778 0 .5 r
F P
0 g
s
.51898 .70609 m .51678 .70623 L .51639 .69256 L p .781 0 .5 r
F P
0 g
s
.51639 .69256 m .51832 .69192 L .51898 .70609 L p .781 0 .5 r
F P
0 g
s
.5226 .70586 m .51898 .70609 L .51832 .69192 L p .785 0 .5 r
F P
0 g
s
.51832 .69192 m .52152 .69087 L .5226 .70586 L p .785 0 .5 r
F P
0 g
s
.42381 1.38074 m .38007 1.45634 L .31619 1.40994 L p .864 .075 .873 r
F P
0 g
s
.42969 1.4385 m .38007 1.45634 L p .54582 1.37153 L .854 .073 .864 r
F P
0 g
s
.38007 1.45634 m .42381 1.38074 L .54582 1.37153 L p .854 .073 .864 r
F P
0 g
s
.57877 .73115 m .5531 .72654 L .55463 .70384 L p .781 .042 .708 r
F P
0 g
s
.55463 .70384 m .58141 .70214 L .57877 .73115 L p .781 .042 .708 r
F P
0 g
s
.52856 .70548 m .5226 .70586 L .52152 .69087 L p .793 .004 .518 r
F P
0 g
s
.52152 .69087 m .52679 .68913 L .52856 .70548 L p .793 .004 .518 r
F P
0 g
s
.53297 .62748 m .52521 .64351 L .50912 .62982 L p 1 .009 .546 r
F P
0 g
s
.50912 .62982 m .50631 .61315 L .53297 .62748 L p 1 .009 .546 r
F P
0 g
s
.50156 .79549 m .49396 .81071 L .47023 .81656 L p .66 .123 1 r
F P
0 g
s
.49396 .81071 m .50156 .79549 L .5177 .78325 L p .653 .103 1 r
F P
0 g
s
.20549 .83049 m .32622 .82309 L .35034 .85048 L p .872 .073 .864 r
F P
0 g
s
.41388 .83014 m .35034 .85048 L .32622 .82309 L p .873 .081 .907 r
F P
0 g
s
.5384 .70486 m .52856 .70548 L .52679 .68913 L p .807 .012 .558 r
F P
0 g
s
.52679 .68913 m .53549 .68625 L .5384 .70486 L p .807 .012 .558 r
F P
0 g
s
.54987 .6815 m .53549 .68625 L .52922 .66878 L p .906 .007 .534 r
F P
0 g
s
.52922 .66878 m .53954 .66099 L .54987 .6815 L p .906 .007 .534 r
F P
0 g
s
.53294 .74195 m .54555 .74813 L .53313 .76733 L p .64 .069 .846 r
F P
0 g
s
.54555 .74813 m .53294 .74195 L .5375 .72373 L p .694 .051 .755 r
F P
0 g
s
.5375 .72373 m .5531 .72654 L .54555 .74813 L p .694 .051 .755 r
F P
0 g
s
.5254 .75876 m .53313 .76733 L .5177 .78325 L p .592 .092 .961 r
F P
0 g
s
.53313 .76733 m .5254 .75876 L .53294 .74195 L p .64 .069 .846 r
F P
0 g
s
.42331 .53954 m .4594 .58079 L .42599 .58582 L p .956 .053 .765 r
F P
0 g
s
.42599 .58582 m .36808 .55662 L .42331 .53954 L p .956 .053 .765 r
F P
0 g
s
.51384 .71947 m .51367 .71944 L .51368 .70643 L p .651 .014 .569 r
F P
0 g
s
.51368 .70643 m .51386 .70641 L .51384 .71947 L p .651 .014 .569 r
F P
0 g
s
.55463 .70384 m .5384 .70486 L .53549 .68625 L p .821 .021 .606 r
F P
0 g
s
.53549 .68625 m .54987 .6815 L .55463 .70384 L p .821 .021 .606 r
F P
0 g
s
.51413 .71952 m .51384 .71947 L .51386 .70641 L p .652 .014 .571 r
F P
0 g
s
.51386 .70641 m .51416 .70639 L .51413 .71952 L p .652 .014 .571 r
F P
0 g
s
.5146 .71961 m .51413 .71952 L .51416 .70639 L p .654 .015 .573 r
F P
0 g
s
.51416 .70639 m .51465 .70636 L .5146 .71961 L p .654 .015 .573 r
F P
0 g
s
.5531 .72654 m .5375 .72373 L .5384 .70486 L p .753 .036 .678 r
F P
0 g
s
.5384 .70486 m .55463 .70384 L .5531 .72654 L p .753 .036 .678 r
F P
0 g
s
.51538 .71975 m .5146 .71961 L .51465 .70636 L p .657 .015 .576 r
F P
0 g
s
.51465 .70636 m .51545 .70631 L .51538 .71975 L p .657 .015 .576 r
F P
0 g
s
.51667 .71998 m .51538 .71975 L .51545 .70631 L p .663 .016 .582 r
F P
0 g
s
.51545 .70631 m .51678 .70623 L .51667 .71998 L p .663 .016 .582 r
F P
0 g
s
.51879 .72036 m .51667 .71998 L .51678 .70623 L p .672 .018 .591 r
F P
0 g
s
.51678 .70623 m .51898 .70609 L .51879 .72036 L p .672 .018 .591 r
F P
0 g
s
.50161 .58531 m .50631 .61315 L .48088 .60534 L p 1 .035 .673 r
F P
0 g
s
.48088 .60534 m .4594 .58079 L .50161 .58531 L p 1 .035 .673 r
F P
0 g
s
.52228 .72099 m .51879 .72036 L .51898 .70609 L p .684 .021 .604 r
F P
0 g
s
.51898 .70609 m .5226 .70586 L .52228 .72099 L p .684 .021 .604 r
F P
0 g
s
.52803 .72202 m .52228 .72099 L .5226 .70586 L p .702 .025 .623 r
F P
0 g
s
.5226 .70586 m .52856 .70548 L .52803 .72202 L p .702 .025 .623 r
F P
0 g
s
.5375 .72373 m .52803 .72202 L .52856 .70548 L p .726 .03 .648 r
F P
0 g
s
.52856 .70548 m .5384 .70486 L .5375 .72373 L p .726 .03 .648 r
F P
0 g
s
.16755 .50014 m .22694 .48545 L p .21987 .5629 L .884 .061 .803 r
F P
0 g
s
.22694 .48545 m .27045 .50739 L .21987 .5629 L p .884 .061 .803 r
F P
0 g
s
.21987 .5629 m .06016 .53329 L .16755 .50014 L p .884 .061 .803 r
F P
0 g
s
.55666 .64807 m .53954 .66099 L .52521 .64351 L p .975 .014 .568 r
F P
0 g
s
.52521 .64351 m .53297 .62748 L .55666 .64807 L p .975 .014 .568 r
F P
0 g
s
.58141 .70214 m .55463 .70384 L .54987 .6815 L p .834 .031 .654 r
F P
0 g
s
.52803 .72202 m .5375 .72373 L .53294 .74195 L p .654 .048 .741 r
F P
0 g
s
.51601 .77359 m .5177 .78325 L .50156 .79549 L p .623 .123 1 r
F P
0 g
s
.5177 .78325 m .51601 .77359 L .5254 .75876 L p .592 .092 .961 r
F P
0 g
s
.62561 .69935 m .58141 .70214 L .57367 .67364 L p .844 .04 .698 r
F P
0 g
s
.54987 .6815 m .57367 .67364 L .58141 .70214 L p .834 .031 .654 r
F P
0 g
s
.53294 .74195 m .52526 .7382 L .52803 .72202 L p .654 .048 .741 r
F P
0 g
s
.52228 .72099 m .52803 .72202 L .52526 .7382 L p .62 .046 .728 r
F P
0 g
s
.57367 .67364 m .54987 .6815 L .53954 .66099 L p .898 .021 .607 r
F P
0 g
s
.52526 .7382 m .53294 .74195 L .5254 .75876 L p .582 .07 .851 r
F P
0 g
s
.53954 .66099 m .55666 .64807 L .57367 .67364 L p .898 .021 .607 r
F P
0 g
s
.52526 .7382 m .5206 .73592 L .52228 .72099 L p .62 .046 .728 r
F P
0 g
s
.51879 .72036 m .52228 .72099 L .5206 .73592 L p .594 .044 .718 r
F P
0 g
s
.5206 .73592 m .51777 .73453 L .51879 .72036 L p .594 .044 .718 r
F P
0 g
s
.51667 .71998 m .51879 .72036 L .51777 .73453 L p .576 .042 .711 r
F P
0 g
s
.51777 .73453 m .51605 .73369 L .51667 .71998 L p .576 .042 .711 r
F P
0 g
s
.51538 .71975 m .51667 .71998 L .51605 .73369 L p .564 .041 .706 r
F P
0 g
s
.51605 .73369 m .51501 .73318 L .51538 .71975 L p .564 .041 .706 r
F P
0 g
s
.5146 .71961 m .51538 .71975 L .51501 .73318 L p .556 .041 .703 r
F P
0 g
s
.51501 .73318 m .51438 .73287 L .5146 .71961 L p .556 .041 .703 r
F P
0 g
s
.51413 .71952 m .5146 .71961 L .51438 .73287 L p .551 .04 .701 r
F P
0 g
s
.69866 .69472 m .62561 .69935 L .61314 .6606 L p .851 .046 .732 r
F P
0 g
s
.57367 .67364 m .61314 .6606 L .62561 .69935 L p .844 .04 .698 r
F P
0 g
s
.51438 .73287 m .51399 .73269 L .51413 .71952 L p .551 .04 .701 r
F P
0 g
s
.51384 .71947 m .51413 .71952 L .51399 .73269 L p .548 .04 .699 r
F P
0 g
s
.51399 .73269 m .51376 .73257 L .51384 .71947 L p .548 .04 .699 r
F P
0 g
s
.51367 .71944 m .51384 .71947 L .51376 .73257 L p .546 .04 .698 r
F P
0 g
s
.51376 .73257 m .51362 .7325 L .51367 .71944 L p .546 .04 .698 r
F P
0 g
s
.52069 .75354 m .5254 .75876 L .51601 .77359 L p .6 .1 .999 r
F P
0 g
s
.5254 .75876 m .52069 .75354 L .52526 .7382 L p .582 .07 .851 r
F P
0 g
s
.5206 .73592 m .52526 .7382 L .52069 .75354 L p .571 .071 .853 r
F P
0 g
s
.81298 .9849 m .96821 1.01104 L .85295 1.05047 L p .847 .061 .806 r
F P
0 g
s
.54582 1.37153 m .55102 1.39738 L .42969 1.4385 L p .854 .073 .864 r
F P
0 g
s
.52069 .75354 m .51783 .75036 L .5206 .73592 L p .571 .071 .853 r
F P
0 g
s
.51777 .73453 m .5206 .73592 L .51783 .75036 L p .571 .071 .854 r
F P
0 g
s
.41388 .83014 m .4528 .81768 L .47023 .81656 L p .796 .102 1 r
F P
0 g
s
.48712 .80421 m .47023 .81656 L .4528 .81768 L p .708 .134 1 r
F P
0 g
s
.47023 .81656 m .48712 .80421 L .50156 .79549 L p .66 .123 1 r
F P
0 g
s
.38105 .24651 m .47546 .2209 L p .36715 .2701 L .88 .054 .77 r
F P
0 g
s
.47546 .2209 m .48134 .25771 L .36715 .2701 L p .88 .054 .77 r
F P
0 g
s
.36715 .2701 m .35442 .25472 L .38105 .24651 L p .88 .054 .77 r
F P
0 g
s
.81953 .68708 m .69866 .69472 L .6789 .63887 L p .855 .051 .756 r
F P
0 g
s
.61314 .6606 m .6789 .63887 L .69866 .69472 L p .851 .046 .732 r
F P
0 g
s
.5062 .78619 m .50156 .79549 L .48712 .80421 L p .66 .16 1 r
F P
0 g
s
.50156 .79549 m .5062 .78619 L .51601 .77359 L p .623 .123 1 r
F P
0 g
s
.54591 .60073 m .53297 .62748 L .50631 .61315 L p .986 .03 .649 r
F P
0 g
s
.50631 .61315 m .50161 .58531 L .54591 .60073 L p .986 .03 .649 r
F P
0 g
s
.51783 .75036 m .51609 .74844 L .51777 .73453 L p .571 .071 .854 r
F P
0 g
s
.51605 .73369 m .51777 .73453 L .51609 .74844 L p .571 .071 .853 r
F P
0 g
s
.61314 .6606 m .57367 .67364 L .55666 .64807 L p .889 .034 .668 r
F P
0 g
s
.75197 1.05757 m .66012 1.01554 L .69626 .96524 L p .832 .06 .802 r
F P
0 g
s
.69626 .96524 m .81298 .9849 L .75197 1.05757 L p .832 .06 .802 r
F P
0 g
s
.51609 .74844 m .51503 .74727 L .51605 .73369 L p .571 .071 .853 r
F P
0 g
s
.51501 .73318 m .51605 .73369 L .51503 .74727 L p .571 .071 .853 r
F P
0 g
s
.51601 .77359 m .51499 .7677 L .52069 .75354 L p .6 .1 .999 r
F P
0 g
s
.51783 .75036 m .52069 .75354 L .51499 .7677 L p .606 .106 1 r
F P
0 g
s
.51503 .74727 m .51439 .74655 L .51501 .73318 L p .571 .071 .853 r
F P
0 g
s
.51438 .73287 m .51501 .73318 L .51439 .74655 L p .571 .071 .853 r
F P
0 g
s
.51499 .7677 m .51601 .77359 L .5062 .78619 L p .645 .145 1 r
F P
0 g
s
.51439 .74655 m .514 .74612 L .51438 .73287 L p .571 .071 .853 r
F P
0 g
s
.51399 .73269 m .51438 .73287 L .514 .74612 L p .57 .07 .852 r
F P
0 g
s
.70703 .32788 m .74201 .29995 L .76236 .33015 L p .859 .052 .761 r
F P
0 g
s
.74201 .29995 m .70703 .32788 L .60168 .27752 L p .869 .052 .759 r
F P
0 g
s
.514 .74612 m .51377 .74586 L .51399 .73269 L p .57 .07 .852 r
F P
0 g
s
.51376 .73257 m .51399 .73269 L .51377 .74586 L p .57 .07 .852 r
F P
0 g
s
.51377 .74586 m .51362 .7457 L .51376 .73257 L p .57 .07 .852 r
F P
0 g
s
.51362 .7325 m .51376 .73257 L .51362 .7457 L p .57 .07 .852 r
F P
0 g
s
.51362 .7457 m .51354 .74561 L .51362 .7325 L p .57 .07 .852 r
F P
0 g
s
.26443 1.14038 m .21582 1.10795 L p .31972 1.13702 L .867 .072 .859 r
F P
0 g
s
.21582 1.10795 m .23794 1.10135 L .31972 1.13702 L p .867 .072 .859 r
F P
0 g
s
.3939 1.08639 m .31972 1.13702 L .23794 1.10135 L p .858 .078 .889 r
F P
0 g
s
.31972 1.13702 m .3939 1.08639 L .45981 1.09092 L p .836 .077 .886 r
F P
0 g
s
.51499 .7677 m .51437 .76411 L .51783 .75036 L p .606 .106 1 r
F P
0 g
s
.51609 .74844 m .51783 .75036 L .51437 .76411 L p .611 .111 1 r
F P
0 g
s
.55666 .64807 m .58516 .62656 L .61314 .6606 L p .889 .034 .668 r
F P
0 g
s
.58516 .62656 m .55666 .64807 L .53297 .62748 L p .938 .03 .65 r
F P
0 g
s
.53297 .62748 m .54591 .60073 L .58516 .62656 L p .938 .03 .65 r
F P
0 g
s
.32622 .82309 m .39971 .81859 L .41388 .83014 L p .873 .081 .907 r
F P
0 g
s
.4528 .81768 m .41388 .83014 L .39971 .81859 L p .866 .098 .988 r
F P
0 g
s
.51437 .76411 m .51399 .76194 L .51609 .74844 L p .611 .111 1 r
F P
0 g
s
.51503 .74727 m .51609 .74844 L .51399 .76194 L p .613 .113 1 r
F P
0 g
s
.87251 .68373 m .81953 .68708 L .78915 .60245 L p .858 .055 .773 r
F P
0 g
s
.6789 .63887 m .78915 .60245 L .81953 .68708 L p .855 .051 .756 r
F P
0 g
s
.5062 .78619 m .50903 .78053 L .51499 .7677 L p .645 .145 1 r
F P
0 g
s
.51437 .76411 m .51499 .7677 L .50903 .78053 L p .664 .164 1 r
F P
0 g
s
.51399 .76194 m .51376 .76062 L .51503 .74727 L p .613 .113 1 r
F P
0 g
s
.51439 .74655 m .51503 .74727 L .51376 .76062 L p .615 .115 1 r
F P
0 g
s
.51376 .76062 m .51362 .75981 L .51439 .74655 L p .615 .115 1 r
F P
0 g
s
.514 .74612 m .51439 .74655 L .51362 .75981 L p .616 .116 1 r
F P
0 g
s
.51362 .75981 m .51353 .75933 L .514 .74612 L p .616 .116 1 r
F P
0 g
s
.51377 .74586 m .514 .74612 L .51353 .75933 L p .617 .117 1 r
F P
0 g
s
.51353 .75933 m .51348 .75903 L .51377 .74586 L p .617 .117 1 r
F P
0 g
s
.51362 .7457 m .51377 .74586 L .51348 .75903 L p .617 .117 1 r
F P
0 g
s
.51348 .75903 m .51345 .75885 L .51362 .7457 L p .617 .117 1 r
F P
0 g
s
.51354 .74561 m .51362 .7457 L .51345 .75885 L p .617 .117 1 r
F P
0 g
s
.51345 .75885 m .51343 .75874 L .51354 .74561 L p .617 .117 1 r
F P
0 g
s
.48712 .80421 m .49742 .79667 L .5062 .78619 L p .66 .16 1 r
F P
0 g
s
.50903 .78053 m .5062 .78619 L .49742 .79667 L p .693 .193 1 r
F P
0 g
s
.82609 .61396 m .87251 .68373 L p .78915 .60245 L .858 .055 .773 r
F P
0 g
s
.50903 .78053 m .51074 .77708 L .51437 .76411 L p .664 .164 1 r
F P
0 g
s
.51399 .76194 m .51437 .76411 L .51074 .77708 L p .675 .175 1 r
F P
0 g
s
.4528 .81768 m .47656 .81007 L .48712 .80421 L p .708 .134 1 r
F P
0 g
s
.49742 .79667 m .48712 .80421 L .47656 .81007 L p .666 .166 1 r
F P
0 g
s
.4937 .53843 m .50161 .58531 L .4594 .58079 L p .954 .046 .73 r
F P
0 g
s
.4594 .58079 m .42331 .53954 L .4937 .53843 L p .954 .046 .73 r
F P
0 g
s
.6789 .63887 m .61314 .6606 L .58516 .62656 L p .881 .043 .714 r
F P
0 g
s
.51074 .77708 m .51179 .77499 L .51399 .76194 L p .675 .175 1 r
F P
0 g
s
.51376 .76062 m .51399 .76194 L .51179 .77499 L p .68 .18 1 r
F P
0 g
s
.51179 .77499 m .51242 .77371 L .51376 .76062 L p .68 .18 1 r
F P
0 g
s
.51362 .75981 m .51376 .76062 L .51242 .77371 L p .682 .182 1 r
F P
0 g
s
.49742 .79667 m .5037 .79208 L .50903 .78053 L p .693 .193 1 r
F P
0 g
s
.51074 .77708 m .50903 .78053 L .5037 .79208 L p 1 0 .5 r
F P
0 g
s
.36192 .46937 m .42331 .53954 L .36808 .55662 L p .914 .056 .781 r
F P
0 g
s
.36808 .55662 m .27045 .50739 L .36192 .46937 L p .914 .056 .781 r
F P
0 g
s
.51242 .77371 m .51281 .77294 L .51362 .75981 L p .682 .182 1 r
F P
0 g
s
.51353 .75933 m .51362 .75981 L .51281 .77294 L p .682 .182 1 r
F P
0 g
s
.51281 .77294 m .51304 .77247 L .51353 .75933 L p .682 .182 1 r
F P
0 g
s
.51348 .75903 m .51353 .75933 L .51304 .77247 L p .682 .182 1 r
F P
0 g
s
.51304 .77247 m .51318 .77219 L .51348 .75903 L p .682 .182 1 r
F P
0 g
s
.51345 .75885 m .51348 .75903 L .51318 .77219 L p .682 .182 1 r
F P
0 g
s
.51318 .77219 m .51327 .77202 L .51345 .75885 L p .682 .182 1 r
F P
0 g
s
.51343 .75874 m .51345 .75885 L .51327 .77202 L p .681 .181 1 r
F P
0 g
s
.51327 .77202 m .51332 .77191 L .51343 .75874 L p .681 .181 1 r
F P
0 g
s
.5037 .79208 m .50751 .78929 L .51074 .77708 L p 1 0 .5 r
F P
0 g
s
.51179 .77499 m .51074 .77708 L .50751 .78929 L p 1 0 .5 r
F P
0 g
s
.39971 .81859 m .44439 .81585 L .4528 .81768 L p .866 .098 .988 r
F P
0 g
s
.47656 .81007 m .4528 .81768 L .44439 .81585 L p .806 .122 1 r
F P
0 g
s
.47656 .81007 m .49103 .80544 L .49742 .79667 L p .666 .166 1 r
F P
0 g
s
.5037 .79208 m .49742 .79667 L .49103 .80544 L p .891 0 .5 r
F P
0 g
s
.52533 1.04053 m .53281 1.08068 L .45981 1.09092 L p .788 .081 .907 r
F P
0 g
s
.53281 1.08068 m .52533 1.04053 L .56828 1.0193 L p .784 .074 .871 r
F P
0 g
s
.56828 1.0193 m .60283 1.0551 L .53281 1.08068 L p .784 .074 .871 r
F P
0 g
s
.50751 .78929 m .50983 .7876 L .51179 .77499 L p 1 0 .5 r
F P
0 g
s
.51242 .77371 m .51179 .77499 L .50983 .7876 L p 1 0 .5 r
F P
0 g
s
.50983 .7876 m .51123 .78657 L .51242 .77371 L p 1 0 .5 r
F P
0 g
s
.51281 .77294 m .51242 .77371 L .51123 .78657 L p 1 0 .5 r
F P
0 g
s
.51123 .78657 m .51209 .78595 L .51281 .77294 L p 1 0 .5 r
F P
0 g
s
.51304 .77247 m .51281 .77294 L .51209 .78595 L p 1 0 .5 r
F P
0 g
s
.20549 .83049 m .15292 .83371 L .07666 .7697 L p .886 .066 .828 r
F P
0 g
s
.51209 .78595 m .5126 .78557 L .51304 .77247 L p 1 0 .5 r
F P
0 g
s
.51318 .77219 m .51304 .77247 L .5126 .78557 L p 1 0 .5 r
F P
0 g
s
.5126 .78557 m .51292 .78534 L .51318 .77219 L p 1 0 .5 r
F P
0 g
s
.51327 .77202 m .51318 .77219 L .51292 .78534 L p 1 0 .5 r
F P
0 g
s
.51292 .78534 m .51311 .7852 L .51327 .77202 L p 1 0 .5 r
F P
0 g
s
.51332 .77191 m .51327 .77202 L .51311 .7852 L p 1 0 .5 r
F P
0 g
s
.51311 .7852 m .51322 .78512 L .51332 .77191 L p 1 0 .5 r
F P
0 g
s
.49103 .80544 m .49982 .80262 L .5037 .79208 L p .891 0 .5 r
F P
0 g
s
.50751 .78929 m .5037 .79208 L .49982 .80262 L p .955 0 .5 r
F P
0 g
s
.60283 1.0551 m .56828 1.0193 L .60315 .98947 L p .792 .067 .833 r
F P
0 g
s
.60315 .98947 m .66012 1.01554 L .60283 1.0551 L p .792 .067 .833 r
F P
0 g
s
.58516 .62656 m .63295 .5905 L .6789 .63887 L p .881 .043 .714 r
F P
0 g
s
.63295 .5905 m .58516 .62656 L .54591 .60073 L p .911 .041 .705 r
F P
0 g
s
.07666 .7697 m .04386 .7432 L p .20549 .83049 L .886 .066 .828 r
F P
0 g
s
.04386 .7432 m .2094 .77205 L .20549 .83049 L p .886 .066 .828 r
F P
0 g
s
.32622 .82309 m .20549 .83049 L .2094 .77205 L p .898 .069 .843 r
F P
0 g
s
.44439 .81585 m .47152 .81419 L .47656 .81007 L p .806 .122 1 r
F P
0 g
s
.49103 .80544 m .47656 .81007 L .47152 .81419 L p .528 0 .5 r
F P
0 g
s
.71098 .25145 m .74201 .29995 L p .60168 .27752 L .869 .052 .759 r
F P
0 g
s
.56769 .5557 m .54591 .60073 L .50161 .58531 L p .937 .042 .71 r
F P
0 g
s
.50161 .58531 m .4937 .53843 L .56769 .5557 L p .937 .042 .71 r
F P
0 g
s
.49982 .80262 m .50516 .80092 L .50751 .78929 L p .955 0 .5 r
F P
0 g
s
.50983 .7876 m .50751 .78929 L .50516 .80092 L p .965 0 .5 r
F P
0 g
s
.59988 .18193 m .65252 .16632 L p .48134 .25771 L .877 .052 .762 r
F P
0 g
s
.65252 .16632 m .60168 .27752 L .48134 .25771 L p .877 .052 .762 r
F P
0 g
s
.48134 .25771 m .47546 .2209 L .59988 .18193 L p .877 .052 .762 r
F P
0 g
s
.60168 .27752 m .65252 .16632 L .71098 .25145 L p .869 .052 .759 r
F P
0 g
s
.50516 .80092 m .5084 .79988 L .50983 .7876 L p .965 0 .5 r
F P
0 g
s
.51123 .78657 m .50983 .7876 L .5084 .79988 L p .966 0 .5 r
F P
0 g
s
.5084 .79988 m .51037 .79925 L .51123 .78657 L p .966 0 .5 r
F P
0 g
s
.51209 .78595 m .51123 .78657 L .51037 .79925 L p .964 0 .5 r
F P
0 g
s
.94438 .97803 m .96821 1.01104 L p .83051 .90177 L .857 .058 .791 r
F P
0 g
s
.96821 1.01104 m .81298 .9849 L .83051 .90177 L p .857 .058 .791 r
F P
0 g
s
.51037 .79925 m .51156 .79887 L .51209 .78595 L p .964 0 .5 r
F P
0 g
s
.5126 .78557 m .51209 .78595 L .51156 .79887 L p .963 0 .5 r
F P
0 g
s
.51156 .79887 m .51229 .79863 L .5126 .78557 L p .963 0 .5 r
F P
0 g
s
.51292 .78534 m .5126 .78557 L .51229 .79863 L p .962 0 .5 r
F P
0 g
s
.51229 .79863 m .51273 .79849 L .51292 .78534 L p .962 0 .5 r
F P
0 g
s
.51311 .7852 m .51292 .78534 L .51273 .79849 L p .962 0 .5 r
F P
0 g
s
.51273 .79849 m .51299 .79841 L .51311 .7852 L p .962 0 .5 r
F P
0 g
s
.51322 .78512 m .51311 .7852 L .51299 .79841 L p .962 0 .5 r
F P
0 g
s
.51299 .79841 m .51315 .79836 L .51322 .78512 L p .962 0 .5 r
F P
0 g
s
.47152 .81419 m .48799 .81318 L .49103 .80544 L p .528 0 .5 r
F P
0 g
s
.49982 .80262 m .49103 .80544 L .48799 .81318 L p .678 0 .5 r
F P
0 g
s
.54591 .60073 m .56769 .5557 L .63295 .5905 L p .911 .041 .705 r
F P
0 g
s
.64711 1.35993 m .55102 1.39738 L p .66316 1.3391 L .85 .07 .85 r
F P
0 g
s
.55102 1.39738 m .54582 1.37153 L .66316 1.3391 L p .85 .07 .85 r
F P
0 g
s
.48047 1.05225 m .45981 1.09092 L .3939 1.08639 L p .806 .087 .934 r
F P
0 g
s
.45981 1.09092 m .48047 1.05225 L .52533 1.04053 L p .788 .081 .907 r
F P
0 g
s
.2094 .77205 m .33019 .7931 L .32622 .82309 L p .898 .069 .843 r
F P
0 g
s
.39971 .81859 m .32622 .82309 L .33019 .7931 L p .919 .074 .871 r
F P
0 g
s
.48799 .81318 m .49799 .81257 L .49982 .80262 L p .678 0 .5 r
F P
0 g
s
.50516 .80092 m .49982 .80262 L .49799 .81257 L p .732 0 .5 r
F P
0 g
s
.78915 .60245 m .6789 .63887 L .63295 .5905 L p .874 .049 .745 r
F P
0 g
s
.49799 .81257 m .50405 .8122 L .50516 .80092 L p .732 0 .5 r
F P
0 g
s
.5084 .79988 m .50516 .80092 L .50405 .8122 L p .752 0 .5 r
F P
0 g
s
.50405 .8122 m .50773 .81197 L .5084 .79988 L p .752 0 .5 r
F P
0 g
s
.51037 .79925 m .5084 .79988 L .50773 .81197 L p .762 0 .5 r
F P
0 g
s
.50773 .81197 m .50996 .81184 L .51037 .79925 L p .762 0 .5 r
F P
0 g
s
.51156 .79887 m .51037 .79925 L .50996 .81184 L p .767 0 .5 r
F P
0 g
s
.50996 .81184 m .51132 .81175 L .51156 .79887 L p .767 0 .5 r
F P
0 g
s
.51229 .79863 m .51156 .79887 L .51132 .81175 L p .769 0 .5 r
F P
0 g
s
.51132 .81175 m .51214 .8117 L .51229 .79863 L p .769 0 .5 r
F P
0 g
s
.51273 .79849 m .51229 .79863 L .51214 .8117 L p .771 0 .5 r
F P
0 g
s
.51214 .8117 m .51263 .81167 L .51273 .79849 L p .771 0 .5 r
F P
0 g
s
.51299 .79841 m .51273 .79849 L .51263 .81167 L p .772 0 .5 r
F P
0 g
s
.51263 .81167 m .51294 .81165 L .51299 .79841 L p .772 0 .5 r
F P
0 g
s
.51315 .79836 m .51299 .79841 L .51294 .81165 L p .772 0 .5 r
F P
0 g
s
.51294 .81165 m .51312 .81164 L .51315 .79836 L p .772 0 .5 r
F P
0 g
s
.33019 .7931 m .40271 .80574 L .39971 .81859 L p .919 .074 .871 r
F P
0 g
s
.44439 .81585 m .39971 .81859 L .40271 .80574 L p .949 .083 .917 r
F P
0 g
s
.40271 .80574 m .44642 .81336 L .44439 .81585 L p .949 .083 .917 r
F P
0 g
s
.47152 .81419 m .44439 .81585 L .44642 .81336 L p .939 .089 .947 r
F P
0 g
s
.44642 .81336 m .47283 .81796 L .47152 .81419 L p .939 .089 .947 r
F P
0 g
s
.48799 .81318 m .47152 .81419 L .47283 .81796 L p .5 0 .5 r
F P
0 g
s
.47283 .81796 m .48882 .82075 L .48799 .81318 L p .5 0 .5 r
F P
0 g
s
.49799 .81257 m .48799 .81318 L .48882 .82075 L p .5 0 .5 r
F P
0 g
s
.48882 .82075 m .4985 .82243 L .49799 .81257 L p .5 0 .5 r
F P
0 g
s
.50405 .8122 m .49799 .81257 L .4985 .82243 L p .564 0 .5 r
F P
0 g
s
.4985 .82243 m .50437 .82346 L .50405 .8122 L p .564 0 .5 r
F P
0 g
s
.50773 .81197 m .50405 .8122 L .50437 .82346 L p .6 .004 .518 r
F P
0 g
s
.50437 .82346 m .50792 .82408 L .50773 .81197 L p .6 .004 .518 r
F P
0 g
s
.50996 .81184 m .50773 .81197 L .50792 .82408 L p .621 .008 .539 r
F P
0 g
s
.50792 .82408 m .51008 .82445 L .50996 .81184 L p .621 .008 .539 r
F P
0 g
s
.51132 .81175 m .50996 .81184 L .51008 .82445 L p .632 .01 .551 r
F P
0 g
s
.51008 .82445 m .51139 .82468 L .51132 .81175 L p .632 .01 .551 r
F P
0 g
s
.51214 .8117 m .51132 .81175 L .51139 .82468 L p .639 .011 .557 r
F P
0 g
s
.51139 .82468 m .51218 .82482 L .51214 .8117 L p .639 .011 .557 r
F P
0 g
s
.51263 .81167 m .51214 .8117 L .51218 .82482 L p .643 .012 .561 r
F P
0 g
s
.51218 .82482 m .51266 .8249 L .51263 .81167 L p .643 .012 .561 r
F P
0 g
s
.51294 .81165 m .51263 .81167 L .51266 .8249 L p .645 .013 .564 r
F P
0 g
s
.51266 .8249 m .51295 .82495 L .51294 .81165 L p .645 .013 .564 r
F P
0 g
s
.51312 .81164 m .51294 .81165 L .51295 .82495 L p .646 .013 .565 r
F P
0 g
s
.51295 .82495 m .51313 .82498 L .51312 .81164 L p .646 .013 .565 r
F P
0 g
s
.66012 1.01554 m .60315 .98947 L .62474 .9532 L p .808 .059 .796 r
F P
0 g
s
.62474 .9532 m .69626 .96524 L .66012 1.01554 L p .808 .059 .796 r
F P
0 g
s
.48018 .45831 m .4937 .53843 L .42331 .53954 L p .915 .052 .759 r
F P
0 g
s
.42331 .53954 m .36192 .46937 L .48018 .45831 L p .915 .052 .759 r
F P
0 g
s
.51304 .83833 m .51318 .83839 L .51313 .82498 L p .541 .039 .696 r
F P
0 g
s
.51313 .82498 m .51295 .82495 L .51304 .83833 L p .541 .039 .696 r
F P
0 g
s
.5128 .83821 m .51304 .83833 L .51295 .82495 L p .539 .039 .695 r
F P
0 g
s
.51295 .82495 m .51266 .8249 L .5128 .83821 L p .539 .039 .695 r
F P
0 g
s
.51241 .83803 m .5128 .83821 L .51266 .8249 L p .539 .039 .694 r
F P
0 g
s
.51266 .8249 m .51218 .82482 L .51241 .83803 L p .539 .039 .694 r
F P
0 g
s
.51177 .83772 m .51241 .83803 L .51218 .82482 L p .538 .038 .691 r
F P
0 g
s
.51218 .82482 m .51139 .82468 L .51177 .83772 L p .538 .038 .691 r
F P
0 g
s
.31619 1.40994 m .28009 1.38812 L p .42381 1.38074 L .864 .075 .873 r
F P
0 g
s
.5107 .83722 m .51177 .83772 L .51139 .82468 L p .537 .037 .687 r
F P
0 g
s
.51139 .82468 m .51008 .82445 L .5107 .83722 L p .537 .037 .687 r
F P
0 g
s
.50895 .83639 m .5107 .83722 L .51008 .82445 L p .536 .036 .68 r
F P
0 g
s
.51008 .82445 m .50792 .82408 L .50895 .83639 L p .536 .036 .68 r
F P
0 g
s
.50606 .83502 m .50895 .83639 L .50792 .82408 L p .533 .033 .667 r
F P
0 g
s
.50792 .82408 m .50437 .82346 L .50606 .83502 L p .533 .033 .667 r
F P
0 g
s
.50129 .83276 m .50606 .83502 L .50437 .82346 L p .528 .028 .64 r
F P
0 g
s
.50437 .82346 m .4985 .82243 L .50129 .83276 L p .528 .028 .64 r
F P
0 g
s
.49341 .82903 m .50129 .83276 L .4985 .82243 L p .516 .016 .579 r
F P
0 g
s
.4985 .82243 m .48882 .82075 L .49341 .82903 L p .516 .016 .579 r
F P
0 g
s
.66316 1.3391 m .67487 1.35033 L .64711 1.35993 L p .85 .07 .85 r
F P
0 g
s
.48038 .82285 m .49341 .82903 L .48882 .82075 L p .5 0 .5 r
F P
0 g
s
.48882 .82075 m .47283 .81796 L .48038 .82285 L p .5 0 .5 r
F P
0 g
s
.83051 .90177 m .88539 .89852 L .94438 .97803 L p .857 .058 .791 r
F P
0 g
s
.81298 .9849 m .69626 .96524 L .70529 .90919 L p .847 .056 .78 r
F P
0 g
s
.70529 .90919 m .83051 .90177 L .81298 .9849 L p .847 .056 .78 r
F P
0 g
s
.23794 1.10135 m .21582 1.10795 L .19932 1.09544 L p .883 .071 .853 r
F P
0 g
s
.23794 1.10135 m .34454 1.06952 L .3939 1.08639 L p .858 .078 .889 r
F P
0 g
s
.44016 1.05482 m .3939 1.08639 L .34454 1.06952 L p .839 .089 .943 r
F P
0 g
s
.3939 1.08639 m .44016 1.05482 L .48047 1.05225 L p .806 .087 .934 r
F P
0 g
s
.47283 .81796 m .44642 .81336 L .45878 .81262 L p 1 .053 .765 r
F P
0 g
s
.45878 .81262 m .48038 .82285 L .47283 .81796 L p 1 .053 .765 r
F P
0 g
s
.51318 .85178 m .51327 .85188 L .51318 .83839 L p .57 .07 .852 r
F P
0 g
s
.51318 .83839 m .51304 .83833 L .51318 .85178 L p .57 .07 .852 r
F P
0 g
s
.51303 .85163 m .51318 .85178 L .51304 .83833 L p .57 .07 .851 r
F P
0 g
s
.51304 .83833 m .5128 .83821 L .51303 .85163 L p .57 .07 .851 r
F P
0 g
s
.51279 .85137 m .51303 .85163 L .5128 .83821 L p .57 .07 .851 r
F P
0 g
s
.5128 .83821 m .51241 .83803 L .51279 .85137 L p .57 .07 .851 r
F P
0 g
s
.5124 .85094 m .51279 .85137 L .51241 .83803 L p .57 .07 .85 r
F P
0 g
s
.51241 .83803 m .51177 .83772 L .5124 .85094 L p .57 .07 .85 r
F P
0 g
s
.63295 .5905 m .71396 .52938 L .78915 .60245 L p .874 .049 .745 r
F P
0 g
s
.71396 .52938 m .63295 .5905 L .56769 .5557 L p .892 .048 .741 r
F P
0 g
s
.51174 .85024 m .5124 .85094 L .51177 .83772 L p .57 .07 .849 r
F P
0 g
s
.51177 .83772 m .5107 .83722 L .51174 .85024 L p .57 .07 .849 r
F P
0 g
s
.78915 .60245 m .81261 .59469 L .82609 .61396 L p .858 .055 .773 r
F P
0 g
s
.51067 .84909 m .51174 .85024 L .5107 .83722 L p .569 .069 .847 r
F P
0 g
s
.5107 .83722 m .50895 .83639 L .51067 .84909 L p .569 .069 .847 r
F P
0 g
s
.26724 .47368 m .34871 .45427 L p .27045 .50739 L .891 .058 .789 r
F P
0 g
s
.34871 .45427 m .36192 .46937 L .27045 .50739 L p .891 .058 .789 r
F P
0 g
s
.27045 .50739 m .22694 .48545 L .26724 .47368 L p .891 .058 .789 r
F P
0 g
s
.50889 .84718 m .51067 .84909 L .50895 .83639 L p .568 .068 .841 r
F P
0 g
s
.50895 .83639 m .50606 .83502 L .50889 .84718 L p .568 .068 .841 r
F P
0 g
s
.53351 1.31044 m .54582 1.37153 L .42381 1.38074 L p .831 .078 .889 r
F P
0 g
s
.54582 1.37153 m .53351 1.31044 L .60605 1.28435 L p .826 .073 .865 r
F P
0 g
s
.60605 1.28435 m .66316 1.3391 L .54582 1.37153 L p .826 .073 .865 r
F P
0 g
s
.50595 .84403 m .50889 .84718 L .50606 .83502 L p .565 .065 .826 r
F P
0 g
s
.50606 .83502 m .50129 .83276 L .50595 .84403 L p .565 .065 .826 r
F P
0 g
s
.75871 1.31679 m .67487 1.35033 L p .76051 1.28512 L .851 .067 .833 r
F P
0 g
s
.67487 1.35033 m .66316 1.3391 L .76051 1.28512 L p .851 .067 .833 r
F P
0 g
s
.5207 1.01565 m .52533 1.04053 L .48047 1.05225 L p .732 .092 .962 r
F P
0 g
s
.52533 1.04053 m .5207 1.01565 L .54693 .99716 L p .734 .08 .9 r
F P
0 g
s
.54693 .99716 m .56828 1.0193 L .52533 1.04053 L p .734 .08 .9 r
F P
0 g
s
.42288 .79561 m .45878 .81262 L .44642 .81336 L p 1 .064 .819 r
F P
0 g
s
.44642 .81336 m .40271 .80574 L .42288 .79561 L p 1 .064 .819 r
F P
0 g
s
.56828 1.0193 m .54693 .99716 L .56812 .97344 L p .75 .068 .84 r
F P
0 g
s
.56812 .97344 m .60315 .98947 L .56828 1.0193 L p .75 .068 .84 r
F P
0 g
s
.19932 1.09544 m .13993 1.05477 L p .23794 1.10135 L .883 .071 .853 r
F P
0 g
s
.13993 1.05477 m .19438 1.05166 L .23794 1.10135 L p .883 .071 .853 r
F P
0 g
s
.34454 1.06952 m .23794 1.10135 L .19438 1.05166 L p .885 .076 .879 r
F P
0 g
s
.5011 .83882 m .50595 .84403 L .50129 .83276 L p .555 .055 .776 r
F P
0 g
s
.50129 .83276 m .49341 .82903 L .5011 .83882 L p .555 .055 .776 r
F P
0 g
s
.51335 .86534 m .51337 .86544 L .51327 .85188 L p .618 .118 1 r
F P
0 g
s
.51327 .85188 m .51318 .85178 L .51335 .86534 L p .618 .118 1 r
F P
0 g
s
.51332 .86516 m .51335 .86534 L .51318 .85178 L p .618 .118 1 r
F P
0 g
s
.51318 .85178 m .51303 .85163 L .51332 .86516 L p .618 .118 1 r
F P
0 g
s
.51327 .86487 m .51332 .86516 L .51303 .85163 L p .618 .118 1 r
F P
0 g
s
.51303 .85163 m .51279 .85137 L .51327 .86487 L p .618 .118 1 r
F P
0 g
s
.51318 .86439 m .51327 .86487 L .51279 .85137 L p .619 .119 1 r
F P
0 g
s
.51279 .85137 m .5124 .85094 L .51318 .86439 L p .619 .119 1 r
F P
0 g
s
.51304 .8636 m .51318 .86439 L .5124 .85094 L p .619 .119 1 r
F P
0 g
s
.5124 .85094 m .51174 .85024 L .51304 .8636 L p .619 .119 1 r
F P
0 g
s
.81261 .59469 m .78915 .60245 L .71396 .52938 L p .869 .053 .766 r
F P
0 g
s
.51281 .86229 m .51304 .8636 L .51174 .85024 L p .62 .12 1 r
F P
0 g
s
.51174 .85024 m .51067 .84909 L .51281 .86229 L p .62 .12 1 r
F P
0 g
s
.49306 .83019 m .5011 .83882 L .49341 .82903 L p .522 .022 .612 r
F P
0 g
s
.49341 .82903 m .48038 .82285 L .49306 .83019 L p .522 .022 .612 r
F P
0 g
s
.51242 .86014 m .51281 .86229 L .51067 .84909 L p .62 .12 1 r
F P
0 g
s
.51067 .84909 m .50889 .84718 L .51242 .86014 L p .62 .12 1 r
F P
0 g
s
.60486 .47886 m .56769 .5557 L .4937 .53843 L p .907 .049 .746 r
F P
0 g
s
.4937 .53843 m .48018 .45831 L .60486 .47886 L p .907 .049 .746 r
F P
0 g
s
.51178 .85658 m .51242 .86014 L .50889 .84718 L p .617 .117 1 r
F P
0 g
s
.50889 .84718 m .50595 .84403 L .51178 .85658 L p .617 .117 1 r
F P
0 g
s
.36286 .76718 m .42288 .79561 L .40271 .80574 L p .956 .064 .82 r
F P
0 g
s
.40271 .80574 m .33019 .7931 L .36286 .76718 L p .956 .064 .82 r
F P
0 g
s
.56769 .5557 m .60486 .47886 L .71396 .52938 L p .892 .048 .741 r
F P
0 g
s
.49327 1.0283 m .48047 1.05225 L .44016 1.05482 L p .752 .103 1 r
F P
0 g
s
.48047 1.05225 m .49327 1.0283 L .5207 1.01565 L p .732 .092 .962 r
F P
0 g
s
.51354 .87899 m .51348 .8791 L .51337 .86544 L p .68 .18 1 r
F P
0 g
s
.51337 .86544 m .51335 .86534 L .51354 .87899 L p .68 .18 1 r
F P
0 g
s
.51362 .87882 m .51354 .87899 L .51335 .86534 L p .68 .18 1 r
F P
0 g
s
.51335 .86534 m .51332 .86516 L .51362 .87882 L p .68 .18 1 r
F P
0 g
s
.60315 .98947 m .56812 .97344 L .58109 .94584 L p .776 .057 .786 r
F P
0 g
s
.58109 .94584 m .62474 .9532 L .60315 .98947 L p .776 .057 .786 r
F P
0 g
s
.51377 .87854 m .51362 .87882 L .51332 .86516 L p .679 .179 1 r
F P
0 g
s
.51332 .86516 m .51327 .86487 L .51377 .87854 L p .679 .179 1 r
F P
0 g
s
.51401 .87808 m .51377 .87854 L .51327 .86487 L p .678 .178 1 r
F P
0 g
s
.51327 .86487 m .51318 .86439 L .51401 .87808 L p .678 .178 1 r
F P
0 g
s
.51072 .85069 m .51178 .85658 L .50595 .84403 L p .594 .094 .972 r
F P
0 g
s
.50595 .84403 m .5011 .83882 L .51072 .85069 L p .594 .094 .972 r
F P
0 g
s
.5144 .87732 m .51401 .87808 L .51318 .86439 L p .675 .175 1 r
F P
0 g
s
.51318 .86439 m .51304 .8636 L .5144 .87732 L p .675 .175 1 r
F P
0 g
s
.47972 .81587 m .49306 .83019 L .48038 .82285 L p 1 .024 .619 r
F P
0 g
s
.48038 .82285 m .45878 .81262 L .47972 .81587 L p 1 .024 .619 r
F P
0 g
s
.77128 .53184 m .81261 .59469 L p .71396 .52938 L .869 .053 .766 r
F P
0 g
s
.51505 .87607 m .5144 .87732 L .51304 .8636 L p .669 .169 1 r
F P
0 g
s
.51304 .8636 m .51281 .86229 L .51505 .87607 L p .669 .169 1 r
F P
0 g
s
.28009 1.38812 m .31279 1.36753 L .42381 1.38074 L p .864 .075 .873 r
F P
0 g
s
.45787 1.32186 m .42381 1.38074 L .31279 1.36753 L p .845 .081 .905 r
F P
0 g
s
.42381 1.38074 m .45787 1.32186 L .53351 1.31044 L p .831 .078 .889 r
F P
0 g
s
.66316 1.3391 m .60605 1.28435 L .66544 1.24484 L p .83 .068 .838 r
F P
0 g
s
.66544 1.24484 m .76051 1.28512 L .66316 1.3391 L p .83 .068 .838 r
F P
0 g
s
.51612 .87399 m .51505 .87607 L .51281 .86229 L p 1 0 .5 r
F P
0 g
s
.51281 .86229 m .51242 .86014 L .51612 .87399 L p 1 0 .5 r
F P
0 g
s
.69626 .96524 m .62474 .9532 L .62962 .91367 L p .832 .052 .762 r
F P
0 g
s
.62962 .91367 m .70529 .90919 L .69626 .96524 L p .832 .052 .762 r
F P
0 g
s
.51788 .87057 m .51612 .87399 L .51242 .86014 L p 1 0 .5 r
F P
0 g
s
.51242 .86014 m .51178 .85658 L .51788 .87057 L p 1 0 .5 r
F P
0 g
s
.50897 .84094 m .51072 .85069 L .5011 .83882 L p 1 0 .5 r
F P
0 g
s
.5011 .83882 m .49306 .83019 L .50897 .84094 L p 1 0 .5 r
F P
0 g
s
.5137 .89275 m .51358 .89283 L .51348 .8791 L p 1 0 .5 r
F P
0 g
s
.51348 .8791 m .51354 .87899 L .5137 .89275 L p 1 0 .5 r
F P
0 g
s
.5139 .89261 m .5137 .89275 L .51354 .87899 L p 1 0 .5 r
F P
0 g
s
.51354 .87899 m .51362 .87882 L .5139 .89261 L p 1 0 .5 r
F P
0 g
s
.51422 .89239 m .5139 .89261 L .51362 .87882 L p 1 0 .5 r
F P
0 g
s
.51362 .87882 m .51377 .87854 L .51422 .89239 L p 1 0 .5 r
F P
0 g
s
.51474 .89201 m .51422 .89239 L .51377 .87854 L p 1 0 .5 r
F P
0 g
s
.51377 .87854 m .51401 .87808 L .51474 .89201 L p 1 0 .5 r
F P
0 g
s
.51561 .8914 m .51474 .89201 L .51401 .87808 L p 1 0 .5 r
F P
0 g
s
.51401 .87808 m .5144 .87732 L .51561 .8914 L p 1 0 .5 r
F P
0 g
s
.5208 .86491 m .51788 .87057 L .51178 .85658 L p 1 0 .5 r
F P
0 g
s
.51178 .85658 m .51072 .85069 L .5208 .86491 L p 1 0 .5 r
F P
0 g
s
.51705 .89038 m .51561 .8914 L .5144 .87732 L p 1 0 .5 r
F P
0 g
s
.5144 .87732 m .51505 .87607 L .51705 .89038 L p 1 0 .5 r
F P
0 g
s
.76051 1.28512 m .80119 1.30235 L .75871 1.31679 L p .851 .067 .833 r
F P
0 g
s
.26159 .71921 m .36286 .76718 L .33019 .7931 L p .919 .063 .816 r
F P
0 g
s
.33019 .7931 m .2094 .77205 L .26159 .71921 L p .919 .063 .816 r
F P
0 g
s
.51941 .88871 m .51705 .89038 L .51505 .87607 L p 1 0 .5 r
F P
0 g
s
.51505 .87607 m .51612 .87399 L .51941 .88871 L p 1 0 .5 r
F P
0 g
s
.45746 .79198 m .47972 .81587 L .45878 .81262 L p 1 .046 .729 r
F P
0 g
s
.45878 .81262 m .42288 .79561 L .45746 .79198 L p 1 .046 .729 r
F P
0 g
s
.52332 .88594 m .51941 .88871 L .51612 .87399 L p 1 0 .5 r
F P
0 g
s
.51612 .87399 m .51788 .87057 L .52332 .88594 L p 1 0 .5 r
F P
0 g
s
.53383 .98358 m .54693 .99716 L .5207 1.01565 L p .665 .087 .936 r
F P
0 g
s
.54693 .99716 m .53383 .98358 L .54669 .96363 L p .697 .07 .848 r
F P
0 g
s
.54669 .96363 m .56812 .97344 L .54693 .99716 L p .697 .07 .848 r
F P
0 g
s
.51382 .9066 m .51366 .90665 L .51358 .89283 L p .961 0 .5 r
F P
0 g
s
.51358 .89283 m .5137 .89275 L .51382 .9066 L p .961 0 .5 r
F P
0 g
s
.51409 .90651 m .51382 .9066 L .5137 .89275 L p .96 0 .5 r
F P
0 g
s
.5137 .89275 m .5139 .89261 L .51409 .90651 L p .96 0 .5 r
F P
0 g
s
.51454 .90638 m .51409 .90651 L .5139 .89261 L p .96 0 .5 r
F P
0 g
s
.5139 .89261 m .51422 .89239 L .51454 .90638 L p .96 0 .5 r
F P
0 g
s
.50605 .82474 m .50897 .84094 L .49306 .83019 L p 1 .008 .542 r
F P
0 g
s
.49306 .83019 m .47972 .81587 L .50605 .82474 L p 1 .008 .542 r
F P
0 g
s
.51528 .90615 m .51454 .90638 L .51422 .89239 L p .959 0 .5 r
F P
0 g
s
.51422 .89239 m .51474 .89201 L .51528 .90615 L p .959 0 .5 r
F P
0 g
s
.52563 .85554 m .5208 .86491 L .51072 .85069 L p 1 0 .5 r
F P
0 g
s
.51072 .85069 m .50897 .84094 L .52563 .85554 L p 1 0 .5 r
F P
0 g
s
.51649 .90577 m .51528 .90615 L .51474 .89201 L p .958 0 .5 r
F P
0 g
s
.51474 .89201 m .51561 .8914 L .51649 .90577 L p .958 0 .5 r
F P
0 g
s
.5185 .90515 m .51649 .90577 L .51561 .8914 L p .955 0 .5 r
F P
0 g
s
.51561 .8914 m .51705 .89038 L .5185 .90515 L p .955 0 .5 r
F P
0 g
s
.52978 .88137 m .52332 .88594 L .51788 .87057 L p 1 0 .5 r
F P
0 g
s
.51788 .87057 m .5208 .86491 L .52978 .88137 L p 1 0 .5 r
F P
0 g
s
.51785 1.00036 m .5207 1.01565 L .49327 1.0283 L p .645 .108 1 r
F P
0 g
s
.5207 1.01565 m .51785 1.00036 L .53383 .98358 L p .665 .087 .936 r
F P
0 g
s
.62474 .9532 m .58109 .94584 L .58383 .91638 L p .811 .048 .739 r
F P
0 g
s
.58383 .91638 m .62962 .91367 L .62474 .9532 L p .811 .048 .739 r
F P
0 g
s
.52181 .90413 m .5185 .90515 L .51705 .89038 L p .95 0 .5 r
F P
0 g
s
.51705 .89038 m .51941 .88871 L .52181 .90413 L p .95 0 .5 r
F P
0 g
s
.56812 .97344 m .54669 .96363 L .55452 .94137 L p .737 .055 .773 r
F P
0 g
s
.55452 .94137 m .58109 .94584 L .56812 .97344 L p .737 .055 .773 r
F P
0 g
s
.52726 .90244 m .52181 .90413 L .51941 .88871 L p .942 0 .5 r
F P
0 g
s
.51941 .88871 m .52332 .88594 L .52726 .90244 L p .942 0 .5 r
F P
0 g
s
.31279 1.36753 m .28009 1.38812 L .25552 1.3711 L p .879 .075 .875 r
F P
0 g
s
.34454 1.06952 m .41031 1.04988 L .44016 1.05482 L p .839 .089 .943 r
F P
0 g
s
.46869 1.03535 m .44016 1.05482 L .41031 1.04988 L p .798 .108 1 r
F P
0 g
s
.44016 1.05482 m .46869 1.03535 L .49327 1.0283 L p .752 .103 1 r
F P
0 g
s
.53628 .89965 m .52726 .90244 L .52332 .88594 L p .929 0 .5 r
F P
0 g
s
.52332 .88594 m .52978 .88137 L .53628 .89965 L p .929 0 .5 r
F P
0 g
s
.51388 .92053 m .51369 .92054 L .51366 .90665 L p .774 0 .5 r
F P
0 g
s
.51366 .90665 m .51382 .9066 L .51388 .92053 L p .774 0 .5 r
F P
0 g
s
.51418 .92051 m .51388 .92053 L .51382 .9066 L p .774 0 .5 r
F P
0 g
s
.51382 .9066 m .51409 .90651 L .51418 .92051 L p .774 0 .5 r
F P
0 g
s
.54047 .87381 m .52978 .88137 L .5208 .86491 L p 1 0 .5 r
F P
0 g
s
.5208 .86491 m .52563 .85554 L .54047 .87381 L p 1 0 .5 r
F P
0 g
s
.51469 .92048 m .51418 .92051 L .51409 .90651 L p .775 0 .5 r
F P
0 g
s
.51409 .90651 m .51454 .90638 L .51469 .92048 L p .775 0 .5 r
F P
0 g
s
.86508 1.27747 m .80119 1.30235 L p .82389 1.21387 L .858 .063 .816 r
F P
0 g
s
.80119 1.30235 m .76051 1.28512 L .82389 1.21387 L p .858 .063 .816 r
F P
0 g
s
.51553 .92043 m .51469 .92048 L .51454 .90638 L p .777 0 .5 r
F P
0 g
s
.51454 .90638 m .51528 .90615 L .51553 .92043 L p .777 0 .5 r
F P
0 g
s
.5169 .92035 m .51553 .92043 L .51528 .90615 L p .779 0 .5 r
F P
0 g
s
.51528 .90615 m .51649 .90577 L .5169 .92035 L p .779 0 .5 r
F P
0 g
s
.51918 .92021 m .5169 .92035 L .51649 .90577 L p .782 0 .5 r
F P
0 g
s
.51649 .90577 m .5185 .90515 L .51918 .92021 L p .782 0 .5 r
F P
0 g
s
.52292 .91999 m .51918 .92021 L .5185 .90515 L p .786 0 .5 r
F P
0 g
s
.5185 .90515 m .52181 .90413 L .52292 .91999 L p .786 0 .5 r
F P
0 g
s
.58109 .94584 m .55452 .94137 L .5561 .91803 L p .784 .042 .709 r
F P
0 g
s
.5561 .91803 m .58383 .91638 L .58109 .94584 L p .784 .042 .709 r
F P
0 g
s
.5291 .91963 m .52292 .91999 L .52181 .90413 L p .795 .003 .514 r
F P
0 g
s
.52181 .90413 m .52726 .90244 L .5291 .91963 L p .795 .003 .514 r
F P
0 g
s
.53367 .83996 m .52563 .85554 L .50897 .84094 L p 1 .006 .532 r
F P
0 g
s
.50897 .84094 m .50605 .82474 L .53367 .83996 L p 1 .006 .532 r
F P
0 g
s
.50113 1.01359 m .49327 1.0283 L .46869 1.03535 L p .649 .13 1 r
F P
0 g
s
.49327 1.0283 m .50113 1.01359 L .51785 1.00036 L p .645 .108 1 r
F P
0 g
s
.19438 1.05166 m .31945 1.04451 L .34454 1.06952 L p .885 .076 .879 r
F P
0 g
s
.41031 1.04988 m .34454 1.06952 L .31945 1.04451 L p .885 .085 .927 r
F P
0 g
s
.53929 .91902 m .5291 .91963 L .52726 .90244 L p .81 .011 .554 r
F P
0 g
s
.52726 .90244 m .53628 .89965 L .53929 .91902 L p .81 .011 .554 r
F P
0 g
s
.55117 .89504 m .53628 .89965 L .52978 .88137 L p .916 .005 .526 r
F P
0 g
s
.52978 .88137 m .54047 .87381 L .55117 .89504 L p .916 .005 .526 r
F P
0 g
s
.53363 .95766 m .54669 .96363 L .53383 .98358 L p .636 .071 .853 r
F P
0 g
s
.54669 .96363 m .53363 .95766 L .53836 .93865 L p .693 .052 .758 r
F P
0 g
s
.53836 .93865 m .55452 .94137 L .54669 .96363 L p .693 .052 .758 r
F P
0 g
s
.52582 .97529 m .53383 .98358 L .51785 1.00036 L p .595 .095 .976 r
F P
0 g
s
.53383 .98358 m .52582 .97529 L .53363 .95766 L p .636 .071 .853 r
F P
0 g
s
.42004 .75182 m .45746 .79198 L .42288 .79561 L p .976 .054 .77 r
F P
0 g
s
.42288 .79561 m .36286 .76718 L .42004 .75182 L p .976 .054 .77 r
F P
0 g
s
.51386 .93452 m .51368 .93449 L .51369 .92054 L p .651 .014 .569 r
F P
0 g
s
.51369 .92054 m .51388 .92053 L .51386 .93452 L p .651 .014 .569 r
F P
0 g
s
.5561 .91803 m .53929 .91902 L .53628 .89965 L p .826 .02 .602 r
F P
0 g
s
.53628 .89965 m .55117 .89504 L .5561 .91803 L p .826 .02 .602 r
F P
0 g
s
.51416 .93457 m .51386 .93452 L .51388 .92053 L p .652 .014 .57 r
F P
0 g
s
.51388 .92053 m .51418 .92051 L .51416 .93457 L p .652 .014 .57 r
F P
0 g
s
.51465 .93465 m .51416 .93457 L .51418 .92051 L p .654 .015 .573 r
F P
0 g
s
.51418 .92051 m .51469 .92048 L .51465 .93465 L p .654 .015 .573 r
F P
0 g
s
.55452 .94137 m .53836 .93865 L .53929 .91902 L p .754 .035 .677 r
F P
0 g
s
.53929 .91902 m .5561 .91803 L .55452 .94137 L p .754 .035 .677 r
F P
0 g
s
.51545 .93479 m .51465 .93465 L .51469 .92048 L p .657 .015 .576 r
F P
0 g
s
.51469 .92048 m .51553 .92043 L .51545 .93479 L p .657 .015 .576 r
F P
0 g
s
.51678 .93501 m .51545 .93479 L .51553 .92043 L p .663 .016 .582 r
F P
0 g
s
.51553 .92043 m .5169 .92035 L .51678 .93501 L p .663 .016 .582 r
F P
0 g
s
.51898 .93538 m .51678 .93501 L .5169 .92035 L p .671 .018 .59 r
F P
0 g
s
.5169 .92035 m .51918 .92021 L .51898 .93538 L p .671 .018 .59 r
F P
0 g
s
.50118 .79766 m .50605 .82474 L .47972 .81587 L p 1 .034 .669 r
F P
0 g
s
.47972 .81587 m .45746 .79198 L .50118 .79766 L p 1 .034 .669 r
F P
0 g
s
.52259 .93599 m .51898 .93538 L .51918 .92021 L p .684 .021 .603 r
F P
0 g
s
.51918 .92021 m .52292 .91999 L .52259 .93599 L p .684 .021 .603 r
F P
0 g
s
.52855 .937 m .52259 .93599 L .52292 .91999 L p .702 .024 .622 r
F P
0 g
s
.52292 .91999 m .5291 .91963 L .52855 .937 L p .702 .024 .622 r
F P
0 g
s
.53836 .93865 m .52855 .937 L .5291 .91963 L p .726 .029 .647 r
F P
0 g
s
.5291 .91963 m .53929 .91902 L .53836 .93865 L p .726 .029 .647 r
F P
0 g
s
.15496 .71146 m .21643 .69782 L p .2094 .77205 L .898 .063 .813 r
F P
0 g
s
.21643 .69782 m .26159 .71921 L .2094 .77205 L p .898 .063 .813 r
F P
0 g
s
.2094 .77205 m .04386 .7432 L .15496 .71146 L p .898 .063 .813 r
F P
0 g
s
.55821 .86127 m .54047 .87381 L .52563 .85554 L p .993 .012 .559 r
F P
0 g
s
.52563 .85554 m .53367 .83996 L .55821 .86127 L p .993 .012 .559 r
F P
0 g
s
.58383 .91638 m .5561 .91803 L .55117 .89504 L p .841 .031 .653 r
F P
0 g
s
.52855 .937 m .53836 .93865 L .53363 .95766 L p .652 .049 .743 r
F P
0 g
s
.51611 .99101 m .51785 1.00036 L .50113 1.01359 L p .629 .129 1 r
F P
0 g
s
.51785 1.00036 m .51611 .99101 L .52582 .97529 L p .595 .095 .976 r
F P
0 g
s
.62962 .91367 m .58383 .91638 L .57582 .8874 L p .852 .04 .698 r
F P
0 g
s
.55117 .89504 m .57582 .8874 L .58383 .91638 L p .841 .031 .653 r
F P
0 g
s
.53363 .95766 m .52569 .95402 L .52855 .937 L p .652 .049 .743 r
F P
0 g
s
.52259 .93599 m .52855 .937 L .52569 .95402 L p .618 .046 .729 r
F P
0 g
s
.57582 .8874 m .55117 .89504 L .54047 .87381 L p .909 .02 .602 r
F P
0 g
s
.52569 .95402 m .53363 .95766 L .52582 .97529 L p .577 .071 .856 r
F P
0 g
s
.54047 .87381 m .55821 .86127 L .57582 .8874 L p .909 .02 .602 r
F P
0 g
s
.52569 .95402 m .52086 .95181 L .52259 .93599 L p .618 .046 .729 r
F P
0 g
s
.51898 .93538 m .52259 .93599 L .52086 .95181 L p .592 .044 .719 r
F P
0 g
s
.52086 .95181 m .51793 .95047 L .51898 .93538 L p .592 .044 .719 r
F P
0 g
s
.51678 .93501 m .51898 .93538 L .51793 .95047 L p .575 .042 .711 r
F P
0 g
s
.51793 .95047 m .51615 .94965 L .51678 .93501 L p .575 .042 .711 r
F P
0 g
s
.51545 .93479 m .51678 .93501 L .51615 .94965 L p .563 .041 .706 r
F P
0 g
s
.51615 .94965 m .51507 .94916 L .51545 .93479 L p .563 .041 .706 r
F P
0 g
s
.51465 .93465 m .51545 .93479 L .51507 .94916 L p .556 .041 .703 r
F P
0 g
s
.51507 .94916 m .51441 .94886 L .51465 .93465 L p .556 .041 .703 r
F P
0 g
s
.51416 .93457 m .51465 .93465 L .51441 .94886 L p .551 .04 .701 r
F P
0 g
s
.70529 .90919 m .62962 .91367 L .61673 .87474 L p .86 .047 .735 r
F P
0 g
s
.57582 .8874 m .61673 .87474 L .62962 .91367 L p .852 .04 .698 r
F P
0 g
s
.51441 .94886 m .51402 .94868 L .51416 .93457 L p .551 .04 .701 r
F P
0 g
s
.51386 .93452 m .51416 .93457 L .51402 .94868 L p .548 .04 .699 r
F P
0 g
s
.51402 .94868 m .51377 .94857 L .51386 .93452 L p .548 .04 .699 r
F P
0 g
s
.51368 .93449 m .51386 .93452 L .51377 .94857 L p .546 .04 .698 r
F P
0 g
s
.51377 .94857 m .51363 .9485 L .51368 .93449 L p .546 .04 .698 r
F P
0 g
s
.52095 .97023 m .52582 .97529 L .51611 .99101 L p .603 .103 1 r
F P
0 g
s
.52582 .97529 m .52095 .97023 L .52569 .95402 L p .577 .071 .856 r
F P
0 g
s
.52086 .95181 m .52569 .95402 L .52095 .97023 L p .571 .071 .857 r
F P
0 g
s
.82389 1.21387 m .98463 1.23895 L .86508 1.27747 L p .858 .063 .816 r
F P
0 g
s
.52095 .97023 m .51798 .96716 L .52086 .95181 L p .571 .071 .857 r
F P
0 g
s
.51793 .95047 m .52086 .95181 L .51798 .96716 L p .571 .071 .856 r
F P
0 g
s
.41031 1.04988 m .45062 1.03785 L .46869 1.03535 L p .798 .108 1 r
F P
0 g
s
.48618 1.02342 m .46869 1.03535 L .45062 1.03785 L p .694 .14 1 r
F P
0 g
s
.46869 1.03535 m .48618 1.02342 L .50113 1.01359 L p .649 .13 1 r
F P
0 g
s
.37629 .44638 m .47408 .42216 L p .36192 .46937 L .892 .055 .776 r
F P
0 g
s
.47408 .42216 m .48018 .45831 L .36192 .46937 L p .892 .055 .776 r
F P
0 g
s
.36192 .46937 m .34871 .45427 L .37629 .44638 L p .892 .055 .776 r
F P
0 g
s
.83051 .90177 m .70529 .90919 L .68488 .85365 L p .865 .052 .762 r
F P
0 g
s
.61673 .87474 m .68488 .85365 L .70529 .90919 L p .86 .047 .735 r
F P
0 g
s
.50594 1.0046 m .50113 1.01359 L .48618 1.02342 L p .667 .167 1 r
F P
0 g
s
.50113 1.01359 m .50594 1.0046 L .51611 .99101 L p .629 .129 1 r
F P
0 g
s
.54708 .81395 m .53367 .83996 L .50605 .82474 L p 1 .029 .644 r
F P
0 g
s
.50605 .82474 m .50118 .79766 L .54708 .81395 L p 1 .029 .644 r
F P
0 g
s
.51798 .96716 m .51618 .96529 L .51793 .95047 L p .571 .071 .856 r
F P
0 g
s
.51615 .94965 m .51793 .95047 L .51618 .96529 L p .571 .071 .855 r
F P
0 g
s
.61673 .87474 m .57582 .8874 L .55821 .86127 L p .901 .033 .666 r
F P
0 g
s
.76051 1.28512 m .66544 1.24484 L .70296 1.195 L p .84 .062 .811 r
F P
0 g
s
.70296 1.195 m .82389 1.21387 L .76051 1.28512 L p .84 .062 .811 r
F P
0 g
s
.51618 .96529 m .51509 .96416 L .51615 .94965 L p .571 .071 .855 r
F P
0 g
s
.51507 .94916 m .51615 .94965 L .51509 .96416 L p .571 .071 .854 r
F P
0 g
s
.51611 .99101 m .51505 .98531 L .52095 .97023 L p .603 .103 1 r
F P
0 g
s
.51798 .96716 m .52095 .97023 L .51505 .98531 L p .608 .108 1 r
F P
0 g
s
.51509 .96416 m .51443 .96347 L .51507 .94916 L p .571 .071 .854 r
F P
0 g
s
.51441 .94886 m .51507 .94916 L .51443 .96347 L p .571 .071 .853 r
F P
0 g
s
.51505 .98531 m .51611 .99101 L .50594 1.0046 L p .65 .15 1 r
F P
0 g
s
.51443 .96347 m .51402 .96306 L .51441 .94886 L p .571 .071 .853 r
F P
0 g
s
.51402 .94868 m .51441 .94886 L .51402 .96306 L p .571 .071 .853 r
F P
0 g
s
.71396 .52938 m .75025 .50199 L .77128 .53184 L p .869 .053 .766 r
F P
0 g
s
.75025 .50199 m .71396 .52938 L .60486 .47886 L p .88 .053 .764 r
F P
0 g
s
.51402 .96306 m .51378 .9628 L .51402 .94868 L p .571 .071 .853 r
F P
0 g
s
.51377 .94857 m .51402 .94868 L .51378 .9628 L p .57 .07 .852 r
F P
0 g
s
.51378 .9628 m .51363 .96265 L .51377 .94857 L p .57 .07 .852 r
F P
0 g
s
.51363 .9485 m .51377 .94857 L .51363 .96265 L p .57 .07 .852 r
F P
0 g
s
.51363 .96265 m .51354 .96256 L .51363 .9485 L p .57 .07 .852 r
F P
0 g
s
.25552 1.3711 m .20498 1.34145 L p .31279 1.36753 L .879 .075 .875 r
F P
0 g
s
.20498 1.34145 m .22788 1.33514 L .31279 1.36753 L p .879 .075 .875 r
F P
0 g
s
.38955 1.31918 m .31279 1.36753 L .22788 1.33514 L p .869 .082 .908 r
F P
0 g
s
.31279 1.36753 m .38955 1.31918 L .45787 1.32186 L p .845 .081 .905 r
F P
0 g
s
.51505 .98531 m .5144 .98185 L .51798 .96716 L p .608 .108 1 r
F P
0 g
s
.51618 .96529 m .51798 .96716 L .5144 .98185 L p .612 .112 1 r
F P
0 g
s
.55821 .86127 m .58775 .84037 L .61673 .87474 L p .901 .033 .666 r
F P
0 g
s
.58775 .84037 m .55821 .86127 L .53367 .83996 L p .954 .029 .646 r
F P
0 g
s
.53367 .83996 m .54708 .81395 L .58775 .84037 L p .954 .029 .646 r
F P
0 g
s
.31945 1.04451 m .39559 1.04017 L .41031 1.04988 L p .885 .085 .927 r
F P
0 g
s
.45062 1.03785 m .41031 1.04988 L .39559 1.04017 L p .872 .102 1 r
F P
0 g
s
.5144 .98185 m .51401 .97974 L .51618 .96529 L p .612 .112 1 r
F P
0 g
s
.51509 .96416 m .51618 .96529 L .51401 .97974 L p .614 .114 1 r
F P
0 g
s
.88539 .89852 m .83051 .90177 L .79923 .81825 L p .868 .056 .78 r
F P
0 g
s
.68488 .85365 m .79923 .81825 L .83051 .90177 L p .865 .052 .762 r
F P
0 g
s
.50594 1.0046 m .50887 .99912 L .51505 .98531 L p .65 .15 1 r
F P
0 g
s
.5144 .98185 m .51505 .98531 L .50887 .99912 L p .668 .168 1 r
F P
0 g
s
.51401 .97974 m .51377 .97846 L .51509 .96416 L p .614 .114 1 r
F P
0 g
s
.51443 .96347 m .51509 .96416 L .51377 .97846 L p .616 .116 1 r
F P
0 g
s
.51377 .97846 m .51363 .97769 L .51443 .96347 L p .616 .116 1 r
F P
0 g
s
.51402 .96306 m .51443 .96347 L .51363 .97769 L p .616 .116 1 r
F P
0 g
s
.51363 .97769 m .51354 .97722 L .51402 .96306 L p .616 .116 1 r
F P
0 g
s
.51378 .9628 m .51402 .96306 L .51354 .97722 L p .617 .117 1 r
F P
0 g
s
.51354 .97722 m .51348 .97693 L .51378 .9628 L p .617 .117 1 r
F P
0 g
s
.51363 .96265 m .51378 .9628 L .51348 .97693 L p .617 .117 1 r
F P
0 g
s
.51348 .97693 m .51345 .97676 L .51363 .96265 L p .617 .117 1 r
F P
0 g
s
.51354 .96256 m .51363 .96265 L .51345 .97676 L p .617 .117 1 r
F P
0 g
s
.51345 .97676 m .51343 .97665 L .51354 .96256 L p .617 .117 1 r
F P
0 g
s
.48618 1.02342 m .49685 1.01613 L .50594 1.0046 L p .667 .167 1 r
F P
0 g
s
.50887 .99912 m .50594 1.0046 L .49685 1.01613 L p .695 .195 1 r
F P
0 g
s
.83749 .82965 m .88539 .89852 L p .79923 .81825 L .868 .056 .78 r
F P
0 g
s
.50887 .99912 m .51065 .99578 L .5144 .98185 L p .668 .168 1 r
F P
0 g
s
.51401 .97974 m .5144 .98185 L .51065 .99578 L p .677 .177 1 r
F P
0 g
s
.45062 1.03785 m .47523 1.0305 L .48618 1.02342 L p .694 .14 1 r
F P
0 g
s
.49685 1.01613 m .48618 1.02342 L .47523 1.0305 L p .663 .163 1 r
F P
0 g
s
.49298 .75202 m .50118 .79766 L .45746 .79198 L p .974 .046 .732 r
F P
0 g
s
.45746 .79198 m .42004 .75182 L .49298 .75202 L p .974 .046 .732 r
F P
0 g
s
.68488 .85365 m .61673 .87474 L .58775 .84037 L p .893 .043 .716 r
F P
0 g
s
.51065 .99578 m .51173 .99376 L .51401 .97974 L p .677 .177 1 r
F P
0 g
s
.51377 .97846 m .51401 .97974 L .51173 .99376 L p .681 .181 1 r
F P
0 g
s
.51173 .99376 m .51239 .99253 L .51377 .97846 L p .681 .181 1 r
F P
0 g
s
.51363 .97769 m .51377 .97846 L .51239 .99253 L p .682 .182 1 r
F P
0 g
s
.49685 1.01613 m .50335 1.0117 L .50887 .99912 L p .695 .195 1 r
F P
0 g
s
.51065 .99578 m .50887 .99912 L .50335 1.0117 L p 1 0 .5 r
F P
0 g
s
.3563 .68341 m .42004 .75182 L .36286 .76718 L p .93 .058 .788 r
F P
0 g
s
.36286 .76718 m .26159 .71921 L .3563 .68341 L p .93 .058 .788 r
F P
0 g
s
.51239 .99253 m .51279 .99178 L .51363 .97769 L p .682 .182 1 r
F P
0 g
s
.51354 .97722 m .51363 .97769 L .51279 .99178 L p .682 .182 1 r
F P
0 g
s
.51279 .99178 m .51303 .99133 L .51354 .97722 L p .682 .182 1 r
F P
0 g
s
.51348 .97693 m .51354 .97722 L .51303 .99133 L p .682 .182 1 r
F P
0 g
s
.51303 .99133 m .51318 .99105 L .51348 .97693 L p .682 .182 1 r
F P
0 g
s
.51345 .97676 m .51348 .97693 L .51318 .99105 L p .682 .182 1 r
F P
0 g
s
.51318 .99105 m .51327 .99089 L .51345 .97676 L p .682 .182 1 r
F P
0 g
s
.51343 .97665 m .51345 .97676 L .51327 .99089 L p .681 .181 1 r
F P
0 g
s
.51327 .99089 m .51332 .99079 L .51343 .97665 L p .681 .181 1 r
F P
0 g
s
.50335 1.0117 m .5073 1.009 L .51065 .99578 L p 1 0 .5 r
F P
0 g
s
.51173 .99376 m .51065 .99578 L .5073 1.009 L p 1 0 .5 r
F P
0 g
s
.39559 1.04017 m .44189 1.03752 L .45062 1.03785 L p .872 .102 1 r
F P
0 g
s
.47523 1.0305 m .45062 1.03785 L .44189 1.03752 L p .786 .122 1 r
F P
0 g
s
.47523 1.0305 m .49022 1.02603 L .49685 1.01613 L p .663 .163 1 r
F P
0 g
s
.50335 1.0117 m .49685 1.01613 L .49022 1.02603 L p .892 0 .5 r
F P
0 g
s
.52577 1.27202 m .53351 1.31044 L .45787 1.32186 L p .793 .085 .927 r
F P
0 g
s
.53351 1.31044 m .52577 1.27202 L .57029 1.25005 L p .789 .077 .887 r
F P
0 g
s
.57029 1.25005 m .60605 1.28435 L .53351 1.31044 L p .789 .077 .887 r
F P
0 g
s
.5073 1.009 m .5097 1.00736 L .51173 .99376 L p 1 0 .5 r
F P
0 g
s
.51239 .99253 m .51173 .99376 L .5097 1.00736 L p 1 0 .5 r
F P
0 g
s
.5097 1.00736 m .51116 1.00637 L .51239 .99253 L p 1 0 .5 r
F P
0 g
s
.51279 .99178 m .51239 .99253 L .51116 1.00637 L p 1 0 .5 r
F P
0 g
s
.51116 1.00637 m .51204 1.00577 L .51279 .99178 L p 1 0 .5 r
F P
0 g
s
.51303 .99133 m .51279 .99178 L .51204 1.00577 L p 1 0 .5 r
F P
0 g
s
.19438 1.05166 m .13993 1.05477 L .06053 .99389 L p .899 .068 .84 r
F P
0 g
s
.51204 1.00577 m .51258 1.0054 L .51303 .99133 L p 1 0 .5 r
F P
0 g
s
.51318 .99105 m .51303 .99133 L .51258 1.0054 L p 1 0 .5 r
F P
0 g
s
.51258 1.0054 m .5129 1.00518 L .51318 .99105 L p 1 0 .5 r
F P
0 g
s
.51327 .99089 m .51318 .99105 L .5129 1.00518 L p 1 0 .5 r
F P
0 g
s
.5129 1.00518 m .5131 1.00504 L .51327 .99089 L p 1 0 .5 r
F P
0 g
s
.51332 .99079 m .51327 .99089 L .5131 1.00504 L p 1 0 .5 r
F P
0 g
s
.5131 1.00504 m .51322 1.00496 L .51332 .99079 L p 1 0 .5 r
F P
0 g
s
.49022 1.02603 m .49933 1.02331 L .50335 1.0117 L p .892 0 .5 r
F P
0 g
s
.5073 1.009 m .50335 1.0117 L .49933 1.02331 L p .948 0 .5 r
F P
0 g
s
.60605 1.28435 m .57029 1.25005 L .60643 1.21985 L p .797 .069 .845 r
F P
0 g
s
.60643 1.21985 m .66544 1.24484 L .60605 1.28435 L p .797 .069 .845 r
F P
0 g
s
.58775 .84037 m .63731 .80531 L .68488 .85365 L p .893 .043 .716 r
F P
0 g
s
.63731 .80531 m .58775 .84037 L .54708 .81395 L p .926 .041 .706 r
F P
0 g
s
.06053 .99389 m .02634 .96877 L p .19438 1.05166 L .899 .068 .84 r
F P
0 g
s
.02634 .96877 m .19816 .99666 L .19438 1.05166 L p .899 .068 .84 r
F P
0 g
s
.31945 1.04451 m .19438 1.05166 L .19816 .99666 L p .913 .071 .857 r
F P
0 g
s
.44189 1.03752 m .47 1.03592 L .47523 1.0305 L p .786 .122 1 r
F P
0 g
s
.49022 1.02603 m .47523 1.0305 L .47 1.03592 L p .55 0 .5 r
F P
0 g
s
.71818 .4538 m .75025 .50199 L p .60486 .47886 L .88 .053 .764 r
F P
0 g
s
.56968 .77014 m .54708 .81395 L .50118 .79766 L p .955 .042 .711 r
F P
0 g
s
.50118 .79766 m .49298 .75202 L .56968 .77014 L p .955 .042 .711 r
F P
0 g
s
.49933 1.02331 m .50486 1.02165 L .5073 1.009 L p .948 0 .5 r
F P
0 g
s
.5097 1.00736 m .5073 1.009 L .50486 1.02165 L p .96 0 .5 r
F P
0 g
s
.60307 .3846 m .65769 .36964 L p .48018 .45831 L .888 .053 .767 r
F P
0 g
s
.65769 .36964 m .60486 .47886 L .48018 .45831 L p .888 .053 .767 r
F P
0 g
s
.48018 .45831 m .47408 .42216 L .60307 .3846 L p .888 .053 .767 r
F P
0 g
s
.60486 .47886 m .65769 .36964 L .71818 .4538 L p .88 .053 .764 r
F P
0 g
s
.50486 1.02165 m .50822 1.02065 L .5097 1.00736 L p .96 0 .5 r
F P
0 g
s
.51116 1.00637 m .5097 1.00736 L .50822 1.02065 L p .962 0 .5 r
F P
0 g
s
.50822 1.02065 m .51026 1.02004 L .51116 1.00637 L p .962 0 .5 r
F P
0 g
s
.51204 1.00577 m .51116 1.00637 L .51026 1.02004 L p .962 0 .5 r
F P
0 g
s
.96008 1.20674 m .98463 1.23895 L p .8423 1.13243 L .868 .06 .8 r
F P
0 g
s
.98463 1.23895 m .82389 1.21387 L .8423 1.13243 L p .868 .06 .8 r
F P
0 g
s
.51026 1.02004 m .5115 1.01967 L .51204 1.00577 L p .962 0 .5 r
F P
0 g
s
.51258 1.0054 m .51204 1.00577 L .5115 1.01967 L p .962 0 .5 r
F P
0 g
s
.5115 1.01967 m .51225 1.01945 L .51258 1.0054 L p .962 0 .5 r
F P
0 g
s
.5129 1.00518 m .51258 1.0054 L .51225 1.01945 L p .962 0 .5 r
F P
0 g
s
.51225 1.01945 m .5127 1.01931 L .5129 1.00518 L p .962 0 .5 r
F P
0 g
s
.5131 1.00504 m .5129 1.00518 L .5127 1.01931 L p .962 0 .5 r
F P
0 g
s
.5127 1.01931 m .51298 1.01923 L .5131 1.00504 L p .962 0 .5 r
F P
0 g
s
.51322 1.00496 m .5131 1.00504 L .51298 1.01923 L p .961 0 .5 r
F P
0 g
s
.51298 1.01923 m .51314 1.01918 L .51322 1.00496 L p .961 0 .5 r
F P
0 g
s
.47 1.03592 m .48707 1.03494 L .49022 1.02603 L p .55 0 .5 r
F P
0 g
s
.49933 1.02331 m .49022 1.02603 L .48707 1.03494 L p .682 0 .5 r
F P
0 g
s
.54708 .81395 m .56968 .77014 L .63731 .80531 L p .926 .041 .706 r
F P
0 g
s
.47927 1.28487 m .45787 1.32186 L .38955 1.31918 L p .812 .091 .957 r
F P
0 g
s
.45787 1.32186 m .47927 1.28487 L .52577 1.27202 L p .793 .085 .927 r
F P
0 g
s
.19816 .99666 m .32346 1.017 L .31945 1.04451 L p .913 .071 .857 r
F P
0 g
s
.39559 1.04017 m .31945 1.04451 L .32346 1.017 L p .934 .077 .886 r
F P
0 g
s
.48707 1.03494 m .49743 1.03435 L .49933 1.02331 L p .682 0 .5 r
F P
0 g
s
.50486 1.02165 m .49933 1.02331 L .49743 1.03435 L p .731 0 .5 r
F P
0 g
s
.79923 .81825 m .68488 .85365 L .63731 .80531 L p .886 .05 .75 r
F P
0 g
s
.49743 1.03435 m .50371 1.03399 L .50486 1.02165 L p .731 0 .5 r
F P
0 g
s
.50822 1.02065 m .50486 1.02165 L .50371 1.03399 L p .751 0 .5 r
F P
0 g
s
.50371 1.03399 m .50752 1.03377 L .50822 1.02065 L p .751 0 .5 r
F P
0 g
s
.51026 1.02004 m .50822 1.02065 L .50752 1.03377 L p .761 0 .5 r
F P
0 g
s
.50752 1.03377 m .50984 1.03364 L .51026 1.02004 L p .761 0 .5 r
F P
0 g
s
.5115 1.01967 m .51026 1.02004 L .50984 1.03364 L p .766 0 .5 r
F P
0 g
s
.50984 1.03364 m .51124 1.03356 L .5115 1.01967 L p .766 0 .5 r
F P
0 g
s
.51225 1.01945 m .5115 1.01967 L .51124 1.03356 L p .769 0 .5 r
F P
0 g
s
.51124 1.03356 m .51209 1.03351 L .51225 1.01945 L p .769 0 .5 r
F P
0 g
s
.5127 1.01931 m .51225 1.01945 L .51209 1.03351 L p .771 0 .5 r
F P
0 g
s
.51209 1.03351 m .51261 1.03348 L .5127 1.01931 L p .771 0 .5 r
F P
0 g
s
.51298 1.01923 m .5127 1.01931 L .51261 1.03348 L p .772 0 .5 r
F P
0 g
s
.51261 1.03348 m .51292 1.03347 L .51298 1.01923 L p .772 0 .5 r
F P
0 g
s
.51314 1.01918 m .51298 1.01923 L .51292 1.03347 L p .772 0 .5 r
F P
0 g
s
.51292 1.03347 m .51311 1.03345 L .51314 1.01918 L p .772 0 .5 r
F P
0 g
s
.32346 1.017 m .39866 1.02921 L .39559 1.04017 L p .934 .077 .886 r
F P
0 g
s
.44189 1.03752 m .39559 1.04017 L .39866 1.02921 L p .96 .086 .93 r
F P
0 g
s
.39866 1.02921 m .44397 1.03657 L .44189 1.03752 L p .96 .086 .93 r
F P
0 g
s
.47 1.03592 m .44189 1.03752 L .44397 1.03657 L p .914 .086 .928 r
F P
0 g
s
.44397 1.03657 m .47135 1.04101 L .47 1.03592 L p .914 .086 .928 r
F P
0 g
s
.48707 1.03494 m .47 1.03592 L .47135 1.04101 L p .5 0 .5 r
F P
0 g
s
.47135 1.04101 m .48792 1.0437 L .48707 1.03494 L p .5 0 .5 r
F P
0 g
s
.49743 1.03435 m .48707 1.03494 L .48792 1.0437 L p .504 0 .5 r
F P
0 g
s
.48792 1.0437 m .49796 1.04533 L .49743 1.03435 L p .504 0 .5 r
F P
0 g
s
.50371 1.03399 m .49743 1.03435 L .49796 1.04533 L p .568 0 .5 r
F P
0 g
s
.49796 1.04533 m .50404 1.04632 L .50371 1.03399 L p .568 0 .5 r
F P
0 g
s
.50752 1.03377 m .50371 1.03399 L .50404 1.04632 L p .602 .004 .521 r
F P
0 g
s
.50404 1.04632 m .50772 1.04691 L .50752 1.03377 L p .602 .004 .521 r
F P
0 g
s
.50984 1.03364 m .50752 1.03377 L .50772 1.04691 L p .622 .008 .541 r
F P
0 g
s
.50772 1.04691 m .50996 1.04728 L .50984 1.03364 L p .622 .008 .541 r
F P
0 g
s
.51124 1.03356 m .50984 1.03364 L .50996 1.04728 L p .633 .01 .552 r
F P
0 g
s
.50996 1.04728 m .51131 1.0475 L .51124 1.03356 L p .633 .01 .552 r
F P
0 g
s
.51209 1.03351 m .51124 1.03356 L .51131 1.0475 L p .639 .012 .558 r
F P
0 g
s
.51131 1.0475 m .51214 1.04763 L .51209 1.03351 L p .639 .012 .558 r
F P
0 g
s
.51261 1.03348 m .51209 1.03351 L .51214 1.04763 L p .643 .012 .562 r
F P
0 g
s
.51214 1.04763 m .51263 1.04771 L .51261 1.03348 L p .643 .012 .562 r
F P
0 g
s
.51292 1.03347 m .51261 1.03348 L .51263 1.04771 L p .645 .013 .564 r
F P
0 g
s
.51263 1.04771 m .51294 1.04776 L .51292 1.03347 L p .645 .013 .564 r
F P
0 g
s
.51311 1.03345 m .51292 1.03347 L .51294 1.04776 L p .647 .013 .565 r
F P
0 g
s
.51294 1.04776 m .51312 1.04779 L .51311 1.03345 L p .647 .013 .565 r
F P
0 g
s
.66544 1.24484 m .60643 1.21985 L .62884 1.18344 L p .815 .061 .804 r
F P
0 g
s
.62884 1.18344 m .70296 1.195 L .66544 1.24484 L p .815 .061 .804 r
F P
0 g
s
.47893 .67393 m .49298 .75202 L .42004 .75182 L p .931 .053 .765 r
F P
0 g
s
.42004 .75182 m .3563 .68341 L .47893 .67393 L p .931 .053 .765 r
F P
0 g
s
.51302 1.06213 m .51317 1.0622 L .51312 1.04779 L p .541 .039 .696 r
F P
0 g
s
.51312 1.04779 m .51294 1.04776 L .51302 1.06213 L p .541 .039 .696 r
F P
0 g
s
.51278 1.06203 m .51302 1.06213 L .51294 1.04776 L p .539 .039 .695 r
F P
0 g
s
.51294 1.04776 m .51263 1.04771 L .51278 1.06203 L p .539 .039 .695 r
F P
0 g
s
.51237 1.06185 m .51278 1.06203 L .51263 1.04771 L p .539 .039 .694 r
F P
0 g
s
.51263 1.04771 m .51214 1.04763 L .51237 1.06185 L p .539 .039 .694 r
F P
0 g
s
.51171 1.06155 m .51237 1.06185 L .51214 1.04763 L p .538 .038 .691 r
F P
0 g
s
.51214 1.04763 m .51131 1.0475 L .51171 1.06155 L p .538 .038 .691 r
F P
0 g
s
.51061 1.06107 m .51171 1.06155 L .51131 1.0475 L p .537 .037 .687 r
F P
0 g
s
.51131 1.0475 m .50996 1.04728 L .51061 1.06107 L p .537 .037 .687 r
F P
0 g
s
.50879 1.06027 m .51061 1.06107 L .50996 1.04728 L p .536 .036 .68 r
F P
0 g
s
.50996 1.04728 m .50772 1.04691 L .50879 1.06027 L p .536 .036 .68 r
F P
0 g
s
.50579 1.05895 m .50879 1.06027 L .50772 1.04691 L p .533 .033 .667 r
F P
0 g
s
.50772 1.04691 m .50404 1.04632 L .50579 1.05895 L p .533 .033 .667 r
F P
0 g
s
.50085 1.05677 m .50579 1.05895 L .50404 1.04632 L p .528 .028 .642 r
F P
0 g
s
.50404 1.04632 m .49796 1.04533 L .50085 1.05677 L p .528 .028 .642 r
F P
0 g
s
.49268 1.05316 m .50085 1.05677 L .49796 1.04533 L p .517 .017 .587 r
F P
0 g
s
.49796 1.04533 m .48792 1.0437 L .49268 1.05316 L p .517 .017 .587 r
F P
0 g
s
.47917 1.04721 m .49268 1.05316 L .48792 1.0437 L p .5 0 .5 r
F P
0 g
s
.48792 1.0437 m .47135 1.04101 L .47917 1.04721 L p .5 0 .5 r
F P
0 g
s
.8423 1.13243 m .89924 1.1293 L .96008 1.20674 L p .868 .06 .8 r
F P
0 g
s
.82389 1.21387 m .70296 1.195 L .7124 1.13956 L p .857 .057 .787 r
F P
0 g
s
.7124 1.13956 m .8423 1.13243 L .82389 1.21387 L p .857 .057 .787 r
F P
0 g
s
.22788 1.33514 m .20498 1.34145 L .18781 1.32977 L p .897 .074 .868 r
F P
0 g
s
.22788 1.33514 m .3383 1.30474 L .38955 1.31918 L p .869 .082 .908 r
F P
0 g
s
.43746 1.289 m .38955 1.31918 L .3383 1.30474 L p .847 .093 .967 r
F P
0 g
s
.38955 1.31918 m .43746 1.289 L .47927 1.28487 L p .812 .091 .957 r
F P
0 g
s
.47135 1.04101 m .44397 1.03657 L .45677 1.03733 L p 1 .049 .744 r
F P
0 g
s
.45677 1.03733 m .47917 1.04721 L .47135 1.04101 L p 1 .049 .744 r
F P
0 g
s
.51317 1.0766 m .51326 1.07669 L .51317 1.0622 L p .57 .07 .851 r
F P
0 g
s
.51317 1.0622 m .51302 1.06213 L .51317 1.0766 L p .57 .07 .851 r
F P
0 g
s
.51302 1.07645 m .51317 1.0766 L .51302 1.06213 L p .57 .07 .851 r
F P
0 g
s
.51302 1.06213 m .51278 1.06203 L .51302 1.07645 L p .57 .07 .851 r
F P
0 g
s
.51277 1.0762 m .51302 1.07645 L .51278 1.06203 L p .57 .07 .851 r
F P
0 g
s
.51278 1.06203 m .51237 1.06185 L .51277 1.0762 L p .57 .07 .851 r
F P
0 g
s
.51236 1.07579 m .51277 1.0762 L .51237 1.06185 L p .57 .07 .85 r
F P
0 g
s
.51237 1.06185 m .51171 1.06155 L .51236 1.07579 L p .57 .07 .85 r
F P
0 g
s
.63731 .80531 m .72141 .74583 L .79923 .81825 L p .886 .05 .75 r
F P
0 g
s
.72141 .74583 m .63731 .80531 L .56968 .77014 L p .906 .049 .745 r
F P
0 g
s
.51168 1.07511 m .51236 1.07579 L .51171 1.06155 L p .57 .07 .848 r
F P
0 g
s
.51171 1.06155 m .51061 1.06107 L .51168 1.07511 L p .57 .07 .848 r
F P
0 g
s
.79923 .81825 m .82357 .81071 L .83749 .82965 L p .868 .056 .78 r
F P
0 g
s
.51057 1.074 m .51168 1.07511 L .51061 1.06107 L p .569 .069 .845 r
F P
0 g
s
.51061 1.06107 m .50879 1.06027 L .51057 1.074 L p .569 .069 .845 r
F P
0 g
s
.25816 .68661 m .34257 .66868 L p .26159 .71921 L .905 .059 .797 r
F P
0 g
s
.34257 .66868 m .3563 .68341 L .26159 .71921 L p .905 .059 .797 r
F P
0 g
s
.26159 .71921 m .21643 .69782 L .25816 .68661 L p .905 .059 .797 r
F P
0 g
s
.50872 1.07216 m .51057 1.074 L .50879 1.06027 L p .568 .068 .838 r
F P
0 g
s
.50879 1.06027 m .50579 1.05895 L .50872 1.07216 L p .568 .068 .838 r
F P
0 g
s
.50568 1.06912 m .50872 1.07216 L .50579 1.05895 L p .564 .064 .822 r
F P
0 g
s
.50579 1.05895 m .50085 1.05677 L .50568 1.06912 L p .564 .064 .822 r
F P
0 g
s
.52097 1.24819 m .52577 1.27202 L .47927 1.28487 L p .732 .097 .986 r
F P
0 g
s
.52577 1.27202 m .52097 1.24819 L .54816 1.22884 L p .734 .083 .917 r
F P
0 g
s
.54816 1.22884 m .57029 1.25005 L .52577 1.27202 L p .734 .083 .917 r
F P
0 g
s
.41953 1.02091 m .45677 1.03733 L .44397 1.03657 L p 1 .065 .823 r
F P
0 g
s
.44397 1.03657 m .39866 1.02921 L .41953 1.02091 L p 1 .065 .823 r
F P
0 g
s
.57029 1.25005 m .54816 1.22884 L .57013 1.20447 L p .752 .07 .852 r
F P
0 g
s
.57013 1.20447 m .60643 1.21985 L .57029 1.25005 L p .752 .07 .852 r
F P
0 g
s
.18781 1.32977 m .12597 1.29234 L p .22788 1.33514 L .897 .074 .868 r
F P
0 g
s
.12597 1.29234 m .18245 1.28937 L .22788 1.33514 L p .897 .074 .868 r
F P
0 g
s
.3383 1.30474 m .22788 1.33514 L .18245 1.28937 L p .898 .079 .897 r
F P
0 g
s
.50065 1.0641 m .50568 1.06912 L .50085 1.05677 L p .555 .055 .776 r
F P
0 g
s
.50085 1.05677 m .49268 1.05316 L .50065 1.0641 L p .555 .055 .776 r
F P
0 g
s
.51335 1.09117 m .51337 1.09127 L .51326 1.07669 L p .618 .118 1 r
F P
0 g
s
.51326 1.07669 m .51317 1.0766 L .51335 1.09117 L p .618 .118 1 r
F P
0 g
s
.51332 1.091 m .51335 1.09117 L .51317 1.0766 L p .618 .118 1 r
F P
0 g
s
.51317 1.0766 m .51302 1.07645 L .51332 1.091 L p .618 .118 1 r
F P
0 g
s
.51326 1.09072 m .51332 1.091 L .51302 1.07645 L p .618 .118 1 r
F P
0 g
s
.51302 1.07645 m .51277 1.0762 L .51326 1.09072 L p .618 .118 1 r
F P
0 g
s
.51318 1.09025 m .51326 1.09072 L .51277 1.0762 L p .618 .118 1 r
F P
0 g
s
.51277 1.0762 m .51236 1.07579 L .51318 1.09025 L p .618 .118 1 r
F P
0 g
s
.51303 1.08949 m .51318 1.09025 L .51236 1.07579 L p .619 .119 1 r
F P
0 g
s
.51236 1.07579 m .51168 1.07511 L .51303 1.08949 L p .619 .119 1 r
F P
0 g
s
.82357 .81071 m .79923 .81825 L .72141 .74583 L p .881 .054 .772 r
F P
0 g
s
.51278 1.08823 m .51303 1.08949 L .51168 1.07511 L p .619 .119 1 r
F P
0 g
s
.51168 1.07511 m .51057 1.074 L .51278 1.08823 L p .619 .119 1 r
F P
0 g
s
.49231 1.05578 m .50065 1.0641 L .49268 1.05316 L p .527 .027 .634 r
F P
0 g
s
.49268 1.05316 m .47917 1.04721 L .49231 1.05578 L p .527 .027 .634 r
F P
0 g
s
.51238 1.08616 m .51278 1.08823 L .51057 1.074 L p .619 .119 1 r
F P
0 g
s
.51057 1.074 m .50872 1.07216 L .51238 1.08616 L p .619 .119 1 r
F P
0 g
s
.60829 .69528 m .56968 .77014 L .49298 .75202 L p .922 .05 .75 r
F P
0 g
s
.49298 .75202 m .47893 .67393 L .60829 .69528 L p .922 .05 .75 r
F P
0 g
s
.51172 1.08273 m .51238 1.08616 L .50872 1.07216 L p .615 .115 1 r
F P
0 g
s
.50872 1.07216 m .50568 1.06912 L .51172 1.08273 L p .615 .115 1 r
F P
0 g
s
.35724 .99344 m .41953 1.02091 L .39866 1.02921 L p .976 .066 .83 r
F P
0 g
s
.39866 1.02921 m .32346 1.017 L .35724 .99344 L p .976 .066 .83 r
F P
0 g
s
.56968 .77014 m .60829 .69528 L .72141 .74583 L p .906 .049 .745 r
F P
0 g
s
.49253 1.26195 m .47927 1.28487 L .43746 1.289 L p .751 .109 1 r
F P
0 g
s
.47927 1.28487 m .49253 1.26195 L .52097 1.24819 L p .732 .097 .986 r
F P
0 g
s
.51354 1.10584 m .51349 1.10594 L .51337 1.09127 L p .68 .18 1 r
F P
0 g
s
.51337 1.09127 m .51335 1.09117 L .51354 1.10584 L p .68 .18 1 r
F P
0 g
s
.51363 1.10568 m .51354 1.10584 L .51335 1.09117 L p .68 .18 1 r
F P
0 g
s
.51335 1.09117 m .51332 1.091 L .51363 1.10568 L p .68 .18 1 r
F P
0 g
s
.60643 1.21985 m .57013 1.20447 L .58359 1.17638 L p .78 .059 .793 r
F P
0 g
s
.58359 1.17638 m .62884 1.18344 L .60643 1.21985 L p .78 .059 .793 r
F P
0 g
s
.51378 1.10541 m .51363 1.10568 L .51332 1.091 L p .679 .179 1 r
F P
0 g
s
.51332 1.091 m .51326 1.09072 L .51378 1.10541 L p .679 .179 1 r
F P
0 g
s
.51403 1.10496 m .51378 1.10541 L .51326 1.09072 L p .678 .178 1 r
F P
0 g
s
.51326 1.09072 m .51318 1.09025 L .51403 1.10496 L p .678 .178 1 r
F P
0 g
s
.51062 1.07705 m .51172 1.08273 L .50568 1.06912 L p .596 .096 .982 r
F P
0 g
s
.50568 1.06912 m .50065 1.0641 L .51062 1.07705 L p .596 .096 .982 r
F P
0 g
s
.51444 1.10423 m .51403 1.10496 L .51318 1.09025 L p .675 .175 1 r
F P
0 g
s
.51318 1.09025 m .51303 1.08949 L .51444 1.10423 L p .675 .175 1 r
F P
0 g
s
.47847 1.04196 m .49231 1.05578 L .47917 1.04721 L p 1 .02 .598 r
F P
0 g
s
.47917 1.04721 m .45677 1.03733 L .47847 1.04196 L p 1 .02 .598 r
F P
0 g
s
.78085 .74852 m .82357 .81071 L p .72141 .74583 L .881 .054 .772 r
F P
0 g
s
.51511 1.10302 m .51444 1.10423 L .51303 1.08949 L p .67 .17 1 r
F P
0 g
s
.51303 1.08949 m .51278 1.08823 L .51511 1.10302 L p .67 .17 1 r
F P
0 g
s
.51622 1.10103 m .51511 1.10302 L .51278 1.08823 L p 1 0 .5 r
F P
0 g
s
.51278 1.08823 m .51238 1.08616 L .51622 1.10103 L p 1 0 .5 r
F P
0 g
s
.70296 1.195 m .62884 1.18344 L .63393 1.14387 L p .84 .054 .768 r
F P
0 g
s
.63393 1.14387 m .7124 1.13956 L .70296 1.195 L p .84 .054 .768 r
F P
0 g
s
.51805 1.09773 m .51622 1.10103 L .51238 1.08616 L p 1 0 .5 r
F P
0 g
s
.51238 1.08616 m .51172 1.08273 L .51805 1.09773 L p 1 0 .5 r
F P
0 g
s
.5088 1.06765 m .51062 1.07705 L .50065 1.0641 L p 1 0 .5 r
F P
0 g
s
.50065 1.0641 m .49231 1.05578 L .5088 1.06765 L p 1 0 .5 r
F P
0 g
s
.51371 1.12062 m .51359 1.1207 L .51349 1.10594 L p 1 0 .5 r
F P
0 g
s
.51349 1.10594 m .51354 1.10584 L .51371 1.12062 L p 1 0 .5 r
F P
0 g
s
.51391 1.12049 m .51371 1.12062 L .51354 1.10584 L p 1 0 .5 r
F P
0 g
s
.51354 1.10584 m .51363 1.10568 L .51391 1.12049 L p 1 0 .5 r
F P
0 g
s
.51425 1.12027 m .51391 1.12049 L .51363 1.10568 L p 1 0 .5 r
F P
0 g
s
.51363 1.10568 m .51378 1.10541 L .51425 1.12027 L p 1 0 .5 r
F P
0 g
s
.51479 1.11991 m .51425 1.12027 L .51378 1.10541 L p 1 0 .5 r
F P
0 g
s
.51378 1.10541 m .51403 1.10496 L .51479 1.11991 L p 1 0 .5 r
F P
0 g
s
.51569 1.11932 m .51479 1.11991 L .51403 1.10496 L p 1 0 .5 r
F P
0 g
s
.51403 1.10496 m .51444 1.10423 L .51569 1.11932 L p 1 0 .5 r
F P
0 g
s
.52107 1.09228 m .51805 1.09773 L .51172 1.08273 L p 1 0 .5 r
F P
0 g
s
.51172 1.08273 m .51062 1.07705 L .52107 1.09228 L p 1 0 .5 r
F P
0 g
s
.51718 1.11834 m .51569 1.11932 L .51444 1.10423 L p 1 0 .5 r
F P
0 g
s
.51444 1.10423 m .51511 1.10302 L .51718 1.11834 L p 1 0 .5 r
F P
0 g
s
.25206 .94707 m .35724 .99344 L .32346 1.017 L p .936 .065 .827 r
F P
0 g
s
.32346 1.017 m .19816 .99666 L .25206 .94707 L p .936 .065 .827 r
F P
0 g
s
.51964 1.11673 m .51718 1.11834 L .51511 1.10302 L p 1 0 .5 r
F P
0 g
s
.51511 1.10302 m .51622 1.10103 L .51964 1.11673 L p 1 0 .5 r
F P
0 g
s
.45538 1.0189 m .47847 1.04196 L .45677 1.03733 L p 1 .045 .727 r
F P
0 g
s
.45677 1.03733 m .41953 1.02091 L .45538 1.0189 L p 1 .045 .727 r
F P
0 g
s
.52369 1.11407 m .51964 1.11673 L .51622 1.10103 L p 1 0 .5 r
F P
0 g
s
.51622 1.10103 m .51805 1.09773 L .52369 1.11407 L p 1 0 .5 r
F P
0 g
s
.53458 1.21582 m .54816 1.22884 L .52097 1.24819 L p .66 .091 .954 r
F P
0 g
s
.54816 1.22884 m .53458 1.21582 L .54792 1.19506 L p .695 .072 .858 r
F P
0 g
s
.54792 1.19506 m .57013 1.20447 L .54816 1.22884 L p .695 .072 .858 r
F P
0 g
s
.51384 1.1355 m .51367 1.13555 L .51359 1.1207 L p .961 0 .5 r
F P
0 g
s
.51359 1.1207 m .51371 1.12062 L .51384 1.1355 L p .961 0 .5 r
F P
0 g
s
.51412 1.13542 m .51384 1.1355 L .51371 1.12062 L p .961 0 .5 r
F P
0 g
s
.51371 1.12062 m .51391 1.12049 L .51412 1.13542 L p .961 0 .5 r
F P
0 g
s
.51458 1.13529 m .51412 1.13542 L .51391 1.12049 L p .961 0 .5 r
F P
0 g
s
.51391 1.12049 m .51425 1.12027 L .51458 1.13529 L p .961 0 .5 r
F P
0 g
s
.50578 1.05202 m .5088 1.06765 L .49231 1.05578 L p 1 .004 .521 r
F P
0 g
s
.49231 1.05578 m .47847 1.04196 L .50578 1.05202 L p 1 .004 .521 r
F P
0 g
s
.51535 1.13507 m .51458 1.13529 L .51425 1.12027 L p .96 0 .5 r
F P
0 g
s
.51425 1.12027 m .51479 1.11991 L .51535 1.13507 L p .96 0 .5 r
F P
0 g
s
.52609 1.08325 m .52107 1.09228 L .51062 1.07705 L p 1 0 .5 r
F P
0 g
s
.51062 1.07705 m .5088 1.06765 L .52609 1.08325 L p 1 0 .5 r
F P
0 g
s
.51661 1.1347 m .51535 1.13507 L .51479 1.11991 L p .959 0 .5 r
F P
0 g
s
.51479 1.11991 m .51569 1.11932 L .51661 1.1347 L p .959 0 .5 r
F P
0 g
s
.51869 1.13411 m .51661 1.1347 L .51569 1.11932 L p .958 0 .5 r
F P
0 g
s
.51569 1.11932 m .51718 1.11834 L .51869 1.13411 L p .958 0 .5 r
F P
0 g
s
.53039 1.10967 m .52369 1.11407 L .51805 1.09773 L p 1 0 .5 r
F P
0 g
s
.51805 1.09773 m .52107 1.09228 L .53039 1.10967 L p 1 0 .5 r
F P
0 g
s
.51801 1.23354 m .52097 1.24819 L .49253 1.26195 L p .637 .114 1 r
F P
0 g
s
.52097 1.24819 m .51801 1.23354 L .53458 1.21582 L p .66 .091 .954 r
F P
0 g
s
.62884 1.18344 m .58359 1.17638 L .58644 1.14648 L p .817 .049 .743 r
F P
0 g
s
.58644 1.14648 m .63393 1.14387 L .62884 1.18344 L p .817 .049 .743 r
F P
0 g
s
.52212 1.13312 m .51869 1.13411 L .51718 1.11834 L p .955 0 .5 r
F P
0 g
s
.51718 1.11834 m .51964 1.11673 L .52212 1.13312 L p .955 0 .5 r
F P
0 g
s
.57013 1.20447 m .54792 1.19506 L .55604 1.17208 L p .738 .056 .779 r
F P
0 g
s
.55604 1.17208 m .58359 1.17638 L .57013 1.20447 L p .738 .056 .779 r
F P
0 g
s
.52778 1.1315 m .52212 1.13312 L .51964 1.11673 L p .949 0 .5 r
F P
0 g
s
.51964 1.11673 m .52369 1.11407 L .52778 1.1315 L p .949 0 .5 r
F P
0 g
s
.3383 1.30474 m .40648 1.28596 L .43746 1.289 L p .847 .093 .967 r
F P
0 g
s
.46703 1.27037 m .43746 1.289 L .40648 1.28596 L p .798 .114 1 r
F P
0 g
s
.43746 1.289 m .46703 1.27037 L .49253 1.26195 L p .751 .109 1 r
F P
0 g
s
.53712 1.12881 m .52778 1.1315 L .52369 1.11407 L p .938 0 .5 r
F P
0 g
s
.52369 1.11407 m .53039 1.10967 L .53712 1.12881 L p .938 0 .5 r
F P
0 g
s
.51389 1.15046 m .5137 1.15047 L .51367 1.13555 L p .774 0 .5 r
F P
0 g
s
.51367 1.13555 m .51384 1.1355 L .51389 1.15046 L p .774 0 .5 r
F P
0 g
s
.51421 1.15045 m .51389 1.15046 L .51384 1.1355 L p .775 0 .5 r
F P
0 g
s
.51384 1.1355 m .51412 1.13542 L .51421 1.15045 L p .775 0 .5 r
F P
0 g
s
.54147 1.10239 m .53039 1.10967 L .52107 1.09228 L p 1 0 .5 r
F P
0 g
s
.52107 1.09228 m .52609 1.08325 L .54147 1.10239 L p 1 0 .5 r
F P
0 g
s
.51474 1.15042 m .51421 1.15045 L .51412 1.13542 L p .775 0 .5 r
F P
0 g
s
.51412 1.13542 m .51458 1.13529 L .51474 1.15042 L p .775 0 .5 r
F P
0 g
s
.51561 1.15037 m .51474 1.15042 L .51458 1.13529 L p .777 0 .5 r
F P
0 g
s
.51458 1.13529 m .51535 1.13507 L .51561 1.15037 L p .777 0 .5 r
F P
0 g
s
.51703 1.15029 m .51561 1.15037 L .51535 1.13507 L p .779 0 .5 r
F P
0 g
s
.51535 1.13507 m .51661 1.1347 L .51703 1.15029 L p .779 0 .5 r
F P
0 g
s
.51939 1.15016 m .51703 1.15029 L .51661 1.1347 L p .783 0 .5 r
F P
0 g
s
.51661 1.1347 m .51869 1.13411 L .51939 1.15016 L p .783 0 .5 r
F P
0 g
s
.52328 1.14995 m .51939 1.15016 L .51869 1.13411 L p .788 0 .5 r
F P
0 g
s
.51869 1.13411 m .52212 1.13312 L .52328 1.14995 L p .788 0 .5 r
F P
0 g
s
.58359 1.17638 m .55604 1.17208 L .55768 1.14806 L p .788 .042 .711 r
F P
0 g
s
.55768 1.14806 m .58644 1.14648 L .58359 1.17638 L p .788 .042 .711 r
F P
0 g
s
.52968 1.1496 m .52328 1.14995 L .52212 1.13312 L p .797 .002 .51 r
F P
0 g
s
.52212 1.13312 m .52778 1.1315 L .52968 1.1496 L p .797 .002 .51 r
F P
0 g
s
.53442 1.06823 m .52609 1.08325 L .5088 1.06765 L p 1 .003 .515 r
F P
0 g
s
.5088 1.06765 m .50578 1.05202 L .53442 1.06823 L p 1 .003 .515 r
F P
0 g
s
.50068 1.24787 m .49253 1.26195 L .46703 1.27037 L p .638 .138 1 r
F P
0 g
s
.49253 1.26195 m .50068 1.24787 L .51801 1.23354 L p .637 .114 1 r
F P
0 g
s
.18245 1.28937 m .31217 1.28254 L .3383 1.30474 L p .898 .079 .897 r
F P
0 g
s
.40648 1.28596 m .3383 1.30474 L .31217 1.28254 L p .896 .09 .948 r
F P
0 g
s
.54025 1.14902 m .52968 1.1496 L .52778 1.1315 L p .813 .01 .55 r
F P
0 g
s
.52778 1.1315 m .53712 1.12881 L .54025 1.14902 L p .813 .01 .55 r
F P
0 g
s
.55257 1.12438 m .53712 1.12881 L .53039 1.10967 L p .926 .003 .517 r
F P
0 g
s
.53039 1.10967 m .54147 1.10239 L .55257 1.12438 L p .926 .003 .517 r
F P
0 g
s
.53438 1.18932 m .54792 1.19506 L .53458 1.21582 L p .632 .072 .862 r
F P
0 g
s
.54792 1.19506 m .53438 1.18932 L .53928 1.16947 L p .692 .052 .762 r
F P
0 g
s
.53928 1.16947 m .55604 1.17208 L .54792 1.19506 L p .692 .052 .762 r
F P
0 g
s
.52629 1.20786 m .53458 1.21582 L .51801 1.23354 L p .599 .099 .993 r
F P
0 g
s
.53458 1.21582 m .52629 1.20786 L .53438 1.18932 L p .632 .072 .862 r
F P
0 g
s
.41652 .98011 m .45538 1.0189 L .41953 1.02091 L p .998 .055 .776 r
F P
0 g
s
.41953 1.02091 m .35724 .99344 L .41652 .98011 L p .998 .055 .776 r
F P
0 g
s
.51388 1.1655 m .51369 1.16547 L .5137 1.15047 L p .65 .014 .569 r
F P
0 g
s
.5137 1.15047 m .51389 1.15046 L .51388 1.1655 L p .65 .014 .569 r
F P
0 g
s
.55768 1.14806 m .54025 1.14902 L .53712 1.12881 L p .831 .02 .598 r
F P
0 g
s
.53712 1.12881 m .55257 1.12438 L .55768 1.14806 L p .831 .02 .598 r
F P
0 g
s
.51419 1.16555 m .51388 1.1655 L .51389 1.15046 L p .652 .014 .57 r
F P
0 g
s
.51389 1.15046 m .51421 1.15045 L .51419 1.16555 L p .652 .014 .57 r
F P
0 g
s
.51469 1.16563 m .51419 1.16555 L .51421 1.15045 L p .654 .014 .572 r
F P
0 g
s
.51421 1.15045 m .51474 1.15042 L .51469 1.16563 L p .654 .014 .572 r
F P
0 g
s
.55604 1.17208 m .53928 1.16947 L .54025 1.14902 L p .756 .035 .677 r
F P
0 g
s
.54025 1.14902 m .55768 1.14806 L .55604 1.17208 L p .756 .035 .677 r
F P
0 g
s
.51553 1.16576 m .51469 1.16563 L .51474 1.15042 L p .657 .015 .576 r
F P
0 g
s
.51474 1.15042 m .51561 1.15037 L .51553 1.16576 L p .657 .015 .576 r
F P
0 g
s
.51691 1.16597 m .51553 1.16576 L .51561 1.15037 L p .662 .016 .581 r
F P
0 g
s
.51561 1.15037 m .51703 1.15029 L .51691 1.16597 L p .662 .016 .581 r
F P
0 g
s
.51918 1.16633 m .51691 1.16597 L .51703 1.15029 L p .671 .018 .589 r
F P
0 g
s
.51703 1.15029 m .51939 1.15016 L .51918 1.16633 L p .671 .018 .589 r
F P
0 g
s
.50073 1.0259 m .50578 1.05202 L .47847 1.04196 L p 1 .033 .664 r
F P
0 g
s
.47847 1.04196 m .45538 1.0189 L .50073 1.0259 L p 1 .033 .664 r
F P
0 g
s
.52293 1.16691 m .51918 1.16633 L .51939 1.15016 L p .683 .02 .602 r
F P
0 g
s
.51939 1.15016 m .52328 1.14995 L .52293 1.16691 L p .683 .02 .602 r
F P
0 g
s
.52911 1.16788 m .52293 1.16691 L .52328 1.14995 L p .702 .024 .621 r
F P
0 g
s
.52328 1.14995 m .52968 1.1496 L .52911 1.16788 L p .702 .024 .621 r
F P
0 g
s
.53928 1.16947 m .52911 1.16788 L .52968 1.1496 L p .726 .029 .646 r
F P
0 g
s
.52968 1.1496 m .54025 1.14902 L .53928 1.16947 L p .726 .029 .646 r
F P
0 g
s
.14141 .93875 m .20511 .92636 L p .19816 .99666 L .913 .065 .823 r
F P
0 g
s
.20511 .92636 m .25206 .94707 L .19816 .99666 L p .913 .065 .823 r
F P
0 g
s
.19816 .99666 m .02634 .96877 L .14141 .93875 L p .913 .065 .823 r
F P
0 g
s
.55987 1.09031 m .54147 1.10239 L .52609 1.08325 L p 1 .01 .548 r
F P
0 g
s
.52609 1.08325 m .53442 1.06823 L .55987 1.09031 L p 1 .01 .548 r
F P
0 g
s
.58644 1.14648 m .55768 1.14806 L .55257 1.12438 L p .848 .03 .651 r
F P
0 g
s
.52911 1.16788 m .53928 1.16947 L .53438 1.18932 L p .65 .049 .745 r
F P
0 g
s
.51621 1.22458 m .51801 1.23354 L .50068 1.24787 L p .635 .135 1 r
F P
0 g
s
.51801 1.23354 m .51621 1.22458 L .52629 1.20786 L p .599 .099 .993 r
F P
0 g
s
.63393 1.14387 m .58644 1.14648 L .57814 1.11703 L p .861 .04 .699 r
F P
0 g
s
.55257 1.12438 m .57814 1.11703 L .58644 1.14648 L p .848 .03 .651 r
F P
0 g
s
.53438 1.18932 m .52614 1.18583 L .52911 1.16788 L p .65 .049 .745 r
F P
0 g
s
.52293 1.16691 m .52911 1.16788 L .52614 1.18583 L p .616 .046 .73 r
F P
0 g
s
.57814 1.11703 m .55257 1.12438 L .54147 1.10239 L p .921 .019 .596 r
F P
0 g
s
.52614 1.18583 m .53438 1.18932 L .52629 1.20786 L p .573 .073 .863 r
F P
0 g
s
.54147 1.10239 m .55987 1.09031 L .57814 1.11703 L p .921 .019 .596 r
F P
0 g
s
.52614 1.18583 m .52114 1.18371 L .52293 1.16691 L p .616 .046 .73 r
F P
0 g
s
.51918 1.16633 m .52293 1.16691 L .52114 1.18371 L p .591 .044 .719 r
F P
0 g
s
.52114 1.18371 m .5181 1.18242 L .51918 1.16633 L p .591 .044 .719 r
F P
0 g
s
.51691 1.16597 m .51918 1.16633 L .5181 1.18242 L p .573 .042 .711 r
F P
0 g
s
.5181 1.18242 m .51625 1.18164 L .51691 1.16597 L p .573 .042 .711 r
F P
0 g
s
.51553 1.16576 m .51691 1.16597 L .51625 1.18164 L p .562 .041 .706 r
F P
0 g
s
.51625 1.18164 m .51513 1.18117 L .51553 1.16576 L p .562 .041 .706 r
F P
0 g
s
.51469 1.16563 m .51553 1.16576 L .51513 1.18117 L p .555 .041 .703 r
F P
0 g
s
.51513 1.18117 m .51445 1.18088 L .51469 1.16563 L p .555 .041 .703 r
F P
0 g
s
.51419 1.16555 m .51469 1.16563 L .51445 1.18088 L p .55 .04 .701 r
F P
0 g
s
.7124 1.13956 m .63393 1.14387 L .62058 1.10485 L p .871 .048 .739 r
F P
0 g
s
.57814 1.11703 m .62058 1.10485 L .63393 1.14387 L p .861 .04 .699 r
F P
0 g
s
.51445 1.18088 m .51404 1.1807 L .51419 1.16555 L p .55 .04 .701 r
F P
0 g
s
.51388 1.1655 m .51419 1.16555 L .51404 1.1807 L p .548 .04 .699 r
F P
0 g
s
.51404 1.1807 m .51379 1.1806 L .51388 1.1655 L p .548 .04 .699 r
F P
0 g
s
.51369 1.16547 m .51388 1.1655 L .51379 1.1806 L p .546 .04 .698 r
F P
0 g
s
.51379 1.1806 m .51364 1.18053 L .51369 1.16547 L p .546 .04 .698 r
F P
0 g
s
.52123 1.20301 m .52629 1.20786 L .51621 1.22458 L p .605 .105 1 r
F P
0 g
s
.52629 1.20786 m .52123 1.20301 L .52614 1.18583 L p .573 .073 .863 r
F P
0 g
s
.52114 1.18371 m .52614 1.18583 L .52123 1.20301 L p .572 .072 .861 r
F P
0 g
s
.52123 1.20301 m .51815 1.20007 L .52114 1.18371 L p .572 .072 .861 r
F P
0 g
s
.5181 1.18242 m .52114 1.18371 L .51815 1.20007 L p .572 .072 .859 r
F P
0 g
s
.40648 1.28596 m .44828 1.27445 L .46703 1.27037 L p .798 .114 1 r
F P
0 g
s
.46703 1.27037 m .48516 1.25895 L .50068 1.24787 L p .638 .138 1 r
F P
0 g
s
.48516 1.25895 m .46703 1.27037 L .44828 1.27445 L p .674 .145 1 r
F P
0 g
s
.37116 .66119 m .47259 .63865 L p .3563 .68341 L .906 .057 .783 r
F P
0 g
s
.47259 .63865 m .47893 .67393 L .3563 .68341 L p .906 .057 .783 r
F P
0 g
s
.3563 .68341 m .34257 .66868 L .37116 .66119 L p .906 .057 .783 r
F P
0 g
s
.8423 1.13243 m .7124 1.13956 L .69131 1.08453 L p .877 .054 .768 r
F P
0 g
s
.62058 1.10485 m .69131 1.08453 L .7124 1.13956 L p .871 .048 .739 r
F P
0 g
s
.50566 1.23925 m .50068 1.24787 L .48516 1.25895 L p .674 .174 1 r
F P
0 g
s
.50068 1.24787 m .50566 1.23925 L .51621 1.22458 L p .635 .135 1 r
F P
0 g
s
.54834 1.04315 m .53442 1.06823 L .50578 1.05202 L p 1 .028 .638 r
F P
0 g
s
.50578 1.05202 m .50073 1.0259 L .54834 1.04315 L p 1 .028 .638 r
F P
0 g
s
.51815 1.20007 m .51629 1.19827 L .5181 1.18242 L p .572 .072 .859 r
F P
0 g
s
.51625 1.18164 m .5181 1.18242 L .51629 1.19827 L p .571 .071 .857 r
F P
0 g
s
.62058 1.10485 m .57814 1.11703 L .55987 1.09031 L p .914 .033 .665 r
F P
0 g
s
.51629 1.19827 m .51515 1.19719 L .51625 1.18164 L p .571 .071 .857 r
F P
0 g
s
.51513 1.18117 m .51625 1.18164 L .51515 1.19719 L p .571 .071 .855 r
F P
0 g
s
.51621 1.22458 m .51511 1.21912 L .52123 1.20301 L p .605 .105 1 r
F P
0 g
s
.51815 1.20007 m .52123 1.20301 L .51511 1.21912 L p .61 .11 1 r
F P
0 g
s
.51515 1.19719 m .51446 1.19653 L .51513 1.18117 L p .571 .071 .855 r
F P
0 g
s
.51445 1.18088 m .51513 1.18117 L .51446 1.19653 L p .571 .071 .854 r
F P
0 g
s
.51511 1.21912 m .51621 1.22458 L .50566 1.23925 L p .656 .156 1 r
F P
0 g
s
.51446 1.19653 m .51405 1.19613 L .51445 1.18088 L p .571 .071 .854 r
F P
0 g
s
.51404 1.1807 m .51445 1.18088 L .51405 1.19613 L p .571 .071 .853 r
F P
0 g
s
.72141 .74583 m .75912 .71915 L .78085 .74852 L p .881 .054 .772 r
F P
0 g
s
.75912 .71915 m .72141 .74583 L .60829 .69528 L p .893 .054 .77 r
F P
0 g
s
.51405 1.19613 m .51379 1.19588 L .51404 1.1807 L p .571 .071 .853 r
F P
0 g
s
.51379 1.1806 m .51404 1.1807 L .51379 1.19588 L p .571 .071 .853 r
F P
0 g
s
.51379 1.19588 m .51364 1.19574 L .51379 1.1806 L p .571 .071 .853 r
F P
0 g
s
.51364 1.18053 m .51379 1.1806 L .51364 1.19574 L p .57 .07 .852 r
F P
0 g
s
.51364 1.19574 m .51355 1.19565 L .51364 1.18053 L p .57 .07 .852 r
F P
0 g
s
.51511 1.21912 m .51444 1.21579 L .51815 1.20007 L p .61 .11 1 r
F P
0 g
s
.51629 1.19827 m .51815 1.20007 L .51444 1.21579 L p .613 .113 1 r
F P
0 g
s
.55987 1.09031 m .59053 1.07018 L .62058 1.10485 L p .914 .033 .665 r
F P
0 g
s
.59053 1.07018 m .55987 1.09031 L .53442 1.06823 L p .973 .028 .642 r
F P
0 g
s
.53442 1.06823 m .54834 1.04315 L .59053 1.07018 L p .973 .028 .642 r
F P
0 g
s
.31217 1.28254 m .39117 1.27838 L .40648 1.28596 L p .896 .09 .948 r
F P
0 g
s
.44828 1.27445 m .40648 1.28596 L .39117 1.27838 L p .873 .107 1 r
F P
0 g
s
.51444 1.21579 m .51403 1.21377 L .51629 1.19827 L p .613 .113 1 r
F P
0 g
s
.51515 1.19719 m .51629 1.19827 L .51403 1.21377 L p .615 .115 1 r
F P
0 g
s
.89924 1.1293 m .8423 1.13243 L .81007 1.05043 L p .881 .057 .787 r
F P
0 g
s
.69131 1.08453 m .81007 1.05043 L .8423 1.13243 L p .877 .054 .768 r
F P
0 g
s
.50566 1.23925 m .5087 1.234 L .51511 1.21912 L p .656 .156 1 r
F P
0 g
s
.51444 1.21579 m .51511 1.21912 L .5087 1.234 L p .672 .172 1 r
F P
0 g
s
.51403 1.21377 m .51378 1.21255 L .51515 1.19719 L p .615 .115 1 r
F P
0 g
s
.51446 1.19653 m .51515 1.19719 L .51378 1.21255 L p .616 .116 1 r
F P
0 g
s
.51378 1.21255 m .51363 1.2118 L .51446 1.19653 L p .616 .116 1 r
F P
0 g
s
.51405 1.19613 m .51446 1.19653 L .51363 1.2118 L p .617 .117 1 r
F P
0 g
s
.51363 1.2118 m .51354 1.21135 L .51405 1.19613 L p .617 .117 1 r
F P
0 g
s
.51379 1.19588 m .51405 1.19613 L .51354 1.21135 L p .617 .117 1 r
F P
0 g
s
.51354 1.21135 m .51349 1.21108 L .51379 1.19588 L p .617 .117 1 r
F P
0 g
s
.51364 1.19574 m .51379 1.19588 L .51349 1.21108 L p .617 .117 1 r
F P
0 g
s
.51349 1.21108 m .51345 1.21091 L .51364 1.19574 L p .617 .117 1 r
F P
0 g
s
.51355 1.19565 m .51364 1.19574 L .51345 1.21091 L p .617 .117 1 r
F P
0 g
s
.51345 1.21091 m .51343 1.21081 L .51355 1.19565 L p .617 .117 1 r
F P
0 g
s
.48516 1.25895 m .49623 1.25198 L .50566 1.23925 L p .674 .174 1 r
F P
0 g
s
.5087 1.234 m .50566 1.23925 L .49623 1.25198 L p .696 .196 1 r
F P
0 g
s
.84976 1.06167 m .89924 1.1293 L p .81007 1.05043 L .881 .057 .787 r
F P
0 g
s
.5087 1.234 m .51055 1.23081 L .51444 1.21579 L p .672 .172 1 r
F P
0 g
s
.51403 1.21377 m .51444 1.21579 L .51055 1.23081 L p .68 .18 1 r
F P
0 g
s
.44828 1.27445 m .47381 1.26742 L .48516 1.25895 L p .674 .145 1 r
F P
0 g
s
.49623 1.25198 m .48516 1.25895 L .47381 1.26742 L p .723 0 .5 r
F P
0 g
s
.4922 .98183 m .50073 1.0259 L .45538 1.0189 L p .997 .047 .734 r
F P
0 g
s
.45538 1.0189 m .41652 .98011 L .4922 .98183 L p .997 .047 .734 r
F P
0 g
s
.69131 1.08453 m .62058 1.10485 L .59053 1.07018 L p .906 .043 .717 r
F P
0 g
s
.51055 1.23081 m .51167 1.22887 L .51403 1.21377 L p .68 .18 1 r
F P
0 g
s
.51378 1.21255 m .51403 1.21377 L .51167 1.22887 L p .682 .182 1 r
F P
0 g
s
.51167 1.22887 m .51235 1.22769 L .51378 1.21255 L p .682 .182 1 r
F P
0 g
s
.51363 1.2118 m .51378 1.21255 L .51235 1.22769 L p .683 .183 1 r
F P
0 g
s
.49623 1.25198 m .50297 1.24773 L .5087 1.234 L p .696 .196 1 r
F P
0 g
s
.51055 1.23081 m .5087 1.234 L .50297 1.24773 L p 1 0 .5 r
F P
0 g
s
.35025 .91395 m .41652 .98011 L .35724 .99344 L p .949 .059 .796 r
F P
0 g
s
.35724 .99344 m .25206 .94707 L .35025 .91395 L p .949 .059 .796 r
F P
0 g
s
.51235 1.22769 m .51276 1.22697 L .51363 1.2118 L p .683 .183 1 r
F P
0 g
s
.51354 1.21135 m .51363 1.2118 L .51276 1.22697 L p .682 .182 1 r
F P
0 g
s
.51276 1.22697 m .51302 1.22654 L .51354 1.21135 L p .682 .182 1 r
F P
0 g
s
.51349 1.21108 m .51354 1.21135 L .51302 1.22654 L p .682 .182 1 r
F P
0 g
s
.51302 1.22654 m .51317 1.22628 L .51349 1.21108 L p .682 .182 1 r
F P
0 g
s
.51345 1.21091 m .51349 1.21108 L .51317 1.22628 L p .682 .182 1 r
F P
0 g
s
.51317 1.22628 m .51326 1.22612 L .51345 1.21091 L p .682 .182 1 r
F P
0 g
s
.51343 1.21081 m .51345 1.21091 L .51326 1.22612 L p .681 .181 1 r
F P
0 g
s
.51326 1.22612 m .51332 1.22602 L .51343 1.21081 L p .681 .181 1 r
F P
0 g
s
.50297 1.24773 m .50707 1.24515 L .51055 1.23081 L p 1 0 .5 r
F P
0 g
s
.51167 1.22887 m .51055 1.23081 L .50707 1.24515 L p 1 0 .5 r
F P
0 g
s
.39117 1.27838 m .4392 1.27586 L .44828 1.27445 L p .873 .107 1 r
F P
0 g
s
.47381 1.26742 m .44828 1.27445 L .4392 1.27586 L p .757 .12 1 r
F P
0 g
s
.47381 1.26742 m .48935 1.26314 L .49623 1.25198 L p .723 0 .5 r
F P
0 g
s
.50297 1.24773 m .49623 1.25198 L .48935 1.26314 L p .89 0 .5 r
F P
0 g
s
.50707 1.24515 m .50956 1.24358 L .51167 1.22887 L p 1 0 .5 r
F P
0 g
s
.51235 1.22769 m .51167 1.22887 L .50956 1.24358 L p 1 0 .5 r
F P
0 g
s
.50956 1.24358 m .51107 1.24263 L .51235 1.22769 L p 1 0 .5 r
F P
0 g
s
.51276 1.22697 m .51235 1.22769 L .51107 1.24263 L p 1 0 .5 r
F P
0 g
s
.51107 1.24263 m .51199 1.24205 L .51276 1.22697 L p 1 0 .5 r
F P
0 g
s
.51302 1.22654 m .51276 1.22697 L .51199 1.24205 L p 1 0 .5 r
F P
0 g
s
.18245 1.28937 m .12597 1.29234 L .04317 1.23526 L p .915 .071 .854 r
F P
0 g
s
.51199 1.24205 m .51254 1.2417 L .51302 1.22654 L p 1 0 .5 r
F P
0 g
s
.51317 1.22628 m .51302 1.22654 L .51254 1.2417 L p 1 0 .5 r
F P
0 g
s
.51254 1.2417 m .51288 1.24149 L .51317 1.22628 L p 1 0 .5 r
F P
0 g
s
.51326 1.22612 m .51317 1.22628 L .51288 1.24149 L p 1 0 .5 r
F P
0 g
s
.51288 1.24149 m .51309 1.24136 L .51326 1.22612 L p 1 0 .5 r
F P
0 g
s
.51332 1.22602 m .51326 1.22612 L .51309 1.24136 L p 1 0 .5 r
F P
0 g
s
.51309 1.24136 m .51321 1.24128 L .51332 1.22602 L p 1 0 .5 r
F P
0 g
s
.48935 1.26314 m .4988 1.26054 L .50297 1.24773 L p .89 0 .5 r
F P
0 g
s
.50707 1.24515 m .50297 1.24773 L .4988 1.26054 L p .941 0 .5 r
F P
0 g
s
.59053 1.07018 m .642 1.03638 L .69131 1.08453 L p .906 .043 .717 r
F P
0 g
s
.642 1.03638 m .59053 1.07018 L .54834 1.04315 L p .943 .041 .707 r
F P
0 g
s
.04317 1.23526 m .00746 1.21183 L p .18245 1.28937 L .915 .071 .854 r
F P
0 g
s
.00746 1.21183 m .18605 1.23853 L .18245 1.28937 L p .915 .071 .854 r
F P
0 g
s
.31217 1.28254 m .18245 1.28937 L .18605 1.23853 L p .929 .074 .872 r
F P
0 g
s
.4392 1.27586 m .46837 1.27432 L .47381 1.26742 L p .757 .12 1 r
F P
0 g
s
.48935 1.26314 m .47381 1.26742 L .46837 1.27432 L p .569 0 .5 r
F P
0 g
s
.72592 .67145 m .75912 .71915 L p .60829 .69528 L .893 .054 .77 r
F P
0 g
s
.57182 1.00088 m .54834 1.04315 L .50073 1.0259 L p .975 .042 .712 r
F P
0 g
s
.50073 1.0259 m .4922 .98183 L .57182 1.00088 L p .975 .042 .712 r
F P
0 g
s
.4988 1.26054 m .50454 1.25896 L .50707 1.24515 L p .941 0 .5 r
F P
0 g
s
.50956 1.24358 m .50707 1.24515 L .50454 1.25896 L p .955 0 .5 r
F P
0 g
s
.60651 .60283 m .66327 .58868 L p .47893 .67393 L .902 .055 .774 r
F P
0 g
s
.66327 .58868 m .60829 .69528 L .47893 .67393 L p .902 .055 .774 r
F P
0 g
s
.47893 .67393 m .47259 .63865 L .60651 .60283 L p .902 .055 .774 r
F P
0 g
s
.60829 .69528 m .66327 .58868 L .72592 .67145 L p .893 .054 .77 r
F P
0 g
s
.50454 1.25896 m .50803 1.258 L .50956 1.24358 L p .955 0 .5 r
F P
0 g
s
.51107 1.24263 m .50956 1.24358 L .50803 1.258 L p .959 0 .5 r
F P
0 g
s
.50803 1.258 m .51014 1.25742 L .51107 1.24263 L p .959 0 .5 r
F P
0 g
s
.51199 1.24205 m .51107 1.24263 L .51014 1.25742 L p .961 0 .5 r
F P
0 g
s
.51014 1.25742 m .51142 1.25706 L .51199 1.24205 L p .961 0 .5 r
F P
0 g
s
.51254 1.2417 m .51199 1.24205 L .51142 1.25706 L p .961 0 .5 r
F P
0 g
s
.51142 1.25706 m .5122 1.25685 L .51254 1.2417 L p .961 0 .5 r
F P
0 g
s
.51288 1.24149 m .51254 1.2417 L .5122 1.25685 L p .961 0 .5 r
F P
0 g
s
.5122 1.25685 m .51267 1.25672 L .51288 1.24149 L p .961 0 .5 r
F P
0 g
s
.51309 1.24136 m .51288 1.24149 L .51267 1.25672 L p .961 0 .5 r
F P
0 g
s
.51267 1.25672 m .51296 1.25664 L .51309 1.24136 L p .961 0 .5 r
F P
0 g
s
.51321 1.24128 m .51309 1.24136 L .51296 1.25664 L p .961 0 .5 r
F P
0 g
s
.51296 1.25664 m .51313 1.25659 L .51321 1.24128 L p .961 0 .5 r
F P
0 g
s
.46837 1.27432 m .48608 1.27339 L .48935 1.26314 L p .569 0 .5 r
F P
0 g
s
.4988 1.26054 m .48935 1.26314 L .48608 1.27339 L p .684 0 .5 r
F P
0 g
s
.54834 1.04315 m .57182 1.00088 L .642 1.03638 L p .943 .041 .707 r
F P
0 g
s
.18605 1.23853 m .31622 1.25798 L .31217 1.28254 L p .929 .074 .872 r
F P
0 g
s
.39117 1.27838 m .31217 1.28254 L .31622 1.25798 L p .95 .08 .902 r
F P
0 g
s
.48608 1.27339 m .49683 1.27282 L .4988 1.26054 L p .684 0 .5 r
F P
0 g
s
.50454 1.25896 m .4988 1.26054 L .49683 1.27282 L p .73 0 .5 r
F P
0 g
s
.81007 1.05043 m .69131 1.08453 L .642 1.03638 L p .9 .051 .755 r
F P
0 g
s
.49683 1.27282 m .50335 1.27248 L .50454 1.25896 L p .73 0 .5 r
F P
0 g
s
.50803 1.258 m .50454 1.25896 L .50335 1.27248 L p .75 0 .5 r
F P
0 g
s
.50335 1.27248 m .5073 1.27227 L .50803 1.258 L p .75 0 .5 r
F P
0 g
s
.51014 1.25742 m .50803 1.258 L .5073 1.27227 L p .76 0 .5 r
F P
0 g
s
.5073 1.27227 m .5097 1.27215 L .51014 1.25742 L p .76 0 .5 r
F P
0 g
s
.51142 1.25706 m .51014 1.25742 L .5097 1.27215 L p .766 0 .5 r
F P
0 g
s
.5097 1.27215 m .51116 1.27207 L .51142 1.25706 L p .766 0 .5 r
F P
0 g
s
.5122 1.25685 m .51142 1.25706 L .51116 1.27207 L p .769 0 .5 r
F P
0 g
s
.51116 1.27207 m .51204 1.27202 L .5122 1.25685 L p .769 0 .5 r
F P
0 g
s
.51267 1.25672 m .5122 1.25685 L .51204 1.27202 L p .771 0 .5 r
F P
0 g
s
.51204 1.27202 m .51258 1.27199 L .51267 1.25672 L p .771 0 .5 r
F P
0 g
s
.51296 1.25664 m .51267 1.25672 L .51258 1.27199 L p .772 0 .5 r
F P
0 g
s
.51258 1.27199 m .5129 1.27198 L .51296 1.25664 L p .772 0 .5 r
F P
0 g
s
.51313 1.25659 m .51296 1.25664 L .5129 1.27198 L p .772 0 .5 r
F P
0 g
s
.5129 1.27198 m .5131 1.27197 L .51313 1.25659 L p .772 0 .5 r
F P
0 g
s
.31622 1.25798 m .3943 1.26965 L .39117 1.27838 L p .95 .08 .902 r
F P
0 g
s
.4392 1.27586 m .39117 1.27838 L .3943 1.26965 L p .965 .088 .938 r
F P
0 g
s
.3943 1.26965 m .44134 1.27669 L .4392 1.27586 L p .965 .088 .938 r
F P
0 g
s
.46837 1.27432 m .4392 1.27586 L .44134 1.27669 L p .5 0 .5 r
F P
0 g
s
.44134 1.27669 m .46976 1.28093 L .46837 1.27432 L p .5 0 .5 r
F P
0 g
s
.48608 1.27339 m .46837 1.27432 L .46976 1.28093 L p .5 0 .5 r
F P
0 g
s
.46976 1.28093 m .48696 1.2835 L .48608 1.27339 L p .5 0 .5 r
F P
0 g
s
.49683 1.27282 m .48608 1.27339 L .48696 1.2835 L p .515 0 .5 r
F P
0 g
s
.48696 1.2835 m .49737 1.28506 L .49683 1.27282 L p .515 0 .5 r
F P
0 g
s
.50335 1.27248 m .49683 1.27282 L .49737 1.28506 L p .572 0 .5 r
F P
0 g
s
.49737 1.28506 m .50368 1.286 L .50335 1.27248 L p .572 0 .5 r
F P
0 g
s
.5073 1.27227 m .50335 1.27248 L .50368 1.286 L p .604 .005 .524 r
F P
0 g
s
.50368 1.286 m .50751 1.28658 L .5073 1.27227 L p .604 .005 .524 r
F P
0 g
s
.5097 1.27215 m .5073 1.27227 L .50751 1.28658 L p .623 .008 .542 r
F P
0 g
s
.50751 1.28658 m .50983 1.28692 L .5097 1.27215 L p .623 .008 .542 r
F P
0 g
s
.51116 1.27207 m .5097 1.27215 L .50983 1.28692 L p .634 .01 .552 r
F P
0 g
s
.50983 1.28692 m .51123 1.28713 L .51116 1.27207 L p .634 .01 .552 r
F P
0 g
s
.51204 1.27202 m .51116 1.27207 L .51123 1.28713 L p .64 .012 .558 r
F P
0 g
s
.51123 1.28713 m .51209 1.28726 L .51204 1.27202 L p .64 .012 .558 r
F P
0 g
s
.51258 1.27199 m .51204 1.27202 L .51209 1.28726 L p .643 .012 .562 r
F P
0 g
s
.51209 1.28726 m .51261 1.28734 L .51258 1.27199 L p .643 .012 .562 r
F P
0 g
s
.5129 1.27198 m .51258 1.27199 L .51261 1.28734 L p .645 .013 .564 r
F P
0 g
s
.51261 1.28734 m .51292 1.28738 L .5129 1.27198 L p .645 .013 .564 r
F P
0 g
s
.5131 1.27197 m .5129 1.27198 L .51292 1.28738 L p .647 .013 .565 r
F P
0 g
s
.51292 1.28738 m .51311 1.28741 L .5131 1.27197 L p .647 .013 .565 r
F P
0 g
s
.47759 .90631 m .4922 .98183 L .41652 .98011 L p .95 .054 .771 r
F P
0 g
s
.41652 .98011 m .35025 .91395 L .47759 .90631 L p .95 .054 .771 r
F P
0 g
s
.51301 1.30288 m .51316 1.30294 L .51311 1.28741 L p .541 .039 .696 r
F P
0 g
s
.51311 1.28741 m .51292 1.28738 L .51301 1.30288 L p .541 .039 .696 r
F P
0 g
s
.51275 1.30277 m .51301 1.30288 L .51292 1.28738 L p .539 .039 .695 r
F P
0 g
s
.51292 1.28738 m .51261 1.28734 L .51275 1.30277 L p .539 .039 .695 r
F P
0 g
s
.51233 1.3026 m .51275 1.30277 L .51261 1.28734 L p .539 .039 .694 r
F P
0 g
s
.51261 1.28734 m .51209 1.28726 L .51233 1.3026 L p .539 .039 .694 r
F P
0 g
s
.51164 1.30232 m .51233 1.3026 L .51209 1.28726 L p .538 .038 .691 r
F P
0 g
s
.51209 1.28726 m .51123 1.28713 L .51164 1.30232 L p .538 .038 .691 r
F P
0 g
s
.5105 1.30186 m .51164 1.30232 L .51123 1.28713 L p .537 .037 .687 r
F P
0 g
s
.51123 1.28713 m .50983 1.28692 L .5105 1.30186 L p .537 .037 .687 r
F P
0 g
s
.50861 1.30109 m .5105 1.30186 L .50983 1.28692 L p .536 .036 .68 r
F P
0 g
s
.50983 1.28692 m .50751 1.28658 L .50861 1.30109 L p .536 .036 .68 r
F P
0 g
s
.5055 1.29983 m .50861 1.30109 L .50751 1.28658 L p .534 .034 .668 r
F P
0 g
s
.50751 1.28658 m .50368 1.286 L .5055 1.29983 L p .534 .034 .668 r
F P
0 g
s
.50037 1.29775 m .5055 1.29983 L .50368 1.286 L p .529 .029 .644 r
F P
0 g
s
.50368 1.286 m .49737 1.28506 L .50037 1.29775 L p .529 .029 .644 r
F P
0 g
s
.49189 1.29431 m .50037 1.29775 L .49737 1.28506 L p .519 .019 .593 r
F P
0 g
s
.49737 1.28506 m .48696 1.2835 L .49189 1.29431 L p .519 .019 .593 r
F P
0 g
s
.47787 1.28862 m .49189 1.29431 L .48696 1.2835 L p .5 0 .5 r
F P
0 g
s
.48696 1.2835 m .46976 1.28093 L .47787 1.28862 L p .5 0 .5 r
F P
0 g
s
.45461 1.27918 m .47787 1.28862 L .46976 1.28093 L p .5 0 .5 r
F P
0 g
s
.46976 1.28093 m .44134 1.27669 L .45461 1.27918 L p .5 0 .5 r
F P
0 g
s
.51316 1.31846 m .51326 1.31855 L .51316 1.30294 L p .57 .07 .851 r
F P
0 g
s
.51316 1.30294 m .51301 1.30288 L .51316 1.31846 L p .57 .07 .851 r
F P
0 g
s
.513 1.31832 m .51316 1.31846 L .51301 1.30288 L p .57 .07 .851 r
F P
0 g
s
.51301 1.30288 m .51275 1.30277 L .513 1.31832 L p .57 .07 .851 r
F P
0 g
s
.51275 1.31808 m .513 1.31832 L .51275 1.30277 L p .57 .07 .85 r
F P
0 g
s
.51275 1.30277 m .51233 1.3026 L .51275 1.31808 L p .57 .07 .85 r
F P
0 g
s
.51232 1.31769 m .51275 1.31808 L .51233 1.3026 L p .57 .07 .849 r
F P
0 g
s
.51233 1.3026 m .51164 1.30232 L .51232 1.31769 L p .57 .07 .849 r
F P
0 g
s
.642 1.03638 m .72943 .97897 L .81007 1.05043 L p .9 .051 .755 r
F P
0 g
s
.72943 .97897 m .642 1.03638 L .57182 1.00088 L p .921 .05 .75 r
F P
0 g
s
.51162 1.31705 m .51232 1.31769 L .51164 1.30232 L p .569 .069 .847 r
F P
0 g
s
.51164 1.30232 m .5105 1.30186 L .51162 1.31705 L p .569 .069 .847 r
F P
0 g
s
.81007 1.05043 m .83537 1.04316 L .84976 1.06167 L p .881 .057 .787 r
F P
0 g
s
.51046 1.31598 m .51162 1.31705 L .5105 1.30186 L p .569 .069 .843 r
F P
0 g
s
.5105 1.30186 m .50861 1.30109 L .51046 1.31598 L p .569 .069 .843 r
F P
0 g
s
.24839 .91585 m .33597 .89968 L p .25206 .94707 L .921 .061 .806 r
F P
0 g
s
.33597 .89968 m .35025 .91395 L .25206 .94707 L p .921 .061 .806 r
F P
0 g
s
.25206 .94707 m .20511 .92636 L .24839 .91585 L p .921 .061 .806 r
F P
0 g
s
.50854 1.31423 m .51046 1.31598 L .50861 1.30109 L p .567 .067 .836 r
F P
0 g
s
.50861 1.30109 m .5055 1.29983 L .50854 1.31423 L p .567 .067 .836 r
F P
0 g
s
.50539 1.31133 m .50854 1.31423 L .5055 1.29983 L p .564 .064 .819 r
F P
0 g
s
.5055 1.29983 m .50037 1.29775 L .50539 1.31133 L p .564 .064 .819 r
F P
0 g
s
.41593 1.26349 m .45461 1.27918 L .44134 1.27669 L p 1 .065 .823 r
F P
0 g
s
.44134 1.27669 m .3943 1.26965 L .41593 1.26349 L p 1 .065 .823 r
F P
0 g
s
.50016 1.30653 m .50539 1.31133 L .50037 1.29775 L p .555 .055 .775 r
F P
0 g
s
.50037 1.29775 m .49189 1.29431 L .50016 1.30653 L p .555 .055 .775 r
F P
0 g
s
.51335 1.33416 m .51337 1.33426 L .51326 1.31855 L p .618 .118 1 r
F P
0 g
s
.51326 1.31855 m .51316 1.31846 L .51335 1.33416 L p .618 .118 1 r
F P
0 g
s
.51332 1.334 m .51335 1.33416 L .51316 1.31846 L p .618 .118 1 r
F P
0 g
s
.51316 1.31846 m .513 1.31832 L .51332 1.334 L p .618 .118 1 r
F P
0 g
s
.51326 1.33373 m .51332 1.334 L .513 1.31832 L p .618 .118 1 r
F P
0 g
s
.513 1.31832 m .51275 1.31808 L .51326 1.33373 L p .618 .118 1 r
F P
0 g
s
.51317 1.33329 m .51326 1.33373 L .51275 1.31808 L p .618 .118 1 r
F P
0 g
s
.51275 1.31808 m .51232 1.31769 L .51317 1.33329 L p .618 .118 1 r
F P
0 g
s
.51301 1.33257 m .51317 1.33329 L .51232 1.31769 L p .618 .118 1 r
F P
0 g
s
.51232 1.31769 m .51162 1.31705 L .51301 1.33257 L p .618 .118 1 r
F P
0 g
s
.83537 1.04316 m .81007 1.05043 L .72943 .97897 L p .894 .056 .779 r
F P
0 g
s
.51276 1.33137 m .51301 1.33257 L .51162 1.31705 L p .618 .118 1 r
F P
0 g
s
.51162 1.31705 m .51046 1.31598 L .51276 1.33137 L p .618 .118 1 r
F P
0 g
s
.49151 1.29859 m .50016 1.30653 L .49189 1.29431 L p .53 .03 .651 r
F P
0 g
s
.49189 1.29431 m .47787 1.28862 L .49151 1.29859 L p .53 .03 .651 r
F P
0 g
s
.51234 1.32939 m .51276 1.33137 L .51046 1.31598 L p .617 .117 1 r
F P
0 g
s
.51046 1.31598 m .50854 1.31423 L .51234 1.32939 L p .617 .117 1 r
F P
0 g
s
.61198 .92854 m .57182 1.00088 L .4922 .98183 L p .939 .051 .755 r
F P
0 g
s
.4922 .98183 m .47759 .90631 L .61198 .92854 L p .939 .051 .755 r
F P
0 g
s
.51165 1.32611 m .51234 1.32939 L .50854 1.31423 L p .614 .114 1 r
F P
0 g
s
.50854 1.31423 m .50539 1.31133 L .51165 1.32611 L p .614 .114 1 r
F P
0 g
s
.3512 1.23723 m .41593 1.26349 L .3943 1.26965 L p .996 .068 .84 r
F P
0 g
s
.3943 1.26965 m .31622 1.25798 L .3512 1.23723 L p .996 .068 .84 r
F P
0 g
s
.57182 1.00088 m .61198 .92854 L .72943 .97897 L p .921 .05 .75 r
F P
0 g
s
.51355 1.34997 m .51349 1.35007 L .51337 1.33426 L p .68 .18 1 r
F P
0 g
s
.51337 1.33426 m .51335 1.33416 L .51355 1.34997 L p .68 .18 1 r
F P
0 g
s
.51364 1.34982 m .51355 1.34997 L .51335 1.33416 L p .68 .18 1 r
F P
0 g
s
.51335 1.33416 m .51332 1.334 L .51364 1.34982 L p .68 .18 1 r
F P
0 g
s
.5138 1.34956 m .51364 1.34982 L .51332 1.334 L p .679 .179 1 r
F P
0 g
s
.51332 1.334 m .51326 1.33373 L .5138 1.34956 L p .679 .179 1 r
F P
0 g
s
.51405 1.34914 m .5138 1.34956 L .51326 1.33373 L p .678 .178 1 r
F P
0 g
s
.51326 1.33373 m .51317 1.33329 L .51405 1.34914 L p .678 .178 1 r
F P
0 g
s
.51052 1.3207 m .51165 1.32611 L .50539 1.31133 L p .597 .097 .987 r
F P
0 g
s
.50539 1.31133 m .50016 1.30653 L .51052 1.3207 L p .597 .097 .987 r
F P
0 g
s
.51448 1.34844 m .51405 1.34914 L .51317 1.33329 L p .676 .176 1 r
F P
0 g
s
.51317 1.33329 m .51301 1.33257 L .51448 1.34844 L p .676 .176 1 r
F P
0 g
s
.47713 1.2854 m .49151 1.29859 L .47787 1.28862 L p 1 .014 .572 r
F P
0 g
s
.47787 1.28862 m .45461 1.27918 L .47713 1.2854 L p 1 .014 .572 r
F P
0 g
s
.79117 .98192 m .83537 1.04316 L p .72943 .97897 L .894 .056 .779 r
F P
0 g
s
.51517 1.34729 m .51448 1.34844 L .51301 1.33257 L p .67 .17 1 r
F P
0 g
s
.51301 1.33257 m .51276 1.33137 L .51517 1.34729 L p .67 .17 1 r
F P
0 g
s
.51632 1.34539 m .51517 1.34729 L .51276 1.33137 L p 1 0 .5 r
F P
0 g
s
.51276 1.33137 m .51234 1.32939 L .51632 1.34539 L p 1 0 .5 r
F P
0 g
s
.51822 1.34224 m .51632 1.34539 L .51234 1.32939 L p 1 0 .5 r
F P
0 g
s
.51234 1.32939 m .51165 1.32611 L .51822 1.34224 L p 1 0 .5 r
F P
0 g
s
.50863 1.31174 m .51052 1.3207 L .50016 1.30653 L p 1 0 .5 r
F P
0 g
s
.50016 1.30653 m .49151 1.29859 L .50863 1.31174 L p 1 0 .5 r
F P
0 g
s
.51372 1.3659 m .5136 1.36597 L .51349 1.35007 L p 1 0 .5 r
F P
0 g
s
.51349 1.35007 m .51355 1.34997 L .51372 1.3659 L p 1 0 .5 r
F P
0 g
s
.51393 1.36577 m .51372 1.3659 L .51355 1.34997 L p 1 0 .5 r
F P
0 g
s
.51355 1.34997 m .51364 1.34982 L .51393 1.36577 L p 1 0 .5 r
F P
0 g
s
.51428 1.36556 m .51393 1.36577 L .51364 1.34982 L p 1 0 .5 r
F P
0 g
s
.51364 1.34982 m .5138 1.34956 L .51428 1.36556 L p 1 0 .5 r
F P
0 g
s
.51484 1.36522 m .51428 1.36556 L .5138 1.34956 L p 1 0 .5 r
F P
0 g
s
.5138 1.34956 m .51405 1.34914 L .51484 1.36522 L p 1 0 .5 r
F P
0 g
s
.51578 1.36466 m .51484 1.36522 L .51405 1.34914 L p 1 0 .5 r
F P
0 g
s
.51405 1.34914 m .51448 1.34844 L .51578 1.36466 L p 1 0 .5 r
F P
0 g
s
.52137 1.33705 m .51822 1.34224 L .51165 1.32611 L p 1 0 .5 r
F P
0 g
s
.51165 1.32611 m .51052 1.3207 L .52137 1.33705 L p 1 0 .5 r
F P
0 g
s
.51733 1.36373 m .51578 1.36466 L .51448 1.34844 L p 1 0 .5 r
F P
0 g
s
.51448 1.34844 m .51517 1.34729 L .51733 1.36373 L p 1 0 .5 r
F P
0 g
s
.24178 1.19284 m .3512 1.23723 L .31622 1.25798 L p .955 .068 .839 r
F P
0 g
s
.31622 1.25798 m .18605 1.23853 L .24178 1.19284 L p .955 .068 .839 r
F P
0 g
s
.51987 1.36219 m .51733 1.36373 L .51517 1.34729 L p 1 0 .5 r
F P
0 g
s
.51517 1.34729 m .51632 1.34539 L .51987 1.36219 L p 1 0 .5 r
F P
0 g
s
.45313 1.26337 m .47713 1.2854 L .45461 1.27918 L p 1 .044 .721 r
F P
0 g
s
.45461 1.27918 m .41593 1.26349 L .45313 1.26337 L p 1 .044 .721 r
F P
0 g
s
.52408 1.35966 m .51987 1.36219 L .51632 1.34539 L p 1 0 .5 r
F P
0 g
s
.51632 1.34539 m .51822 1.34224 L .52408 1.35966 L p 1 0 .5 r
F P
0 g
s
.51385 1.38192 m .51368 1.38197 L .5136 1.36597 L p .961 0 .5 r
F P
0 g
s
.5136 1.36597 m .51372 1.3659 L .51385 1.38192 L p .961 0 .5 r
F P
0 g
s
.51414 1.38185 m .51385 1.38192 L .51372 1.3659 L p .961 0 .5 r
F P
0 g
s
.51372 1.3659 m .51393 1.36577 L .51414 1.38185 L p .961 0 .5 r
F P
0 g
s
.51463 1.38172 m .51414 1.38185 L .51393 1.36577 L p .961 0 .5 r
F P
0 g
s
.51393 1.36577 m .51428 1.36556 L .51463 1.38172 L p .961 0 .5 r
F P
0 g
s
.50549 1.29682 m .50863 1.31174 L .49151 1.29859 L p 1 0 .5 r
F P
0 g
s
.49151 1.29859 m .47713 1.2854 L .50549 1.29682 L p 1 0 .5 r
F P
0 g
s
.51542 1.38151 m .51463 1.38172 L .51428 1.36556 L p .961 0 .5 r
F P
0 g
s
.51428 1.36556 m .51484 1.36522 L .51542 1.38151 L p .961 0 .5 r
F P
0 g
s
.52657 1.32844 m .52137 1.33705 L .51052 1.3207 L p 1 0 .5 r
F P
0 g
s
.51052 1.3207 m .50863 1.31174 L .52657 1.32844 L p 1 0 .5 r
F P
0 g
s
.51673 1.38117 m .51542 1.38151 L .51484 1.36522 L p .961 0 .5 r
F P
0 g
s
.51484 1.36522 m .51578 1.36466 L .51673 1.38117 L p .961 0 .5 r
F P
0 g
s
.51889 1.3806 m .51673 1.38117 L .51578 1.36466 L p .961 0 .5 r
F P
0 g
s
.51578 1.36466 m .51733 1.36373 L .51889 1.3806 L p .961 0 .5 r
F P
0 g
s
.53104 1.35547 m .52408 1.35966 L .51822 1.34224 L p 1 0 .5 r
F P
0 g
s
.51822 1.34224 m .52137 1.33705 L .53104 1.35547 L p 1 0 .5 r
F P
0 g
s
.52245 1.37966 m .51889 1.3806 L .51733 1.36373 L p .96 0 .5 r
F P
0 g
s
.51733 1.36373 m .51987 1.36219 L .52245 1.37966 L p .96 0 .5 r
F P
0 g
s
.52833 1.37812 m .52245 1.37966 L .51987 1.36219 L p .956 0 .5 r
F P
0 g
s
.51987 1.36219 m .52408 1.35966 L .52833 1.37812 L p .956 0 .5 r
F P
0 g
s
.53803 1.37556 m .52833 1.37812 L .52408 1.35966 L p .949 0 .5 r
F P
0 g
s
.52408 1.35966 m .53104 1.35547 L .53803 1.37556 L p .949 0 .5 r
F P
0 g
s
.54255 1.34854 m .53104 1.35547 L .52137 1.33705 L p 1 0 .5 r
F P
0 g
s
.52137 1.33705 m .52657 1.32844 L .54255 1.34854 L p 1 0 .5 r
F P
0 g
s
.53523 1.31413 m .52657 1.32844 L .50863 1.31174 L p 1 0 .5 r
F P
0 g
s
.50863 1.31174 m .50549 1.29682 L .53523 1.31413 L p 1 0 .5 r
F P
0 g
s
.55407 1.37134 m .53803 1.37556 L .53104 1.35547 L p .937 .002 .508 r
F P
0 g
s
.53104 1.35547 m .54255 1.34854 L .55407 1.37134 L p .937 .002 .508 r
F P
0 g
s
.41272 1.22628 m .45313 1.26337 L .41593 1.26349 L p 1 .056 .78 r
F P
0 g
s
.41593 1.26349 m .3512 1.23723 L .41272 1.22628 L p 1 .056 .78 r
F P
0 g
s
.50023 1.27188 m .50549 1.29682 L .47713 1.2854 L p 1 .031 .656 r
F P
0 g
s
.47713 1.2854 m .45313 1.26337 L .50023 1.27188 L p 1 .031 .656 r
F P
0 g
s
.1268 1.1839 m .19291 1.17301 L p .18605 1.23853 L .93 .067 .835 r
F P
0 g
s
.19291 1.17301 m .24178 1.19284 L .18605 1.23853 L p .93 .067 .835 r
F P
0 g
s
.18605 1.23853 m .00746 1.21183 L .1268 1.1839 L p .93 .067 .835 r
F P
0 g
s
.56166 1.33703 m .54255 1.34854 L .52657 1.32844 L p 1 .007 .535 r
F P
0 g
s
.52657 1.32844 m .53523 1.31413 L .56166 1.33703 L p 1 .007 .535 r
F P
0 g
s
.58063 1.36436 m .55407 1.37134 L .54255 1.34854 L p .935 .018 .589 r
F P
0 g
s
.54255 1.34854 m .56166 1.33703 L .58063 1.36436 L p .935 .018 .589 r
F P
0 g
s
.36564 .89267 m .47099 .87215 L p .35025 .91395 L .922 .058 .791 r
F P
0 g
s
.47099 .87215 m .47759 .90631 L .35025 .91395 L p .922 .058 .791 r
F P
0 g
s
.35025 .91395 m .33597 .89968 L .36564 .89267 L p .922 .058 .791 r
F P
0 g
s
.5497 1.2902 m .53523 1.31413 L .50549 1.29682 L p 1 .026 .631 r
F P
0 g
s
.50549 1.29682 m .50023 1.27188 L .5497 1.2902 L p 1 .026 .631 r
F P
0 g
s
.62472 1.35276 m .58063 1.36436 L .56166 1.33703 L p .929 .032 .662 r
F P
0 g
s
.72943 .97897 m .76867 .9532 L .79117 .98192 L p .894 .056 .779 r
F P
0 g
s
.76867 .9532 m .72943 .97897 L .61198 .92854 L p .907 .055 .777 r
F P
0 g
s
.56166 1.33703 m .59353 1.31784 L .62472 1.35276 L p .929 .032 .662 r
F P
0 g
s
.59353 1.31784 m .56166 1.33703 L .53523 1.31413 L p .995 .027 .637 r
F P
0 g
s
.53523 1.31413 m .5497 1.2902 L .59353 1.31784 L p .995 .027 .637 r
F P
0 g
s
.49137 1.22977 m .50023 1.27188 L .45313 1.26337 L p 1 .047 .736 r
F P
0 g
s
.45313 1.26337 m .41272 1.22628 L .49137 1.22977 L p 1 .047 .736 r
F P
0 g
s
.69824 1.33341 m .62472 1.35276 L .59353 1.31784 L p .922 .044 .72 r
F P
0 g
s
.34372 1.16295 m .41272 1.22628 L .3512 1.23723 L p .969 .061 .805 r
F P
0 g
s
.3512 1.23723 m .24178 1.19284 L .34372 1.16295 L p .969 .061 .805 r
F P
0 g
s
.59353 1.31784 m .64705 1.28561 L .69824 1.33341 L p .922 .044 .72 r
F P
0 g
s
.64705 1.28561 m .59353 1.31784 L .5497 1.2902 L p .962 .042 .708 r
F P
0 g
s
.73427 .90621 m .76867 .9532 L p .61198 .92854 L .907 .055 .777 r
F P
0 g
s
.57412 1.24984 m .5497 1.2902 L .50023 1.27188 L p .999 .042 .712 r
F P
0 g
s
.50023 1.27188 m .49137 1.22977 L .57412 1.24984 L p .999 .042 .712 r
F P
0 g
s
.61023 .83848 m .66929 .82531 L p .47759 .90631 L .917 .056 .781 r
F P
0 g
s
.66929 .82531 m .61198 .92854 L .47759 .90631 L p .917 .056 .781 r
F P
0 g
s
.47759 .90631 m .47099 .87215 L .61023 .83848 L p .917 .056 .781 r
F P
0 g
s
.61198 .92854 m .66929 .82531 L .73427 .90621 L p .907 .055 .777 r
F P
0 g
s
.5497 1.2902 m .57412 1.24984 L .64705 1.28561 L p .962 .042 .708 r
F P
0 g
s
.82177 1.30091 m .69824 1.33341 L .64705 1.28561 L p .915 .052 .76 r
F P
0 g
s
.47615 1.1575 m .49137 1.22977 L .41272 1.22628 L p .971 .055 .777 r
F P
0 g
s
.41272 1.22628 m .34372 1.16295 L .47615 1.1575 L p .971 .055 .777 r
F P
0 g
s
.64705 1.28561 m .73809 1.2308 L .82177 1.30091 L p .915 .052 .76 r
F P
0 g
s
.73809 1.2308 m .64705 1.28561 L .57412 1.24984 L p .94 .051 .755 r
F P
0 g
s
.23784 1.16334 m .32882 1.14928 L p .24178 1.19284 L .939 .063 .816 r
F P
0 g
s
.32882 1.14928 m .34372 1.16295 L .24178 1.19284 L p .939 .063 .816 r
F P
0 g
s
.24178 1.19284 m .19291 1.17301 L .23784 1.16334 L p .939 .063 .816 r
F P
0 g
s
.8481 1.29399 m .82177 1.30091 L .73809 1.2308 L p .91 .057 .787 r
F P
0 g
s
.61596 1.18067 m .57412 1.24984 L .49137 1.22977 L p .959 .052 .76 r
F P
0 g
s
.49137 1.22977 m .47615 1.1575 L .61596 1.18067 L p .959 .052 .76 r
F P
0 g
s
.57412 1.24984 m .61596 1.18067 L .73809 1.2308 L p .94 .051 .755 r
F P
0 g
s
.80231 1.23404 m .8481 1.29399 L p .73809 1.2308 L .91 .057 .787 r
F P
0 g
s
.35967 1.14285 m .46925 1.12476 L p .34372 1.16295 L .941 .06 .8 r
F P
0 g
s
.46925 1.12476 m .47615 1.1575 L .34372 1.16295 L p .941 .06 .8 r
F P
0 g
s
.34372 1.16295 m .32882 1.14928 L .35967 1.14285 L p .941 .06 .8 r
F P
0 g
s
.73809 1.2308 m .77899 1.20617 L .80231 1.23404 L p .91 .057 .787 r
F P
0 g
s
.77899 1.20617 m .73809 1.2308 L .61596 1.18067 L p .924 .057 .784 r
F P
0 g
s
.74331 1.16018 m .77899 1.20617 L p .61596 1.18067 L .924 .057 .784 r
F P
0 g
s
.61425 1.09372 m .67581 1.08174 L p .47615 1.1575 L .935 .058 .789 r
F P
0 g
s
.67581 1.08174 m .61596 1.18067 L .47615 1.1575 L p .935 .058 .789 r
F P
0 g
s
.47615 1.1575 m .46925 1.12476 L .61425 1.09372 L p .935 .058 .789 r
F P
0 g
s
.61596 1.18067 m .67581 1.08174 L .74331 1.16018 L p .924 .057 .784 r
F P
0 g
s
.25 Mabswid
.64829 0 m
.92355 .39114 L
s
.92355 .39114 m
1 1.45231 L
s
1 1.45231 m
.67666 1.11531 L
s
.67666 1.11531 m
.64829 0 L
s
.08437 .22162 m
0 1.30791 L
s
0 1.30791 m
.67666 1.11531 L
s
.67666 1.11531 m
.64829 0 L
s
.64829 0 m
.08437 .22162 L
s
0 1.30791 m
.37715 1.60465 L
s
.07747 1.36886 m
.07813 1.3588 L
s
gsave
.07615 1.38898 -66.6597 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.19926 1.46469 m
.19973 1.45462 L
s
gsave
.19833 1.48483 -64.6952 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.31272 1.55396 m
.31302 1.54389 L
s
gsave
.31213 1.57411 -64.6989 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.10254 1.38859 m
.10291 1.38255 L
s
.12724 1.40803 m
.12759 1.40199 L
s
.1516 1.42719 m
.15192 1.42115 L
s
.1756 1.44607 m
.1759 1.44003 L
s
.22259 1.48305 m
.22285 1.47701 L
s
.2456 1.50115 m
.24584 1.49511 L
s
.26828 1.519 m
.2685 1.51295 L
s
.29066 1.5366 m
.29085 1.53056 L
s
.05203 1.34884 m
.05245 1.34281 L
s
.02621 1.32853 m
.02665 1.3225 L
s
.33449 1.57109 m
.33465 1.56504 L
s
.35596 1.58798 m
.3561 1.58194 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[71]:=",
  FormatType->StandardForm,
  ImageSize->{107.5, 172.438},
  ImageMargins->{{138, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001[0000[1000`40O003h00OJgoo001[Ool006]o
o`00Jgoo001[Ool006]oo`00B7oo0P008Goo0015Ool300000goo001oo`0POol004=oo`8000Aoo`80
021oo`00@7oo0`001Woo00<007oo00007goo000mOol30009Ool00`00Ool0000OOol003]oo`8000ao
o`04001oogoo000NOol003Qoo`<000ioo`05001oogooOol0000MOol003Ioo`80015oo`03001oogoo
009oo`03001oogoo01Yoo`00<goo0`004goo00<007ooOol00Woo00<007ooOol06Woo000aOol2000F
Ool00`00Oomoo`03Ool00`00Oomoo`0IOol002ioo`<001Qoo`03001oogoo00Aoo`03001oogoo01Qo
o`00:goo0`006goo00<007ooOol017oo00<007ooOol067oo000YOol2000NOol00`00Oomoo`05Ool0
0`00Oomoo`0GOol002Ioo`<0021oo`03001oogoo00Ioo`03001oogoo01Ioo`0097oo0P008goo00<0
07ooOol01Woo00<007ooOol05Woo000QOol3000UOol00`00Oomoo`07Ool00`00Oomoo`0EOol001mo
o`8002Moo`8000Yoo`03001oogoo01Aoo`0077oo0`009Woo0`0000=`>000Ool02Woo00<007ooOol0
4goo000IOol3000VOol30003L3P3000:Ool00`00Oomoo`0COol001Moo`8002Eoo`@000I`>0800003
K3P007oo00Uoo`03001oogoo019oo`0057oo0`008goo10002G0h00<006`h00000V`h00<007ooOol0
1Woo0`004goo000COol2000ROol3000=L3P00`00K3P00002K3P00`00Oomoo`03Ool300000fPh0000
000COol001=oo`03001oogoo01ioo`<00003L3P0070h00a`>004001/>6`h0003K3P00`00Ool00002
0002J3L00`00J3QX>002000BOol000aoo`8000Eoo`8001aoo`<000A`>003001`>70h00]`>004001/
>6`h0004K3P00`00J3MX=`04J3L01@00J3P007oo00004Goo000<Ool00`00Ool00004Ool00`00Ool0
000HOol30008L3P00`00L3Q`>00:L3P01000K3Q/>0001F`h00<006PgJ3L00fPg00H006PhJ3P007oo
000@Ool000aoo`03001oo`0000Aoo`04001oogoo000BOol50006L3P90008L3P01@00K3Q/>6`h0000
1F`h00<006PgJ3L00fPg00@006PhJ3QX>080011oo`003Goo0P0017oo00D007ooOomoo`0000aoo`D0
00A`>0L000E`>004001`=g0gL3L50003L3P01@00K3Q/>6`h00001V`h00<006PgJ3L00fPg00@006Ph
J3QX>08000moo`004Woo0P0017oo00<007ooOol01goo0P001g0h0P0000=`>000L3P02G0h00<0070g
L3L01W0g0`001F`h00<006`hK3P00f`h00<006PgJ3L00fPg00<006PhJ3P00VPh0P003Woo000BOol0
0`00Oomoo`04Ool00`00Oomoo`03Ool40005L3P30004L3P00`00L3Q`>007L3P00`00L3M`=`08L3L0
1000L3L000000V`h00<006`hK3P00f`h00<006PgJ3L00fPg00@006PhJ3QX>0<000ioo`004Woo00<0
07ooOol01Goo1@0016`i0P0000=`>0000000270h00<0070hL3P01W0h00<0070gL3L01g0g00<0070g
L3L00g0g0P001V`h2@000VPh0P003Goo000BOol00`00Oomoo`02Ool3000;K3T2000:L3P00`00L3Q`
>006L3P00`00L3M`=`06L3L00`00L3M`=`04L3L4000016`h001/>0001FPh00<006PhJ3P00fPh0P00
37oo000BOol00`00Ool00002000>K3T01000L3T00000270h00<0070hL3P01W0h00<0070gL3L01G0g
00<0070gL3L01G0g00D0070gL3M`=`0000=/>003001X>6Ph009X>003001X>6Ph00AX>003001oogoo
00Yoo`004Woo10003V`i00<0070iL3T00W0i0P001g0h00<0070hL3P01G0h00<0070gL3L01G0g00<0
070gL3L01G0g00<0070g00000V`g00D006`hK3Q/>000009X>003001X>6Ph00EX>08000]oo`004Woo
0P000V`i1@0026`i00<0070iL3T01G0i00<0070hL3P0170h3@000g0g00<0070gL3L01G0g0P0016`g
00@006`hK3P0009X>003001X>6Ph00IX>08000Yoo`004Woo00<007oo00001V`i1@000V`i00<0070i
L3T01g0i0P0000A`>0000000009h>003001d=g@g00=d=`03001d=W@f009d=P<000Q`=`03001/=f`g
00A/=`06001/>6`h001X>00026Ph00<007oo00002Goo000BOol01000Oomoo`002V`i1@00270i1000
17Ph00<007@gM3L00W@g00<007@fM3H017@f00@0070f000000=`=`<000M/=`03001/>6`h008000UX
>08000Uoo`004Woo00D007ooOomoo`0000Y/>@04001/FVaJK5X50002L3T00`00M3Ud>@02M3T30002
N3P00`00M3Md=`02M3L00`00M3Id=P02M3H00`00L3I`=P02L3H300000g0h00000008K3L00`00K3P0
000;J3P20008Ool0019oo`03001oogoo009oo`03001/>F`i00M/>@03001/FVaJ00I/FP@000Id>@T0
00=d=P03001`=P00008000=`>003001`>00000U/=`04001/>0000009J3P30007Ool0019oo`03001o
ogoo00=oo`03001/>F`i00I/>@03001/FVaJ00M/FP03001`Fg1K00<0009d>@06001l>G`i001l=`00
0W`e00<007PD000010001W0h00@0070h000000U/=`P000EX>08000Moo`004Woo00<007ooOol017oo
00<006`iK3T016`i00<006aJK5X026aJ00<0071KL5/00g1K3@002G0h00H0070hL3P0070h0004K3L3
000016`h001/>0001FPi1`001goo000BOol00`00Oomoo`05Ool00`00K3U/>@03K3T00`00K5Y/FP08
K5X01000L5]`Fg1K1P0000=dG00000000P003G0h00H0070hL3P0070h0002K3L20005K3P00`00K3P0
0009J3T20007Ool0015oo`03001oogoo00Moo`03001/>F`i014000=/F`03001/GP0000800003L3P0
070h00a`>005001`>70hL3P00002L3P20007K3P00`00K3P00006J3T300000goo001oo`06Ool0015o
o`03001oogoo00Qoo`80009/FP03001/FVaJ00Q/FP03001/FfaK00=/F`<000A`>003001`>70h00]`
>005001`>70hL3P00003L3P00`00K3Q/>005K3P01000K3Q/>0000fPi0P0017oo00<007ooOol01Goo
000AOol00`00Oomoo`0:Ool3K5X00`00K5Y/FP06K5X70008L3P00`00L3Q`>00:L3P01@00L3Q`>70h
0000170h00<006`hK3P01F`h00<006`hK3P00`001Woo00<007ooOol01Goo000AOol2000<Ool3K5X0
1000K5Y/FVaJ10000W0i00<0070hL3P0170h2P00270h00<0070hL3P00W0h00<0070hL3P00W0h00<0
06`hK3P01F`h00D006`hK3Q/>00000Moo`03001oogoo00Eoo`004Goo00<007ooOol037oo00<006aJ
00000`001W0i1`001W@h00@007@gM3Md=`D000=`>003001`>70h009`>003001`>70h00=`>003001/
>6`h00A/>003001/>6`h009/>003001oogoo00Eoo`03001oogoo00Aoo`004Goo00<007ooOol02goo
0`00270i0P0000=d>000M3P02W@h00<007@gM3L01W@g0`001G0h00<0070hL3P0170h00<006`hK3P0
16`h00<006`hK3P00`001Woo00<007ooOol017oo000AOol00`00Oomoo`08Ool30003L3T20004L3T2
0004M3P00`00M3Qd>008M3P00`00M3Md=`08M3L01000L3L000000W0h00<0070hL3P0170h2P000VPh
00<007ooOol017oo00<007ooOol017oo000AOol00`00Oomoo`05Ool30008L3T01000L3T000001g@h
00<007@hM3P01g@h00<007@gM3L01g@g00<0070gL3L00W0g0`001g0h00<006PhJ3P00fPh00<006Ph
J3P00fPh00<007ooOol00goo00<007ooOol017oo000AOol00`00Oomoo`02Ool3000<L3T20009M3P0
0`00M3Qd>007M3P00`00M3Md=`06M3L00`00L3M`=`04L3L30004L3P20005J3P00`00J3QX>004J3P0
0`00Oomoo`02Ool00`00Oomoo`04Ool0015oo`D000i`>@03001`>G0i008000Qd>003001d>7@h00Id
>003001d=g@g00Ed=`03001`=g0g00E`=`03001`=g0g00800005L3P006`hK3P00003J3P00`00J3QX
>005J3P00`00Oomoo`02Ool00`00Oomoo`04Ool0015oo`@000i`>@03001`>G0i00=`>@<000Id>003
001d>7@h00Ed>003001d=g@g00Ed=`03001`=g0g00E`=`03001`=g0g009`=`03001/>6`h009/>004
001X>6Ph0008J3P01@00Oomoogoo00001Woo0008Ool01000Ool000001Goo0P000VaJ1@00270i00<0
070iL3T01g0i0P000g@h3P000g@g00<0070gL3L01G0g00@0070gL3L0009/=`05001/>6`hK3P00002
J3P00`00J3QX>006J3P01@00Oomoogoo00001Woo0008Ool01@00Ool007oo000017oo00<007oo0000
1VaJ1@000W0i00<0070iL3T02W0i0`000gPh00<007PgN3L00gPg00<007@fM3H00W@f0`00270g0`00
16`g00L006`hK3Q/>000J3P00009J3P01000Oomoo`001Woo0008Ool01@00Ool007oo00000goo00D0
07ooOomoo`0000Y/FPD000U`>@03001h>GPi008000=h>003001h=gPg009h=`03001d=W@f00Ad=P04
001d=P000004L3L20007K3L01@00K3Q/>6`h00002fPh00<007oo00001Woo0008Ool00`00Oomoo`02
0003Ool00`00Oomoo`03Ool:K5X01000L5Y`FW1J1@000g0i00<007PiN3T00gPi00D007PhN3Qh>000
00Ah=`03001d=W@f009d=P03001d=W@f009d=P800004L3L006`g0008K3L00`00K3Q/>0050007J3P0
0`00Ool00006Ool0011oo`8000Eoo`03001/FVaJ00I/FP03001`FW1J00I`FPL000=h>@/0009d=P03
001d=W@f00Ad=P04001/=`000009K3L01000K3Q/>0000fPi1`0000=X>00000001Woo000@Ool00`00
Oomoo`05Ool00`00K5Y/FP05K5X00`00L5Y`FP08L5X00`00L5]`F`02L5/700001G`g001l=G`e0000
0W`D0P001W@f0`0000=`>000K3L02F`g00@006`h000000UX>@<000Ioo`0047oo00<007ooOol01Woo
00<006aJK5X00faJ00<0071JL5X0271J00<0071KL5/01G1K2P000g`D00@007PD001d=P<000=`>0<0
00Y/=`03001/>00000MX>@<00003Ool007oo00Eoo`0047oo00<007ooOol01goo00<006aJK5X00VaJ
00<0071JL5X00g1J3P000faN3@001W0h0P0000=`>000K3L00V`g10000V`h00@006`hK3P000AX>@80
00Aoo`03001oogoo00Aoo`0047oo00<007ooOol027oo2P001VaK00<006aLK5`01FaL0P0000ATO`00
H5iPGPD000Y`>003001`>000009`>0<000M/>004001/>000J3T30007Ool00`00Oomoo`03Ool0011o
o`03001oogoo00Yoo`9/FP03001/FfaK00Y/F`03001/G6aL00<000=XG0D000i`>003001`>000009`
>003001/>6`h00M/>004001/>6`h000:Ool00`00Oomoo`03Ool0011oo`03001oogoo00]oo`9/FP03
001/FfaK00Y/F`80009XG0D0009`>@03001`>70h00a`>004001`>70h0003L3P00`00K3Q/>006K3P0
1@00K3Q/>6`h00002Goo00<007ooOol00goo000@Ool00`00Oomoo`0<Ool00`00K5X00006K5/30002
J5/40007L3T00`00L3Q`>00<L3P01000L3Q`>000170h00<006`hK3P01V`h00D006`hK3Q/>00000Qo
o`03001oogoo00=oo`0047oo00<007ooOol03Goo00<006aJ00000VaK0`0000=XF`0000000P001W0i
2@002W0h00D0070hL3Q`>00000E`>003001/>6`h00E/>003001/>6`h009/>003001oogoo00Eoo`03
001oogoo00=oo`0047oo00<007ooOol03Goo00<006aJ00001P000g0i1`001G@h00@007@gM3Md=`L0
00=`>005001`>70hL3P00005L3P00`00K3Q/>005K3P01000K3Q/>6`h0`001Woo00<007ooOol00goo
000@Ool00`00Oomoo`0>Ool40005L3T200000g@i001d>009M3P00`00M3Md=`08M3L30004L3P00`00
L3Q`>004L3P;0002K3T00`00Oomoo`04Ool00`00Oomoo`03Ool000moo`03001oogoo00]oo`@000I`
>@<000Ad>@03001d>7@h00Qd>003001d=g@g00Ud=`03001`=`00009`>003001`>70h00E`>003001X
>6Ph00AX>003001/>F`i00=/>@03001oogoo00=oo`03001oogoo00=oo`003goo00<007ooOol01Woo
1@00171J0`0000=`>@00000027@i00<007@hM3P01g@h00<007@gM3L027@g00<0070gL3L00W0g0P00
1g0h00<006PhJ3P016Ph00<006`iK3T016`i00<007ooOol00Woo00<007ooOol00goo000?Ool20003
Ool4000<L5X2000:M3T00`00M3Qd>006M3P00`00M3Md=`08M3L00`00L3M`=`03L3L30006L3P00`00
J3QX>002J3P00`00K3U/>@05K3T00`00Oomoo`02Ool00`00Oomoo`03Ool000moo`03001oo`000080
00m`FP03001dFWAJ008000Ud>@03001d>7@h00Ed>003001d=g@g00Md=`03001`=g0g00A`=`03001`
=g0g00800003L3P00000009`>005001X>6PhJ3P00008K3T01@00Oomoogoo00001Goo000?Ool4000?
L5X00`00M5YdFP03M5X30007M3T00`00M3Qd>005M3P00`00M3Md=`06M3L00`00L3M`=`04L3L00`00
L3M`=`02L3L00`00L3Q`>003L3P01000J3QX>00026`i00D007ooOomoo`0000Eoo`003goo0P000W1J
1@002G1J00<007AJM5X01gAJ0P000g@i3@001G@g00<0070gL3L01G0g00@0070gL3L000=`=`A`>004
001X>6Ph0009K3T01000Oomoo`001Goo000?Ool00`00Ool00006L5X50003L5X00`00M5YdFP0:M5X3
0003O3P00`00O3Ml=`04O3L00`00N3Ih=P030002M3L00`00L3M`=`05L3L00`00L3L00005L3L01000
L3Q`>70h0P002f`i00<007oo00001Goo000?Ool01000Oomoo`002W1J1P002GAJ00<007QJN5X00P00
0g`h00<007`gO3L00g`g00<007PfN3H00gPf0P00270g0P001g0g00@0070hL3Q`>0D000Q/>@03001o
o`0000Aoo`003goo00<007ooOol00Woo2g1J00@0071JL5Y`FPD000=dFP03001hFWQJ00=hFP80009l
>003001l=g`g00=l=`03001h=WPf00=h=P04001d=P000004L3L20009L3L01000L3Q`>00016Pi1`00
0V`i0P0017oo000?Ool00`00Oomoo`03Ool00`00L5Y`FP07L5X00`00L5Y`FP06L5X70003N5X:0004
N3H00`00M3Id=P02M3H20000170g001`=`002W0g00@0070hL3P000YX>@@000Aoo`003goo00<007oo
Ool017oo00<0071JL5X01G1J00<0071JL5X02G1J00<007AKM5/00WAK1@0000AlFP00000000=l=@06
001l5000001h=P001W@f00@0070gL3L000]`=`04001`>0000008J3T300000goo001oo`03Ool000mo
o`03001oogoo00Eoo`03001`FW1J00A`FP03001`FW1J00U`FP04001dFgAKM5/200000gAK00000009
0003O1@00`00M3Id=P03M3H01000L3I`=W0f0P00370g00@006`hK3P000AX>@<000Aoo`03001oogoo
009oo`003goo00<007ooOol01Woo00@0071JL5Y`FQ8000A/G@80009TO`03001POf1o00<00005O1@0
07`D001h500200000g@f001`=P02L3H40005L3L40002K3P01000K3Q/>6`h10001goo00<007ooOol0
0Woo000>Ool00`00Oomoo`08Ool30002K5X00`00K5]/F`0:K5/00`00K5e/G@030004J5d70002O140
0`00N1Ah5002N1@50003M3P00`00L3M`=`030007K3P01000K3Q/>0002Woo00<007ooOol00Woo000>
Ool00`00Oomoo`0:Ool4K5X00`00K5]/F`0:K5/20005J5d00`00I5eTG@03I5d01@00I5`00000O140
1@001g@h10002V`h00D006`hK3Q/>00000Uoo`03001oogoo009oo`003Woo0P0037oo00D006aJK5Y/
FP0000I/F`<000A/F`<00003J5d006AM00ATG@03001TG00000<000]d>005001d>000M3P0000:K3P0
1@00K3Q/>6`h00002Goo00<007ooOol00Woo000>Ool00`00Oomoo`0=Ool01000K5Y/FP000VaK0`00
2VaK100000=TG@0000000P003g@h00<007@h00000W@h00<006`hK3P026`h00D006`hK3Q/>00000Qo
o`03001oogoo009oo`0017oo0P0000=oo`0000001Goo00<007ooOol03Woo00<006aJK5X00P002faK
00<006QK000010000W@i00<007@hM3P03G@h00@007@hM3P000=d>003001/>6`h00M/>003001/>6`h
009/>003001oogoo00Eoo`03001oogoo009oo`001Goo00D007oo001oo`0000Aoo`03001oogoo00mo
o`04001/FfaKK5/20007K5/40007M3T00`00M3Qd>00=M3P01000M3Qd>00017@h00<006`hK3P01V`h
00<006`hK3P00V`h00<007ooOol01Goo00<007ooOol00Woo0006Ool200000goo001oo`03Ool00`00
Oomoo`0AOol01000K5]/FfaK1`002g@i00<007@hM3P037@h00D007@hM3Qd>00000Ed>003001/>6`h
00`000Ioo`03001oogoo009oo`001Goo0P0000=oo`00000017oo00<007ooOol03goo1`0017@i4@00
2W@h00<007@hM3P00W@h00<007@hM3P00g@h0`001V`h00<006`iK3T00V`i00<007ooOol017oo00<0
07ooOol00Woo000>Ool00`00Oomoo`0<Ool30008M3T300000gPi001h>00:N3P01000N3Qh>7Ph1`00
0g@h00<007@hM3P00W@h00<007@hM3P017@h00<006`hK3P01F`h00<006`iK3T00f`i00<007ooOol0
17oo00<007ooOol00Goo000>Ool00`00Oomoo`09Ool30003M5X30002M3T30005N3T00`00N3Qh>008
N3P00`00N3Qh>008N3P30005M3P00`00M3Qd>005M3P00`00K3Q/>003K3P00`00K3U/>@05K3T00`00
Oomoo`03Ool00`00Oomoo`01Ool000ioo`03001oogoo00Aoo`D000UdFP8000Uh>@03001h>7Ph00Qh
>003001h>7Ph00Uh>003001d=`0000800003M3P007@h00Id>003001/>6`h00=/>003001/>F`i00I/
>@03001oogoo009oo`03001oogoo005oo`003Woo00<007oo000010003GAJ00<007AJM5X00P0027Pi
00<007PhN3P01gPh00<007PhN3P027Ph00<007@gM3L00g@g0`001g@h00<006`hK3P00V`h00<006`i
K3T01f`i00D007ooOomoo`0000=oo`003Goo100047AJ00<007AJM5X00gAJ0P001gPi00<007PhN3P0
1WPh00<007PhN3P027Ph00<007@gM3L017@g00<007@g00000P0000Ed>000001`>00000A/>003001/
>F`i00Q/>@04001oogoo0003Ool000eoo`04001oog1JL5X60009M5X00`00M5YdFP06M5X20006N3T0
0`00N3Qh>006N3P00`00N3Qh>006N3P00`00M3Md=`05M3L00`00M3Md=`02M3L00`00L3Q`>002L3P0
1000K3Q/>00036`i00<007oo00000goo000=Ool01000Oomoo`001W1J1@000gAJ00<007AJM5X02GAJ
0P000gPi3@001GPh00<007@gM3L01W@g00@007@gM3L000M`>0L000Q/>@03001oo`0000=oo`003Goo
00D007ooOomoo`0000Y`FPH000YdFP@000Al>003001l=g`g00=l=`03001l=W`f00<0009h>003001d
=g@g00Id=`03001d=`0000Q`>003001X>@0000A/>@L0009/>@8000=oo`003Goo00<007ooOol00goo
2g1J00@007AKM5]dF`H000=dFP03001lFWaJ009lFP<0009l>003001l=g`g009l=`03001l=W`f00=l
=P8000Ud=`8000M`>004001`>70h000<K3T40003Ool000eoo`8000Eoo`03001`FW1J00M`FP03001d
FgAK00MdF`L000=lFPL00003O3L007`f00El=P03001h=P00008000Ad=`8000U`>004001`>70h000:
K3T300000goo001oo`02Ool000eoo`03001oogoo00Eoo`03001`FW1J00E`FP03001dFgAK00YdF`03
001dG7AL009dG0D00005O5X007`g001l=@020005O3H00`00N3Ih=P03N3H2000017@g001`>0002W0h
00<0070h00001f`i0`0017oo00<007ooOol00Goo000=Ool00`00Oomoo`06Ool00`00L5Y`FP04L5X0
0`00M5]dF`09M5/01000M5adG7AL3P0000Il5000000007`f0007N3H01000L3Q`>0002g0h00<0070h
00000f`i0`001goo00<007ooOol00Goo000=Ool00`00Oomoo`07Ool01000L5Y`FW1J4P001G1M0P00
0VAo100000=l4000O1@00W`D00<007PfN3H00gPf0P000g0f0P00370h1@002Woo00<007ooOol00Goo
000=Ool00`00Oomoo`08Ool30002L5/00`00L5a`G00;L5`00`00L5e`G@030004J5h20002I5d30000
1G`@001l5000O1@00P0000=h=P00L3H01G0f00<0070hL3P0170h10000W0h00D0070iL3U`>@0000Yo
o`03001oogoo005oo`003Goo00<007ooOol02Woo171K00<0071LL5`02g1L0P0016QN0P0016AM00@0
06AM0000009l4003001l57`D009l5003001`=W0f00E`=P80009`>0<000M`>004001`>G0i000:Ool0
0`00Oomoo`01Ool000eoo`03001oogoo00]oo`05001`Fg1KL5/00006L5`40004K5`200000fQN001T
G@05I5d02P00I5eTG@00O0l007`A001l50000W@e00@0070fL3I`=P@00003L3H0000000Y`>005001`
>G0iL3T0000:Ool10001Ool1Ool000aoo`8000moo`04001`Fg1K0002L5`3000:K5`;000016QK0000
07`A0P000W@e1@000g@i00<006`g00002g0h00D0070iL3U`>@0000Yoo`40005oo`5oo`003Goo00<0
07ooOol03Woo00<0071KL5/00P002VaL0P0026QL00<006QKJ5/00VQK00<007`?000010001g@i0`00
00=/=`00L3P02W0h00D0070iL3U`>@0000Uoo`40005oo`5oo`0037oo00<007ooOol047oo00@006aK
K5]/F`<000I/G003001XG6QL00MXG004001XFfQKJ5/4000;M3T300000g@i0000000;L3P00`00L3U`
>@02L3T00`00Oomoo`06Ool10001Ool1Ool000aoo`03001oogoo019oo`8000=/F`<00003K5`00000
00UXG0D000ad>@@00005M3T007@iM3T0000;L3P00`00L3U`>@02L3T00`00Oomoo`06Ool10001Ool1
Ool000aoo`03001oogoo01Aoo`03001/FfaK00=/F`04001XG0000003J5`50003N3T00`00M3Ud>@08
M3T30002M3T01@00M3Ud>G@i00000W@i00<0070hL3P00g0h30001goo0@000Goo0Goo000<Ool00`00
Oomoo`0EOol01@00K5]/FfaK00000faK100027Pi00<007@iM3T017@i10001G@i00<007@iM3T00W@i
00<007@iM3T01@001V`i00<006`iK3T00V`i00<007ooOol01Goo0@000Goo0Goo000<Ool00`00Oomo
o`0FOol70006N3T9000017@i0000000027@i00<007@iM3T017@i00@007@iM3T000U/>@03001/>F`i
00=/>@03001oogoo00Aoo`40005oo`5oo`0037oo00<007ooOol047oo1`0017QJ20001W`h20001W@i
00<007@iM3T01W@i00@007@iM3T000M/>@03001/>F`i00E/>@03001oogoo00=oo`40005oo`5oo`00
37oo00<007ooOol02goo1@0027QJ0`000g`i00<007`hO3P01G`h10001gPh10000W@i00<007@iM3T0
1g@i00<007@i00001f`i00<006`iK3T01V`i00<007ooOol00Woo0@000Goo0Goo000<Ool00`00Oomo
o`06Ool50005M5X30002N5X30007O3T01000O3Ql>7`h0`0017`h00<007PhN3P027Ph0P002g@i00<0
07@i00001V`i00<006`iK3T01f`i00D007ooOomoo`00009oo`0037oo00<007ooOol00Woo100037AJ
0`002W`i10001g`h00<007PhN3P02GPh00<007PhN3P00P0027@i00<007@i00001F`i00<006`iK3T0
26`i00@007ooOol0009oo`0037oo00<007oo00000P003gAJ00@007QJN5YhFP<000Al>@<0009l>@03
001l>7`h00Il>003001h>7Ph00Qh>003001h>7Ph00Ah>0<000Ed>@04001d>@000002K3T00`00K3U/
>@0:K3T00`00Ool00002Ool000aoo`D000idFP03001hFWQJ00EhFP@000Il>@03001l>7`h00Il>003
001h>7Ph00Ih>003001h>7Ph00Qh>0<00003M3T0000000800003J3T0000000D000U/>@80009oo`00
37oo00<007ooM5/00WAK2@0017AJ00<007QJN5X00gQJ100000AhFP00000000=l>@h000Ih>003001h
>7Ph00]h>004001d>G@iM3T20002J3T00`00K5Y/FP02K5X80002K3T20001Ool000aoo`04001oogoo
000:M5/:0007N5X40005O3P00`00O3Ml=`03O3L00`00O3Il=P030002N3P00`00N3Qh>00:N3P01000
M3Qd>7@h0g@i0`003FaJ10000Goo000;Ool20004Ool<M5/:0003N5X00`00O5YlFP02O5X30003O3P0
0`00O3Ml=`02O3L00`00O3Il=P03O3H2000;N3P20005M3P00`00M3Ud>@02000<K5X30001Ool10001
Ool0009oo`D000Aoo`03001oogoo00Aoo`8000IdF`@000UdF`L000=lFPP00003O3L007`f00El=P04
001h=P000007N3P00`00M3Qd>006M3P00`00M3Ud>@020008K5X30004Ool10001Ool000Aoo`800003
Ool007oo009oo`03001oogoo00Ioo`800004M5/000000002M5/00`00M5]dF`0:M5/00`00N5ahG002
N5`90002O1@20005O3H00`00N3Ih=P02N3H00`00N3Qh>002N3P2000:M3P00`00M3Ud>@020004K5X3
0007Ool10001Ool000Aoo`800003Ool007oo009oo`03001oogoo00Eoo`@000EdF`03001dFgAK00Ad
F``00003N5`0000000H0009l5003001l500000800003O3H007Pf00Ah=P800003N3P007@h00ad>003
001d>G@i00D000Yoo`40005oo`000goo0P0000=oo`0000000goo00<007ooOol00Woo0`0017oo3000
1g1L00<0071NL5h01G1N2P000g`D00<007PfN3H01WPf00<007@hM3P03G@h00<007@iM3T00P0037oo
0@000Goo000;Ool00`00Ool000020009Ool5L5/00`00L5a`G00:L5`40003K5h00`00I5iTGP03I5h0
2P00I5d00000O1@007`D001l50000gPf0P000g@g00<007@hM3P037@h0P0000=oo`00Ool02goo0@00
0Goo000;Ool2000=Ool20003L5/00`00L5a`G004L5`30004K5d300000faN001TGP04I5h00`00I5eT
G@020002O0l01`00O1Al57`D001h=P0000Id=`03001d>7@h00Ed>0@000Ioo`03001oogoo00Uoo`40
005oo`003Goo00<007ooOol037oo00D0071KL5]`F`00009`G0<000Y/G@X00004J5`00000O0l20003
O1@00`00M3Md=`06M3L00`00M3Qd>005000:Ool00`00Oomoo`08Ool10001Ool000eoo`8000ioo`04
001`Fg1KL5/2000:K5d20007K5`00`00J5aXG003J5`20002O1420002M3D00`00M3Md=`06M3L5000=
Ool00`00Oomoo`07Ool10001Ool000moo`8000eoo`8000=`F`<000I/G@03001/G6aL00I/G003001X
G6QL00AXG0800003O140000000Ad=@03001d=g@g00<0009/FP80015oo`03001oogoo00Ioo`40005o
o`0047oo0P003Woo0P00171K0`0000=/G@0000002FaL00<006QLJ5`016QL0`000W@B00<007@eM3D0
10000VaK0P005Goo00<007ooOol01Goo0@000Goo000BOol00`00Oomoo`0=Ool00`00L5]`F`04L5/0
1000K5`000001faL00<006QLJ5`01FQL0P0000Ad4000M19d4P8000=/F`<001Qoo`03001oogoo00Ao
o`40005oo`004Woo0P003goo00D0071KL5]`F`0000E/F`D0009/G003001XG6QL009XG0P000=/F`<0
01aoo`03001oogoo00=oo`40005oo`0057oo0P0047oo00<006aKK5/02FaK1`000faK0P0000A/F`00
K5]/F`80021oo`03001oogoo00=oo`4000005Woo00<007ooOol03goo00<006aKK5/026aK00<006aK
K5/026aK0`0097oo00<007ooOol00Woo0@00000GOol00`00Oomoo`0?Ool00`00K5]/F`06K5/00`00
K5]/F`06K5/3000XOol01000Oomoogoo0@00000>Ool3000017oo000000000goo0P004Goo00<006aK
K5/016aK00<006aKK5/00faK0`00;7oo00<007ooOol00@00000DOol00`00Oomoo`02Ool2000AOol0
0`00K5]/F`02K5/01000K5]/FfaK0`00<7oo0@000Goo0@00000COol00`00Oomoo`05Ool2000@Ool0
1000K5]/F`000faK00<007ooOol0<Woo0P00000DOol00`00Oomoo`05Ool00`00Oomoo`0?Ool01@00
K5/006aK0000=Goo0`00000MOol2000@Ool00`00Oomoo`0bOol40003Ool001ioo`8000moo`03001o
ogoo02aoo`03001oo`0000<000Moo`0087oo00<007ooOol037oo00<007ooOol0:Woo10002goo000Q
Ool2000<Ool00`00Oomoo`0VOol4000?Ool0029oo`8000]oo`03001oogoo029oo`@001=oo`0097oo
00<007ooOol027oo00<007ooOol07Goo1@005goo000LOol20006Ool20009Ool00`00Oomoo`0IOol5
000KOol001aoo`03001oo`0000Moo`8000Moo`03001oogoo01Ioo`@0015oo`<000]oo`0077oo00<0
07oo00002Goo0P001Goo00<007ooOol04Woo1@005Woo00<007ooOol02Goo000MOol2000:Ool00`00
Oomoo`03Ool00`00Oomoo`0>Ool5000IOol00`00Oomoo`0:Ool002Yoo`8000=oo`03001oogoo00Mo
o`04001oogooOol5000MOol00`00Oomoo`09Ool002]oo`80009oo`03001oogoo00Moo`@002ioo`00
;Goo00<007oo00001Goo10004Goo0P007goo000^Ool200000goo00000002000EOol00`00Ool0000N
Ool002Moo`<000Eoo`8001Uoo`03001oo`0001ioo`00:Goo00<007ooOol07goo0P007Woo000XOol0
0`00Oomoo`0;Ool6000_Ool002Uoo`03001oogoo00moo`03001oogoo02eoo`00>Woo00<007ooOol0
;Woo000kOol00`00Oomoo`0]Ool006]oo`00Jgoo001[Ool006]oo`00Jgoo001[Ool006]oo`00\
\>"],
  ImageRangeCache->{{{0, 106.5}, {171.438, 0}} -> {0.10769, -0.0354694, \
0.00651674, 0.00651674}}]
}, Closed]],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`Re(z)\)],
    FormatType->StandardForm],
  " ranges over 10\[Pi], there are ",
  Cell[BoxData[
      \(TraditionalForm\`10  \[Pi]/2  \[Pi] = 5\)],
    FormatType->StandardForm],
  " complete revolutions in the corkscrew-shaped surface. If we restrict ",
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm],
  " to vary over the domain ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Pi]\) < Im(z) \[LessEqual] \[Pi]\)],
    FormatType->StandardForm],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`z \[NotEqual] \[Infinity]\)],
    FormatType->StandardForm],
  ", then there is only ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]/2  \[Pi] = 1\)],
    FormatType->StandardForm],
  " complete revolution, as shown in the next plot. There ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)],
    FormatType->StandardForm],
  " assumes every complex number exactly once (with the sole exception of the \
point ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)],
    FormatType->StandardForm],
  ") and we can therefore invent a new one-to-one function ",
  Cell[BoxData[
      \(TraditionalForm\`w(z)\)],
    FormatType->StandardForm],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`w(\[ExponentialE]\^z) = z\)],
    FormatType->StandardForm],
  ". Then ",
  Cell[BoxData[
      \(TraditionalForm\`w(z) = ln(z)\)],
    FormatType->StandardForm],
  ", the natural logarithm. The whole ",
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm],
  "-plane is covered, but we get a discontinuity along the negative imaginary \
axis. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot3D[
        Evaluate[{Re[\[ExponentialE]\^\(w\_r + \[ImaginaryI]\ w\_i\)], 
            Im[\[ExponentialE]\^\(w\_r + \[ImaginaryI]\ w\_i\)], 
            w\_i}], {w\_r, \(-5\), 
          5}, {w\_i, \(-\[Pi]\), \[Pi]}];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .7763 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.08655e-16 1.04293 -0.084746 1.04293 [
[.16851 .19252 -10.5152 -7 ]
[.16851 .19252 .10981 0 ]
[.33773 .12704 -6.6007 -7 ]
[.33773 .12704 .4618 0 ]
[.51812 .05728 -6.32184 -7 ]
[.51812 .05728 .86566 0 ]
[.78438 .10259 0 -4.76844 ]
[.78438 .10259 10.625 2.23156 ]
[.86351 .22297 0 -4.68141 ]
[.86351 .22297 7.0625 2.31859 ]
[.93422 .33055 0 -4.60555 ]
[.93422 .33055 7.1875 2.39445 ]
[.01357 .3013 -10.5625 -2.17671 ]
[.01357 .3013 0 4.82329 ]
[.00411 .36258 -7.0625 -2.21603 ]
[.00411 .36258 0 4.78397 ]
[-0.00572 .42623 -7.125 -2.25703 ]
[-0.00572 .42623 0 4.74297 ]
[ 0 0 0 0 ]
[ 1 .7763 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0317 .25804 m
.70169 0 L
s
.17763 .20184 m
.18219 .20649 L
s
gsave
.16851 .19252 -71.5152 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34628 .13688 m
.35056 .1418 L
s
gsave
.33773 .12704 -67.6007 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.526 .06766 m
.52994 .07286 L
s
gsave
.51812 .05728 -67.3218 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.21052 .18917 m
.21323 .19199 L
s
.24383 .17634 m
.2465 .1792 L
s
.27755 .16335 m
.28019 .16624 L
s
.3117 .1502 m
.3143 .15312 L
s
.38131 .12339 m
.38384 .12638 L
s
.41678 .10973 m
.41927 .11275 L
s
.45272 .09589 m
.45517 .09894 L
s
.48912 .08187 m
.49153 .08495 L
s
.14514 .21435 m
.14791 .21711 L
s
.11304 .22671 m
.11584 .22944 L
s
.08133 .23892 m
.08416 .24163 L
s
.05001 .25099 m
.05286 .25366 L
s
.56337 .05327 m
.56569 .05642 L
s
.60124 .03869 m
.60351 .04187 L
s
.63961 .02391 m
.64184 .02713 L
s
.6785 .00893 m
.68068 .01218 L
s
.25 Mabswid
.70169 0 m
.97317 .41255 L
s
.77212 .10703 m
.76599 .10925 L
s
gsave
.78438 .10259 -61 -8.76844 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.85116 .22713 m
.84498 .22922 L
s
gsave
.86351 .22297 -61 -8.68141 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.92179 .33447 m
.91557 .33644 L
s
gsave
.93422 .33055 -61 -8.60555 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.78867 .13218 m
.78499 .13349 L
s
.80484 .15674 m
.80115 .15804 L
s
.82063 .18075 m
.81694 .18203 L
s
.83607 .2042 m
.83237 .20547 L
s
.86591 .24956 m
.8622 .25079 L
s
.88034 .27148 m
.87663 .27271 L
s
.89446 .29294 m
.89074 .29414 L
s
.90827 .31393 m
.90455 .31512 L
s
.75517 .08127 m
.7515 .08262 L
s
.73781 .05489 m
.73415 .05625 L
s
.72002 .02785 m
.71636 .02924 L
s
.70178 .00014 m
.69813 .00154 L
s
.93503 .35459 m
.93129 .35575 L
s
.94798 .37428 m
.94425 .37543 L
s
.96068 .39357 m
.95694 .39471 L
s
.97311 .41246 m
.96937 .41359 L
s
.25 Mabswid
.0317 .25804 m
0 .46462 L
s
.02577 .29669 m
.03186 .29439 L
s
gsave
.01357 .3013 -71.5625 -6.17671 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.01635 .35809 m
.02247 .35584 L
s
gsave
.00411 .36258 -68.0625 -6.21603 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.00656 .42186 m
.0127 .41968 L
s
gsave
-0.00572 .42623 -68.125 -6.25703 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.02344 .31183 m
.02711 .31045 L
s
.0211 .3271 m
.02477 .32574 L
s
.01873 .34252 m
.0224 .34117 L
s
.01393 .3738 m
.01761 .37247 L
s
.0115 .38967 m
.01518 .38834 L
s
.00904 .40569 m
.01272 .40437 L
s
.02807 .2817 m
.03172 .28031 L
s
.03035 .26685 m
.034 .26545 L
s
.00405 .4382 m
.00774 .4369 L
s
.00152 .45469 m
.00522 .4534 L
s
.25 Mabswid
.0317 .25804 m
0 .46462 L
s
0 .46462 m
.38133 .7763 L
s
.38133 .7763 m
.38843 .58822 L
s
.38843 .58822 m
.0317 .25804 L
s
.70169 0 m
.97317 .41255 L
s
.97317 .41255 m
1 .6113 L
s
1 .6113 m
.71498 .21633 L
s
.71498 .21633 m
.70169 0 L
s
.0317 .25804 m
0 .46462 L
s
0 .46462 m
.71498 .21633 L
s
.71498 .21633 m
.70169 0 L
s
.70169 0 m
.0317 .25804 L
s
.38843 .58822 m
.97317 .41255 L
s
.97317 .41255 m
1 .6113 L
s
1 .6113 m
.38133 .7763 L
s
.38133 .7763 m
.38843 .58822 L
s
0 0 m
1 0 L
1 .7763 L
0 .7763 L
closepath
clip
newpath
.5 Mabswid
.43811 .7051 m .42542 .73497 L .38236 .74894 L p .853 .069 .846 r
F P
0 g
s
.38236 .74894 m .36675 .73722 L p .43811 .7051 L .853 .069 .846 r
F P
0 g
s
.50741 .70668 m .42542 .73497 L p .51185 .70374 L .849 .069 .843 r
F P
0 g
s
.42542 .73497 m .43811 .7051 L .51185 .70374 L p .849 .069 .843 r
F P
0 g
s
.36675 .73722 m .34615 .7229 L p .43811 .7051 L .853 .069 .846 r
F P
0 g
s
.51185 .70374 m .51178 .70522 L .50741 .70668 L p .849 .069 .843 r
F P
0 g
s
.51178 .70522 m .51185 .70374 L .5181 .70297 L closepath p .839 .071 .855 r
F P
0 g
s
.36654 .6988 m .34615 .7229 L .32857 .71 L p .859 .07 .848 r
F P
0 g
s
.34615 .7229 m .36654 .6988 L .43811 .7051 L p .853 .069 .846 r
F P
0 g
s
.51434 .65151 m .51185 .70374 L .43811 .7051 L p .839 .071 .855 r
F P
0 g
s
.51185 .70374 m .51434 .65151 L .56896 .64293 L p .835 .07 .848 r
F P
0 g
s
.5181 .70297 m .51185 .70374 L p .56896 .64293 L .835 .07 .848 r
F P
0 g
s
.56896 .64293 m .58091 .68003 L .5181 .70297 L p .835 .07 .848 r
F P
0 g
s
.45977 .65415 m .43811 .7051 L .36654 .6988 L p .845 .072 .86 r
F P
0 g
s
.43811 .7051 m .45977 .65415 L .51434 .65151 L p .839 .071 .855 r
F P
0 g
s
.32857 .71 m .29572 .68773 L p .36654 .6988 L .859 .07 .848 r
F P
0 g
s
.59714 .67351 m .58091 .68003 L p .62182 .62841 L .832 .068 .84 r
F P
0 g
s
.58091 .68003 m .56896 .64293 L .62182 .62841 L p .832 .068 .84 r
F P
0 g
s
.62182 .62841 m .64228 .65684 L .59714 .67351 L p .832 .068 .84 r
F P
0 g
s
.29572 .68773 m .29933 .68508 L .36654 .6988 L p .859 .07 .848 r
F P
0 g
s
.40703 .65095 m .36654 .6988 L .29933 .68508 L p .852 .072 .862 r
F P
0 g
s
.36654 .6988 m .40703 .65095 L .45977 .65415 L p .845 .072 .86 r
F P
0 g
s
.66311 .64836 m .64228 .65684 L p .67116 .60808 L .832 .066 .832 r
F P
0 g
s
.64228 .65684 m .62182 .62841 L .67116 .60808 L p .832 .066 .832 r
F P
0 g
s
.67116 .60808 m .702 .63399 L .66311 .64836 L p .832 .066 .832 r
F P
0 g
s
.29091 .42061 m .22583 .44252 L .19031 .41507 L p .862 .067 .835 r
F P
0 g
s
.72107 .62624 m .702 .63399 L p .71519 .58226 L .833 .064 .822 r
F P
0 g
s
.702 .63399 m .67116 .60808 L .71519 .58226 L p .833 .064 .822 r
F P
0 g
s
.29933 .68508 m .29572 .68773 L .29343 .68608 L p .865 .07 .848 r
F P
0 g
s
.29343 .68608 m .28416 .67988 L .29933 .68508 L p .865 .07 .848 r
F P
0 g
s
.29933 .68508 m .28416 .67988 L .2564 .66105 L p .861 .073 .863 r
F P
0 g
s
.35793 .64218 m .29933 .68508 L p .2564 .66105 L .861 .073 .863 r
F P
0 g
s
.29933 .68508 m .35793 .64218 L .40703 .65095 L p .852 .072 .862 r
F P
0 g
s
.71519 .58226 m .76557 .60997 L .72107 .62624 L p .833 .064 .822 r
F P
0 g
s
.55633 .60374 m .56896 .64293 L .51434 .65151 L p .82 .073 .863 r
F P
0 g
s
.56896 .64293 m .55633 .60374 L .59503 .59117 L p .817 .07 .852 r
F P
0 g
s
.59503 .59117 m .62182 .62841 L .56896 .64293 L p .817 .07 .852 r
F P
0 g
s
.51624 .61186 m .51434 .65151 L .45977 .65415 L p .825 .074 .872 r
F P
0 g
s
.51434 .65151 m .51624 .61186 L .55633 .60374 L p .82 .073 .863 r
F P
0 g
s
.19031 .41507 m .18428 .41073 L p .29091 .42061 L .862 .067 .835 r
F P
0 g
s
.18428 .41073 m .26529 .39591 L .29091 .42061 L p .862 .067 .835 r
F P
0 g
s
.35433 .39925 m .29091 .42061 L .26529 .39591 L p .863 .07 .851 r
F P
0 g
s
.7779 .60503 m .76557 .60997 L p .75217 .55142 L .835 .063 .813 r
F P
0 g
s
.76557 .60997 m .71519 .58226 L .75217 .55142 L p .835 .063 .813 r
F P
0 g
s
.62182 .62841 m .59503 .59117 L .63094 .5743 L p .817 .068 .84 r
F P
0 g
s
.63094 .5743 m .67116 .60808 L .62182 .62841 L p .817 .068 .84 r
F P
0 g
s
.47618 .61551 m .45977 .65415 L .40703 .65095 L p .832 .076 .879 r
F P
0 g
s
.45977 .65415 m .47618 .61551 L .51624 .61186 L p .825 .074 .872 r
F P
0 g
s
.83765 .58189 m .83317 .58526 L .7779 .60503 L p .835 .063 .813 r
F P
0 g
s
.75217 .55142 m .83765 .58189 L p .7779 .60503 L .835 .063 .813 r
F P
0 g
s
.67116 .60808 m .63094 .5743 L .66268 .55339 L p .819 .065 .827 r
F P
0 g
s
.66268 .55339 m .71519 .58226 L .67116 .60808 L p .819 .065 .827 r
F P
0 g
s
.26529 .39591 m .18428 .41073 L .1496 .38382 L p .871 .066 .829 r
F P
0 g
s
.43761 .6148 m .40703 .65095 L .35793 .64218 L p .842 .077 .883 r
F P
0 g
s
.40703 .65095 m .43761 .6148 L .47618 .61551 L p .832 .076 .879 r
F P
0 g
s
.26529 .39591 m .33661 .38287 L .35433 .39925 L p .863 .07 .851 r
F P
0 g
s
.4007 .38364 m .35433 .39925 L .33661 .38287 L p .864 .075 .875 r
F P
0 g
s
.83832 .58337 m .83317 .58526 L .83765 .58189 L p .844 .062 .812 r
F P
0 g
s
.83765 .58189 m .84012 .58277 L .83832 .58337 L p .844 .062 .812 r
F P
0 g
s
.89981 .56142 m .84012 .58277 L p .87864 .53655 L .847 .061 .805 r
F P
0 g
s
.84012 .58277 m .83765 .58189 L .87864 .53655 L p .847 .061 .805 r
F P
0 g
s
.83765 .58189 m .75217 .55142 L .78043 .51623 L p .838 .061 .803 r
F P
0 g
s
.78043 .51623 m .87864 .53655 L .83765 .58189 L p .838 .061 .803 r
F P
0 g
s
.2564 .66105 m .25165 .65817 L p .35793 .64218 L .861 .073 .863 r
F P
0 g
s
.14336 .37332 m .2498 .36821 L .26529 .39591 L p .871 .066 .829 r
F P
0 g
s
.1496 .38382 m .14336 .37332 L p .26529 .39591 L .871 .066 .829 r
F P
0 g
s
.33661 .38287 m .26529 .39591 L .2498 .36821 L p .876 .069 .843 r
F P
0 g
s
.25165 .65817 m .31429 .62823 L .35793 .64218 L p .861 .073 .863 r
F P
0 g
s
.31429 .62823 m .25165 .65817 L .21701 .63504 L p .871 .072 .861 r
F P
0 g
s
.71519 .58226 m .66268 .55339 L .68897 .52889 L p .822 .063 .814 r
F P
0 g
s
.68897 .52889 m .75217 .55142 L .71519 .58226 L p .822 .063 .814 r
F P
0 g
s
.33661 .38287 m .38834 .37341 L .4007 .38364 L p .864 .075 .875 r
F P
0 g
s
.4344 .37229 m .4007 .38364 L .38834 .37341 L p .865 .082 .911 r
F P
0 g
s
.87864 .53655 m .93814 .54887 L .89981 .56142 L p .847 .061 .805 r
F P
0 g
s
.40193 .60995 m .35793 .64218 L .31429 .62823 L p .854 .077 .884 r
F P
0 g
s
.35793 .64218 m .40193 .60995 L .43761 .6148 L p .842 .077 .883 r
F P
0 g
s
.54689 .57447 m .55633 .60374 L .51624 .61186 L p .8 .076 .882 r
F P
0 g
s
.55633 .60374 m .54689 .57447 L .57506 .56342 L p .797 .073 .866 r
F P
0 g
s
.57506 .56342 m .59503 .59117 L .55633 .60374 L p .797 .073 .866 r
F P
0 g
s
.51765 .58222 m .51624 .61186 L .47618 .61551 L p .805 .079 .896 r
F P
0 g
s
.51624 .61186 m .51765 .58222 L .54689 .57447 L p .8 .076 .882 r
F P
0 g
s
.59503 .59117 m .57506 .56342 L .60108 .54921 L p .797 .07 .85 r
F P
0 g
s
.60108 .54921 m .63094 .5743 L .59503 .59117 L p .797 .07 .85 r
F P
0 g
s
.2498 .36821 m .32643 .36453 L .33661 .38287 L p .876 .069 .843 r
F P
0 g
s
.38834 .37341 m .33661 .38287 L .32643 .36453 L p .883 .072 .862 r
F P
0 g
s
.38834 .37341 m .42573 .36657 L .4344 .37229 L p .865 .082 .911 r
F P
0 g
s
.45881 .36407 m .4344 .37229 L .42573 .36657 L p .861 .093 .966 r
F P
0 g
s
.48845 .58666 m .47618 .61551 L .43761 .6148 L p .815 .081 .906 r
F P
0 g
s
.47618 .61551 m .48845 .58666 L .51765 .58222 L p .805 .079 .896 r
F P
0 g
s
.97431 .53634 m .93814 .54887 L p .90619 .48596 L .85 .06 .798 r
F P
0 g
s
.93814 .54887 m .87864 .53655 L .90619 .48596 L p .85 .06 .798 r
F P
0 g
s
.13663 .37364 m .14336 .37332 L .1496 .38382 L closepath p .88 .064 .822 r
F P
0 g
s
.63094 .5743 m .60108 .54921 L .62393 .53208 L p .8 .066 .832 r
F P
0 g
s
.62393 .53208 m .66268 .55339 L .63094 .5743 L p .8 .066 .832 r
F P
0 g
s
.42573 .36657 m .45269 .36164 L .45881 .36407 L p .861 .093 .966 r
F P
0 g
s
.47643 .35814 m .45881 .36407 L .45269 .36164 L p .843 .109 1 r
F P
0 g
s
.32643 .36453 m .38152 .36188 L .38834 .37341 L p .883 .072 .862 r
F P
0 g
s
.42573 .36657 m .38834 .37341 L .38152 .36188 L p .892 .078 .892 r
F P
0 g
s
.75217 .55142 m .68897 .52889 L .70862 .50136 L p .827 .06 .801 r
F P
0 g
s
.70862 .50136 m .78043 .51623 L .75217 .55142 L p .827 .06 .801 r
F P
0 g
s
.9626 .49034 m .98924 .53159 L .97431 .53634 L p .85 .06 .798 r
F P
0 g
s
.90619 .48596 m .9626 .49034 L p .97431 .53634 L .85 .06 .798 r
F P
0 g
s
.45269 .36164 m .47209 .35809 L .47643 .35814 L p .843 .109 1 r
F P
0 g
s
.48912 .35386 m .47643 .35814 L .47209 .35809 L p .777 .126 1 r
F P
0 g
s
.46039 .58787 m .43761 .6148 L .40193 .60995 L p .827 .083 .913 r
F P
0 g
s
.43761 .6148 m .46039 .58787 L .48845 .58666 L p .815 .081 .906 r
F P
0 g
s
.38152 .36188 m .42109 .35999 L .42573 .36657 L p .892 .078 .892 r
F P
0 g
s
.45269 .36164 m .42573 .36657 L .42109 .35999 L p .902 .087 .937 r
F P
0 g
s
.87864 .53655 m .78043 .51623 L .79844 .4776 L p .843 .059 .794 r
F P
0 g
s
.79844 .4776 m .90619 .48596 L .87864 .53655 L p .843 .059 .794 r
F P
0 g
s
.14336 .37332 m .13663 .37364 L .13118 .36916 L p .874 .063 .815 r
F P
0 g
s
.13118 .36916 m .07587 .3249 L p .14336 .37332 L .874 .063 .815 r
F P
0 g
s
.07587 .3249 m .13479 .32972 L .14336 .37332 L p .874 .063 .815 r
F P
0 g
s
.2498 .36821 m .14336 .37332 L .13479 .32972 L p .88 .064 .822 r
F P
0 g
s
.47209 .35809 m .48604 .35554 L .48912 .35386 L p .777 .126 1 r
F P
0 g
s
.49825 .35079 m .48912 .35386 L .48604 .35554 L p .5 0 .5 r
F P
0 g
s
.66268 .55339 m .62393 .53208 L .64264 .51237 L p .806 .063 .815 r
F P
0 g
s
.64264 .51237 m .68897 .52889 L .66268 .55339 L p .806 .063 .815 r
F P
0 g
s
.42109 .35999 m .44949 .35862 L .45269 .36164 L p .902 .087 .937 r
F P
0 g
s
.47209 .35809 m .45269 .36164 L .44949 .35862 L p .902 .1 .998 r
F P
0 g
s
.21701 .63504 m .20937 .63043 L p .31429 .62823 L .871 .072 .861 r
F P
0 g
s
.20937 .63043 m .27791 .60969 L .31429 .62823 L p .871 .072 .861 r
F P
0 g
s
.37055 .60134 m .31429 .62823 L .27791 .60969 L p .868 .076 .881 r
F P
0 g
s
.31429 .62823 m .37055 .60134 L .40193 .60995 L p .854 .077 .884 r
F P
0 g
s
.48604 .35554 m .49606 .35371 L .49825 .35079 L p .5 0 .5 r
F P
0 g
s
.50481 .34858 m .49825 .35079 L .49606 .35371 L p .631 0 .5 r
F P
0 g
s
.13479 .32972 m .24571 .33878 L .2498 .36821 L p .88 .064 .822 r
F P
0 g
s
.32643 .36453 m .2498 .36821 L .24571 .33878 L p .888 .066 .832 r
F P
0 g
s
.49606 .35371 m .50325 .35239 L .50481 .34858 L p .631 0 .5 r
F P
0 g
s
.50952 .34699 m .50481 .34858 L .50325 .35239 L p .699 0 .5 r
F P
0 g
s
.44949 .35862 m .46987 .35764 L .47209 .35809 L p .902 .1 .998 r
F P
0 g
s
.48604 .35554 m .47209 .35809 L .46987 .35764 L p .85 .108 1 r
F P
0 g
s
.50325 .35239 m .5084 .35145 L .50952 .34699 L p .699 0 .5 r
F P
0 g
s
.5129 .34585 m .50952 .34699 L .5084 .35145 L p .731 0 .5 r
F P
0 g
s
.46987 .35764 m .48448 .35694 L .48604 .35554 L p .85 .108 1 r
F P
0 g
s
.49606 .35371 m .48604 .35554 L .48448 .35694 L p .5 0 .5 r
F P
0 g
s
.5084 .35145 m .5121 .35077 L .5129 .34585 L p .731 0 .5 r
F P
0 g
s
.51533 .34504 m .5129 .34585 L .5121 .35077 L p .748 0 .5 r
F P
0 g
s
.24571 .33878 m .32455 .34522 L .32643 .36453 L p .888 .066 .832 r
F P
0 g
s
.38152 .36188 m .32643 .36453 L .32455 .34522 L p .901 .069 .846 r
F P
0 g
s
.5121 .35077 m .51476 .35029 L .51533 .34504 L p .748 0 .5 r
F P
0 g
s
.51707 .34445 m .51533 .34504 L .51476 .35029 L p .757 0 .5 r
F P
0 g
s
.51476 .35029 m .51666 .34994 L .51707 .34445 L p .757 0 .5 r
F P
0 g
s
.51831 .34403 m .51707 .34445 L .51666 .34994 L p .762 0 .5 r
F P
0 g
s
.48448 .35694 m .49496 .35644 L .49606 .35371 L p .5 0 .5 r
F P
0 g
s
.50325 .35239 m .49606 .35371 L .49496 .35644 L p .525 0 .5 r
F P
0 g
s
.53992 .55284 m .54689 .57447 L .51765 .58222 L p .772 .082 .908 r
F P
0 g
s
.54689 .57447 m .53992 .55284 L .56033 .54296 L p .77 .077 .885 r
F P
0 g
s
.56033 .54296 m .57506 .56342 L .54689 .57447 L p .77 .077 .885 r
F P
0 g
s
.51666 .34994 m .51802 .34969 L .51831 .34403 L p .762 0 .5 r
F P
0 g
s
.51921 .34373 m .51831 .34403 L .51802 .34969 L p .766 0 .5 r
F P
0 g
s
.51802 .34969 m .519 .34951 L .51921 .34373 L p .766 0 .5 r
F P
0 g
s
.51985 .34352 m .51921 .34373 L .519 .34951 L p .768 0 .5 r
F P
0 g
s
.519 .34951 m .5197 .34938 L .51985 .34352 L p .768 0 .5 r
F P
0 g
s
.52031 .34336 m .51985 .34352 L .5197 .34938 L p .77 0 .5 r
F P
0 g
s
.5197 .34938 m .5202 .34929 L .52031 .34336 L p .77 0 .5 r
F P
0 g
s
.52063 .34325 m .52031 .34336 L .5202 .34929 L p .771 0 .5 r
F P
0 g
s
.5202 .34929 m .52056 .34922 L .52063 .34325 L p .771 0 .5 r
F P
0 g
s
.52087 .34317 m .52063 .34325 L .52056 .34922 L p .771 0 .5 r
F P
0 g
s
.52056 .34922 m .52081 .34918 L .52087 .34317 L p .771 0 .5 r
F P
0 g
s
.52104 .34311 m .52087 .34317 L .52081 .34918 L p .772 0 .5 r
F P
0 g
s
.52081 .34918 m .521 .34914 L .52104 .34311 L p .772 0 .5 r
F P
0 g
s
.52116 .34307 m .52104 .34311 L .521 .34914 L p .772 0 .5 r
F P
0 g
s
.521 .34914 m .52113 .34912 L .52116 .34307 L p .772 0 .5 r
F P
0 g
s
.52125 .34304 m .52116 .34307 L .52113 .34912 L p .772 0 .5 r
F P
0 g
s
.52113 .34912 m .52123 .3491 L .52125 .34304 L p .772 0 .5 r
F P
0 g
s
.49496 .35644 m .50247 .35608 L .50325 .35239 L p .525 0 .5 r
F P
0 g
s
.5084 .35145 m .50325 .35239 L .50247 .35608 L p .598 0 .5 r
F P
0 g
s
.32455 .34522 m .38071 .3498 L .38152 .36188 L p .901 .069 .846 r
F P
0 g
s
.42109 .35999 m .38152 .36188 L .38071 .3498 L p .919 .073 .867 r
F P
0 g
s
.57506 .56342 m .56033 .54296 L .57913 .53078 L p .772 .072 .862 r
F P
0 g
s
.57913 .53078 m .60108 .54921 L .57506 .56342 L p .772 .072 .862 r
F P
0 g
s
.5187 .56031 m .51765 .58222 L .48845 .58666 L p .778 .086 .928 r
F P
0 g
s
.51765 .58222 m .5187 .56031 L .53992 .55284 L p .772 .082 .908 r
F P
0 g
s
.50247 .35608 m .50785 .35582 L .5084 .35145 L p .598 0 .5 r
F P
0 g
s
.5121 .35077 m .5084 .35145 L .50785 .35582 L p .636 0 .5 r
F P
0 g
s
.50785 .35582 m .51171 .35564 L .5121 .35077 L p .636 0 .5 r
F P
0 g
s
.51476 .35029 m .5121 .35077 L .51171 .35564 L p .658 0 .5 r
F P
0 g
s
.38071 .3498 m .42078 .35308 L .42109 .35999 L p .919 .073 .867 r
F P
0 g
s
.44949 .35862 m .42109 .35999 L .42078 .35308 L p .943 .079 .897 r
F P
0 g
s
.43456 .58605 m .40193 .60995 L .37055 .60134 L p .843 .083 .915 r
F P
0 g
s
.40193 .60995 m .43456 .58605 L .46039 .58787 L p .827 .083 .913 r
F P
0 g
s
.51171 .35564 m .51447 .3555 L .51476 .35029 L p .658 0 .5 r
F P
0 g
s
.51666 .34994 m .51476 .35029 L .51447 .3555 L p .671 0 .5 r
F P
0 g
s
.51447 .3555 m .51646 .35541 L .51666 .34994 L p .671 0 .5 r
F P
0 g
s
.51802 .34969 m .51666 .34994 L .51646 .35541 L p .679 0 .5 r
F P
0 g
s
.51646 .35541 m .51788 .35534 L .51802 .34969 L p .679 0 .5 r
F P
0 g
s
.519 .34951 m .51802 .34969 L .51788 .35534 L p .684 0 .5 r
F P
0 g
s
.51788 .35534 m .51889 .35529 L .519 .34951 L p .684 0 .5 r
F P
0 g
s
.5197 .34938 m .519 .34951 L .51889 .35529 L p .688 0 .5 r
F P
0 g
s
.51889 .35529 m .51962 .35526 L .5197 .34938 L p .688 0 .5 r
F P
0 g
s
.5202 .34929 m .5197 .34938 L .51962 .35526 L p .691 0 .5 r
F P
0 g
s
.51962 .35526 m .52014 .35523 L .5202 .34929 L p .691 0 .5 r
F P
0 g
s
.52056 .34922 m .5202 .34929 L .52014 .35523 L p .692 0 .5 r
F P
0 g
s
.52014 .35523 m .52052 .35521 L .52056 .34922 L p .692 0 .5 r
F P
0 g
s
.52081 .34918 m .52056 .34922 L .52052 .35521 L p .694 0 .5 r
F P
0 g
s
.52052 .35521 m .52079 .3552 L .52081 .34918 L p .694 0 .5 r
F P
0 g
s
.521 .34914 m .52081 .34918 L .52079 .3552 L p .694 0 .5 r
F P
0 g
s
.52079 .3552 m .52098 .35519 L .521 .34914 L p .694 0 .5 r
F P
0 g
s
.52113 .34912 m .521 .34914 L .52098 .35519 L p .695 0 .501 r
F P
0 g
s
.52098 .35519 m .52112 .35519 L .52113 .34912 L p .695 0 .501 r
F P
0 g
s
.52123 .3491 m .52113 .34912 L .52112 .35519 L p .696 0 .502 r
F P
0 g
s
.52112 .35519 m .52122 .35518 L .52123 .3491 L p .696 0 .502 r
F P
0 g
s
.42078 .35308 m .44941 .35542 L .44949 .35862 L p .943 .079 .897 r
F P
0 g
s
.46987 .35764 m .44949 .35862 L .44941 .35542 L p .964 .087 .933 r
F P
0 g
s
.44941 .35542 m .46988 .35709 L .46987 .35764 L p .964 .087 .933 r
F P
0 g
s
.48448 .35694 m .46987 .35764 L .46988 .35709 L p .932 .086 .928 r
F P
0 g
s
.46988 .35709 m .48453 .35828 L .48448 .35694 L p .932 .086 .928 r
F P
0 g
s
.49496 .35644 m .48448 .35694 L .48453 .35828 L p .5 0 .5 r
F P
0 g
s
.60108 .54921 m .57913 .53078 L .59555 .51648 L p .777 .068 .839 r
F P
0 g
s
.59555 .51648 m .62393 .53208 L .60108 .54921 L p .777 .068 .839 r
F P
0 g
s
.48453 .35828 m .49501 .35914 L .49496 .35644 L p .5 0 .5 r
F P
0 g
s
.50247 .35608 m .49496 .35644 L .49501 .35914 L p .5 0 .5 r
F P
0 g
s
.49501 .35914 m .50252 .35975 L .50247 .35608 L p .5 0 .5 r
F P
0 g
s
.50785 .35582 m .50247 .35608 L .50252 .35975 L p .502 0 .5 r
F P
0 g
s
.50252 .35975 m .50789 .36019 L .50785 .35582 L p .502 0 .5 r
F P
0 g
s
.51171 .35564 m .50785 .35582 L .50789 .36019 L p .548 0 .5 r
F P
0 g
s
.50789 .36019 m .51174 .36051 L .51171 .35564 L p .548 0 .5 r
F P
0 g
s
.51447 .3555 m .51171 .35564 L .51174 .36051 L p .578 .003 .514 r
F P
0 g
s
.51174 .36051 m .5145 .36073 L .51447 .3555 L p .578 .003 .514 r
F P
0 g
s
.51646 .35541 m .51447 .3555 L .5145 .36073 L p .599 .007 .534 r
F P
0 g
s
.5145 .36073 m .51647 .36089 L .51646 .35541 L p .599 .007 .534 r
F P
0 g
s
.51788 .35534 m .51646 .35541 L .51647 .36089 L p .612 .009 .547 r
F P
0 g
s
.68897 .52889 m .64264 .51237 L .6564 .49056 L p .813 .06 .799 r
F P
0 g
s
.6564 .49056 m .70862 .50136 L .68897 .52889 L p .813 .06 .799 r
F P
0 g
s
.51647 .36089 m .51789 .36101 L .51788 .35534 L p .612 .009 .547 r
F P
0 g
s
.51889 .35529 m .51788 .35534 L .51789 .36101 L p .621 .011 .556 r
F P
0 g
s
.51789 .36101 m .5189 .36109 L .51889 .35529 L p .621 .011 .556 r
F P
0 g
s
.51962 .35526 m .51889 .35529 L .5189 .36109 L p .627 .012 .562 r
F P
0 g
s
.4975 .56534 m .48845 .58666 L .46039 .58787 L p .789 .089 .945 r
F P
0 g
s
.48845 .58666 m .4975 .56534 L .5187 .56031 L p .778 .086 .928 r
F P
0 g
s
.5189 .36109 m .51963 .36115 L .51962 .35526 L p .627 .012 .562 r
F P
0 g
s
.52014 .35523 m .51962 .35526 L .51963 .36115 L p .632 .013 .566 r
F P
0 g
s
.51963 .36115 m .52015 .36119 L .52014 .35523 L p .632 .013 .566 r
F P
0 g
s
.52052 .35521 m .52014 .35523 L .52015 .36119 L p .634 .014 .569 r
F P
0 g
s
.52015 .36119 m .52052 .36122 L .52052 .35521 L p .634 .014 .569 r
F P
0 g
s
.52079 .3552 m .52052 .35521 L .52052 .36122 L p .637 .014 .571 r
F P
0 g
s
.52052 .36122 m .52079 .36125 L .52079 .3552 L p .637 .014 .571 r
F P
0 g
s
.52098 .35519 m .52079 .3552 L .52079 .36125 L p .638 .014 .572 r
F P
0 g
s
.52079 .36125 m .52098 .36126 L .52098 .35519 L p .638 .014 .572 r
F P
0 g
s
.52112 .35519 m .52098 .35519 L .52098 .36126 L p .639 .015 .573 r
F P
0 g
s
.52098 .36126 m .52112 .36127 L .52112 .35519 L p .639 .015 .573 r
F P
0 g
s
.52122 .35518 m .52112 .35519 L .52112 .36127 L p .64 .015 .574 r
F P
0 g
s
.52112 .36127 m .52122 .36128 L .52122 .35518 L p .64 .015 .574 r
F P
0 g
s
.78043 .51623 m .70862 .50136 L .7206 .47156 L p .834 .058 .789 r
F P
0 g
s
.7206 .47156 m .79844 .4776 L .78043 .51623 L p .834 .058 .789 r
F P
0 g
s
.52114 .36738 m .52123 .36741 L .52122 .36128 L p .584 .029 .643 r
F P
0 g
s
.52122 .36128 m .52112 .36127 L .52114 .36738 L p .584 .029 .643 r
F P
0 g
s
.521 .36736 m .52114 .36738 L .52112 .36127 L p .583 .028 .642 r
F P
0 g
s
.52112 .36127 m .52098 .36126 L .521 .36736 L p .583 .028 .642 r
F P
0 g
s
.52082 .36732 m .521 .36736 L .52098 .36126 L p .582 .028 .642 r
F P
0 g
s
.52098 .36126 m .52079 .36125 L .52082 .36732 L p .582 .028 .642 r
F P
0 g
s
.52057 .36726 m .52082 .36732 L .52079 .36125 L p .58 .028 .641 r
F P
0 g
s
.52079 .36125 m .52052 .36122 L .52057 .36726 L p .58 .028 .641 r
F P
0 g
s
.52021 .36718 m .52057 .36726 L .52052 .36122 L p .578 .028 .639 r
F P
0 g
s
.52052 .36122 m .52015 .36119 L .52021 .36718 L p .578 .028 .639 r
F P
0 g
s
.51972 .36708 m .52021 .36718 L .52015 .36119 L p .574 .027 .637 r
F P
0 g
s
.52015 .36119 m .51963 .36115 L .51972 .36708 L p .574 .027 .637 r
F P
0 g
s
.51902 .36692 m .51972 .36708 L .51963 .36115 L p .569 .027 .634 r
F P
0 g
s
.51963 .36115 m .5189 .36109 L .51902 .36692 L p .569 .027 .634 r
F P
0 g
s
.51806 .36671 m .51902 .36692 L .5189 .36109 L p .562 .026 .629 r
F P
0 g
s
.5189 .36109 m .51789 .36101 L .51806 .36671 L p .562 .026 .629 r
F P
0 g
s
.51671 .36642 m .51806 .36671 L .51789 .36101 L p .552 .024 .622 r
F P
0 g
s
.51789 .36101 m .51647 .36089 L .51671 .36642 L p .552 .024 .622 r
F P
0 g
s
.51483 .36601 m .51671 .36642 L .51647 .36089 L p .536 .022 .612 r
F P
0 g
s
.51647 .36089 m .5145 .36073 L .51483 .36601 L p .536 .022 .612 r
F P
0 g
s
.5122 .36544 m .51483 .36601 L .5145 .36073 L p .519 .019 .596 r
F P
0 g
s
.5145 .36073 m .51174 .36051 L .5122 .36544 L p .519 .019 .596 r
F P
0 g
s
.50853 .36464 m .5122 .36544 L .51174 .36051 L p .514 .014 .571 r
F P
0 g
s
.51174 .36051 m .50789 .36019 L .50853 .36464 L p .514 .014 .571 r
F P
0 g
s
.5034 .36352 m .50853 .36464 L .50789 .36019 L p .505 .005 .527 r
F P
0 g
s
.50789 .36019 m .50252 .35975 L .5034 .36352 L p .505 .005 .527 r
F P
0 g
s
.49623 .36195 m .5034 .36352 L .50252 .35975 L p .5 0 .5 r
F P
0 g
s
.50252 .35975 m .49501 .35914 L .49623 .36195 L p .5 0 .5 r
F P
0 g
s
.4862 .35977 m .49623 .36195 L .49501 .35914 L p .5 0 .5 r
F P
0 g
s
.49501 .35914 m .48453 .35828 L .4862 .35977 L p .5 0 .5 r
F P
0 g
s
.48453 .35828 m .46988 .35709 L .47217 .35671 L p 1 .063 .817 r
F P
0 g
s
.47217 .35671 m .4862 .35977 L .48453 .35828 L p 1 .063 .817 r
F P
0 g
s
.62393 .53208 m .59555 .51648 L .6089 .50034 L p .784 .063 .817 r
F P
0 g
s
.6089 .50034 m .64264 .51237 L .62393 .53208 L p .784 .063 .817 r
F P
0 g
s
.52117 .37352 m .52125 .37356 L .52123 .36741 L p .543 .043 .715 r
F P
0 g
s
.52123 .36741 m .52114 .36738 L .52117 .37352 L p .543 .043 .715 r
F P
0 g
s
.52105 .37348 m .52117 .37352 L .52114 .36738 L p .543 .043 .714 r
F P
0 g
s
.52114 .36738 m .521 .36736 L .52105 .37348 L p .543 .043 .714 r
F P
0 g
s
.52088 .37342 m .52105 .37348 L .521 .36736 L p .543 .043 .714 r
F P
0 g
s
.521 .36736 m .52082 .36732 L .52088 .37342 L p .543 .043 .714 r
F P
0 g
s
.52065 .37333 m .52088 .37342 L .52082 .36732 L p .543 .043 .713 r
F P
0 g
s
.52082 .36732 m .52057 .36726 L .52065 .37333 L p .543 .043 .713 r
F P
0 g
s
.52033 .37321 m .52065 .37333 L .52057 .36726 L p .542 .042 .712 r
F P
0 g
s
.52057 .36726 m .52021 .36718 L .52033 .37321 L p .542 .042 .712 r
F P
0 g
s
.51988 .37304 m .52033 .37321 L .52021 .36718 L p .542 .042 .71 r
F P
0 g
s
.52021 .36718 m .51972 .36708 L .51988 .37304 L p .542 .042 .71 r
F P
0 g
s
.51925 .3728 m .51988 .37304 L .51972 .36708 L p .542 .042 .708 r
F P
0 g
s
.51972 .36708 m .51902 .36692 L .51925 .3728 L p .542 .042 .708 r
F P
0 g
s
.51838 .37248 m .51925 .3728 L .51902 .36692 L p .541 .041 .705 r
F P
0 g
s
.51902 .36692 m .51806 .36671 L .51838 .37248 L p .541 .041 .705 r
F P
0 g
s
.45251 .35242 m .47217 .35671 L .46988 .35709 L p 1 .072 .858 r
F P
0 g
s
.46988 .35709 m .44941 .35542 L .45251 .35242 L p 1 .072 .858 r
F P
0 g
s
.51716 .37202 m .51838 .37248 L .51806 .36671 L p .54 .04 .7 r
F P
0 g
s
.51806 .36671 m .51671 .36642 L .51716 .37202 L p .54 .04 .7 r
F P
0 g
s
.51545 .37138 m .51716 .37202 L .51671 .36642 L p .538 .038 .692 r
F P
0 g
s
.51671 .36642 m .51483 .36601 L .51545 .37138 L p .538 .038 .692 r
F P
0 g
s
.51306 .37048 m .51545 .37138 L .51483 .36601 L p .536 .036 .68 r
F P
0 g
s
.51483 .36601 m .5122 .36544 L .51306 .37048 L p .536 .036 .68 r
F P
0 g
s
.50973 .36923 m .51306 .37048 L .5122 .36544 L p .532 .032 .66 r
F P
0 g
s
.5122 .36544 m .50853 .36464 L .50973 .36923 L p .532 .032 .66 r
F P
0 g
s
.42493 .34641 m .45251 .35242 L .44941 .35542 L p .98 .07 .851 r
F P
0 g
s
.44941 .35542 m .42078 .35308 L .42493 .34641 L p .98 .07 .851 r
F P
0 g
s
.47718 .56802 m .46039 .58787 L .43456 .58605 L p .805 .091 .956 r
F P
0 g
s
.46039 .58787 m .47718 .56802 L .4975 .56534 L p .789 .089 .945 r
F P
0 g
s
.50508 .36748 m .50973 .36923 L .50853 .36464 L p .525 .025 .624 r
F P
0 g
s
.50853 .36464 m .5034 .36352 L .50508 .36748 L p .525 .025 .624 r
F P
0 g
s
.52121 .37969 m .52128 .37973 L .52125 .37356 L p .559 .059 .794 r
F P
0 g
s
.52125 .37356 m .52117 .37352 L .52121 .37969 L p .559 .059 .794 r
F P
0 g
s
.52111 .37963 m .52121 .37969 L .52117 .37352 L p .559 .059 .794 r
F P
0 g
s
.52117 .37352 m .52105 .37348 L .52111 .37963 L p .559 .059 .794 r
F P
0 g
s
.52097 .37955 m .52111 .37963 L .52105 .37348 L p .559 .059 .794 r
F P
0 g
s
.52105 .37348 m .52088 .37342 L .52097 .37955 L p .559 .059 .794 r
F P
0 g
s
.52077 .37944 m .52097 .37955 L .52088 .37342 L p .559 .059 .793 r
F P
0 g
s
.52088 .37342 m .52065 .37333 L .52077 .37944 L p .559 .059 .793 r
F P
0 g
s
.5205 .37928 m .52077 .37944 L .52065 .37333 L p .559 .059 .793 r
F P
0 g
s
.52065 .37333 m .52033 .37321 L .5205 .37928 L p .559 .059 .793 r
F P
0 g
s
.49856 .36503 m .50508 .36748 L .5034 .36352 L p .511 .011 .555 r
F P
0 g
s
.5034 .36352 m .49623 .36195 L .49856 .36503 L p .511 .011 .555 r
F P
0 g
s
.52011 .37905 m .5205 .37928 L .52033 .37321 L p .558 .058 .792 r
F P
0 g
s
.52033 .37321 m .51988 .37304 L .52011 .37905 L p .558 .058 .792 r
F P
0 g
s
.51958 .37874 m .52011 .37905 L .51988 .37304 L p .558 .058 .791 r
F P
0 g
s
.51988 .37304 m .51925 .3728 L .51958 .37874 L p .558 .058 .791 r
F P
0 g
s
.51883 .37831 m .51958 .37874 L .51925 .3728 L p .558 .058 .789 r
F P
0 g
s
.51925 .3728 m .51838 .37248 L .51883 .37831 L p .558 .058 .789 r
F P
0 g
s
.38614 .33795 m .42493 .34641 L .42078 .35308 L p .943 .068 .838 r
F P
0 g
s
.42078 .35308 m .38071 .3498 L .38614 .33795 L p .943 .068 .838 r
F P
0 g
s
.51779 .37771 m .51883 .37831 L .51838 .37248 L p .557 .057 .786 r
F P
0 g
s
.51838 .37248 m .51716 .37202 L .51779 .37771 L p .557 .057 .786 r
F P
0 g
s
.51634 .37686 m .51779 .37771 L .51716 .37202 L p .556 .056 .781 r
F P
0 g
s
.51716 .37202 m .51545 .37138 L .51634 .37686 L p .556 .056 .781 r
F P
0 g
s
.48944 .36161 m .49856 .36503 L .49623 .36195 L p .5 0 .5 r
F P
0 g
s
.49623 .36195 m .4862 .35977 L .48944 .36161 L p .5 0 .5 r
F P
0 g
s
.5143 .37569 m .51634 .37686 L .51545 .37138 L p .555 .055 .773 r
F P
0 g
s
.51545 .37138 m .51306 .37048 L .5143 .37569 L p .555 .055 .773 r
F P
0 g
s
.51146 .37404 m .5143 .37569 L .51306 .37048 L p .552 .052 .758 r
F P
0 g
s
.51306 .37048 m .50973 .36923 L .51146 .37404 L p .552 .052 .758 r
F P
0 g
s
.52127 .38589 m .52132 .38594 L .52128 .37973 L p .578 .078 .89 r
F P
0 g
s
.52128 .37973 m .52121 .37969 L .52127 .38589 L p .578 .078 .89 r
F P
0 g
s
.52119 .38582 m .52127 .38589 L .52121 .37969 L p .578 .078 .89 r
F P
0 g
s
.52121 .37969 m .52111 .37963 L .52119 .38582 L p .578 .078 .89 r
F P
0 g
s
.52108 .38572 m .52119 .38582 L .52111 .37963 L p .578 .078 .89 r
F P
0 g
s
.52111 .37963 m .52097 .37955 L .52108 .38572 L p .578 .078 .89 r
F P
0 g
s
.52092 .38558 m .52108 .38572 L .52097 .37955 L p .578 .078 .89 r
F P
0 g
s
.52097 .37955 m .52077 .37944 L .52092 .38558 L p .578 .078 .89 r
F P
0 g
s
.52071 .38539 m .52092 .38558 L .52077 .37944 L p .578 .078 .89 r
F P
0 g
s
.52077 .37944 m .5205 .37928 L .52071 .38539 L p .578 .078 .89 r
F P
0 g
s
.52041 .38513 m .52071 .38539 L .5205 .37928 L p .578 .078 .89 r
F P
0 g
s
.5205 .37928 m .52011 .37905 L .52041 .38513 L p .578 .078 .89 r
F P
0 g
s
.4862 .35977 m .47217 .35671 L .47666 .3568 L p 1 .043 .713 r
F P
0 g
s
.47666 .3568 m .48944 .36161 L .4862 .35977 L p 1 .043 .713 r
F P
0 g
s
.51999 .38476 m .52041 .38513 L .52011 .37905 L p .578 .078 .89 r
F P
0 g
s
.52011 .37905 m .51958 .37874 L .51999 .38476 L p .578 .078 .89 r
F P
0 g
s
.33142 .32603 m .38614 .33795 L .38071 .3498 L p .917 .065 .827 r
F P
0 g
s
.38071 .3498 m .32455 .34522 L .33142 .32603 L p .917 .065 .827 r
F P
0 g
s
.50749 .37173 m .51146 .37404 L .50973 .36923 L p .545 .045 .727 r
F P
0 g
s
.50973 .36923 m .50508 .36748 L .50749 .37173 L p .545 .045 .727 r
F P
0 g
s
.51941 .38424 m .51999 .38476 L .51958 .37874 L p .578 .078 .89 r
F P
0 g
s
.51958 .37874 m .51883 .37831 L .51941 .38424 L p .578 .078 .89 r
F P
0 g
s
.51859 .38352 m .51941 .38424 L .51883 .37831 L p .578 .078 .889 r
F P
0 g
s
.51883 .37831 m .51779 .37771 L .51859 .38352 L p .578 .078 .889 r
F P
0 g
s
.53481 .53699 m .53992 .55284 L .5187 .56031 L p .734 .088 .941 r
F P
0 g
s
.53992 .55284 m .53481 .53699 L .54956 .52799 L p .734 .082 .909 r
F P
0 g
s
.54956 .52799 m .56033 .54296 L .53992 .55284 L p .734 .082 .909 r
F P
0 g
s
.51745 .38251 m .51859 .38352 L .51779 .37771 L p .578 .078 .888 r
F P
0 g
s
.51779 .37771 m .51634 .37686 L .51745 .38251 L p .578 .078 .888 r
F P
0 g
s
.27791 .60969 m .3448 .58945 L .37055 .60134 L p .868 .076 .881 r
F P
0 g
s
.41202 .58151 m .37055 .60134 L .3448 .58945 L p .862 .082 .912 r
F P
0 g
s
.37055 .60134 m .41202 .58151 L .43456 .58605 L p .843 .083 .915 r
F P
0 g
s
.56033 .54296 m .54956 .52799 L .56311 .51731 L p .739 .076 .878 r
F P
0 g
s
.56311 .51731 m .57913 .53078 L .56033 .54296 L p .739 .076 .878 r
F P
0 g
s
.50192 .36851 m .50749 .37173 L .50508 .36748 L p .532 .032 .662 r
F P
0 g
s
.50508 .36748 m .49856 .36503 L .50192 .36851 L p .532 .032 .662 r
F P
0 g
s
.51586 .3811 m .51745 .38251 L .51634 .37686 L p .577 .077 .884 r
F P
0 g
s
.51634 .37686 m .5143 .37569 L .51586 .3811 L p .577 .077 .884 r
F P
0 g
s
.52133 .39211 m .52137 .39217 L .52132 .38594 L p .603 .103 1 r
F P
0 g
s
.52132 .38594 m .52127 .38589 L .52133 .39211 L p .603 .103 1 r
F P
0 g
s
.45871 .35006 m .47666 .3568 L .47217 .35671 L p 1 .057 .784 r
F P
0 g
s
.47217 .35671 m .45251 .35242 L .45871 .35006 L p 1 .057 .784 r
F P
0 g
s
.52128 .39204 m .52133 .39211 L .52127 .38589 L p .603 .103 1 r
F P
0 g
s
.52127 .38589 m .52119 .38582 L .52128 .39204 L p .603 .103 1 r
F P
0 g
s
.64264 .51237 m .6089 .50034 L .61858 .48273 L p .795 .059 .795 r
F P
0 g
s
.61858 .48273 m .6564 .49056 L .64264 .51237 L p .795 .059 .795 r
F P
0 g
s
.5212 .39193 m .52128 .39204 L .52119 .38582 L p .603 .103 1 r
F P
0 g
s
.52119 .38582 m .52108 .38572 L .5212 .39193 L p .603 .103 1 r
F P
0 g
s
.5211 .39177 m .5212 .39193 L .52108 .38572 L p .603 .103 1 r
F P
0 g
s
.52108 .38572 m .52092 .38558 L .5211 .39177 L p .603 .103 1 r
F P
0 g
s
.52095 .39156 m .5211 .39177 L .52092 .38558 L p .603 .103 1 r
F P
0 g
s
.52092 .38558 m .52071 .38539 L .52095 .39156 L p .603 .103 1 r
F P
0 g
s
.51364 .37913 m .51586 .3811 L .5143 .37569 L p .575 .075 .873 r
F P
0 g
s
.5143 .37569 m .51146 .37404 L .51364 .37913 L p .575 .075 .873 r
F P
0 g
s
.52075 .39126 m .52095 .39156 L .52071 .38539 L p .603 .103 1 r
F P
0 g
s
.52071 .38539 m .52041 .38513 L .52075 .39126 L p .603 .103 1 r
F P
0 g
s
.52047 .39085 m .52075 .39126 L .52041 .38513 L p .604 .104 1 r
F P
0 g
s
.52041 .38513 m .51999 .38476 L .52047 .39085 L p .604 .104 1 r
F P
0 g
s
.51946 .54425 m .5187 .56031 L .4975 .56534 L p .739 .094 .972 r
F P
0 g
s
.5187 .56031 m .51946 .54425 L .53481 .53699 L p .734 .088 .941 r
F P
0 g
s
.52007 .39027 m .52047 .39085 L .51999 .38476 L p .604 .104 1 r
F P
0 g
s
.51999 .38476 m .51941 .38424 L .52007 .39027 L p .604 .104 1 r
F P
0 g
s
.57913 .53078 m .56311 .51731 L .5749 .50512 L p .747 .069 .847 r
F P
0 g
s
.5749 .50512 m .59555 .51648 L .57913 .53078 L p .747 .069 .847 r
F P
0 g
s
.49412 .36399 m .50192 .36851 L .49856 .36503 L p .506 .006 .531 r
F P
0 g
s
.49856 .36503 m .48944 .36161 L .49412 .36399 L p .506 .006 .531 r
F P
0 g
s
.70862 .50136 m .6564 .49056 L .6645 .46721 L p .822 .057 .783 r
F P
0 g
s
.6645 .46721 m .7206 .47156 L .70862 .50136 L p .822 .057 .783 r
F P
0 g
s
.51952 .38946 m .52007 .39027 L .51941 .38424 L p .605 .105 1 r
F P
0 g
s
.51941 .38424 m .51859 .38352 L .51952 .38946 L p .605 .105 1 r
F P
0 g
s
.2539 .30913 m .33142 .32603 L .32455 .34522 L p .899 .064 .819 r
F P
0 g
s
.32455 .34522 m .24571 .33878 L .2539 .30913 L p .899 .064 .819 r
F P
0 g
s
.51052 .37637 m .51364 .37913 L .51146 .37404 L p .569 .069 .845 r
F P
0 g
s
.51146 .37404 m .50749 .37173 L .51052 .37637 L p .569 .069 .845 r
F P
0 g
s
.51875 .38833 m .51952 .38946 L .51859 .38352 L p .605 .105 1 r
F P
0 g
s
.51859 .38352 m .51745 .38251 L .51875 .38833 L p .605 .105 1 r
F P
0 g
s
.92887 .43671 m .9626 .49034 L p .91815 .43154 L .854 .058 .792 r
F P
0 g
s
.9626 .49034 m .90619 .48596 L .91815 .43154 L p .854 .058 .792 r
F P
0 g
s
.51768 .38675 m .51875 .38833 L .51745 .38251 L p .605 .105 1 r
F P
0 g
s
.51745 .38251 m .51586 .3811 L .51768 .38675 L p .605 .105 1 r
F P
0 g
s
.5214 .39837 m .52142 .39843 L .52137 .39217 L p .635 .135 1 r
F P
0 g
s
.52137 .39217 m .52133 .39211 L .5214 .39837 L p .635 .135 1 r
F P
0 g
s
.52138 .39829 m .5214 .39837 L .52133 .39211 L p .635 .135 1 r
F P
0 g
s
.52133 .39211 m .52128 .39204 L .52138 .39829 L p .635 .135 1 r
F P
0 g
s
.52134 .39817 m .52138 .39829 L .52128 .39204 L p .636 .136 1 r
F P
0 g
s
.52128 .39204 m .5212 .39193 L .52134 .39817 L p .636 .136 1 r
F P
0 g
s
.52129 .39801 m .52134 .39817 L .5212 .39193 L p .636 .136 1 r
F P
0 g
s
.5212 .39193 m .5211 .39177 L .52129 .39801 L p .636 .136 1 r
F P
0 g
s
.52122 .39779 m .52129 .39801 L .5211 .39177 L p .636 .136 1 r
F P
0 g
s
.5211 .39177 m .52095 .39156 L .52122 .39779 L p .636 .136 1 r
F P
0 g
s
.52113 .39747 m .52122 .39779 L .52095 .39156 L p .637 .137 1 r
F P
0 g
s
.52095 .39156 m .52075 .39126 L .52113 .39747 L p .637 .137 1 r
F P
0 g
s
.43345 .34057 m .45871 .35006 L .45251 .35242 L p 1 .061 .803 r
F P
0 g
s
.45251 .35242 m .42493 .34641 L .43345 .34057 L p 1 .061 .803 r
F P
0 g
s
.52099 .39703 m .52113 .39747 L .52075 .39126 L p .637 .137 1 r
F P
0 g
s
.52075 .39126 m .52047 .39085 L .52099 .39703 L p .637 .137 1 r
F P
0 g
s
.50617 .37251 m .51052 .37637 L .50749 .37173 L p .554 .054 .769 r
F P
0 g
s
.50749 .37173 m .50192 .36851 L .50617 .37251 L p .554 .054 .769 r
F P
0 g
s
.45854 .5685 m .43456 .58605 L .41202 .58151 L p .826 .092 .961 r
F P
0 g
s
.43456 .58605 m .45854 .5685 L .47718 .56802 L p .805 .091 .956 r
F P
0 g
s
.48318 .35764 m .49412 .36399 L .48944 .36161 L p 1 .025 .624 r
F P
0 g
s
.48944 .36161 m .47666 .3568 L .48318 .35764 L p 1 .025 .624 r
F P
0 g
s
.51617 .38455 m .51768 .38675 L .51586 .3811 L p .603 .103 1 r
F P
0 g
s
.51586 .3811 m .51364 .37913 L .51617 .38455 L p .603 .103 1 r
F P
0 g
s
.5208 .39642 m .52099 .39703 L .52047 .39085 L p .638 .138 1 r
F P
0 g
s
.52047 .39085 m .52007 .39027 L .5208 .39642 L p .638 .138 1 r
F P
0 g
s
.52054 .39556 m .5208 .39642 L .52007 .39027 L p .638 .138 1 r
F P
0 g
s
.52007 .39027 m .51952 .38946 L .52054 .39556 L p .638 .138 1 r
F P
0 g
s
.50414 .54973 m .4975 .56534 L .47718 .56802 L p .75 .1 .999 r
F P
0 g
s
.4975 .56534 m .50414 .54973 L .51946 .54425 L p .739 .094 .972 r
F P
0 g
s
.59555 .51648 m .5749 .50512 L .58442 .49162 L p .759 .064 .818 r
F P
0 g
s
.58442 .49162 m .6089 .50034 L .59555 .51648 L p .759 .064 .818 r
F P
0 g
s
.52017 .39436 m .52054 .39556 L .51952 .38946 L p .638 .138 1 r
F P
0 g
s
.51952 .38946 m .51875 .38833 L .52017 .39436 L p .638 .138 1 r
F P
0 g
s
.51406 .38146 m .51617 .38455 L .51364 .37913 L p .594 .094 .969 r
F P
0 g
s
.51364 .37913 m .51052 .37637 L .51406 .38146 L p .594 .094 .969 r
F P
0 g
s
.52147 .40467 m .52147 .40473 L .52142 .39843 L p .672 .172 1 r
F P
0 g
s
.52142 .39843 m .5214 .39837 L .52147 .40467 L p .672 .172 1 r
F P
0 g
s
.52148 .40458 m .52147 .40467 L .5214 .39837 L p .672 .172 1 r
F P
0 g
s
.5214 .39837 m .52138 .39829 L .52148 .40458 L p .672 .172 1 r
F P
0 g
s
.52148 .40446 m .52148 .40458 L .52138 .39829 L p .672 .172 1 r
F P
0 g
s
.52138 .39829 m .52134 .39817 L .52148 .40446 L p .672 .172 1 r
F P
0 g
s
.52149 .4043 m .52148 .40446 L .52134 .39817 L p .672 .172 1 r
F P
0 g
s
.52134 .39817 m .52129 .39801 L .52149 .4043 L p .672 .172 1 r
F P
0 g
s
.51966 .39268 m .52017 .39436 L .51875 .38833 L p .636 .136 1 r
F P
0 g
s
.51875 .38833 m .51768 .38675 L .51966 .39268 L p .636 .136 1 r
F P
0 g
s
.90619 .48596 m .79844 .4776 L .80489 .4367 L p .849 .057 .786 r
F P
0 g
s
.80489 .4367 m .91815 .43154 L .90619 .48596 L p .849 .057 .786 r
F P
0 g
s
.5215 .40407 m .52149 .4043 L .52129 .39801 L p .672 .172 1 r
F P
0 g
s
.52129 .39801 m .52122 .39779 L .5215 .40407 L p .672 .172 1 r
F P
0 g
s
.50192 .36851 m .49412 .36399 L .50005 .36709 L p 1 0 .5 r
F P
0 g
s
.50005 .36709 m .50617 .37251 L .50192 .36851 L p 1 0 .5 r
F P
0 g
s
.52152 .40375 m .5215 .40407 L .52122 .39779 L p .671 .171 1 r
F P
0 g
s
.52122 .39779 m .52113 .39747 L .52152 .40375 L p .671 .171 1 r
F P
0 g
s
.52154 .4033 m .52152 .40375 L .52113 .39747 L p .671 .171 1 r
F P
0 g
s
.52113 .39747 m .52099 .39703 L .52154 .4033 L p .671 .171 1 r
F P
0 g
s
.1434 .28504 m .2539 .30913 L .24571 .33878 L p .887 .063 .813 r
F P
0 g
s
.24571 .33878 m .13479 .32972 L .1434 .28504 L p .887 .063 .813 r
F P
0 g
s
.52156 .40268 m .52154 .4033 L .52099 .39703 L p .669 .169 1 r
F P
0 g
s
.52099 .39703 m .5208 .39642 L .52156 .40268 L p .669 .169 1 r
F P
0 g
s
.51895 .39033 m .51966 .39268 L .51768 .38675 L p .629 .129 1 r
F P
0 g
s
.51768 .38675 m .51617 .38455 L .51895 .39033 L p .629 .129 1 r
F P
0 g
s
.5216 .40181 m .52156 .40268 L .5208 .39642 L p .667 .167 1 r
F P
0 g
s
.5208 .39642 m .52054 .39556 L .5216 .40181 L p .667 .167 1 r
F P
0 g
s
.51111 .37713 m .51406 .38146 L .51052 .37637 L p .57 .07 .852 r
F P
0 g
s
.51052 .37637 m .50617 .37251 L .51111 .37713 L p .57 .07 .852 r
F P
0 g
s
.46778 .34872 m .48318 .35764 L .47666 .3568 L p 1 .043 .716 r
F P
0 g
s
.47666 .3568 m .45871 .35006 L .46778 .34872 L p 1 .043 .716 r
F P
0 g
s
.52166 .40059 m .5216 .40181 L .52054 .39556 L p .661 .161 1 r
F P
0 g
s
.52054 .39556 m .52017 .39436 L .52166 .40059 L p .661 .161 1 r
F P
0 g
s
.39776 .32716 m .43345 .34057 L .42493 .34641 L p .962 .061 .807 r
F P
0 g
s
.42493 .34641 m .38614 .33795 L .39776 .32716 L p .962 .061 .807 r
F P
0 g
s
.52155 .41099 m .52152 .41105 L .52147 .40473 L p 1 0 .5 r
F P
0 g
s
.52147 .40473 m .52147 .40467 L .52155 .41099 L p 1 0 .5 r
F P
0 g
s
.52158 .41091 m .52155 .41099 L .52147 .40467 L p 1 0 .5 r
F P
0 g
s
.52147 .40467 m .52148 .40458 L .52158 .41091 L p 1 0 .5 r
F P
0 g
s
.52163 .4108 m .52158 .41091 L .52148 .40458 L p 1 0 .5 r
F P
0 g
s
.52148 .40458 m .52148 .40446 L .52163 .4108 L p 1 0 .5 r
F P
0 g
s
.52169 .41064 m .52163 .4108 L .52148 .40446 L p 1 0 .5 r
F P
0 g
s
.52148 .40446 m .52149 .4043 L .52169 .41064 L p 1 0 .5 r
F P
0 g
s
.52178 .41041 m .52169 .41064 L .52149 .4043 L p 1 0 .5 r
F P
0 g
s
.52149 .4043 m .5215 .40407 L .52178 .41041 L p 1 0 .5 r
F P
0 g
s
.52174 .39889 m .52166 .40059 L .52017 .39436 L p 1 0 .5 r
F P
0 g
s
.52017 .39436 m .51966 .39268 L .52174 .39889 L p 1 0 .5 r
F P
0 g
s
.51794 .38705 m .51895 .39033 L .51617 .38455 L p 1 0 .5 r
F P
0 g
s
.51617 .38455 m .51406 .38146 L .51794 .38705 L p 1 0 .5 r
F P
0 g
s
.52191 .4101 m .52178 .41041 L .5215 .40407 L p 1 0 .5 r
F P
0 g
s
.5215 .40407 m .52152 .40375 L .52191 .4101 L p 1 0 .5 r
F P
0 g
s
.52208 .40967 m .52191 .4101 L .52152 .40375 L p 1 0 .5 r
F P
0 g
s
.52152 .40375 m .52154 .4033 L .52208 .40967 L p 1 0 .5 r
F P
0 g
s
.52232 .40906 m .52208 .40967 L .52154 .4033 L p 1 0 .5 r
F P
0 g
s
.52154 .4033 m .52156 .40268 L .52232 .40906 L p 1 0 .5 r
F P
0 g
s
.49146 .35948 m .50005 .36709 L .49412 .36399 L p 1 .011 .554 r
F P
0 g
s
.49412 .36399 m .48318 .35764 L .49146 .35948 L p 1 .011 .554 r
F P
0 g
s
.52267 .40822 m .52232 .40906 L .52156 .40268 L p 1 0 .5 r
F P
0 g
s
.52156 .40268 m .5216 .40181 L .52267 .40822 L p 1 0 .5 r
F P
0 g
s
.52184 .3965 m .52174 .39889 L .51966 .39268 L p 1 0 .5 r
F P
0 g
s
.51966 .39268 m .51895 .39033 L .52184 .3965 L p 1 0 .5 r
F P
0 g
s
.6564 .49056 m .61858 .48273 L .62414 .46408 L p .807 .055 .775 r
F P
0 g
s
.62414 .46408 m .6645 .46721 L .6564 .49056 L p .807 .055 .775 r
F P
0 g
s
.6089 .50034 m .58442 .49162 L .59127 .47708 L p .772 .058 .79 r
F P
0 g
s
.59127 .47708 m .61858 .48273 L .6089 .50034 L p .772 .058 .79 r
F P
0 g
s
.50697 .37105 m .51111 .37713 L .50617 .37251 L p 1 0 .5 r
F P
0 g
s
.50617 .37251 m .50005 .36709 L .50697 .37105 L p 1 0 .5 r
F P
0 g
s
.52314 .40703 m .52267 .40822 L .5216 .40181 L p 1 0 .5 r
F P
0 g
s
.5216 .40181 m .52166 .40059 L .52314 .40703 L p 1 0 .5 r
F P
0 g
s
.48946 .55351 m .47718 .56802 L .45854 .5685 L p .769 .104 1 r
F P
0 g
s
.47718 .56802 m .48946 .55351 L .50414 .54973 L p .75 .1 .999 r
F P
0 g
s
.52162 .41735 m .52158 .41741 L .52152 .41105 L p 1 0 .5 r
F P
0 g
s
.52152 .41105 m .52155 .41099 L .52162 .41735 L p 1 0 .5 r
F P
0 g
s
.52168 .41728 m .52162 .41735 L .52155 .41099 L p 1 0 .5 r
F P
0 g
s
.52155 .41099 m .52158 .41091 L .52168 .41728 L p 1 0 .5 r
F P
0 g
s
.52176 .41717 m .52168 .41728 L .52158 .41091 L p 1 0 .5 r
F P
0 g
s
.52158 .41091 m .52163 .4108 L .52176 .41717 L p 1 0 .5 r
F P
0 g
s
.51654 .38244 m .51794 .38705 L .51406 .38146 L p 1 0 .5 r
F P
0 g
s
.51406 .38146 m .51111 .37713 L .51654 .38244 L p 1 0 .5 r
F P
0 g
s
.52188 .41702 m .52176 .41717 L .52163 .4108 L p 1 0 .5 r
F P
0 g
s
.52163 .4108 m .52169 .41064 L .52188 .41702 L p 1 0 .5 r
F P
0 g
s
.52205 .41682 m .52188 .41702 L .52169 .41064 L p 1 0 .5 r
F P
0 g
s
.52169 .41064 m .52178 .41041 L .52205 .41682 L p 1 0 .5 r
F P
0 g
s
.52228 .41653 m .52205 .41682 L .52178 .41041 L p 1 0 .5 r
F P
0 g
s
.52178 .41041 m .52191 .4101 L .52228 .41653 L p 1 0 .5 r
F P
0 g
s
.52381 .40538 m .52314 .40703 L .52166 .40059 L p 1 0 .5 r
F P
0 g
s
.52166 .40059 m .52174 .39889 L .52381 .40538 L p 1 0 .5 r
F P
0 g
s
.54172 .5171 m .54956 .52799 L .53481 .53699 L p .689 .088 .938 r
F P
0 g
s
.54956 .52799 m .54172 .5171 L .55147 .50754 L p .699 .079 .895 r
F P
0 g
s
.55147 .50754 m .56311 .51731 L .54956 .52799 L p .699 .079 .895 r
F P
0 g
s
.5226 .41613 m .52228 .41653 L .52191 .4101 L p 1 0 .5 r
F P
0 g
s
.52191 .4101 m .52208 .40967 L .5226 .41613 L p 1 0 .5 r
F P
0 g
s
.52199 .39317 m .52184 .3965 L .51895 .39033 L p 1 0 .5 r
F P
0 g
s
.51895 .39033 m .51794 .38705 L .52199 .39317 L p 1 0 .5 r
F P
0 g
s
.52305 .41556 m .5226 .41613 L .52208 .40967 L p 1 0 .5 r
F P
0 g
s
.52208 .40967 m .52232 .40906 L .52305 .41556 L p 1 0 .5 r
F P
0 g
s
.53109 .52546 m .53481 .53699 L .51946 .54425 L p .684 .097 .984 r
F P
0 g
s
.53481 .53699 m .53109 .52546 L .54172 .5171 L p .689 .088 .938 r
F P
0 g
s
.56311 .51731 m .55147 .50754 L .55993 .49689 L p .712 .071 .855 r
F P
0 g
s
.55993 .49689 m .5749 .50512 L .56311 .51731 L p .712 .071 .855 r
F P
0 g
s
.52368 .41478 m .52305 .41556 L .52232 .40906 L p 1 0 .5 r
F P
0 g
s
.52232 .40906 m .52267 .40822 L .52368 .41478 L p 1 0 .5 r
F P
0 g
s
.44604 .33612 m .46778 .34872 L .45871 .35006 L p 1 .051 .757 r
F P
0 g
s
.45871 .35006 m .43345 .34057 L .44604 .33612 L p 1 .051 .757 r
F P
0 g
s
.79844 .4776 m .7206 .47156 L .72414 .44038 L p .842 .056 .778 r
F P
0 g
s
.72414 .44038 m .80489 .4367 L .79844 .4776 L p .842 .056 .778 r
F P
0 g
s
.52474 .40307 m .52381 .40538 L .52174 .39889 L p 1 0 .5 r
F P
0 g
s
.52174 .39889 m .52184 .3965 L .52474 .40307 L p 1 0 .5 r
F P
0 g
s
.04094 .28018 m .07379 .26986 L p .13479 .32972 L .879 .062 .809 r
F P
0 g
s
.07379 .26986 m .1434 .28504 L .13479 .32972 L p .879 .062 .809 r
F P
0 g
s
.13479 .32972 m .07587 .3249 L p .04094 .28018 L .879 .062 .809 r
F P
0 g
s
.52455 .41368 m .52368 .41478 L .52267 .40822 L p 1 0 .5 r
F P
0 g
s
.52267 .40822 m .52314 .40703 L .52455 .41368 L p 1 0 .5 r
F P
0 g
s
.52168 .42374 m .52162 .42379 L .52158 .41741 L p 1 0 .5 r
F P
0 g
s
.52158 .41741 m .52162 .41735 L .52168 .42374 L p 1 0 .5 r
F P
0 g
s
.52177 .42368 m .52168 .42374 L .52162 .41735 L p 1 0 .5 r
F P
0 g
s
.52162 .41735 m .52168 .41728 L .52177 .42368 L p 1 0 .5 r
F P
0 g
s
.52189 .42358 m .52177 .42368 L .52168 .41728 L p 1 0 .5 r
F P
0 g
s
.52168 .41728 m .52176 .41717 L .52189 .42358 L p 1 0 .5 r
F P
0 g
s
.52206 .42345 m .52189 .42358 L .52176 .41717 L p 1 0 .5 r
F P
0 g
s
.52176 .41717 m .52188 .41702 L .52206 .42345 L p 1 0 .5 r
F P
0 g
s
.52229 .42327 m .52206 .42345 L .52188 .41702 L p 1 0 .5 r
F P
0 g
s
.52188 .41702 m .52205 .41682 L .52229 .42327 L p 1 0 .5 r
F P
0 g
s
.52578 .41215 m .52455 .41368 L .52314 .40703 L p 1 0 .5 r
F P
0 g
s
.52314 .40703 m .52381 .40538 L .52578 .41215 L p 1 0 .5 r
F P
0 g
s
.52262 .42302 m .52229 .42327 L .52205 .41682 L p 1 0 .5 r
F P
0 g
s
.52205 .41682 m .52228 .41653 L .52262 .42302 L p 1 0 .5 r
F P
0 g
s
.5749 .50512 m .55993 .49689 L .56674 .48531 L p .728 .064 .818 r
F P
0 g
s
.56674 .48531 m .58442 .49162 L .5749 .50512 L p .728 .064 .818 r
F P
0 g
s
.47935 .34875 m .49146 .35948 L .48318 .35764 L p 1 .032 .661 r
F P
0 g
s
.48318 .35764 m .46778 .34872 L .47935 .34875 L p 1 .032 .661 r
F P
0 g
s
.34711 .30814 m .39776 .32716 L .38614 .33795 L p .93 .061 .806 r
F P
0 g
s
.38614 .33795 m .33142 .32603 L .34711 .30814 L p .93 .061 .806 r
F P
0 g
s
.52221 .3885 m .52199 .39317 L .51794 .38705 L p 1 0 .5 r
F P
0 g
s
.51794 .38705 m .51654 .38244 L .52221 .3885 L p 1 0 .5 r
F P
0 g
s
.52307 .42267 m .52262 .42302 L .52228 .41653 L p 1 0 .5 r
F P
0 g
s
.52228 .41653 m .5226 .41613 L .52307 .42267 L p 1 0 .5 r
F P
0 g
s
.52002 .53255 m .51946 .54425 L .50414 .54973 L p .684 .106 1 r
F P
0 g
s
.51946 .54425 m .52002 .53255 L .53109 .52546 L p .684 .097 .984 r
F P
0 g
s
.51456 .37598 m .51654 .38244 L .51111 .37713 L p 1 0 .5 r
F P
0 g
s
.51111 .37713 m .50697 .37105 L .51456 .37598 L p 1 0 .5 r
F P
0 g
s
.50114 .36251 m .50697 .37105 L .50005 .36709 L p 1 .002 .511 r
F P
0 g
s
.50005 .36709 m .49146 .35948 L .50114 .36251 L p 1 .002 .511 r
F P
0 g
s
.52604 .39983 m .52474 .40307 L .52184 .3965 L p 1 0 .5 r
F P
0 g
s
.52184 .3965 m .52199 .39317 L .52604 .39983 L p 1 0 .5 r
F P
0 g
s
.52371 .42217 m .52307 .42267 L .5226 .41613 L p 1 0 .5 r
F P
0 g
s
.5226 .41613 m .52305 .41556 L .52371 .42217 L p 1 0 .5 r
F P
0 g
s
.5246 .42149 m .52371 .42217 L .52305 .41556 L p 1 0 .5 r
F P
0 g
s
.52305 .41556 m .52368 .41478 L .5246 .42149 L p 1 0 .5 r
F P
0 g
s
.52749 .41001 m .52578 .41215 L .52381 .40538 L p 1 0 .5 r
F P
0 g
s
.52381 .40538 m .52474 .40307 L .52749 .41001 L p 1 0 .5 r
F P
0 g
s
.52584 .42053 m .5246 .42149 L .52368 .41478 L p 1 0 .5 r
F P
0 g
s
.52368 .41478 m .52455 .41368 L .52584 .42053 L p 1 0 .5 r
F P
0 g
s
.3448 .58945 m .39374 .57464 L .41202 .58151 L p .862 .082 .912 r
F P
0 g
s
.44236 .567 m .41202 .58151 L .39374 .57464 L p .852 .091 .957 r
F P
0 g
s
.41202 .58151 m .44236 .567 L .45854 .5685 L p .826 .092 .961 r
F P
0 g
s
.52174 .43017 m .52166 .4302 L .52162 .42379 L p .976 0 .5 r
F P
0 g
s
.52162 .42379 m .52168 .42374 L .52174 .43017 L p .976 0 .5 r
F P
0 g
s
.52184 .43011 m .52174 .43017 L .52168 .42374 L p .976 0 .5 r
F P
0 g
s
.52168 .42374 m .52177 .42368 L .52184 .43011 L p .976 0 .5 r
F P
0 g
s
.52199 .43004 m .52184 .43011 L .52177 .42368 L p .976 0 .5 r
F P
0 g
s
.52177 .42368 m .52189 .42358 L .52199 .43004 L p .976 0 .5 r
F P
0 g
s
.61858 .48273 m .59127 .47708 L .59513 .46183 L p .788 .053 .765 r
F P
0 g
s
.59513 .46183 m .62414 .46408 L .61858 .48273 L p .788 .053 .765 r
F P
0 g
s
.5222 .42993 m .52199 .43004 L .52189 .42358 L p .975 0 .5 r
F P
0 g
s
.52189 .42358 m .52206 .42345 L .5222 .42993 L p .975 0 .5 r
F P
0 g
s
.52757 .41918 m .52584 .42053 L .52455 .41368 L p 1 0 .5 r
F P
0 g
s
.52455 .41368 m .52578 .41215 L .52757 .41918 L p 1 0 .5 r
F P
0 g
s
.5225 .42978 m .5222 .42993 L .52206 .42345 L p .975 0 .5 r
F P
0 g
s
.52206 .42345 m .52229 .42327 L .5225 .42978 L p .975 0 .5 r
F P
0 g
s
.07587 .3249 m .0276 .28475 L .04094 .28018 L p .879 .062 .809 r
F P
0 g
s
.52291 .42957 m .5225 .42978 L .52229 .42327 L p .974 0 .5 r
F P
0 g
s
.52229 .42327 m .52262 .42302 L .52291 .42957 L p .974 0 .5 r
F P
0 g
s
.52347 .42929 m .52291 .42957 L .52262 .42302 L p .972 0 .5 r
F P
0 g
s
.52262 .42302 m .52307 .42267 L .52347 .42929 L p .972 0 .5 r
F P
0 g
s
.52989 .40701 m .52749 .41001 L .52474 .40307 L p 1 0 .5 r
F P
0 g
s
.52474 .40307 m .52604 .39983 L .52989 .40701 L p 1 0 .5 r
F P
0 g
s
.52786 .3953 m .52604 .39983 L .52199 .39317 L p 1 0 .5 r
F P
0 g
s
.52199 .39317 m .52221 .3885 L .52786 .3953 L p 1 0 .5 r
F P
0 g
s
.58442 .49162 m .56674 .48531 L .5716 .47301 L p .746 .057 .784 r
F P
0 g
s
.5716 .47301 m .59127 .47708 L .58442 .49162 L p .746 .057 .784 r
F P
0 g
s
.52427 .42888 m .52347 .42929 L .52307 .42267 L p .97 0 .5 r
F P
0 g
s
.52307 .42267 m .52371 .42217 L .52427 .42888 L p .97 0 .5 r
F P
0 g
s
.7206 .47156 m .6645 .46721 L .66647 .44301 L p .833 .054 .769 r
F P
0 g
s
.66647 .44301 m .72414 .44038 L .7206 .47156 L p .833 .054 .769 r
F P
0 g
s
.52538 .42832 m .52427 .42888 L .52371 .42217 L p .968 0 .5 r
F P
0 g
s
.52371 .42217 m .5246 .42149 L .52538 .42832 L p .968 0 .5 r
F P
0 g
s
.53 .41731 m .52757 .41918 L .52578 .41215 L p 1 0 .5 r
F P
0 g
s
.52578 .41215 m .52749 .41001 L .53 .41731 L p 1 0 .5 r
F P
0 g
s
.5225 .38193 m .52221 .3885 L .51654 .38244 L p 1 0 .5 r
F P
0 g
s
.51654 .38244 m .51456 .37598 L .5225 .38193 L p 1 0 .5 r
F P
0 g
s
.50896 .53837 m .50414 .54973 L .48946 .55351 L p .693 .115 1 r
F P
0 g
s
.50414 .54973 m .50896 .53837 L .52002 .53255 L p .684 .106 1 r
F P
0 g
s
.52693 .42754 m .52538 .42832 L .5246 .42149 L p .964 0 .5 r
F P
0 g
s
.5246 .42149 m .52584 .42053 L .52693 .42754 L p .964 0 .5 r
F P
0 g
s
.47603 .55569 m .45854 .5685 L .44236 .567 L p .796 .106 1 r
F P
0 g
s
.45854 .5685 m .47603 .55569 L .48946 .55351 L p .769 .104 1 r
F P
0 g
s
.5291 .42644 m .52693 .42754 L .52584 .42053 L p .958 0 .5 r
F P
0 g
s
.52584 .42053 m .52757 .41918 L .5291 .42644 L p .958 0 .5 r
F P
0 g
s
.51178 .36689 m .51456 .37598 L .50697 .37105 L p 1 0 .5 r
F P
0 g
s
.50697 .37105 m .50114 .36251 L .51178 .36689 L p 1 0 .5 r
F P
0 g
s
.52178 .43662 m .52169 .43665 L .52166 .4302 L p .863 0 .5 r
F P
0 g
s
.52166 .4302 m .52174 .43017 L .52178 .43662 L p .863 0 .5 r
F P
0 g
s
.5219 .43658 m .52178 .43662 L .52174 .43017 L p .863 0 .5 r
F P
0 g
s
.52174 .43017 m .52184 .43011 L .5219 .43658 L p .863 0 .5 r
F P
0 g
s
.52208 .43652 m .5219 .43658 L .52184 .43011 L p .864 0 .5 r
F P
0 g
s
.52184 .43011 m .52199 .43004 L .52208 .43652 L p .864 0 .5 r
F P
0 g
s
.52232 .43645 m .52208 .43652 L .52199 .43004 L p .864 0 .5 r
F P
0 g
s
.52199 .43004 m .5222 .42993 L .52232 .43645 L p .864 0 .5 r
F P
0 g
s
.52266 .43634 m .52232 .43645 L .5222 .42993 L p .864 0 .5 r
F P
0 g
s
.5222 .42993 m .5225 .42978 L .52266 .43634 L p .864 0 .5 r
F P
0 g
s
.52313 .43619 m .52266 .43634 L .5225 .42978 L p .864 0 .5 r
F P
0 g
s
.5225 .42978 m .52291 .42957 L .52313 .43619 L p .864 0 .5 r
F P
0 g
s
.53339 .41468 m .53 .41731 L .52749 .41001 L p 1 0 .5 r
F P
0 g
s
.52749 .41001 m .52989 .40701 L .53339 .41468 L p 1 0 .5 r
F P
0 g
s
.52379 .43597 m .52313 .43619 L .52291 .42957 L p .864 0 .5 r
F P
0 g
s
.52291 .42957 m .52347 .42929 L .52379 .43597 L p .864 0 .5 r
F P
0 g
s
.53326 .40282 m .52989 .40701 L .52604 .39983 L p 1 0 .5 r
F P
0 g
s
.52604 .39983 m .52786 .3953 L .53326 .40282 L p 1 0 .5 r
F P
0 g
s
.41522 .31825 m .44604 .33612 L .43345 .34057 L p .975 .055 .776 r
F P
0 g
s
.43345 .34057 m .39776 .32716 L .41522 .31825 L p .975 .055 .776 r
F P
0 g
s
.52471 .43568 m .52379 .43597 L .52347 .42929 L p .864 0 .5 r
F P
0 g
s
.52347 .42929 m .52427 .42888 L .52471 .43568 L p .864 0 .5 r
F P
0 g
s
.53213 .42491 m .5291 .42644 L .52757 .41918 L p .95 0 .5 r
F P
0 g
s
.52757 .41918 m .53 .41731 L .53213 .42491 L p .95 0 .5 r
F P
0 g
s
.526 .43527 m .52471 .43568 L .52427 .42888 L p .864 0 .5 r
F P
0 g
s
.52427 .42888 m .52538 .42832 L .526 .43527 L p .864 0 .5 r
F P
0 g
s
.49291 .35045 m .50114 .36251 L .49146 .35948 L p 1 .024 .622 r
F P
0 g
s
.49146 .35948 m .47935 .34875 L .49291 .35045 L p 1 .024 .622 r
F P
0 g
s
.54305 .50047 m .55147 .50754 L .54172 .5171 L p .652 .083 .915 r
F P
0 g
s
.55147 .50754 m .54305 .50047 L .54912 .49095 L p .672 .073 .864 r
F P
0 g
s
.54912 .49095 m .55993 .49689 L .55147 .50754 L p .672 .073 .864 r
F P
0 g
s
.52779 .43469 m .526 .43527 L .52538 .42832 L p .864 0 .5 r
F P
0 g
s
.52538 .42832 m .52693 .42754 L .52779 .43469 L p .864 0 .5 r
F P
0 g
s
.53605 .50921 m .54172 .5171 L .53109 .52546 L p .634 .094 .972 r
F P
0 g
s
.54172 .5171 m .53605 .50921 L .54305 .50047 L p .652 .083 .915 r
F P
0 g
s
.53043 .38893 m .52786 .3953 L .52221 .3885 L p 1 0 .5 r
F P
0 g
s
.52221 .3885 m .5225 .38193 L .53043 .38893 L p 1 0 .5 r
F P
0 g
s
.55993 .49689 m .54912 .49095 L .55399 .48077 L p .694 .064 .818 r
F P
0 g
s
.55399 .48077 m .56674 .48531 L .55993 .49689 L p .694 .064 .818 r
F P
0 g
s
.46222 .33357 m .47935 .34875 L .46778 .34872 L p 1 .044 .718 r
F P
0 g
s
.46778 .34872 m .44604 .33612 L .46222 .33357 L p 1 .044 .718 r
F P
0 g
s
.6645 .46721 m .62414 .46408 L .62526 .44489 L p .821 .051 .756 r
F P
0 g
s
.62526 .44489 m .66647 .44301 L .6645 .46721 L p .821 .051 .756 r
F P
0 g
s
.59127 .47708 m .5716 .47301 L .57429 .46021 L p .767 .051 .753 r
F P
0 g
s
.57429 .46021 m .59513 .46183 L .59127 .47708 L p .767 .051 .753 r
F P
0 g
s
.5303 .43389 m .52779 .43469 L .52693 .42754 L p .864 0 .5 r
F P
0 g
s
.52693 .42754 m .5291 .42644 L .5303 .43389 L p .864 0 .5 r
F P
0 g
s
.53637 .42277 m .53213 .42491 L .53 .41731 L p .939 0 .5 r
F P
0 g
s
.53 .41731 m .53339 .41468 L .53637 .42277 L p .939 0 .5 r
F P
0 g
s
.53814 .411 m .53339 .41468 L .52989 .40701 L p 1 0 .5 r
F P
0 g
s
.52989 .40701 m .53326 .40282 L .53814 .411 L p 1 0 .5 r
F P
0 g
s
.52181 .4431 m .52171 .44312 L .52169 .43665 L p .774 0 .5 r
F P
0 g
s
.52169 .43665 m .52178 .43662 L .52181 .4431 L p .774 0 .5 r
F P
0 g
s
.52195 .44308 m .52181 .4431 L .52178 .43662 L p .774 0 .5 r
F P
0 g
s
.52178 .43662 m .5219 .43658 L .52195 .44308 L p .774 0 .5 r
F P
0 g
s
.52214 .44304 m .52195 .44308 L .5219 .43658 L p .774 0 .5 r
F P
0 g
s
.5219 .43658 m .52208 .43652 L .52214 .44304 L p .774 0 .5 r
F P
0 g
s
.5284 .51709 m .53109 .52546 L .52002 .53255 L p .619 .107 1 r
F P
0 g
s
.53109 .52546 m .5284 .51709 L .53605 .50921 L p .634 .094 .972 r
F P
0 g
s
.5224 .443 m .52214 .44304 L .52208 .43652 L p .775 0 .5 r
F P
0 g
s
.52208 .43652 m .52232 .43645 L .5224 .443 L p .775 0 .5 r
F P
0 g
s
.52277 .44293 m .5224 .443 L .52232 .43645 L p .776 0 .5 r
F P
0 g
s
.52232 .43645 m .52266 .43634 L .52277 .44293 L p .776 0 .5 r
F P
0 g
s
.52329 .44284 m .52277 .44293 L .52266 .43634 L p .777 0 .5 r
F P
0 g
s
.52266 .43634 m .52313 .43619 L .52329 .44284 L p .777 0 .5 r
F P
0 g
s
.5338 .43277 m .5303 .43389 L .5291 .42644 L p .863 0 .5 r
F P
0 g
s
.5291 .42644 m .53213 .42491 L .5338 .43277 L p .863 0 .5 r
F P
0 g
s
.52401 .44272 m .52329 .44284 L .52313 .43619 L p .778 0 .5 r
F P
0 g
s
.52313 .43619 m .52379 .43597 L .52401 .44272 L p .778 0 .5 r
F P
0 g
s
.52501 .44254 m .52401 .44272 L .52379 .43597 L p .779 0 .5 r
F P
0 g
s
.52379 .43597 m .52471 .43568 L .52501 .44254 L p .779 0 .5 r
F P
0 g
s
.56674 .48531 m .55399 .48077 L .55745 .47008 L p .718 .055 .777 r
F P
0 g
s
.55745 .47008 m .5716 .47301 L .56674 .48531 L p .718 .055 .777 r
F P
0 g
s
.52642 .4423 m .52501 .44254 L .52471 .43568 L p .781 0 .5 r
F P
0 g
s
.52471 .43568 m .526 .43527 L .52642 .4423 L p .781 0 .5 r
F P
0 g
s
.52292 .3727 m .5225 .38193 L .51456 .37598 L p 1 0 .5 r
F P
0 g
s
.51456 .37598 m .51178 .36689 L .52292 .3727 L p 1 0 .5 r
F P
0 g
s
.52838 .44196 m .52642 .4423 L .526 .43527 L p .784 0 .5 r
F P
0 g
s
.526 .43527 m .52779 .43469 L .52838 .44196 L p .784 0 .5 r
F P
0 g
s
.53797 .39692 m .53326 .40282 L .52786 .3953 L p 1 0 .5 r
F P
0 g
s
.52786 .3953 m .53043 .38893 L .53797 .39692 L p 1 0 .5 r
F P
0 g
s
.27472 .28094 m .34711 .30814 L .33142 .32603 L p .908 .061 .805 r
F P
0 g
s
.33142 .32603 m .2539 .30913 L .27472 .28094 L p .908 .061 .805 r
F P
0 g
s
.49839 .54295 m .48946 .55351 L .47603 .55569 L p .711 .122 1 r
F P
0 g
s
.48946 .55351 m .49839 .54295 L .50896 .53837 L p .693 .115 1 r
F P
0 g
s
.5387 .4312 m .5338 .43277 L .53213 .42491 L p .861 0 .5 r
F P
0 g
s
.53213 .42491 m .53637 .42277 L .5387 .4312 L p .861 0 .5 r
F P
0 g
s
.53111 .44148 m .52838 .44196 L .52779 .43469 L p .787 0 .5 r
F P
0 g
s
.52779 .43469 m .5303 .43389 L .53111 .44148 L p .787 0 .5 r
F P
0 g
s
.5423 .41977 m .53637 .42277 L .53339 .41468 L p .926 0 .5 r
F P
0 g
s
.53339 .41468 m .53814 .411 L .5423 .41977 L p .926 0 .5 r
F P
0 g
s
.62414 .46408 m .59513 .46183 L .59578 .44624 L p .807 .048 .741 r
F P
0 g
s
.59578 .44624 m .62526 .44489 L .62414 .46408 L p .807 .048 .741 r
F P
0 g
s
.53493 .44082 m .53111 .44148 L .5303 .43389 L p .795 .003 .517 r
F P
0 g
s
.5303 .43389 m .5338 .43277 L .53493 .44082 L p .795 .003 .517 r
F P
0 g
s
.52042 .52407 m .52002 .53255 L .50896 .53837 L p .621 .121 1 r
F P
0 g
s
.52002 .53255 m .52042 .52407 L .5284 .51709 L p .619 .107 1 r
F P
0 g
s
.5716 .47301 m .55745 .47008 L .55934 .45905 L p .743 .048 .739 r
F P
0 g
s
.55934 .45905 m .57429 .46021 L .5716 .47301 L p .743 .048 .739 r
F P
0 g
s
.52182 .44961 m .52172 .44961 L .52171 .44312 L p .699 .001 .507 r
F P
0 g
s
.52171 .44312 m .52181 .4431 L .52182 .44961 L p .699 .001 .507 r
F P
0 g
s
.52197 .4496 m .52182 .44961 L .52181 .4431 L p .7 .002 .508 r
F P
0 g
s
.52181 .4431 m .52195 .44308 L .52197 .4496 L p .7 .002 .508 r
F P
0 g
s
.52216 .44959 m .52197 .4496 L .52195 .44308 L p .7 .002 .509 r
F P
0 g
s
.52195 .44308 m .52214 .44304 L .52216 .44959 L p .7 .002 .509 r
F P
0 g
s
.52244 .44958 m .52216 .44959 L .52214 .44304 L p .702 .002 .511 r
F P
0 g
s
.52214 .44304 m .5224 .443 L .52244 .44958 L p .702 .002 .511 r
F P
0 g
s
.52282 .44956 m .52244 .44958 L .5224 .443 L p .703 .003 .513 r
F P
0 g
s
.5224 .443 m .52277 .44293 L .52282 .44956 L p .703 .003 .513 r
F P
0 g
s
.52336 .44954 m .52282 .44956 L .52277 .44293 L p .705 .003 .516 r
F P
0 g
s
.52277 .44293 m .52329 .44284 L .52336 .44954 L p .705 .003 .516 r
F P
0 g
s
.52411 .44951 m .52336 .44954 L .52329 .44284 L p .708 .004 .521 r
F P
0 g
s
.52329 .44284 m .52401 .44272 L .52411 .44951 L p .708 .004 .521 r
F P
0 g
s
.52516 .44946 m .52411 .44951 L .52401 .44272 L p .712 .005 .526 r
F P
0 g
s
.52401 .44272 m .52501 .44254 L .52516 .44946 L p .712 .005 .526 r
F P
0 g
s
.54027 .43989 m .53493 .44082 L .5338 .43277 L p .804 .009 .543 r
F P
0 g
s
.5338 .43277 m .5387 .4312 L .54027 .43989 L p .804 .009 .543 r
F P
0 g
s
.54554 .42901 m .5387 .4312 L .53637 .42277 L p .863 .005 .526 r
F P
0 g
s
.53637 .42277 m .5423 .41977 L .54554 .42901 L p .863 .005 .526 r
F P
0 g
s
.52662 .44939 m .52516 .44946 L .52501 .44254 L p .717 .007 .534 r
F P
0 g
s
.52501 .44254 m .52642 .4423 L .52662 .44939 L p .717 .007 .534 r
F P
0 g
s
.5448 .40585 m .53814 .411 L .53326 .40282 L p .977 0 .5 r
F P
0 g
s
.53326 .40282 m .53797 .39692 L .5448 .40585 L p .977 0 .5 r
F P
0 g
s
.52866 .4493 m .52662 .44939 L .52642 .4423 L p .724 .009 .545 r
F P
0 g
s
.52642 .4423 m .52838 .44196 L .52866 .4493 L p .724 .009 .545 r
F P
0 g
s
.59513 .46183 m .57429 .46021 L .57469 .4472 L p .79 .045 .723 r
F P
0 g
s
.57469 .4472 m .59578 .44624 L .59513 .46183 L p .79 .045 .723 r
F P
0 g
s
.53151 .44917 m .52866 .4493 L .52838 .44196 L p .733 .012 .558 r
F P
0 g
s
.52838 .44196 m .53111 .44148 L .53151 .44917 L p .733 .012 .558 r
F P
0 g
s
.50786 .35404 m .51178 .36689 L .50114 .36251 L p 1 .02 .598 r
F P
0 g
s
.50114 .36251 m .49291 .35045 L .50786 .35404 L p 1 .02 .598 r
F P
0 g
s
.53548 .44899 m .53151 .44917 L .53111 .44148 L p .744 .015 .575 r
F P
0 g
s
.53111 .44148 m .53493 .44082 L .53548 .44899 L p .744 .015 .575 r
F P
0 g
s
.54133 .48666 m .54912 .49095 L .54305 .50047 L p .629 .074 .871 r
F P
0 g
s
.54912 .49095 m .54133 .48666 L .54481 .4775 L p .658 .063 .817 r
F P
0 g
s
.54481 .4775 m .55399 .48077 L .54912 .49095 L p .658 .063 .817 r
F P
0 g
s
.53403 .37997 m .53043 .38893 L .5225 .38193 L p 1 .001 .507 r
F P
0 g
s
.5225 .38193 m .52292 .3727 L .53403 .37997 L p 1 .001 .507 r
F P
0 g
s
.55399 .48077 m .54481 .4775 L .54728 .46797 L p .688 .054 .769 r
F P
0 g
s
.54728 .46797 m .55745 .47008 L .55399 .48077 L p .688 .054 .769 r
F P
0 g
s
.54773 .43859 m .54027 .43989 L .5387 .4312 L p .814 .015 .573 r
F P
0 g
s
.5387 .4312 m .54554 .42901 L .54773 .43859 L p .814 .015 .573 r
F P
0 g
s
.53698 .49536 m .54305 .50047 L .53605 .50921 L p .6 .087 .934 r
F P
0 g
s
.54305 .50047 m .53698 .49536 L .54133 .48666 L p .629 .074 .871 r
F P
0 g
s
.54103 .44873 m .53548 .44899 L .53493 .44082 L p .756 .019 .595 r
F P
0 g
s
.53493 .44082 m .54027 .43989 L .54103 .44873 L p .756 .019 .595 r
F P
0 g
s
.5506 .41557 m .5423 .41977 L .53814 .411 L p .917 .006 .528 r
F P
0 g
s
.53814 .411 m .5448 .40585 L .5506 .41557 L p .917 .006 .528 r
F P
0 g
s
.57429 .46021 m .55934 .45905 L .55959 .44789 L p .771 .041 .704 r
F P
0 g
s
.55959 .44789 m .57469 .4472 L .57429 .46021 L p .771 .041 .704 r
F P
0 g
s
.55745 .47008 m .54728 .46797 L .54862 .45822 L p .718 .045 .725 r
F P
0 g
s
.54862 .45822 m .55934 .45905 L .55745 .47008 L p .718 .045 .725 r
F P
0 g
s
.54877 .44838 m .54103 .44873 L .54027 .43989 L p .77 .024 .619 r
F P
0 g
s
.54027 .43989 m .54773 .43859 L .54877 .44838 L p .77 .024 .619 r
F P
0 g
s
.53195 .50351 m .53605 .50921 L .5284 .51709 L p .601 .101 1 r
F P
0 g
s
.53605 .50921 m .53195 .50351 L .53698 .49536 L p .6 .087 .934 r
F P
0 g
s
.52182 .45614 m .52172 .45614 L .52172 .44961 L p .643 .015 .577 r
F P
0 g
s
.52172 .44961 m .52182 .44961 L .52182 .45614 L p .643 .015 .577 r
F P
0 g
s
.52196 .45615 m .52182 .45614 L .52182 .44961 L p .644 .016 .578 r
F P
0 g
s
.52182 .44961 m .52197 .4496 L .52196 .45615 L p .644 .016 .578 r
F P
0 g
s
.52216 .45617 m .52196 .45615 L .52197 .4496 L p .645 .016 .579 r
F P
0 g
s
.52197 .4496 m .52216 .44959 L .52216 .45617 L p .645 .016 .579 r
F P
0 g
s
.52244 .45619 m .52216 .45617 L .52216 .44959 L p .646 .016 .58 r
F P
0 g
s
.52216 .44959 m .52244 .44958 L .52244 .45619 L p .646 .016 .58 r
F P
0 g
s
.52282 .45622 m .52244 .45619 L .52244 .44958 L p .648 .016 .582 r
F P
0 g
s
.52244 .44958 m .52282 .44956 L .52282 .45622 L p .648 .016 .582 r
F P
0 g
s
.52335 .45626 m .52282 .45622 L .52282 .44956 L p .651 .017 .585 r
F P
0 g
s
.52282 .44956 m .52336 .44954 L .52335 .45626 L p .651 .017 .585 r
F P
0 g
s
.5241 .45632 m .52335 .45626 L .52336 .44954 L p .654 .018 .588 r
F P
0 g
s
.52336 .44954 m .52411 .44951 L .5241 .45632 L p .654 .018 .588 r
F P
0 g
s
.55512 .42594 m .54554 .42901 L .5423 .41977 L p .867 .014 .568 r
F P
0 g
s
.5423 .41977 m .5506 .41557 L .55512 .42594 L p .867 .014 .568 r
F P
0 g
s
.52514 .4564 m .5241 .45632 L .52411 .44951 L p .659 .019 .593 r
F P
0 g
s
.52411 .44951 m .52516 .44946 L .52514 .4564 L p .659 .019 .593 r
F P
0 g
s
.5266 .45651 m .52514 .4564 L .52516 .44946 L p .665 .02 .599 r
F P
0 g
s
.52516 .44946 m .52662 .44939 L .5266 .45651 L p .665 .02 .599 r
F P
0 g
s
.52863 .45667 m .5266 .45651 L .52662 .44939 L p .674 .021 .607 r
F P
0 g
s
.52662 .44939 m .52866 .4493 L .52863 .45667 L p .674 .021 .607 r
F P
0 g
s
.53146 .45689 m .52863 .45667 L .52866 .4493 L p .684 .023 .617 r
F P
0 g
s
.52866 .4493 m .53151 .44917 L .53146 .45689 L p .684 .023 .617 r
F P
0 g
s
.53541 .4572 m .53146 .45689 L .53151 .44917 L p .697 .026 .63 r
F P
0 g
s
.53151 .44917 m .53548 .44899 L .53541 .4572 L p .697 .026 .63 r
F P
0 g
s
.55934 .45905 m .54862 .45822 L .54877 .44838 L p .751 .037 .684 r
F P
0 g
s
.54877 .44838 m .55959 .44789 L .55934 .45905 L p .751 .037 .684 r
F P
0 g
s
.51247 .53013 m .50896 .53837 L .49839 .54295 L p .635 .135 1 r
F P
0 g
s
.50896 .53837 m .51247 .53013 L .52042 .52407 L p .621 .121 1 r
F P
0 g
s
.54093 .45763 m .53541 .4572 L .53548 .44899 L p .713 .029 .646 r
F P
0 g
s
.53548 .44899 m .54103 .44873 L .54093 .45763 L p .713 .029 .646 r
F P
0 g
s
.55816 .43678 m .54773 .43859 L .54554 .42901 L p .824 .021 .606 r
F P
0 g
s
.54554 .42901 m .55512 .42594 L .55816 .43678 L p .824 .021 .606 r
F P
0 g
s
.54862 .45822 m .54093 .45763 L .54103 .44873 L p .731 .033 .664 r
F P
0 g
s
.54103 .44873 m .54877 .44838 L .54862 .45822 L p .731 .033 .664 r
F P
0 g
s
.55959 .44789 m .54877 .44838 L .54773 .43859 L p .786 .029 .644 r
F P
0 g
s
.54773 .43859 m .55816 .43678 L .55959 .44789 L p .786 .029 .644 r
F P
0 g
s
.54461 .38864 m .53797 .39692 L .53043 .38893 L p 1 .006 .528 r
F P
0 g
s
.53043 .38893 m .53403 .37997 L .54461 .38864 L p 1 .006 .528 r
F P
0 g
s
.54093 .45763 m .54862 .45822 L .54728 .46797 L p .694 .042 .711 r
F P
0 g
s
.53998 .46646 m .54728 .46797 L .54481 .4775 L p .659 .052 .76 r
F P
0 g
s
.54728 .46797 m .53998 .46646 L .54093 .45763 L p .694 .042 .711 r
F P
0 g
s
.48126 .33336 m .49291 .35045 L .47935 .34875 L p 1 .037 .687 r
F P
0 g
s
.47935 .34875 m .46222 .33357 L .48126 .33336 L p 1 .037 .687 r
F P
0 g
s
.57469 .4472 m .55959 .44789 L .55816 .43678 L p .8 .034 .671 r
F P
0 g
s
.39374 .57464 m .42936 .56386 L .44236 .567 L p .852 .091 .957 r
F P
0 g
s
.46443 .55646 m .44236 .567 L .42936 .56386 L p .831 .105 1 r
F P
0 g
s
.44236 .567 m .46443 .55646 L .47603 .55569 L p .796 .106 1 r
F P
0 g
s
.53822 .47514 m .54481 .4775 L .54133 .48666 L p .623 .063 .815 r
F P
0 g
s
.54481 .4775 m .53822 .47514 L .53998 .46646 L p .659 .052 .76 r
F P
0 g
s
.53541 .4572 m .54093 .45763 L .53998 .46646 L p .672 .039 .697 r
F P
0 g
s
.52645 .51105 m .5284 .51709 L .52042 .52407 L p .619 .119 1 r
F P
0 g
s
.5284 .51709 m .52645 .51105 L .53195 .50351 L p .601 .101 1 r
F P
0 g
s
.53998 .46646 m .53474 .46538 L .53541 .4572 L p .672 .039 .697 r
F P
0 g
s
.53146 .45689 m .53541 .4572 L .53474 .46538 L p .653 .037 .686 r
F P
0 g
s
.59578 .44624 m .57469 .4472 L .57275 .43425 L p .814 .039 .696 r
F P
0 g
s
.55816 .43678 m .57275 .43425 L .57469 .4472 L p .8 .034 .671 r
F P
0 g
s
.53474 .46538 m .53098 .4646 L .53146 .45689 L p .653 .037 .686 r
F P
0 g
s
.52863 .45667 m .53146 .45689 L .53098 .4646 L p .637 .035 .676 r
F P
0 g
s
.53572 .48358 m .54133 .48666 L .53698 .49536 L p .586 .076 .878 r
F P
0 g
s
.54133 .48666 m .53572 .48358 L .53822 .47514 L p .623 .063 .815 r
F P
0 g
s
.53098 .4646 m .52828 .46404 L .52863 .45667 L p .637 .035 .676 r
F P
0 g
s
.5266 .45651 m .52863 .45667 L .52828 .46404 L p .625 .034 .668 r
F P
0 g
s
.57275 .43425 m .55816 .43678 L .55512 .42594 L p .833 .028 .639 r
F P
0 g
s
.55416 .3986 m .5448 .40585 L .53797 .39692 L p .957 .011 .553 r
F P
0 g
s
.53797 .39692 m .54461 .38864 L .55416 .3986 L p .957 .011 .553 r
F P
0 g
s
.53474 .46538 m .53998 .46646 L .53822 .47514 L p .632 .05 .752 r
F P
0 g
s
.52828 .46404 m .52635 .46364 L .5266 .45651 L p .625 .034 .668 r
F P
0 g
s
.52514 .4564 m .5266 .45651 L .52635 .46364 L p .615 .032 .662 r
F P
0 g
s
.52635 .46364 m .52497 .46336 L .52514 .4564 L p .615 .032 .662 r
F P
0 g
s
.5241 .45632 m .52514 .4564 L .52497 .46336 L p .607 .031 .657 r
F P
0 g
s
.37123 .29275 m .41522 .31825 L .39776 .32716 L p .939 .057 .786 r
F P
0 g
s
.39776 .32716 m .34711 .30814 L .37123 .29275 L p .939 .057 .786 r
F P
0 g
s
.48873 .54639 m .47603 .55569 L .46443 .55646 L p .742 .125 1 r
F P
0 g
s
.47603 .55569 m .48873 .54639 L .49839 .54295 L p .711 .122 1 r
F P
0 g
s
.52497 .46336 m .52398 .46315 L .5241 .45632 L p .607 .031 .657 r
F P
0 g
s
.52335 .45626 m .5241 .45632 L .52398 .46315 L p .602 .031 .654 r
F P
0 g
s
.52351 .35965 m .52292 .3727 L .51178 .36689 L p 1 .017 .587 r
F P
0 g
s
.51178 .36689 m .50786 .35404 L .52351 .35965 L p 1 .017 .587 r
F P
0 g
s
.52398 .46315 m .52326 .463 L .52335 .45626 L p .602 .031 .654 r
F P
0 g
s
.52282 .45622 m .52335 .45626 L .52326 .463 L p .598 .03 .651 r
F P
0 g
s
.52326 .463 m .52275 .4629 L .52282 .45622 L p .598 .03 .651 r
F P
0 g
s
.52244 .45619 m .52282 .45622 L .52275 .4629 L p .594 .03 .649 r
F P
0 g
s
.52275 .4629 m .52239 .46282 L .52244 .45619 L p .594 .03 .649 r
F P
0 g
s
.52216 .45617 m .52244 .45619 L .52239 .46282 L p .592 .03 .648 r
F P
0 g
s
.62526 .44489 m .59578 .44624 L .59318 .4307 L p .827 .044 .719 r
F P
0 g
s
.57275 .43425 m .59318 .4307 L .59578 .44624 L p .814 .039 .696 r
F P
0 g
s
.52239 .46282 m .52213 .46277 L .52216 .45617 L p .592 .03 .648 r
F P
0 g
s
.52196 .45615 m .52216 .45617 L .52213 .46277 L p .591 .029 .647 r
F P
0 g
s
.52213 .46277 m .52194 .46273 L .52196 .45615 L p .591 .029 .647 r
F P
0 g
s
.52182 .45614 m .52196 .45615 L .52194 .46273 L p .59 .029 .646 r
F P
0 g
s
.52194 .46273 m .52181 .4627 L .52182 .45614 L p .59 .029 .646 r
F P
0 g
s
.52172 .45614 m .52182 .45614 L .52181 .4627 L p .589 .029 .646 r
F P
0 g
s
.52181 .4627 m .52171 .46268 L .52172 .45614 L p .589 .029 .646 r
F P
0 g
s
.55512 .42594 m .56855 .42164 L .57275 .43425 L p .833 .028 .639 r
F P
0 g
s
.56855 .42164 m .55512 .42594 L .5506 .41557 L p .87 .022 .609 r
F P
0 g
s
.53261 .49169 m .53698 .49536 L .53195 .50351 L p .59 .09 .952 r
F P
0 g
s
.53698 .49536 m .53261 .49169 L .53572 .48358 L p .586 .076 .878 r
F P
0 g
s
.56226 .40968 m .5506 .41557 L .5448 .40585 L p .911 .016 .58 r
F P
0 g
s
.5448 .40585 m .55416 .3986 L .56226 .40968 L p .911 .016 .58 r
F P
0 g
s
.53822 .47514 m .53348 .47346 L .53474 .46538 L p .632 .05 .752 r
F P
0 g
s
.53098 .4646 m .53474 .46538 L .53348 .47346 L p .609 .049 .744 r
F P
0 g
s
.43784 .31198 m .46222 .33357 L .44604 .33612 L p .981 .05 .749 r
F P
0 g
s
.44604 .33612 m .41522 .31825 L .43784 .31198 L p .981 .05 .749 r
F P
0 g
s
.5506 .41557 m .56226 .40968 L .56855 .42164 L p .87 .022 .609 r
F P
0 g
s
.53348 .47346 m .53822 .47514 L .53572 .48358 L p .591 .062 .812 r
F P
0 g
s
.66647 .44301 m .62526 .44489 L .62182 .42572 L p .837 .048 .739 r
F P
0 g
s
.59318 .4307 m .62182 .42572 L .62526 .44489 L p .827 .044 .719 r
F P
0 g
s
.53348 .47346 m .53008 .47224 L .53098 .4646 L p .609 .049 .744 r
F P
0 g
s
.52828 .46404 m .53098 .4646 L .53008 .47224 L p .59 .048 .738 r
F P
0 g
s
.52072 .51794 m .52042 .52407 L .51247 .53013 L p .639 .139 1 r
F P
0 g
s
.52042 .52407 m .52072 .51794 L .52645 .51105 L p .619 .119 1 r
F P
0 g
s
.59318 .4307 m .57275 .43425 L .56855 .42164 L p .842 .034 .671 r
F P
0 g
s
.53008 .47224 m .52764 .47137 L .52828 .46404 L p .59 .048 .738 r
F P
0 g
s
.52635 .46364 m .52828 .46404 L .52764 .47137 L p .574 .046 .732 r
F P
0 g
s
.52899 .49941 m .53195 .50351 L .52645 .51105 L p .609 .109 1 r
F P
0 g
s
.53195 .50351 m .52899 .49941 L .53261 .49169 L p .59 .09 .952 r
F P
0 g
s
.5317 .48136 m .53572 .48358 L .53261 .49169 L p .576 .076 .882 r
F P
0 g
s
.53572 .48358 m .5317 .48136 L .53348 .47346 L p .591 .062 .812 r
F P
0 g
s
.52764 .47137 m .52589 .47075 L .52635 .46364 L p .574 .046 .732 r
F P
0 g
s
.52497 .46336 m .52635 .46364 L .52589 .47075 L p .562 .046 .728 r
F P
0 g
s
.53008 .47224 m .53348 .47346 L .5317 .48136 L p .562 .062 .809 r
F P
0 g
s
.52589 .47075 m .52464 .4703 L .52497 .46336 L p .562 .046 .728 r
F P
0 g
s
.52398 .46315 m .52497 .46336 L .52464 .4703 L p .553 .045 .725 r
F P
0 g
s
.50485 .53531 m .49839 .54295 L .48873 .54639 L p .646 .146 1 r
F P
0 g
s
.49839 .54295 m .50485 .53531 L .51247 .53013 L p .635 .135 1 r
F P
0 g
s
.52464 .4703 m .52374 .46998 L .52398 .46315 L p .553 .045 .725 r
F P
0 g
s
.52326 .463 m .52398 .46315 L .52374 .46998 L p .546 .044 .722 r
F P
0 g
s
.52374 .46998 m .52309 .46975 L .52326 .463 L p .546 .044 .722 r
F P
0 g
s
.52275 .4629 m .52326 .463 L .52309 .46975 L p .544 .044 .721 r
F P
0 g
s
.72414 .44038 m .66647 .44301 L .66207 .41872 L p .845 .051 .755 r
F P
0 g
s
.62182 .42572 m .66207 .41872 L .66647 .44301 L p .837 .048 .739 r
F P
0 g
s
.52309 .46975 m .52263 .46959 L .52275 .4629 L p .544 .044 .721 r
F P
0 g
s
.52239 .46282 m .52275 .4629 L .52263 .46959 L p .544 .044 .719 r
F P
0 g
s
.52263 .46959 m .5223 .46947 L .52239 .46282 L p .544 .044 .719 r
F P
0 g
s
.52213 .46277 m .52239 .46282 L .5223 .46947 L p .544 .044 .718 r
F P
0 g
s
.5223 .46947 m .52206 .46939 L .52213 .46277 L p .544 .044 .718 r
F P
0 g
s
.52194 .46273 m .52213 .46277 L .52206 .46939 L p .543 .043 .717 r
F P
0 g
s
.52206 .46939 m .52189 .46933 L .52194 .46273 L p .543 .043 .717 r
F P
0 g
s
.52181 .4627 m .52194 .46273 L .52189 .46933 L p .543 .043 .717 r
F P
0 g
s
.52189 .46933 m .52177 .46928 L .52181 .4627 L p .543 .043 .717 r
F P
0 g
s
.52171 .46268 m .52181 .4627 L .52177 .46928 L p .543 .043 .717 r
F P
0 g
s
.52177 .46928 m .52169 .46925 L .52171 .46268 L p .543 .043 .717 r
F P
0 g
s
.53912 .36731 m .53403 .37997 L .52292 .3727 L p 1 .018 .588 r
F P
0 g
s
.52292 .3727 m .52351 .35965 L .53912 .36731 L p 1 .018 .588 r
F P
0 g
s
.5317 .48136 m .5288 .47977 L .53008 .47224 L p .562 .062 .809 r
F P
0 g
s
.52764 .47137 m .53008 .47224 L .5288 .47977 L p .561 .061 .807 r
F P
0 g
s
.52946 .48905 m .53261 .49169 L .52899 .49941 L p .593 .093 .967 r
F P
0 g
s
.53261 .49169 m .52946 .48905 L .5317 .48136 L p .576 .076 .882 r
F P
0 g
s
.56855 .42164 m .5874 .41561 L .59318 .4307 L p .842 .034 .671 r
F P
0 g
s
.5874 .41561 m .56855 .42164 L .56226 .40968 L p .871 .03 .648 r
F P
0 g
s
.5288 .47977 m .5317 .48136 L .52946 .48905 L p .577 .077 .886 r
F P
0 g
s
.5288 .47977 m .52673 .47863 L .52764 .47137 L p .561 .061 .807 r
F P
0 g
s
.52589 .47075 m .52764 .47137 L .52673 .47863 L p .561 .061 .804 r
F P
0 g
s
.52505 .5067 m .52645 .51105 L .52072 .51794 L p .631 .131 1 r
F P
0 g
s
.52645 .51105 m .52505 .5067 L .52899 .49941 L p .609 .109 1 r
F P
0 g
s
.52673 .47863 m .52524 .47781 L .52589 .47075 L p .561 .061 .804 r
F P
0 g
s
.52464 .4703 m .52589 .47075 L .52524 .47781 L p .56 .06 .802 r
F P
0 g
s
.62182 .42572 m .59318 .4307 L .5874 .41561 L p .848 .04 .7 r
F P
0 g
s
.51499 .52418 m .51247 .53013 L .50485 .53531 L p .659 .159 1 r
F P
0 g
s
.51247 .53013 m .51499 .52418 L .52072 .51794 L p .639 .139 1 r
F P
0 g
s
.52524 .47781 m .52417 .47722 L .52464 .4703 L p .56 .06 .802 r
F P
0 g
s
.52374 .46998 m .52464 .4703 L .52417 .47722 L p .56 .06 .8 r
F P
0 g
s
.80489 .4367 m .72414 .44038 L .71875 .40887 L p .851 .054 .768 r
F P
0 g
s
.66207 .41872 m .71875 .40887 L .72414 .44038 L p .845 .051 .755 r
F P
0 g
s
.5023 .33582 m .50786 .35404 L .49291 .35045 L p 1 .033 .665 r
F P
0 g
s
.49291 .35045 m .48126 .33336 L .5023 .33582 L p 1 .033 .665 r
F P
0 g
s
.52417 .47722 m .5234 .4768 L .52374 .46998 L p .56 .06 .8 r
F P
0 g
s
.52309 .46975 m .52374 .46998 L .5234 .4768 L p .56 .06 .799 r
F P
0 g
s
.52946 .48905 m .5272 .48715 L .5288 .47977 L p .577 .077 .886 r
F P
0 g
s
.52673 .47863 m .5288 .47977 L .5272 .48715 L p .578 .078 .888 r
F P
0 g
s
.5234 .4768 m .52285 .4765 L .52309 .46975 L p .56 .06 .799 r
F P
0 g
s
.52263 .46959 m .52309 .46975 L .52285 .4765 L p .56 .06 .798 r
F P
0 g
s
.55396 .37695 m .54461 .38864 L .53403 .37997 L p .977 .019 .596 r
F P
0 g
s
.53403 .37997 m .53912 .36731 L .55396 .37695 L p .977 .019 .596 r
F P
0 g
s
.52285 .4765 m .52246 .47629 L .52263 .46959 L p .56 .06 .798 r
F P
0 g
s
.5223 .46947 m .52263 .46959 L .52246 .47629 L p .559 .059 .797 r
F P
0 g
s
.56226 .40968 m .57866 .40139 L .5874 .41561 L p .871 .03 .648 r
F P
0 g
s
.57866 .40139 m .56226 .40968 L .55416 .3986 L p .904 .025 .627 r
F P
0 g
s
.52687 .49646 m .52899 .49941 L .52505 .5067 L p .615 .115 1 r
F P
0 g
s
.52899 .49941 m .52687 .49646 L .52946 .48905 L p .593 .093 .967 r
F P
0 g
s
.52246 .47629 m .52218 .47613 L .5223 .46947 L p .559 .059 .797 r
F P
0 g
s
.52206 .46939 m .5223 .46947 L .52218 .47613 L p .559 .059 .796 r
F P
0 g
s
.52218 .47613 m .52198 .47602 L .52206 .46939 L p .559 .059 .796 r
F P
0 g
s
.52189 .46933 m .52206 .46939 L .52198 .47602 L p .559 .059 .796 r
F P
0 g
s
.52198 .47602 m .52183 .47594 L .52189 .46933 L p .559 .059 .796 r
F P
0 g
s
.52177 .46928 m .52189 .46933 L .52183 .47594 L p .559 .059 .796 r
F P
0 g
s
.52183 .47594 m .52173 .47588 L .52177 .46928 L p .559 .059 .796 r
F P
0 g
s
.52169 .46925 m .52177 .46928 L .52173 .47588 L p .559 .059 .795 r
F P
0 g
s
.52173 .47588 m .52165 .47584 L .52169 .46925 L p .559 .059 .795 r
F P
0 g
s
.5272 .48715 m .52946 .48905 L .52687 .49646 L p .596 .096 .98 r
F P
0 g
s
.17022 .24169 m .27472 .28094 L .2539 .30913 L p .894 .061 .804 r
F P
0 g
s
.2539 .30913 m .1434 .28504 L .17022 .24169 L p .894 .061 .804 r
F P
0 g
s
.5272 .48715 m .52558 .48578 L .52673 .47863 L p .578 .078 .888 r
F P
0 g
s
.52524 .47781 m .52673 .47863 L .52558 .48578 L p .578 .078 .889 r
F P
0 g
s
.56735 .38839 m .55416 .3986 L .54461 .38864 L p .939 .022 .609 r
F P
0 g
s
.54461 .38864 m .55396 .37695 L .56735 .38839 L p .939 .022 .609 r
F P
0 g
s
.55416 .3986 m .56735 .38839 L .57866 .40139 L p .904 .025 .627 r
F P
0 g
s
.52093 .51352 m .52072 .51794 L .51499 .52418 L p .658 .158 1 r
F P
0 g
s
.52072 .51794 m .52093 .51352 L .52505 .5067 L p .631 .131 1 r
F P
0 g
s
.52558 .48578 m .52441 .48481 L .52524 .47781 L p .578 .078 .889 r
F P
0 g
s
.52417 .47722 m .52524 .47781 L .52441 .48481 L p .578 .078 .89 r
F P
0 g
s
.52441 .48481 m .52358 .4841 L .52417 .47722 L p .578 .078 .89 r
F P
0 g
s
.5234 .4768 m .52417 .47722 L .52358 .4841 L p .578 .078 .89 r
F P
0 g
s
.52687 .49646 m .52534 .49433 L .5272 .48715 L p .596 .096 .98 r
F P
0 g
s
.52558 .48578 m .5272 .48715 L .52534 .49433 L p .598 .098 .989 r
F P
0 g
s
.52358 .4841 m .52298 .4836 L .5234 .4768 L p .578 .078 .89 r
F P
0 g
s
.52285 .4765 m .5234 .4768 L .52298 .4836 L p .578 .078 .89 r
F P
0 g
s
.52404 .50356 m .52505 .5067 L .52093 .51352 L p .643 .143 1 r
F P
0 g
s
.52505 .5067 m .52404 .50356 L .52687 .49646 L p .615 .115 1 r
F P
0 g
s
.91815 .43154 m .80489 .4367 L .79888 .39494 L p .855 .056 .778 r
F P
0 g
s
.71875 .40887 m .79888 .39494 L .80489 .4367 L p .851 .054 .768 r
F P
0 g
s
.42936 .56386 m .45516 .55605 L .46443 .55646 L p .831 .105 1 r
F P
0 g
s
.48041 .54881 m .46443 .55646 L .45516 .55605 L p .784 .124 1 r
F P
0 g
s
.46443 .55646 m .48041 .54881 L .48873 .54639 L p .742 .125 1 r
F P
0 g
s
.52298 .4836 m .52255 .48324 L .52285 .4765 L p .578 .078 .89 r
F P
0 g
s
.52246 .47629 m .52285 .4765 L .52255 .48324 L p .578 .078 .89 r
F P
0 g
s
.52534 .49433 m .52687 .49646 L .52404 .50356 L p .62 .12 1 r
F P
0 g
s
.49792 .53966 m .48873 .54639 L .48041 .54881 L p .65 .15 1 r
F P
0 g
s
.48873 .54639 m .49792 .53966 L .50485 .53531 L p .646 .146 1 r
F P
0 g
s
.52255 .48324 m .52224 .48298 L .52246 .47629 L p .578 .078 .89 r
F P
0 g
s
.52218 .47613 m .52246 .47629 L .52224 .48298 L p .578 .078 .89 r
F P
0 g
s
.52224 .48298 m .52202 .4828 L .52218 .47613 L p .578 .078 .89 r
F P
0 g
s
.52198 .47602 m .52218 .47613 L .52202 .4828 L p .578 .078 .89 r
F P
0 g
s
.52202 .4828 m .52186 .48266 L .52198 .47602 L p .578 .078 .89 r
F P
0 g
s
.52183 .47594 m .52198 .47602 L .52186 .48266 L p .578 .078 .89 r
F P
0 g
s
.52186 .48266 m .52175 .48257 L .52183 .47594 L p .578 .078 .89 r
F P
0 g
s
.52173 .47588 m .52183 .47594 L .52175 .48257 L p .578 .078 .89 r
F P
0 g
s
.91815 .43154 m .92535 .43121 L .92887 .43671 L p .854 .058 .792 r
F P
0 g
s
.52175 .48257 m .52167 .4825 L .52173 .47588 L p .578 .078 .89 r
F P
0 g
s
.52165 .47584 m .52173 .47588 L .52167 .4825 L p .578 .078 .89 r
F P
0 g
s
.52167 .4825 m .52161 .48245 L .52165 .47584 L p .578 .078 .89 r
F P
0 g
s
.52534 .49433 m .52425 .49281 L .52558 .48578 L p .598 .098 .989 r
F P
0 g
s
.52441 .48481 m .52558 .48578 L .52425 .49281 L p .599 .099 .996 r
F P
0 g
s
.66207 .41872 m .62182 .42572 L .61391 .40712 L p .854 .045 .724 r
F P
0 g
s
.5874 .41561 m .61391 .40712 L .62182 .42572 L p .848 .04 .7 r
F P
0 g
s
.61391 .40712 m .5874 .41561 L .57866 .40139 L p .872 .036 .682 r
F P
0 g
s
.50953 .52978 m .50485 .53531 L .49792 .53966 L p .672 .172 1 r
F P
0 g
s
.50485 .53531 m .50953 .52978 L .51499 .52418 L p .659 .159 1 r
F P
0 g
s
.52425 .49281 m .52346 .49172 L .52441 .48481 L p .599 .099 .996 r
F P
0 g
s
.52358 .4841 m .52441 .48481 L .52346 .49172 L p .6 .1 1 r
F P
0 g
s
.52404 .50356 m .52331 .50131 L .52534 .49433 L p .62 .12 1 r
F P
0 g
s
.52425 .49281 m .52534 .49433 L .52331 .50131 L p .625 .125 1 r
F P
0 g
s
.51682 .51989 m .51499 .52418 L .50953 .52978 L p .683 .183 1 r
F P
0 g
s
.51499 .52418 m .51682 .51989 L .52093 .51352 L p .658 .158 1 r
F P
0 g
s
.52346 .49172 m .52289 .49093 L .52358 .4841 L p .6 .1 1 r
F P
0 g
s
.52298 .4836 m .52358 .4841 L .52289 .49093 L p .601 .101 1 r
F P
0 g
s
.52435 .34114 m .52351 .35965 L .50786 .35404 L p 1 .031 .653 r
F P
0 g
s
.50786 .35404 m .5023 .33582 L .52435 .34114 L p 1 .031 .653 r
F P
0 g
s
.46464 .309 m .48126 .33336 L .46222 .33357 L p .981 .045 .726 r
F P
0 g
s
.46222 .33357 m .43784 .31198 L .46464 .309 L p .981 .045 .726 r
F P
0 g
s
.52289 .49093 m .52249 .49037 L .52298 .4836 L p .601 .101 1 r
F P
0 g
s
.52255 .48324 m .52298 .4836 L .52249 .49037 L p .601 .101 1 r
F P
0 g
s
.52093 .51352 m .52108 .51035 L .52404 .50356 L p .643 .143 1 r
F P
0 g
s
.52331 .50131 m .52404 .50356 L .52108 .51035 L p .652 .152 1 r
F P
0 g
s
.52108 .51035 m .52093 .51352 L .51682 .51989 L p .675 .175 1 r
F P
0 g
s
.52249 .49037 m .5222 .48997 L .52255 .48324 L p .601 .101 1 r
F P
0 g
s
.52224 .48298 m .52255 .48324 L .5222 .48997 L p .602 .102 1 r
F P
0 g
s
.5222 .48997 m .52199 .48968 L .52224 .48298 L p .602 .102 1 r
F P
0 g
s
.52202 .4828 m .52224 .48298 L .52199 .48968 L p .602 .102 1 r
F P
0 g
s
.52331 .50131 m .52279 .49969 L .52425 .49281 L p .625 .125 1 r
F P
0 g
s
.52346 .49172 m .52425 .49281 L .52279 .49969 L p .628 .128 1 r
F P
0 g
s
.52199 .48968 m .52184 .48947 L .52202 .4828 L p .602 .102 1 r
F P
0 g
s
.52186 .48266 m .52202 .4828 L .52184 .48947 L p .602 .102 1 r
F P
0 g
s
.52184 .48947 m .52174 .48932 L .52186 .48266 L p .602 .102 1 r
F P
0 g
s
.52175 .48257 m .52186 .48266 L .52174 .48932 L p .602 .102 1 r
F P
0 g
s
.52174 .48932 m .52166 .48921 L .52175 .48257 L p .602 .102 1 r
F P
0 g
s
.52167 .4825 m .52175 .48257 L .52166 .48921 L p .602 .102 1 r
F P
0 g
s
.52166 .48921 m .5216 .48914 L .52167 .4825 L p .602 .102 1 r
F P
0 g
s
.52161 .48245 m .52167 .4825 L .5216 .48914 L p .602 .102 1 r
F P
0 g
s
.5216 .48914 m .52156 .48908 L .52161 .48245 L p .602 .102 1 r
F P
0 g
s
.52279 .49969 m .52241 .49853 L .52346 .49172 L p .628 .128 1 r
F P
0 g
s
.52289 .49093 m .52346 .49172 L .52241 .49853 L p .63 .13 1 r
F P
0 g
s
.92535 .43121 m .91815 .43154 L .91681 .41747 L closepath p .849 .057 .786 r
F P
0 g
s
.91681 .41747 m .91815 .43154 L p .79888 .39494 L .855 .056 .778 r
F P
0 g
s
.57866 .40139 m .60179 .38969 L .61391 .40712 L p .872 .036 .682 r
F P
0 g
s
.60179 .38969 m .57866 .40139 L .56735 .38839 L p .897 .034 .668 r
F P
0 g
s
.52108 .51035 m .52119 .50806 L .52331 .50131 L p .652 .152 1 r
F P
0 g
s
.52279 .49969 m .52331 .50131 L .52119 .50806 L p .659 .159 1 r
F P
0 g
s
.52241 .49853 m .52215 .4977 L .52289 .49093 L p .63 .13 1 r
F P
0 g
s
.52249 .49037 m .52289 .49093 L .52215 .4977 L p .631 .131 1 r
F P
0 g
s
.52215 .4977 m .52195 .4971 L .52249 .49037 L p .631 .131 1 r
F P
0 g
s
.5222 .48997 m .52249 .49037 L .52195 .4971 L p .632 .132 1 r
F P
0 g
s
.51682 .51989 m .51813 .5168 L .52108 .51035 L p .675 .175 1 r
F P
0 g
s
.52119 .50806 m .52108 .51035 L .51813 .5168 L p .687 .187 1 r
F P
0 g
s
.54634 .34937 m .53912 .36731 L .52351 .35965 L p .977 .03 .648 r
F P
0 g
s
.52351 .35965 m .52435 .34114 L .54634 .34937 L p .977 .03 .648 r
F P
0 g
s
.52195 .4971 m .52181 .49667 L .5222 .48997 L p .632 .132 1 r
F P
0 g
s
.52199 .48968 m .5222 .48997 L .52181 .49667 L p .633 .133 1 r
F P
0 g
s
.50953 .52978 m .51289 .52581 L .51682 .51989 L p .683 .183 1 r
F P
0 g
s
.51813 .5168 m .51682 .51989 L .51289 .52581 L p .697 .197 1 r
F P
0 g
s
.52181 .49667 m .52172 .49636 L .52199 .48968 L p .633 .133 1 r
F P
0 g
s
.52184 .48947 m .52199 .48968 L .52172 .49636 L p .634 .134 1 r
F P
0 g
s
.49792 .53966 m .50455 .53481 L .50953 .52978 L p .672 .172 1 r
F P
0 g
s
.51289 .52581 m .50953 .52978 L .50455 .53481 L p .687 .187 1 r
F P
0 g
s
.52119 .50806 m .52127 .50642 L .52279 .49969 L p .659 .159 1 r
F P
0 g
s
.52241 .49853 m .52279 .49969 L .52127 .50642 L p .664 .164 1 r
F P
0 g
s
.48041 .54881 m .49195 .5433 L .49792 .53966 L p .65 .15 1 r
F P
0 g
s
.50455 .53481 m .49792 .53966 L .49195 .5433 L p .667 .167 1 r
F P
0 g
s
.52172 .49636 m .52164 .49614 L .52184 .48947 L p .634 .134 1 r
F P
0 g
s
.52174 .48932 m .52184 .48947 L .52164 .49614 L p .634 .134 1 r
F P
0 g
s
.52164 .49614 m .52159 .49599 L .52174 .48932 L p .634 .134 1 r
F P
0 g
s
.52166 .48921 m .52174 .48932 L .52159 .49599 L p .634 .134 1 r
F P
0 g
s
.52159 .49599 m .52156 .49587 L .52166 .48921 L p .634 .134 1 r
F P
0 g
s
.5216 .48914 m .52166 .48921 L .52156 .49587 L p .634 .134 1 r
F P
0 g
s
.52156 .49587 m .52153 .49579 L .5216 .48914 L p .634 .134 1 r
F P
0 g
s
.52156 .48908 m .5216 .48914 L .52153 .49579 L p .635 .135 1 r
F P
0 g
s
.52153 .49579 m .52151 .49573 L .52156 .48908 L p .635 .135 1 r
F P
0 g
s
.71875 .40887 m .66207 .41872 L .65132 .39515 L p .857 .049 .744 r
F P
0 g
s
.61391 .40712 m .65132 .39515 L .66207 .41872 L p .854 .045 .724 r
F P
0 g
s
.40289 .28101 m .43784 .31198 L .41522 .31825 L p .944 .053 .767 r
F P
0 g
s
.41522 .31825 m .37123 .29275 L .40289 .28101 L p .944 .053 .767 r
F P
0 g
s
.30785 .25601 m .37123 .29275 L .34711 .30814 L p .915 .058 .791 r
F P
0 g
s
.34711 .30814 m .27472 .28094 L .30785 .25601 L p .915 .058 .791 r
F P
0 g
s
.56735 .38839 m .586 .37395 L .60179 .38969 L p .897 .034 .668 r
F P
0 g
s
.586 .37395 m .56735 .38839 L .55396 .37695 L p .923 .031 .657 r
F P
0 g
s
.45516 .55605 m .4738 .55041 L .48041 .54881 L p .784 .124 1 r
F P
0 g
s
.49195 .5433 m .48041 .54881 L .4738 .55041 L p .681 .142 1 r
F P
0 g
s
.52127 .50642 m .52132 .50524 L .52241 .49853 L p .664 .164 1 r
F P
0 g
s
.52215 .4977 m .52241 .49853 L .52132 .50524 L p .667 .167 1 r
F P
0 g
s
.51813 .5168 m .51907 .51458 L .52119 .50806 L p .687 .187 1 r
F P
0 g
s
.52127 .50642 m .52119 .50806 L .51907 .51458 L p .694 .194 1 r
F P
0 g
s
.56722 .36039 m .55396 .37695 L .53912 .36731 L p .95 .03 .65 r
F P
0 g
s
.53912 .36731 m .54634 .34937 L .56722 .36039 L p .95 .03 .65 r
F P
0 g
s
.52132 .50524 m .52136 .5044 L .52215 .4977 L p .667 .167 1 r
F P
0 g
s
.52195 .4971 m .52215 .4977 L .52136 .5044 L p .669 .169 1 r
F P
0 g
s
.65132 .39515 m .61391 .40712 L .60179 .38969 L p .872 .042 .711 r
F P
0 g
s
.55396 .37695 m .56722 .36039 L .586 .37395 L p .923 .031 .657 r
F P
0 g
s
.52136 .5044 m .52139 .50379 L .52195 .4971 L p .669 .169 1 r
F P
0 g
s
.52181 .49667 m .52195 .4971 L .52139 .50379 L p .67 .17 1 r
F P
0 g
s
.51289 .52581 m .51531 .52295 L .51813 .5168 L p .697 .197 1 r
F P
0 g
s
.51907 .51458 m .51813 .5168 L .51531 .52295 L p .698 .198 1 r
F P
0 g
s
.52139 .50379 m .52141 .50336 L .52181 .49667 L p .67 .17 1 r
F P
0 g
s
.52172 .49636 m .52181 .49667 L .52141 .50336 L p .671 .171 1 r
F P
0 g
s
.51907 .51458 m .51975 .51299 L .52127 .50642 L p .694 .194 1 r
F P
0 g
s
.52132 .50524 m .52127 .50642 L .51975 .51299 L p .695 .195 1 r
F P
0 g
s
.52141 .50336 m .52143 .50304 L .52172 .49636 L p .671 .171 1 r
F P
0 g
s
.52164 .49614 m .52172 .49636 L .52143 .50304 L p .671 .171 1 r
F P
0 g
s
.52143 .50304 m .52144 .50282 L .52164 .49614 L p .671 .171 1 r
F P
0 g
s
.52159 .49599 m .52164 .49614 L .52144 .50282 L p .671 .171 1 r
F P
0 g
s
.52144 .50282 m .52145 .50266 L .52159 .49599 L p .671 .171 1 r
F P
0 g
s
.52156 .49587 m .52159 .49599 L .52145 .50266 L p .671 .171 1 r
F P
0 g
s
.52145 .50266 m .52145 .50255 L .52156 .49587 L p .671 .171 1 r
F P
0 g
s
.52153 .49579 m .52156 .49587 L .52145 .50255 L p .671 .171 1 r
F P
0 g
s
.52145 .50255 m .52146 .50246 L .52153 .49579 L p .671 .171 1 r
F P
0 g
s
.52151 .49573 m .52153 .49579 L .52146 .50246 L p .672 .172 1 r
F P
0 g
s
.52146 .50246 m .52146 .50241 L .52151 .49573 L p .672 .172 1 r
F P
0 g
s
.50455 .53481 m .50932 .53131 L .51289 .52581 L p .687 .187 1 r
F P
0 g
s
.51531 .52295 m .51289 .52581 L .50932 .53131 L p 1 0 .5 r
F P
0 g
s
.51975 .51299 m .52023 .51185 L .52132 .50524 L p .695 .195 1 r
F P
0 g
s
.52136 .5044 m .52132 .50524 L .52023 .51185 L p .694 .194 1 r
F P
0 g
s
.49195 .5433 m .50027 .53932 L .50455 .53481 L p .667 .167 1 r
F P
0 g
s
.50932 .53131 m .50455 .53481 L .50027 .53932 L p .85 0 .5 r
F P
0 g
s
.51531 .52295 m .51705 .52089 L .51907 .51458 L p .698 .198 1 r
F P
0 g
s
.51975 .51299 m .51907 .51458 L .51705 .52089 L p 1 0 .5 r
F P
0 g
s
.52023 .51185 m .52058 .51103 L .52136 .5044 L p .694 .194 1 r
F P
0 g
s
.52139 .50379 m .52136 .5044 L .52058 .51103 L p .691 .191 1 r
F P
0 g
s
.49435 .3098 m .5023 .33582 L .48126 .33336 L p .974 .042 .709 r
F P
0 g
s
.48126 .33336 m .46464 .309 L .49435 .3098 L p .974 .042 .709 r
F P
0 g
s
.52058 .51103 m .52083 .51044 L .52139 .50379 L p .691 .191 1 r
F P
0 g
s
.52141 .50336 m .52139 .50379 L .52083 .51044 L p .689 .189 1 r
F P
0 g
s
.52083 .51044 m .52101 .51002 L .52141 .50336 L p .689 .189 1 r
F P
0 g
s
.52143 .50304 m .52141 .50336 L .52101 .51002 L p .687 .187 1 r
F P
0 g
s
.52101 .51002 m .52114 .50971 L .52143 .50304 L p .687 .187 1 r
F P
0 g
s
.52144 .50282 m .52143 .50304 L .52114 .50971 L p 1 0 .5 r
F P
0 g
s
.4738 .55041 m .48723 .54635 L .49195 .5433 L p .681 .142 1 r
F P
0 g
s
.50027 .53932 m .49195 .5433 L .48723 .54635 L p .626 0 .5 r
F P
0 g
s
.51705 .52089 m .5183 .51941 L .51975 .51299 L p 1 0 .5 r
F P
0 g
s
.52023 .51185 m .51975 .51299 L .5183 .51941 L p 1 0 .5 r
F P
0 g
s
.52114 .50971 m .52123 .5095 L .52144 .50282 L p 1 0 .5 r
F P
0 g
s
.52145 .50266 m .52144 .50282 L .52123 .5095 L p 1 0 .5 r
F P
0 g
s
.50932 .53131 m .51275 .5288 L .51531 .52295 L p 1 0 .5 r
F P
0 g
s
.51705 .52089 m .51531 .52295 L .51275 .5288 L p 1 0 .5 r
F P
0 g
s
.52123 .5095 m .5213 .50934 L .52145 .50266 L p 1 0 .5 r
F P
0 g
s
.52145 .50255 m .52145 .50266 L .5213 .50934 L p 1 0 .5 r
F P
0 g
s
.5213 .50934 m .52135 .50923 L .52145 .50255 L p 1 0 .5 r
F P
0 g
s
.52146 .50246 m .52145 .50255 L .52135 .50923 L p 1 0 .5 r
F P
0 g
s
.52135 .50923 m .52138 .50915 L .52146 .50246 L p 1 0 .5 r
F P
0 g
s
.52146 .50241 m .52146 .50246 L .52138 .50915 L p 1 0 .5 r
F P
0 g
s
.52138 .50915 m .5214 .50909 L .52146 .50241 L p 1 0 .5 r
F P
0 g
s
.5183 .51941 m .5192 .51835 L .52023 .51185 L p 1 0 .5 r
F P
0 g
s
.52058 .51103 m .52023 .51185 L .5192 .51835 L p 1 0 .5 r
F P
0 g
s
.50027 .53932 m .50625 .53646 L .50932 .53131 L p .85 0 .5 r
F P
0 g
s
.51275 .5288 m .50932 .53131 L .50625 .53646 L p .935 0 .5 r
F P
0 g
s
.5192 .51835 m .51984 .51759 L .52058 .51103 L p 1 0 .5 r
F P
0 g
s
.52083 .51044 m .52058 .51103 L .51984 .51759 L p 1 0 .5 r
F P
0 g
s
.51275 .5288 m .51521 .527 L .51705 .52089 L p 1 0 .5 r
F P
0 g
s
.5183 .51941 m .51705 .52089 L .51521 .527 L p 1 0 .5 r
F P
0 g
s
.79888 .39494 m .89281 .37861 L .91681 .41747 L p .855 .056 .778 r
F P
0 g
s
.60179 .38969 m .63457 .37312 L .65132 .39515 L p .872 .042 .711 r
F P
0 g
s
.63457 .37312 m .60179 .38969 L .586 .37395 L p .891 .04 .701 r
F P
0 g
s
.51984 .51759 m .5203 .51705 L .52083 .51044 L p 1 0 .5 r
F P
0 g
s
.52101 .51002 m .52083 .51044 L .5203 .51705 L p 1 0 .5 r
F P
0 g
s
.5203 .51705 m .52063 .51666 L .52101 .51002 L p 1 0 .5 r
F P
0 g
s
.52114 .50971 m .52101 .51002 L .52063 .51666 L p 1 0 .5 r
F P
0 g
s
.79888 .39494 m .71875 .40887 L .70435 .37817 L p .86 .052 .76 r
F P
0 g
s
.65132 .39515 m .70435 .37817 L .71875 .40887 L p .857 .049 .744 r
F P
0 g
s
.52063 .51666 m .52087 .51638 L .52114 .50971 L p 1 0 .5 r
F P
0 g
s
.52123 .5095 m .52114 .50971 L .52087 .51638 L p 1 0 .5 r
F P
0 g
s
.52087 .51638 m .52104 .51618 L .52123 .5095 L p 1 0 .5 r
F P
0 g
s
.5213 .50934 m .52123 .5095 L .52104 .51618 L p 1 0 .5 r
F P
0 g
s
.52104 .51618 m .52116 .51603 L .5213 .50934 L p 1 0 .5 r
F P
0 g
s
.52135 .50923 m .5213 .50934 L .52116 .51603 L p 1 0 .5 r
F P
0 g
s
.51521 .527 m .51698 .5257 L .5183 .51941 L p 1 0 .5 r
F P
0 g
s
.5192 .51835 m .5183 .51941 L .51698 .5257 L p 1 0 .5 r
F P
0 g
s
.52116 .51603 m .52124 .51593 L .52135 .50923 L p 1 0 .5 r
F P
0 g
s
.52138 .50915 m .52135 .50923 L .52124 .51593 L p 1 0 .5 r
F P
0 g
s
.52124 .51593 m .52131 .51586 L .52138 .50915 L p 1 0 .5 r
F P
0 g
s
.5214 .50909 m .52138 .50915 L .52131 .51586 L p 1 0 .5 r
F P
0 g
s
.52131 .51586 m .52135 .5158 L .5214 .50909 L p 1 0 .5 r
F P
0 g
s
.48723 .54635 m .49689 .54343 L .50027 .53932 L p .626 0 .5 r
F P
0 g
s
.50625 .53646 m .50027 .53932 L .49689 .54343 L p .75 0 .5 r
F P
0 g
s
.50625 .53646 m .51055 .53441 L .51275 .5288 L p .935 0 .5 r
F P
0 g
s
.51521 .527 m .51275 .5288 L .51055 .53441 L p .967 0 .5 r
F P
0 g
s
.51698 .5257 m .51825 .52477 L .5192 .51835 L p 1 0 .5 r
F P
0 g
s
.51984 .51759 m .5192 .51835 L .51825 .52477 L p 1 0 .5 r
F P
0 g
s
.52554 .31469 m .52435 .34114 L .5023 .33582 L p .962 .04 .698 r
F P
0 g
s
.5023 .33582 m .49435 .3098 L .52554 .31469 L p .962 .04 .698 r
F P
0 g
s
.51825 .52477 m .51916 .5241 L .51984 .51759 L p 1 0 .5 r
F P
0 g
s
.5203 .51705 m .51984 .51759 L .51916 .5241 L p 1 0 .5 r
F P
0 g
s
.10953 .25797 m .16709 .24051 L p .1434 .28504 L .884 .061 .803 r
F P
0 g
s
.16709 .24051 m .17022 .24169 L .1434 .28504 L p .884 .061 .803 r
F P
0 g
s
.1434 .28504 m .07379 .26986 L .10953 .25797 L p .884 .061 .803 r
F P
0 g
s
.51916 .5241 m .51981 .52363 L .5203 .51705 L p 1 0 .5 r
F P
0 g
s
.52063 .51666 m .5203 .51705 L .51981 .52363 L p 1 0 .5 r
F P
0 g
s
.51055 .53441 m .51364 .53293 L .51521 .527 L p .967 0 .5 r
F P
0 g
s
.51698 .5257 m .51521 .527 L .51364 .53293 L p .977 0 .5 r
F P
0 g
s
.51981 .52363 m .52028 .52328 L .52063 .51666 L p 1 0 .5 r
F P
0 g
s
.52087 .51638 m .52063 .51666 L .52028 .52328 L p 1 0 .5 r
F P
0 g
s
.70435 .37817 m .65132 .39515 L .63457 .37312 L p .871 .047 .735 r
F P
0 g
s
.52028 .52328 m .52062 .52304 L .52087 .51638 L p 1 0 .5 r
F P
0 g
s
.52104 .51618 m .52087 .51638 L .52062 .52304 L p 1 0 .5 r
F P
0 g
s
.49689 .54343 m .50384 .54132 L .50625 .53646 L p .75 0 .5 r
F P
0 g
s
.51055 .53441 m .50625 .53646 L .50384 .54132 L p .81 0 .5 r
F P
0 g
s
.52062 .52304 m .52086 .52286 L .52104 .51618 L p 1 0 .5 r
F P
0 g
s
.52116 .51603 m .52104 .51618 L .52086 .52286 L p 1 0 .5 r
F P
0 g
s
.52086 .52286 m .52103 .52274 L .52116 .51603 L p 1 0 .5 r
F P
0 g
s
.52124 .51593 m .52116 .51603 L .52103 .52274 L p 1 0 .5 r
F P
0 g
s
.52103 .52274 m .52115 .52265 L .52124 .51593 L p 1 0 .5 r
F P
0 g
s
.52131 .51586 m .52124 .51593 L .52115 .52265 L p 1 0 .5 r
F P
0 g
s
.52115 .52265 m .52124 .52258 L .52131 .51586 L p 1 0 .5 r
F P
0 g
s
.52135 .5158 m .52131 .51586 L .52124 .52258 L p 1 0 .5 r
F P
0 g
s
.52124 .52258 m .52131 .52253 L .52135 .5158 L p 1 0 .5 r
F P
0 g
s
.51364 .53293 m .51585 .53187 L .51698 .5257 L p .977 0 .5 r
F P
0 g
s
.51825 .52477 m .51698 .5257 L .51585 .53187 L p .98 0 .5 r
F P
0 g
s
.586 .37395 m .61252 .35343 L .63457 .37312 L p .891 .04 .701 r
F P
0 g
s
.61252 .35343 m .586 .37395 L .56722 .36039 L p .91 .039 .694 r
F P
0 g
s
.51585 .53187 m .51744 .53111 L .51825 .52477 L p .98 0 .5 r
F P
0 g
s
.51916 .5241 m .51825 .52477 L .51744 .53111 L p .98 0 .5 r
F P
0 g
s
.44072 .27393 m .46464 .309 L .43784 .31198 L p .944 .05 .751 r
F P
0 g
s
.43784 .31198 m .40289 .28101 L .44072 .27393 L p .944 .05 .751 r
F P
0 g
s
.50384 .54132 m .50882 .53982 L .51055 .53441 L p .81 0 .5 r
F P
0 g
s
.51364 .53293 m .51055 .53441 L .50882 .53982 L p .836 0 .5 r
F P
0 g
s
.51744 .53111 m .51858 .53057 L .51916 .5241 L p .98 0 .5 r
F P
0 g
s
.51981 .52363 m .51916 .5241 L .51858 .53057 L p .98 0 .5 r
F P
0 g
s
.51858 .53057 m .5194 .53018 L .51981 .52363 L p .98 0 .5 r
F P
0 g
s
.52028 .52328 m .51981 .52363 L .5194 .53018 L p .979 0 .5 r
F P
0 g
s
.55665 .32374 m .54634 .34937 L .52435 .34114 L p .946 .038 .692 r
F P
0 g
s
.52435 .34114 m .52554 .31469 L .55665 .32374 L p .946 .038 .692 r
F P
0 g
s
.5194 .53018 m .51998 .5299 L .52028 .52328 L p .979 0 .5 r
F P
0 g
s
.52062 .52304 m .52028 .52328 L .51998 .5299 L p .979 0 .5 r
F P
0 g
s
.51998 .5299 m .5204 .5297 L .52062 .52304 L p .979 0 .5 r
F P
0 g
s
.52086 .52286 m .52062 .52304 L .5204 .5297 L p .978 0 .5 r
F P
0 g
s
.5204 .5297 m .5207 .52955 L .52086 .52286 L p .978 0 .5 r
F P
0 g
s
.52103 .52274 m .52086 .52286 L .5207 .52955 L p .978 0 .5 r
F P
0 g
s
.50882 .53982 m .5124 .53873 L .51364 .53293 L p .836 0 .5 r
F P
0 g
s
.51585 .53187 m .51364 .53293 L .5124 .53873 L p .848 0 .5 r
F P
0 g
s
.5207 .52955 m .52092 .52945 L .52103 .52274 L p .978 0 .5 r
F P
0 g
s
.52115 .52265 m .52103 .52274 L .52092 .52945 L p .978 0 .5 r
F P
0 g
s
.52092 .52945 m .52107 .52938 L .52115 .52265 L p .978 0 .5 r
F P
0 g
s
.52124 .52258 m .52115 .52265 L .52107 .52938 L p .978 0 .5 r
F P
0 g
s
.52107 .52938 m .52119 .52932 L .52124 .52258 L p .978 0 .5 r
F P
0 g
s
.52131 .52253 m .52124 .52258 L .52119 .52932 L p .977 0 .5 r
F P
0 g
s
.52119 .52932 m .52126 .52929 L .52131 .52253 L p .977 0 .5 r
F P
0 g
s
.56722 .36039 m .58612 .33678 L .61252 .35343 L p .91 .039 .694 r
F P
0 g
s
.58612 .33678 m .56722 .36039 L .54634 .34937 L p .929 .038 .691 r
F P
0 g
s
.5124 .53873 m .51497 .53796 L .51585 .53187 L p .848 0 .5 r
F P
0 g
s
.51744 .53111 m .51585 .53187 L .51497 .53796 L p .854 0 .5 r
F P
0 g
s
.54634 .34937 m .55665 .32374 L .58612 .33678 L p .929 .038 .691 r
F P
0 g
s
.51497 .53796 m .51681 .5374 L .51744 .53111 L p .854 0 .5 r
F P
0 g
s
.51858 .53057 m .51744 .53111 L .51681 .5374 L p .858 0 .5 r
F P
0 g
s
.51681 .5374 m .51813 .537 L .51858 .53057 L p .858 0 .5 r
F P
0 g
s
.5194 .53018 m .51858 .53057 L .51813 .537 L p .86 0 .5 r
F P
0 g
s
.51813 .537 m .51907 .53671 L .5194 .53018 L p .86 0 .5 r
F P
0 g
s
.51998 .5299 m .5194 .53018 L .51907 .53671 L p .861 0 .5 r
F P
0 g
s
.51907 .53671 m .51975 .53651 L .51998 .5299 L p .861 0 .5 r
F P
0 g
s
.5204 .5297 m .51998 .5299 L .51975 .53651 L p .862 0 .5 r
F P
0 g
s
.51975 .53651 m .52024 .53636 L .5204 .5297 L p .862 0 .5 r
F P
0 g
s
.5207 .52955 m .5204 .5297 L .52024 .53636 L p .862 0 .5 r
F P
0 g
s
.52024 .53636 m .52058 .53626 L .5207 .52955 L p .862 0 .5 r
F P
0 g
s
.52092 .52945 m .5207 .52955 L .52058 .53626 L p .862 0 .5 r
F P
0 g
s
.52058 .53626 m .52083 .53618 L .52092 .52945 L p .862 0 .5 r
F P
0 g
s
.52107 .52938 m .52092 .52945 L .52083 .53618 L p .863 0 .5 r
F P
0 g
s
.52083 .53618 m .52101 .53613 L .52107 .52938 L p .863 0 .5 r
F P
0 g
s
.52119 .52932 m .52107 .52938 L .52101 .53613 L p .863 0 .5 r
F P
0 g
s
.52101 .53613 m .52114 .53609 L .52119 .52932 L p .863 0 .5 r
F P
0 g
s
.52126 .52929 m .52119 .52932 L .52114 .53609 L p .863 0 .5 r
F P
0 g
s
.52114 .53609 m .52123 .53606 L .52126 .52929 L p .863 0 .5 r
F P
0 g
s
.89281 .37861 m .79888 .39494 L .78001 .35395 L p .862 .054 .772 r
F P
0 g
s
.70435 .37817 m .78001 .35395 L .79888 .39494 L p .86 .052 .76 r
F P
0 g
s
.3522 .2361 m .40289 .28101 L .37123 .29275 L p .919 .056 .778 r
F P
0 g
s
.37123 .29275 m .30785 .25601 L .3522 .2361 L p .919 .056 .778 r
F P
0 g
s
.63457 .37312 m .68131 .34949 L .70435 .37817 L p .871 .047 .735 r
F P
0 g
s
.68131 .34949 m .63457 .37312 L .61252 .35343 L p .885 .045 .727 r
F P
0 g
s
.22978 .2215 m .24253 .21815 L p .27472 .28094 L .899 .059 .795 r
F P
0 g
s
.24253 .21815 m .30785 .25601 L .27472 .28094 L p .899 .059 .795 r
F P
0 g
s
.27472 .28094 m .17022 .24169 L p .22978 .2215 L .899 .059 .795 r
F P
0 g
s
.48289 .27228 m .49435 .3098 L .46464 .309 L p .941 .048 .738 r
F P
0 g
s
.46464 .309 m .44072 .27393 L .48289 .27228 L p .941 .048 .738 r
F P
0 g
s
.78001 .35395 m .70435 .37817 L .68131 .34949 L p .87 .051 .753 r
F P
0 g
s
.61252 .35343 m .65051 .32401 L .68131 .34949 L p .885 .045 .727 r
F P
0 g
s
.65051 .32401 m .61252 .35343 L .58612 .33678 L p .899 .045 .723 r
F P
0 g
s
.52727 .27653 m .52554 .31469 L .49435 .3098 L p .934 .046 .729 r
F P
0 g
s
.49435 .3098 m .48289 .27228 L .52727 .27653 L p .934 .046 .729 r
F P
0 g
s
.88844 .37126 m .89281 .37861 L p .78001 .35395 L .862 .054 .772 r
F P
0 g
s
.58612 .33678 m .61331 .30282 L .65051 .32401 L p .899 .045 .723 r
F P
0 g
s
.61331 .30282 m .58612 .33678 L .55665 .32374 L p .912 .044 .721 r
F P
0 g
s
.57151 .2868 m .55665 .32374 L .52554 .31469 L p .924 .045 .723 r
F P
0 g
s
.52554 .31469 m .52727 .27653 L .57151 .2868 L p .924 .045 .723 r
F P
0 g
s
.55665 .32374 m .57151 .2868 L .61331 .30282 L p .912 .044 .721 r
F P
0 g
s
.40585 .22282 m .44072 .27393 L .40289 .28101 L p .92 .053 .767 r
F P
0 g
s
.40289 .28101 m .3522 .2361 L .40585 .22282 L p .92 .053 .767 r
F P
0 g
s
.78001 .35395 m .86166 .32781 L .88844 .37126 L p .862 .054 .772 r
F P
0 g
s
.68131 .34949 m .74855 .31549 L .78001 .35395 L p .87 .051 .753 r
F P
0 g
s
.74855 .31549 m .68131 .34949 L .65051 .32401 L p .88 .05 .748 r
F P
0 g
s
.86166 .32781 m .78001 .35395 L .74855 .31549 L p .869 .053 .767 r
F P
0 g
s
.28958 .20423 m .31021 .1989 L p .30785 .25601 L .902 .057 .786 r
F P
0 g
s
.31021 .1989 m .3522 .2361 L .30785 .25601 L p .902 .057 .786 r
F P
0 g
s
.30785 .25601 m .24253 .21815 L .28958 .20423 L p .902 .057 .786 r
F P
0 g
s
.46614 .21741 m .48289 .27228 L .44072 .27393 L p .918 .052 .758 r
F P
0 g
s
.44072 .27393 m .40585 .22282 L .46614 .21741 L p .918 .052 .758 r
F P
0 g
s
.16886 .23994 m .17396 .23843 L .17022 .24169 L p .888 .059 .797 r
F P
0 g
s
.17022 .24169 m .16709 .24051 L .16886 .23994 L p .888 .059 .797 r
F P
0 g
s
.17022 .24169 m .17396 .23843 L .22978 .2215 L p .899 .059 .795 r
F P
0 g
s
.65051 .32401 m .70556 .2814 L .74855 .31549 L p .88 .05 .748 r
F P
0 g
s
.70556 .2814 m .65051 .32401 L .61331 .30282 L p .89 .049 .745 r
F P
0 g
s
.52979 .22067 m .52727 .27653 L .48289 .27228 L p .914 .05 .751 r
F P
0 g
s
.48289 .27228 m .46614 .21741 L .52979 .22067 L p .914 .05 .751 r
F P
0 g
s
.61331 .30282 m .6529 .25336 L .70556 .2814 L p .89 .049 .745 r
F P
0 g
s
.6529 .25336 m .61331 .30282 L .57151 .2868 L p .899 .049 .744 r
F P
0 g
s
.59324 .2328 m .57151 .2868 L .52727 .27653 L p .907 .049 .746 r
F P
0 g
s
.52727 .27653 m .52979 .22067 L .59324 .2328 L p .907 .049 .746 r
F P
0 g
s
.57151 .2868 m .59324 .2328 L .6529 .25336 L p .899 .049 .744 r
F P
0 g
s
.85598 .31823 m .86166 .32781 L p .74855 .31549 L .869 .053 .767 r
F P
0 g
s
.74855 .31549 m .82913 .27475 L .85598 .31823 L p .869 .053 .767 r
F P
0 g
s
.82913 .27475 m .74855 .31549 L .70556 .2814 L p .877 .053 .763 r
F P
0 g
s
.35324 .18634 m .37681 .18024 L p .3522 .2361 L .903 .056 .778 r
F P
0 g
s
.37681 .18024 m .40585 .22282 L .3522 .2361 L p .903 .056 .778 r
F P
0 g
s
.3522 .2361 m .31021 .1989 L .35324 .18634 L p .903 .056 .778 r
F P
0 g
s
.82529 .26829 m .82913 .27475 L p .70556 .2814 L .877 .053 .763 r
F P
0 g
s
.70556 .2814 m .78659 .21867 L p .82529 .26829 L .877 .053 .763 r
F P
0 g
s
.78659 .21867 m .70556 .2814 L .6529 .25336 L p .884 .052 .761 r
F P
0 g
s
.42925 .16494 m .44856 .15984 L p .40585 .22282 L .902 .054 .771 r
F P
0 g
s
.44856 .15984 m .46614 .21741 L .40585 .22282 L p .902 .054 .771 r
F P
0 g
s
.40585 .22282 m .37681 .18024 L .42925 .16494 L p .902 .054 .771 r
F P
0 g
s
.6529 .25336 m .71166 .17997 L .78659 .21867 L p .884 .052 .761 r
F P
0 g
s
.71166 .17997 m .6529 .25336 L .59324 .2328 L p .89 .052 .761 r
F P
0 g
s
.53356 .13721 m .52979 .22067 L .46614 .21741 L p .899 .053 .766 r
F P
0 g
s
.46614 .21741 m .44856 .15984 L .5257 .13707 L p .899 .053 .766 r
F P
0 g
s
.5257 .13707 m .53356 .13721 L p .46614 .21741 L .899 .053 .766 r
F P
0 g
s
.78659 .21867 m .80203 .23086 L .82529 .26829 L p .877 .053 .763 r
F P
0 g
s
.59324 .2328 m .62564 .15226 L .71166 .17997 L p .89 .052 .761 r
F P
0 g
s
.62564 .15226 m .59324 .2328 L .52979 .22067 L p .895 .052 .762 r
F P
0 g
s
.52979 .22067 m .53356 .13721 L .62564 .15226 L p .895 .052 .762 r
F P
0 g
s
.79392 .21773 m .80203 .23086 L .78659 .21867 L p .874 .055 .774 r
F P
0 g
s
.78659 .21867 m .7919 .21456 L .79392 .21773 L p .874 .055 .774 r
F P
0 g
s
.7919 .21456 m .78659 .21867 L .71166 .17997 L p .879 .055 .773 r
F P
0 g
s
.76161 .16582 m .7919 .21456 L p .71166 .17997 L .879 .055 .773 r
F P
0 g
s
.71166 .17997 m .74442 .13905 L .76161 .16582 L p .879 .055 .773 r
F P
0 g
s
.74442 .13905 m .71166 .17997 L .62564 .15226 L p .883 .055 .773 r
F P
0 g
s
.72331 .10542 m .74442 .13905 L p .62564 .15226 L .883 .055 .773 r
F P
0 g
s
.62564 .15226 m .64697 .09923 L .70658 .07961 L p .883 .055 .773 r
F P
0 g
s
.70658 .07961 m .72331 .10542 L p .62564 .15226 L .883 .055 .773 r
F P
0 g
s
.64697 .09923 m .62564 .15226 L .53356 .13721 L p .887 .055 .774 r
F P
0 g
s
.53368 .13465 m .53356 .13721 L .5257 .13707 L closepath p .895 .052 .762 r
F P
0 g
s
.53923 .13287 m .64697 .09923 L p .53356 .13721 L .887 .055 .774 r
F P
0 g
s
.53356 .13721 m .53368 .13465 L .53923 .13287 L p .887 .055 .774 r
F P
0 g
s
.25 Mabswid
.70169 0 m
.97317 .41255 L
s
.97317 .41255 m
1 .6113 L
s
1 .6113 m
.71498 .21633 L
s
.71498 .21633 m
.70169 0 L
s
.0317 .25804 m
0 .46462 L
s
0 .46462 m
.71498 .21633 L
s
.71498 .21633 m
.70169 0 L
s
.70169 0 m
.0317 .25804 L
s
.0317 .25804 m
.70169 0 L
s
.17763 .20184 m
.18219 .20649 L
s
gsave
.16851 .19252 -71.5152 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34628 .13688 m
.35056 .1418 L
s
gsave
.33773 .12704 -67.6007 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.526 .06766 m
.52994 .07286 L
s
gsave
.51812 .05728 -67.3218 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.21052 .18917 m
.21323 .19199 L
s
.24383 .17634 m
.2465 .1792 L
s
.27755 .16335 m
.28019 .16624 L
s
.3117 .1502 m
.3143 .15312 L
s
.38131 .12339 m
.38384 .12638 L
s
.41678 .10973 m
.41927 .11275 L
s
.45272 .09589 m
.45517 .09894 L
s
.48912 .08187 m
.49153 .08495 L
s
.14514 .21435 m
.14791 .21711 L
s
.11304 .22671 m
.11584 .22944 L
s
.08133 .23892 m
.08416 .24163 L
s
.05001 .25099 m
.05286 .25366 L
s
.56337 .05327 m
.56569 .05642 L
s
.60124 .03869 m
.60351 .04187 L
s
.63961 .02391 m
.64184 .02713 L
s
.6785 .00893 m
.68068 .01218 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  FormatType->StandardForm,
  ImageSize->{180, 139.625},
  ImageMargins->{{111, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002d0000Ra000`40O003h00O]7oo002dOol00;Ao
o`00Ogoo0P00<goo001lOol300000goo001oo`0bOol007Uoo`@000=oo`80039oo`00Mgoo0P001goo
00<007oo0000<Goo001dOol30009Ool00`00Ool0000aOol0079oo`800003Ool007oo00Uoo`04001o
o`00000`Ool005aoo`<0011oo`<000ioo`05001oogooOol0000_Ool005ioo`03001oogoo00]oo`@0
011oo`05001oogooOol0000_Ool005eoo`03001oogoo00Yoo`8001Aoo`03001oogoo009oo`03001o
ogoo02aoo`00GWoo00<007ooOol01Woo0`005Woo00<007ooOol00goo00<007ooOol0:goo001UOol2
00000goo001oo`0GOol01000Oomoogoo0P00;Goo001ROol3000LOol00`00Oomoo`03Ool00`00Oomo
o`0ZOol005moo`@001ioo`03001oogoo00Aoo`03001oogoo02Uoo`00GGoo0P008Woo00<007ooOol0
17oo00<007ooOol0:Goo001JOol3000QOol40006Ool2000ZOol005Moo`<0025oo`<0009`>08000Qo
o`03001oogoo02Moo`00EGoo0P008Goo0`001W0h00<007ooOol01Woo00<007ooOol00goo1P007Woo
001BOol4000OOol30009L3P20008Ool00`00Oomoo`07Ool00`00Oomoo`0LOol003eoo`80015oo`80
021oo`<00003L3P0070h00U`>003001`>00000Qoo`03001oogoo00Eoo`03001oogoo01eoo`00?Goo
00<007oo00003Goo0`007goo0`000g0h00<0070hL3P02G0h00<0070h00001goo0P0027oo00<007oo
Ool077oo000mOol00`00Ool0000:Ool3000OOol30006L3P00`00L3Q`>009L3P01000L3Q`>00027oo
00<007ooOol097oo000nOol20008Ool2000OOol30009L3P00`00L3Q`>009L3P01@00L3Q`>70h0000
1goo00<007ooOol097oo0015Ool3000NOol3000;L3P00`00L3Q`>00:L3P01@00L3Q`>70h000027oo
00<007ooOol08goo0013Ool2000KOol7000=L3P00`00L3Q`>00:L3P00`00L3Q`>002L3P00`00Oomo
o`05Ool2000TOol0041oo`<00003Ool007oo01Moo`<000=`>004001`>70hL3P50008L3P00`00L3Q`
>00:L3P00`00L3Q`>003L3P00`00Oomoo`05Ool00`00Oomoo`0ROol003eoo`<001Uoo`@000I`>003
001`>70h00I`>0D0009`>003001`>70h00]`>003001`>70h00=`>003001oogoo00Ioo`03001oogoo
025oo`00>goo0`0067oo0`002W0h00<0070hL3P02g0h0`003G0h00<0070hL3P00W0h00<0070h0000
27oo00<007ooOol087oo000hOol3000HOol3000=L3P00`00L3Q`>00=L3P00`00L3P000020009L3P0
1@00L3Q`>70h00000g0h00<007ooOol01Goo00<007ooOol087oo000fOol3000GOol300000g0h001`
>00=L3P00`00L3Q`>00<L3P00`00L3Q`>003L3P30006L3P01000L3Q`>0001G0h00<007ooOol01Goo
00<007ooOol07goo000LOol3000017oo0000000047oo0`005goo0`00170h00<0070hL3P0370h00<0
070hL3P0370h00<0070hL3P01W0h0`00170h0P001W0h00<007ooOol01Woo00<007ooOol07Woo000R
Ool00`00Oomoo`0;Ool3000GOol30008L3P00`00L3Q`>00;L3P00`00L3Q`>00;L3P00`00L3Q`>00:
L3P300000g0h001`>007L3P00`00Oomoo`05Ool00`00Oomoo`0NOol0025oo`03001oogoo00Yoo`80
009oo`03001oogoo015oo`@000]`>003001`>70h00Y`>003001`>70h00a`>003001`>70h00e`>080
00Q`>003001oogoo00Eoo`8001moo`008Woo00<007ooOol01Woo0`0057oo10000W0h00<0070hL3P0
2W0h00<0070hL3P02W0h00<0070hL3P0370h00<0070hL3P03G0h0P002G0h00<007ooOol01Woo00<0
07ooOol077oo000XOol300000goo001oo`0AOol30007L3P00`00L3Q`>00:L3P00`00L3Q`>009L3P0
0`00L3Q`>00;L3P00`00L3Q`>00=L3P00`00L3P00002L3P00`00L3Q`>005L3P00`00Oomoo`05Ool0
0`00Oomoo`0LOol002Ioo`8001=oo`@000]`>003001`>70h00U`>003001`>70h00U`>003001`>70h
00]`>003001`>70h00a`>004001`>70h0004L3P00`00L3Q`>003L3P00`00Oomoo`06Ool00`00Oomo
o`0KOol002=oo`<00003Ool007oo00ioo`@000A`>@03001`>70h00U`>003001`>70h00Q`>003001`
>70h00U`>003001`>70h00Y`>003001`>70h00a`>005001`>70hL3P0000;L3P00`00Oomoo`05Ool2
000LOol0025oo`80011oo`@000U`>@03001`>70h00Q`>003001`>70h00U`>003001`>70h00Q`>003
001`>70h00Y`>003001`>70h00]`>003001`>70h009`>003001`>70h00M`>003001`>00000Qoo`03
001oogoo00=oo`8001Eoo`007Woo10003Woo0`003W0i00<0070hL3P0270h00<0070hL3P00g0h3000
170h00<0070hL3P02G0h00<0070hL3P02g0h00<0070hL3P00W0h0P002g0h0P0027oo00<007ooOol0
0Woo00<007oo000057oo000KOol3000?Ool30003L3T00`00L3U`>@0<L3T00`00L3Q`>006L3P70005
M3P00`00M3Qd>004M3P80008L3P00`00L3Q`>00;L3P00`00L3P0000200000g0h001`>008L3P01@00
L3Q`>70h000027oo00L007ooOomoo`00Ool0000DOol001Uoo`@000eoo`<000M`>@8000e`>@03001`
>70h00D0009d>003001d>7@h00Qd>003001d>7@h00Md>004001d=g@gM3L50003L3P00`00L3Q`>00:
L3P30005L3P00`00L3Q`>005L3P00`00L3Q`>003L3P00`00Oomoo`04Ool20004Ool2000DOol001Io
o`<000ioo`<000a`>@8000]`>@<000Qd>003001d>7@h00Md>003001d>7@h00Md>003001d=g@g00Id
=`D000Q`>0<000U`>003001`>70h00=`>003001`>70h00A`>003001oogoo00Ioo`03001oogoo01Mo
o`0057oo0`002goo1@004G0i00<0070iL3T01W0i0P000g@h00<007@hM3P01W@h00<007@hM3P01W@h
00<007@hM3P01g@h00<007@gM3L027@g00<0070gL3L00`000W0h0`0000=`>000L3P02W0h00<0070h
L3P00P00270h00<007ooOol01Woo00<007ooOol05Woo000AOol3000;Ool30003L3T00`00L3T00002
000?L3T20004L3T20006M3P00`00M3Qd>005M3P00`00M3Qd>007M3P00`00M3Qd>006M3P00`00M3Md
=`07M3L00`00L3M`=`03L3L40002L3P00`00L3Q`>00:L3P00`00L3P0000:L3P00`00Oomoo`06Ool0
0`00Oomoo`0FOol000ioo`@000Yoo`<000E`>@03001`>G0i00=`>@8000m`>@04001`>@000009M3P0
0`00M3Qd>005M3P00`00M3Qd>006M3P00`00M3Qd>006M3P00`00M3Md=`07M3L00`00L3M`=`030004
L3L2000>L3P00`00L3Q`>00:L3P00`00Oomoo`05Ool2000GOol000eoo`8000Yoo`<000M`>@03001`
>G0i00I`>@<000a`>@<000]d>003001d>7@h00Ed>003001d>7@h00Ed>003001d>7@h00Id>003001d
=g@g00Id=`@000Q`=`04001`=`000009L3P200000g0h001`>00;L3P00`00Oomoo`06Ool00`00Oomo
o`0DOol000eoo`<000Ioo`<000Y`>@03001`>G0i00U`>@<000Q`>@04001d>G@iM3T2000:M3P00`00
M3Qd>004M3P00`00M3Qd>006M3P00`00M3Qd>005M3P00`00M3Md=`04M3L3000:L3L00`00L3M`=`02
L3L20006L3P01@00L3Q`>70h0000370h00<007ooOol01Woo00<007ooOol057oo000=Ool01000Oomo
o`000Woo10002g0i00<0070iL3T03G0i0P001G0i00<007@iM3T017@i0P002G@h00<007@hM3P017@h
00<007@hM3P00W@h20000g@h00@007@gM3Md=`<0009d=`03001`=g0g00M`=`03001`=g0g00E`=`03
001`>70h009`>003001`>70h00=`>003001`>70h00Y`>003001oogoo00Eoo`8001Eoo`003Goo00<0
07ooOol00`00170i10001g0i00<0070iL3T03g0i0`0000=`>@00M3T027@i00<007@hM3P01g@h00@0
07@hM3Qd>0L000=h=`03001d=g@g009d=`L000Ad=`03001`=g0g00M`=`03001`=g0g00M`=`800003
L3P0070h00I`>003001`>70h00U`>003001oogoo00Moo`03001oogoo019oo`0037oo10002g0i1000
0W0i00<0070iL3T04g0i0P002W@i0P001g@h10000gPh00<007PgN3L017Pg00<007@gM3L017@g0P00
0W@g0`000W@g00<0070gL3L01W0g00<0070gL3L02W0g00<0070hL3P01g0h00<0070hL3P01G0h0P00
00=/>000Ool027oo00<007ooOol04Woo000<Ool2000AL3T4000DL3T00`00M3T000020009M3T20002
M3P30003N3P00`00N3Qh>002N3P00`00N3Mh=`04N3L00`00M3Md=`0300000g@g001d=`04M3L30008
L3L00`00L3M`=`08L3L01@00L3M`=g0g00001g0h00<0070hL3P00g0h0P0016`h00<007ooOol01goo
00<007ooOol04Goo000<Ool3000AL3T00`00L5Y`FP05000>L3T00`00M3Ud>@03M3T20008M3T30007
N3P00`00N3Qh>002N3P00`00N3Mh=`03N3L30004M3L00`00M3Md=`04M3L00`00M3L000020004L3L0
0`00L3M`=`08L3L00`00L3M`=`03L3L00`00L3Q`>005L3P00`00L3Q`>0020007K3P00`00Oomoo`06
Ool2000BOol000aoo`03001oogoo008000m`>@03001`FW1J00E`FPD000Q`>@03001d>G@i00Id>@80
00Ed>@04001h>GPiN3T20006N3P01@00N3Qh>7Ph00000WPg10001G@g00<007@gM3L017@g00<007@g
M3L00g@g0P0000=`=`00L3L0270g0P001g0g0P001W0h0P002V`h00<007ooOol01Woo00<007ooOol0
47oo0002Ool50005Ool00`00Oomoo`02Ool00`00L3U`>@0<L3T00`00L5Y`FP0:L5X50002L3T00`00
M3Ud>@09M3T300000g@i001h>@05N3T20005N3P00`00N3Qh>0030004N3L00`00M3Md=`02M3L00`00
M3Md=`04M3L00`00M3Md=`05M3L00`00L3M`=`07L3L00`00L3M`=`09L3L00`00L3Q`>002L3P3000:
K3P00`00Oomoo`07Ool00`00Oomoo`0?Ool000Ioo`03001oogoo00=oo`03001oogoo00=oo`8000]`
>@03001`FW1J011`FP@000ed>@<000Mh>@80009h>0l00003M3L007@g00Ed=`03001d=g@g00Ed=`03
001`=`00008000A`=`03001`=g0g00]`=`04001`>0000002K3P00`00K3Q/>009K3P00`00Oomoo`07
Ool00`00Oomoo`0>Ool000Moo`03001oogoo009oo`03001oogoo00Eoo`03001`>G0i00Q`>@03001`
FW1J015`FP03001`FW1J00D000Md>@04001d>G@iM3T30005N3T40002O3L01000O3Ml=`0017`f00@0
07PfN3Ih=PD0009d=`03001d=g@g00Ed=`03001`=g0g00=`=`800003L3L0070g00i`=`03001/>6`h
00=/>003001/>6`h00U/>003001oogoo00Eoo`80011oo`001Woo0P000goo00<007ooOol01goo1P00
170i00<0071JL5X04G1J00<0071JL5X01G1J10000W@i00<007@iM3T01G@i1P000W`h0P000W`g00@0
07`gO3L000Al=P05001h=WPfN3H00003N3H30006M3L00`00L3M`=`06L3L00`00L3M`=`0;L3L20000
0f`h001/>005K3P00`00K3Q/>008K3P00`00Oomoo`07Ool00`00Oomoo`02Ool30008Ool000]oo`80
00Yoo`A/FPX000e`FP03001`FW1J00Y`FPD000Ed>@H000Al>004001l=g`g0002O3L01@00O3Il=W`f
00000gPf00<007PfN3H00gPf00<007@f00000P0000=d=`00L3L01W0g00@0070gL3L000Y`=`8000A/
>003001/>6`h00A/>003001/>6`h00Q/>003001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Io
o`002goo00<007ooOol02Woo1faJ00<0071JL5X00g1J2@00171J00<0071JL5X02g1J00@007AJM5Yd
FPD0009d>@04001h>GPiN3T300000g`h0000000=0004N3H00`00M3Id=P03M3H00`00L3M`=`04L3L2
0004L3L00`00L3M`=`05L3L20007K3P00`00K3Q/>003K3P00`00K3Q/>003K3P30002K3P00`00Oomo
o`06Ool20004Ool00`00Oomoo`07Ool000]oo`8000aoo`I/FP03001`FW1J00a`FP`000E`FP03001d
FWAJ009dFP8000=dFPD000=h>@<0009l>0800003O3H0000000=l=@03001l57`D008000=h=P03001d
=W@f00=d=P03001d=P0000=`=`03001`=g0g00E`=`03001`=g0g009`=`8000Y/>003001/>6`h00=/
>0D000I/>003001oogoo00Moo`03001oogoo009oo`03001oogoo00Ioo`002goo00<007ooOol037oo
1FaJ00<0071JL5X0471J00<0071JL5X01G1J2`001GAJ00@007QJN5YhFPP00003O3P0000000<0009l
=@05001l57`D001l500200000gPf001d=P03M3H01`00M3Id=W@f001`=`0000U`=`04001`=`00000=
K3P00`00K3Q/>0040009K3P00`00Oomoo`07Ool00`00Oomoo`0;Ool000]oo`03001oogoo00eoo`05
001/FVaJK5X0000BL5X00`00L5Y`FP09L5X30004L5/>00000gaK0000000400000g`e000000050003
O1@30002M3H00`00M3Id=P03M3H00`00L3M`=`09L3L00`00K3Q/>00>K3P20003K3P00`00K3Q/>008
K3P00`00Oomoo`07Ool00`00Oomoo`0:Ool000]oo`8000moo`05001/FVaJK5X0000AL5X00`00L5Y`
FP06L5X300000g1J001`F`08L5/01@00M5]dFgAK00000WAK3@0000El4`00O19l4P0000=l5003001h
57PD008000Ed=P03001`=P0000M`=`80009/=`03001/>6`h00Q/>0<0009/>003001/>6`h00=/>003
001/>6`h00Q/>003001oogoo00Ioo`8000]oo`002Woo00<007ooOol047oo00@006aJK5X0015`FP03
001`FW1J00=`FPH00003L5X0000000L00003L5/00000008000=`G005001`GG1M001`G@030003Ool5
00000g`B001l4P020003N1@00`00M1D00003M3H01@00L3I`=W0f0000170g0P001F`g00<006`hK3P0
16`h0`001V`h00<006`hK3P00f`h00<006`hK3P01f`h00<007ooOol01goo00<007ooOol02Goo0003
Ool20005Ool00`00Oomoo`0AOol00`00K5X00008L5X@0006L5X00`00L5]`F`07L5/01@00L5a`G71L
00000W1L10002Goo1@000W`B0P0000=h5000M1D00W@E00<007@f00001G0f00@0070g000000Q/=`03
001/>6`h00<000U/>003001/>6`h00A/>003001/>6`h00M/>003001oogoo00Moo`03001oogoo00Qo
o`000goo00<007oo000017oo0P004goo2P002FaJ0`002g1J00<0071KL5/00g1K0P000W1K0`0000A/
G@00000000eoo`@0009l4P03001l4`0000Ed5@03001`=W0f00E`=P03001/=f`g00U/=`8000e/>003
001/>6`h00=/>003001/>6`h00M/>003001oogoo00Moo`8000Uoo`000goo00<007oo000017oo00<0
07ooOol057oo00<006aJK5X02faJ0`0000=/FP00L5X0371J1@001VaK0P004Goo0`0000Ul4000O1=l
4`00N1<007@E00000g0e00<0070f00000P000V`f00<006`gK3L016`g0`0000=/=`00K3P03F`h00<0
06`hK3P016`h00<006`hK3P00f`h0`0000=/>000Ool027oo00<007ooOol01goo0004Ool20004Ool0
0`00Oomoo`0FOol00`00K5Y/FP06K5X30005K5X00`00L5Y`FP04L5X40003K5/00`00K5]/F`03K5/3
000EOol30002O1000`00N1=h4`020005L3D00`00K3I/=P04K3H00`00K3M/=`030005K3L00`00K3Q/
>00;K3P00`00K3Q/>002K3P80004K3P00`00Oomoo`08Ool00`00Oomoo`06Ool000Yoo`03001oogoo
01Moo`03001/FVaJ009/FP<000Q/FP03001`FW1J00@000Q/F`03001/F`00008001Qoo`@00004O100
07PC0002L1@01P00L3D00000K3D000M/=P8000Q/=`03001/>6`h00a/>0@000A/>003001/>6`h00I/
>003001oogoo00Moo`8000Moo`002Woo00<007ooOol067oo10002FaJ00<006aJK5X00P003FaK00<0
07ooOol06Woo0P0000Al3`00N14000A`5003001/=F`e009/=@03001/=V`f00<00003K3L006`g00Q/
=`03001/>6`h00E/>0D0009/>003001/>6`h00E/>003001/>6`h00M/>003001oogoo00Moo`03001o
ogoo00Eoo`002Goo0P006Goo0`0016aJ1`0016aJ00<006aKK5/01faK0`007Woo0`0000Ql3`00M180
070D001/50001F`e0P001F`g00<006`gK3L01f`g00<006`h000010001f`h00<006`hK3P01V`h00<0
06`hK3P01V`h00<007ooOol027oo00<007ooOol017oo0009Ool00`00Oomoo`0EOol30003Ool4000<
K5X00`00K5]/F`03K5/3000QOol2000017`?000007@B0P000f`D100000=/=P00K3L01F`g00<006`g
K3L00f`g0`0000=/=`00000036`h00<006`hK3P01f`h00<006`hK3P01V`h00<007ooOol01Woo0`00
1Goo0009Ool00`00Oomoo`0BOol30007Ool00`00K5Y/FP0=K5X00`00K5/00002000TOol600000f`C
001/5002K1@00`00K3I/=P02K3H00`00K3M/=`03K3L00`00K3L000040004K3P00`00K3Q/>00<K3P0
0`00K3Q/>007K3P00`00K3Q/>006K3P00`00Oomoo`02Ool300000goo00000005Ool000Uoo`80011o
o`<000aoo`03001/FVaJ00a/FP03001oogoo02Eoo`@00003K18006`C00<00003J3D006`f00A/=P03
001/=`000080009X=`03001/>6`h00I/>003001/>6`h00a/>003001/>6`h00M/>003001/>6`h00I/
>003001oo`00008000Eoo`03001oogoo00=oo`000Woo0P001Goo00<007ooOol037oo0`0047oo0P00
1VaJ1000:Woo0`0000I/4000000006PD0003J3D70005J3L00`00K3Q/>007K3P00`00K3Q/>00;K3P0
0`00K3Q/>008K3P00`00K3Q/>006K3P00`00Oomoo`06Ool00`00Oomoo`03Ool000=oo`03001oogoo
00=oo`03001oogoo00Uoo`<001Eoo`03001/FVaJ00<002ioo`/00003J3H006Pg00=X=`03001X=fPg
00EX=`03001/>6`h00I/>003001/>6`h00A/>0H00003K3P0000001@000Qoo`03001oogoo009oo`00
17oo00@007ooOomoo`8000Qoo`<001Uoo`80035oo`D00005I1@006@eI3D00002J3H00`00J3MX=`03
J3L00`00J3MX=`04J3L00`00K3Q/>002K3P;0007J3P00`00K3U/>@09K3T00`00K3U/>@05K3T20008
Ool00`00Oomoo`02Ool000=oo`8000=oo`03001oogoo00Aoo`<001ioo`03001oogoo02ioo`03001L
4V0C01/000AX>003001X>6Ph00]X>003001/>F`i00Y/>@03001/>F`i00=/>@04001/>F`i0007Ool0
0`00Oomoo`02Ool000Qoo`80009oo`<0029oo`03001oogoo02eoo`D00005H3D0060fH3H00002I3L0
0`00I3MT=`03I3L00`00J3QX>004J3P00`00J3QX>006J3P00`00J3QX>00;J3P00`00K3U/>@0;K3T0
0`00K3U/>@02K3T01@00K3U/>F`i00001Woo00<007ooOol00Woo0008Ool4000VOol2000]Ool;0000
0f@g001T=`03I3L00`00J3QX>005J3P00`00J3QX>006J3P00`00J3QX>00:J3P00`00K3U/>@0=K3T0
1@00K3U/>F`i00000f`i00<007ooOol017oo00<007ooOol00Woo0008Ool2000ZOol00`00Oomoo`0Z
Ool500001EPg001L=e`g00000V0h2P000VPh00<006PhJ3P01fPh00<006PhJ3P02VPh00<006`iK3T0
3F`i00@006`iK3T000E/>@03001oogoo00=oo`03001oogoo009oo`002Woo00<007ooOol0:7oo00<0
07ooOol0:Goo1`0000=L=`00H3P00V0h00<006@hI3P00V@h00<006@hI3P00V@h50001FPh00<006`i
K3T03V`i00<006`i00001F`i00<007ooOol00goo00<007ooOol00Woo000;Ool00`00Oomoo`0XOol0
0`00Oomoo`0XOol500000ePh001H>00700000f@h001T>006I3P00`00J3UX>@07J3T00`00J3UX>@05
J3T;000<K3T20006K3T00`00Oomoo`03Ool00`00Oomoo`01Ool000aoo`03001oogoo02Qoo`03001o
ogoo02Moo`<00006C5X00000001H>0000e`i00<0060iH3T010001F@h00<006PiJ3T01VPi00<006Pi
J3T02fPi00<006PiJ3T00fPi2@000f`i0P001f`i00<007ooOol00Woo00<007ooOol00Goo000=Ool2
000YOol00`00Oomoo`0VOol60002F5X200000e`i001P>@03H3T00`00I3UT>@0300000f@h001X>@08
J3T00`00J3UX>@0:J3T00`00J3UX>@0=J3T90003K3T00`00Oomoo`02Ool00`00Oomoo`01Ool000mo
o`03001oogoo02Moo`03001oogoo02Eoo`<00005D5/00000F5X00003G5X300000f0i001T>@05I3T4
0007J3T00`00J3UX>@0:J3T00`00J3UX>@0@J3T00`00K3T00003K3T50003Ool00`00Oomoo`01Ool0
011oo`03001oogoo02Moo`03001oogoo02Aoo`@0009DF`<00003G5X0061J009PFP<000ET>@04001X
>FPiJ3T500000fPi001X>@0;J3T00`00J3UX>@0@J3T01@00K3U/>F`i00001V`i00D007ooOomoo`00
00=oo`004Goo00<007ooOol09goo00<007ooOol08goo00<004ao00000P0000ADF`00F5]HF`8000=P
FP03001TFVAJ0080009T>@03001X>FPi00MX>@D000UX>@03001X>FPi011X>@05001/>F`iK3T00007
K3T01000Oomoo`000goo000BOol00`00Oomoo`0WOol00`00Oomoo`0ROol300001U1M00000000F5/0
009LF`03001PFP0000ITFP8000UX>@03001X>FPi009X>@H000=X>@03001X>FPi00mX>@03001/>F`i
00=/>@03001/>F`i00E/>@03001oo`0000=oo`004goo0P00:7oo00<007ooOol087oo0`0000=@O`00
F5`00UQL00<005aKG5/00UaK0P001VAJ00<006AJ00000P001FPi00<006PiJ3T02FPi1@0046Pi00<0
06`iK3T016`i00<006`iK3T01F`i00<007oo00000Woo000EOol00`00Oomoo`0VOol2000POol40000
1UQN001HG000G5`000=LF`04001PFP000003I5X00`00I5YTFP03I5X20002J3T00`00J3UX>@0<J3T0
0`00J3UX>@04000<J3T00`00K3U/>@05K3T00`00K3U/>@04K3T00`00Ool00002Ool001Ioo`03001o
ogoo02Moo`03001oogoo01aoo`@0009HGP8000=LG003001LF`0000APFP03001TFP0000UTFP8000eX
>@03001X>FPi00EX>@D000IX>@03001/>F`i00I/>@03001/>F`i00E/>@80009oo`005goo00<007oo
Ool09goo00<007ooOol06Woo1@0000AHGP00G5d000=LG08000EPFP<000QTFP03001XFVQJ00<000UX
>@03001X>FPi00]X>@@0009X>@03001/>F`i00M/>@04001/>F`iK3T50002Ool001Qoo`8002Qoo`03
001oogoo01Moo`P000=LG@03G5`00000009PF`05001PFV1JH5X00003I5X30004I5X00`00J5YXFP04
J5X30005J3T00`00J3UX>@0@J3T50008K3T30004Ool10001Ool1Ool001Yoo`03001oogoo02Ioo`03
001oogoo01Aoo`@00006F7l00000001LGP000UaM0P001F1K00<0061J00001fAJ00@006AJI5X000YX
FP80009X>@03001X>FPi015X>@03001/>F`i009/>@D0009/>@<000Eoo`40005oo`5oo`006goo00<0
07ooOol09Woo00<007ooOol047oo0`0000=DWeQo00000P0000ALO`00G5iLGP<0009PG003001PFf1K
009PF`<000QTFP<000aXFP@0015X>@03001/>F`i00M/>@<0009oo`03001oogoo00=oo`40005oo`5o
o`0077oo00<007ooOol09Woo00<007ooOol02goo100000ETO`00001PO`00009LO`07001LO`00G5h0
061M0000161L00@0061K000000=TF`03001TFVAJ00ATFP04001XFVQJJ5X20009J5X00`00J5YXFP02
J5X3000=J3T00`00K3U/>@05K3T30006Ool00`00Oomoo`03Ool10001Ool001eoo`03001oogoo02Io
o`03001oogoo00Moo`<00003J7l00000009TO`9PO`L000=PG@03001PG61L009PG08000ITF`04001T
FVAJI5X20006J5X20006J5X00`00J5YXFP06J5X30009J3T00`00K3U/>@02K3T4000:Ool00`00Oomo
o`02Ool10001Ool001ioo`8002Moo`03001oogoo00=oo`<000=/GP03001TO`0000D0009TGP04001P
GF1M0004H5d400000fAK001TF`06I5/00`00I5X0000:J5X00`00J5YXFP02J5X00`00J5YXFP0:J5X3
0005J3T00`00K3U/>@03000?Ool01@00Oomoogoo00000Goo000POol00`00Oomoo`0UOol00`00Ool0
00020002K5h30002J5h01@00I5iTGVAN00000fAN00D0061MH5ePG@00009PG@<000ETF`03001TFfAK
00ATF`<000]XFP04001XFVQJ000@J5X20002J3T4000BOol01@00Oomoogoo00000Goo000QOol00`00
Oomoo`0SOol30004K5d00`00J5h00002J5h01@00I5iTGVAN000016AN00<0061M000010000VAL00<0
06AKI5/016AK00@006AKI5]TF`8000=XFP03001XFVQJ00UXFP<001=XFP8001Ioo`04001oogoo0001
Ool0029oo`03001oogoo01moo`<000A/G@8000AXG@d0009TG003001TG6AL00=TG003001TFfAK00=T
F`04001TF`000006J5X00`00J5YXFP07J5X01@00J5YXFVQJ00004FQJ0P0067oo00<007oo00000Goo
000SOol2000LOol30006K5d00`00J5eXG@03J5d00`00J5eXG@03J5d00`00J5aXG002J5`00`00I5aT
G002I5`00`00I5aTG003I5`00`00I5]TF`03I5/20009J5X00`00J5YXFP04J5X20005J5X2000<J5X2
000KOol00`00Ool00001Ool002Eoo`03001oogoo01Eoo`@000A/G0800003K5d0000000AXG@8000EX
G@03001XG6QL009XG003001TG6AL00=TG003001TG6AL00=TG003001TFfAK00<00003J5/006QJ00UX
FP04001XFVQJJ5X20009J5X20008J5X00`00Oomoo`0MOol10001Ool1000002Ioo`03001oogoo011o
o`@000Y/G004001XG@000002J5d00`00J5eXG@04J5d00`00J5aXG003J5`00`00I5aTG003I5`01000
I5aTG6AL1@001FQK00<006QJJ5X026QJ00<006QJ00003FQJ00H006QJJ5X006QJ000SOol2000002Mo
o`03001oogoo00aoo`<000Y/G0<000E/G0D000=XG@03001XG6QL00AXG003001TG6AL00L000=XF`03
001XFfQK00EXF`03001XFVQJ00MXFP<000eXFP<002Eoo`<00000:7oo0P002Goo0`000faK0P001VaL
0P001faL00<006QLJ5`00fQL3@000fQK00<006QKJ5/016QK00<006QKJ5/01VQK00<006QJJ5X00fQJ
0`000fQJ00<006QJJ5X01fQJ0`0097oo10000goo000ZOol00`00Oomoo`03Ool30008K5/2000016aL
0000000026aL00<006QLJ5`01VQL00<006QLJ5`016QL00<006QKJ5/016QK00<006QKJ5/01FQK00<0
06QKJ5/01VQK00<006QJ00000P001fQJ0P001FQJ0P0097oo0`001goo000[Ool00`00Ool00002000=
K5/00`00K5a/G008K5`00`00J5aXG006J5`00`00J5aXG004J5`00`00J5]XF`05J5/00`00J5]XF`05
J5/00`00J5]XF`06J5/2000<J5X00`00J5YXFP02000ROol4000:Ool002]oo`8000e/F`8000=/F`<0
00E/G003001XG6QL00IXG003001XG6QL00EXG003001XFfQK00EXF`03001XFfQK00EXF`03001XFfQK
00=XF`<00003J5X006QJ00]XFP<0021oo`@000ioo`00;Goo00<007oo000026aK0P0026aK0`0000=/
G000J5`01fQL00<006QLJ5`01FQL00<006QKJ5/01VQK00<006QKJ5/01VQK00<006QK00000P001FQJ
00<006QJJ5X01VQJ0`007goo10004Woo000^Ool40004K5/2000=K5/50004J5`00`00J5aXG006J5`0
0`00J5]XF`06J5/00`00J5]XF`02J5/60009J5X00`00J5YXFP03J5X2000NOol4000FOol0031oo`04
001oo`00K5/2000=K5/00`00K5]/F`04K5/90004J5`01000J5]XFfQK2P0016QK00<006QJJ5X026QJ
00<006QJJ5X00`007Goo0`006Woo000aOol00`00Ool0000=K5/2000:K5/00`00K5]/F`03K5/80005
J5/00`00J5]XF`07J5/00`00J5YXFP07J5X3000LOol4000MOol0039oo`03001oo`0000]/F`03001/
FfaK00U/F`03001/FfaK00M/F`03001XFfQK00MXF`03001XFfQK00MXF`03001XFVQJ00AXFP<001]o
o`@0025oo`00<goo0P0000=oofaKK5/01faK00<006aKK5/02FaK00<006aKK5/01faK00<006QKJ5/0
26QK00<006QKJ5/01fQK00<006QJJ5X00VQJ0P006Woo10009Goo000eOol00`00Ool00005K5/2000;
K5/00`00K5]/F`08K5/00`00J5]XF`08J5/00`00J5]XF`08J5/01000J5X0000067oo1000:Goo000f
Ool00`00Ool00003K5/00`00K5]/F`0:K5/00`00K5]/F`09K5/00`00J5]XF`07J5/00`00J5]XF`08
J5/3000GOol3000]Ool003Moo`03001oogoo00800003K5/0000000U/F`03001/FfaK00U/F`03001X
FfQK00QXF`03001XFfQK00EXF`<001Ioo`@0031oo`00>7oo00D007ooOomoo`00009/F`D000=/F`03
001/FfaK00Y/F`03001XFfQK00QXF`03001XFfQK009XF`<001Eoo`@003Aoo`00>Goo0P000Woo0P00
1FaK2P001VaK00<006QKJ5/026QK00<006QK00000P0057oo1000>7oo000kOol01@00Oomoogoo0000
1VaK00<006aKK5/01FaK4`0057oo0`00?7oo000lOol01@00Oomoogoo000016aK00<006aKK5/02faK
00<006aJK5X026aJ00<007ooOol047oo1000?goo000mOol00`00Oomoo`02Ool00`00K5/0000=K5/0
0`00K5Y/FP06K5X00`00Oomoo`0?Ool40013Ool003ioo`8000=oo`03001/FfaK00]/F`03001/FVaJ
00A/FP03001oogoo00ioo`@004Moo`00@7oo00D007ooOomoo`0000a/F`04001/FVaJK5X@Ool4001;
Ool0045oo`05001oogooOol00009K5/200000faJOomoo`0>Ool3001?Ool0049oo`04001oogooOol2
0004K5/3000?Ool4001BOol004=oo`03001oogoo009oo`04001/FfaK000>Ool4001FOol004Aoo`80
00=oo`03001oogoo00Yoo`@005Yoo`00AWoo00@007ooOol000Qoo`@005ioo`00Agoo00<007oo0000
1Goo0`00HWoo0018Ool200000goo00000002001UOol004Uoo`8006Uoo`00]7oo002dOol00;Aoo`00
\
\>"],
  ImageRangeCache->{{{0, 179}, {138.625, 0}} -> {-0.0463054, 0.0642164, \
0.00561535, 0.00561535}}]
}, Closed]],

Cell[TextData[{
  "Because of the discontinuity along the negative real axis, the logarithm \
function has a branch cut running from 0 to ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\)\)],
    FormatType->StandardForm],
  ". Along the negative real axis, the resulting function is not continuous, \
and the values at this limit differ by ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]\ \[ImaginaryI]\)],
    FormatType->StandardForm],
  " depending on the direction of approach. Note that the placement of the \
discontinuity on the negative real axis is a direct consequence of our choice \
of the initial strip to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)],
    FormatType->StandardForm],
  "; by choosing different constraints on the domain, we could move the \
branch cut to a different position. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot3D[
        Evaluate[{Re[\[ExponentialE]\^\(w\_r + \[ImaginaryI]\ w\_i\)], 
            Im[\[ExponentialE]\^\(w\_r + \[ImaginaryI]\ w\_i\)], 
            w\_i}], {w\_r, \(-5\), 
          5}, {w\_i, \(-\(\(3\ \[Pi]\)\/2\)\), \[Pi]\/2}];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .80175 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.14315e-17 1.05309 -0.0743297 1.05309 [
[.1537 .18979 -10.5152 -7 ]
[.1537 .18979 .10981 0 ]
[.3267 .12224 -6.6007 -7 ]
[.3267 .12224 .4618 0 ]
[.51119 .05024 -6.32184 -7 ]
[.51119 .05024 .86566 0 ]
[.77149 .12032 0 -4.76844 ]
[.77149 .12032 10.625 2.23156 ]
[.85302 .24196 0 -4.68141 ]
[.85302 .24196 7.0625 2.31859 ]
[.9259 .35071 0 -4.60555 ]
[.9259 .35071 7.1875 2.39445 ]
[.01601 .28101 -10.375 -2.15606 ]
[.01601 .28101 0 4.84394 ]
[.00643 .34313 -10.5625 -2.19515 ]
[.00643 .34313 0 4.80485 ]
[-0.00351 .40768 -7.0625 -2.23591 ]
[-0.00351 .40768 0 4.76409 ]
[ 0 0 0 0 ]
[ 1 .80175 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03233 .24995 m
.67538 0 L
s
.16291 .1992 m
.16752 .2039 L
s
gsave
.1537 .18979 -71.5152 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.33533 .13218 m
.33965 .13714 L
s
gsave
.3267 .12224 -67.6007 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51915 .06073 m
.52313 .06597 L
s
gsave
.51119 .05024 -67.3218 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.19654 .18613 m
.19927 .18898 L
s
.23058 .17289 m
.23328 .17578 L
s
.26506 .15949 m
.26772 .16241 L
s
.29997 .14592 m
.3026 .14887 L
s
.37115 .11825 m
.3737 .12127 L
s
.40743 .10415 m
.40994 .1072 L
s
.44418 .08987 m
.44665 .09295 L
s
.48142 .07539 m
.48385 .07851 L
s
.1297 .2121 m
.1325 .21489 L
s
.0969 .22485 m
.09973 .22761 L
s
.0645 .23745 m
.06735 .24018 L
s
.03249 .24989 m
.03537 .25259 L
s
.55738 .04587 m
.55972 .04905 L
s
.59612 .03081 m
.59842 .03402 L
s
.63538 .01555 m
.63763 .01879 L
s
.67518 8e-05 m
.67738 .00336 L
s
.25 Mabswid
.67538 0 m
.9737 .44463 L
s
.75912 .12481 m
.75293 .12705 L
s
gsave
.77149 .12032 -61 -8.76844 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84054 .24617 m
.83431 .24828 L
s
gsave
.85302 .24196 -61 -8.68141 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.91334 .35468 m
.90707 .35666 L
s
gsave
.9259 .35071 -61 -8.60555 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.77617 .15022 m
.77245 .15154 L
s
.79282 .17504 m
.78909 .17635 L
s
.80909 .19929 m
.80536 .20059 L
s
.825 .223 m
.82126 .22428 L
s
.85575 .26883 m
.852 .27008 L
s
.87062 .291 m
.86687 .29223 L
s
.88517 .31268 m
.88141 .3139 L
s
.89941 .3339 m
.89565 .33511 L
s
.74166 .09879 m
.73795 .10015 L
s
.72378 .07213 m
.72008 .07352 L
s
.70546 .04483 m
.70177 .04623 L
s
.68668 .01684 m
.683 .01826 L
s
.92699 .37501 m
.92322 .37619 L
s
.94035 .39493 m
.93657 .39609 L
s
.95344 .41443 m
.94966 .41558 L
s
.96626 .43354 m
.96247 .43468 L
s
.25 Mabswid
.03233 .24995 m
0 .46115 L
s
.0283 .27629 m
.03444 .27393 L
s
gsave
.01601 .28101 -71.375 -6.15606 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.01877 .33854 m
.02494 .33624 L
s
gsave
.00643 .34313 -71.5625 -6.19515 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.00887 .40321 m
.01506 .40097 L
s
gsave
-0.00351 .40768 -68.0625 -6.23591 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
.02595 .29163 m
.02964 .29022 L
s
.02358 .30712 m
.02727 .30572 L
s
.02119 .32275 m
.02488 .32136 L
s
.01633 .35447 m
.02003 .3531 L
s
.01387 .37056 m
.01757 .3692 L
s
.01138 .38681 m
.01509 .38545 L
s
.03062 .26109 m
.03431 .25967 L
s
.00633 .41977 m
.01005 .41844 L
s
.00377 .4365 m
.00749 .43518 L
s
.00119 .45339 m
.00491 .45208 L
s
.25 Mabswid
.03233 .24995 m
0 .46115 L
s
0 .46115 m
.41151 .80175 L
s
.41151 .80175 m
.41732 .61059 L
s
.41732 .61059 m
.03233 .24995 L
s
.67538 0 m
.9737 .44463 L
s
.9737 .44463 m
1 .64598 L
s
1 .64598 m
.6864 .22043 L
s
.6864 .22043 m
.67538 0 L
s
.03233 .24995 m
0 .46115 L
s
0 .46115 m
.6864 .22043 L
s
.6864 .22043 m
.67538 0 L
s
.67538 0 m
.03233 .24995 L
s
.41732 .61059 m
.9737 .44463 L
s
.9737 .44463 m
1 .64598 L
s
1 .64598 m
.41151 .80175 L
s
.41151 .80175 m
.41732 .61059 L
s
0 0 m
1 0 L
1 .80175 L
0 .80175 L
closepath
clip
newpath
.5 Mabswid
.48087 .58745 m .47489 .61519 L .41656 .63555 L p .839 .066 .83 r
F P
0 g
s
.41656 .63555 m .40937 .62942 L p .48087 .58745 L .839 .066 .83 r
F P
0 g
s
.40937 .62942 m .39144 .61511 L p .48087 .58745 L .839 .066 .83 r
F P
0 g
s
.54644 .58866 m .47489 .61519 L p .55339 .58263 L .836 .065 .826 r
F P
0 g
s
.47489 .61519 m .48087 .58745 L .55339 .58263 L p .836 .065 .826 r
F P
0 g
s
.40944 .58402 m .39144 .61511 L .37188 .59882 L p .844 .066 .832 r
F P
0 g
s
.39144 .61511 m .40944 .58402 L .48087 .58745 L p .839 .066 .83 r
F P
0 g
s
.55339 .58263 m .55382 .58603 L .54644 .58866 L p .836 .065 .826 r
F P
0 g
s
.55382 .58603 m .55339 .58263 L .57153 .57929 L closepath p .827 .067 .836 r
F P
0 g
s
.54641 .52709 m .55339 .58263 L .48087 .58745 L p .827 .067 .836 r
F P
0 g
s
.55339 .58263 m .54641 .52709 L .59922 .51558 L p .824 .066 .83 r
F P
0 g
s
.57153 .57929 m .55339 .58263 L p .59922 .51558 L .824 .066 .83 r
F P
0 g
s
.59922 .51558 m .62054 .56036 L .57153 .57929 L p .824 .066 .83 r
F P
0 g
s
.37188 .59882 m .33988 .57391 L p .40944 .58402 L .844 .066 .832 r
F P
0 g
s
.49276 .53227 m .48087 .58745 L .40944 .58402 L p .831 .068 .841 r
F P
0 g
s
.48087 .58745 m .49276 .53227 L .54641 .52709 L p .827 .067 .836 r
F P
0 g
s
.62928 .55667 m .62054 .56036 L p .64942 .49782 L .822 .065 .823 r
F P
0 g
s
.62054 .56036 m .59922 .51558 L .64942 .49782 L p .822 .065 .823 r
F P
0 g
s
.64942 .49782 m .68264 .53594 L .62928 .55667 L p .822 .065 .823 r
F P
0 g
s
.33988 .57391 m .34127 .57252 L .40944 .58402 L p .844 .066 .832 r
F P
0 g
s
.44004 .53115 m .40944 .58402 L .34127 .57252 L p .837 .069 .845 r
F P
0 g
s
.40944 .58402 m .44004 .53115 L .49276 .53227 L p .831 .068 .841 r
F P
0 g
s
.34127 .57252 m .33988 .57391 L .3389 .5731 L p .849 .067 .833 r
F P
0 g
s
.3389 .5731 m .33604 .57091 L .34127 .57252 L p .849 .067 .833 r
F P
0 g
s
.34127 .57252 m .33604 .57091 L .30461 .54644 L p .844 .069 .846 r
F P
0 g
s
.39005 .52395 m .34127 .57252 L p .30461 .54644 L .844 .069 .846 r
F P
0 g
s
.34127 .57252 m .39005 .52395 L .44004 .53115 L p .837 .069 .845 r
F P
0 g
s
.54112 .48503 m .54641 .52709 L .49276 .53227 L p .814 .07 .851 r
F P
0 g
s
.54641 .52709 m .54112 .48503 L .57981 .47483 L p .81 .068 .842 r
F P
0 g
s
.57981 .47483 m .59922 .51558 L .54641 .52709 L p .81 .068 .842 r
F P
0 g
s
.59922 .51558 m .57981 .47483 L .61645 .45997 L p .809 .066 .831 r
F P
0 g
s
.61645 .45997 m .64942 .49782 L .59922 .51558 L p .809 .066 .831 r
F P
0 g
s
.50176 .49048 m .49276 .53227 L .44004 .53115 L p .819 .072 .858 r
F P
0 g
s
.49276 .53227 m .50176 .49048 L .54112 .48503 L p .814 .07 .851 r
F P
0 g
s
.46316 .49122 m .44004 .53115 L .39005 .52395 L p .827 .073 .863 r
F P
0 g
s
.44004 .53115 m .46316 .49122 L .50176 .49048 L p .819 .072 .858 r
F P
0 g
s
.30461 .54644 m .29731 .54129 L p .39005 .52395 L .844 .069 .846 r
F P
0 g
s
.34456 .51099 m .29731 .54129 L .27043 .52072 L p .853 .069 .845 r
F P
0 g
s
.29731 .54129 m .34456 .51099 L .39005 .52395 L p .844 .069 .846 r
F P
0 g
s
.42672 .48742 m .39005 .52395 L .34456 .51099 L p .837 .073 .865 r
F P
0 g
s
.39005 .52395 m .42672 .48742 L .46316 .49122 L p .827 .073 .863 r
F P
0 g
s
.53717 .45364 m .54112 .48503 L .50176 .49048 L p .796 .074 .87 r
F P
0 g
s
.54112 .48503 m .53717 .45364 L .56535 .44446 L p .792 .071 .857 r
F P
0 g
s
.56535 .44446 m .57981 .47483 L .54112 .48503 L p .792 .071 .857 r
F P
0 g
s
.57981 .47483 m .56535 .44446 L .59195 .43186 L p .791 .069 .843 r
F P
0 g
s
.59195 .43186 m .61645 .45997 L .57981 .47483 L p .791 .069 .843 r
F P
0 g
s
.50848 .4593 m .50176 .49048 L .46316 .49122 L p .803 .076 .881 r
F P
0 g
s
.50176 .49048 m .50848 .4593 L .53717 .45364 L p .796 .074 .87 r
F P
0 g
s
.27043 .52072 m .25847 .51236 L p .34456 .51099 L .853 .069 .845 r
F P
0 g
s
.25847 .51236 m .30538 .49282 L .34456 .51099 L p .853 .069 .845 r
F P
0 g
s
.39384 .4794 m .34456 .51099 L .30538 .49282 L p .848 .073 .864 r
F P
0 g
s
.34456 .51099 m .39384 .4794 L .42672 .48742 L p .837 .073 .865 r
F P
0 g
s
.48038 .46147 m .46316 .49122 L .42672 .48742 L p .813 .078 .889 r
F P
0 g
s
.46316 .49122 m .48038 .46147 L .50848 .4593 L p .803 .076 .881 r
F P
0 g
s
.30538 .49282 m .25847 .51236 L .23352 .49346 L p .862 .068 .842 r
F P
0 g
s
.7026 .71815 m .69094 .72281 L p .70452 .66345 L .835 .066 .832 r
F P
0 g
s
.69094 .72281 m .65611 .68688 L .70452 .66345 L p .835 .066 .832 r
F P
0 g
s
.45395 .46031 m .42672 .48742 L .39384 .4794 L p .826 .078 .892 r
F P
0 g
s
.42672 .48742 m .45395 .46031 L .48038 .46147 L p .813 .078 .889 r
F P
0 g
s
.70452 .66345 m .75763 .6984 L .7026 .71815 L p .835 .066 .832 r
F P
0 g
s
.55469 .42207 m .56535 .44446 L .53717 .45364 L p .767 .076 .878 r
F P
0 g
s
.56535 .44446 m .55469 .42207 L .57393 .41117 L p .767 .072 .858 r
F P
0 g
s
.57393 .41117 m .59195 .43186 L .56535 .44446 L p .767 .072 .858 r
F P
0 g
s
.53425 .43047 m .53717 .45364 L .50848 .4593 L p .771 .079 .897 r
F P
0 g
s
.53717 .45364 m .53425 .43047 L .55469 .42207 L p .767 .076 .878 r
F P
0 g
s
.51344 .43628 m .50848 .4593 L .48038 .46147 L p .778 .083 .913 r
F P
0 g
s
.50848 .4593 m .51344 .43628 L .53425 .43047 L p .771 .079 .897 r
F P
0 g
s
.23352 .49346 m .21967 .48377 L p .30538 .49282 L .862 .068 .842 r
F P
0 g
s
.21967 .48377 m .27423 .47012 L .30538 .49282 L p .862 .068 .842 r
F P
0 g
s
.36586 .46761 m .30538 .49282 L .27423 .47012 L p .861 .072 .86 r
F P
0 g
s
.30538 .49282 m .36586 .46761 L .39384 .4794 L p .848 .073 .864 r
F P
0 g
s
.76535 .69534 m .75763 .6984 L p .74657 .63471 L .837 .064 .822 r
F P
0 g
s
.75763 .6984 m .70452 .66345 L .74657 .63471 L p .837 .064 .822 r
F P
0 g
s
.49307 .43955 m .48038 .46147 L .45395 .46031 L p .791 .085 .925 r
F P
0 g
s
.48038 .46147 m .49307 .43955 L .51344 .43628 L p .778 .083 .913 r
F P
0 g
s
.82716 .6696 m .81207 .67885 L .76535 .69534 L p .837 .064 .822 r
F P
0 g
s
.74657 .63471 m .82716 .6696 L p .76535 .69534 L .837 .064 .822 r
F P
0 g
s
.43024 .45607 m .39384 .4794 L .36586 .46761 L p .841 .078 .892 r
F P
0 g
s
.39384 .4794 m .43024 .45607 L .45395 .46031 L p .826 .078 .892 r
F P
0 g
s
.47396 .44038 m .45395 .46031 L .43024 .45607 L p .808 .087 .933 r
F P
0 g
s
.45395 .46031 m .47396 .44038 L .49307 .43955 L p .791 .085 .925 r
F P
0 g
s
.54689 .40569 m .55469 .42207 L .53425 .43047 L p .733 .081 .905 r
F P
0 g
s
.55469 .42207 m .54689 .40569 L .56077 .39607 L p .736 .075 .876 r
F P
0 g
s
.56077 .39607 m .57393 .41117 L .55469 .42207 L p .736 .075 .876 r
F P
0 g
s
.53212 .4135 m .53425 .43047 L .51344 .43628 L p .736 .086 .932 r
F P
0 g
s
.53425 .43047 m .53212 .4135 L .54689 .40569 L p .733 .081 .905 r
F P
0 g
s
.82813 .67309 m .81207 .67885 L .82716 .6696 L p .847 .064 .82 r
F P
0 g
s
.51707 .41943 m .51344 .43628 L .49307 .43955 L p .744 .092 .958 r
F P
0 g
s
.51344 .43628 m .51707 .41943 L .53212 .4135 L p .736 .086 .932 r
F P
0 g
s
.27423 .47012 m .21967 .48377 L .18883 .4604 L p .871 .067 .837 r
F P
0 g
s
.82716 .6696 m .83216 .67176 L .82813 .67309 L p .847 .064 .82 r
F P
0 g
s
.89134 .65087 m .83216 .67176 L p .87559 .62693 L .849 .062 .812 r
F P
0 g
s
.83216 .67176 m .82716 .6696 L .87559 .62693 L p .849 .062 .812 r
F P
0 g
s
.82716 .6696 m .74657 .63471 L .7805 .60123 L p .84 .062 .812 r
F P
0 g
s
.7805 .60123 m .87559 .62693 L .82716 .6696 L p .84 .062 .812 r
F P
0 g
s
.50235 .42351 m .49307 .43955 L .47396 .44038 L p .758 .096 .979 r
F P
0 g
s
.49307 .43955 m .50235 .42351 L .51707 .41943 L p .744 .092 .958 r
F P
0 g
s
.27423 .47012 m .34403 .45267 L .36586 .46761 L p .861 .072 .86 r
F P
0 g
s
.41024 .44912 m .36586 .46761 L .34403 .45267 L p .859 .077 .886 r
F P
0 g
s
.36586 .46761 m .41024 .44912 L .43024 .45607 L p .841 .078 .892 r
F P
0 g
s
.65611 .68688 m .62144 .65113 L .65654 .63188 L p .82 .068 .838 r
F P
0 g
s
.65654 .63188 m .70452 .66345 L .65611 .68688 L p .82 .068 .838 r
F P
0 g
s
.4569 .43897 m .43024 .45607 L .41024 .44912 L p .83 .087 .933 r
F P
0 g
s
.43024 .45607 m .4569 .43897 L .47396 .44038 L p .808 .087 .933 r
F P
0 g
s
.54121 .39378 m .54689 .40569 L .53212 .4135 L p .69 .088 .938 r
F P
0 g
s
.54689 .40569 m .54121 .39378 L .55121 .3851 L p .696 .08 .898 r
F P
0 g
s
.55121 .3851 m .56077 .39607 L .54689 .40569 L p .696 .08 .898 r
F P
0 g
s
.53057 .40115 m .53212 .4135 L .51707 .41943 L p .689 .096 .979 r
F P
0 g
s
.53212 .4135 m .53057 .40115 L .54121 .39378 L p .69 .088 .938 r
F P
0 g
s
.18883 .4604 m .17732 .45224 L p .27423 .47012 L .871 .067 .837 r
F P
0 g
s
.17732 .45224 m .25277 .44385 L .27423 .47012 L p .871 .067 .837 r
F P
0 g
s
.34403 .45267 m .27423 .47012 L .25277 .44385 L p .874 .071 .853 r
F P
0 g
s
.48857 .42582 m .47396 .44038 L .4569 .43897 L p .78 .098 .992 r
F P
0 g
s
.47396 .44038 m .48857 .42582 L .50235 .42351 L p .758 .096 .979 r
F P
0 g
s
.51971 .40717 m .51707 .41943 L .50235 .42351 L p .694 .104 1 r
F P
0 g
s
.51707 .41943 m .51971 .40717 L .53057 .40115 L p .689 .096 .979 r
F P
0 g
s
.87559 .62693 m .92458 .64017 L .89134 .65087 L p .849 .062 .812 r
F P
0 g
s
.54429 .37716 m .55121 .3851 L .54121 .39378 L p .649 .085 .924 r
F P
0 g
s
.5091 .41185 m .50235 .42351 L .48857 .42582 L p .708 .111 1 r
F P
0 g
s
.50235 .42351 m .5091 .41185 L .51971 .40717 L p .694 .104 1 r
F P
0 g
s
.5371 .38515 m .54121 .39378 L .53057 .40115 L p .635 .096 .978 r
F P
0 g
s
.54121 .39378 m .5371 .38515 L .54429 .37716 L p .649 .085 .924 r
F P
0 g
s
.70452 .66345 m .65654 .63188 L .68667 .60877 L p .823 .065 .825 r
F P
0 g
s
.68667 .60877 m .74657 .63471 L .70452 .66345 L p .823 .065 .825 r
F P
0 g
s
.52944 .39221 m .53057 .40115 L .51971 .40717 L p .625 .108 1 r
F P
0 g
s
.53057 .40115 m .52944 .39221 L .5371 .38515 L p .635 .096 .978 r
F P
0 g
s
.34403 .45267 m .39486 .43995 L .41024 .44912 L p .859 .077 .886 r
F P
0 g
s
.4426 .43563 m .41024 .44912 L .39486 .43995 L p .855 .085 .925 r
F P
0 g
s
.41024 .44912 m .4426 .43563 L .4569 .43897 L p .83 .087 .933 r
F P
0 g
s
.4763 .42653 m .4569 .43897 L .4426 .43563 L p .809 .099 .995 r
F P
0 g
s
.4569 .43897 m .4763 .42653 L .48857 .42582 L p .78 .098 .992 r
F P
0 g
s
.96464 .62643 m .92458 .64017 L p .91136 .5784 L .852 .061 .805 r
F P
0 g
s
.92458 .64017 m .87559 .62693 L .91136 .5784 L p .852 .061 .805 r
F P
0 g
s
.52163 .39829 m .51971 .40717 L .5091 .41185 L p .622 .12 1 r
F P
0 g
s
.51971 .40717 m .52163 .39829 L .52944 .39221 L p .625 .108 1 r
F P
0 g
s
.49918 .41526 m .48857 .42582 L .4763 .42653 L p .732 .116 1 r
F P
0 g
s
.48857 .42582 m .49918 .41526 L .5091 .41185 L p .708 .111 1 r
F P
0 g
s
.5393 .37143 m .54429 .37716 L .5371 .38515 L p .595 .09 .951 r
F P
0 g
s
.53414 .37892 m .5371 .38515 L .52944 .39221 L p .605 .105 1 r
F P
0 g
s
.5371 .38515 m .53414 .37892 L .5393 .37143 L p .595 .09 .951 r
F P
0 g
s
.25277 .44385 m .32947 .43532 L .34403 .45267 L p .874 .071 .853 r
F P
0 g
s
.39486 .43995 m .34403 .45267 L .32947 .43532 L p .878 .075 .875 r
F P
0 g
s
.51399 .4034 m .5091 .41185 L .49918 .41526 L p .632 .132 1 r
F P
0 g
s
.5091 .41185 m .51399 .4034 L .52163 .39829 L p .622 .12 1 r
F P
0 g
s
.52863 .38574 m .52944 .39221 L .52163 .39829 L p .622 .122 1 r
F P
0 g
s
.52944 .39221 m .52863 .38574 L .53414 .37892 L p .605 .105 1 r
F P
0 g
s
.5357 .3673 m .5393 .37143 L .53414 .37892 L p .596 .096 .978 r
F P
0 g
s
.532 .37443 m .53414 .37892 L .52863 .38574 L p .614 .114 1 r
F P
0 g
s
.53414 .37892 m .532 .37443 L .5357 .3673 L p .596 .096 .978 r
F P
0 g
s
.52301 .39187 m .52163 .39829 L .51399 .4034 L p .641 .141 1 r
F P
0 g
s
.52163 .39829 m .52301 .39187 L .52863 .38574 L p .622 .122 1 r
F P
0 g
s
.4426 .43563 m .46608 .42585 L .4763 .42653 L p .809 .099 .995 r
F P
0 g
s
.49037 .41751 m .4763 .42653 L .46608 .42585 L p .768 .118 1 r
F P
0 g
s
.4763 .42653 m .49037 .41751 L .49918 .41526 L p .732 .116 1 r
F P
0 g
s
.97638 .58729 m .99616 .61657 L .96464 .62643 L p .852 .061 .805 r
F P
0 g
s
.91136 .5784 m .97638 .58729 L p .96464 .62643 L .852 .061 .805 r
F P
0 g
s
.39486 .43995 m .43172 .43073 L .4426 .43563 L p .855 .085 .925 r
F P
0 g
s
.46608 .42585 m .4426 .43563 L .43172 .43073 L p .844 .097 .985 r
F P
0 g
s
.53312 .36433 m .5357 .3673 L .532 .37443 L p .601 .101 1 r
F P
0 g
s
.50686 .40761 m .49918 .41526 L .49037 .41751 L p .648 .141 1 r
F P
0 g
s
.49918 .41526 m .50686 .40761 L .51399 .4034 L p .632 .132 1 r
F P
0 g
s
.52804 .38108 m .52863 .38574 L .52301 .39187 L p .637 .137 1 r
F P
0 g
s
.52863 .38574 m .52804 .38108 L .532 .37443 L p .614 .114 1 r
F P
0 g
s
.53046 .3712 m .532 .37443 L .52804 .38108 L p .623 .123 1 r
F P
0 g
s
.532 .37443 m .53046 .3712 L .53312 .36433 L p .601 .101 1 r
F P
0 g
s
.25277 .44385 m .17732 .45224 L .13116 .417 L p .88 .066 .83 r
F P
0 g
s
.51752 .39731 m .51399 .4034 L .50686 .40761 L p .659 .159 1 r
F P
0 g
s
.51399 .4034 m .51752 .39731 L .52301 .39187 L p .641 .141 1 r
F P
0 g
s
.53126 .3622 m .53312 .36433 L .53046 .3712 L p .605 .105 1 r
F P
0 g
s
.87559 .62693 m .7805 .60123 L .80463 .56379 L p .844 .06 .802 r
F P
0 g
s
.80463 .56379 m .91136 .5784 L .87559 .62693 L p .844 .06 .802 r
F P
0 g
s
.52401 .38724 m .52301 .39187 L .51752 .39731 L p .663 .163 1 r
F P
0 g
s
.52301 .39187 m .52401 .38724 L .52804 .38108 L p .637 .137 1 r
F P
0 g
s
.53046 .3712 m .52935 .36888 L .53126 .3622 L p .605 .105 1 r
F P
0 g
s
.52993 .36067 m .53126 .3622 L .52935 .36888 L p .608 .108 1 r
F P
0 g
s
.32947 .43532 m .38487 .42916 L .39486 .43995 L p .878 .075 .875 r
F P
0 g
s
.43172 .43073 m .39486 .43995 L .38487 .42916 L p .883 .082 .91 r
F P
0 g
s
.74657 .63471 m .68667 .60877 L .71054 .58232 L p .828 .062 .812 r
F P
0 g
s
.71054 .58232 m .7805 .60123 L .74657 .63471 L p .828 .062 .812 r
F P
0 g
s
.52762 .37773 m .52804 .38108 L .52401 .38724 L p .652 .152 1 r
F P
0 g
s
.52804 .38108 m .52762 .37773 L .53046 .3712 L p .623 .123 1 r
F P
0 g
s
.52935 .36888 m .53046 .3712 L .52762 .37773 L p .632 .132 1 r
F P
0 g
s
.52935 .36888 m .52856 .36721 L .52993 .36067 L p .608 .108 1 r
F P
0 g
s
.52897 .35957 m .52993 .36067 L .52856 .36721 L p .611 .111 1 r
F P
0 g
s
.52856 .36721 m .52799 .36602 L .52897 .35957 L p .611 .111 1 r
F P
0 g
s
.52828 .35879 m .52897 .35957 L .52799 .36602 L p .613 .113 1 r
F P
0 g
s
.52762 .37773 m .52732 .37532 L .52935 .36888 L p .632 .132 1 r
F P
0 g
s
.52856 .36721 m .52935 .36888 L .52732 .37532 L p .638 .138 1 r
F P
0 g
s
.46608 .42585 m .48306 .41878 L .49037 .41751 L p .768 .118 1 r
F P
0 g
s
.50054 .41099 m .49037 .41751 L .48306 .41878 L p .684 .142 1 r
F P
0 g
s
.49037 .41751 m .50054 .41099 L .50686 .40761 L p .648 .141 1 r
F P
0 g
s
.52799 .36602 m .52758 .36516 L .52828 .35879 L p .613 .113 1 r
F P
0 g
s
.52779 .35822 m .52828 .35879 L .52758 .36516 L p .614 .114 1 r
F P
0 g
s
.5124 .40209 m .50686 .40761 L .50054 .41099 L p .668 .168 1 r
F P
0 g
s
.50686 .40761 m .5124 .40209 L .51752 .39731 L p .659 .159 1 r
F P
0 g
s
.52006 .39291 m .51752 .39731 L .5124 .40209 L p .685 .185 1 r
F P
0 g
s
.51752 .39731 m .52006 .39291 L .52401 .38724 L p .663 .163 1 r
F P
0 g
s
.52758 .36516 m .52729 .36454 L .52779 .35822 L p .614 .114 1 r
F P
0 g
s
.52744 .35782 m .52779 .35822 L .52729 .36454 L p .615 .115 1 r
F P
0 g
s
.52401 .38724 m .52472 .38391 L .52762 .37773 L p .652 .152 1 r
F P
0 g
s
.52732 .37532 m .52762 .37773 L .52472 .38391 L p .665 .165 1 r
F P
0 g
s
.62144 .65113 m .59565 .62453 L .621 .60849 L p .801 .069 .846 r
F P
0 g
s
.621 .60849 m .65654 .63188 L .62144 .65113 L p .801 .069 .846 r
F P
0 g
s
.52472 .38391 m .52401 .38724 L .52006 .39291 L p .684 .184 1 r
F P
0 g
s
.52729 .36454 m .52708 .3641 L .52744 .35782 L p .615 .115 1 r
F P
0 g
s
.52719 .35753 m .52744 .35782 L .52708 .3641 L p .616 .116 1 r
F P
0 g
s
.52708 .3641 m .52693 .36379 L .52719 .35753 L p .616 .116 1 r
F P
0 g
s
.527 .35732 m .52719 .35753 L .52693 .36379 L p .616 .116 1 r
F P
0 g
s
.52732 .37532 m .5271 .37359 L .52856 .36721 L p .638 .138 1 r
F P
0 g
s
.52799 .36602 m .52856 .36721 L .5271 .37359 L p .643 .143 1 r
F P
0 g
s
.43172 .43073 m .45836 .42407 L .46608 .42585 L p .844 .097 .985 r
F P
0 g
s
.48306 .41878 m .46608 .42585 L .45836 .42407 L p .815 .115 1 r
F P
0 g
s
.52693 .36379 m .52682 .36356 L .527 .35732 L p .616 .116 1 r
F P
0 g
s
.52688 .35717 m .527 .35732 L .52682 .36356 L p .617 .117 1 r
F P
0 g
s
.52682 .36356 m .52674 .3634 L .52688 .35717 L p .617 .117 1 r
F P
0 g
s
.52678 .35706 m .52688 .35717 L .52674 .3634 L p .617 .117 1 r
F P
0 g
s
.52674 .3634 m .52669 .36328 L .52678 .35706 L p .617 .117 1 r
F P
0 g
s
.52672 .35699 m .52678 .35706 L .52669 .36328 L p .617 .117 1 r
F P
0 g
s
.52669 .36328 m .52665 .3632 L .52672 .35699 L p .617 .117 1 r
F P
0 g
s
.52667 .35693 m .52672 .35699 L .52665 .3632 L p .617 .117 1 r
F P
0 g
s
.52665 .3632 m .52662 .36314 L .52667 .35693 L p .617 .117 1 r
F P
0 g
s
.5271 .37359 m .52694 .37235 L .52799 .36602 L p .643 .143 1 r
F P
0 g
s
.52758 .36516 m .52799 .36602 L .52694 .37235 L p .646 .146 1 r
F P
0 g
s
.12966 .41332 m .24245 .41516 L .25277 .44385 L p .88 .066 .83 r
F P
0 g
s
.13116 .417 m .12966 .41332 L p .25277 .44385 L .88 .066 .83 r
F P
0 g
s
.32947 .43532 m .25277 .44385 L .24245 .41516 L p .887 .068 .842 r
F P
0 g
s
.52472 .38391 m .52524 .38152 L .52732 .37532 L p .665 .165 1 r
F P
0 g
s
.5271 .37359 m .52732 .37532 L .52524 .38152 L p .675 .175 1 r
F P
0 g
s
.52694 .37235 m .52683 .37146 L .52758 .36516 L p .646 .146 1 r
F P
0 g
s
.52729 .36454 m .52758 .36516 L .52683 .37146 L p .649 .149 1 r
F P
0 g
s
.52683 .37146 m .52675 .37082 L .52729 .36454 L p .649 .149 1 r
F P
0 g
s
.52708 .3641 m .52729 .36454 L .52675 .37082 L p .65 .15 1 r
F P
0 g
s
.52006 .39291 m .52189 .38975 L .52472 .38391 L p .684 .184 1 r
F P
0 g
s
.52524 .38152 m .52472 .38391 L .52189 .38975 L p .696 .196 1 r
F P
0 g
s
.52675 .37082 m .52669 .37037 L .52708 .3641 L p .65 .15 1 r
F P
0 g
s
.52693 .36379 m .52708 .3641 L .52669 .37037 L p .651 .151 1 r
F P
0 g
s
.52524 .38152 m .52561 .3798 L .5271 .37359 L p .675 .175 1 r
F P
0 g
s
.52694 .37235 m .5271 .37359 L .52561 .3798 L p .68 .18 1 r
F P
0 g
s
.52669 .37037 m .52665 .37004 L .52693 .36379 L p .651 .151 1 r
F P
0 g
s
.52682 .36356 m .52693 .36379 L .52665 .37004 L p .652 .152 1 r
F P
0 g
s
.52665 .37004 m .52662 .3698 L .52682 .36356 L p .652 .152 1 r
F P
0 g
s
.52674 .3634 m .52682 .36356 L .52662 .3698 L p .653 .153 1 r
F P
0 g
s
.5124 .40209 m .51639 .39812 L .52006 .39291 L p .685 .185 1 r
F P
0 g
s
.52189 .38975 m .52006 .39291 L .51639 .39812 L p .696 .196 1 r
F P
0 g
s
.52662 .3698 m .5266 .36963 L .52674 .3634 L p .653 .153 1 r
F P
0 g
s
.52669 .36328 m .52674 .3634 L .5266 .36963 L p .653 .153 1 r
F P
0 g
s
.5266 .36963 m .52659 .36951 L .52669 .36328 L p .653 .153 1 r
F P
0 g
s
.52665 .3632 m .52669 .36328 L .52659 .36951 L p .653 .153 1 r
F P
0 g
s
.52659 .36951 m .52657 .36943 L .52665 .3632 L p .653 .153 1 r
F P
0 g
s
.52662 .36314 m .52665 .3632 L .52657 .36943 L p .653 .153 1 r
F P
0 g
s
.52657 .36943 m .52657 .36936 L .52662 .36314 L p .653 .153 1 r
F P
0 g
s
.50054 .41099 m .50786 .4063 L .5124 .40209 L p .668 .168 1 r
F P
0 g
s
.51639 .39812 m .5124 .40209 L .50786 .4063 L p .681 .181 1 r
F P
0 g
s
.52561 .3798 m .52587 .37857 L .52694 .37235 L p .68 .18 1 r
F P
0 g
s
.52683 .37146 m .52694 .37235 L .52587 .37857 L p .683 .183 1 r
F P
0 g
s
.38487 .42916 m .42479 .42472 L .43172 .43073 L p .883 .082 .91 r
F P
0 g
s
.45836 .42407 m .43172 .43073 L .42479 .42472 L p .885 .092 .961 r
F P
0 g
s
.48306 .41878 m .4953 .41367 L .50054 .41099 L p .684 .142 1 r
F P
0 g
s
.50786 .4063 m .50054 .41099 L .4953 .41367 L p .66 .16 1 r
F P
0 g
s
.52189 .38975 m .52321 .38748 L .52524 .38152 L p .696 .196 1 r
F P
0 g
s
.52561 .3798 m .52524 .38152 L .52321 .38748 L p .699 .199 1 r
F P
0 g
s
.52587 .37857 m .52606 .37769 L .52683 .37146 L p .683 .183 1 r
F P
0 g
s
.52675 .37082 m .52683 .37146 L .52606 .37769 L p .685 .185 1 r
F P
0 g
s
.52606 .37769 m .5262 .37705 L .52675 .37082 L p .685 .185 1 r
F P
0 g
s
.52669 .37037 m .52675 .37082 L .5262 .37705 L p .685 .185 1 r
F P
0 g
s
.5262 .37705 m .5263 .3766 L .52669 .37037 L p .685 .185 1 r
F P
0 g
s
.52665 .37004 m .52669 .37037 L .5263 .3766 L p .685 .185 1 r
F P
0 g
s
.51639 .39812 m .51926 .39526 L .52189 .38975 L p .696 .196 1 r
F P
0 g
s
.52321 .38748 m .52189 .38975 L .51926 .39526 L p 1 0 .5 r
F P
0 g
s
.5263 .3766 m .52637 .37627 L .52665 .37004 L p .685 .185 1 r
F P
0 g
s
.52662 .3698 m .52665 .37004 L .52637 .37627 L p .684 .184 1 r
F P
0 g
s
.52321 .38748 m .52415 .38585 L .52561 .3798 L p .699 .199 1 r
F P
0 g
s
.52587 .37857 m .52561 .3798 L .52415 .38585 L p .696 .196 1 r
F P
0 g
s
.52637 .37627 m .52642 .37604 L .52662 .3698 L p .684 .184 1 r
F P
0 g
s
.5266 .36963 m .52662 .3698 L .52642 .37604 L p .684 .184 1 r
F P
0 g
s
.45836 .42407 m .47756 .41927 L .48306 .41878 L p .815 .115 1 r
F P
0 g
s
.4953 .41367 m .48306 .41878 L .47756 .41927 L p .737 .134 1 r
F P
0 g
s
.52642 .37604 m .52646 .37587 L .5266 .36963 L p .684 .184 1 r
F P
0 g
s
.52659 .36951 m .5266 .36963 L .52646 .37587 L p .684 .184 1 r
F P
0 g
s
.52646 .37587 m .52648 .37575 L .52659 .36951 L p .684 .184 1 r
F P
0 g
s
.52657 .36943 m .52659 .36951 L .52648 .37575 L p .683 .183 1 r
F P
0 g
s
.52648 .37575 m .5265 .37567 L .52657 .36943 L p .683 .183 1 r
F P
0 g
s
.52657 .36936 m .52657 .36943 L .5265 .37567 L p .683 .183 1 r
F P
0 g
s
.5265 .37567 m .52651 .37561 L .52657 .36936 L p .683 .183 1 r
F P
0 g
s
.52415 .38585 m .52483 .38468 L .52587 .37857 L p .696 .196 1 r
F P
0 g
s
.52606 .37769 m .52587 .37857 L .52483 .38468 L p 1 0 .5 r
F P
0 g
s
.50786 .4063 m .51314 .40292 L .51639 .39812 L p .681 .181 1 r
F P
0 g
s
.51926 .39526 m .51639 .39812 L .51314 .40292 L p .995 0 .5 r
F P
0 g
s
.52483 .38468 m .52532 .38384 L .52606 .37769 L p 1 0 .5 r
F P
0 g
s
.5262 .37705 m .52606 .37769 L .52532 .38384 L p 1 0 .5 r
F P
0 g
s
.51926 .39526 m .52132 .39321 L .52321 .38748 L p 1 0 .5 r
F P
0 g
s
.52415 .38585 m .52321 .38748 L .52132 .39321 L p 1 0 .5 r
F P
0 g
s
.52532 .38384 m .52566 .38324 L .5262 .37705 L p 1 0 .5 r
F P
0 g
s
.5263 .3766 m .5262 .37705 L .52566 .38324 L p 1 0 .5 r
F P
0 g
s
.4953 .41367 m .50411 .41 L .50786 .4063 L p .66 .16 1 r
F P
0 g
s
.51314 .40292 m .50786 .4063 L .50411 .41 L p .792 0 .5 r
F P
0 g
s
.52566 .38324 m .52591 .38281 L .5263 .3766 L p 1 0 .5 r
F P
0 g
s
.52637 .37627 m .5263 .3766 L .52591 .38281 L p 1 0 .5 r
F P
0 g
s
.65654 .63188 m .621 .60849 L .64258 .58968 L p .805 .066 .828 r
F P
0 g
s
.64258 .58968 m .68667 .60877 L .65654 .63188 L p .805 .066 .828 r
F P
0 g
s
.24245 .41516 m .32312 .41648 L .32947 .43532 L p .887 .068 .842 r
F P
0 g
s
.38487 .42916 m .32947 .43532 L .32312 .41648 L p .897 .072 .86 r
F P
0 g
s
.52591 .38281 m .52609 .3825 L .52637 .37627 L p 1 0 .5 r
F P
0 g
s
.52642 .37604 m .52637 .37627 L .52609 .3825 L p 1 0 .5 r
F P
0 g
s
.52609 .3825 m .52622 .38228 L .52642 .37604 L p 1 0 .5 r
F P
0 g
s
.52646 .37587 m .52642 .37604 L .52622 .38228 L p 1 0 .5 r
F P
0 g
s
.52132 .39321 m .5228 .39174 L .52415 .38585 L p 1 0 .5 r
F P
0 g
s
.52483 .38468 m .52415 .38585 L .5228 .39174 L p 1 0 .5 r
F P
0 g
s
.52622 .38228 m .52631 .38212 L .52646 .37587 L p 1 0 .5 r
F P
0 g
s
.52648 .37575 m .52646 .37587 L .52631 .38212 L p 1 0 .5 r
F P
0 g
s
.52631 .38212 m .52638 .382 L .52648 .37575 L p 1 0 .5 r
F P
0 g
s
.5265 .37567 m .52648 .37575 L .52638 .382 L p 1 0 .5 r
F P
0 g
s
.52638 .382 m .52643 .38192 L .5265 .37567 L p 1 0 .5 r
F P
0 g
s
.52651 .37561 m .5265 .37567 L .52643 .38192 L p 1 0 .5 r
F P
0 g
s
.52643 .38192 m .52646 .38186 L .52651 .37561 L p 1 0 .5 r
F P
0 g
s
.51314 .40292 m .51692 .40049 L .51926 .39526 L p .995 0 .5 r
F P
0 g
s
.52132 .39321 m .51926 .39526 L .51692 .40049 L p 1 0 .5 r
F P
0 g
s
.42479 .42472 m .45351 .42152 L .45836 .42407 L p .885 .092 .961 r
F P
0 g
s
.47756 .41927 m .45836 .42407 L .45351 .42152 L p .872 .107 1 r
F P
0 g
s
.5228 .39174 m .52386 .39068 L .52483 .38468 L p 1 0 .5 r
F P
0 g
s
.52532 .38384 m .52483 .38468 L .52386 .39068 L p 1 0 .5 r
F P
0 g
s
.47756 .41927 m .49138 .41581 L .4953 .41367 L p .737 .134 1 r
F P
0 g
s
.50411 .41 m .4953 .41367 L .49138 .41581 L p .555 0 .5 r
F P
0 g
s
.52386 .39068 m .52462 .38992 L .52532 .38384 L p 1 0 .5 r
F P
0 g
s
.52566 .38324 m .52532 .38384 L .52462 .38992 L p 1 0 .5 r
F P
0 g
s
.51692 .40049 m .51965 .39874 L .52132 .39321 L p 1 0 .5 r
F P
0 g
s
.5228 .39174 m .52132 .39321 L .51965 .39874 L p 1 0 .5 r
F P
0 g
s
.52462 .38992 m .52517 .38938 L .52566 .38324 L p 1 0 .5 r
F P
0 g
s
.52591 .38281 m .52566 .38324 L .52517 .38938 L p 1 0 .5 r
F P
0 g
s
.50411 .41 m .51045 .40736 L .51314 .40292 L p .792 0 .5 r
F P
0 g
s
.51692 .40049 m .51314 .40292 L .51045 .40736 L p .875 0 .5 r
F P
0 g
s
.52517 .38938 m .52556 .38899 L .52591 .38281 L p 1 0 .5 r
F P
0 g
s
.52609 .3825 m .52591 .38281 L .52556 .38899 L p 1 0 .5 r
F P
0 g
s
.52556 .38899 m .52584 .38871 L .52609 .3825 L p 1 0 .5 r
F P
0 g
s
.52622 .38228 m .52609 .3825 L .52584 .38871 L p 1 0 .5 r
F P
0 g
s
.52584 .38871 m .52604 .38851 L .52622 .38228 L p 1 0 .5 r
F P
0 g
s
.52631 .38212 m .52622 .38228 L .52604 .38851 L p 1 0 .5 r
F P
0 g
s
.52604 .38851 m .52618 .38837 L .52631 .38212 L p 1 0 .5 r
F P
0 g
s
.52638 .382 m .52631 .38212 L .52618 .38837 L p 1 0 .5 r
F P
0 g
s
.52618 .38837 m .52629 .38826 L .52638 .382 L p 1 0 .5 r
F P
0 g
s
.52643 .38192 m .52638 .382 L .52629 .38826 L p 1 0 .5 r
F P
0 g
s
.52629 .38826 m .52636 .38819 L .52643 .38192 L p 1 0 .5 r
F P
0 g
s
.52646 .38186 m .52643 .38192 L .52636 .38819 L p 1 0 .5 r
F P
0 g
s
.51965 .39874 m .5216 .39749 L .5228 .39174 L p 1 0 .5 r
F P
0 g
s
.52386 .39068 m .5228 .39174 L .5216 .39749 L p 1 0 .5 r
F P
0 g
s
.52636 .38819 m .52641 .38814 L .52646 .38186 L p 1 0 .5 r
F P
0 g
s
.5216 .39749 m .523 .39659 L .52386 .39068 L p 1 0 .5 r
F P
0 g
s
.52462 .38992 m .52386 .39068 L .523 .39659 L p 1 0 .5 r
F P
0 g
s
.51045 .40736 m .515 .40547 L .51692 .40049 L p .875 0 .5 r
F P
0 g
s
.51965 .39874 m .51692 .40049 L .515 .40547 L p .905 0 .5 r
F P
0 g
s
.49138 .41581 m .50132 .41332 L .50411 .41 L p .555 0 .5 r
F P
0 g
s
.51045 .40736 m .50411 .41 L .50132 .41332 L p .688 0 .5 r
F P
0 g
s
.523 .39659 m .524 .39595 L .52462 .38992 L p 1 0 .5 r
F P
0 g
s
.52517 .38938 m .52462 .38992 L .524 .39595 L p 1 0 .5 r
F P
0 g
s
.32312 .41648 m .38086 .41743 L .38487 .42916 L p .897 .072 .86 r
F P
0 g
s
.42479 .42472 m .38487 .42916 L .38086 .41743 L p .911 .077 .887 r
F P
0 g
s
.45351 .42152 m .47415 .41923 L .47756 .41927 L p .872 .107 1 r
F P
0 g
s
.49138 .41581 m .47756 .41927 L .47415 .41923 L p .803 .117 1 r
F P
0 g
s
.524 .39595 m .52472 .39549 L .52517 .38938 L p 1 0 .5 r
F P
0 g
s
.52556 .38899 m .52517 .38938 L .52472 .39549 L p 1 0 .5 r
F P
0 g
s
.52472 .39549 m .52524 .39515 L .52556 .38899 L p 1 0 .5 r
F P
0 g
s
.52584 .38871 m .52556 .38899 L .52524 .39515 L p 1 0 .5 r
F P
0 g
s
.515 .40547 m .51827 .4041 L .51965 .39874 L p .905 0 .5 r
F P
0 g
s
.5216 .39749 m .51965 .39874 L .51827 .4041 L p .915 0 .5 r
F P
0 g
s
.52524 .39515 m .52561 .39492 L .52584 .38871 L p 1 0 .5 r
F P
0 g
s
.52604 .38851 m .52584 .38871 L .52561 .39492 L p 1 0 .5 r
F P
0 g
s
.52561 .39492 m .52588 .39475 L .52604 .38851 L p 1 0 .5 r
F P
0 g
s
.52618 .38837 m .52604 .38851 L .52588 .39475 L p 1 0 .5 r
F P
0 g
s
.52588 .39475 m .52607 .39463 L .52618 .38837 L p 1 0 .5 r
F P
0 g
s
.52629 .38826 m .52618 .38837 L .52607 .39463 L p 1 0 .5 r
F P
0 g
s
.52607 .39463 m .5262 .39454 L .52629 .38826 L p 1 0 .5 r
F P
0 g
s
.52636 .38819 m .52629 .38826 L .5262 .39454 L p 1 0 .5 r
F P
0 g
s
.5262 .39454 m .5263 .39448 L .52636 .38819 L p 1 0 .5 r
F P
0 g
s
.52641 .38814 m .52636 .38819 L .5263 .39448 L p 1 0 .5 r
F P
0 g
s
.5263 .39448 m .52637 .39443 L .52641 .38814 L p 1 0 .5 r
F P
0 g
s
.50132 .41332 m .50845 .41154 L .51045 .40736 L p .688 0 .5 r
F P
0 g
s
.515 .40547 m .51045 .40736 L .50845 .41154 L p .754 0 .5 r
F P
0 g
s
.51827 .4041 m .52061 .40313 L .5216 .39749 L p .915 0 .5 r
F P
0 g
s
.523 .39659 m .5216 .39749 L .52061 .40313 L p .918 0 .5 r
F P
0 g
s
.52061 .40313 m .52229 .40243 L .523 .39659 L p .918 0 .5 r
F P
0 g
s
.524 .39595 m .523 .39659 L .52229 .40243 L p .918 0 .5 r
F P
0 g
s
.47415 .41923 m .48897 .41758 L .49138 .41581 L p .803 .117 1 r
F P
0 g
s
.50132 .41332 m .49138 .41581 L .48897 .41758 L p .5 0 .5 r
F P
0 g
s
.52229 .40243 m .5235 .40192 L .524 .39595 L p .918 0 .5 r
F P
0 g
s
.52472 .39549 m .524 .39595 L .5235 .40192 L p .918 0 .5 r
F P
0 g
s
.50845 .41154 m .51357 .41026 L .515 .40547 L p .754 0 .5 r
F P
0 g
s
.51827 .4041 m .515 .40547 L .51357 .41026 L p .783 0 .5 r
F P
0 g
s
.5235 .40192 m .52436 .40156 L .52472 .39549 L p .918 0 .5 r
F P
0 g
s
.52524 .39515 m .52472 .39549 L .52436 .40156 L p .918 0 .5 r
F P
0 g
s
.52436 .40156 m .52498 .40131 L .52524 .39515 L p .918 0 .5 r
F P
0 g
s
.52561 .39492 m .52524 .39515 L .52498 .40131 L p .918 0 .5 r
F P
0 g
s
.38086 .41743 m .4222 .4181 L .42479 .42472 L p .911 .077 .887 r
F P
0 g
s
.45351 .42152 m .42479 .42472 L .4222 .4181 L p .927 .085 .925 r
F P
0 g
s
.52498 .40131 m .52542 .40112 L .52561 .39492 L p .918 0 .5 r
F P
0 g
s
.52588 .39475 m .52561 .39492 L .52542 .40112 L p .917 0 .5 r
F P
0 g
s
.52542 .40112 m .52574 .40099 L .52588 .39475 L p .917 0 .5 r
F P
0 g
s
.52607 .39463 m .52588 .39475 L .52574 .40099 L p .917 0 .5 r
F P
0 g
s
.52574 .40099 m .52597 .40089 L .52607 .39463 L p .917 0 .5 r
F P
0 g
s
.5262 .39454 m .52607 .39463 L .52597 .40089 L p .917 0 .5 r
F P
0 g
s
.52597 .40089 m .52613 .40083 L .5262 .39454 L p .917 0 .5 r
F P
0 g
s
.5263 .39448 m .5262 .39454 L .52613 .40083 L p .917 0 .5 r
F P
0 g
s
.52613 .40083 m .52625 .40078 L .5263 .39448 L p .917 0 .5 r
F P
0 g
s
.52637 .39443 m .5263 .39448 L .52625 .40078 L p .917 0 .5 r
F P
0 g
s
.52625 .40078 m .52633 .40074 L .52637 .39443 L p .917 0 .5 r
F P
0 g
s
.51357 .41026 m .51725 .40934 L .51827 .4041 L p .783 0 .5 r
F P
0 g
s
.52061 .40313 m .51827 .4041 L .51725 .40934 L p .797 0 .5 r
F P
0 g
s
.48897 .41758 m .4996 .4164 L .50132 .41332 L p .5 0 .5 r
F P
0 g
s
.50845 .41154 m .50132 .41332 L .4996 .4164 L p .583 0 .5 r
F P
0 g
s
.7805 .60123 m .71054 .58232 L .72702 .55317 L p .834 .06 .799 r
F P
0 g
s
.72702 .55317 m .80463 .56379 L .7805 .60123 L p .834 .06 .799 r
F P
0 g
s
.51725 .40934 m .51988 .40868 L .52061 .40313 L p .797 0 .5 r
F P
0 g
s
.52229 .40243 m .52061 .40313 L .51988 .40868 L p .804 0 .5 r
F P
0 g
s
.51988 .40868 m .52177 .40821 L .52229 .40243 L p .804 0 .5 r
F P
0 g
s
.5235 .40192 m .52229 .40243 L .52177 .40821 L p .808 0 .5 r
F P
0 g
s
.52177 .40821 m .52312 .40787 L .5235 .40192 L p .808 0 .5 r
F P
0 g
s
.52436 .40156 m .5235 .40192 L .52312 .40787 L p .811 0 .5 r
F P
0 g
s
.4222 .4181 m .4518 .41859 L .45351 .42152 L p .927 .085 .925 r
F P
0 g
s
.47415 .41923 m .45351 .42152 L .4518 .41859 L p .934 .094 .971 r
F P
0 g
s
.4996 .4164 m .50723 .41555 L .50845 .41154 L p .583 0 .5 r
F P
0 g
s
.51357 .41026 m .50845 .41154 L .50723 .41555 L p .649 0 .5 r
F P
0 g
s
.52312 .40787 m .52409 .40763 L .52436 .40156 L p .811 0 .5 r
F P
0 g
s
.52498 .40131 m .52436 .40156 L .52409 .40763 L p .813 0 .5 r
F P
0 g
s
.52409 .40763 m .52479 .40745 L .52498 .40131 L p .813 0 .5 r
F P
0 g
s
.52542 .40112 m .52498 .40131 L .52479 .40745 L p .814 0 .5 r
F P
0 g
s
.52479 .40745 m .52529 .40733 L .52542 .40112 L p .814 0 .5 r
F P
0 g
s
.52574 .40099 m .52542 .40112 L .52529 .40733 L p .814 0 .5 r
F P
0 g
s
.52529 .40733 m .52564 .40724 L .52574 .40099 L p .814 0 .5 r
F P
0 g
s
.52597 .40089 m .52574 .40099 L .52564 .40724 L p .815 0 .5 r
F P
0 g
s
.52564 .40724 m .5259 .40718 L .52597 .40089 L p .815 0 .5 r
F P
0 g
s
.52613 .40083 m .52597 .40089 L .5259 .40718 L p .815 0 .5 r
F P
0 g
s
.5259 .40718 m .52608 .40713 L .52613 .40083 L p .815 0 .5 r
F P
0 g
s
.52625 .40078 m .52613 .40083 L .52608 .40713 L p .815 0 .5 r
F P
0 g
s
.52608 .40713 m .52621 .4071 L .52625 .40078 L p .815 0 .5 r
F P
0 g
s
.52633 .40074 m .52625 .40078 L .52621 .4071 L p .816 0 .5 r
F P
0 g
s
.68667 .60877 m .64258 .58968 L .65945 .56851 L p .812 .062 .811 r
F P
0 g
s
.65945 .56851 m .71054 .58232 L .68667 .60877 L p .812 .062 .811 r
F P
0 g
s
.52621 .4071 m .52631 .40707 L .52633 .40074 L p .816 0 .5 r
F P
0 g
s
.50723 .41555 m .5127 .41494 L .51357 .41026 L p .649 0 .5 r
F P
0 g
s
.51725 .40934 m .51357 .41026 L .5127 .41494 L p .683 0 .5 r
F P
0 g
s
.5127 .41494 m .51663 .4145 L .51725 .40934 L p .683 0 .5 r
F P
0 g
s
.51988 .40868 m .51725 .40934 L .51663 .4145 L p .701 0 .5 r
F P
0 g
s
.4518 .41859 m .47299 .41893 L .47415 .41923 L p .934 .094 .971 r
F P
0 g
s
.48897 .41758 m .47415 .41923 L .47299 .41893 L p .879 .095 .976 r
F P
0 g
s
.93761 .5284 m .97638 .58729 L p .93216 .52521 L .856 .06 .798 r
F P
0 g
s
.97638 .58729 m .91136 .5784 L .93216 .52521 L p .856 .06 .798 r
F P
0 g
s
.51663 .4145 m .51944 .41419 L .51988 .40868 L p .701 0 .5 r
F P
0 g
s
.52177 .40821 m .51988 .40868 L .51944 .41419 L p .712 0 .5 r
F P
0 g
s
.51944 .41419 m .52145 .41397 L .52177 .40821 L p .712 0 .5 r
F P
0 g
s
.52312 .40787 m .52177 .40821 L .52145 .41397 L p .719 0 .5 r
F P
0 g
s
.52145 .41397 m .5229 .41381 L .52312 .40787 L p .719 0 .5 r
F P
0 g
s
.52409 .40763 m .52312 .40787 L .5229 .41381 L p .724 0 .5 r
F P
0 g
s
.47299 .41893 m .48818 .41918 L .48897 .41758 L p .879 .095 .976 r
F P
0 g
s
.4996 .4164 m .48897 .41758 L .48818 .41918 L p .5 0 .5 r
F P
0 g
s
.5229 .41381 m .52393 .41369 L .52409 .40763 L p .724 0 .5 r
F P
0 g
s
.52479 .40745 m .52409 .40763 L .52393 .41369 L p .727 0 .5 r
F P
0 g
s
.52393 .41369 m .52467 .41361 L .52479 .40745 L p .727 0 .5 r
F P
0 g
s
.52529 .40733 m .52479 .40745 L .52467 .41361 L p .729 0 .5 r
F P
0 g
s
.52467 .41361 m .5252 .41355 L .52529 .40733 L p .729 0 .5 r
F P
0 g
s
.52564 .40724 m .52529 .40733 L .5252 .41355 L p .73 0 .5 r
F P
0 g
s
.5252 .41355 m .52558 .41351 L .52564 .40724 L p .73 0 .5 r
F P
0 g
s
.5259 .40718 m .52564 .40724 L .52558 .41351 L p .731 0 .5 r
F P
0 g
s
.52558 .41351 m .52586 .41348 L .5259 .40718 L p .731 0 .5 r
F P
0 g
s
.52608 .40713 m .5259 .40718 L .52586 .41348 L p .732 0 .5 r
F P
0 g
s
.52586 .41348 m .52605 .41345 L .52608 .40713 L p .732 0 .5 r
F P
0 g
s
.52621 .4071 m .52608 .40713 L .52605 .41345 L p .732 0 .5 r
F P
0 g
s
.52605 .41345 m .52619 .41344 L .52621 .4071 L p .732 0 .5 r
F P
0 g
s
.52631 .40707 m .52621 .4071 L .52619 .41344 L p .733 0 .5 r
F P
0 g
s
.52619 .41344 m .52629 .41343 L .52631 .40707 L p .733 0 .5 r
F P
0 g
s
.48818 .41918 m .49906 .41936 L .4996 .4164 L p .5 0 .5 r
F P
0 g
s
.50723 .41555 m .4996 .4164 L .49906 .41936 L p .5 0 .5 r
F P
0 g
s
.59565 .62453 m .57664 .60492 L .59491 .59133 L p .775 .071 .856 r
F P
0 g
s
.59491 .59133 m .621 .60849 L .59565 .62453 L p .775 .071 .856 r
F P
0 g
s
.49906 .41936 m .50685 .41949 L .50723 .41555 L p .5 0 .5 r
F P
0 g
s
.5127 .41494 m .50723 .41555 L .50685 .41949 L p .553 0 .5 r
F P
0 g
s
.50685 .41949 m .51244 .41958 L .5127 .41494 L p .553 0 .5 r
F P
0 g
s
.51663 .4145 m .5127 .41494 L .51244 .41958 L p .593 0 .5 r
F P
0 g
s
.51244 .41958 m .51644 .41964 L .51663 .4145 L p .593 0 .5 r
F P
0 g
s
.51944 .41419 m .51663 .4145 L .51644 .41964 L p .617 0 .5 r
F P
0 g
s
.51644 .41964 m .5193 .41969 L .51944 .41419 L p .617 0 .5 r
F P
0 g
s
.52145 .41397 m .51944 .41419 L .5193 .41969 L p .631 0 .5 r
F P
0 g
s
.5193 .41969 m .52136 .41972 L .52145 .41397 L p .631 0 .5 r
F P
0 g
s
.5229 .41381 m .52145 .41397 L .52136 .41972 L p .642 .002 .509 r
F P
0 g
s
.52136 .41972 m .52283 .41975 L .5229 .41381 L p .642 .002 .509 r
F P
0 g
s
.52393 .41369 m .5229 .41381 L .52283 .41975 L p .651 .004 .519 r
F P
0 g
s
.52283 .41975 m .52388 .41976 L .52393 .41369 L p .651 .004 .519 r
F P
0 g
s
.52467 .41361 m .52393 .41369 L .52388 .41976 L p .656 .005 .525 r
F P
0 g
s
.52388 .41976 m .52464 .41978 L .52467 .41361 L p .656 .005 .525 r
F P
0 g
s
.5252 .41355 m .52467 .41361 L .52464 .41978 L p .66 .006 .53 r
F P
0 g
s
.52464 .41978 m .52518 .41979 L .5252 .41355 L p .66 .006 .53 r
F P
0 g
s
.52558 .41351 m .5252 .41355 L .52518 .41979 L p .663 .007 .533 r
F P
0 g
s
.52518 .41979 m .52557 .41979 L .52558 .41351 L p .663 .007 .533 r
F P
0 g
s
.52586 .41348 m .52558 .41351 L .52557 .41979 L p .665 .007 .535 r
F P
0 g
s
.52557 .41979 m .52584 .4198 L .52586 .41348 L p .665 .007 .535 r
F P
0 g
s
.52605 .41345 m .52586 .41348 L .52584 .4198 L p .666 .007 .537 r
F P
0 g
s
.52584 .4198 m .52604 .4198 L .52605 .41345 L p .666 .007 .537 r
F P
0 g
s
.52619 .41344 m .52605 .41345 L .52604 .4198 L p .667 .008 .538 r
F P
0 g
s
.52604 .4198 m .52619 .4198 L .52619 .41344 L p .667 .008 .538 r
F P
0 g
s
.52629 .41343 m .52619 .41344 L .52619 .4198 L p .668 .008 .539 r
F P
0 g
s
.52619 .4198 m .52629 .4198 L .52629 .41343 L p .668 .008 .539 r
F P
0 g
s
.5262 .42619 m .52629 .4262 L .52629 .4198 L p .612 .022 .608 r
F P
0 g
s
.52629 .4198 m .52619 .4198 L .5262 .42619 L p .612 .022 .608 r
F P
0 g
s
.52606 .42617 m .5262 .42619 L .52619 .4198 L p .611 .022 .608 r
F P
0 g
s
.52619 .4198 m .52604 .4198 L .52606 .42617 L p .611 .022 .608 r
F P
0 g
s
.52586 .42614 m .52606 .42617 L .52604 .4198 L p .61 .021 .607 r
F P
0 g
s
.52604 .4198 m .52584 .4198 L .52586 .42614 L p .61 .021 .607 r
F P
0 g
s
.52559 .4261 m .52586 .42614 L .52584 .4198 L p .609 .021 .606 r
F P
0 g
s
.52584 .4198 m .52557 .41979 L .52559 .4261 L p .609 .021 .606 r
F P
0 g
s
.52521 .42605 m .52559 .4261 L .52557 .41979 L p .607 .021 .604 r
F P
0 g
s
.52557 .41979 m .52518 .41979 L .52521 .42605 L p .607 .021 .604 r
F P
0 g
s
.52469 .42597 m .52521 .42605 L .52518 .41979 L p .603 .02 .601 r
F P
0 g
s
.52518 .41979 m .52464 .41978 L .52469 .42597 L p .603 .02 .601 r
F P
0 g
s
.52395 .42586 m .52469 .42597 L .52464 .41978 L p .599 .02 .598 r
F P
0 g
s
.52464 .41978 m .52388 .41976 L .52395 .42586 L p .599 .02 .598 r
F P
0 g
s
.52292 .42572 m .52395 .42586 L .52388 .41976 L p .592 .019 .593 r
F P
0 g
s
.52388 .41976 m .52283 .41975 L .52292 .42572 L p .592 .019 .593 r
F P
0 g
s
.52149 .42551 m .52292 .42572 L .52283 .41975 L p .583 .017 .585 r
F P
0 g
s
.52283 .41975 m .52136 .41972 L .52149 .42551 L p .583 .017 .585 r
F P
0 g
s
.51948 .42522 m .52149 .42551 L .52136 .41972 L p .568 .015 .574 r
F P
0 g
s
.52136 .41972 m .5193 .41969 L .51948 .42522 L p .568 .015 .574 r
F P
0 g
s
.51669 .42482 m .51948 .42522 L .5193 .41969 L p .547 .011 .557 r
F P
0 g
s
.5193 .41969 m .51644 .41964 L .51669 .42482 L p .547 .011 .557 r
F P
0 g
s
.51278 .42425 m .51669 .42482 L .51644 .41964 L p .512 .006 .529 r
F P
0 g
s
.51644 .41964 m .51244 .41958 L .51278 .42425 L p .512 .006 .529 r
F P
0 g
s
.50733 .42346 m .51278 .42425 L .51244 .41958 L p .5 0 .5 r
F P
0 g
s
.51244 .41958 m .50685 .41949 L .50733 .42346 L p .5 0 .5 r
F P
0 g
s
.49971 .42236 m .50733 .42346 L .50685 .41949 L p .5 0 .5 r
F P
0 g
s
.50685 .41949 m .49906 .41936 L .49971 .42236 L p .5 0 .5 r
F P
0 g
s
.48907 .42082 m .49971 .42236 L .49906 .41936 L p .5 0 .5 r
F P
0 g
s
.49906 .41936 m .48818 .41918 L .48907 .42082 L p .5 0 .5 r
F P
0 g
s
.48818 .41918 m .47299 .41893 L .47418 .41867 L p .964 .072 .862 r
F P
0 g
s
.47418 .41867 m .48907 .42082 L .48818 .41918 L p .964 .072 .862 r
F P
0 g
s
.621 .60849 m .59491 .59133 L .61037 .57574 L p .782 .066 .832 r
F P
0 g
s
.61037 .57574 m .64258 .58968 L .621 .60849 L p .782 .066 .832 r
F P
0 g
s
.45335 .41566 m .47418 .41867 L .47299 .41893 L p .997 .079 .897 r
F P
0 g
s
.47299 .41893 m .4518 .41859 L .45335 .41566 L p .997 .079 .897 r
F P
0 g
s
.91136 .5784 m .80463 .56379 L .81747 .52343 L p .85 .059 .793 r
F P
0 g
s
.81747 .52343 m .93216 .52521 L .91136 .5784 L p .85 .059 .793 r
F P
0 g
s
.42416 .41144 m .45335 .41566 L .4518 .41859 L p .968 .076 .88 r
F P
0 g
s
.4518 .41859 m .4222 .4181 L .42416 .41144 L p .968 .076 .88 r
F P
0 g
s
.38321 .40552 m .42416 .41144 L .4222 .4181 L p .938 .072 .858 r
F P
0 g
s
.4222 .4181 m .38086 .41743 L .38321 .40552 L p .938 .072 .858 r
F P
0 g
s
.12635 .41326 m .12966 .41332 L .13116 .417 L closepath p .889 .064 .822 r
F P
0 g
s
.32562 .3972 m .38321 .40552 L .38086 .41743 L p .915 .068 .842 r
F P
0 g
s
.38086 .41743 m .32312 .41648 L .32562 .3972 L p .915 .068 .842 r
F P
0 g
s
.24439 .38546 m .32562 .3972 L .32312 .41648 L p .9 .066 .83 r
F P
0 g
s
.32312 .41648 m .24245 .41516 L .24439 .38546 L p .9 .066 .83 r
F P
0 g
s
.52622 .4326 m .52631 .43263 L .52629 .4262 L p .556 .036 .678 r
F P
0 g
s
.52629 .4262 m .5262 .42619 L .52622 .4326 L p .556 .036 .678 r
F P
0 g
s
.52609 .43257 m .52622 .4326 L .5262 .42619 L p .555 .036 .678 r
F P
0 g
s
.5262 .42619 m .52606 .42617 L .52609 .43257 L p .555 .036 .678 r
F P
0 g
s
.52591 .43252 m .52609 .43257 L .52606 .42617 L p .553 .035 .677 r
F P
0 g
s
.52606 .42617 m .52586 .42614 L .52591 .43252 L p .553 .035 .677 r
F P
0 g
s
.52566 .43244 m .52591 .43252 L .52586 .42614 L p .552 .035 .676 r
F P
0 g
s
.52586 .42614 m .52559 .4261 L .52566 .43244 L p .552 .035 .676 r
F P
0 g
s
.52531 .43234 m .52566 .43244 L .52559 .4261 L p .549 .035 .675 r
F P
0 g
s
.52559 .4261 m .52521 .42605 L .52531 .43234 L p .549 .035 .675 r
F P
0 g
s
.52482 .4322 m .52531 .43234 L .52521 .42605 L p .545 .035 .673 r
F P
0 g
s
.52521 .42605 m .52469 .42597 L .52482 .4322 L p .545 .035 .673 r
F P
0 g
s
.52413 .43201 m .52482 .4322 L .52469 .42597 L p .54 .034 .67 r
F P
0 g
s
.52469 .42597 m .52395 .42586 L .52413 .43201 L p .54 .034 .67 r
F P
0 g
s
.52318 .43173 m .52413 .43201 L .52395 .42586 L p .533 .033 .666 r
F P
0 g
s
.52395 .42586 m .52292 .42572 L .52318 .43173 L p .533 .033 .666 r
F P
0 g
s
.52184 .43135 m .52318 .43173 L .52292 .42572 L p .532 .032 .66 r
F P
0 g
s
.52292 .42572 m .52149 .42551 L .52184 .43135 L p .532 .032 .66 r
F P
0 g
s
.51998 .43082 m .52184 .43135 L .52149 .42551 L p .53 .03 .652 r
F P
0 g
s
.52149 .42551 m .51948 .42522 L .51998 .43082 L p .53 .03 .652 r
F P
0 g
s
.51738 .43008 m .51998 .43082 L .51948 .42522 L p .528 .028 .638 r
F P
0 g
s
.51948 .42522 m .51669 .42482 L .51738 .43008 L p .528 .028 .638 r
F P
0 g
s
.12934 .36883 m .24439 .38546 L .24245 .41516 L p .889 .064 .822 r
F P
0 g
s
.24245 .41516 m .12966 .41332 L .12934 .36883 L p .889 .064 .822 r
F P
0 g
s
.51374 .42904 m .51738 .43008 L .51669 .42482 L p .523 .023 .616 r
F P
0 g
s
.51669 .42482 m .51278 .42425 L .51374 .42904 L p .523 .023 .616 r
F P
0 g
s
.50866 .42759 m .51374 .42904 L .51278 .42425 L p .516 .016 .578 r
F P
0 g
s
.51278 .42425 m .50733 .42346 L .50866 .42759 L p .516 .016 .578 r
F P
0 g
s
.50156 .42556 m .50866 .42759 L .50733 .42346 L p .502 .002 .508 r
F P
0 g
s
.50733 .42346 m .49971 .42236 L .50156 .42556 L p .502 .002 .508 r
F P
0 g
s
.12301 .41056 m .05729 .35842 L p .12966 .41332 L .882 .063 .817 r
F P
0 g
s
.05729 .35842 m .12934 .36883 L .12966 .41332 L p .882 .063 .817 r
F P
0 g
s
.12966 .41332 m .12635 .41326 L .12301 .41056 L p .882 .063 .817 r
F P
0 g
s
.52626 .43905 m .52634 .43908 L .52631 .43263 L p .551 .051 .753 r
F P
0 g
s
.52631 .43263 m .52622 .4326 L .52626 .43905 L p .551 .051 .753 r
F P
0 g
s
.52615 .439 m .52626 .43905 L .52622 .4326 L p .551 .051 .753 r
F P
0 g
s
.52622 .4326 m .52609 .43257 L .52615 .439 L p .551 .051 .753 r
F P
0 g
s
.52599 .43892 m .52615 .439 L .52609 .43257 L p .55 .05 .752 r
F P
0 g
s
.52609 .43257 m .52591 .43252 L .52599 .43892 L p .55 .05 .752 r
F P
0 g
s
.52576 .43882 m .52599 .43892 L .52591 .43252 L p .55 .05 .752 r
F P
0 g
s
.52591 .43252 m .52566 .43244 L .52576 .43882 L p .55 .05 .752 r
F P
0 g
s
.52546 .43868 m .52576 .43882 L .52566 .43244 L p .55 .05 .751 r
F P
0 g
s
.52566 .43244 m .52531 .43234 L .52546 .43868 L p .55 .05 .751 r
F P
0 g
s
.49162 .42272 m .50156 .42556 L .49971 .42236 L p .5 0 .5 r
F P
0 g
s
.49971 .42236 m .48907 .42082 L .49162 .42272 L p .5 0 .5 r
F P
0 g
s
.52502 .43848 m .52546 .43868 L .52531 .43234 L p .55 .05 .749 r
F P
0 g
s
.52531 .43234 m .52482 .4322 L .52502 .43848 L p .55 .05 .749 r
F P
0 g
s
.71054 .58232 m .65945 .56851 L .67083 .54548 L p .82 .059 .794 r
F P
0 g
s
.67083 .54548 m .72702 .55317 L .71054 .58232 L p .82 .059 .794 r
F P
0 g
s
.52442 .43821 m .52502 .43848 L .52482 .4322 L p .55 .05 .748 r
F P
0 g
s
.52482 .4322 m .52413 .43201 L .52442 .43821 L p .55 .05 .748 r
F P
0 g
s
.52358 .43782 m .52442 .43821 L .52413 .43201 L p .549 .049 .745 r
F P
0 g
s
.52413 .43201 m .52318 .43173 L .52358 .43782 L p .549 .049 .745 r
F P
0 g
s
.5224 .43728 m .52358 .43782 L .52318 .43173 L p .548 .048 .741 r
F P
0 g
s
.52318 .43173 m .52184 .43135 L .5224 .43728 L p .548 .048 .741 r
F P
0 g
s
.52076 .43653 m .5224 .43728 L .52184 .43135 L p .547 .047 .735 r
F P
0 g
s
.52184 .43135 m .51998 .43082 L .52076 .43653 L p .547 .047 .735 r
F P
0 g
s
.48907 .42082 m .47418 .41867 L .47769 .41874 L p 1 .051 .754 r
F P
0 g
s
.47769 .41874 m .49162 .42272 L .48907 .42082 L p 1 .051 .754 r
F P
0 g
s
.51847 .43548 m .52076 .43653 L .51998 .43082 L p .545 .045 .725 r
F P
0 g
s
.51998 .43082 m .51738 .43008 L .51847 .43548 L p .545 .045 .725 r
F P
0 g
s
.51526 .43401 m .51847 .43548 L .51738 .43008 L p .541 .041 .707 r
F P
0 g
s
.51738 .43008 m .51374 .42904 L .51526 .43401 L p .541 .041 .707 r
F P
0 g
s
.64258 .58968 m .61037 .57574 L .62233 .55847 L p .791 .062 .809 r
F P
0 g
s
.62233 .55847 m .65945 .56851 L .64258 .58968 L p .791 .062 .809 r
F P
0 g
s
.52631 .44552 m .52638 .44557 L .52634 .43908 L p .568 .068 .84 r
F P
0 g
s
.52634 .43908 m .52626 .43905 L .52631 .44552 L p .568 .068 .84 r
F P
0 g
s
.51078 .43196 m .51526 .43401 L .51374 .42904 L p .535 .035 .675 r
F P
0 g
s
.51374 .42904 m .50866 .42759 L .51078 .43196 L p .535 .035 .675 r
F P
0 g
s
.52622 .44546 m .52631 .44552 L .52626 .43905 L p .568 .068 .839 r
F P
0 g
s
.52626 .43905 m .52615 .439 L .52622 .44546 L p .568 .068 .839 r
F P
0 g
s
.52609 .44537 m .52622 .44546 L .52615 .439 L p .568 .068 .839 r
F P
0 g
s
.52615 .439 m .52599 .43892 L .52609 .44537 L p .568 .068 .839 r
F P
0 g
s
.52591 .44524 m .52609 .44537 L .52599 .43892 L p .568 .068 .839 r
F P
0 g
s
.52599 .43892 m .52576 .43882 L .52591 .44524 L p .568 .068 .839 r
F P
0 g
s
.52565 .44506 m .52591 .44524 L .52576 .43882 L p .568 .068 .839 r
F P
0 g
s
.52576 .43882 m .52546 .43868 L .52565 .44506 L p .568 .068 .839 r
F P
0 g
s
.45816 .41316 m .47769 .41874 L .47418 .41867 L p 1 .064 .82 r
F P
0 g
s
.47418 .41867 m .45335 .41566 L .45816 .41316 L p 1 .064 .82 r
F P
0 g
s
.5253 .44482 m .52565 .44506 L .52546 .43868 L p .568 .068 .838 r
F P
0 g
s
.52546 .43868 m .52502 .43848 L .5253 .44482 L p .568 .068 .838 r
F P
0 g
s
.5248 .44447 m .5253 .44482 L .52502 .43848 L p .567 .067 .837 r
F P
0 g
s
.52502 .43848 m .52442 .43821 L .5248 .44447 L p .567 .067 .837 r
F P
0 g
s
.52411 .44399 m .5248 .44447 L .52442 .43821 L p .567 .067 .836 r
F P
0 g
s
.52442 .43821 m .52358 .43782 L .52411 .44399 L p .567 .067 .836 r
F P
0 g
s
.52315 .44332 m .52411 .44399 L .52358 .43782 L p .567 .067 .834 r
F P
0 g
s
.52358 .43782 m .5224 .43728 L .52315 .44332 L p .567 .067 .834 r
F P
0 g
s
.50451 .42909 m .51078 .43196 L .50866 .42759 L p .522 .022 .612 r
F P
0 g
s
.50866 .42759 m .50156 .42556 L .50451 .42909 L p .522 .022 .612 r
F P
0 g
s
.5218 .44238 m .52315 .44332 L .5224 .43728 L p .566 .066 .83 r
F P
0 g
s
.5224 .43728 m .52076 .43653 L .5218 .44238 L p .566 .066 .83 r
F P
0 g
s
.51992 .44107 m .5218 .44238 L .52076 .43653 L p .565 .065 .824 r
F P
0 g
s
.52076 .43653 m .51847 .43548 L .51992 .44107 L p .565 .065 .824 r
F P
0 g
s
.43071 .40532 m .45816 .41316 L .45335 .41566 L p 1 .066 .83 r
F P
0 g
s
.45335 .41566 m .42416 .41144 L .43071 .40532 L p 1 .066 .83 r
F P
0 g
s
.49572 .42507 m .50451 .42909 L .50156 .42556 L p .5 0 .5 r
F P
0 g
s
.50156 .42556 m .49162 .42272 L .49572 .42507 L p .5 0 .5 r
F P
0 g
s
.52637 .45203 m .52642 .45208 L .52638 .44557 L p .589 .089 .947 r
F P
0 g
s
.52638 .44557 m .52631 .44552 L .52637 .45203 L p .589 .089 .947 r
F P
0 g
s
.5263 .45195 m .52637 .45203 L .52631 .44552 L p .589 .089 .947 r
F P
0 g
s
.52631 .44552 m .52622 .44546 L .5263 .45195 L p .589 .089 .947 r
F P
0 g
s
.51729 .43924 m .51992 .44107 L .51847 .43548 L p .562 .062 .811 r
F P
0 g
s
.51847 .43548 m .51526 .43401 L .51729 .43924 L p .562 .062 .811 r
F P
0 g
s
.52621 .45185 m .5263 .45195 L .52622 .44546 L p .59 .09 .948 r
F P
0 g
s
.52622 .44546 m .52609 .44537 L .52621 .45185 L p .59 .09 .948 r
F P
0 g
s
.52607 .4517 m .52621 .45185 L .52609 .44537 L p .59 .09 .948 r
F P
0 g
s
.52609 .44537 m .52591 .44524 L .52607 .4517 L p .59 .09 .948 r
F P
0 g
s
.52589 .4515 m .52607 .4517 L .52591 .44524 L p .59 .09 .948 r
F P
0 g
s
.52591 .44524 m .52565 .44506 L .52589 .4515 L p .59 .09 .948 r
F P
0 g
s
.52563 .45121 m .52589 .4515 L .52565 .44506 L p .59 .09 .949 r
F P
0 g
s
.52565 .44506 m .5253 .44482 L .52563 .45121 L p .59 .09 .949 r
F P
0 g
s
.52526 .45082 m .52563 .45121 L .5253 .44482 L p .59 .09 .949 r
F P
0 g
s
.5253 .44482 m .5248 .44447 L .52526 .45082 L p .59 .09 .949 r
F P
0 g
s
.52476 .45026 m .52526 .45082 L .5248 .44447 L p .59 .09 .95 r
F P
0 g
s
.5248 .44447 m .52411 .44399 L .52476 .45026 L p .59 .09 .95 r
F P
0 g
s
.57664 .60492 m .56274 .59059 L .57589 .57881 L p .743 .073 .867 r
F P
0 g
s
.57589 .57881 m .59491 .59133 L .57664 .60492 L p .743 .073 .867 r
F P
0 g
s
.51361 .43668 m .51729 .43924 L .51526 .43401 L p .557 .057 .784 r
F P
0 g
s
.51526 .43401 m .51078 .43196 L .51361 .43668 L p .557 .057 .784 r
F P
0 g
s
.52405 .44949 m .52476 .45026 L .52411 .44399 L p .59 .09 .95 r
F P
0 g
s
.52411 .44399 m .52315 .44332 L .52405 .44949 L p .59 .09 .95 r
F P
0 g
s
.52306 .44841 m .52405 .44949 L .52315 .44332 L p .59 .09 .95 r
F P
0 g
s
.52315 .44332 m .5218 .44238 L .52306 .44841 L p .59 .09 .95 r
F P
0 g
s
.80463 .56379 m .72702 .55317 L .73515 .52216 L p .841 .057 .787 r
F P
0 g
s
.73515 .52216 m .81747 .52343 L .80463 .56379 L p .841 .057 .787 r
F P
0 g
s
.49162 .42272 m .47769 .41874 L .4834 .41943 L p 1 .031 .657 r
F P
0 g
s
.4834 .41943 m .49572 .42507 L .49162 .42272 L p 1 .031 .657 r
F P
0 g
s
.52167 .4469 m .52306 .44841 L .5218 .44238 L p .589 .089 .947 r
F P
0 g
s
.5218 .44238 m .51992 .44107 L .52167 .4469 L p .589 .089 .947 r
F P
0 g
s
.52644 .45857 m .52647 .45863 L .52642 .45208 L p .618 .118 1 r
F P
0 g
s
.52642 .45208 m .52637 .45203 L .52644 .45857 L p .618 .118 1 r
F P
0 g
s
.50845 .4331 m .51361 .43668 L .51078 .43196 L p .544 .044 .719 r
F P
0 g
s
.51078 .43196 m .50451 .42909 L .50845 .4331 L p .544 .044 .719 r
F P
0 g
s
.5264 .45849 m .52644 .45857 L .52637 .45203 L p .618 .118 1 r
F P
0 g
s
.52637 .45203 m .5263 .45195 L .5264 .45849 L p .618 .118 1 r
F P
0 g
s
.52635 .45837 m .5264 .45849 L .5263 .45195 L p .618 .118 1 r
F P
0 g
s
.5263 .45195 m .52621 .45185 L .52635 .45837 L p .618 .118 1 r
F P
0 g
s
.52627 .45821 m .52635 .45837 L .52621 .45185 L p .618 .118 1 r
F P
0 g
s
.52621 .45185 m .52607 .4517 L .52627 .45821 L p .618 .118 1 r
F P
0 g
s
.52615 .45799 m .52627 .45821 L .52607 .4517 L p .618 .118 1 r
F P
0 g
s
.52607 .4517 m .52589 .4515 L .52615 .45799 L p .618 .118 1 r
F P
0 g
s
.39201 .39427 m .43071 .40532 L .42416 .41144 L p .961 .065 .826 r
F P
0 g
s
.42416 .41144 m .38321 .40552 L .39201 .39427 L p .961 .065 .826 r
F P
0 g
s
.526 .45768 m .52615 .45799 L .52589 .4515 L p .619 .119 1 r
F P
0 g
s
.52589 .4515 m .52563 .45121 L .526 .45768 L p .619 .119 1 r
F P
0 g
s
.52578 .45725 m .526 .45768 L .52563 .45121 L p .619 .119 1 r
F P
0 g
s
.52563 .45121 m .52526 .45082 L .52578 .45725 L p .619 .119 1 r
F P
0 g
s
.51973 .44478 m .52167 .4469 L .51992 .44107 L p .588 .088 .938 r
F P
0 g
s
.51992 .44107 m .51729 .43924 L .51973 .44478 L p .588 .088 .938 r
F P
0 g
s
.52548 .45664 m .52578 .45725 L .52526 .45082 L p .62 .12 1 r
F P
0 g
s
.52526 .45082 m .52476 .45026 L .52548 .45664 L p .62 .12 1 r
F P
0 g
s
.59491 .59133 m .57589 .57881 L .58696 .5656 L p .753 .067 .836 r
F P
0 g
s
.58696 .5656 m .61037 .57574 L .59491 .59133 L p .753 .067 .836 r
F P
0 g
s
.52506 .4558 m .52548 .45664 L .52476 .45026 L p .62 .12 1 r
F P
0 g
s
.52476 .45026 m .52405 .44949 L .52506 .4558 L p .62 .12 1 r
F P
0 g
s
.52447 .45462 m .52506 .4558 L .52405 .44949 L p .621 .121 1 r
F P
0 g
s
.52405 .44949 m .52306 .44841 L .52447 .45462 L p .621 .121 1 r
F P
0 g
s
.51702 .44182 m .51973 .44478 L .51729 .43924 L p .581 .081 .907 r
F P
0 g
s
.51729 .43924 m .51361 .43668 L .51702 .44182 L p .581 .081 .907 r
F P
0 g
s
.50123 .42807 m .50845 .4331 L .50451 .42909 L p .517 .017 .586 r
F P
0 g
s
.50451 .42909 m .49572 .42507 L .50123 .42807 L p .517 .017 .586 r
F P
0 g
s
.46608 .4115 m .4834 .41943 L .47769 .41874 L p 1 .049 .746 r
F P
0 g
s
.47769 .41874 m .45816 .41316 L .46608 .4115 L p 1 .049 .746 r
F P
0 g
s
.52652 .46514 m .52653 .4652 L .52647 .45863 L p .654 .154 1 r
F P
0 g
s
.52647 .45863 m .52644 .45857 L .52652 .46514 L p .654 .154 1 r
F P
0 g
s
.52651 .46506 m .52652 .46514 L .52644 .45857 L p .654 .154 1 r
F P
0 g
s
.52644 .45857 m .5264 .45849 L .52651 .46506 L p .654 .154 1 r
F P
0 g
s
.52649 .46494 m .52651 .46506 L .5264 .45849 L p .654 .154 1 r
F P
0 g
s
.5264 .45849 m .52635 .45837 L .52649 .46494 L p .654 .154 1 r
F P
0 g
s
.52364 .45298 m .52447 .45462 L .52306 .44841 L p .62 .12 1 r
F P
0 g
s
.52306 .44841 m .52167 .4469 L .52364 .45298 L p .62 .12 1 r
F P
0 g
s
.52647 .46477 m .52649 .46494 L .52635 .45837 L p .655 .155 1 r
F P
0 g
s
.52635 .45837 m .52627 .45821 L .52647 .46477 L p .655 .155 1 r
F P
0 g
s
.52644 .46454 m .52647 .46477 L .52627 .45821 L p .655 .155 1 r
F P
0 g
s
.52627 .45821 m .52615 .45799 L .52644 .46454 L p .655 .155 1 r
F P
0 g
s
.5264 .46422 m .52644 .46454 L .52615 .45799 L p .655 .155 1 r
F P
0 g
s
.52615 .45799 m .526 .45768 L .5264 .46422 L p .655 .155 1 r
F P
0 g
s
.52634 .46377 m .5264 .46422 L .526 .45768 L p .655 .155 1 r
F P
0 g
s
.526 .45768 m .52578 .45725 L .52634 .46377 L p .655 .155 1 r
F P
0 g
s
.65945 .56851 m .62233 .55847 L .63026 .53993 L p .803 .058 .788 r
F P
0 g
s
.63026 .53993 m .67083 .54548 L .65945 .56851 L p .803 .058 .788 r
F P
0 g
s
.52625 .46315 m .52634 .46377 L .52578 .45725 L p .655 .155 1 r
F P
0 g
s
.52578 .45725 m .52548 .45664 L .52625 .46315 L p .655 .155 1 r
F P
0 g
s
.52249 .45067 m .52364 .45298 L .52167 .4469 L p .616 .116 1 r
F P
0 g
s
.52167 .4469 m .51973 .44478 L .52249 .45067 L p .616 .116 1 r
F P
0 g
s
.51322 .43768 m .51702 .44182 L .51361 .43668 L p .564 .064 .821 r
F P
0 g
s
.51361 .43668 m .50845 .4331 L .51322 .43768 L p .564 .064 .821 r
F P
0 g
s
.52614 .46227 m .52625 .46315 L .52548 .45664 L p .655 .155 1 r
F P
0 g
s
.52548 .45664 m .52506 .4558 L .52614 .46227 L p .655 .155 1 r
F P
0 g
s
.33725 .37863 m .39201 .39427 L .38321 .40552 L p .93 .064 .821 r
F P
0 g
s
.38321 .40552 m .32562 .3972 L .33725 .37863 L p .93 .064 .821 r
F P
0 g
s
.52598 .46105 m .52614 .46227 L .52506 .4558 L p .653 .153 1 r
F P
0 g
s
.52506 .4558 m .52447 .45462 L .52598 .46105 L p .653 .153 1 r
F P
0 g
s
.49108 .421 m .50123 .42807 L .49572 .42507 L p 1 .015 .577 r
F P
0 g
s
.49572 .42507 m .4834 .41943 L .49108 .421 L p 1 .015 .577 r
F P
0 g
s
.52659 .47175 m .52658 .47181 L .52653 .4652 L p .682 .182 1 r
F P
0 g
s
.52653 .4652 m .52652 .46514 L .52659 .47175 L p .682 .182 1 r
F P
0 g
s
.52661 .47166 m .52659 .47175 L .52652 .46514 L p .682 .182 1 r
F P
0 g
s
.52652 .46514 m .52651 .46506 L .52661 .47166 L p .682 .182 1 r
F P
0 g
s
.52664 .47155 m .52661 .47166 L .52651 .46506 L p .681 .181 1 r
F P
0 g
s
.52651 .46506 m .52649 .46494 L .52664 .47155 L p .681 .181 1 r
F P
0 g
s
.52087 .44745 m .52249 .45067 L .51973 .44478 L p .604 .104 1 r
F P
0 g
s
.51973 .44478 m .51702 .44182 L .52087 .44745 L p .604 .104 1 r
F P
0 g
s
.52668 .47138 m .52664 .47155 L .52649 .46494 L p .681 .181 1 r
F P
0 g
s
.52649 .46494 m .52647 .46477 L .52668 .47138 L p .681 .181 1 r
F P
0 g
s
.52673 .47116 m .52668 .47138 L .52647 .46477 L p .68 .18 1 r
F P
0 g
s
.52647 .46477 m .52644 .46454 L .52673 .47116 L p .68 .18 1 r
F P
0 g
s
.52575 .45934 m .52598 .46105 L .52447 .45462 L p .648 .148 1 r
F P
0 g
s
.52447 .45462 m .52364 .45298 L .52575 .45934 L p .648 .148 1 r
F P
0 g
s
.61037 .57574 m .58696 .5656 L .59547 .55121 L p .766 .061 .807 r
F P
0 g
s
.59547 .55121 m .62233 .55847 L .61037 .57574 L p .766 .061 .807 r
F P
0 g
s
.5268 .47084 m .52673 .47116 L .52644 .46454 L p .679 .179 1 r
F P
0 g
s
.52644 .46454 m .5264 .46422 L .5268 .47084 L p .679 .179 1 r
F P
0 g
s
.5269 .47039 m .5268 .47084 L .5264 .46422 L p .676 .176 1 r
F P
0 g
s
.5264 .46422 m .52634 .46377 L .5269 .47039 L p .676 .176 1 r
F P
0 g
s
.52704 .46977 m .5269 .47039 L .52634 .46377 L p .673 .173 1 r
F P
0 g
s
.52634 .46377 m .52625 .46315 L .52704 .46977 L p .673 .173 1 r
F P
0 g
s
.44165 .40033 m .46608 .4115 L .45816 .41316 L p 1 .056 .781 r
F P
0 g
s
.45816 .41316 m .43071 .40532 L .44165 .40033 L p 1 .056 .781 r
F P
0 g
s
.50789 .43186 m .51322 .43768 L .50845 .4331 L p 1 0 .5 r
F P
0 g
s
.50845 .4331 m .50123 .42807 L .50789 .43186 L p 1 0 .5 r
F P
0 g
s
.52724 .4689 m .52704 .46977 L .52625 .46315 L p 1 0 .5 r
F P
0 g
s
.52625 .46315 m .52614 .46227 L .52724 .4689 L p 1 0 .5 r
F P
0 g
s
.52543 .45695 m .52575 .45934 L .52364 .45298 L p .634 .134 1 r
F P
0 g
s
.52364 .45298 m .52249 .45067 L .52543 .45695 L p .634 .134 1 r
F P
0 g
s
.52752 .46769 m .52724 .4689 L .52614 .46227 L p 1 0 .5 r
F P
0 g
s
.52614 .46227 m .52598 .46105 L .52752 .46769 L p 1 0 .5 r
F P
0 g
s
.72702 .55317 m .67083 .54548 L .6761 .52124 L p .83 .056 .778 r
F P
0 g
s
.6761 .52124 m .73515 .52216 L .72702 .55317 L p .83 .056 .778 r
F P
0 g
s
.51861 .44293 m .52087 .44745 L .51702 .44182 L p 1 0 .5 r
F P
0 g
s
.51702 .44182 m .51322 .43768 L .51861 .44293 L p 1 0 .5 r
F P
0 g
s
.52667 .47839 m .52663 .47845 L .52658 .47181 L p 1 0 .5 r
F P
0 g
s
.52658 .47181 m .52659 .47175 L .52667 .47839 L p 1 0 .5 r
F P
0 g
s
.52672 .47831 m .52667 .47839 L .52659 .47175 L p 1 0 .5 r
F P
0 g
s
.52659 .47175 m .52661 .47166 L .52672 .47831 L p 1 0 .5 r
F P
0 g
s
.52679 .4782 m .52672 .47831 L .52661 .47166 L p 1 0 .5 r
F P
0 g
s
.52661 .47166 m .52664 .47155 L .52679 .4782 L p 1 0 .5 r
F P
0 g
s
.52688 .47805 m .52679 .4782 L .52664 .47155 L p 1 0 .5 r
F P
0 g
s
.52664 .47155 m .52668 .47138 L .52688 .47805 L p 1 0 .5 r
F P
0 g
s
.52701 .47783 m .52688 .47805 L .52668 .47138 L p 1 0 .5 r
F P
0 g
s
.52668 .47138 m .52673 .47116 L .52701 .47783 L p 1 0 .5 r
F P
0 g
s
.5279 .46599 m .52752 .46769 L .52598 .46105 L p 1 0 .5 r
F P
0 g
s
.52598 .46105 m .52575 .45934 L .5279 .46599 L p 1 0 .5 r
F P
0 g
s
.5272 .47753 m .52701 .47783 L .52673 .47116 L p 1 0 .5 r
F P
0 g
s
.52673 .47116 m .5268 .47084 L .5272 .47753 L p 1 0 .5 r
F P
0 g
s
.52499 .4536 m .52543 .45695 L .52249 .45067 L p 1 0 .5 r
F P
0 g
s
.52249 .45067 m .52087 .44745 L .52499 .4536 L p 1 0 .5 r
F P
0 g
s
.52746 .4771 m .5272 .47753 L .5268 .47084 L p 1 0 .5 r
F P
0 g
s
.5268 .47084 m .5269 .47039 L .52746 .4771 L p 1 0 .5 r
F P
0 g
s
.52782 .47651 m .52746 .4771 L .5269 .47039 L p 1 0 .5 r
F P
0 g
s
.5269 .47039 m .52704 .46977 L .52782 .47651 L p 1 0 .5 r
F P
0 g
s
.47679 .41106 m .49108 .421 L .4834 .41943 L p 1 .037 .683 r
F P
0 g
s
.4834 .41943 m .46608 .4115 L .47679 .41106 L p 1 .037 .683 r
F P
0 g
s
.52832 .47569 m .52782 .47651 L .52704 .46977 L p 1 0 .5 r
F P
0 g
s
.52704 .46977 m .52724 .4689 L .52832 .47569 L p 1 0 .5 r
F P
0 g
s
.52844 .46362 m .5279 .46599 L .52575 .45934 L p 1 0 .5 r
F P
0 g
s
.52575 .45934 m .52543 .45695 L .52844 .46362 L p 1 0 .5 r
F P
0 g
s
.56274 .59059 m .55264 .58018 L .56209 .56973 L p .705 .076 .88 r
F P
0 g
s
.56209 .56973 m .57589 .57881 L .56274 .59059 L p .705 .076 .88 r
F P
0 g
s
.52902 .47454 m .52832 .47569 L .52724 .4689 L p 1 0 .5 r
F P
0 g
s
.52724 .4689 m .52752 .46769 L .52902 .47454 L p 1 0 .5 r
F P
0 g
s
.5004 .42369 m .50789 .43186 L .50123 .42807 L p 1 .004 .52 r
F P
0 g
s
.50123 .42807 m .49108 .421 L .5004 .42369 L p 1 .004 .52 r
F P
0 g
s
.52674 .48507 m .52668 .48512 L .52663 .47845 L p 1 0 .5 r
F P
0 g
s
.52663 .47845 m .52667 .47839 L .52674 .48507 L p 1 0 .5 r
F P
0 g
s
.52682 .485 m .52674 .48507 L .52667 .47839 L p 1 0 .5 r
F P
0 g
s
.52667 .47839 m .52672 .47831 L .52682 .485 L p 1 0 .5 r
F P
0 g
s
.52692 .4849 m .52682 .485 L .52672 .47831 L p 1 0 .5 r
F P
0 g
s
.52672 .47831 m .52679 .4782 L .52692 .4849 L p 1 0 .5 r
F P
0 g
s
.25929 .35636 m .33725 .37863 L .32562 .3972 L p .91 .063 .816 r
F P
0 g
s
.32562 .3972 m .24439 .38546 L .25929 .35636 L p .91 .063 .816 r
F P
0 g
s
.51543 .43659 m .51861 .44293 L .51322 .43768 L p 1 0 .5 r
F P
0 g
s
.51322 .43768 m .50789 .43186 L .51543 .43659 L p 1 0 .5 r
F P
0 g
s
.52707 .48476 m .52692 .4849 L .52679 .4782 L p 1 0 .5 r
F P
0 g
s
.52679 .4782 m .52688 .47805 L .52707 .48476 L p 1 0 .5 r
F P
0 g
s
.52728 .48456 m .52707 .48476 L .52688 .47805 L p 1 0 .5 r
F P
0 g
s
.52688 .47805 m .52701 .47783 L .52728 .48456 L p 1 0 .5 r
F P
0 g
s
.52437 .44891 m .52499 .4536 L .52087 .44745 L p 1 0 .5 r
F P
0 g
s
.52087 .44745 m .51861 .44293 L .52437 .44891 L p 1 0 .5 r
F P
0 g
s
.52757 .48429 m .52728 .48456 L .52701 .47783 L p 1 0 .5 r
F P
0 g
s
.52701 .47783 m .5272 .47753 L .52757 .48429 L p 1 0 .5 r
F P
0 g
s
.53 .47293 m .52902 .47454 L .52752 .46769 L p 1 0 .5 r
F P
0 g
s
.52752 .46769 m .5279 .46599 L .53 .47293 L p 1 0 .5 r
F P
0 g
s
.52797 .48391 m .52757 .48429 L .5272 .47753 L p 1 0 .5 r
F P
0 g
s
.5272 .47753 m .52746 .4771 L .52797 .48391 L p 1 0 .5 r
F P
0 g
s
.57589 .57881 m .56209 .56973 L .57002 .55827 L p .72 .068 .841 r
F P
0 g
s
.57002 .55827 m .58696 .5656 L .57589 .57881 L p .72 .068 .841 r
F P
0 g
s
.62233 .55847 m .59547 .55121 L .60103 .53593 L p .782 .056 .78 r
F P
0 g
s
.60103 .53593 m .63026 .53993 L .62233 .55847 L p .782 .056 .78 r
F P
0 g
s
.52919 .46029 m .52844 .46362 L .52543 .45695 L p 1 0 .5 r
F P
0 g
s
.52543 .45695 m .52499 .4536 L .52919 .46029 L p 1 0 .5 r
F P
0 g
s
.52853 .48337 m .52797 .48391 L .52746 .4771 L p 1 0 .5 r
F P
0 g
s
.52746 .4771 m .52782 .47651 L .52853 .48337 L p 1 0 .5 r
F P
0 g
s
.52932 .48263 m .52853 .48337 L .52782 .47651 L p 1 0 .5 r
F P
0 g
s
.52782 .47651 m .52832 .47569 L .52932 .48263 L p 1 0 .5 r
F P
0 g
s
.40708 .3845 m .44165 .40033 L .43071 .40532 L p .978 .059 .794 r
F P
0 g
s
.43071 .40532 m .39201 .39427 L .40708 .3845 L p .978 .059 .794 r
F P
0 g
s
.53137 .47068 m .53 .47293 L .5279 .46599 L p 1 0 .5 r
F P
0 g
s
.5279 .46599 m .52844 .46362 L .53137 .47068 L p 1 0 .5 r
F P
0 g
s
.53042 .48159 m .52932 .48263 L .52832 .47569 L p 1 0 .5 r
F P
0 g
s
.52832 .47569 m .52902 .47454 L .53042 .48159 L p 1 0 .5 r
F P
0 g
s
.5268 .49178 m .52673 .49182 L .52668 .48512 L p 1 0 .5 r
F P
0 g
s
.52668 .48512 m .52674 .48507 L .5268 .49178 L p 1 0 .5 r
F P
0 g
s
.5269 .49172 m .5268 .49178 L .52674 .48507 L p 1 0 .5 r
F P
0 g
s
.52674 .48507 m .52682 .485 L .5269 .49172 L p 1 0 .5 r
F P
0 g
s
.52704 .49163 m .5269 .49172 L .52682 .485 L p 1 0 .5 r
F P
0 g
s
.52682 .485 m .52692 .4849 L .52704 .49163 L p 1 0 .5 r
F P
0 g
s
.52724 .49151 m .52704 .49163 L .52692 .4849 L p 1 0 .5 r
F P
0 g
s
.52692 .4849 m .52707 .48476 L .52724 .49151 L p 1 0 .5 r
F P
0 g
s
.52751 .49135 m .52724 .49151 L .52707 .48476 L p 1 0 .5 r
F P
0 g
s
.52707 .48476 m .52728 .48456 L .52751 .49135 L p 1 0 .5 r
F P
0 g
s
.53196 .48014 m .53042 .48159 L .52902 .47454 L p 1 0 .5 r
F P
0 g
s
.52902 .47454 m .53 .47293 L .53196 .48014 L p 1 0 .5 r
F P
0 g
s
.52789 .49112 m .52751 .49135 L .52728 .48456 L p 1 0 .5 r
F P
0 g
s
.52728 .48456 m .52757 .48429 L .52789 .49112 L p 1 0 .5 r
F P
0 g
s
.67083 .54548 m .63026 .53993 L .63374 .52059 L p .816 .054 .768 r
F P
0 g
s
.63374 .52059 m .6761 .52124 L .67083 .54548 L p .816 .054 .768 r
F P
0 g
s
.58696 .5656 m .57002 .55827 L .57608 .54597 L p .737 .061 .804 r
F P
0 g
s
.57608 .54597 m .59547 .55121 L .58696 .5656 L p .737 .061 .804 r
F P
0 g
s
.52842 .49079 m .52789 .49112 L .52757 .48429 L p 1 0 .5 r
F P
0 g
s
.52757 .48429 m .52797 .48391 L .52842 .49079 L p 1 0 .5 r
F P
0 g
s
.53025 .45564 m .52919 .46029 L .52499 .4536 L p 1 0 .5 r
F P
0 g
s
.52499 .4536 m .52437 .44891 L .53025 .45564 L p 1 0 .5 r
F P
0 g
s
.5333 .46752 m .53137 .47068 L .52844 .46362 L p 1 0 .5 r
F P
0 g
s
.52844 .46362 m .52919 .46029 L .5333 .46752 L p 1 0 .5 r
F P
0 g
s
.52917 .49034 m .52842 .49079 L .52797 .48391 L p 1 0 .5 r
F P
0 g
s
.52797 .48391 m .52853 .48337 L .52917 .49034 L p 1 0 .5 r
F P
0 g
s
.5235 .44232 m .52437 .44891 L .51861 .44293 L p 1 0 .5 r
F P
0 g
s
.51861 .44293 m .51543 .43659 L .5235 .44232 L p 1 0 .5 r
F P
0 g
s
.53021 .48971 m .52917 .49034 L .52853 .48337 L p 1 0 .5 r
F P
0 g
s
.52853 .48337 m .52932 .48263 L .53021 .48971 L p 1 0 .5 r
F P
0 g
s
.53411 .47811 m .53196 .48014 L .53 .47293 L p 1 0 .5 r
F P
0 g
s
.53 .47293 m .53137 .47068 L .53411 .47811 L p 1 0 .5 r
F P
0 g
s
.51096 .42766 m .51543 .43659 L .50789 .43186 L p 1 0 .5 r
F P
0 g
s
.50789 .43186 m .5004 .42369 L .51096 .42766 L p 1 0 .5 r
F P
0 g
s
.45658 .397 m .47679 .41106 L .46608 .4115 L p 1 .047 .737 r
F P
0 g
s
.46608 .4115 m .44165 .40033 L .45658 .397 L p 1 .047 .737 r
F P
0 g
s
.53165 .48883 m .53021 .48971 L .52932 .48263 L p 1 0 .5 r
F P
0 g
s
.52932 .48263 m .53042 .48159 L .53165 .48883 L p 1 0 .5 r
F P
0 g
s
.48983 .41216 m .5004 .42369 L .49108 .421 L p 1 .027 .635 r
F P
0 g
s
.49108 .421 m .47679 .41106 L .48983 .41216 L p 1 .027 .635 r
F P
0 g
s
.52685 .49852 m .52676 .49856 L .52673 .49182 L p .916 0 .5 r
F P
0 g
s
.52673 .49182 m .5268 .49178 L .52685 .49852 L p .916 0 .5 r
F P
0 g
s
.52697 .49847 m .52685 .49852 L .5268 .49178 L p .916 0 .5 r
F P
0 g
s
.5268 .49178 m .5269 .49172 L .52697 .49847 L p .916 0 .5 r
F P
0 g
s
.53368 .48759 m .53165 .48883 L .53042 .48159 L p 1 0 .5 r
F P
0 g
s
.53042 .48159 m .53196 .48014 L .53368 .48759 L p 1 0 .5 r
F P
0 g
s
.52714 .49841 m .52697 .49847 L .5269 .49172 L p .916 0 .5 r
F P
0 g
s
.5269 .49172 m .52704 .49163 L .52714 .49841 L p .916 0 .5 r
F P
0 g
s
.52737 .49832 m .52714 .49841 L .52704 .49163 L p .916 0 .5 r
F P
0 g
s
.52704 .49163 m .52724 .49151 L .52737 .49832 L p .916 0 .5 r
F P
0 g
s
.5277 .49819 m .52737 .49832 L .52724 .49151 L p .916 0 .5 r
F P
0 g
s
.52724 .49151 m .52751 .49135 L .5277 .49819 L p .916 0 .5 r
F P
0 g
s
.52816 .49801 m .5277 .49819 L .52751 .49135 L p .916 0 .5 r
F P
0 g
s
.52751 .49135 m .52789 .49112 L .52816 .49801 L p .916 0 .5 r
F P
0 g
s
.5288 .49775 m .52816 .49801 L .52789 .49112 L p .915 0 .5 r
F P
0 g
s
.52789 .49112 m .52842 .49079 L .5288 .49775 L p .915 0 .5 r
F P
0 g
s
.53711 .47526 m .53411 .47811 L .53137 .47068 L p 1 0 .5 r
F P
0 g
s
.53137 .47068 m .5333 .46752 L .53711 .47526 L p 1 0 .5 r
F P
0 g
s
.53599 .46311 m .5333 .46752 L .52919 .46029 L p 1 0 .5 r
F P
0 g
s
.52919 .46029 m .53025 .45564 L .53599 .46311 L p 1 0 .5 r
F P
0 g
s
.52969 .4974 m .5288 .49775 L .52842 .49079 L p .915 0 .5 r
F P
0 g
s
.52842 .49079 m .52917 .49034 L .52969 .4974 L p .915 0 .5 r
F P
0 g
s
.53093 .49691 m .52969 .4974 L .52917 .49034 L p .914 0 .5 r
F P
0 g
s
.52917 .49034 m .53021 .48971 L .53093 .49691 L p .914 0 .5 r
F P
0 g
s
.53651 .48587 m .53368 .48759 L .53196 .48014 L p 1 0 .5 r
F P
0 g
s
.53196 .48014 m .53411 .47811 L .53651 .48587 L p 1 0 .5 r
F P
0 g
s
.59547 .55121 m .57608 .54597 L .58 .53305 L p .757 .054 .77 r
F P
0 g
s
.58 .53305 m .60103 .53593 L .59547 .55121 L p .757 .054 .77 r
F P
0 g
s
.53267 .49622 m .53093 .49691 L .53021 .48971 L p .912 0 .5 r
F P
0 g
s
.53021 .48971 m .53165 .48883 L .53267 .49622 L p .912 0 .5 r
F P
0 g
s
.53173 .4491 m .53025 .45564 L .52437 .44891 L p 1 0 .5 r
F P
0 g
s
.52437 .44891 m .5235 .44232 L .53173 .4491 L p 1 0 .5 r
F P
0 g
s
.63026 .53993 m .60103 .53593 L .60338 .52012 L p .799 .051 .755 r
F P
0 g
s
.60338 .52012 m .63374 .52059 L .63026 .53993 L p .799 .051 .755 r
F P
0 g
s
.5351 .49526 m .53267 .49622 L .53165 .48883 L p .91 0 .5 r
F P
0 g
s
.53165 .48883 m .53368 .48759 L .5351 .49526 L p .91 0 .5 r
F P
0 g
s
.55264 .58018 m .54533 .57263 L .55211 .56317 L p .66 .079 .893 r
F P
0 g
s
.55211 .56317 m .56209 .56973 L .55264 .58018 L p .66 .079 .893 r
F P
0 g
s
.52689 .5053 m .52679 .50532 L .52676 .49856 L p .816 0 .5 r
F P
0 g
s
.52676 .49856 m .52685 .49852 L .52689 .5053 L p .816 0 .5 r
F P
0 g
s
.52702 .50526 m .52689 .5053 L .52685 .49852 L p .817 0 .5 r
F P
0 g
s
.52685 .49852 m .52697 .49847 L .52702 .50526 L p .817 0 .5 r
F P
0 g
s
.54047 .48346 m .53651 .48587 L .53411 .47811 L p .99 0 .5 r
F P
0 g
s
.53411 .47811 m .53711 .47526 L .54047 .48346 L p .99 0 .5 r
F P
0 g
s
.52721 .50522 m .52702 .50526 L .52697 .49847 L p .817 0 .5 r
F P
0 g
s
.52697 .49847 m .52714 .49841 L .52721 .50522 L p .817 0 .5 r
F P
0 g
s
.52748 .50516 m .52721 .50522 L .52714 .49841 L p .817 0 .5 r
F P
0 g
s
.52714 .49841 m .52737 .49832 L .52748 .50516 L p .817 0 .5 r
F P
0 g
s
.56209 .56973 m .55211 .56317 L .55779 .55297 L p .682 .069 .844 r
F P
0 g
s
.55779 .55297 m .57002 .55827 L .56209 .56973 L p .682 .069 .844 r
F P
0 g
s
.52784 .50507 m .52748 .50516 L .52737 .49832 L p .818 0 .5 r
F P
0 g
s
.52737 .49832 m .5277 .49819 L .52784 .50507 L p .818 0 .5 r
F P
0 g
s
.52836 .50495 m .52784 .50507 L .5277 .49819 L p .818 0 .5 r
F P
0 g
s
.5277 .49819 m .52816 .49801 L .52836 .50495 L p .818 0 .5 r
F P
0 g
s
.54132 .47128 m .53711 .47526 L .5333 .46752 L p 1 0 .5 r
F P
0 g
s
.5333 .46752 m .53599 .46311 L .54132 .47128 L p 1 0 .5 r
F P
0 g
s
.52907 .50478 m .52836 .50495 L .52816 .49801 L p .819 0 .5 r
F P
0 g
s
.52816 .49801 m .5288 .49775 L .52907 .50478 L p .819 0 .5 r
F P
0 g
s
.53849 .49392 m .5351 .49526 L .53368 .48759 L p .906 0 .5 r
F P
0 g
s
.53368 .48759 m .53651 .48587 L .53849 .49392 L p .906 0 .5 r
F P
0 g
s
.52227 .43304 m .5235 .44232 L .51543 .43659 L p 1 0 .5 r
F P
0 g
s
.51543 .43659 m .51096 .42766 L .52227 .43304 L p 1 0 .5 r
F P
0 g
s
.53007 .50454 m .52907 .50478 L .5288 .49775 L p .82 0 .5 r
F P
0 g
s
.5288 .49775 m .52969 .4974 L .53007 .50454 L p .82 0 .5 r
F P
0 g
s
.1474 .3244 m .25929 .35636 L .24439 .38546 L p .896 .063 .813 r
F P
0 g
s
.24439 .38546 m .12934 .36883 L .1474 .3244 L p .896 .063 .813 r
F P
0 g
s
.53147 .50421 m .53007 .50454 L .52969 .4974 L p .822 0 .5 r
F P
0 g
s
.52969 .4974 m .53093 .49691 L .53147 .50421 L p .822 0 .5 r
F P
0 g
s
.93216 .52521 m .93552 .52526 L .93761 .5284 L p .856 .06 .798 r
F P
0 g
s
.57002 .55827 m .55779 .55297 L .56211 .54219 L p .705 .06 .8 r
F P
0 g
s
.56211 .54219 m .57608 .54597 L .57002 .55827 L p .705 .06 .8 r
F P
0 g
s
.53342 .50375 m .53147 .50421 L .53093 .49691 L p .823 0 .5 r
F P
0 g
s
.53093 .49691 m .53267 .49622 L .53342 .50375 L p .823 0 .5 r
F P
0 g
s
.53977 .45691 m .53599 .46311 L .53025 .45564 L p 1 0 .5 r
F P
0 g
s
.53025 .45564 m .53173 .4491 L .53977 .45691 L p 1 0 .5 r
F P
0 g
s
.35785 .36197 m .40708 .3845 L .39201 .39427 L p .942 .06 .799 r
F P
0 g
s
.39201 .39427 m .33725 .37863 L .35785 .36197 L p .942 .06 .799 r
F P
0 g
s
.53614 .5031 m .53342 .50375 L .53267 .49622 L p .825 0 .5 r
F P
0 g
s
.53267 .49622 m .5351 .49526 L .53614 .5031 L p .825 0 .5 r
F P
0 g
s
.54323 .49205 m .53849 .49392 L .53651 .48587 L p .901 0 .5 r
F P
0 g
s
.53651 .48587 m .54047 .48346 L .54323 .49205 L p .901 0 .5 r
F P
0 g
s
.54602 .48009 m .54047 .48346 L .53711 .47526 L p .97 0 .5 r
F P
0 g
s
.53711 .47526 m .54132 .47128 L .54602 .48009 L p .97 0 .5 r
F P
0 g
s
.53994 .5022 m .53614 .5031 L .5351 .49526 L p .827 0 .5 r
F P
0 g
s
.5351 .49526 m .53849 .49392 L .53994 .5022 L p .827 0 .5 r
F P
0 g
s
.50464 .41506 m .51096 .42766 L .5004 .42369 L p 1 .021 .603 r
F P
0 g
s
.5004 .42369 m .48983 .41216 L .50464 .41506 L p 1 .021 .603 r
F P
0 g
s
.52691 .5121 m .52681 .51211 L .52679 .50532 L p .735 0 .5 r
F P
0 g
s
.52679 .50532 m .52689 .5053 L .52691 .5121 L p .735 0 .5 r
F P
0 g
s
.52706 .51209 m .52691 .5121 L .52689 .5053 L p .735 0 .5 r
F P
0 g
s
.52689 .5053 m .52702 .50526 L .52706 .51209 L p .735 0 .5 r
F P
0 g
s
.60103 .53593 m .58 .53305 L .58161 .51978 L p .779 .048 .739 r
F P
0 g
s
.58161 .51978 m .60338 .52012 L .60103 .53593 L p .779 .048 .739 r
F P
0 g
s
.52726 .51206 m .52706 .51209 L .52702 .50526 L p .735 0 .5 r
F P
0 g
s
.52702 .50526 m .52721 .50522 L .52726 .51206 L p .735 0 .5 r
F P
0 g
s
.52754 .51203 m .52726 .51206 L .52721 .50522 L p .736 0 .5 r
F P
0 g
s
.52721 .50522 m .52748 .50516 L .52754 .51203 L p .736 0 .5 r
F P
0 g
s
.52793 .51199 m .52754 .51203 L .52748 .50516 L p .737 0 .5 r
F P
0 g
s
.52748 .50516 m .52784 .50507 L .52793 .51199 L p .737 0 .5 r
F P
0 g
s
.57608 .54597 m .56211 .54219 L .56489 .53099 L p .73 .052 .759 r
F P
0 g
s
.56489 .53099 m .58 .53305 L .57608 .54597 L p .73 .052 .759 r
F P
0 g
s
.52848 .51194 m .52793 .51199 L .52784 .50507 L p .738 0 .5 r
F P
0 g
s
.52784 .50507 m .52836 .50495 L .52848 .51194 L p .738 0 .5 r
F P
0 g
s
.52924 .51185 m .52848 .51194 L .52836 .50495 L p .74 0 .5 r
F P
0 g
s
.52836 .50495 m .52907 .50478 L .52924 .51185 L p .74 0 .5 r
F P
0 g
s
.93552 .52526 m .93216 .52521 L .93246 .52055 L closepath p .85 .059 .793 r
F P
0 g
s
.53031 .51174 m .52924 .51185 L .52907 .50478 L p .742 0 .5 r
F P
0 g
s
.52907 .50478 m .53007 .50454 L .53031 .51174 L p .742 0 .5 r
F P
0 g
s
.93216 .52521 m .81747 .52343 L .81786 .48144 L p .856 .057 .785 r
F P
0 g
s
.93246 .52055 m .93216 .52521 L p .81786 .48144 L .856 .057 .785 r
F P
0 g
s
.53179 .51159 m .53031 .51174 L .53007 .50454 L p .745 0 .5 r
F P
0 g
s
.53007 .50454 m .53147 .50421 L .53179 .51159 L p .745 0 .5 r
F P
0 g
s
.53387 .51137 m .53179 .51159 L .53147 .50421 L p .751 .002 .511 r
F P
0 g
s
.53147 .50421 m .53342 .50375 L .53387 .51137 L p .751 .002 .511 r
F P
0 g
s
.54526 .50094 m .53994 .5022 L .53849 .49392 L p .831 .003 .514 r
F P
0 g
s
.53849 .49392 m .54323 .49205 L .54526 .50094 L p .831 .003 .514 r
F P
0 g
s
.54723 .4657 m .54132 .47128 L .53599 .46311 L p 1 0 .5 r
F P
0 g
s
.53599 .46311 m .53977 .45691 L .54723 .4657 L p 1 0 .5 r
F P
0 g
s
.54986 .48943 m .54323 .49205 L .54047 .48346 L p .894 0 .5 r
F P
0 g
s
.54047 .48346 m .54602 .48009 L .54986 .48943 L p .894 0 .5 r
F P
0 g
s
.53677 .51106 m .53387 .51137 L .53342 .50375 L p .759 .005 .526 r
F P
0 g
s
.53342 .50375 m .53614 .5031 L .53677 .51106 L p .759 .005 .526 r
F P
0 g
s
.53382 .43989 m .53173 .4491 L .5235 .44232 L p 1 0 .5 r
F P
0 g
s
.5235 .44232 m .52227 .43304 L .53382 .43989 L p 1 0 .5 r
F P
0 g
s
.54082 .51063 m .53677 .51106 L .53614 .5031 L p .769 .009 .545 r
F P
0 g
s
.53614 .5031 m .53994 .5022 L .54082 .51063 L p .769 .009 .545 r
F P
0 g
s
.47486 .39582 m .48983 .41216 L .47679 .41106 L p 1 .04 .7 r
F P
0 g
s
.47679 .41106 m .45658 .397 L .47486 .39582 L p 1 .04 .7 r
F P
0 g
s
.81747 .52343 m .73515 .52216 L .73427 .49025 L p .85 .055 .776 r
F P
0 g
s
.73427 .49025 m .81786 .48144 L .81747 .52343 L p .85 .055 .776 r
F P
0 g
s
.42787 .37702 m .45658 .397 L .44165 .40033 L p .988 .053 .764 r
F P
0 g
s
.44165 .40033 m .40708 .3845 L .42787 .37702 L p .988 .053 .764 r
F P
0 g
s
.58 .53305 m .56489 .53099 L .56601 .51954 L p .757 .044 .722 r
F P
0 g
s
.56601 .51954 m .58161 .51978 L .58 .53305 L p .757 .044 .722 r
F P
0 g
s
.55269 .49918 m .54526 .50094 L .54323 .49205 L p .839 .01 .548 r
F P
0 g
s
.54323 .49205 m .54986 .48943 L .55269 .49918 L p .839 .01 .548 r
F P
0 g
s
.54647 .51004 m .54082 .51063 L .53994 .5022 L p .78 .014 .568 r
F P
0 g
s
.53994 .5022 m .54526 .50094 L .54647 .51004 L p .78 .014 .568 r
F P
0 g
s
.55379 .47536 m .54602 .48009 L .54132 .47128 L p .95 .001 .504 r
F P
0 g
s
.54132 .47128 m .54723 .4657 L .55379 .47536 L p .95 .001 .504 r
F P
0 g
s
.52692 .51893 m .52681 .51893 L .52681 .51211 L p .671 .009 .543 r
F P
0 g
s
.52681 .51211 m .52691 .5121 L .52692 .51893 L p .671 .009 .543 r
F P
0 g
s
.52706 .51893 m .52692 .51893 L .52691 .5121 L p .671 .009 .544 r
F P
0 g
s
.52691 .5121 m .52706 .51209 L .52706 .51893 L p .671 .009 .544 r
F P
0 g
s
.52727 .51894 m .52706 .51893 L .52706 .51209 L p .672 .009 .545 r
F P
0 g
s
.52706 .51209 m .52726 .51206 L .52727 .51894 L p .672 .009 .545 r
F P
0 g
s
.52756 .51894 m .52727 .51894 L .52726 .51206 L p .674 .009 .546 r
F P
0 g
s
.52726 .51206 m .52754 .51203 L .52756 .51894 L p .674 .009 .546 r
F P
0 g
s
.54898 .54916 m .55779 .55297 L .55211 .56317 L p .642 .069 .847 r
F P
0 g
s
.55779 .55297 m .54898 .54916 L .55207 .53948 L p .672 .059 .794 r
F P
0 g
s
.55207 .53948 m .56211 .54219 L .55779 .55297 L p .672 .059 .794 r
F P
0 g
s
.52795 .51895 m .52756 .51894 L .52754 .51203 L p .675 .01 .548 r
F P
0 g
s
.52754 .51203 m .52793 .51199 L .52795 .51895 L p .675 .01 .548 r
F P
0 g
s
.54492 .55843 m .55211 .56317 L .54533 .57263 L p .612 .081 .906 r
F P
0 g
s
.55211 .56317 m .54492 .55843 L .54898 .54916 L p .642 .069 .847 r
F P
0 g
s
.52851 .51896 m .52795 .51895 L .52793 .51199 L p .678 .01 .551 r
F P
0 g
s
.52793 .51199 m .52848 .51194 L .52851 .51896 L p .678 .01 .551 r
F P
0 g
s
.52929 .51897 m .52851 .51896 L .52848 .51194 L p .681 .011 .555 r
F P
0 g
s
.52848 .51194 m .52924 .51185 L .52929 .51897 L p .681 .011 .555 r
F P
0 g
s
.73515 .52216 m .6761 .52124 L .67487 .49651 L p .842 .053 .764 r
F P
0 g
s
.67487 .49651 m .73427 .49025 L .73515 .52216 L p .842 .053 .764 r
F P
0 g
s
.53037 .51899 m .52929 .51897 L .52924 .51185 L p .685 .012 .56 r
F P
0 g
s
.52924 .51185 m .53031 .51174 L .53037 .51899 L p .685 .012 .56 r
F P
0 g
s
.53189 .51901 m .53037 .51899 L .53031 .51174 L p .691 .013 .567 r
F P
0 g
s
.53031 .51174 m .53179 .51159 L .53189 .51901 L p .691 .013 .567 r
F P
0 g
s
.534 .51904 m .53189 .51901 L .53179 .51159 L p .698 .015 .576 r
F P
0 g
s
.53179 .51159 m .53387 .51137 L .534 .51904 L p .698 .015 .576 r
F P
0 g
s
.56211 .54219 m .55207 .53948 L .55405 .5295 L p .703 .05 .748 r
F P
0 g
s
.55405 .5295 m .56489 .53099 L .56211 .54219 L p .703 .05 .748 r
F P
0 g
s
.53695 .51909 m .534 .51904 L .53387 .51137 L p .708 .017 .587 r
F P
0 g
s
.53387 .51137 m .53677 .51106 L .53695 .51909 L p .708 .017 .587 r
F P
0 g
s
.54533 .57263 m .54005 .56719 L .54492 .55843 L p .612 .081 .906 r
F P
0 g
s
.81786 .48144 m .90166 .4726 L .93246 .52055 L p .856 .057 .785 r
F P
0 g
s
.55436 .50921 m .54647 .51004 L .54526 .50094 L p .793 .019 .595 r
F P
0 g
s
.54526 .50094 m .55269 .49918 L .55436 .50921 L p .793 .019 .595 r
F P
0 g
s
.54107 .51915 m .53695 .51909 L .53677 .51106 L p .72 .02 .602 r
F P
0 g
s
.53677 .51106 m .54082 .51063 L .54107 .51915 L p .72 .02 .602 r
F P
0 g
s
.6761 .52124 m .63374 .52059 L .63256 .50097 L p .832 .05 .749 r
F P
0 g
s
.63256 .50097 m .67487 .49651 L .6761 .52124 L p .832 .05 .749 r
F P
0 g
s
.55915 .48576 m .54986 .48943 L .54602 .48009 L p .894 .009 .545 r
F P
0 g
s
.54602 .48009 m .55379 .47536 L .55915 .48576 L p .894 .009 .545 r
F P
0 g
s
.54681 .51924 m .54107 .51915 L .54082 .51063 L p .734 .024 .62 r
F P
0 g
s
.54082 .51063 m .54647 .51004 L .54681 .51924 L p .734 .024 .62 r
F P
0 g
s
.54509 .44819 m .53977 .45691 L .53173 .4491 L p 1 .002 .511 r
F P
0 g
s
.53173 .4491 m .53382 .43989 L .54509 .44819 L p 1 .002 .511 r
F P
0 g
s
.56489 .53099 m .55405 .5295 L .55482 .51936 L p .735 .041 .704 r
F P
0 g
s
.55482 .51936 m .56601 .51954 L .56489 .53099 L p .735 .041 .704 r
F P
0 g
s
.63374 .52059 m .60338 .52012 L .60237 .50415 L p .819 .046 .731 r
F P
0 g
s
.60237 .50415 m .63256 .50097 L .63374 .52059 L p .819 .046 .731 r
F P
0 g
s
.55482 .51936 m .54681 .51924 L .54647 .51004 L p .751 .028 .641 r
F P
0 g
s
.54647 .51004 m .55436 .50921 L .55482 .51936 L p .751 .028 .641 r
F P
0 g
s
.56308 .49672 m .55269 .49918 L .54986 .48943 L p .847 .017 .585 r
F P
0 g
s
.54986 .48943 m .55915 .48576 L .56308 .49672 L p .847 .017 .585 r
F P
0 g
s
.60338 .52012 m .58161 .51978 L .58081 .50642 L p .804 .042 .71 r
F P
0 g
s
.58081 .50642 m .60237 .50415 L .60338 .52012 L p .804 .042 .71 r
F P
0 g
s
.52053 .41995 m .52227 .43304 L .51096 .42766 L p 1 .017 .587 r
F P
0 g
s
.51096 .42766 m .50464 .41506 L .52053 .41995 L p 1 .017 .587 r
F P
0 g
s
.58161 .51978 m .56601 .51954 L .56539 .50804 L p .787 .037 .687 r
F P
0 g
s
.56539 .50804 m .58081 .50642 L .58161 .51978 L p .787 .037 .687 r
F P
0 g
s
.56539 .50804 m .55436 .50921 L .55269 .49918 L p .806 .025 .624 r
F P
0 g
s
.55269 .49918 m .56308 .49672 L .56539 .50804 L p .806 .025 .624 r
F P
0 g
s
.56601 .51954 m .55482 .51936 L .55436 .50921 L p .769 .033 .664 r
F P
0 g
s
.55436 .50921 m .56539 .50804 L .56601 .51954 L p .769 .033 .664 r
F P
0 g
s
.54681 .51924 m .55482 .51936 L .55405 .5295 L p .712 .037 .687 r
F P
0 g
s
.54626 .52844 m .55405 .5295 L .55207 .53948 L p .676 .047 .736 r
F P
0 g
s
.55405 .5295 m .54626 .52844 L .54681 .51924 L p .712 .037 .687 r
F P
0 g
s
.54107 .51915 m .54681 .51924 L .54626 .52844 L p .692 .034 .671 r
F P
0 g
s
.54626 .52844 m .54068 .52767 L .54107 .51915 L p .692 .034 .671 r
F P
0 g
s
.53695 .51909 m .54107 .51915 L .54068 .52767 L p .675 .032 .658 r
F P
0 g
s
.54068 .52767 m .53668 .52713 L .53695 .51909 L p .675 .032 .658 r
F P
0 g
s
.534 .51904 m .53695 .51909 L .53668 .52713 L p .66 .029 .646 r
F P
0 g
s
.53668 .52713 m .53381 .52673 L .534 .51904 L p .66 .029 .646 r
F P
0 g
s
.53189 .51901 m .534 .51904 L .53381 .52673 L p .649 .027 .637 r
F P
0 g
s
.53381 .52673 m .53175 .52645 L .53189 .51901 L p .649 .027 .637 r
F P
0 g
s
.53037 .51899 m .53189 .51901 L .53175 .52645 L p .64 .026 .63 r
F P
0 g
s
.53175 .52645 m .53028 .52625 L .53037 .51899 L p .64 .026 .63 r
F P
0 g
s
.52929 .51897 m .53037 .51899 L .53028 .52625 L p .633 .025 .625 r
F P
0 g
s
.54486 .53753 m .55207 .53948 L .54898 .54916 L p .64 .058 .788 r
F P
0 g
s
.55207 .53948 m .54486 .53753 L .54626 .52844 L p .676 .047 .736 r
F P
0 g
s
.53028 .52625 m .52922 .52611 L .52929 .51897 L p .633 .025 .625 r
F P
0 g
s
.52851 .51896 m .52929 .51897 L .52922 .52611 L p .628 .024 .621 r
F P
0 g
s
.52922 .52611 m .52846 .526 L .52851 .51896 L p .628 .024 .621 r
F P
0 g
s
.52795 .51895 m .52851 .51896 L .52846 .526 L p .624 .024 .618 r
F P
0 g
s
.52846 .526 m .52792 .52593 L .52795 .51895 L p .624 .024 .618 r
F P
0 g
s
.52756 .51894 m .52795 .51895 L .52792 .52593 L p .621 .023 .616 r
F P
0 g
s
.52792 .52593 m .52753 .52587 L .52756 .51894 L p .621 .023 .616 r
F P
0 g
s
.52727 .51894 m .52756 .51894 L .52753 .52587 L p .619 .023 .614 r
F P
0 g
s
.52753 .52587 m .52725 .52584 L .52727 .51894 L p .619 .023 .614 r
F P
0 g
s
.52706 .51893 m .52727 .51894 L .52725 .52584 L p .618 .023 .613 r
F P
0 g
s
.52725 .52584 m .52705 .52581 L .52706 .51893 L p .618 .023 .613 r
F P
0 g
s
.52692 .51893 m .52706 .51893 L .52705 .52581 L p .617 .022 .612 r
F P
0 g
s
.52705 .52581 m .52691 .52579 L .52692 .51893 L p .617 .022 .612 r
F P
0 g
s
.52681 .51893 m .52692 .51893 L .52691 .52579 L p .616 .022 .612 r
F P
0 g
s
.52691 .52579 m .52681 .52578 L .52681 .51893 L p .616 .022 .612 r
F P
0 g
s
.55554 .45785 m .54723 .4657 L .53977 .45691 L p .989 .007 .536 r
F P
0 g
s
.53977 .45691 m .54509 .44819 L .55554 .45785 L p .989 .007 .536 r
F P
0 g
s
.54265 .54642 m .54898 .54916 L .54492 .55843 L p .603 .07 .848 r
F P
0 g
s
.54898 .54916 m .54265 .54642 L .54486 .53753 L p .64 .058 .788 r
F P
0 g
s
.58081 .50642 m .56539 .50804 L .56308 .49672 L p .819 .031 .654 r
F P
0 g
s
.54068 .52767 m .54626 .52844 L .54486 .53753 L p .651 .045 .725 r
F P
0 g
s
.54486 .53753 m .53968 .53613 L .54068 .52767 L p .651 .045 .725 r
F P
0 g
s
.53668 .52713 m .54068 .52767 L .53968 .53613 L p .63 .043 .715 r
F P
0 g
s
.53973 .55502 m .54492 .55843 L .54005 .56719 L p .583 .083 .917 r
F P
0 g
s
.54492 .55843 m .53973 .55502 L .54265 .54642 L p .603 .07 .848 r
F P
0 g
s
.56308 .49672 m .57763 .49327 L .58081 .50642 L p .819 .031 .654 r
F P
0 g
s
.57763 .49327 m .56308 .49672 L .55915 .48576 L p .854 .025 .623 r
F P
0 g
s
.56471 .46872 m .55379 .47536 L .54723 .4657 L p .938 .013 .563 r
F P
0 g
s
.54723 .4657 m .55554 .45785 L .56471 .46872 L p .938 .013 .563 r
F P
0 g
s
.53968 .53613 m .54486 .53753 L .54265 .54642 L p .61 .056 .782 r
F P
0 g
s
.53968 .53613 m .53596 .53513 L .53668 .52713 L p .63 .043 .715 r
F P
0 g
s
.53381 .52673 m .53668 .52713 L .53596 .53513 L p .613 .041 .706 r
F P
0 g
s
.60237 .50415 m .58081 .50642 L .57763 .49327 L p .83 .037 .683 r
F P
0 g
s
.55915 .48576 m .57218 .48061 L .57763 .49327 L p .854 .025 .623 r
F P
0 g
s
.57218 .48061 m .55915 .48576 L .55379 .47536 L p .894 .018 .592 r
F P
0 g
s
.53596 .53513 m .53329 .5344 L .53381 .52673 L p .613 .041 .706 r
F P
0 g
s
.53175 .52645 m .53381 .52673 L .53329 .5344 L p .599 .04 .7 r
F P
0 g
s
.55379 .47536 m .56471 .46872 L .57218 .48061 L p .894 .018 .592 r
F P
0 g
s
.53329 .5344 m .53138 .53389 L .53175 .52645 L p .599 .04 .7 r
F P
0 g
s
.53028 .52625 m .53175 .52645 L .53138 .53389 L p .588 .039 .695 r
F P
0 g
s
.53138 .53389 m .53001 .53352 L .53028 .52625 L p .588 .039 .695 r
F P
0 g
s
.52922 .52611 m .53028 .52625 L .53001 .53352 L p .58 .038 .691 r
F P
0 g
s
.53001 .53352 m .52903 .53325 L .52922 .52611 L p .58 .038 .691 r
F P
0 g
s
.52846 .526 m .52922 .52611 L .52903 .53325 L p .574 .037 .687 r
F P
0 g
s
.54005 .56719 m .53624 .56326 L .53973 .55502 L p .583 .083 .917 r
F P
0 g
s
.52903 .53325 m .52833 .53306 L .52846 .526 L p .574 .037 .687 r
F P
0 g
s
.52792 .52593 m .52846 .526 L .52833 .53306 L p .57 .037 .685 r
F P
0 g
s
.52833 .53306 m .52782 .53293 L .52792 .52593 L p .57 .037 .685 r
F P
0 g
s
.52753 .52587 m .52792 .52593 L .52782 .53293 L p .567 .037 .684 r
F P
0 g
s
.5381 .54445 m .54265 .54642 L .53973 .55502 L p .57 .07 .848 r
F P
0 g
s
.54265 .54642 m .5381 .54445 L .53968 .53613 L p .61 .056 .782 r
F P
0 g
s
.52782 .53293 m .52746 .53283 L .52753 .52587 L p .567 .037 .684 r
F P
0 g
s
.52725 .52584 m .52753 .52587 L .52746 .53283 L p .564 .036 .682 r
F P
0 g
s
.53596 .53513 m .53968 .53613 L .5381 .54445 L p .585 .055 .777 r
F P
0 g
s
.52746 .53283 m .5272 .53276 L .52725 .52584 L p .564 .036 .682 r
F P
0 g
s
.52705 .52581 m .52725 .52584 L .5272 .53276 L p .563 .036 .682 r
F P
0 g
s
.5272 .53276 m .52702 .53271 L .52705 .52581 L p .563 .036 .682 r
F P
0 g
s
.52691 .52579 m .52705 .52581 L .52702 .53271 L p .561 .036 .681 r
F P
0 g
s
.52702 .53271 m .52688 .53267 L .52691 .52579 L p .561 .036 .681 r
F P
0 g
s
.52681 .52578 m .52691 .52579 L .52688 .53267 L p .56 .036 .68 r
F P
0 g
s
.52688 .53267 m .52679 .53265 L .52681 .52578 L p .56 .036 .68 r
F P
0 g
s
.53677 .42689 m .53382 .43989 L .52227 .43304 L p 1 .016 .582 r
F P
0 g
s
.52227 .43304 m .52053 .41995 L .53677 .42689 L p 1 .016 .582 r
F P
0 g
s
.49568 .39719 m .50464 .41506 L .48983 .41216 L p 1 .035 .674 r
F P
0 g
s
.48983 .41216 m .47486 .39582 L .49568 .39719 L p 1 .035 .674 r
F P
0 g
s
.5381 .54445 m .53483 .54303 L .53596 .53513 L p .585 .055 .777 r
F P
0 g
s
.53329 .5344 m .53596 .53513 L .53483 .54303 L p .563 .054 .772 r
F P
0 g
s
.63256 .50097 m .60237 .50415 L .59803 .48843 L p .84 .042 .71 r
F P
0 g
s
.57763 .49327 m .59803 .48843 L .60237 .50415 L p .83 .037 .683 r
F P
0 g
s
.53601 .55257 m .53973 .55502 L .53624 .56326 L p .585 .085 .926 r
F P
0 g
s
.53973 .55502 m .53601 .55257 L .5381 .54445 L p .57 .07 .848 r
F P
0 g
s
.53483 .54303 m .53249 .54202 L .53329 .5344 L p .563 .054 .772 r
F P
0 g
s
.53138 .53389 m .53329 .5344 L .53249 .54202 L p .553 .053 .767 r
F P
0 g
s
.59803 .48843 m .57763 .49327 L .57218 .48061 L p .86 .032 .658 r
F P
0 g
s
.53483 .54303 m .5381 .54445 L .53601 .55257 L p .569 .069 .847 r
F P
0 g
s
.53249 .54202 m .5308 .54129 L .53138 .53389 L p .553 .053 .767 r
F P
0 g
s
.53001 .53352 m .53138 .53389 L .5308 .54129 L p .553 .053 .764 r
F P
0 g
s
.5308 .54129 m .5296 .54077 L .53001 .53352 L p .553 .053 .764 r
F P
0 g
s
.52903 .53325 m .53001 .53352 L .5296 .54077 L p .552 .052 .761 r
F P
0 g
s
.04928 .31847 m .0869 .30712 L p .12934 .36883 L .887 .062 .81 r
F P
0 g
s
.0869 .30712 m .1474 .3244 L .12934 .36883 L p .887 .062 .81 r
F P
0 g
s
.12934 .36883 m .05729 .35842 L p .04928 .31847 L .887 .062 .81 r
F P
0 g
s
.5296 .54077 m .52873 .54039 L .52903 .53325 L p .552 .052 .761 r
F P
0 g
s
.52833 .53306 m .52903 .53325 L .52873 .54039 L p .552 .052 .759 r
F P
0 g
s
.52873 .54039 m .52811 .54013 L .52833 .53306 L p .552 .052 .759 r
F P
0 g
s
.52782 .53293 m .52833 .53306 L .52811 .54013 L p .552 .052 .758 r
F P
0 g
s
.28717 .32962 m .35785 .36197 L .33725 .37863 L p .918 .06 .802 r
F P
0 g
s
.33725 .37863 m .25929 .35636 L .28717 .32962 L p .918 .06 .802 r
F P
0 g
s
.52811 .54013 m .52767 .53993 L .52782 .53293 L p .552 .052 .758 r
F P
0 g
s
.52746 .53283 m .52782 .53293 L .52767 .53993 L p .551 .051 .757 r
F P
0 g
s
.52767 .53993 m .52735 .5398 L .52746 .53283 L p .551 .051 .757 r
F P
0 g
s
.5272 .53276 m .52746 .53283 L .52735 .5398 L p .551 .051 .756 r
F P
0 g
s
.52735 .5398 m .52712 .5397 L .5272 .53276 L p .551 .051 .756 r
F P
0 g
s
.52702 .53271 m .5272 .53276 L .52712 .5397 L p .551 .051 .755 r
F P
0 g
s
.53601 .55257 m .53333 .55081 L .53483 .54303 L p .569 .069 .847 r
F P
0 g
s
.53249 .54202 m .53483 .54303 L .53333 .55081 L p .569 .069 .846 r
F P
0 g
s
.52712 .5397 m .52696 .53963 L .52702 .53271 L p .551 .051 .755 r
F P
0 g
s
.52688 .53267 m .52702 .53271 L .52696 .53963 L p .551 .051 .755 r
F P
0 g
s
.52696 .53963 m .52684 .53958 L .52688 .53267 L p .551 .051 .755 r
F P
0 g
s
.52679 .53265 m .52688 .53267 L .52684 .53958 L p .551 .051 .755 r
F P
0 g
s
.52684 .53958 m .52676 .53954 L .52679 .53265 L p .551 .051 .755 r
F P
0 g
s
.55259 .43588 m .54509 .44819 L .53382 .43989 L p 1 .017 .587 r
F P
0 g
s
.53382 .43989 m .53677 .42689 L .55259 .43588 L p 1 .017 .587 r
F P
0 g
s
.53624 .56326 m .5335 .56044 L .53601 .55257 L p .585 .085 .926 r
F P
0 g
s
.57218 .48061 m .59049 .47338 L .59803 .48843 L p .86 .032 .658 r
F P
0 g
s
.59049 .47338 m .57218 .48061 L .56471 .46872 L p .892 .027 .636 r
F P
0 g
s
.53333 .55081 m .53601 .55257 L .5335 .56044 L p .587 .087 .933 r
F P
0 g
s
.67487 .49651 m .63256 .50097 L .62668 .48164 L p .848 .047 .733 r
F P
0 g
s
.59803 .48843 m .62668 .48164 L .63256 .50097 L p .84 .042 .71 r
F P
0 g
s
.53333 .55081 m .53141 .54954 L .53249 .54202 L p .569 .069 .846 r
F P
0 g
s
.5308 .54129 m .53249 .54202 L .53141 .54954 L p .569 .069 .845 r
F P
0 g
s
.53141 .54954 m .53004 .54864 L .5308 .54129 L p .569 .069 .845 r
F P
0 g
s
.5296 .54077 m .5308 .54129 L .53004 .54864 L p .569 .069 .844 r
F P
0 g
s
.45353 .37255 m .47486 .39582 L .45658 .397 L p .991 .048 .738 r
F P
0 g
s
.45658 .397 m .42787 .37702 L .45353 .37255 L p .991 .048 .738 r
F P
0 g
s
.56726 .44677 m .55554 .45785 L .54509 .44819 L p .965 .02 .599 r
F P
0 g
s
.54509 .44819 m .55259 .43588 L .56726 .44677 L p .965 .02 .599 r
F P
0 g
s
.56471 .46872 m .58008 .45937 L .59049 .47338 L p .892 .027 .636 r
F P
0 g
s
.58008 .45937 m .56471 .46872 L .55554 .45785 L p .927 .023 .616 r
F P
0 g
s
.53004 .54864 m .52905 .54799 L .5296 .54077 L p .569 .069 .844 r
F P
0 g
s
.52873 .54039 m .5296 .54077 L .52905 .54799 L p .569 .069 .843 r
F P
0 g
s
.5335 .56044 m .53154 .55841 L .53333 .55081 L p .587 .087 .933 r
F P
0 g
s
.53141 .54954 m .53333 .55081 L .53154 .55841 L p .587 .087 .937 r
F P
0 g
s
.52905 .54799 m .52834 .54752 L .52873 .54039 L p .569 .069 .843 r
F P
0 g
s
.52811 .54013 m .52873 .54039 L .52834 .54752 L p .568 .068 .842 r
F P
0 g
s
.55554 .45785 m .56726 .44677 L .58008 .45937 L p .927 .023 .616 r
F P
0 g
s
.52834 .54752 m .52783 .54719 L .52811 .54013 L p .568 .068 .842 r
F P
0 g
s
.52767 .53993 m .52811 .54013 L .52783 .54719 L p .568 .068 .842 r
F P
0 g
s
.62668 .48164 m .59803 .48843 L .59049 .47338 L p .864 .038 .691 r
F P
0 g
s
.52783 .54719 m .52747 .54695 L .52767 .53993 L p .568 .068 .842 r
F P
0 g
s
.52735 .5398 m .52767 .53993 L .52747 .54695 L p .568 .068 .841 r
F P
0 g
s
.52747 .54695 m .52721 .54678 L .52735 .5398 L p .568 .068 .841 r
F P
0 g
s
.52712 .5397 m .52735 .5398 L .52721 .54678 L p .568 .068 .841 r
F P
0 g
s
.52721 .54678 m .52702 .54665 L .52712 .5397 L p .568 .068 .841 r
F P
0 g
s
.52696 .53963 m .52712 .5397 L .52702 .54665 L p .568 .068 .841 r
F P
0 g
s
.52702 .54665 m .52689 .54656 L .52696 .53963 L p .568 .068 .841 r
F P
0 g
s
.52684 .53958 m .52696 .53963 L .52689 .54656 L p .568 .068 .84 r
F P
0 g
s
.52689 .54656 m .52679 .5465 L .52684 .53958 L p .568 .068 .84 r
F P
0 g
s
.52676 .53954 m .52684 .53958 L .52679 .5465 L p .568 .068 .84 r
F P
0 g
s
.52679 .5465 m .52672 .54646 L .52676 .53954 L p .568 .068 .84 r
F P
0 g
s
.53154 .55841 m .53013 .55695 L .53141 .54954 L p .587 .087 .937 r
F P
0 g
s
.53004 .54864 m .53141 .54954 L .53013 .55695 L p .588 .088 .941 r
F P
0 g
s
.38678 .34843 m .42787 .37702 L .40708 .3845 L p .95 .056 .779 r
F P
0 g
s
.40708 .3845 m .35785 .36197 L .38678 .34843 L p .95 .056 .779 r
F P
0 g
s
.51807 .40135 m .52053 .41995 L .50464 .41506 L p 1 .031 .656 r
F P
0 g
s
.50464 .41506 m .49568 .39719 L .51807 .40135 L p 1 .031 .656 r
F P
0 g
s
.53013 .55695 m .52911 .55591 L .53004 .54864 L p .588 .088 .941 r
F P
0 g
s
.52905 .54799 m .53004 .54864 L .52911 .55591 L p .589 .089 .943 r
F P
0 g
s
.73427 .49025 m .67487 .49651 L .66703 .47207 L p .855 .05 .751 r
F P
0 g
s
.62668 .48164 m .66703 .47207 L .67487 .49651 L p .848 .047 .733 r
F P
0 g
s
.52911 .55591 m .52839 .55516 L .52905 .54799 L p .589 .089 .943 r
F P
0 g
s
.52834 .54752 m .52905 .54799 L .52839 .55516 L p .589 .089 .944 r
F P
0 g
s
.52839 .55516 m .52787 .55462 L .52834 .54752 L p .589 .089 .944 r
F P
0 g
s
.52783 .54719 m .52834 .54752 L .52787 .55462 L p .589 .089 .945 r
F P
0 g
s
.52787 .55462 m .52749 .55424 L .52783 .54719 L p .589 .089 .945 r
F P
0 g
s
.52747 .54695 m .52783 .54719 L .52749 .55424 L p .589 .089 .946 r
F P
0 g
s
.52749 .55424 m .52722 .55396 L .52747 .54695 L p .589 .089 .946 r
F P
0 g
s
.52721 .54678 m .52747 .54695 L .52722 .55396 L p .589 .089 .946 r
F P
0 g
s
.52722 .55396 m .52703 .55376 L .52721 .54678 L p .589 .089 .946 r
F P
0 g
s
.52702 .54665 m .52721 .54678 L .52703 .55376 L p .589 .089 .946 r
F P
0 g
s
.52703 .55376 m .52689 .55362 L .52702 .54665 L p .589 .089 .946 r
F P
0 g
s
.52689 .54656 m .52702 .54665 L .52689 .55362 L p .589 .089 .946 r
F P
0 g
s
.52689 .55362 m .5268 .55352 L .52689 .54656 L p .589 .089 .946 r
F P
0 g
s
.52679 .5465 m .52689 .54656 L .5268 .55352 L p .589 .089 .947 r
F P
0 g
s
.5268 .55352 m .52673 .55345 L .52679 .5465 L p .589 .089 .947 r
F P
0 g
s
.52672 .54646 m .52679 .5465 L .52673 .55345 L p .589 .089 .947 r
F P
0 g
s
.52673 .55345 m .52667 .5534 L .52672 .54646 L p .589 .089 .947 r
F P
0 g
s
.59049 .47338 m .61629 .46318 L .62668 .48164 L p .864 .038 .691 r
F P
0 g
s
.61629 .46318 m .59049 .47338 L .58008 .45937 L p .889 .035 .674 r
F P
0 g
s
.05729 .35842 m .02037 .32806 L .04928 .31847 L p .887 .062 .81 r
F P
0 g
s
.54096 .40844 m .53677 .42689 L .52053 .41995 L p .998 .03 .648 r
F P
0 g
s
.52053 .41995 m .51807 .40135 L .54096 .40844 L p .998 .03 .648 r
F P
0 g
s
.66703 .47207 m .62668 .48164 L .61629 .46318 L p .867 .044 .718 r
F P
0 g
s
.58008 .45937 m .6018 .44616 L .61629 .46318 L p .889 .035 .674 r
F P
0 g
s
.6018 .44616 m .58008 .45937 L .56726 .44677 L p .916 .032 .661 r
F P
0 g
s
.81786 .48144 m .73427 .49025 L .72407 .45855 L p .86 .053 .766 r
F P
0 g
s
.66703 .47207 m .72407 .45855 L .73427 .49025 L p .855 .05 .751 r
F P
0 g
s
.4829 .37167 m .49568 .39719 L .47486 .39582 L p .987 .043 .717 r
F P
0 g
s
.47486 .39582 m .45353 .37255 L .4829 .37167 L p .987 .043 .717 r
F P
0 g
s
.56324 .41842 m .55259 .43588 L .53677 .42689 L p .971 .029 .646 r
F P
0 g
s
.53677 .42689 m .54096 .40844 L .56324 .41842 L p .971 .029 .646 r
F P
0 g
s
.56726 .44677 m .58385 .4311 L .6018 .44616 L p .916 .032 .661 r
F P
0 g
s
.58385 .4311 m .56726 .44677 L .55259 .43588 L p .943 .03 .651 r
F P
0 g
s
.55259 .43588 m .56324 .41842 L .58385 .4311 L p .943 .03 .651 r
F P
0 g
s
.61629 .46318 m .65278 .44876 L .66703 .47207 L p .867 .044 .718 r
F P
0 g
s
.65278 .44876 m .61629 .46318 L .6018 .44616 L p .886 .041 .706 r
F P
0 g
s
.72407 .45855 m .66703 .47207 L .65278 .44876 L p .869 .048 .741 r
F P
0 g
s
.90166 .4726 m .81786 .48144 L .80509 .43934 L p .863 .056 .778 r
F P
0 g
s
.72407 .45855 m .80509 .43934 L .81786 .48144 L p .86 .053 .766 r
F P
0 g
s
.18448 .28262 m .28717 .32962 L .25929 .35636 L p .902 .061 .803 r
F P
0 g
s
.25929 .35636 m .1474 .3244 L .18448 .28262 L p .902 .061 .803 r
F P
0 g
s
.42287 .33909 m .45353 .37255 L .42787 .37702 L p .952 .052 .761 r
F P
0 g
s
.42787 .37702 m .38678 .34843 L .42287 .33909 L p .952 .052 .761 r
F P
0 g
s
.51455 .37478 m .51807 .40135 L .49568 .39719 L p .977 .041 .703 r
F P
0 g
s
.49568 .39719 m .4829 .37167 L .51455 .37478 L p .977 .041 .703 r
F P
0 g
s
.6018 .44616 m .63264 .42741 L .65278 .44876 L p .886 .041 .706 r
F P
0 g
s
.63264 .42741 m .6018 .44616 L .58385 .4311 L p .906 .039 .697 r
F P
0 g
s
.32735 .30706 m .38678 .34843 L .35785 .36197 L p .924 .058 .788 r
F P
0 g
s
.35785 .36197 m .28717 .32962 L .32735 .30706 L p .924 .058 .788 r
F P
0 g
s
.54694 .38207 m .54096 .40844 L .51807 .40135 L p .962 .039 .694 r
F P
0 g
s
.51807 .40135 m .51455 .37478 L .54694 .38207 L p .962 .039 .694 r
F P
0 g
s
.58385 .4311 m .60747 .40877 L .63264 .42741 L p .906 .039 .697 r
F P
0 g
s
.60747 .40877 m .58385 .4311 L .56324 .41842 L p .926 .038 .692 r
F P
0 g
s
.8935 .45938 m .90166 .4726 L p .80509 .43934 L .863 .056 .778 r
F P
0 g
s
.57844 .39349 m .56324 .41842 L .54096 .40844 L p .945 .038 .69 r
F P
0 g
s
.54096 .40844 m .54694 .38207 L .57844 .39349 L p .945 .038 .69 r
F P
0 g
s
.56324 .41842 m .57844 .39349 L .60747 .40877 L p .926 .038 .692 r
F P
0 g
s
.65278 .44876 m .70468 .42826 L .72407 .45855 L p .869 .048 .741 r
F P
0 g
s
.70468 .42826 m .65278 .44876 L .63264 .42741 L p .883 .046 .732 r
F P
0 g
s
.80509 .43934 m .72407 .45855 L .70468 .42826 L p .87 .052 .758 r
F P
0 g
s
.46446 .33488 m .4829 .37167 L .45353 .37255 L p .951 .049 .746 r
F P
0 g
s
.45353 .37255 m .42287 .33909 L .46446 .33488 L p .951 .049 .746 r
F P
0 g
s
.80509 .43934 m .87074 .42377 L .8935 .45938 L p .863 .056 .778 r
F P
0 g
s
.63264 .42741 m .67674 .40059 L .70468 .42826 L p .883 .046 .732 r
F P
0 g
s
.67674 .40059 m .63264 .42741 L .60747 .40877 L p .897 .045 .726 r
F P
0 g
s
.50948 .33642 m .51455 .37478 L .4829 .37167 L p .945 .047 .734 r
F P
0 g
s
.4829 .37167 m .46446 .33488 L .50948 .33642 L p .945 .047 .734 r
F P
0 g
s
.37826 .29041 m .42287 .33909 L .38678 .34843 L p .926 .055 .775 r
F P
0 g
s
.38678 .34843 m .32735 .30706 L .37826 .29041 L p .926 .055 .775 r
F P
0 g
s
.11893 .29679 m .1778 .27956 L p .1474 .3244 L .891 .061 .804 r
F P
0 g
s
.1778 .27956 m .18448 .28262 L .1474 .3244 L p .891 .061 .804 r
F P
0 g
s
.1474 .3244 m .0869 .30712 L .11893 .29679 L p .891 .061 .804 r
F P
0 g
s
.60747 .40877 m .64141 .37669 L .67674 .40059 L p .897 .045 .726 r
F P
0 g
s
.64141 .37669 m .60747 .40877 L .57844 .39349 L p .911 .045 .723 r
F P
0 g
s
.87074 .42377 m .80509 .43934 L .77907 .39886 L p .87 .054 .772 r
F P
0 g
s
.70468 .42826 m .77907 .39886 L .80509 .43934 L p .87 .052 .758 r
F P
0 g
s
.77907 .39886 m .70468 .42826 L .67674 .40059 L p .88 .05 .752 r
F P
0 g
s
.55558 .34401 m .54694 .38207 L .51455 .37478 L p .936 .045 .727 r
F P
0 g
s
.51455 .37478 m .50948 .33642 L .55558 .34401 L p .936 .045 .727 r
F P
0 g
s
.57844 .39349 m .60033 .35758 L .64141 .37669 L p .911 .045 .723 r
F P
0 g
s
.60033 .35758 m .57844 .39349 L .54694 .38207 L p .925 .045 .723 r
F P
0 g
s
.24734 .25922 m .25559 .25713 L p .28717 .32962 L .906 .059 .793 r
F P
0 g
s
.25559 .25713 m .32735 .30706 L .28717 .32962 L p .906 .059 .793 r
F P
0 g
s
.28717 .32962 m .18448 .28262 L p .24734 .25922 L .906 .059 .793 r
F P
0 g
s
.54694 .38207 m .55558 .34401 L .60033 .35758 L p .925 .045 .723 r
F P
0 g
s
.43752 .28112 m .46446 .33488 L .42287 .33909 L p .926 .053 .764 r
F P
0 g
s
.42287 .33909 m .37826 .29041 L .43752 .28112 L p .926 .053 .764 r
F P
0 g
s
.86 .40626 m .87074 .42377 L p .77907 .39886 L .87 .054 .772 r
F P
0 g
s
.67674 .40059 m .74045 .36184 L .77907 .39886 L p .88 .05 .752 r
F P
0 g
s
.74045 .36184 m .67674 .40059 L .64141 .37669 L p .891 .05 .748 r
F P
0 g
s
.77907 .39886 m .83991 .37482 L .86 .40626 L p .87 .054 .772 r
F P
0 g
s
.50204 .28025 m .50948 .33642 L .46446 .33488 L p .923 .051 .756 r
F P
0 g
s
.46446 .33488 m .43752 .28112 L .50204 .28025 L p .923 .051 .756 r
F P
0 g
s
.83991 .37482 m .77907 .39886 L .74045 .36184 L p .878 .053 .767 r
F P
0 g
s
.64141 .37669 m .69075 .33006 L .74045 .36184 L p .891 .05 .748 r
F P
0 g
s
.69075 .33006 m .64141 .37669 L .60033 .35758 L p .9 .049 .746 r
F P
0 g
s
.31584 .23985 m .32891 .23657 L p .32735 .30706 L .909 .057 .785 r
F P
0 g
s
.32891 .23657 m .37826 .29041 L .32735 .30706 L p .909 .057 .785 r
F P
0 g
s
.32735 .30706 m .25559 .25713 L .31584 .23985 L p .909 .057 .785 r
F P
0 g
s
.56822 .28829 m .55558 .34401 L .50948 .33642 L p .917 .05 .75 r
F P
0 g
s
.50948 .33642 m .50204 .28025 L .56822 .28829 L p .917 .05 .75 r
F P
0 g
s
.60033 .35758 m .63231 .30514 L .69075 .33006 L p .9 .049 .746 r
F P
0 g
s
.63231 .30514 m .60033 .35758 L .55558 .34401 L p .909 .049 .747 r
F P
0 g
s
.55558 .34401 m .56822 .28829 L .63231 .30514 L p .909 .049 .747 r
F P
0 g
s
.1819 .27827 m .19836 .27355 L .18448 .28262 L p .894 .059 .797 r
F P
0 g
s
.18448 .28262 m .1778 .27956 L .1819 .27827 L p .894 .059 .797 r
F P
0 g
s
.18448 .28262 m .19836 .27355 L .24734 .25922 L p .906 .059 .793 r
F P
0 g
s
.82985 .35843 m .83991 .37482 L p .74045 .36184 L .878 .053 .767 r
F P
0 g
s
.74045 .36184 m .80632 .32177 L .82985 .35843 L p .878 .053 .767 r
F P
0 g
s
.80632 .32177 m .74045 .36184 L .69075 .33006 L p .885 .053 .764 r
F P
0 g
s
.3937 .21811 m .40456 .21535 L p .37826 .29041 L .909 .055 .777 r
F P
0 g
s
.40456 .21535 m .43752 .28112 L .37826 .29041 L p .909 .055 .777 r
F P
0 g
s
.37826 .29041 m .32891 .23657 L .3937 .21811 L p .909 .055 .777 r
F P
0 g
s
.79968 .31101 m .80632 .32177 L p .69075 .33006 L .885 .053 .764 r
F P
0 g
s
.69075 .33006 m .76376 .26106 L p .79968 .31101 L .885 .053 .764 r
F P
0 g
s
.76376 .26106 m .69075 .33006 L .63231 .30514 L p .892 .053 .763 r
F P
0 g
s
.49092 .19624 m .50204 .28025 L .43752 .28112 L p .907 .054 .771 r
F P
0 g
s
.43752 .28112 m .40456 .21535 L .467 .19745 L p .907 .054 .771 r
F P
0 g
s
.467 .19745 m .49092 .19624 L p .43752 .28112 L .907 .054 .771 r
F P
0 g
s
.63231 .30514 m .67995 .22701 L .76376 .26106 L p .892 .053 .763 r
F P
0 g
s
.67995 .22701 m .63231 .30514 L .56822 .28829 L p .898 .053 .764 r
F P
0 g
s
.58712 .20499 m .56822 .28829 L .50204 .28025 L p .903 .053 .766 r
F P
0 g
s
.50204 .28025 m .49092 .19624 L .58712 .20499 L p .903 .053 .766 r
F P
0 g
s
.56822 .28829 m .58712 .20499 L .67995 .22701 L p .898 .053 .764 r
F P
0 g
s
.76376 .26106 m .76978 .26484 L .79968 .31101 L p .885 .053 .764 r
F P
0 g
s
.76696 .26044 m .76978 .26484 L .76376 .26106 L p .881 .055 .776 r
F P
0 g
s
.76376 .26106 m .76598 .25896 L .76696 .26044 L p .881 .055 .776 r
F P
0 g
s
.76598 .25896 m .76376 .26106 L .67995 .22701 L p .886 .055 .775 r
F P
0 g
s
.73284 .20779 m .76598 .25896 L p .67995 .22701 L .886 .055 .775 r
F P
0 g
s
.67995 .22701 m .71129 .17562 L .73284 .20779 L p .886 .055 .775 r
F P
0 g
s
.71129 .17562 m .67995 .22701 L .58712 .20499 L p .89 .055 .776 r
F P
0 g
s
.49018 .19068 m .49092 .19624 L .467 .19745 L closepath p .903 .053 .766 r
F P
0 g
s
.49994 .18762 m .59774 .1582 L p .49092 .19624 L .893 .056 .778 r
F P
0 g
s
.59774 .1582 m .58712 .20499 L .49092 .19624 L p .893 .056 .778 r
F P
0 g
s
.49092 .19624 m .49018 .19068 L .49994 .18762 L p .893 .056 .778 r
F P
0 g
s
.69054 .14399 m .71129 .17562 L p .58712 .20499 L .89 .055 .776 r
F P
0 g
s
.58712 .20499 m .59774 .1582 L .68194 .1313 L p .89 .055 .776 r
F P
0 g
s
.68194 .1313 m .69054 .14399 L p .58712 .20499 L .89 .055 .776 r
F P
0 g
s
.25 Mabswid
.67538 0 m
.9737 .44463 L
s
.9737 .44463 m
1 .64598 L
s
1 .64598 m
.6864 .22043 L
s
.6864 .22043 m
.67538 0 L
s
.03233 .24995 m
0 .46115 L
s
0 .46115 m
.6864 .22043 L
s
.6864 .22043 m
.67538 0 L
s
.67538 0 m
.03233 .24995 L
s
.03233 .24995 m
.67538 0 L
s
.16291 .1992 m
.16752 .2039 L
s
gsave
.1537 .18979 -71.5152 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.33533 .13218 m
.33965 .13714 L
s
gsave
.3267 .12224 -67.6007 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51915 .06073 m
.52313 .06597 L
s
gsave
.51119 .05024 -67.3218 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.19654 .18613 m
.19927 .18898 L
s
.23058 .17289 m
.23328 .17578 L
s
.26506 .15949 m
.26772 .16241 L
s
.29997 .14592 m
.3026 .14887 L
s
.37115 .11825 m
.3737 .12127 L
s
.40743 .10415 m
.40994 .1072 L
s
.44418 .08987 m
.44665 .09295 L
s
.48142 .07539 m
.48385 .07851 L
s
.1297 .2121 m
.1325 .21489 L
s
.0969 .22485 m
.09973 .22761 L
s
.0645 .23745 m
.06735 .24018 L
s
.03249 .24989 m
.03537 .25259 L
s
.55738 .04587 m
.55972 .04905 L
s
.59612 .03081 m
.59842 .03402 L
s
.63538 .01555 m
.63763 .01879 L
s
.67518 8e-05 m
.67738 .00336 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[73]:=",
  FormatType->StandardForm,
  ImageSize->{180, 144.25},
  ImageMargins->{{106, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002d0000T1000`40O003h00O]7oo002dOol00;Ao
o`00]7oo001jOol3000gOol007Moo`<00003Ool007oo03Moo`00MGoo0P0017oo0P00=goo001bOol4
0005Ool00`00Ool0000fOol005]oo`<0015oo`<000Uoo`03001oo`0003Ioo`00GGoo00<007ooOol0
3Goo0P0037oo00@007ooOol003Eoo`00G7oo00<007ooOol02goo0`0000=oo`00Ool02goo00D007oo
Oomoo`0003Aoo`00GGoo00<007ooOol027oo0P004Goo00D007ooOomoo`0003Aoo`00IGoo10004Woo
00<007ooOol00Woo0P00<Woo001ROol3000FOol00`00Oomoo`03Ool00`00Oomoo`0`Ool0061oo`80
01Yoo`03001oogoo009oo`03001oogoo031oo`00GGoo0`000Woo00<007ooOol05goo00<007ooOol0
0goo00<007ooOol0;goo001KOol2000OOol00`00Oomoo`04Ool2000_Ool005Qoo`@0021oo`03001o
ogoo00Eoo`03001oogoo02eoo`00EGoo0`0097oo00<007ooOol01Goo00<007ooOol0;Goo001COol2
000WOol00`00Oomoo`06Ool00`00Oomoo`0/Ool0051oo`<0009oo`03001oogoo02Aoo`03001oogoo
00Moo`03001oogoo02]oo`00?7oo0P0047oo0P00;7oo00<007ooOol01goo0P00;7oo000lOol00`00
Ool0000<Ool4000]Ool00`00Oomoo`08Ool00`00Oomoo`0ZOol003aoo`03001oo`0000Uoo`<0035o
o`03001oogoo00Uoo`03001oogoo00=oo`H0021oo`00?Goo0P001goo0`00<goo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol07Woo0013Ool3000fOol00`00Oomoo`0:Ool20007Ool00`00Oomo
o`0OOol0045oo`8003Uoo`8000aoo`03001oogoo00Ioo`03001oogoo01ioo`00?Woo0`000Woo00<0
07ooOol0<goo1@0037oo00<007ooOol09goo000kOol3000hOol30003L3P00`00L3P0000<Ool00`00
Oomoo`0VOol003Uoo`800003Ool007oo03Eoo`<000I`>003001`>00000eoo`8002Ioo`00=Woo0`00
=goo0`002G0h00@0070hL3P000aoo`03001oogoo02Eoo`00=7oo0`00=Goo1000370h00D0070hL3Q`
>00000aoo`03001oogoo02Aoo`006goo1P0047oo0`00=Goo0`000W0h00<0070hL3P02g0h00D0070h
L3Q`>00000eoo`03001oogoo02=oo`0087oo00<007ooOol02goo0`00=Goo0`001G0h00<0070hL3P0
370h00D0070hL3Q`>00000aoo`03001oogoo02=oo`007goo00<007ooOol02Woo0P000goo00<007oo
Ool0;goo0`00270h00<0070hL3P0370h00<0070hL3P00W0h00<007ooOol02Woo00<007ooOol08Woo
000POol00`00Oomoo`06Ool3000dOol3000;L3P00`00L3Q`>00<L3P00`00L3Q`>002L3P00`00Oomo
o`0;Ool00`00Oomoo`0QOol002Moo`80009oo`03001oogoo02aoo`H000e`>003001`>70h00e`>007
001`>70hL3P0070h000037oo00<007ooOol08Goo000TOol3000_Ool;000<L3P00`00L3Q`>00=L3P0
1000L3Q`>0000g0h00<007ooOol02Woo00<007ooOol087oo000QOol300000goo001oo`0/Ool30006
M3P00`00L3Q`>002L3P90003L3P00`00L3Q`>00=L3P00`00L3P00004L3P00`00Oomoo`0;Ool00`00
Oomoo`0OOol001moo`8002moo`<000Ud>003001`>70h00]`>0@00003L3P0000000a`>003001`>000
00E`>003001oogoo00Yoo`03001oogoo01moo`0077oo1000;Goo0`0037@h00<0070hL3P03W0h00@0
070hL3Q`>0D000M`>08000I`>003001oogoo00]oo`03001oogoo01ioo`006Woo0P00;Woo0`0000=d
>000M3P03G@h00<0070hL3P03G0h00<0070hL3P01W0h1@0000=`>0000000270h00<007ooOol02goo
00<007ooOol07Goo000GOol3000/Ool40005M3P00`00M3Qd>00;M3P00`00L3Q`>00<L3P00`00L3Q`
>00:L3P50009L3P00`00Oomoo`0:Ool2000NOol001Aoo`<000=oo`03001oogoo02Ioo`<000Ud>003
001d>7@h00]d>003001`>70h00a`>003001`>70h00M`>0<000=`>003001`>00000Q`>003001oogoo
00]oo`03001oogoo00Aoo`8001Ioo`004Woo0`00:goo0`0037@h00<007@hM3P02g@h00<0070hL3P0
370h00<0070hL3P0170h0`001G0h00D0070hL3Q`>00000Q`>003001oogoo00]oo`03001oogoo00=o
o`03001oo`0001Eoo`003goo0`000Woo00<007ooOol09Woo0`0000=d>@00M3P03G@h00<007@hM3P0
2W@h00<0070hL3P02g0h00<0070hL3P00W0h0`00270h00<0070hL3P00W0h00<0070hL3P01W0h00<0
07ooOol02goo00<007ooOol00Woo00<007oo00005Goo000>Ool2000YOol40005M3T00`00M3Qd>00;
M3P00`00M3Qd>00:M3P00`00L3Q`>00;L3P00`00L3P00002000:L3P00`00L3Q`>003L3P00`00L3Q`
>002L3P01@00L3Q`>70h000037oo0P001Goo0P005Goo000>Ool3000UOol3000:M3T00`00M3Qd>00;
M3P00`00M3Qd>009M3P00`00L3Q`>00;L3P2000<L3P00`00L3Q`>005L3P00`00L3Q`>006L3P00`00
Oomoo`0;Ool00`00Oomoo`0IOol000ioo`800003Ool007oo01ioo`D000id>@03001d>7@h00Yd>003
001d>7@h00Yd>003001`>70h00M`>0@000e`>003001`>70h00I`>003001`>70h00E`>08000eoo`03
001oogoo01Qoo`003Woo00D007ooOomoo`0001Yoo`@000E`>@03001d>G@i00ad>@03001d>7@h00Yd
>003001d>7@h00Ud>003001`>70h00A`>0<0009`>003001`>70h00]`>003001`>70h00Q`>003001`
>70h00=`>003001`>00000eoo`8001Uoo`003Woo0P000goo00<007ooOol057oo0`002W0i0P003G@i
00<007@hM3P02G@h00<007@hM3P02G@h00@0070hL3Q`>0<000E`>003001`>70h00]`>003001`>70h
00Q`>003001`>70h009`>004001`>70h000=Ool2000IOol000eoo`8000Eoo`03001oogoo00ioo`D0
00m`>@03001d>G@i00]d>@03001d>7@h00Qd>003001d>7@h00Ad>0T000Q`>003001`>70h00Y`>003
001`>70h00Y`>004001`>70h0004L3P00`00Oomoo`0<Ool00`00Oomoo`0FOol000=oo`<0009oo`03
001oogoo009oo`03001oogoo00Eoo`03001oogoo00Yoo`<000=`>@80011`>@8000ad>@03001d>7@h
00=d>0D00003M3P0000000<000=d>0<000=d=`D0009`>003001`>70h00]`>003001`>70h00]`>080
00I`>003001oogoo00]oo`03001oogoo01Ioo`001goo0`000goo0P001goo00<007ooOol01Woo0`00
1W0i00@0070i0000011`>@03001d>G@i00Ud>@H000Ed>003001d>7@h00Ad>080009d>003001d=g@g
00Id=`D000Y`>003001`>70h00a`>08000M`>003001oogoo00]oo`8001Ioo`002Goo00D007ooOomo
o`0000Uoo`03001oogoo009oo`<000Q`>@03001`>G0i009`>@<000i`>@8000Id>@<0009d>003001d
>7@h00Md>003001d>7@h00<000Ad>003001d=g@g00Qd=`03001d=g@g00@000E`>003001`>70h00a`
>003001`>00000M`>003001oogoo00aoo`03001oogoo01Aoo`003Goo00<007ooOol027oo10002W0i
00<0070iL3T01W0i0P003W0i00<007@iM3T00`001W@h00<007@hM3P01W@h0`001g@h00<007@gM3L0
27@g00<007@gM3L017@g0`000W0h00<0070hL3P02g0h00D0070hL3Q`>00000M`>003001oogoo00]o
o`03001oogoo01Aoo`003Goo0P001goo1@002W0i00<0070iL3T02G0i0P00370i0`002W@h00<007@h
M3P00W@h0`0000=d>000M3P01g@h00<007@gM3L01g@g00<007@gM3L027@g0`00370h00<0070hL3P0
0g0h00<0070hL3P01G0h00<007ooOol02goo00<007ooOol04goo000=Ool00`00Oomoo`03Ool30005
L3T30006L3T00`00L3U`>@0<L3T20009L3T01@00M3Ud>G@i00002W@h10001G@h00<007@hM3P01W@h
00<007@gM3L01W@g00<007@gM3L02G@g00<0070g00000P00270h00<0070hL3P01G0h00<0070hL3P0
1G0h00<007ooOol02Woo0P0057oo000<Ool20002Ool3000;L3T30002L3T00`00L3U`>@0?L3T30004
L3T20005M3T20006M3P40007M3P00`00M3Qd>006M3P00`00M3Md=`06M3L00`00M3Md=`08M3L00`00
L3M`=`03L3L20005L3P00`00L3Q`>006L3P00`00L3Q`>006L3P00`00Oomoo`0:Ool00`00Oomoo`0B
Ool000aoo`@0015`>@@001=`>@800003L3T007@i00Qd>@80009d>08000Ad>003001d>7@h00Ed>003
001d>7@h00Ed>003001d=g@g00Id=`03001d=g@g00Qd=`03001`=g0g00E`=`<00003L3P0070h00U`
>003001`>70h00=`>003001`>00000eoo`03001oogoo015oo`0037oo0P00570i00<0071JL5X01000
470i0`002W@i0`001g@h00<007@hM3P017@h00<007@hM3P01G@h00<007@gM3L01W@g00<007@gM3L0
1g@g00<0070gL3L02G0g00<0070hL3P02W0h00<0070hL3P00P000g0h00<007ooOol02goo00<007oo
Ool047oo000<Ool3000BL3T00`00L5Y`FP05L5X4000;L3T01000M3Ud>G@i0`0017@i0`000W@i0P00
1W@h50000g@g00<007@gM3L01g@g00<0070gL3L02G0g00<0070gL3L00P002W0h0P001G0h00<007oo
Ool02goo00<007ooOol047oo000<Ool00`00Oomoo`02000@L3T00`00L5Y`FP09L5X30007L3T00`00
M3Ud>@05M3T40007M3T00`00M3Qd>00300000gPh001h=`05N3L00`00N3Mh=`04N3L00`00M3Md=`02
M3L50008M3L00`00L3M`=`08L3L00`00L3M`=`03L3L20007L3P20007L3P00`00Oomoo`0;Ool00`00
Oomoo`03Ool30009Ool0009oo`D000Eoo`03001oogoo009oo`03001`>G0i00a`>@03001`FW1J00e`
FP@0009`>@03001d>G@i00Ad>@<00003M3T0000000Md>@<000Eh>003001h=gPg00Ah=`03001h=gPg
00=h=`03001d=g@g00Ed=`03001d=`00008000Ad=`03001`=g0g00Q`=`03001`=g0g00I`=`03001`
>70h009`>080009`>003001`>70h00E`>003001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Mo
o`001Woo00<007ooOol00goo00<007ooOol00goo00<0070iL3T02g0i00<0071JL5X04G1J10000g@i
0P001W@i0`0000Ad>@00000000=h>003001h>7Ph00=h>003001h=gPg00=h=`03001h=gPg00=h=`03
001d=g@g00Ed=`03001d=g@g009d=`<00003M3L0070g00Q`=`03001`=g0g00Q`=`800003L3P0070h
00A`>003001`>70h00A`>003001oogoo00]oo`8000Aoo`03001oogoo00Qoo`001goo00D007ooOomo
o`0000Moo`L000I`>@03001`FW1J019`FP03001dFWAJ00<000Yd>@<000Ih>08000Ah>003001h=gPg
00=h=`03001h=gPg00=h=`03001d=g@g00Ad=`03001d=g@g00Ed=`03001`=g0g00M`=`03001`=g0g
00]`=`03001`>70h00E`>003001`>70h00A`>003001oogoo00]oo`03001oogoo00=oo`03001oogoo
00Moo`001Woo0P000goo00<007ooOol01goo1G1J2@004G1J10000gAJ0`001W@i00@007PiN3Uh>@80
00Ih>003001h>7Ph009h>003001h=gPg009h=`03001h=gPg00=h=`03001d=g@g00=d=`03001d=g@g
00Id=`03001d=`00008000A`=`03001`=g0g00Y`=`03001`>00000M`>003001`>70h00A`>003001o
ogoo00aoo`03001oogoo00aoo`002goo0P002Goo2G1J00@0071JL5Y`FPL000Q`FP<000UdFP<0009d
>@03001h>GPi00Ah>@8000Eh>003001h>7Ph00l000=d=`03001d=g@g00Ed=`03001d=g@g00=d=`80
0003L3L0070g00Y`=`8000=`>003001`>70h00E`>003001`>70h00A`>003001oogoo00aoo`03001o
ogoo00]oo`002goo00<007ooOol02Goo271J00<0071JL5X0271J200000=`FP00M5X037AJ10001gPi
0P000WPh10000W`g00<007`fO3H00W`f00<007`fO3H00W`f00<007PfN3H010001W@g00<007@gM3L0
1W@g00<0070gL3L0270g0P001W0h00<0070hL3P01G0h00<0070hL3P00P0000=/>000Ool037oo0P00
3Goo000;Ool2000;Ool00`00L5Y`FP04L5X00`00L5Y`FP0:L5X300000g1J00000005000;M5X00`00
M5YdFP030005N3T30004O3P01000O3Ml=`0017`f00D007`fO3Il=P0000Eh=P8000Ed=`03001d=g@g
00Ad=`05001`=g0gL3L00007L3L00`00L3Q`>007L3P00`00L3Q`>005L3P20004K3P00`00Oomoo`0<
Ool00`00Oomoo`0:Ool000]oo`03001oogoo00aoo`E`FP03001`FW1J00Q`FP8000I`FP03001`FW1J
009`FPL000=dFP03001dFWAJ00AdFP<00003N3T007`i009l>@8000=l>004001l=g`g0003O3H00`00
O3Il=P02O3H00`00N3Ih=P02N3H00`00N3H0000200000g@g001d=`05M3L00`00L3M`=`03L3L20003
L3L2000;L3P00`00L3Q`>002L3P30006K3P00`00Oomoo`0<Ool00`00Oomoo`09Ool000]oo`03001o
ogoo00eoo`A`FP03001`FW1J00E`FP<000Q`FP03001`FW1J00U`FPH000MdFP<000Al>@800003O3P0
000000T00003O3H007Pf00=h=P03001h=WPf009h=P03001d=g@g00Ad=`03001`=g0g00I`=`03001`
=`0000i`>004001`>0000003K3P00`00K3Q/>003K3P00`00Oomoo`0<Ool00`00Oomoo`09Ool000Yo
o`<000moo`04001`FW1J0004L5X3000;L5X00`00L5Y`FP0;L5X01000M5YdFWAJ1@000WAJ00<007QJ
N5X00`000W`i0`000W`g00<007`f00000W`e00<007`DO1@0100000=h=P00N3H017Pf00<007@f0000
0P0000=d=`00L3L02G0g00<0070hL3P03W0h00<006`hK3P016`h00<006`hK3P00f`h00<007ooOol0
37oo00<007ooOol027oo000:Ool00`00Oomoo`0@Ool01000L5X0071J0`003W1J00<0071JL5X02g1J
00<007AJM5X01WAJ1P000WQJ1`0000Al=`00O3H0009l=@04001l57`D0002O1@20004N3H00`00M3Id
=P03M3H00`00L3M`=`06L3L200000g0g001`>00;L3P300000f`h001/>006K3P00`00K3Q/>003K3P0
0`00Oomoo`0<Ool00`00Oomoo`07Ool000=oo`8000Eoo`03001oogoo015ooa`000I`FP03001dFWAJ
00MdFP03001hFgQK009hFa<000=l5005001l5000N3H00005M3H01000L3I`=P00170g0P00170g00<0
070hL3P01W0h0`001F`h00<006`hK3P016`h00<006`hK3P00f`h00<007ooOol037oo0P0027oo0003
Ool00`00Ool00004Ool2000?Ool300000goo001`FP0AL5X00`00L5Y`FP05L5XT00000g`C001l4P04
0003O1@00`00M3Id=P03M3H00`00L3I`=P02L3H01000L3L000001g0g00<0070hL3P00g0h0P002F`h
00<006`hK3P016`h00<006`hK3P00f`h00<007ooOol037oo00<007ooOol01Woo0003Ool00`00Ool0
0004Ool00`00Oomoo`0<Ool20006Ool00`00L5Y`FP0?L5X00`00L5Y`FP0:L5X00`00L5]`F`07L5/0
1@00M5adG7AL00000WAL0`000g1N2`000W`B00H007`DO1Al5000N1@200000g@f001`=P05L3H00`00
L3M`=`08L3L00`00L3P00002000;K3P00`00K3Q/>005K3P00`00K3Q/>00200000f`h001oo`0=Ool0
0`00Oomoo`05Ool000Aoo`8000Aoo`03001oogoo00Uoo`<000Uoo`03001`FW1J00i`FP03001`FW1J
00]`FP03001`Fg1K009`F`<00003L5/00000008000A`G@D0009TO`9PO`03001POf1o00<00005O0l0
07`B001l4P020004N1@00`00L3I`=P03L3H01000L3I`=P002W0g00<006`hK3P03F`h00@006`hK3Q/
>0H000=/>003001oogoo00aoo`8000Ioo`002Woo00<007ooOol01Woo0`003Goo0P003W1J00<0071J
L5X01G1J1@0000=`FP0000000`001W1K0`001FaM00H006Ao001PO`00H7l:0003O1801`00N1Ah57PD
001d=@0000=`=P03001`=W0f009`=P03001`=g0g00=`=`<00003K3L006`h00m/>0<000A/>003001/
>6`h00=/>003001oogoo00]oo`8000Ioo`002Goo00<007ooOol017oo0`004Woo00<0071JL5X02G1J
00<0071JL5X01`001VaK00<0071KL5/0171K0`000faL00<006aM00000P0000=XG@00I5d00fAM0P00
0VAM00<0061MH5d01@0000Il4P00N1<007PD0003M3D00`00L3H00006L3H00`00L3L000020005K3L0
0`00K3Q/>008K3P30002K3P00`00K3Q/>005K3P00`00K3Q/>002K3P00`00Oomoo`0;Ool30005Ool0
00Uoo`04001oogooOol3000FOol01000L5Y`FW1J1`000faJ00<006aKK5/02faK00<0071KL5/00`00
1faL00D006QM001XG@0000ATG@05001TGFAMI5d00003H5d400000g`@001h4`02N1<00`00M3Ed=@03
M3D00`00L3I`=P06L3H00`00K3M/=`07K3L00`00K3Q/>004K3P30006K3P00`00K3Q/>005K3P00`00
K3Q/>002K3P00`00Oomoo`07Ool30002Ool00`00Oomoo`03Ool000Uoo`@001Yoo`<000]/FP03001/
FfaK00]/F`8000I/G0<000AXG003001TG@00009TG@05001TGFAMI5d00003H5d00`00H5aPG0030000
1g`A001h4`00M1<007@e0080009`=@03001`=W0f00<0009/=P03001/=f`g00Q/=`03001/>6`h00<0
00U/>003001/>6`h00I/>005001/>6`hK3P00006Ool30005Ool00`00Oomoo`03Ool000Uoo`8001io
o`03001/FVaJ00Y/FP03001/FfaK00A/F`@000A/F`800004K5`000000005J5`00`00J5aXG002J5`A
00000g`A001d4`02M1<00`00L3E`=@03L3D20006K3H00`00K3M/=`08K3L2000<K3P00`00K3Q/>006
K3P00`00K3Q/>002K3P00`00Ool000030008Ool00`00Oomoo`03Ool000]oo`03001oogoo01eoo`03
001/FVaJ00Q/FP03001/FfaK00@000Y/F`03001XG6QL00AXG08000EXG003001XG6QL009XG003001T
G6AL009TG003001TFfAK00<00005O0l007PBN1800002L1@01P00L3D00000K3H000M/=P04001/=f`g
K3L50002K3P00`00K3Q/>00<K3P00`00K3Q/>006K3P00`00K3Q/>002K3P00`00Oomoo`0;Ool00`00
Oomoo`02Ool000aoo`03001oogoo01eoo`03001/FVaJ00Q/FP8000Y/F`<000=/F`<00003J5`006QL
00EXG003001XG6QL009XG003001TG6AL00=TG003001TFfAK00D00003N180000000=`5003001/=V`f
009/=P03001/=V`f00=/=P03001/=P00008000M/>003001/>6`h00a/>003001/>6`h00M/>003001/
>00000<000aoo`03001oogoo009oo`003Goo00<007ooOol07Goo00<006aJK5X01@0016aJ0P001VaK
0P002FaK00<006QLJ5`016QL00<006QLJ5`00VQL00<006ALI5`00fAL00@006AKI5]TF`<00003O0l0
0000009`4P800003K3D006`f00=/=P03001/=V`f00<0009/=`03001/>6`h00Q/>003001/>6`h00]/
>003001/>6`h009/>0L000=/>@03001oogoo00Yoo`03001oogoo009oo`003Woo00<007ooOol07Goo
0P002faJ0P0000A/F`00000000U/F`04001XFfQKJ5/300000fQL001XG004J5`00`00I5aTG003I5`0
1000I5]TFfAK1`0000=/4`00K3D00V`e00<006`fK3H010001F`g00<006`hK3P026`h00<006`hK3P0
1F`h1P0000=/>00000000P001V`i00<006`iK3T00V`i00<007ooOol02Goo00<007ooOol00Woo000?
Ool2000OOol00`00K5Y/FP0:K5X00`00K5]/F`08K5/20007J5/F00001V`B001/4f`C001/=@@0009X
=P03001/=f`g00E/=`03001/>6`h009/>0@00003K3P0000000H000M/>003001/>F`i00Q/>@03001/
>F`i009/>@03001oogoo00Qoo`03001oogoo009oo`004Goo00<007ooOol07Goo00<006aJK5X01VaJ
0P000faK00<006aKK5/01FaK00<006QKJ5/01VQK00<006QKJ5/016QK00<006QKJ5/016QK00@006QK
J5]XF`D00003K180000000<00003J3D006Pf00AX=P04001/=f`gK3L200000f`g000000030005J3P0
0`00K3Q/>00<K3P00`00K3U/>@09K3T01@00K3U/>F`i00002Woo00<007ooOol00Woo000BOol00`00
Oomoo`0NOol00`00K5Y/FP02K5X20006K5/20003K5/20008J5/00`00J5]XF`04J5/00`00J5]XF`05
J5/01@00J5]XFfQKJ0l01P000VPD00@006Pe001X=@T000=X=`03001X>6Ph00MX>003001/>6`h00a/
>003001/>F`i00Y/>@05001/>F`iK3T00009Ool00`00Oomoo`02Ool001=oo`03001oogoo01ioo`04
001/FP00000:K5/00`00K5/00009J5/00`00J5]XF`05J5/00`00J5]XF`05J5/01000J5]XFfQK2`00
0V@f00<006PgJ3L00VPg00<006PgJ3L016Pg00<006PhJ3P026Ph00<006`hK3P02f`h00<006`iK3T0
2V`i00D006`iK3U/>@0000Yoo`03001oogoo005oo`0057oo00<007ooOol07Woo00<006aKK5/02faK
00<006QK00001fQK00<006QKJ5/01FQK00<006QKJ5/01FQK00<006QKJ5/00VQK0`0000ML4f0D001P
=@00I3D00003I3H00`00J3MX=`02J3L00`00J3MX=`05J3L00`00J3QX>007J3P00`00K3Q/>00;K3P0
0`00K3U/>@0;K3T01@00K3U/>F`i00002Goo00<007ooOol00Goo000EOol2000POol00`00K5]/F`07
K5/00`00K5]/F`02K5/40002J5/00`00J5]XF`06J5/00`00J5]XF`05J5/00`00J5]XF`02J5//0006
K3P00`00K3U/>@0<K3T01@00K3U/>F`i000027oo00<007ooOol00Goo000GOol00`00Oomoo`0NOol0
0`00K5]/F`04K5/20009K5/70004J5/00`00J5]XF`05J5/00`00J5]XF`02J5/600001E`f001P=f0g
00000V0g00<006@hI3P00V@h00<006PhJ3P01FPh00<006PhJ3P01fPh00<006PiJ3T01FPi6`001goo
00<007ooOol00Goo000HOol00`00Oomoo`0NOol01000K5]/FfaK0P002faK00<006QKJ5/016QK7@00
00=P=`00I3P00f@h00<006PhJ3P01FPh00<006PhJ3P01VPh00<006PiJ3T036Pi00<006`iK3T03F`i
00<006`iK3T00P001goo00<007ooOol00Goo000IOol00`00Oomoo`0NOol00`00K5/0000<K5/00`00
J5]XF`08J5/00`00J5YXFP06J5X00`00J5YXFP02J5X6000015Pg001L>0000V0h2`000VPh00<006Ph
J3P01fPh00<006PiJ3T02fPi00<006`iK3T03f`i0P000V`i00<007ooOol017oo00<007ooOol00Goo
000JOol2000OOol00`00K5]/F`0:K5/00`00J5]XF`08J5/00`00J5YXFP07J5X00`00J5YXFP02J5X4
00000e0i000000040002H3P00`00I3QT>002I3P00`00I3UT>@02I3T50007J3P00`00J3UX>@0;J3T0
0`00K3U/>@0@K3T01@00K3U/>F`i00001Goo00<007ooOol00Goo000LOol00`00Oomoo`0NOol00`00
K5]/F`07K5/00`00J5]XF`08J5/00`00J5YXFP07J5X00`00J5YXFP03J5X70002F3T00`00G3UL>@02
0003I3P00`00I3UT>@05I3T00`00J3UX>@0500000fPh001X>@0<J3T00`00K3U/>@0@K3T00`00K3T0
0002K3T00`00Oomoo`04Ool10001Ool1Ool001eoo`03001oogoo01moo`M/F`03001XFfQK00UXF`03
001XFVQJ00MXFP03001XFVQJ00=XFP<00006C5/0051K001H>@000e`i00<0060i00000V@h00<006@i
I3T016@i00<006PiJ3T01VPi2@001VPi00<006`iK3T046`i00<006`i00000f`i00<007ooOol00goo
0@000Goo0Goo000NOol00`00Oomoo`0OOol5K5/00`00J5]XF`09J5/00`00J5YXFP08J5X00`00J5YX
FP04J5X500001UAK00000000G3T000AP>@D000=T>@03001X>FPi00MX>@03001X>FPi00EX>@T0011/
>@04001/>F`i0002K3T00`00Oomoo`03Ool10001Ool1Ool001moo`03001oogoo01moo`04001/FfaK
000;J5/00`00J5YXFP08J5X00`00J5YXFP07J5X200000eAL00000002G5X20004H3T00`00I3UT>@02
I3T40008J3T00`00J3UX>@0;J3T01000K3U/>F`i1P002F`i00<006`iK3T00V`i00@006`iK3T000Ao
o`40005oo`5oo`0087oo0P0087oo1@002FQK00<006QJJ5X026QJ00<006QJJ5X01fQJ0P0000QDG000
F5`005aJ001PFP000V0i00<006@iI3T01F@i00<006@i00000P0016Pi00<006PiJ3T02fPi00<006`i
K3T026`i1P000f`i00<006`iK3T00f`i00@006`iK3T000=oo`40005oo`5oo`008Woo00<007ooOol0
87oo00<006aJ000010000fQK00<006QJJ5X02FQJ00<006QJJ5X02FQJ00<005QLF5`00`000f1J0`00
1F@i00<006@iI3T00f@i0P000VPi00<006PiJ3T02fPi00<006`iK3T03V`i2P000V`i00D007ooOomo
o`00009oo`008goo00<007ooOol087oo00<006aJK5X00faJ2@001FQJ00<006QJJ5X016QJ1`0000=H
G000G5/00UaK0V1J00@006AJI5YTFP80009T>@03001T>F@i00MT>@<000]X>@03001/>F`i015/>@03
001/>F`i00A/>@D0009oo`40005oo`5oo`0097oo00<007ooOol087oo00<006aJK5X016aJ00<006QJ
J5X016QJ30001FQJ00@007oo000000=LF`<000ETFP<000QT>@04001X>FPiJ3T40006J3T00`00K3U/
>@0AK3T00`00K3U/>@07K3T00`00K3T00003Ool10001Ool002Eoo`03001oogoo021oo`03001/FVaJ
009/FP03001XFVQJ00YXFP03001XFVQJ00IXFP03001oogoo00Aoo`03001LF`0000=PF`05001TFVAJ
I5X00003I5X30004I3T00`00J3UX>@06J3T40002J3T00`00K3U/>@0@K3T00`00K3U/>@09K3T00`00
K3T00002Ool10001Ool002Ioo`80025oo`04001/FVaJ000=J5X00`00J5YXFP03J5X00`00Oomoo`08
Ool00`00H5]PF`03H5/2I5X00`00I5YTFP05I5X01000I3UT>@003FPi100046`i00<006`iK3T02V`i
00H006`iK3T007oo0001Ool002Qoo`03001oogoo01moo`03001/FP0000aXFP05001XFVQJJ5X0000=
Ool00`00H5]PF`03H5/30008I5X3000>J3T00`00J3UX>@04000<K3T00`00K3U/>@0;K3T00`00K3U/
>@020001Ool002Uoo`03001oogoo01moo`03001XFVQJ00YXFP<0015oo`05001PFf1KH5/00003I5/0
0`00I5YTFP04I5X01000J5YXFVQJ0P002fPi00<006PiJ3T01FPi10001f`i00<006`iK3T03F`i00@0
06`i0000005oo`00:Woo00<007ooOol07goo00<006QJJ5X01fQJ0P005Goo00<0061K00001FAK0P00
0fAJ00<006QJJ5X016QJ0`001fPi00<006PiJ3T02VPi10000V`i00<006`iK3T03F`i0`000Goo0@00
0Goo000[Ool00`00Oomoo`0OOol00`00J5YXFP03J5X3000HOol00`00I5]TF`06I5/00`00I5X0000:
J5X20004J3T00`00J3UX>@0?J3T4000;K3T30002Ool00`00Ool00001Ool002aoo`80021oo`80009X
FP03001oogoo01Yoo`03001TFfAK00ETF`<000aXFP04001X>FPi000AJ3T00`00K3U/>@02K3T50003
K3T30006Ool10001Ool1000002ioo`03001oogoo01moo`03001oogoo01eoo`03001TFfAK009TF`80
00=XFP03001XFVQJ00YXFP<0011X>@03001/>F`i00Q/>@<000Yoo`800000;goo00<007ooOol07Woo
00<007ooOol07Woo00@006AK000000IXFP8000QXFP8000=XFP<000aX>@03001/>F`i00I/>@<000ao
o`<00000<7oo00<007ooOol07Goo00<007ooOol07goo00<006QJJ5X026QJ0P0016QJ0P0026QJ0`00
26Pi00<006`iK3T016`i0`002goo10000goo000aOol00`00Oomoo`0LOol00`00Oomoo`0POol00`00
J5YXFP09J5X01000J5X000003FQJ0P001FPi00<006`iK3T00V`i0`002goo0`001goo000bOol2000L
Ool00`00Oomoo`0QOol00`00J5YXFP08J5X3000@J5X20002J3T01000K3U/>F`i0P002Woo10002Woo
000dOol00`00Oomoo`0IOol00`00Oomoo`0ROol00`00J5YXFP05J5X20003J5X00`00J5YXFP0@J5X0
0`00K3U/>@020008Ool4000>Ool003Eoo`03001oogoo01Qoo`03001oogoo02=oo`03001XFVQJ009X
FP8000IXFP8000mXFP<000Qoo`<0019oo`00=Woo00<007ooOol05goo00<007ooOol097oo00@006QJ
000000YXFP03001XFVQJ00YXFP8000Moo`@001Eoo`00=goo00<007ooOol05Woo00<007ooOol09Goo
00<006QJJ5X02fQJ0P0026QJ0P001Goo10006Goo000hOol2000FOol00`00Oomoo`0VOol00`00J5YX
FP0<J5X00`00J5YXFP03J5X00`00Oomoo`03Ool3000MOol003Yoo`03001oogoo01=oo`03001oogoo
02Moo`03001XFVQJ00]XFP<00003J5Yoogoo009oo`@0021oo`00>goo00<007ooOol04Woo00<007oo
Ool0:7oo00<006QJJ5X026QJ0P0017oo100097oo000lOol00`00Oomoo`0@Ool00`00Oomoo`0ZOol0
0`00J5YXFP04J5X30002Ool4000XOol003eoo`80011oo`03001oogoo02]oo`04001XFVQJJ5X20002
Ool3000/Ool003moo`03001oogoo00eoo`03001oogoo02aoo`L002moo`00@7oo00<007ooOol037oo
00<007ooOol0:goo1000<goo0011Ool00`00Oomoo`0;Ool00`00Oomoo`0XOol3000gOol0049oo`03
001oogoo00Yoo`03001oogoo02Aoo`@003Yoo`00@goo0P002Woo00<007ooOol087oo1000?Woo0015
Ool00`00Oomoo`07Ool00`00Oomoo`0LOol40012Ool004Ioo`03001oogoo00Ioo`03001oogoo01Uo
o`<004Ioo`00Agoo00<007ooOol01Goo00<007ooOol05Goo1000BGoo0018Ool00`00Oomoo`04Ool0
0`00Oomoo`0AOol4001=Ool004Uoo`8000Aoo`03001oogoo00ioo`<0055oo`00Bgoo00D007ooOomo
o`0000aoo`@005Aoo`00C7oo00@007ooOol000Qoo`@005Qoo`00CGoo00<007oo00001Goo0`00G7oo
001>Ool200000goo00000002001OOol004moo`8006=oo`00]7oo002dOol00;Aoo`00\
\>"],
  ImageRangeCache->{{{0, 179}, {143.25, 0}} -> {-0.0530639, 0.0500459, \
0.00560143, 0.00560143}}]
}, Closed]],

Cell[TextData[{
  "If we had defined ",
  Cell[BoxData[
      \(TraditionalForm\`ln(z)\)],
    FormatType->StandardForm],
  " to mean the inverse of the function graphed above, then ",
  Cell[BoxData[
      \(TraditionalForm\`ln(z)\)],
    FormatType->StandardForm],
  " would have a branch cut running along the positive imaginary axis, since \
that is where this jump discontinuity lies. Such a definition of ",
  Cell[BoxData[
      \(TraditionalForm\`ln(z)\)],
    FormatType->StandardForm],
  " would be literally unconventional; the branch cut is usually placed on \
the negative real axis, as in the previous illustration, by mathematical \
convention."
}], "Text"],

Cell[TextData[{
  "The branch cut of ",
  Cell[BoxData[
      \(TraditionalForm\`\@z\)],
    FormatType->StandardForm],
  " arises in a similar way. This time, we start with the inverse function ",
  Cell[BoxData[
      \(TraditionalForm\`z\^2\)],
    FormatType->StandardForm],
  ", which maps the right half-plane ",
  Cell[BoxData[
      \(TraditionalForm\`Re(z) \[GreaterEqual] 0\)],
    FormatType->StandardForm],
  " onto the whole complex plane, leaving a branch cut along the negative \
imaginary axis."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot3D[
        Evaluate[{Re[\((w\_r + \[ImaginaryI]\ w\_i)\)\^2], 
            Im[\((w\_r + \[ImaginaryI]\ w\_i)\)\^2], w\_i}], {w\_r, 0, 
          2}, {w\_i, \(-2\), 2}];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92684 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.70448e-16 1.07815 -0.0240652 1.07815 [
[.02648 .17501 -10.2923 -7 ]
[.02648 .17501 .08272 0 ]
[.13889 .13172 -10.2069 -7 ]
[.13889 .13172 .35563 0 ]
[.25462 .08715 -6.64323 -7 ]
[.25462 .08715 .41927 0 ]
[.37384 .04125 -6.51893 -7 ]
[.37384 .04125 .60607 0 ]
[.49669 -0.00604 -6.16911 -7 ]
[.49669 -0.00604 .76839 0 ]
[.64055 .13884 0 -4.76502 ]
[.64055 .13884 10.625 2.23498 ]
[.78661 .32783 0 -4.66513 ]
[.78661 .32783 7.0625 2.33487 ]
[.91539 .49448 0 -4.57987 ]
[.91539 .49448 7.1875 2.42013 ]
[.01175 .19871 -10.5625 -2.15885 ]
[.01175 .19871 0 4.84115 ]
[.00599 .24966 -10.3125 -2.18103 ]
[.00599 .24966 0 4.81897 ]
[.00011 .30175 -7.0625 -2.20375 ]
[.00011 .30175 0 4.79625 ]
[-0.00591 .35503 -6.875 -2.22702 ]
[-0.00591 .35503 0 4.77298 ]
[-0.01207 .40954 -7.125 -2.25086 ]
[-0.01207 .40954 0 4.74914 ]
[ 0 0 0 0 ]
[ 1 .92684 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0249 .18885 m
.51694 0 L
s
.03593 .18462 m
.04065 .18942 L
s
gsave
.02648 .17501 -71.2923 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.14808 .14157 m
.15267 .1465 L
s
gsave
.13889 .13172 -71.2069 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.26353 .09726 m
.26799 .10232 L
s
gsave
.25462 .08715 -67.6432 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.38244 .05162 m
.38675 .05681 L
s
gsave
.37384 .04125 -67.5189 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.50496 .0046 m
.5091 .00991 L
s
gsave
.49669 -0.00604 -67.1691 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.06366 .17397 m
.06648 .17687 L
s
.0916 .16325 m
.0944 .16617 L
s
.11974 .15245 m
.12251 .15539 L
s
.17663 .13062 m
.17936 .13359 L
s
.20538 .11958 m
.2081 .12257 L
s
.23435 .10846 m
.23705 .11147 L
s
.29293 .08598 m
.29558 .08903 L
s
.32255 .07461 m
.32518 .07768 L
s
.35238 .06316 m
.35499 .06625 L
s
.41273 .04 m
.41529 .04313 L
s
.44324 .02829 m
.44578 .03144 L
s
.47399 .01649 m
.4765 .01966 L
s
.25 Mabswid
.51694 0 m
.98167 .60079 L
s
.62788 .14342 m
.62154 .14571 L
s
gsave
.64055 .13884 -61 -8.76502 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.77382 .33208 m
.76743 .33421 L
s
gsave
.78661 .32783 -61 -8.66513 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.90251 .49845 m
.89607 .50044 L
s
gsave
.91539 .49448 -61 -8.57987 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.65861 .18315 m
.6548 .1845 L
s
.68854 .22184 m
.68472 .22317 L
s
.7177 .25953 m
.71388 .26085 L
s
.74612 .29627 m
.74229 .29757 L
s
.80083 .36701 m
.79699 .36827 L
s
.82719 .40108 m
.82334 .40232 L
s
.8529 .43432 m
.84905 .43555 L
s
.878 .46677 m
.87415 .46798 L
s
.59631 .10261 m
.59252 .10401 L
s
.56388 .06068 m
.56009 .0621 L
s
.53054 .01758 m
.52676 .01902 L
s
.92645 .52939 m
.92258 .53057 L
s
.94983 .55962 m
.94596 .56078 L
s
.97268 .58916 m
.9688 .59031 L
s
.25 Mabswid
.0249 .18885 m
0 .41054 L
s
.02433 .19389 m
.03063 .19148 L
s
gsave
.01175 .19871 -71.5625 -6.15885 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.0186 .24491 m
.02491 .24253 L
s
gsave
.00599 .24966 -71.3125 -6.18103 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.01274 .29707 m
.01906 .29473 L
s
gsave
.00011 .30175 -68.0625 -6.20375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.00675 .35043 m
.01308 .34812 L
s
gsave
-0.00591 .35503 -67.875 -6.22702 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.00062 .40501 m
.00697 .40274 L
s
gsave
-0.01207 .40954 -68.125 -6.25086 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.0232 .204 m
.02698 .20256 L
s
.02206 .21416 m
.02584 .21272 L
s
.02091 .22436 m
.02469 .22293 L
s
.01976 .23461 m
.02354 .23318 L
s
.01744 .25525 m
.02123 .25383 L
s
.01628 .26563 m
.02006 .26422 L
s
.0151 .27607 m
.01889 .27465 L
s
.01393 .28655 m
.01772 .28514 L
s
.01156 .30765 m
.01535 .30625 L
s
.01036 .31827 m
.01416 .31687 L
s
.00917 .32894 m
.01296 .32755 L
s
.00796 .33966 m
.01176 .33827 L
s
.00554 .36124 m
.00934 .35987 L
s
.00432 .37211 m
.00812 .37074 L
s
.00309 .38303 m
.00689 .38166 L
s
.00186 .39399 m
.00566 .39263 L
s
.25 Mabswid
.0249 .18885 m
0 .41054 L
s
0 .41054 m
.55678 .92684 L
s
.55678 .92684 m
.55611 .72586 L
s
.55611 .72586 m
.0249 .18885 L
s
.51694 0 m
.98167 .60079 L
s
.98167 .60079 m
1 .80739 L
s
1 .80739 m
.51579 .22681 L
s
.51579 .22681 m
.51694 0 L
s
.0249 .18885 m
0 .41054 L
s
0 .41054 m
.51579 .22681 L
s
.51579 .22681 m
.51694 0 L
s
.51694 0 m
.0249 .18885 L
s
.55611 .72586 m
.98167 .60079 L
s
.98167 .60079 m
1 .80739 L
s
1 .80739 m
.55678 .92684 L
s
.55678 .92684 m
.55611 .72586 L
s
0 0 m
1 0 L
1 .92684 L
0 .92684 L
closepath
clip
newpath
.5 Mabswid
.76248 .85302 m .70711 .84366 L .72565 .80794 L p .819 .059 .795 r
F P
0 g
s
.72565 .80794 m .77988 .81582 L .76248 .85302 L p .819 .059 .795 r
F P
0 g
s
.70711 .84366 m .65477 .83326 L .67457 .79902 L p .815 .06 .798 r
F P
0 g
s
.67457 .79902 m .72565 .80794 L .70711 .84366 L p .815 .06 .798 r
F P
0 g
s
.65477 .83326 m .60544 .82179 L .62661 .78904 L p .81 .06 .801 r
F P
0 g
s
.62661 .78904 m .67457 .79902 L .65477 .83326 L p .81 .06 .801 r
F P
0 g
s
.77988 .81582 m .72565 .80794 L .74128 .77243 L p .819 .058 .79 r
F P
0 g
s
.74128 .77243 m .79438 .77873 L .77988 .81582 L p .819 .058 .79 r
F P
0 g
s
.60544 .82179 m .55909 .80921 L .58176 .77796 L p .805 .061 .806 r
F P
0 g
s
.58176 .77796 m .62661 .78904 L .60544 .82179 L p .805 .061 .806 r
F P
0 g
s
.72565 .80794 m .67457 .79902 L .69147 .76508 L p .814 .059 .793 r
F P
0 g
s
.69147 .76508 m .74128 .77243 L .72565 .80794 L p .814 .059 .793 r
F P
0 g
s
.67457 .79902 m .62661 .78904 L .64489 .75666 L p .809 .059 .797 r
F P
0 g
s
.64489 .75666 m .69147 .76508 L .67457 .79902 L p .809 .059 .797 r
F P
0 g
s
.55909 .80921 m .51571 .7955 L .54 .76576 L p .8 .062 .812 r
F P
0 g
s
.54 .76576 m .58176 .77796 L .55909 .80921 L p .8 .062 .812 r
F P
0 g
s
.79438 .77873 m .74128 .77243 L .75392 .73717 L p .82 .057 .785 r
F P
0 g
s
.75392 .73717 m .80586 .74181 L .79438 .77873 L p .82 .057 .785 r
F P
0 g
s
.62661 .78904 m .58176 .77796 L .60154 .74715 L p .804 .06 .801 r
F P
0 g
s
.60154 .74715 m .64489 .75666 L .62661 .78904 L p .804 .06 .801 r
F P
0 g
s
.74128 .77243 m .69147 .76508 L .70538 .73147 L p .815 .058 .788 r
F P
0 g
s
.70538 .73147 m .75392 .73717 L .74128 .77243 L p .815 .058 .788 r
F P
0 g
s
.51571 .7955 m .47531 .78062 L .50133 .7524 L p .794 .064 .818 r
F P
0 g
s
.50133 .7524 m .54 .76576 L .51571 .7955 L p .794 .064 .818 r
F P
0 g
s
.69147 .76508 m .64489 .75666 L .66019 .7247 L p .809 .058 .791 r
F P
0 g
s
.66019 .7247 m .70538 .73147 L .69147 .76508 L p .809 .058 .791 r
F P
0 g
s
.58176 .77796 m .54 .76576 L .56139 .73654 L p .798 .061 .807 r
F P
0 g
s
.56139 .73654 m .60154 .74715 L .58176 .77796 L p .798 .061 .807 r
F P
0 g
s
.34229 .46057 m .36133 .48252 L .3271 .48555 L p .976 .043 .716 r
F P
0 g
s
.3271 .48555 m .30589 .46172 L .34229 .46057 L p .976 .043 .716 r
F P
0 g
s
.64489 .75666 m .60154 .74715 L .61834 .71685 L p .803 .059 .796 r
F P
0 g
s
.61834 .71685 m .66019 .7247 L .64489 .75666 L p .803 .059 .796 r
F P
0 g
s
.80586 .74181 m .75392 .73717 L .76346 .7022 L p .821 .056 .78 r
F P
0 g
s
.76346 .7022 m .81422 .7051 L .80586 .74181 L p .821 .056 .78 r
F P
0 g
s
.47531 .78062 m .43789 .76453 L .46574 .73785 L p .789 .065 .826 r
F P
0 g
s
.46574 .73785 m .50133 .7524 L .47531 .78062 L p .789 .065 .826 r
F P
0 g
s
.54 .76576 m .50133 .7524 L .52443 .72478 L p .791 .063 .814 r
F P
0 g
s
.52443 .72478 m .56139 .73654 L .54 .76576 L p .791 .063 .814 r
F P
0 g
s
.75392 .73717 m .70538 .73147 L .71621 .69824 L p .815 .056 .782 r
F P
0 g
s
.71621 .69824 m .76346 .7022 L .75392 .73717 L p .815 .056 .782 r
F P
0 g
s
.60154 .74715 m .56139 .73654 L .57979 .70789 L p .796 .06 .802 r
F P
0 g
s
.57979 .70789 m .61834 .71685 L .60154 .74715 L p .796 .06 .802 r
F P
0 g
s
.70538 .73147 m .66019 .7247 L .67242 .69321 L p .809 .057 .785 r
F P
0 g
s
.67242 .69321 m .71621 .69824 L .70538 .73147 L p .809 .057 .785 r
F P
0 g
s
.37587 .46047 m .39278 .48051 L .36133 .48252 L p .988 .041 .705 r
F P
0 g
s
.36133 .48252 m .34229 .46057 L .37587 .46047 L p .988 .041 .705 r
F P
0 g
s
.50133 .7524 m .46574 .73785 L .49066 .71184 L p .785 .065 .823 r
F P
0 g
s
.49066 .71184 m .52443 .72478 L .50133 .7524 L p .785 .065 .823 r
F P
0 g
s
.43789 .76453 m .40345 .74718 L .43325 .72207 L p .784 .067 .835 r
F P
0 g
s
.43325 .72207 m .46574 .73785 L .43789 .76453 L p .784 .067 .835 r
F P
0 g
s
.66019 .7247 m .61834 .71685 L .63207 .68708 L p .803 .058 .789 r
F P
0 g
s
.63207 .68708 m .67242 .69321 L .66019 .7247 L p .803 .058 .789 r
F P
0 g
s
.32643 .43707 m .34229 .46057 L .30589 .46172 L p .97 .042 .711 r
F P
0 g
s
.30589 .46172 m .28776 .43628 L .32643 .43707 L p .97 .042 .711 r
F P
0 g
s
.56139 .73654 m .52443 .72478 L .54453 .69779 L p .788 .062 .809 r
F P
0 g
s
.54453 .69779 m .57979 .70789 L .56139 .73654 L p .788 .062 .809 r
F P
0 g
s
.81422 .7051 m .76346 .7022 L .76979 .6676 L p .823 .055 .773 r
F P
0 g
s
.76979 .6676 m .81935 .66865 L .81422 .7051 L p .823 .055 .773 r
F P
0 g
s
.40656 .46145 m .42138 .47953 L .39278 .48051 L p 1 .038 .692 r
F P
0 g
s
.39278 .48051 m .37587 .46047 L .40656 .46145 L p 1 .038 .692 r
F P
0 g
s
.61834 .71685 m .57979 .70789 L .59513 .67985 L p .795 .059 .795 r
F P
0 g
s
.59513 .67985 m .63207 .68708 L .61834 .71685 L p .795 .059 .795 r
F P
0 g
s
.76346 .7022 m .71621 .69824 L .72386 .66546 L p .817 .055 .775 r
F P
0 g
s
.72386 .66546 m .76979 .6676 L .76346 .7022 L p .817 .055 .775 r
F P
0 g
s
.52443 .72478 m .49066 .71184 L .51256 .68654 L p .781 .064 .818 r
F P
0 g
s
.51256 .68654 m .54453 .69779 L .52443 .72478 L p .781 .064 .818 r
F P
0 g
s
.46574 .73785 m .43325 .72207 L .46009 .6977 L p .778 .067 .833 r
F P
0 g
s
.46009 .6977 m .49066 .71184 L .46574 .73785 L p .778 .067 .833 r
F P
0 g
s
.71621 .69824 m .67242 .69321 L .68149 .66223 L p .811 .055 .777 r
F P
0 g
s
.68149 .66223 m .72386 .66546 L .71621 .69824 L p .811 .055 .777 r
F P
0 g
s
.36224 .43895 m .37587 .46047 L .34229 .46057 L p .981 .04 .7 r
F P
0 g
s
.34229 .46057 m .32643 .43707 L .36224 .43895 L p .981 .04 .7 r
F P
0 g
s
.57979 .70789 m .54453 .69779 L .56156 .67149 L p .786 .061 .803 r
F P
0 g
s
.56156 .67149 m .59513 .67985 L .57979 .70789 L p .786 .061 .803 r
F P
0 g
s
.40345 .74718 m .37203 .72851 L .40388 .70501 L p .779 .069 .845 r
F P
0 g
s
.40388 .70501 m .43325 .72207 L .40345 .74718 L p .779 .069 .845 r
F P
0 g
s
.67242 .69321 m .63207 .68708 L .64266 .6579 L p .803 .056 .781 r
F P
0 g
s
.64266 .6579 m .68149 .66223 L .67242 .69321 L p .803 .056 .781 r
F P
0 g
s
.43427 .46352 m .44703 .4796 L .42138 .47953 L p 1 .035 .674 r
F P
0 g
s
.42138 .47953 m .40656 .46145 L .43427 .46352 L p 1 .035 .674 r
F P
0 g
s
.31381 .41195 m .32643 .43707 L .28776 .43628 L p .963 .042 .708 r
F P
0 g
s
.28776 .43628 m .27277 .40915 L .31381 .41195 L p .963 .042 .708 r
F P
0 g
s
.63207 .68708 m .59513 .67985 L .60732 .65247 L p .795 .057 .787 r
F P
0 g
s
.60732 .65247 m .64266 .6579 L .63207 .68708 L p .795 .057 .787 r
F P
0 g
s
.39509 .44194 m .40656 .46145 L .37587 .46047 L p .993 .037 .686 r
F P
0 g
s
.37587 .46047 m .36224 .43895 L .39509 .44194 L p .993 .037 .686 r
F P
0 g
s
.49066 .71184 m .46009 .6977 L .48388 .6741 L p .773 .066 .83 r
F P
0 g
s
.48388 .6741 m .51256 .68654 L .49066 .71184 L p .773 .066 .83 r
F P
0 g
s
.54453 .69779 m .51256 .68654 L .53138 .66199 L p .777 .063 .813 r
F P
0 g
s
.53138 .66199 m .56156 .67149 L .54453 .69779 L p .777 .063 .813 r
F P
0 g
s
.43325 .72207 m .40388 .70501 L .43273 .68231 L p .772 .069 .844 r
F P
0 g
s
.43273 .68231 m .46009 .6977 L .43325 .72207 L p .772 .069 .844 r
F P
0 g
s
.81935 .66865 m .76979 .6676 L .77284 .63339 L p .825 .053 .767 r
F P
0 g
s
.77284 .63339 m .82116 .63252 L .81935 .66865 L p .825 .053 .767 r
F P
0 g
s
.76979 .6676 m .72386 .66546 L .72825 .63315 L p .82 .054 .768 r
F P
0 g
s
.72825 .63315 m .77284 .63339 L .76979 .6676 L p .82 .054 .768 r
F P
0 g
s
.59513 .67985 m .56156 .67149 L .57546 .64592 L p .785 .059 .794 r
F P
0 g
s
.57546 .64592 m .60732 .65247 L .59513 .67985 L p .785 .059 .794 r
F P
0 g
s
.45893 .46668 m .46968 .48074 L .44703 .4796 L p 1 .03 .651 r
F P
0 g
s
.44703 .4796 m .43427 .46352 L .45893 .46668 L p 1 .03 .651 r
F P
0 g
s
.72386 .66546 m .68149 .66223 L .68733 .63181 L p .813 .054 .769 r
F P
0 g
s
.68733 .63181 m .72825 .63315 L .72386 .66546 L p .813 .054 .769 r
F P
0 g
s
.35193 .41588 m .36224 .43895 L .32643 .43707 L p .972 .039 .697 r
F P
0 g
s
.32643 .43707 m .31381 .41195 L .35193 .41588 L p .972 .039 .697 r
F P
0 g
s
.68149 .66223 m .64266 .6579 L .65003 .62936 L p .805 .054 .772 r
F P
0 g
s
.65003 .62936 m .68733 .63181 L .68149 .66223 L p .805 .054 .772 r
F P
0 g
s
.37203 .72851 m .34365 .70848 L .37765 .68662 L p .775 .071 .855 r
F P
0 g
s
.37765 .68662 m .40388 .70501 L .37203 .72851 L p .775 .071 .855 r
F P
0 g
s
.42492 .44605 m .43427 .46352 L .40656 .46145 L p 1 .034 .669 r
F P
0 g
s
.40656 .46145 m .39509 .44194 L .42492 .44605 L p 1 .034 .669 r
F P
0 g
s
.51256 .68654 m .48388 .6741 L .50457 .65131 L p .767 .065 .825 r
F P
0 g
s
.50457 .65131 m .53138 .66199 L .51256 .68654 L p .767 .065 .825 r
F P
0 g
s
.56156 .67149 m .53138 .66199 L .54705 .63822 L p .774 .061 .804 r
F P
0 g
s
.54705 .63822 m .57546 .64592 L .56156 .67149 L p .774 .061 .804 r
F P
0 g
s
.64266 .6579 m .60732 .65247 L .61631 .6258 L p .796 .055 .776 r
F P
0 g
s
.61631 .6258 m .65003 .62936 L .64266 .6579 L p .796 .055 .776 r
F P
0 g
s
.46009 .6977 m .43273 .68231 L .45851 .66043 L p .765 .069 .843 r
F P
0 g
s
.45851 .66043 m .48388 .6741 L .46009 .6977 L p .765 .069 .843 r
F P
0 g
s
.48048 .47095 m .48924 .48297 L .46968 .48074 L p 1 .024 .618 r
F P
0 g
s
.46968 .48074 m .45893 .46668 L .48048 .47095 L p 1 .024 .618 r
F P
0 g
s
.38703 .42094 m .39509 .44194 L .36224 .43895 L p .981 .037 .684 r
F P
0 g
s
.36224 .43895 m .35193 .41588 L .38703 .42094 L p .981 .037 .684 r
F P
0 g
s
.60732 .65247 m .57546 .64592 L .58615 .62111 L p .785 .057 .783 r
F P
0 g
s
.58615 .62111 m .61631 .6258 L .60732 .65247 L p .785 .057 .783 r
F P
0 g
s
.40388 .70501 m .37765 .68662 L .40861 .66562 L p .767 .071 .857 r
F P
0 g
s
.40861 .66562 m .43273 .68231 L .40388 .70501 L p .767 .071 .857 r
F P
0 g
s
.45167 .45127 m .45893 .46668 L .43427 .46352 L p 1 .029 .646 r
F P
0 g
s
.43427 .46352 m .42492 .44605 L .45167 .45127 L p 1 .029 .646 r
F P
0 g
s
.30451 .38513 m .31381 .41195 L .27277 .40915 L p .955 .041 .707 r
F P
0 g
s
.27277 .40915 m .26099 .38024 L .30451 .38513 L p .955 .041 .707 r
F P
0 g
s
.53138 .66199 m .50457 .65131 L .5221 .62937 L p .762 .064 .818 r
F P
0 g
s
.5221 .62937 m .54705 .63822 L .53138 .66199 L p .762 .064 .818 r
F P
0 g
s
.48388 .6741 m .45851 .66043 L .48115 .63943 L p .758 .068 .841 r
F P
0 g
s
.48115 .63943 m .50457 .65131 L .48388 .6741 L p .758 .068 .841 r
F P
0 g
s
.82116 .63252 m .77284 .63339 L .77252 .59963 L p .829 .052 .76 r
F P
0 g
s
.77284 .63339 m .72825 .63315 L .72931 .60139 L p .823 .052 .76 r
F P
0 g
s
.72931 .60139 m .77252 .59963 L .77284 .63339 L p .823 .052 .76 r
F P
0 g
s
.72825 .63315 m .68733 .63181 L .68985 .60201 L p .817 .052 .76 r
F P
0 g
s
.68985 .60201 m .72931 .60139 L .72825 .63315 L p .817 .052 .76 r
F P
0 g
s
.77252 .59963 m .81956 .59675 L .82116 .63252 L p .829 .052 .76 r
F P
0 g
s
.57546 .64592 m .54705 .63822 L .55951 .61528 L p .772 .059 .794 r
F P
0 g
s
.55951 .61528 m .58615 .62111 L .57546 .64592 L p .772 .059 .794 r
F P
0 g
s
.68733 .63181 m .65003 .62936 L .65411 .60151 L p .809 .052 .761 r
F P
0 g
s
.65411 .60151 m .68985 .60201 L .68733 .63181 L p .809 .052 .761 r
F P
0 g
s
.49886 .47633 m .50565 .48629 L .48924 .48297 L p 1 .014 .571 r
F P
0 g
s
.48924 .48297 m .48048 .47095 L .49886 .47633 L p 1 .014 .571 r
F P
0 g
s
.41906 .42714 m .42492 .44605 L .39509 .44194 L p .992 .034 .668 r
F P
0 g
s
.39509 .44194 m .38703 .42094 L .41906 .42714 L p .992 .034 .668 r
F P
0 g
s
.65003 .62936 m .61631 .6258 L .62203 .59988 L p .799 .053 .764 r
F P
0 g
s
.62203 .59988 m .65411 .60151 L .65003 .62936 L p .799 .053 .764 r
F P
0 g
s
.43273 .68231 m .40861 .66562 L .43645 .64551 L p .759 .072 .858 r
F P
0 g
s
.43645 .64551 m .45851 .66043 L .43273 .68231 L p .759 .072 .858 r
F P
0 g
s
.34365 .70848 m .31834 .68702 L .3546 .66685 L p .772 .073 .866 r
F P
0 g
s
.3546 .66685 m .37765 .68662 L .34365 .70848 L p .772 .073 .866 r
F P
0 g
s
.47526 .45762 m .48048 .47095 L .45893 .46668 L p 1 .023 .617 r
F P
0 g
s
.45893 .46668 m .45167 .45127 L .47526 .45762 L p 1 .023 .617 r
F P
0 g
s
.34502 .39117 m .35193 .41588 L .31381 .41195 L p .962 .039 .697 r
F P
0 g
s
.31381 .41195 m .30451 .38513 L .34502 .39117 L p .962 .039 .697 r
F P
0 g
s
.61631 .6258 m .58615 .62111 L .59357 .59711 L p .787 .054 .77 r
F P
0 g
s
.59357 .59711 m .62203 .59988 L .61631 .6258 L p .787 .054 .77 r
F P
0 g
s
.54705 .63822 m .5221 .62937 L .5364 .6083 L p .757 .062 .808 r
F P
0 g
s
.5364 .6083 m .55951 .61528 L .54705 .63822 L p .757 .062 .808 r
F P
0 g
s
.50457 .65131 m .48115 .63943 L .5006 .61932 L p .749 .067 .836 r
F P
0 g
s
.5006 .61932 m .5221 .62937 L .50457 .65131 L p .749 .067 .836 r
F P
0 g
s
.58615 .62111 m .55951 .61528 L .56872 .59321 L p .773 .056 .779 r
F P
0 g
s
.56872 .59321 m .59357 .59711 L .58615 .62111 L p .773 .056 .779 r
F P
0 g
s
.44794 .43448 m .45167 .45127 L .42492 .44605 L p 1 .03 .649 r
F P
0 g
s
.42492 .44605 m .41906 .42714 L .44794 .43448 L p 1 .03 .649 r
F P
0 g
s
.51401 .48283 m .51887 .49072 L .50565 .48629 L p 1 0 .5 r
F P
0 g
s
.50565 .48629 m .49886 .47633 L .51401 .48283 L p 1 0 .5 r
F P
0 g
s
.45851 .66043 m .43645 .64551 L .46113 .62631 L p .749 .072 .859 r
F P
0 g
s
.46113 .62631 m .48115 .63943 L .45851 .66043 L p .749 .072 .859 r
F P
0 g
s
.37765 .68662 m .3546 .66685 L .38776 .64759 L p .764 .074 .87 r
F P
0 g
s
.38776 .64759 m .40861 .66562 L .37765 .68662 L p .764 .074 .87 r
F P
0 g
s
.49564 .4651 m .49886 .47633 L .48048 .47095 L p 1 .016 .578 r
F P
0 g
s
.48048 .47095 m .47526 .45762 L .49564 .4651 L p 1 .016 .578 r
F P
0 g
s
.38245 .39838 m .38703 .42094 L .35193 .41588 L p .968 .037 .685 r
F P
0 g
s
.35193 .41588 m .34502 .39117 L .38245 .39838 L p .968 .037 .685 r
F P
0 g
s
.5221 .62937 m .5006 .61932 L .51682 .60015 L p .741 .066 .829 r
F P
0 g
s
.51682 .60015 m .5364 .6083 L .5221 .62937 L p .741 .066 .829 r
F P
0 g
s
.72931 .60139 m .68985 .60201 L .689 .57287 L p .822 .05 .75 r
F P
0 g
s
.68985 .60201 m .65411 .60151 L .65484 .57438 L p .814 .05 .75 r
F P
0 g
s
.65484 .57438 m .689 .57287 L .68985 .60201 L p .814 .05 .75 r
F P
0 g
s
.55951 .61528 m .5364 .6083 L .54745 .58816 L p .755 .059 .794 r
F P
0 g
s
.54745 .58816 m .56872 .59321 L .55951 .61528 L p .755 .059 .794 r
F P
0 g
s
.65411 .60151 m .62203 .59988 L .62442 .57474 L p .805 .05 .75 r
F P
0 g
s
.62442 .57474 m .65484 .57438 L .65411 .60151 L p .805 .05 .75 r
F P
0 g
s
.77252 .59963 m .72931 .60139 L .72694 .57021 L p .828 .05 .751 r
F P
0 g
s
.689 .57287 m .72694 .57021 L .72931 .60139 L p .822 .05 .75 r
F P
0 g
s
.62203 .59988 m .59357 .59711 L .59769 .57396 L p .793 .051 .753 r
F P
0 g
s
.59769 .57396 m .62442 .57474 L .62203 .59988 L p .793 .051 .753 r
F P
0 g
s
.47363 .44296 m .47526 .45762 L .45167 .45127 L p 1 .025 .625 r
F P
0 g
s
.45167 .45127 m .44794 .43448 L .47363 .44296 L p 1 .025 .625 r
F P
0 g
s
.81956 .59675 m .77252 .59963 L .76874 .56639 L p .833 .051 .753 r
F P
0 g
s
.72694 .57021 m .76874 .56639 L .77252 .59963 L p .828 .05 .751 r
F P
0 g
s
.48115 .63943 m .46113 .62631 L .48258 .60807 L p .737 .072 .858 r
F P
0 g
s
.48258 .60807 m .5006 .61932 L .48115 .63943 L p .737 .072 .858 r
F P
0 g
s
.5259 .49045 m .52884 .49625 L .51887 .49072 L p 1 0 .5 r
F P
0 g
s
.51887 .49072 m .51401 .48283 L .5259 .49045 L p 1 0 .5 r
F P
0 g
s
.40861 .66562 m .38776 .64759 L .41776 .62927 L p .754 .075 .874 r
F P
0 g
s
.41776 .62927 m .43645 .64551 L .40861 .66562 L p .754 .075 .874 r
F P
0 g
s
.51278 .4737 m .51401 .48283 L .49886 .47633 L p 1 .005 .527 r
F P
0 g
s
.49886 .47633 m .49564 .4651 L .51278 .4737 L p 1 .005 .527 r
F P
0 g
s
.59357 .59711 m .56872 .59321 L .57462 .57204 L p .777 .052 .76 r
F P
0 g
s
.57462 .57204 m .59769 .57396 L .59357 .59711 L p .777 .052 .76 r
F P
0 g
s
.76874 .56639 m .81445 .5614 L .81956 .59675 L p .833 .051 .753 r
F P
0 g
s
.41674 .40674 m .41906 .42714 L .38703 .42094 L p .975 .034 .671 r
F P
0 g
s
.38703 .42094 m .38245 .39838 L .41674 .40674 L p .975 .034 .671 r
F P
0 g
s
.29861 .35653 m .30451 .38513 L .26099 .38024 L p .947 .041 .707 r
F P
0 g
s
.26099 .38024 m .25253 .34946 L .29861 .35653 L p .947 .041 .707 r
F P
0 g
s
.5364 .6083 m .51682 .60015 L .52975 .58194 L p .734 .063 .817 r
F P
0 g
s
.52975 .58194 m .54745 .58816 L .5364 .6083 L p .734 .063 .817 r
F P
0 g
s
.56872 .59321 m .54745 .58816 L .55518 .56896 L p .756 .055 .773 r
F P
0 g
s
.55518 .56896 m .57462 .57204 L .56872 .59321 L p .756 .055 .773 r
F P
0 g
s
.49606 .45257 m .49564 .4651 L .47526 .45762 L p 1 .019 .597 r
F P
0 g
s
.47526 .45762 m .47363 .44296 L .49606 .45257 L p 1 .019 .597 r
F P
0 g
s
.5006 .61932 m .48258 .60807 L .50076 .59081 L p .725 .071 .856 r
F P
0 g
s
.50076 .59081 m .51682 .60015 L .5006 .61932 L p .725 .071 .856 r
F P
0 g
s
.43645 .64551 m .41776 .62927 L .44453 .61192 L p .742 .076 .878 r
F P
0 g
s
.44453 .61192 m .46113 .62631 L .43645 .64551 L p .742 .076 .878 r
F P
0 g
s
.52662 .48343 m .5259 .49045 L .51401 .48283 L p 1 0 .5 r
F P
0 g
s
.51401 .48283 m .51278 .4737 L .52662 .48343 L p 1 0 .5 r
F P
0 g
s
.53449 .49918 m .53552 .50289 L .52884 .49625 L p 1 0 .5 r
F P
0 g
s
.52884 .49625 m .5259 .49045 L .53449 .49918 L p 1 0 .5 r
F P
0 g
s
.44782 .41625 m .44794 .43448 L .41906 .42714 L p .982 .031 .655 r
F P
0 g
s
.41906 .42714 m .41674 .40674 L .44782 .41625 L p .982 .031 .655 r
F P
0 g
s
.3416 .36477 m .34502 .39117 L .30451 .38513 L p .951 .04 .698 r
F P
0 g
s
.30451 .38513 m .29861 .35653 L .3416 .36477 L p .951 .04 .698 r
F P
0 g
s
.65484 .57438 m .62442 .57474 L .62344 .55044 L p .813 .047 .735 r
F P
0 g
s
.62442 .57474 m .59769 .57396 L .59845 .5517 L p .802 .047 .734 r
F P
0 g
s
.59845 .5517 m .62344 .55044 L .62442 .57474 L p .802 .047 .734 r
F P
0 g
s
.54745 .58816 m .52975 .58194 L .53937 .56472 L p .73 .059 .797 r
F P
0 g
s
.53937 .56472 m .55518 .56896 L .54745 .58816 L p .73 .059 .797 r
F P
0 g
s
.689 .57287 m .65484 .57438 L .65217 .54802 L p .822 .047 .737 r
F P
0 g
s
.62344 .55044 m .65217 .54802 L .65484 .57438 L p .813 .047 .735 r
F P
0 g
s
.59769 .57396 m .57462 .57204 L .57718 .5518 L p .786 .047 .737 r
F P
0 g
s
.57718 .5518 m .59845 .5517 L .59769 .57396 L p .786 .047 .737 r
F P
0 g
s
.5152 .46332 m .51278 .4737 L .49564 .4651 L p 1 .013 .564 r
F P
0 g
s
.49564 .4651 m .49606 .45257 L .5152 .46332 L p 1 .013 .564 r
F P
0 g
s
.51682 .60015 m .50076 .59081 L .51563 .57455 L p .711 .07 .85 r
F P
0 g
s
.51563 .57455 m .52975 .58194 L .51682 .60015 L p .711 .07 .85 r
F P
0 g
s
.72694 .57021 m .689 .57287 L .68471 .54443 L p .829 .048 .739 r
F P
0 g
s
.65217 .54802 m .68471 .54443 L .689 .57287 L p .822 .047 .737 r
F P
0 g
s
.57462 .57204 m .55518 .56896 L .55958 .55074 L p .764 .049 .745 r
F P
0 g
s
.55958 .55074 m .57718 .5518 L .57462 .57204 L p .764 .049 .745 r
F P
0 g
s
.46113 .62631 m .44453 .61192 L .46804 .59557 L p .728 .077 .884 r
F P
0 g
s
.46804 .59557 m .48258 .60807 L .46113 .62631 L p .728 .077 .884 r
F P
0 g
s
.53714 .49427 m .53449 .49918 L .5259 .49045 L p 1 0 .5 r
F P
0 g
s
.5259 .49045 m .52662 .48343 L .53714 .49427 L p 1 0 .5 r
F P
0 g
s
.53975 .50902 m .53887 .51065 L .53552 .50289 L p 1 0 .5 r
F P
0 g
s
.53552 .50289 m .53449 .49918 L .53975 .50902 L p 1 0 .5 r
F P
0 g
s
.47564 .42691 m .47363 .44296 L .44794 .43448 L p .987 .027 .637 r
F P
0 g
s
.44794 .43448 m .44782 .41625 L .47564 .42691 L p .987 .027 .637 r
F P
0 g
s
.76874 .56639 m .72694 .57021 L .7211 .53966 L p .834 .048 .742 r
F P
0 g
s
.68471 .54443 m .7211 .53966 L .72694 .57021 L p .829 .048 .739 r
F P
0 g
s
.55518 .56896 m .53937 .56472 L .54565 .54852 L p .734 .053 .765 r
F P
0 g
s
.54565 .54852 m .55958 .55074 L .55518 .56896 L p .734 .053 .765 r
F P
0 g
s
.53102 .47518 m .52662 .48343 L .51278 .4737 L p 1 .007 .534 r
F P
0 g
s
.51278 .4737 m .5152 .46332 L .53102 .47518 L p 1 .007 .534 r
F P
0 g
s
.52975 .58194 m .51563 .57455 L .52718 .55931 L p .697 .067 .837 r
F P
0 g
s
.52718 .55931 m .53937 .56472 L .52975 .58194 L p .697 .067 .837 r
F P
0 g
s
.38143 .37419 m .38245 .39838 L .34502 .39117 L p .956 .038 .688 r
F P
0 g
s
.34502 .39117 m .3416 .36477 L .38143 .37419 L p .956 .038 .688 r
F P
0 g
s
.48258 .60807 m .46804 .59557 L .48824 .58024 L p .71 .078 .889 r
F P
0 g
s
.48824 .58024 m .50076 .59081 L .48258 .60807 L p .71 .078 .889 r
F P
0 g
s
.54432 .50621 m .53975 .50902 L .53449 .49918 L p 1 0 .5 r
F P
0 g
s
.53449 .49918 m .53714 .49427 L .54432 .50621 L p 1 0 .5 r
F P
0 g
s
.81445 .5614 m .76874 .56639 L .76142 .5337 L p .838 .049 .745 r
F P
0 g
s
.7211 .53966 m .76142 .5337 L .76874 .56639 L p .834 .048 .742 r
F P
0 g
s
.50016 .43871 m .49606 .45257 L .47363 .44296 L p .989 .024 .618 r
F P
0 g
s
.47363 .44296 m .47564 .42691 L .50016 .43871 L p .989 .024 .618 r
F P
0 g
s
.59845 .5517 m .57718 .5518 L .57637 .53253 L p .802 .042 .709 r
F P
0 g
s
.57718 .5518 m .55958 .55074 L .56062 .53352 L p .783 .042 .708 r
F P
0 g
s
.56062 .53352 m .57637 .53253 L .57718 .5518 L p .783 .042 .708 r
F P
0 g
s
.62344 .55044 m .59845 .5517 L .59583 .53036 L p .816 .043 .713 r
F P
0 g
s
.57637 .53253 m .59583 .53036 L .59845 .5517 L p .802 .042 .709 r
F P
0 g
s
.54348 .48815 m .53714 .49427 L .52662 .48343 L p .999 .003 .516 r
F P
0 g
s
.52662 .48343 m .53102 .47518 L .54348 .48815 L p .999 .003 .516 r
F P
0 g
s
.54166 .51997 m .53887 .51952 L .53887 .51065 L p 1 0 .5 r
F P
0 g
s
.53887 .51065 m .53975 .50902 L .54166 .51997 L p 1 0 .5 r
F P
0 g
s
.53937 .56472 m .52718 .55931 L .53537 .54513 L p .689 .062 .809 r
F P
0 g
s
.53537 .54513 m .54565 .54852 L .53937 .56472 L p .689 .062 .809 r
F P
0 g
s
.55958 .55074 m .54565 .54852 L .54857 .53335 L p .752 .043 .717 r
F P
0 g
s
.54857 .53335 m .56062 .53352 L .55958 .55074 L p .752 .043 .717 r
F P
0 g
s
.65217 .54802 m .62344 .55044 L .61904 .52702 L p .825 .044 .719 r
F P
0 g
s
.59583 .53036 m .61904 .52702 L .62344 .55044 L p .816 .043 .713 r
F P
0 g
s
.50076 .59081 m .48824 .58024 L .50511 .56595 L p .688 .079 .895 r
F P
0 g
s
.50511 .56595 m .51563 .57455 L .50076 .59081 L p .688 .079 .895 r
F P
0 g
s
.54813 .51924 m .54166 .51997 L .53975 .50902 L p .89 0 .5 r
F P
0 g
s
.53975 .50902 m .54432 .50621 L .54813 .51924 L p .89 0 .5 r
F P
0 g
s
.55258 .50221 m .54432 .50621 L .53714 .49427 L p .941 .006 .529 r
F P
0 g
s
.53714 .49427 m .54348 .48815 L .55258 .50221 L p .941 .006 .529 r
F P
0 g
s
.54565 .54852 m .53537 .54513 L .5402 .53201 L p .7 .051 .753 r
F P
0 g
s
.5402 .53201 m .54857 .53335 L .54565 .54852 L p .7 .051 .753 r
F P
0 g
s
.41804 .38478 m .41674 .40674 L .38245 .39838 L p .96 .035 .677 r
F P
0 g
s
.38245 .39838 m .38143 .37419 L .41804 .38478 L p .96 .035 .677 r
F P
0 g
s
.68471 .54443 m .65217 .54802 L .64605 .52248 L p .832 .045 .724 r
F P
0 g
s
.61904 .52702 m .64605 .52248 L .65217 .54802 L p .825 .044 .719 r
F P
0 g
s
.52133 .45164 m .5152 .46332 L .49606 .45257 L p .985 .02 .598 r
F P
0 g
s
.49606 .45257 m .50016 .43871 L .52133 .45164 L p .985 .02 .598 r
F P
0 g
s
.76142 .5337 m .80575 .52653 L .81445 .5614 L p .838 .049 .745 r
F P
0 g
s
.51563 .57455 m .50511 .56595 L .51861 .55272 L p .662 .08 .898 r
F P
0 g
s
.51861 .55272 m .52718 .55931 L .51563 .57455 L p .662 .08 .898 r
F P
0 g
s
.54857 .53335 m .5402 .53201 L .54166 .51997 L p .757 .03 .648 r
F P
0 g
s
.54166 .51997 m .54813 .51924 L .54857 .53335 L p .757 .03 .648 r
F P
0 g
s
.53887 .51952 m .54166 .51997 L .5402 .53201 L p .646 .046 .731 r
F P
0 g
s
.57637 .53253 m .56062 .53352 L .55829 .51734 L p .814 .033 .666 r
F P
0 g
s
.56062 .53352 m .54857 .53335 L .54813 .51924 L p .795 .03 .652 r
F P
0 g
s
.54813 .51924 m .55829 .51734 L .56062 .53352 L p .795 .03 .652 r
F P
0 g
s
.55829 .51734 m .54813 .51924 L .54432 .50621 L p .864 .016 .581 r
F P
0 g
s
.54432 .50621 m .55258 .50221 L .55829 .51734 L p .864 .016 .581 r
F P
0 g
s
.5402 .53201 m .5355 .52949 L .53887 .51952 L p .646 .046 .731 r
F P
0 g
s
.59583 .53036 m .57637 .53253 L .57217 .51425 L p .826 .036 .68 r
F P
0 g
s
.55829 .51734 m .57217 .51425 L .57637 .53253 L p .814 .033 .666 r
F P
0 g
s
.52718 .55931 m .51861 .55272 L .52875 .54056 L p .63 .079 .896 r
F P
0 g
s
.52875 .54056 m .53537 .54513 L .52718 .55931 L p .63 .079 .896 r
F P
0 g
s
.5355 .52949 m .5402 .53201 L .53537 .54513 L p .602 .074 .868 r
F P
0 g
s
.53914 .46567 m .53102 .47518 L .5152 .46332 L p .972 .017 .584 r
F P
0 g
s
.5152 .46332 m .52133 .45164 L .53914 .46567 L p .972 .017 .584 r
F P
0 g
s
.53537 .54513 m .52875 .54056 L .5355 .52949 L p .602 .074 .868 r
F P
0 g
s
.57217 .51425 m .55829 .51734 L .55258 .50221 L p .857 .025 .624 r
F P
0 g
s
.7211 .53966 m .68471 .54443 L .67692 .51675 L p .837 .046 .729 r
F P
0 g
s
.64605 .52248 m .67692 .51675 L .68471 .54443 L p .832 .045 .724 r
F P
0 g
s
.61904 .52702 m .59583 .53036 L .58979 .50998 L p .834 .038 .692 r
F P
0 g
s
.57217 .51425 m .58979 .50998 L .59583 .53036 L p .826 .036 .68 r
F P
0 g
s
.55355 .4808 m .54348 .48815 L .53102 .47518 L p .945 .016 .58 r
F P
0 g
s
.53102 .47518 m .53914 .46567 L .55355 .4808 L p .945 .016 .58 r
F P
0 g
s
.45137 .39653 m .44782 .41625 L .41674 .40674 L p .963 .033 .664 r
F P
0 g
s
.41674 .40674 m .41804 .38478 L .45137 .39653 L p .963 .033 .664 r
F P
0 g
s
.55258 .50221 m .56456 .497 L .57217 .51425 L p .857 .025 .624 r
F P
0 g
s
.56456 .497 m .55258 .50221 L .54348 .48815 L p .904 .019 .593 r
F P
0 g
s
.54348 .48815 m .55355 .4808 L .56456 .497 L p .904 .019 .593 r
F P
0 g
s
.58979 .50998 m .57217 .51425 L .56456 .497 L p .856 .03 .652 r
F P
0 g
s
.2962 .32604 m .29861 .35653 L .25253 .34946 L p .939 .042 .709 r
F P
0 g
s
.25253 .34946 m .24746 .31671 L .2962 .32604 L p .939 .042 .709 r
F P
0 g
s
.64605 .52248 m .61904 .52702 L .61119 .5045 L p .839 .04 .702 r
F P
0 g
s
.58979 .50998 m .61119 .5045 L .61904 .52702 L p .834 .038 .692 r
F P
0 g
s
.76142 .5337 m .7211 .53966 L .71171 .5098 L p .841 .047 .734 r
F P
0 g
s
.67692 .51675 m .71171 .5098 L .7211 .53966 L p .837 .046 .729 r
F P
0 g
s
.48137 .40944 m .47564 .42691 L .44782 .41625 L p .963 .03 .651 r
F P
0 g
s
.44782 .41625 m .45137 .39653 L .48137 .40944 L p .963 .03 .651 r
F P
0 g
s
.56456 .497 m .58031 .49058 L .58979 .50998 L p .856 .03 .652 r
F P
0 g
s
.58031 .49058 m .56456 .497 L .55355 .4808 L p .887 .026 .631 r
F P
0 g
s
.61119 .5045 m .58979 .50998 L .58031 .49058 L p .855 .034 .672 r
F P
0 g
s
.508 .42348 m .50016 .43871 L .47564 .42691 L p .961 .028 .638 r
F P
0 g
s
.47564 .42691 m .48137 .40944 L .508 .42348 L p .961 .028 .638 r
F P
0 g
s
.67692 .51675 m .64605 .52248 L .63644 .4978 L p .843 .042 .711 r
F P
0 g
s
.61119 .5045 m .63644 .4978 L .64605 .52248 L p .839 .04 .702 r
F P
0 g
s
.55355 .4808 m .56739 .47221 L .58031 .49058 L p .887 .026 .631 r
F P
0 g
s
.56739 .47221 m .55355 .4808 L .53914 .46567 L p .916 .024 .621 r
F P
0 g
s
.34176 .33658 m .3416 .36477 L .29861 .35653 L p .942 .04 .701 r
F P
0 g
s
.29861 .35653 m .2962 .32604 L .34176 .33658 L p .942 .04 .701 r
F P
0 g
s
.53123 .43863 m .52133 .45164 L .50016 .43871 L p .953 .025 .626 r
F P
0 g
s
.50016 .43871 m .508 .42348 L .53123 .43863 L p .953 .025 .626 r
F P
0 g
s
.53914 .46567 m .55103 .45488 L .56739 .47221 L p .916 .024 .621 r
F P
0 g
s
.55103 .45488 m .53914 .46567 L .52133 .45164 L p .939 .024 .62 r
F P
0 g
s
.52133 .45164 m .53123 .43863 L .55103 .45488 L p .939 .024 .62 r
F P
0 g
s
.80575 .52653 m .76142 .5337 L .7505 .50162 L p .844 .048 .738 r
F P
0 g
s
.71171 .5098 m .7505 .50162 L .76142 .5337 L p .841 .047 .734 r
F P
0 g
s
.63644 .4978 m .61119 .5045 L .59987 .48293 L p .856 .038 .688 r
F P
0 g
s
.58031 .49058 m .59987 .48293 L .61119 .5045 L p .855 .034 .672 r
F P
0 g
s
.59987 .48293 m .58031 .49058 L .56739 .47221 L p .878 .031 .657 r
F P
0 g
s
.71171 .5098 m .67692 .51675 L .66559 .48987 L p .846 .044 .719 r
F P
0 g
s
.63644 .4978 m .66559 .48987 L .67692 .51675 L p .843 .042 .711 r
F P
0 g
s
.38406 .3483 m .38143 .37419 L .3416 .36477 L p .944 .039 .693 r
F P
0 g
s
.3416 .36477 m .34176 .33658 L .38406 .3483 L p .944 .039 .693 r
F P
0 g
s
.56739 .47221 m .58506 .46235 L .59987 .48293 L p .878 .031 .657 r
F P
0 g
s
.58506 .46235 m .56739 .47221 L .55103 .45488 L p .9 .03 .649 r
F P
0 g
s
.7505 .50162 m .79338 .49219 L .80575 .52653 L p .844 .048 .738 r
F P
0 g
s
.42305 .3612 m .41804 .38478 L .38143 .37419 L p .946 .037 .683 r
F P
0 g
s
.38143 .37419 m .38406 .3483 L .42305 .3612 L p .946 .037 .683 r
F P
0 g
s
.66559 .48987 m .63644 .4978 L .62331 .47403 L p .856 .04 .7 r
F P
0 g
s
.59987 .48293 m .62331 .47403 L .63644 .4978 L p .856 .038 .688 r
F P
0 g
s
.62331 .47403 m .59987 .48293 L .58506 .46235 L p .873 .035 .677 r
F P
0 g
s
.55103 .45488 m .56676 .44278 L .58506 .46235 L p .9 .03 .649 r
F P
0 g
s
.56676 .44278 m .55103 .45488 L .53123 .43863 L p .918 .029 .646 r
F P
0 g
s
.7505 .50162 m .71171 .5098 L .69872 .48068 L p .849 .045 .725 r
F P
0 g
s
.66559 .48987 m .69872 .48068 L .71171 .5098 L p .846 .044 .719 r
F P
0 g
s
.45867 .37527 m .45137 .39653 L .41804 .38478 L p .946 .035 .674 r
F P
0 g
s
.41804 .38478 m .42305 .3612 L .45867 .37527 L p .946 .035 .674 r
F P
0 g
s
.53123 .43863 m .54495 .42426 L .56676 .44278 L p .918 .029 .646 r
F P
0 g
s
.54495 .42426 m .53123 .43863 L .508 .42348 L p .931 .03 .649 r
F P
0 g
s
.49088 .39048 m .48137 .40944 L .45137 .39653 L p .944 .033 .664 r
F P
0 g
s
.45137 .39653 m .45867 .37527 L .49088 .39048 L p .944 .033 .664 r
F P
0 g
s
.508 .42348 m .51965 .40682 L .54495 .42426 L p .931 .03 .649 r
F P
0 g
s
.51965 .40682 m .508 .42348 L .48137 .40944 L p .94 .031 .655 r
F P
0 g
s
.48137 .40944 m .49088 .39048 L .51965 .40682 L p .94 .031 .655 r
F P
0 g
s
.58506 .46235 m .60663 .45119 L .62331 .47403 L p .873 .035 .677 r
F P
0 g
s
.60663 .45119 m .58506 .46235 L .56676 .44278 L p .89 .034 .669 r
F P
0 g
s
.69872 .48068 m .66559 .48987 L .65068 .46384 L p .857 .042 .71 r
F P
0 g
s
.62331 .47403 m .65068 .46384 L .66559 .48987 L p .856 .04 .7 r
F P
0 g
s
.65068 .46384 m .62331 .47403 L .60663 .45119 L p .87 .038 .691 r
F P
0 g
s
.79338 .49219 m .7505 .50162 L .73591 .47021 L p .851 .046 .731 r
F P
0 g
s
.69872 .48068 m .73591 .47021 L .7505 .50162 L p .849 .045 .725 r
F P
0 g
s
.56676 .44278 m .58639 .42933 L .60663 .45119 L p .89 .034 .669 r
F P
0 g
s
.58639 .42933 m .56676 .44278 L .54495 .42426 L p .904 .033 .666 r
F P
0 g
s
.29741 .29358 m .2962 .32604 L .24746 .31671 L p .931 .042 .712 r
F P
0 g
s
.24746 .31671 m .24592 .28187 L .29741 .29358 L p .931 .042 .712 r
F P
0 g
s
.73591 .47021 m .69872 .48068 L .68208 .45235 L p .858 .044 .718 r
F P
0 g
s
.65068 .46384 m .68208 .45235 L .69872 .48068 L p .857 .042 .71 r
F P
0 g
s
.54495 .42426 m .56258 .40849 L .58639 .42933 L p .904 .033 .666 r
F P
0 g
s
.56258 .40849 m .54495 .42426 L .51965 .40682 L p .916 .033 .667 r
F P
0 g
s
.60663 .45119 m .63217 .4387 L .65068 .46384 L p .87 .038 .691 r
F P
0 g
s
.63217 .4387 m .60663 .45119 L .58639 .42933 L p .883 .037 .685 r
F P
0 g
s
.34561 .3065 m .34176 .33658 L .2962 .32604 L p .933 .041 .705 r
F P
0 g
s
.2962 .32604 m .29741 .29358 L .34561 .3065 L p .933 .041 .705 r
F P
0 g
s
.73591 .47021 m .77727 .45843 L .79338 .49219 L p .851 .046 .731 r
F P
0 g
s
.68208 .45235 m .65068 .46384 L .63217 .4387 L p .868 .041 .703 r
F P
0 g
s
.51965 .40682 m .53521 .3887 L .56258 .40849 L p .916 .033 .667 r
F P
0 g
s
.53521 .3887 m .51965 .40682 L .49088 .39048 L p .924 .034 .67 r
F P
0 g
s
.39045 .32062 m .38406 .3483 L .34176 .33658 L p .934 .04 .698 r
F P
0 g
s
.34176 .33658 m .34561 .3065 L .39045 .32062 L p .934 .04 .698 r
F P
0 g
s
.49088 .39048 m .50429 .36999 L .53521 .3887 L p .924 .034 .67 r
F P
0 g
s
.50429 .36999 m .49088 .39048 L .45867 .37527 L p .93 .035 .676 r
F P
0 g
s
.43187 .33593 m .42305 .3612 L .38406 .3483 L p .934 .038 .69 r
F P
0 g
s
.38406 .3483 m .39045 .32062 L .43187 .33593 L p .934 .038 .69 r
F P
0 g
s
.45867 .37527 m .46983 .35239 L .50429 .36999 L p .93 .035 .676 r
F P
0 g
s
.46983 .35239 m .45867 .37527 L .42305 .3612 L p .933 .037 .683 r
F P
0 g
s
.42305 .3612 m .43187 .33593 L .46983 .35239 L p .933 .037 .683 r
F P
0 g
s
.58639 .42933 m .61001 .4145 L .63217 .4387 L p .883 .037 .685 r
F P
0 g
s
.61001 .4145 m .58639 .42933 L .56258 .40849 L p .895 .036 .682 r
F P
0 g
s
.77727 .45843 m .73591 .47021 L .71761 .43952 L p .858 .045 .725 r
F P
0 g
s
.68208 .45235 m .71761 .43952 L .73591 .47021 L p .858 .044 .718 r
F P
0 g
s
.63217 .4387 m .66177 .42485 L .68208 .45235 L p .868 .041 .703 r
F P
0 g
s
.66177 .42485 m .63217 .4387 L .61001 .4145 L p .878 .04 .698 r
F P
0 g
s
.71761 .43952 m .68208 .45235 L .66177 .42485 L p .866 .042 .712 r
F P
0 g
s
.56258 .40849 m .58422 .39127 L .61001 .4145 L p .895 .036 .682 r
F P
0 g
s
.58422 .39127 m .56258 .40849 L .53521 .3887 L p .905 .036 .681 r
F P
0 g
s
.53521 .3887 m .55477 .36906 L .58422 .39127 L p .905 .036 .681 r
F P
0 g
s
.55477 .36906 m .53521 .3887 L .50429 .36999 L p .912 .037 .683 r
F P
0 g
s
.71761 .43952 m .75736 .42531 L .77727 .45843 L p .858 .045 .725 r
F P
0 g
s
.61001 .4145 m .63773 .39824 L .66177 .42485 L p .878 .04 .698 r
F P
0 g
s
.63773 .39824 m .61001 .4145 L .58422 .39127 L p .888 .039 .694 r
F P
0 g
s
.50429 .36999 m .52168 .3479 L .55477 .36906 L p .912 .037 .683 r
F P
0 g
s
.52168 .3479 m .50429 .36999 L .46983 .35239 L p .918 .037 .687 r
F P
0 g
s
.75736 .42531 m .71761 .43952 L .69553 .4096 L p .865 .044 .72 r
F P
0 g
s
.66177 .42485 m .69553 .4096 L .71761 .43952 L p .866 .042 .712 r
F P
0 g
s
.69553 .4096 m .66177 .42485 L .63773 .39824 L p .875 .042 .708 r
F P
0 g
s
.46983 .35239 m .48496 .32783 L .52168 .3479 L p .918 .037 .687 r
F P
0 g
s
.48496 .32783 m .46983 .35239 L .43187 .33593 L p .922 .038 .692 r
F P
0 g
s
.30236 .25901 m .29741 .29358 L .24592 .28187 L p .924 .043 .715 r
F P
0 g
s
.24592 .28187 m .24802 .24481 L .30236 .25901 L p .924 .043 .715 r
F P
0 g
s
.43187 .33593 m .44463 .30887 L .48496 .32783 L p .922 .038 .692 r
F P
0 g
s
.44463 .30887 m .43187 .33593 L .39045 .32062 L p .924 .039 .697 r
F P
0 g
s
.35328 .27444 m .34561 .3065 L .29741 .29358 L p .925 .042 .709 r
F P
0 g
s
.29741 .29358 m .30236 .25901 L .35328 .27444 L p .925 .042 .709 r
F P
0 g
s
.58422 .39127 m .60996 .37255 L .63773 .39824 L p .888 .039 .694 r
F P
0 g
s
.60996 .37255 m .58422 .39127 L .55477 .36906 L p .897 .039 .693 r
F P
0 g
s
.39045 .32062 m .40072 .29107 L .44463 .30887 L p .924 .039 .697 r
F P
0 g
s
.40072 .29107 m .39045 .32062 L .34561 .3065 L p .925 .041 .703 r
F P
0 g
s
.34561 .3065 m .35328 .27444 L .40072 .29107 L p .925 .041 .703 r
F P
0 g
s
.63773 .39824 m .66965 .3805 L .69553 .4096 L p .875 .042 .708 r
F P
0 g
s
.66965 .3805 m .63773 .39824 L .60996 .37255 L p .883 .041 .705 r
F P
0 g
s
.69553 .4096 m .73358 .39289 L .75736 .42531 L p .865 .044 .72 r
F P
0 g
s
.55477 .36906 m .57845 .34784 L .60996 .37255 L p .897 .039 .693 r
F P
0 g
s
.57845 .34784 m .55477 .36906 L .52168 .3479 L p .904 .039 .694 r
F P
0 g
s
.73358 .39289 m .69553 .4096 L .66965 .3805 L p .873 .043 .716 r
F P
0 g
s
.52168 .3479 m .54318 .32414 L .57845 .34784 L p .904 .039 .694 r
F P
0 g
s
.54318 .32414 m .52168 .3479 L .48496 .32783 L p .909 .039 .697 r
F P
0 g
s
.60996 .37255 m .63994 .35227 L .66965 .3805 L p .883 .041 .705 r
F P
0 g
s
.63994 .35227 m .60996 .37255 L .57845 .34784 L p .891 .041 .704 r
F P
0 g
s
.48496 .32783 m .50418 .3015 L .54318 .32414 L p .909 .039 .697 r
F P
0 g
s
.50418 .3015 m .48496 .32783 L .44463 .30887 L p .913 .04 .7 r
F P
0 g
s
.66965 .3805 m .70591 .36123 L .73358 .39289 L p .873 .043 .716 r
F P
0 g
s
.70591 .36123 m .66965 .3805 L .63994 .35227 L p .88 .043 .713 r
F P
0 g
s
.44463 .30887 m .46144 .27995 L .50418 .3015 L p .913 .04 .7 r
F P
0 g
s
.46144 .27995 m .44463 .30887 L .40072 .29107 L p .916 .041 .704 r
F P
0 g
s
.57845 .34784 m .60637 .32496 L .63994 .35227 L p .891 .041 .704 r
F P
0 g
s
.60637 .32496 m .57845 .34784 L .54318 .32414 L p .897 .041 .704 r
F P
0 g
s
.40072 .29107 m .41501 .25953 L .46144 .27995 L p .916 .041 .704 r
F P
0 g
s
.41501 .25953 m .40072 .29107 L .35328 .27444 L p .917 .042 .709 r
F P
0 g
s
.35328 .27444 m .36491 .24028 L .41501 .25953 L p .917 .042 .709 r
F P
0 g
s
.36491 .24028 m .35328 .27444 L .30236 .25901 L p .918 .043 .713 r
F P
0 g
s
.30236 .25901 m .3112 .22223 L .36491 .24028 L p .918 .043 .713 r
F P
0 g
s
.3112 .22223 m .30236 .25901 L .24802 .24481 L p .918 .044 .718 r
F P
0 g
s
.24802 .24481 m .25392 .20539 L .3112 .22223 L p .918 .044 .718 r
F P
0 g
s
.54318 .32414 m .56894 .29863 L .60637 .32496 L p .897 .041 .704 r
F P
0 g
s
.56894 .29863 m .54318 .32414 L .50418 .3015 L p .902 .041 .705 r
F P
0 g
s
.63994 .35227 m .67428 .33037 L .70591 .36123 L p .88 .043 .713 r
F P
0 g
s
.67428 .33037 m .63994 .35227 L .60637 .32496 L p .886 .042 .712 r
F P
0 g
s
.50418 .3015 m .52763 .27331 L .56894 .29863 L p .902 .041 .705 r
F P
0 g
s
.52763 .27331 m .50418 .3015 L .46144 .27995 L p .906 .042 .708 r
F P
0 g
s
.60637 .32496 m .63868 .30037 L .67428 .33037 L p .886 .042 .712 r
F P
0 g
s
.63868 .30037 m .60637 .32496 L .56894 .29863 L p .891 .042 .712 r
F P
0 g
s
.46144 .27995 m .48247 .24906 L .52763 .27331 L p .906 .042 .708 r
F P
0 g
s
.48247 .24906 m .46144 .27995 L .41501 .25953 L p .909 .042 .711 r
F P
0 g
s
.41501 .25953 m .43347 .22591 L .48247 .24906 L p .909 .042 .711 r
F P
0 g
s
.43347 .22591 m .41501 .25953 L .36491 .24028 L p .91 .043 .714 r
F P
0 g
s
.56894 .29863 m .59909 .27129 L .63868 .30037 L p .891 .042 .712 r
F P
0 g
s
.59909 .27129 m .56894 .29863 L .52763 .27331 L p .896 .043 .713 r
F P
0 g
s
.36491 .24028 m .38066 .2039 L .43347 .22591 L p .91 .043 .714 r
F P
0 g
s
.38066 .2039 m .36491 .24028 L .3112 .22223 L p .912 .044 .718 r
F P
0 g
s
.3112 .22223 m .32408 .18307 L .38066 .2039 L p .912 .044 .718 r
F P
0 g
s
.32408 .18307 m .3112 .22223 L .25392 .20539 L p .912 .044 .722 r
F P
0 g
s
.25392 .20539 m .26378 .16346 L .32408 .18307 L p .912 .044 .722 r
F P
0 g
s
.52763 .27331 m .55549 .24318 L .59909 .27129 L p .896 .043 .713 r
F P
0 g
s
.55549 .24318 m .52763 .27331 L .48247 .24906 L p .9 .043 .714 r
F P
0 g
s
.48247 .24906 m .50788 .21609 L .55549 .24318 L p .9 .043 .714 r
F P
0 g
s
.50788 .21609 m .48247 .24906 L .43347 .22591 L p .903 .043 .716 r
F P
0 g
s
.43347 .22591 m .45628 .19006 L .50788 .21609 L p .903 .043 .716 r
F P
0 g
s
.45628 .19006 m .43347 .22591 L .38066 .2039 L p .905 .044 .719 r
F P
0 g
s
.38066 .2039 m .40071 .16515 L .45628 .19006 L p .905 .044 .719 r
F P
0 g
s
.40071 .16515 m .38066 .2039 L .32408 .18307 L p .906 .044 .722 r
F P
0 g
s
.32408 .18307 m .3412 .1414 L .40071 .16515 L p .906 .044 .722 r
F P
0 g
s
.3412 .1414 m .32408 .18307 L .26378 .16346 L p .907 .045 .725 r
F P
0 g
s
.26378 .16346 m .27779 .11886 L .3412 .1414 L p .907 .045 .725 r
F P
0 g
s
.25 Mabswid
.51694 0 m
.98167 .60079 L
s
.98167 .60079 m
1 .80739 L
s
1 .80739 m
.51579 .22681 L
s
.51579 .22681 m
.51694 0 L
s
.0249 .18885 m
0 .41054 L
s
0 .41054 m
.51579 .22681 L
s
.51579 .22681 m
.51694 0 L
s
.51694 0 m
.0249 .18885 L
s
.0249 .18885 m
.51694 0 L
s
.03593 .18462 m
.04065 .18942 L
s
gsave
.02648 .17501 -71.2923 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.14808 .14157 m
.15267 .1465 L
s
gsave
.13889 .13172 -71.2069 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.26353 .09726 m
.26799 .10232 L
s
gsave
.25462 .08715 -67.6432 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.38244 .05162 m
.38675 .05681 L
s
gsave
.37384 .04125 -67.5189 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.50496 .0046 m
.5091 .00991 L
s
gsave
.49669 -0.00604 -67.1691 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.06366 .17397 m
.06648 .17687 L
s
.0916 .16325 m
.0944 .16617 L
s
.11974 .15245 m
.12251 .15539 L
s
.17663 .13062 m
.17936 .13359 L
s
.20538 .11958 m
.2081 .12257 L
s
.23435 .10846 m
.23705 .11147 L
s
.29293 .08598 m
.29558 .08903 L
s
.32255 .07461 m
.32518 .07768 L
s
.35238 .06316 m
.35499 .06625 L
s
.41273 .04 m
.41529 .04313 L
s
.44324 .02829 m
.44578 .03144 L
s
.47399 .01649 m
.4765 .01966 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[76]:=",
  FormatType->StandardForm,
  ImageSize->{180, 166.75},
  ImageMargins->{{109, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002d0000YQ000`40O003h00O]7oo002dOol00;Ao
o`00FWoo00<007ooOol0Egoo001IOol3001HOol005]oo`03001oogoo05Ioo`00]7oo002dOol0061o
o`80059oo`00GGoo0`0000=oo`00Ool0DGoo001JOol30002Ool01000Ool00000DGoo0014Ool2000B
Ool30006Ool3001@Ool004Eoo`03001oogoo00eoo`<000Uoo`04001oogoo001?Ool004Ioo`03001o
ogoo00Yoo`8000aoo`04001oogoo001?Ool004Eoo`8000Uoo`<000ioo`05001oogooOol0001>Ool0
04eoo`<0015oo`03001oogoo009oo`03001oogoo04]oo`00Bgoo0P0057oo00<007ooOol00goo00<0
07ooOol0BWoo0018Ool3000FOol00`00Oomoo`04Ool00`00Oomoo`19Ool004Eoo`<0009oo`03001o
ogoo01Aoo`03001oogoo00Aoo`03001oogoo04Uoo`00;goo0P004Woo0`006goo00<007ooOol017oo
0P00BWoo000_Ool00`00Ool0000>Ool3000NOol00`00Oomoo`06Ool00`00Oomoo`17Ool002moo`03
001oo`0000aoo`<0021oo`03001oogoo00Moo`03001oogoo04Ioo`00<7oo0P002Goo0`008goo00<0
07ooOol01goo00<007ooOol0AWoo000hOol4000UOol00`00Oomoo`08Ool00`00Oomoo`15Ool003Io
o`8002Uoo`03001oogoo00Uoo`03001oogoo04Aoo`00<goo1000:Woo00<007ooOol02Woo00<007oo
Ool0@goo000HOol300000goo0000000BOol3000^Ool00`00Oomoo`09Ool20015Ool001eoo`03001o
ogoo00ioo`800003Ool007oo02ioo`03001oogoo00]oo`03001oogoo049oo`007Woo00<007ooOol0
2Woo0`002Woo0P009Woo00<007ooOol03Goo00<007ooOol0@Goo000MOol2000:Ool200000goo001o
o`0:Ool00`00M3L00002000SOol00`00Oomoo`0>Ool00`00Oomoo`10Ool002Ioo`<000moo`03001d
=g@g009d=`<0021oo`03001oogoo00ioo`03001oogoo00Aoo`H003Ioo`008goo0`0000=oo`00Ool0
3Woo00<007@gM3L01W@g0`007Goo00<007ooOol03goo00<007ooOol027oo00<007ooOol0=7oo000Q
Ool2000DOol00`00M3Md=`09M3L2000KOol00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`0e
Ool001ioo`<0009oo`03001oogoo015oo`03001d=g@g00Ud=`03001`=`00008001Qoo`03001oogoo
00moo`03001oo`0000Qoo`03001oogoo03Aoo`001Goo0`0000=oo`00Ool047oo100067oo00<007@g
M3L027@g00<0070gL3L00g0g0P005Woo00<007ooOol04Woo00<007ooOol0?7oo0008Ool3000>Ool2
000KOol00`00M3Md=`09M3L00`00L3M`=`05L3L3000COol00`00Oomoo`0BOol00`00Oomoo`0lOol0
00Yoo`03001oogoo00Uoo`@001aoo`03001d=`0000Qd=`03001`=g0g00U`=`80015oo`03001oogoo
01=oo`03001oogoo03]oo`0057oo0P0087oo00<007@gM3L00`001G@g00<0070gL3L02G0g00@0070g
000000moo`03001oogoo01Aoo`03001oogoo03Yoo`004Goo10008Goo00<007@gM3L00g@g0`000W@g
00<0070gL3L0270g00<0070gL3L00W0g0`0037oo00<007ooOol05Goo00<007ooOol0>Goo000>Ool3
000TOol00`00M3Md=`07M3L2000;L3L00`00L3M`=`05L3L2000:Ool00`00Oomoo`0EOol2000jOol0
00eoo`800003Ool007oo02=oo`03001d=g@g00Qd=`04001d=P000007L3L00`00L3M`=`08L3L20008
Ool00`00Oomoo`0FOol00`00Oomoo`0hOol000eoo`03001oogoo02Eoo`03001d=g@g00Qd=`04001d
=W@fM3H30003L3L00`00L3M`=`09L3L01000L3H000001Woo00<007ooOol05goo00<007ooOol0=goo
000=Ool2000UOol00`00M3Md=`08M3L00`00M3Id=P05M3H200000g0g001`=`09L3L00`00L3I`=P02
L3H20004Ool00`00Oomoo`0HOol00`00Oomoo`0fOol0009oo`<00003Ool0000000Eoo`03001oo`00
02Aoo`03001d=`0000Qd=`03001d=W@f00Md=P03001`=`0000Q`=`03001`=W0f00E`=P05001oogoo
Ool0000JOol00`00Oomoo`0fOol000Moo`03001oogoo00=oo`04001oogoo000SOol00`00M3Id=P03
0005M3L00`00M3Id=P07M3H00`00M3Id=P030005L3L00`00L3I`=P06L3H200000goo001oo`0JOol0
0`00Oomoo`0eOol000Qoo`03001oogoo009oo`05001oogooOol0000ROol00`00M3Id=P03M3H30000
0g@g001d=P08M3H00`00M3Id=P04M3H300000g0g001`=P0:L3H2000LOol00`00Oomoo`0dOol000Mo
o`8000=oo`8000Aoo`03001oogoo01moo`03001d=W@f00Id=P800003M3H007@f00Id=P03001d=W@f
00Md=P03001`=W0f00Y`=P@001Yoo`8003Eoo`0037oo00<007ooOol017oo00<007ooOol07Goo00<0
07@fM3H027@f00<007@fM3H00`0017@f00<007@fM3H01g@f00@007@f000000I`=P<00004L3H0070f
L3H2000IOol00`00Oomoo`0cOol000aoo`8000Ioo`03001oogoo01aoo`03001d=W@f00Md=P03001d
=W@f00Ad=P@000Ud=P03001d=W@f009d=PH00003L3H0070f009`=P04001`=W0fL3H2000HOol00`00
Oomoo`0bOol000aoo`8000Moo`03001oogoo01]oo`03001d=W@f00Md=P03001d=W@f00Md=P03001d
=W@f00Md=P03001d=W@f009d=PD00003L3H0070f00A`=P03001`=W0f009`=P8001Moo`03001oogoo
035oo`0037oo00<007ooOol01goo00<007ooOol06Woo0`001g@f00<007@fM3H01g@f00<007@f0000
0P0017@f00@007@fM3Id=P8000Ed=P03001`=W0f00E`=P04001`=W0f0002L3H00`00Oomoo`0EOol0
0`00Oomoo`0`Ool0009oo`<00003Ool007oo00Aoo`03001oogoo00Qoo`03001oogoo01Uoo`03001d
=W@f00D00003M3H007@f00Qd=P03001d=W@f00=d=P<00003M3H00000008000Md=P04001`=P000005
L3H20004L3H2000FOol00`00Oomoo`0_Ool000Ioo`03001oogoo00=oo`03001oogoo00Uoo`03001o
ogoo01Qoo`03001d=W@f00Ed=P800003M3H007@f00Id=P03001d=W@f00Ed=P<000Ud=P03001`=W0f
009`=P03001`=W0f009`=P8000I`=P03001oogoo01=oo`80031oo`001Woo00<007ooOol00goo00<0
07ooOol02Woo00<007ooOol05goo00<007@fM3H01W@f00<007@fM3H00`0017@f00<007@fM3H00g@f
0P0000=d=P00M3H00P001W@f00<0070fL3H0170f0P0000A`=P00L3H000M`=P03001oogoo01=oo`03
001oogoo02ioo`001Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol05Woo00<007@fM3H0
1W@f00<007@fM3H00g@f10000g@f0`000W@f00<007@fM3H00W@f0P0017@f00<0070fL3H01W0f00D0
070fL3I`=P0000M`=P8001Aoo`03001oogoo02eoo`002goo0P003Woo00<007ooOol05Goo00<007@f
M3H01W@f00<007@fM3H01W@f10001G@f00<007@fM3H017@f0P0000=d=P00L3H0270f00<0070f0000
0W0f00<0070fL3H00g0f00@0070fL3H001Aoo`03001oogoo02aoo`002goo0P003goo00<007ooOol0
57oo0`001G@f00<007@fM3H01G@f0`000W@f10000W@f00<007@fM3H01W@f00<0070fL3H01g0f00@0
070fL3I`=P800003L3H0070f009`=P03001`=W0f009`=P80019oo`03001oogoo02aoo`002goo00<0
07ooOol03goo00<007ooOol04goo00<007@fM3H0100000=d=P00M3H017@f0P0000=d=P00M3H01W@f
0P002G@f00<007@f00000P00170f00<0070fL3H0170f00D0070f001`=P0000M`=P03001oogoo011o
o`03001oogoo02]oo`002goo0P004Goo00<007ooOol04Woo00<007@fM3H017@f0P0000=d=P000000
0P000g@f00<007@fM3H01W@f00<007@f00000P0017@f00<007@fM3H00g@f0P0000=`=P00L3H01g0f
00<0070f00002G0f00<007ooOol047oo00<007ooOol0:Woo000;Ool00`00Oomoo`0AOol00`00Oomo
o`0AOol00`00M3Id=P05M3H70002M3H00`00M3Id=P05M3H00`00M3Id=P03M3H200000g@f001d=P07
M3H00`00L3I`=P08L3H2000:L3H2000AOol00`00Oomoo`0YOol000Aoo`8000Eoo`03001oogoo019o
o`03001oogoo011oo`03001d=W@f00=d=P<000Id=P800003M3H007@f00Ed=P03001d=W@f00Ed=P03
001d=W@f00Md=P04001d=P000006L3H00`00L3I`=P020006L3H01@00L3I`=W0f000047oo00<007oo
Ool0:Goo0004Ool00`00Ool00004Ool00`00Oomoo`0COol00`00Oomoo`0?Ool00`00M3Id=P030002
M3H00`00M3Id=P05M3H00`00M3Id=P040002M3H00`00M3Id=P05M3H01000M3H000001G@f00<007@f
M3H00W@f00<0070fL3H00W0f00<0070fL3H00W0f0P00170f00<0070fL3H00g0f00<007ooOol03Woo
00<007ooOol0:7oo0004Ool00`00Ool00004Ool00`00Oomoo`0DOol00`00Oomoo`0>Ool50003M3H0
0`00M3Id=P05M3H00`00M3Id=P04M3H20007M3H00`00M3Id=P02M3H01@00M3Id=W@f00001W@f0P00
00=`=P00L3H01G0f0`0000=`=P00L3H01W0f00<007ooOol03Woo00<007ooOol00goo0P008Woo0005
Ool20004Ool00`00Oomoo`0EOol00`00Oomoo`0:Ool40004N3H60005M3H00`00M3Id=P05M3H00`00
M3H000020003M3H00`00M3Id=P03M3H200000g@f001d=P07M3H00`00L3I`=P06L3H00`00L3H00009
L3H00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Ool0000QOol000Yoo`8001Qoo`03001oogoo00Mo
o`8000=oo`03001h=WPf00Eh=P03001h=WPf00@00003M3H007@f00Id=P03001d=W@f009d=P800003
M3H007@f00Id=P03001d=W@f00Id=P04001`=W0f0006L3H200000g0f001`=P08L3H2000>Ool20003
Ool00`00Ool0000QOol000Yoo`8001Uoo`03001oogoo00=oo`<000Ioo`03001h=WPf00Ah=P03001h
=WPf00Ah=P@000Ad=P03001d=W@f00Ed=P03001d=W@f00Id=P04001d=@000004M3H00`00L3I`=P02
L3H20003L3H01P00L3I`=P00L3H000I`=P05001`=W0fL3H0000=Ool20004Ool2000QOol000Yoo`03
001oogoo01Uoo`03001oo`00008000Uoo`03001h=WPf00Ah=P03001h=WPf00Eh=P03001h=WPf00<0
0003M3H007@f00Id=P03001d=@00008000=d=P03001d=G@e009d=@800003M3H0070f00I`=P03001`
=P0000=`=P04001`=W0f0003L3H20005L3H00`00Oomoo`0<Ool00`00Oomoo`0TOol000Yoo`8001Yo
o`8000aoo`D0009h=P03001h=WPf00Eh=P03001h=WPf00=h=P800003M3H007@f00Ad=P03001d=G@e
009d=@800003M3H007@e00Ed=@03001`=W0f00M`=P03001`=W0f00=`=P06001`=W0f001`=P00270f
00<007ooOol037oo00<007ooOol08goo000:Ool00`00Oomoo`0FOol30002Ool00`00Oomoo`09Ool0
0`00N3Ih=P02N3H50005N3H00`00N3Ih=P04N3H00`00N3Eh=@0300000g@f001d=@06M3D00`00M3Ed
=@05M3D00`00M3D00006L3H01000L3I`=P00170f00@0070fL3H000Y`=P03001oogoo00aoo`03001o
ogoo029oo`0017oo00<007ooOol00goo00<007ooOol04goo0`001Woo00<007ooOol027oo00<007Pf
N3H017Pf00<007PfN3H0100000=h=P00N3H01GPf00<007PeN3D00gPe0P001g@e00@007@e000000=d
=@04001d=G@eM3D20003L3H00`00L3I`=P02L3H01000L3I`=W0f0P000W0f00<0070fL3H0270f00<0
07ooOol02goo00<007ooOol08Woo0004Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool3000:Ool00`00
Oomoo`07Ool00`00N3Ih=P04N3H00`00N3Ih=P04N3H60002N3H00`00N3Eh=@04N3D01000N3D00000
0g@e00<007@eM3D00W@e00<007@e00001W@e00<0070f00001W0f00<0070f00000W0f00@0070fL3H0
00I`=P800003K3H007oo00eoo`80029oo`0017oo00<007ooOol00goo00<007ooOol03Woo0P003Woo
00<007ooOol01goo00<007PfN3H017Pf00<007PfN3H017Pf00<007PfN3H00WPf0`0000=h=@00N3D0
0gPe00@007PeN3Eh=@800003M3D007@e00Ad=@03001d=G@e00Id=@03001`=W0f00I`=P03001`=W0f
009`=P04001`=W0f0004L3H00`00K3I/=P02K3H00`00Oomoo`0<Ool00`00Oomoo`0POol000Aoo`03
001oogoo00=oo`03001oogoo00]oo`<0015oo`03001oogoo00Ioo`03001h=WPf00Ah=P03001h=WPf
00Ah=P03001h=WPf00Ah=P03001h=GPe00@000Ih=@03001d=G@e00Ad=@04001d=@000004M3D00`00
L3E`=@020003L3H01000L3I`=P000g0f00H0070fL3I`=P00L3H20006K3H00`00Oomoo`0<Ool00`00
Oomoo`0OOol000Uoo`8000Yoo`<001Eoo`03001oogoo00Eoo``0009h=P03001h=WPf00Ah=P03001h
=GPe00=h=@03001h=GPe00Ah=@03001h=@0000800003M3D007@e00=d=@800003M3D0070e00A`=@03
001`=P0000A`=P05001`=W0fL3H00003L3H00`00K3I/=P06K3H00`00Oomoo`0<Ool00`00Oomoo`0O
Ool000Uoo`03001oogoo00Moo`8001Uoo`03001oogoo00Aoo`03001h=WPf00Ah=P03001h=WPf009h
=PD000Ah=P03001h=GPe00=h=@03001h=@0000800003N3D007Pe00Ah=@03001d=G@e00Ed=@03001`
=G0e00E`=@03001`=W0f00A`=P04001`=W0fL3H20002K3H00`00K3I/=P06K3H00`00Oomoo`0<Ool0
0`00Oomoo`0NOol000Uoo`8000Eoo`<001aoo`03001oogoo00Aoo`03001h=WPf00Ah=P03001h=WPf
00=h=P03001h=GPe00<00003N3H007Pe00Ah=@03001h=GPe009h=@03001h=GPe00Ah=@04001h5000
0003M3D01000M3Ed=@000g0e00@0070eL3D000I`=P05001`=P00K3H00003K3H00`00K3I/=P06K3H0
0`00Oomoo`0<Ool00`00Oomoo`0MOol000Uoo`80009oo`<0021oo`03001oogoo00=oo`03001h=WPf
00Ah=P03001h=WPf00Ah=P03001h=GPe009h=@D0009h=@03001h=GPe009h=@03001h500000800003
N3D007PD00=h5003001d=@0000Ad=@03001`=@0000A`=@03001`=W0f00A`=P05001/=V`fK3H00003
K3H00`00K3I/=P02K3H200000f`g001oo`0>Ool00`00Oomoo`0LOol000Uoo`@002Aoo`03001oogoo
00=oo`D00003N3H007Pf00Eh=P03001h=GPe00=h=@04001l=G`eO3D40003N3D00`00N1Ah5002N1@0
0`00N1Ah5004N1@00`00M3Ed=@04M3D00`00L3E`=@04L3D00`00L3H000020002L3H01@00K3I/=V`f
00000f`f00@006`f000000A/=`03001oogoo00aoo`03001oogoo01aoo`000Woo0P001Goo0P009goo
00<007ooOol00Woo00<007PfN3H00WPf1`0000=h=P00N3D017Pe00<007`eO3D00g`e00<007`D0000
0`0017PD00@007PD000000=h5003001d500000=d=@03001`=@0000I`=@03001`=W0f00A`=P04001/
=V`f0004K3H00`00K3M/=`05K3L00`00Oomoo`0<Ool00`00Oomoo`0KOol000=oo`03001oogoo00Eo
o`03001oogoo02Eoo`03001oogoo009oo`03001h=WPf00=h=P03001l=W`f009l=PP00003O3D00000
009l=@03001l57`D009l50@00003N1@007PD009h5003001h500000=d5003001d=@0000=`=@05001`
=G0eL3D00002L3D00`00L3I`=P04L3H00`00K3I/=P0300000f`f001/=`07K3L00`00Oomoo`0<Ool0
0`00Oomoo`0JOol000Aoo`03001oogoo00Eoo`03001oogoo02Eoo`03001oogoo009oo`03001h=WPf
00=h=P03001l=W`f00=l=P03001l=G`e009l=@04001l=G`eO3D30004O1@01000O1Al57`D0P0017PD
00<007@DM1@00g@D00<0070eL3D00g0e00<0070e0000170e00<0070fL3H0170f0P0000=/=P00K3H0
0V`f00<006`gK3L01V`g00<007ooOol037oo00<007ooOol06Goo0003Ool20008Ool00`00Oomoo`0U
Ool01@00Oomoogoo00001GPf00<007`fO3H017`f00<007`eO3D00W`e00<007`eO3D00W`e00<007`D
00000`0017`D00L007`C000007PD001h500200001G@D001d57@D0000170e00<0070eL3D0170e00<0
070f00000P0000=/=P00K3H00V`f00D006`fK3I/=P0000A/=`800003K3L007oo00eoo`03001oogoo
01Uoo`003Woo00<007ooOol09Goo00@007ooOomooa000003O3D007`e00=l=@03001l57`D009l50<0
0003O1@007`C00=l4`03001h57PD009h5003001d57@D009d5003001`=@00009`=@03001`=G0e00A`
=@03001/=V`f00=/=P05001/=V`fK3H00003K3H01000K3L0000016`g00<007ooOol037oo0P006Goo
000?Ool00`00Oomoo`0UOol01000Oomoo`001G`f00<007`fO3H00g`f00@007`eO3El=@H00003O3D0
07`D009l5003001l4g`C008000Al4`8000=h508000Ad5003001`=G0e009`=@07001`=G0eL3D006`f
00001V`f00D006`fK3I/=P0000=/=P03001/=f`g00E/=`03001oogoo00aoo`03001oogoo01Moo`00
47oo00<007ooOol09Goo00@007ooOol000El=P03001l=W`f00=l=P03001l=G`e009l=@04001l=G`e
O3D400000g`D001l4`02O1<00`00O1<000020002O1<00`00N1@00002N1<00`00M1@00002L1@00`00
L3E`=@02L3D00`00L3D00003K3H00`00K3I/=P04K3H00`00K3I/=P0300000f`f001/=`06K3L00`00
Oomoo`0=Ool00`00Oomoo`0FOol0015oo`03001oogoo02Eoo`04001oogoo0005O3H00`00O3Il=P03
O3H00`00O3El=@02O3D01@00O3El=G`e00000W`D100000=l4`00O1<00W`C00D007`CO1=l4`0000Ah
4`03001`570D009`5006001`=G0e001`=@001F`f00<006`fK3H00f`f0`0000=/=P00K3H00V`f00<0
06`gK3L01F`g00<007ooOol03Goo00<007ooOol05Goo000BOol00`00Oomoo`0UOol00`00Oomoo`0D
00000g`e001l5002O1@04P00O1<00000O1<007`C001l4P00O1<007`B001h4`00M1<000A`508000=/
=@03001/=V`f009/=P03001/=V`f00<00003K3H006`f009/=P05001/=V`fK3H00005K3L00`00K3L0
000>Ool00`00Oomoo`0EOol001=oo`03001oogoo02Eoo`03001oo`0000El=P03001l=W`f00=l=P03
001l=W`f009l=P03001l=G`e00T0009l4P80009l4P05001l4W`BO1800003M1<01@00L1@0070E0000
1F`e00D006`fK3H006`f008000E/=P05001/=V`fK3H00002K3H00`00K3M/=`030002K3L00`00Oomo
o`0=Ool2000EOol001Aoo`03001oogoo02Eoo`03001oo`0000El=P03001l=W`f00=l=P03001l=W`f
009l=P03001l=G`e009l=@04001l57`D0002O1<01000O18000000W`@00@007`A001l4P8000=d4`05
001`5G0EL1D00005K3D20002K3H00`00K3I/=P04K3H00`00K3I/=P02K3H50006K3L00`00Oomoo`0=
Ool00`00Oomoo`0COol001Eoo`03001oogoo02Eoo`03001oo`0000El=P03001l=W`f009l=P04001l
=W`fO3H;0002O1<01000O18007`@0`0000Il4@00N19h4P00M1<20004L1D01P00K3D00000K3H000A/
=P03001/=V`f00=/=P03001/=V`f00@00003K3L006`g00I/=`03001oogoo00ioo`03001oogoo019o
o`005Woo0P009Woo00<007oo00003@002Woo1`0000Ml3`00O0l007`@001h4P020002L1@00`00L1E`
5@030004K3H00`00K3I/=P02K3H01000K3I/=V`f10000f`g00@006`gK3L000I/=`03001oogoo00io
o`03001oogoo00Aoo`<000]oo`0067oo00<007ooOol097oo00<007ooOol07Goo1@0000El4000L19`
4P00009`5080009/=@03001/=V`f009/=P04001/=V`fK3H50002K3L00`00K3M/=`03K3L00`00K3L0
0007K3L00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`09Ool001Uoo`03001oogoo02Aoo`03
001oogoo021oo`800007N100070BL18006`D000016`e00@006`fK3I/=P@0009X=P03001/=f`g00=/
=`03001/=f`g00=/=`8000A/=`@0015oo`03001oogoo00=oo`03001oogoo00Yoo`006Woo00<007oo
Ool097oo00<007ooOol087oo00H007P@000006`C0002K1@01P00K3E/=F`e001/=P800003J3H006Pf
00AX=P03001/=f`g00=/=`03001/=f`g00=/=`D000=/=`03001oogoo00moo`8000Eoo`03001oogoo
00Uoo`006goo00<007ooOol097oo00<007ooOol07goo0P0000M/4P00K1=/4`00K1@00002K3D30003
J3H00`00J3IX=P03J3H00`00K3M/=`03K3L00`00K3M/=`0300000fPg001/=`06K3L00`00Oomoo`0?
Ool00`00Oomoo`0?Ool001aoo`03001oogoo02Aoo`03001oogoo01ioo`80009/4PL0009X=P03001X
=VPf009X=P03001X=VPf009X=P04001/=f`gK3L50005J3L00`00K3M/=`05K3L00`00Oomoo`0?Ool0
0`00Oomoo`0>Ool001eoo`03001oogoo02Aoo`03001oogoo01eoo`D00005J3D006PeJ3D00004J3H0
1@00J3IX=VPf00000VPf1P000fPg00<006PgJ3L016Pg0P001V`g00<007ooOol047oo00<007ooOol0
3Goo000NOol00`00Oomoo`0TOol00`00Oomoo`0LOol20002I1@01000J3EX=@000VPe00<006Pf0000
20000fPg00<006PgJ3L00fPg00<006PgJ3L016Pg0P001F`g0`004Woo00<007ooOol037oo000OOol0
0`00Oomoo`0TOol00`00Oomoo`0KOol300000f@D001X=@060002J3H01@00J3MX=fPg00001FPg00<0
06PgJ3L016Pg00<006PgJ3L016Pg1P000VPg00<007ooOol047oo0P003Goo000POol00`00Oomoo`0T
Ool00`00Oomoo`0JOol00`00F3P000030004I3H01@00J3IX=VPf00000fPg00<006PgJ3L016Pg00<0
06PgJ3L00fPg00@006PgJ3MX=`H000EX=`03001oogoo015oo`03001oogoo00]oo`008Goo00<007oo
Ool097oo00<007ooOol067oo0P0000AH>000H3H0009T=P04001T=V@f0004J3H01@00J3MX=fPg0000
0VPg3@000fPg00@006PgJ3L000AX=`03001oogoo019oo`03001oogoo00Yoo`008Woo00<007ooOol0
97oo00<007ooOol05Woo00<0051L00001@0000ET=P00I3IT=P00009X=PT000=X=`03001X=fPg00=X
=`03001X=fPg00AX=`05001X=fPgJ3L00004J3L00`00Oomoo`0BOol00`00Oomoo`09Ool002=oo`03
001oogoo02Aoo`03001oogoo01Aoo`05001@G000F3T00002G3P00`00H3MP=`060002I3L01@00J3MX
=fPg00001FPg00<006PgJ3L00fPg00<006PgJ3L01FPg00D006PgJ3MX=`0000=X=`03001oogoo01=o
o`03001oogoo00Qoo`0097oo0P009Goo00<007ooOol04Woo00<005AL00000P000e`h00@0060gH3L0
009T=`03001T=f@g009T=`05001X=fPgJ3L00006J3L00`00J3MX=`03J3L00`00J3MX=`04J3L01000
J3MX=fPg1@005Goo0P002Goo000VOol00`00Oomoo`0SOol00`00Oomoo`0?Ool2000015AL001HFUQJ
0P0000EL>000H3MP=`0000=T=`03001T=f@g009T=`03001X=fPg009X=`03001X=fPg00=X=`03001X
=fPg00=X=`04001X=fPgJ3L700001FPh001X>6Ph00005Woo00<007ooOol01goo000WOol00`00Oomo
o`0SOol00`00Oomoo`0=Ool00`00F5aHG0020002F5X00`00G3UL>@0;000016@g001X=fPg4P000fPh
00<006PhJ3P00fPh00<006Ph00005goo00<007ooOol01Woo000XOol00`00Oomoo`0SOol00`00Oomo
o`0:Ool20003F5`01000F5/000000e`i00@0060hH3P000=P>004001T>6@hI3P40002I3L00`00J3MX
=`03J3L00`00J3MX=`03J3L00`00J3QX>004J3P00`00J3QX>004J3P2000HOol00`00Oomoo`05Ool0
02Uoo`03001oogoo02=oo`03001oogoo00Qoo`06001HG5QL001HG0000eQK0P0000=L>@00H3P00V0h
00D0060hH3QP>00000AT>003001T=f@g009T=`03001X=fPg00=X=`03001X=fPg00=X=`03001X>6Ph
00AX>003001X>6Ph00EX>08001Moo`03001oogoo00Eoo`00:Woo00<007ooOol08goo00<007ooOol0
1Woo00<005QLF5`00UQL0P000eQK00<005aJG5X00P0000=P>000H3P00f0h00<006@hI3P00V@h00<0
06@gI3L00V@g00<006PgJ3L00fPg00<006PgJ3L016Pg00<006PhJ3P016Ph00<006PhJ3P01FPh00<0
07ooOol05Woo0P001Goo000[Ool00`00Oomoo`0SOol00`00Oomoo`03Ool30003F5`01P00G5]LF`00
F5/000=LFP03001P>F0i00P00003I3P006@g00AT=`03001X=fPg00=X=`03001X=fPg00AX=`03001X
>6Ph00AX>004001X>6PhJ3P5000IOol00`00Oomoo`03Ool002aoo`03001oogoo02=oo`05001oogoo
Ool00003G5`00`00F5`00004G5/300000eaJ001P>@02H3T00`00H3QP>002H3P00`00I3QT>00O0004
J3P2000GOol30004Ool002eoo`03001oogoo02=oo`03001oo`0000ALG0<000=LF`04001LFUaJG5X3
00000f0i001P>003H3P00`00I3QT>002I3P00`00I3QT>003I3P00`00I3QT>003I3P00`00J3QX>004
J3P00`00J3QX>004J3P00`00J3QX>005J3P00`00Ool0000COol30002Ool00`00Oomoo`02Ool002io
o`03001oogoo029oo`<000=LG007001LFeaKG5/005aK000015aJ00<0060iH3T010000V0h00<006@h
I3P00V@h00<006@hI3P00f@h00<006@hI3P00f@h00<006PhJ3P016Ph00<006PhJ3P016Ph00<006Ph
J3P01FPh00@007ooOol000ioo`@000Eoo`03001oogoo009oo`00;goo00<007ooOol087oo00L005aL
G5aLG000G5`00005G5/20003G5X00`00H3UP>@02H3T00`00H3UP>@0500000f@h001T>004I3P00`00
I3QT>003I3P00`00J3QX>004J3P00`00J3QX>005J3P00`00J3QX>005J3P01@00Oomoogoo00002Woo
0`002Goo00<007ooOol00Woo000`Ool00`00Oomoo`0NOol00`00G5aLG003G5`00`00G5]LF`03G5/0
1P00G5YLFP00G5X000AP>@03001P>F0i009P>@04001T>F@iI3T50002I3P00`00I3QT>003I3P00`00
J3QX>004J3P00`00J3QX>005J3P00`00J3QX>005J3P00`00Oomoo`02Ool00`00Oomoo`04Ool3000<
Ool00`00Oomoo`02Ool0035oo`8001aoo`8000ELG003001LF`0000=LF`03001LFUaJ009LFP@0009P
>@05001P>F0iH3T00005I3T01000I3QT>6@h800017oo00<007ooOol0100047oo00<007ooOol00Goo
000cOol00`00Oomoo`0GOol20002H5/01@00G5aLG5aL00000eaK00<005aK00001EaJ00@0061JH5YP
FP<000=P>@03001T>F@i00=T>@03001T>6@h00=T>003001T>6@h00=T>003001X>6Ph00AX>003001X
>6Ph00EX>003001X>6Ph00EX>003001oogoo009oo`<001Aoo`03001oogoo005oo`00=7oo00<007oo
Ool05Goo00<0061KH5/00f1K00<005aL00001EaK0P0015aJ00<0061JH5X00f1J00H0060i0000060i
0004I3T00`00I3QT>004I3P00`00I3QT>003I3P00`00J3QX>004J3P00`00J3QX>005J3P00`00J3QX
>005J3P50002Ool00`00Oomoo`0BOol00`00Oomoo`01Ool003Eoo`03001oogoo019oo`8000IPF`<0
00ALF`03001PFV1J00800003G5X0061J00APFP03001P>F0i009P>@@0009T>@03001T>6@h00=T>003
001T>6@h00=T>003001X>6Ph00EX>003001X>6Ph00EX>003001X>6Ph00EX>003001oogoo00Eoo`03
001oogoo015oo`03001oogoo005oo`00=Woo00<007ooOol03goo0P000V1K00@0061KH5]PF`8000=P
F`800003G5/0061J00APFP@0009PFP03001P>F0i00=P>@04001T>F@iI3T60002I3P00`00I3QT>003
I3P00`00J3QX>005J3P00`00J3QX>004J3P00`00J3QX>006J3P00`00Oomoo`06Ool00`00Oomoo`0@
Ool00`00Oomoo`01Ool003Moo`03001oogoo00aoo`8000EPF`03001PF`0000IPF`<000APFP03001P
FV1J009PFP<000AP>@03001T>F@i00AT>@04001T>F@iI3T=0003J3P00`00J3QX>004J3P00`00J3QX
>006J3P00`00Oomoo`07Ool00`00Oomoo`0?Ool00`00Oomoo`01Ool003Qoo`03001oogoo00Uoo`80
00MPF`<000EPF`04001PFV1JH5X200000f1J001PFP05H5X00`00H5X0000200000f0i001T>@04I3T0
0`00I3UT>@04I3T00`00I3QT>003I3P00`00I3QT>002I3PD0009Ool00`00Oomoo`0?Ool00`00Oomo
o`01Ool003Uoo`03001oogoo00Moo`04001PFf1K0005H5/01@00H5]PFf1K00000f1K00<0061JH5X0
161J0P001F1J00<0061JH5X00f1J10000f@i00<006@iI3T00f@i00<006@hI3P016@h00<006@hI3P0
1F@h00<006PhJ3P016Ph00<006PhJ3P01VPh00<007ooOol027oo00<007ooOol03Woo00<007ooOol0
0Goo000jOol00`00Oomoo`04Ool20004H5/01@00H5]PFf1K00001F1K00<0061K00001V1J00<0061J
H5X00P000V1J00<0061JH5X0161J00@006@iI3UT>@D000AT>@03001T>6@h00AT>003001T>6@h00AT
>003001X>6Ph00EX>003001X>6Ph00IX>003001oogoo00Uoo`03001oogoo00eoo`03001oogoo005o
o`00>goo00<007ooOol00Woo00<0061KH5/01F1K00<0061K00001V1K0`001F1J00<0061JH5X0161J
0P001F1J00<006@iI3T016@i00<006@iI3T00P000V@i00<006@hI3P00f@h00<006@hI3P01F@h00<0
06PhJ3P01FPh00<006PhJ3P01VPh00<007ooOol02Woo00<007ooOol03Goo0@000Goo0Goo000lOol0
0`00Oomoo`020007H5/30005H5/01000H5]PFf1K0`0000=PFP00H5X01V1J00<0061J00000P0000=P
FP00I3T01F@i00<006@iI3T016@i1@000V@h00<006@hI3P01F@h00<006PhJ3P016Ph00<006PhJ3P0
1VPh00<007ooOol037oo00<007ooOol037oo0@000Goo0Goo000mOol01@00Oomoogoo0000161K0P00
0f1K00D0061KH5]PF`0000MPF`8000IPFP03001PFV1J00=PFP<000AT>@03001T>F@i00ET>@03001T
>F@i009T>@h000=X>003001X>6Ph00IX>003001oogoo00eoo`03001oogoo00]oo`40005oo`5oo`00
?Woo00H007ooOomoo`00H5/20006H5/00`00H5/00007H5/00`00H5YPFP020003H5X00`00H5YPFP04
H5X00`00I3UT>@020002I3T00`00I3UT>@04I3T00`00I3UT>@05I3T00`00I3UT>@04I3T00`00J3UX
>@02J3T90003J3P00`00Oomoo`0=Ool00`00Oomoo`0;Ool10001Ool1Ool003moo`80009oo`8000MP
F`<000IPF`03001PFV1J00=PFP03001PFP0000IPFP03001T>F@i00AT>@<000ET>@03001T>F@i00AT
>@03001T>F@i00ET>@03001X>FPi00EX>@03001X>6Ph00=X>0@0011oo`03001oogoo00Yoo`40005o
o`5oo`00@Goo00D007ooOomoo`0000EPF`04001PFf1KH5/20003H5/00`00H5YPFP05H5X30004H5X0
0`00I3UT>@05I3T00`00I3UT>@030002I3T00`00I3UT>@04I3T00`00I3UT>@05I3T00`00J3UX>@05
J3T00`00J3QX>006J3P00`00Oomoo`0?Ool00`00Oomoo`09Ool10001Ool1Ool0049oo`05001oogoo
Ool00003H5/00`00H5]PF`04H5/00`00H5/00007H5X01000I5YTFVAJ0`0000=PFP00I3T01F@i00<0
06@iI3T016@i1P000f@i00<006@iI3T016@i00<006PiJ3T01VPi00<006PhJ3P01VPh00<007ooOol0
47oo00<007ooOol027oo0@000Goo0Goo0013Ool01`00Oomoogoo001PF`0000MPF`@000EPFP03001T
FVAJ00ETFP<000AT>@03001T>F@i00IT>@03001T>F@i009T>@L000=T>@03001X>FPi00EX>@03001X
>6Ph00MX>003001oogoo015oo`03001oogoo00Moo`40005oo`5oo`00A7oo00@007ooOomoo`8000IP
F`03001TFVAJ009TFP<00003H5X006AJ00MTFP03001TFVAJ0080009T>@03001T>F@i00ET>@03001T
>F@i00ET>@03001T>F@i009T>@P000=X>@03001X>6Ph00IX>003001oogoo01=oo`03001oogoo00Io
o`40005oo`5oo`00AGoo00<007ooOol00Woo0P000f1K00<006AJI5X01VAJ0P001fAJ00<006AJI5X0
16AJ0`001F@i00<006@iI3T01F@i00<006@iI3T01V@i00<006PiJ3T00VPi2@000fPh00<007ooOol0
57oo00<007ooOol01Woo0@000Goo0016Ool00`00Oomoo`03Ool00`00H5/00008I5X00`00I5YTFP02
0004I5X00`00I5YTFP05I5X00`00I3UT>@030002I3T00`00I3UT>@04I3T00`00I3UT>@06I3T00`00
J3UX>@06J3T00`00J3UX>@03J3T4000FOol00`00Oomoo`06Ool10001Ool004Moo`03001oogoo00=o
o`8000MTFP03001TFVAJ00=TFP800003I5X006AJ00ITFP03001T>F@i00AT>@H000=T>@03001T>F@i
00IT>@03001X>FPi00EX>@03001X>FPi00MX>@03001oogoo01Eoo`03001oogoo00Eoo`40005oo`00
B7oo00<007ooOol017oo0P0016AJ00<006AJI5X01FAJ10001FAJ00<006@iI3T01V@i00<006@iI3T0
0V@i1@001V@i00<006PiJ3T01VPi00<006PiJ3T01VPi00<007ooOol05goo00<007ooOol017oo0@00
0Goo0019Ool00`00Oomoo`05Ool200000fAJ001TFP06I5X00`00I5YTFP02I5X300000fAJ001T>@07
I3T00`00I3UT>@05I3T00`00I3UT>@040002I3T00`00J3UX>@06J3T00`00J3UX>@06J3T00`00Oomo
o`0HOol00`00Oomoo`03Ool10001Ool004Yoo`03001oogoo00Ioo`<000ETFP03001TFVAJ00ITFP<0
00IT>@03001T>F@i00ET>@03001T>F@i00ET>@L000=X>@03001X>FPi00MX>@03001oogoo01Uoo`03
001oogoo009oo`40005oo`00Bgoo00<007ooOol027oo0`0000=TFP00I5X026AJ00<006@iI3T01000
0V@i00<006@iI3T01F@i00<006@iI3T01V@i00<006PiJ3T00fPi2@000fPi00<007ooOol06goo00D0
07ooOomoo`00005oo`00C7oo0P002goo0P0026AJ00<006@iI3T01F@i10001F@i00<006@iI3T01V@i
00<006PiJ3T01fPi00<006PiJ3T00fPi10007Goo00D007ooOomoo`00005oo`00CWoo00<007ooOol0
2Woo0`0016AJ00<006@iI3T01f@i00<006@iI3T00`000V@i00<006@iI3T01V@i00<006PiJ3T01VPi
00<006PiJ3T01fPi00<007ooOol077oo00@007ooOol0005oo`00Cgoo00<007ooOol037oo0P0000=T
FP00I3T026@i00<006@iI3T016@i10001V@i00<006PiJ3T01fPi00<006PiJ3T01VPi00<007ooOol0
7Woo00<007ooOol00@00001@Ool00`00Oomoo`0=Ool30007I3T00`00I3UT>@06I3T00`00I3UT>@04
0002I3T00`00J3UX>@06J3T00`00J3UX>@07J3T00`00Oomoo`0OOol10001Ool10000055oo`03001o
ogoo00moo`@0009T>@03001T>F@i00IT>@03001T>F@i00ET>@L000AX>@03001X>FPi00IX>@03001o
ogoo025oo`800000DWoo00<007ooOol04Woo10001V@i00<006@iI3T01f@i00<006PiJ3T00fPi2@00
16Pi00<007ooOol087oo0`00001COol00`00Oomoo`0AOol01000Oomoogoo10000V@i00<006@iI3T0
1V@i00<006PiJ3T01fPi00<006PiJ3T00fPi10007goo10000goo001DOol00`00Oomoo`0@Ool00`00
Oomoo`05Ool40006I3T00`00J3UX>@07J3T00`00J3UX>@07J3T00`00Oomoo`0IOol40007Ool005Eo
o`03001oogoo00moo`03001oogoo00Uoo`@0009T>@03001X>FPi00MX>@03001X>FPi00IX>@03001o
ogoo01Moo`<000]oo`00EWoo00<007ooOol03Woo00<007ooOol03Goo10001fPi00<006PiJ3T01fPi
00<007ooOol04goo10003Woo001GOol00`00Oomoo`0=Ool00`00Oomoo`0AOol50002J3T00`00J3UX
>@06J3T00`00Oomoo`0@Ool4000BOol005Qoo`03001oogoo00aoo`03001oogoo01Ioo`@000MX>@03
001oogoo00aoo`@001Ioo`00FGoo00<007ooOol02goo00<007ooOol06Woo1@000VPi00<007ooOol0
27oo10006Woo001JOol2000;Ool00`00Oomoo`0OOol20008Ool3000NOol005aoo`03001oogoo00Qo
o`03001oogoo02Eoo`@0025oo`00GGoo00<007ooOol01goo00<007ooOol08Goo10009Goo001NOol0
0`00Oomoo`06Ool00`00Oomoo`0MOol4000YOol005moo`03001oogoo00Eoo`03001oogoo01Uoo`@0
02eoo`00H7oo00<007ooOol017oo00<007ooOol05Woo0`00<Goo001QOol00`00Oomoo`03Ool00`00
Oomoo`0BOol4000dOol0069oo`03001oogoo009oo`03001oogoo00ioo`@003Qoo`00Hgoo00D007oo
Oomoo`0000aoo`@003aoo`00I7oo00@007ooOol000Qoo`@0041oo`00IGoo00<007oo00001Goo0`00
A7oo001VOol200000goo000000020017Ool006Moo`8004]oo`00\
\>"],
  ImageRangeCache->{{{0, 179}, {165.75, 0}} -> {-0.0508122, -0.0227373, \
0.00546554, 0.00546554}}]
}, Closed]],

Cell[TextData[{
  "Because of the branch cut of ",
  Cell[BoxData[
      \(TraditionalForm\`\@z\)],
    FormatType->StandardForm],
  ", the function ",
  Cell[BoxData[
      \(TraditionalForm\`\@z\^2\)],
    FormatType->StandardForm],
  " is not identical to the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(z) = z\)],
    FormatType->StandardForm],
  " for a complex ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\)\(.\)\)\)],
    FormatType->StandardForm],
  " The plot on the left is the imaginary part of ",
  Cell[BoxData[
      \(TraditionalForm\`\@z\^2\)],
    FormatType->StandardForm],
  "; the one on the right is the imaginary part of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{Plot3D[
              Im[\@\((x + \[ImaginaryI]\ y)\)\^2], {x, \(-\(3\/2\)\), 
                3\/2}, {y, \(-\(3\/2\)\), 3\/2}], 
            Plot3D[Im[x + \[ImaginaryI]\ y], {x, \(-\(3\/2\)\), 
                3\/2}, {y, \(-\(3\/2\)\), 3\/2}]}]];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.21264e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -10.3125 -6.99571 ]
[.12586 .2075 0 .00429 ]
[.3345 .12542 -6.57601 -7 ]
[.3345 .12542 .48649 0 ]
[.56094 .0364 -5.92363 -7 ]
[.56094 .0364 .95137 0 ]
[.75679 .08071 0 -4.80493 ]
[.75679 .08071 10.3125 2.19507 ]
[.8565 .23339 0 -4.69099 ]
[.8565 .23339 7.0625 2.30901 ]
[.9429 .3657 0 -4.59534 ]
[.9429 .3657 6.875 2.40466 ]
[.01852 .30014 -10.3125 -2.15593 ]
[.01852 .30014 0 4.84407 ]
[.00696 .37264 -7.0625 -2.20375 ]
[.00696 .37264 0 4.79625 ]
[-0.00516 .4486 -6.875 -2.25408 ]
[-0.00516 .4486 0 4.74592 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
gsave
.12586 .2075 -71.3125 -10.9957 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -67.576 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.56863 .04703 m
.57247 .05235 L
s
gsave
.56094 .0364 -66.9236 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
gsave
.75679 .08071 -61 -8.80493 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -8.69099 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.93037 .36962 m
.92411 .37158 L
s
gsave
.9429 .3657 -61 -8.59534 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.76562 .11761 m
.76192 .11896 L
s
.78611 .14895 m
.78241 .15028 L
s
.806 .17938 m
.80229 .18068 L
s
.82531 .20892 m
.82159 .2102 L
s
.86231 .2655 m
.85857 .26675 L
s
.88003 .29262 m
.87629 .29385 L
s
.89727 .31899 m
.89353 .3202 L
s
.91405 .34465 m
.9103 .34584 L
s
.72272 .05198 m
.71904 .05338 L
s
.70024 .0176 m
.69657 .01902 L
s
.94627 .39394 m
.94251 .3951 L
s
.96176 .41762 m
.95799 .41877 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03077 .29543 m
.0369 .29308 L
s
gsave
.01852 .30014 -71.3125 -6.15593 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -68.0625 -6.20375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0072 .4442 m
.01338 .44199 L
s
gsave
-0.00516 .4486 -67.875 -6.25408 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02851 .3097 m
.03219 .30829 L
s
.02623 .32409 m
.02991 .3227 L
s
.02393 .33862 m
.02762 .33723 L
s
.02161 .35328 m
.0253 .3519 L
s
.01689 .38302 m
.02059 .38166 L
s
.01451 .3981 m
.0182 .39675 L
s
.01209 .41332 m
.01579 .41198 L
s
.00966 .42868 m
.01336 .42735 L
s
.03301 .2813 m
.03669 .27988 L
s
.03523 .26729 m
.0389 .26586 L
s
.00472 .45986 m
.00843 .45855 L
s
.00221 .47567 m
.00593 .47437 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.606 .448 .832 r
.38255 .59701 .40512 .60371 .44189 .59268 .41978 .58574 Metetra
.606 .448 .832 r
.41978 .58574 .44189 .59268 .47916 .5815 .45753 .57432 Metetra
.606 .448 .832 r
.45753 .57432 .47916 .5815 .51695 .57017 .49582 .56274 Metetra
.606 .448 .832 r
.49582 .56274 .51695 .57017 .55526 .55867 .53465 .551 Metetra
.606 .448 .832 r
.53465 .551 .55526 .55867 .59412 .54701 .57403 .53908 Metetra
.606 .448 .832 r
.57403 .53908 .59412 .54701 .63352 .53519 .61398 .527 Metetra
.606 .448 .832 r
.61398 .527 .63352 .53519 .67349 .5232 .65451 .51474 Metetra
0 0 .813 r
.65451 .51474 .67349 .5232 .72586 .71964 .70487 .68235 Metetra
.696 .276 .583 r
.70487 .68235 .72586 .71964 .76967 .70812 .74895 .67044 Metetra
.696 .276 .583 r
.74895 .67044 .76967 .70812 .81416 .69643 .79371 .65834 Metetra
.696 .276 .583 r
.79371 .65834 .81416 .69643 .85934 .68456 .83918 .64605 Metetra
.696 .276 .583 r
.83918 .64605 .85934 .68456 .90523 .6725 .88537 .63356 Metetra
.696 .276 .583 r
.88537 .63356 .90523 .6725 .95186 .66025 .93231 .62088 Metetra
.696 .276 .583 r
.93231 .62088 .95186 .66025 .99922 .6478 .98 .60798 Metetra
.606 .448 .832 r
.35921 .59007 .38255 .59701 .41978 .58574 .39692 .57857 Metetra
.606 .448 .832 r
.39692 .57857 .41978 .58574 .45753 .57432 .43516 .5669 Metetra
.606 .448 .832 r
.43516 .5669 .45753 .57432 .49582 .56274 .47395 .55506 Metetra
.606 .448 .832 r
.47395 .55506 .49582 .56274 .53465 .551 .5133 .54305 Metetra
.606 .448 .832 r
.5133 .54305 .53465 .551 .57403 .53908 .55323 .53087 Metetra
.606 .448 .832 r
.55323 .53087 .57403 .53908 .61398 .527 .59373 .51851 Metetra
.606 .448 .832 r
.59373 .51851 .61398 .527 .65451 .51474 .63484 .50597 Metetra
0 0 .809 r
.63484 .50597 .65451 .51474 .70487 .68235 .68347 .64434 Metetra
.696 .276 .583 r
.68347 .64434 .70487 .68235 .74895 .67044 .72781 .63201 Metetra
.696 .276 .583 r
.72781 .63201 .74895 .67044 .79371 .65834 .77286 .61949 Metetra
.696 .276 .583 r
.77286 .61949 .79371 .65834 .83918 .64605 .81862 .60676 Metetra
.696 .276 .583 r
.81862 .60676 .83918 .64605 .88537 .63356 .86511 .59384 Metetra
.696 .276 .583 r
.86511 .59384 .88537 .63356 .93231 .62088 .91236 .5807 Metetra
.696 .276 .583 r
.91236 .5807 .93231 .62088 .98 .60798 .96038 .56735 Metetra
.606 .448 .832 r
.33506 .5829 .35921 .59007 .39692 .57857 .37325 .57114 Metetra
.606 .448 .832 r
.37325 .57114 .39692 .57857 .43516 .5669 .412 .55921 Metetra
.606 .448 .832 r
.412 .55921 .43516 .5669 .47395 .55506 .45131 .54711 Metetra
.606 .448 .832 r
.45131 .54711 .47395 .55506 .5133 .54305 .4912 .53483 Metetra
.606 .448 .832 r
.4912 .53483 .5133 .54305 .55323 .53087 .53167 .52236 Metetra
.606 .448 .832 r
.53167 .52236 .55323 .53087 .59373 .51851 .57276 .50972 Metetra
.606 .448 .832 r
.57276 .50972 .59373 .51851 .63484 .50597 .61446 .49688 Metetra
0 0 .799 r
.61446 .49688 .63484 .50597 .68347 .64434 .66165 .60558 Metetra
.696 .276 .583 r
.66165 .60558 .68347 .64434 .72781 .63201 .70626 .59282 Metetra
.696 .276 .583 r
.70626 .59282 .72781 .63201 .77286 .61949 .75158 .57985 Metetra
.696 .276 .583 r
.75158 .57985 .77286 .61949 .81862 .60676 .79764 .56668 Metetra
.696 .276 .583 r
.79764 .56668 .81862 .60676 .86511 .59384 .84444 .5533 Metetra
.696 .276 .583 r
.84444 .5533 .86511 .59384 .91236 .5807 .892 .53969 Metetra
.696 .276 .583 r
.892 .53969 .91236 .5807 .96038 .56735 .94035 .52587 Metetra
.606 .448 .832 r
.31006 .57547 .33506 .5829 .37325 .57114 .34874 .56345 Metetra
.606 .448 .832 r
.34874 .56345 .37325 .57114 .412 .55921 .388 .55125 Metetra
.606 .448 .832 r
.388 .55125 .412 .55921 .45131 .54711 .42785 .53887 Metetra
.606 .448 .832 r
.42785 .53887 .45131 .54711 .4912 .53483 .46828 .5263 Metetra
.606 .448 .832 r
.46828 .5263 .4912 .53483 .53167 .52236 .50933 .51354 Metetra
.606 .448 .832 r
.50933 .51354 .53167 .52236 .57276 .50972 .55101 .5006 Metetra
.606 .448 .832 r
.55101 .5006 .57276 .50972 .61446 .49688 .59332 .48745 Metetra
0 0 .773 r
.59332 .48745 .61446 .49688 .66165 .60558 .63939 .56604 Metetra
.696 .276 .583 r
.63939 .56604 .66165 .60558 .70626 .59282 .68427 .55283 Metetra
.696 .276 .583 r
.68427 .55283 .70626 .59282 .75158 .57985 .72988 .53942 Metetra
.696 .276 .583 r
.72988 .53942 .75158 .57985 .79764 .56668 .77622 .52578 Metetra
.696 .276 .583 r
.77622 .52578 .79764 .56668 .84444 .5533 .82333 .51192 Metetra
.696 .276 .583 r
.82333 .51192 .84444 .5533 .892 .53969 .87122 .49784 Metetra
.696 .276 .583 r
.87122 .49784 .892 .53969 .94035 .52587 .9199 .48351 Metetra
.606 .448 .832 r
.28415 .56777 .31006 .57547 .34874 .56345 .32335 .55547 Metetra
.606 .448 .832 r
.32335 .55547 .34874 .56345 .388 .55125 .36313 .54299 Metetra
.606 .448 .832 r
.36313 .54299 .388 .55125 .42785 .53887 .40352 .53032 Metetra
.606 .448 .832 r
.40352 .53032 .42785 .53887 .46828 .5263 .44452 .51746 Metetra
.606 .448 .832 r
.44452 .51746 .46828 .5263 .50933 .51354 .48616 .5044 Metetra
.606 .448 .832 r
.48616 .5044 .50933 .51354 .55101 .5006 .52844 .49113 Metetra
.606 .448 .832 r
.52844 .49113 .55101 .5006 .59332 .48745 .57137 .47766 Metetra
0 0 .687 r
.57137 .47766 .59332 .48745 .63939 .56604 .61668 .5257 Metetra
.696 .276 .583 r
.61668 .5257 .63939 .56604 .68427 .55283 .66183 .51204 Metetra
.696 .276 .583 r
.66183 .51204 .68427 .55283 .72988 .53942 .70773 .49815 Metetra
.696 .276 .583 r
.70773 .49815 .72988 .53942 .77622 .52578 .75437 .48403 Metetra
.696 .276 .583 r
.75437 .48403 .77622 .52578 .82333 .51192 .80179 .46969 Metetra
.696 .276 .583 r
.80179 .46969 .82333 .51192 .87122 .49784 .85 .4551 Metetra
.696 .276 .583 r
.85 .4551 .87122 .49784 .9199 .48351 .89902 .44026 Metetra
.606 .448 .832 r
.2573 .55979 .28415 .56777 .32335 .55547 .29701 .54721 Metetra
.606 .448 .832 r
.29701 .54721 .32335 .55547 .36313 .54299 .33734 .53443 Metetra
.606 .448 .832 r
.33734 .53443 .36313 .54299 .40352 .53032 .37828 .52146 Metetra
.606 .448 .832 r
.37828 .52146 .40352 .53032 .44452 .51746 .41987 .50828 Metetra
.606 .448 .832 r
.41987 .50828 .44452 .51746 .48616 .5044 .4621 .4949 Metetra
.606 .448 .832 r
.4621 .4949 .48616 .5044 .52844 .49113 .505 .4813 Metetra
.606 .448 .832 r
.505 .4813 .52844 .49113 .57137 .47766 .54858 .46749 Metetra
.815 .443 .443 r
.54858 .46749 .57137 .47766 .61668 .5257 .5935 .48454 Metetra
.696 .276 .583 r
.5935 .48454 .61668 .5257 .66183 .51204 .63894 .4704 Metetra
.696 .276 .583 r
.63894 .4704 .66183 .51204 .70773 .49815 .68512 .45603 Metetra
.696 .276 .583 r
.68512 .45603 .70773 .49815 .75437 .48403 .73206 .44141 Metetra
.696 .276 .583 r
.73206 .44141 .75437 .48403 .80179 .46969 .77979 .42656 Metetra
.696 .276 .583 r
.77979 .42656 .80179 .46969 .85 .4551 .82833 .41145 Metetra
.696 .276 .583 r
.82833 .41145 .85 .4551 .89902 .44026 .87769 .39609 Metetra
.606 .448 .832 r
.22944 .55152 .2573 .55979 .29701 .54721 .26969 .53863 Metetra
.606 .448 .832 r
.26969 .53863 .29701 .54721 .33734 .53443 .31056 .52554 Metetra
.606 .448 .832 r
.31056 .52554 .33734 .53443 .37828 .52146 .35208 .51225 Metetra
.606 .448 .832 r
.35208 .51225 .37828 .52146 .41987 .50828 .39426 .49875 Metetra
.606 .448 .832 r
.39426 .49875 .41987 .50828 .4621 .4949 .43711 .48503 Metetra
.606 .448 .832 r
.43711 .48503 .4621 .4949 .505 .4813 .48064 .47109 Metetra
.606 .448 .832 r
.48064 .47109 .505 .4813 .54858 .46749 .52489 .45693 Metetra
.606 .448 .832 r
.52489 .45693 .54858 .46749 .5935 .48454 .56985 .44253 Metetra
.696 .276 .583 r
.56985 .44253 .5935 .48454 .63894 .4704 .61556 .4279 Metetra
.696 .276 .583 r
.61556 .4279 .63894 .4704 .68512 .45603 .66203 .41302 Metetra
.696 .276 .583 r
.66203 .41302 .68512 .45603 .73206 .44141 .70928 .39789 Metetra
.696 .276 .583 r
.70928 .39789 .73206 .44141 .77979 .42656 .75733 .38251 Metetra
.696 .276 .583 r
.75733 .38251 .77979 .42656 .82833 .41145 .80619 .36687 Metetra
.696 .276 .583 r
.80619 .36687 .82833 .41145 .87769 .39609 .8559 .35095 Metetra
.606 .448 .832 r
.20052 .54293 .22944 .55152 .26969 .53863 .24132 .52973 Metetra
.606 .448 .832 r
.24132 .52973 .26969 .53863 .31056 .52554 .28276 .51631 Metetra
.606 .448 .832 r
.28276 .51631 .31056 .52554 .35208 .51225 .32486 .50269 Metetra
.606 .448 .832 r
.32486 .50269 .35208 .51225 .39426 .49875 .36764 .48885 Metetra
.606 .448 .832 r
.36764 .48885 .39426 .49875 .43711 .48503 .41112 .47477 Metetra
.606 .448 .832 r
.41112 .47477 .43711 .48503 .48064 .47109 .45532 .46047 Metetra
.606 .448 .832 r
.45532 .46047 .48064 .47109 .52489 .45693 .50024 .44594 Metetra
.316 .316 .973 r
.50024 .44594 .52489 .45693 .56985 .44253 .54571 .39965 Metetra
.696 .276 .583 r
.54571 .39965 .56985 .44253 .61556 .4279 .5917 .3845 Metetra
.696 .276 .583 r
.5917 .3845 .61556 .4279 .66203 .41302 .63846 .3691 Metetra
.696 .276 .583 r
.63846 .3691 .66203 .41302 .70928 .39789 .68601 .35344 Metetra
.696 .276 .583 r
.68601 .35344 .70928 .39789 .75733 .38251 .73438 .33752 Metetra
.696 .276 .583 r
.73438 .33752 .75733 .38251 .80619 .36687 .78357 .32132 Metetra
.696 .276 .583 r
.78357 .32132 .80619 .36687 .8559 .35095 .83363 .30483 Metetra
.606 .448 .832 r
.17049 .534 .20052 .54293 .24132 .52973 .21183 .52047 Metetra
.606 .448 .832 r
.21183 .52047 .24132 .52973 .28276 .51631 .25385 .50672 Metetra
.606 .448 .832 r
.25385 .50672 .28276 .51631 .32486 .50269 .29656 .49275 Metetra
.606 .448 .832 r
.29656 .49275 .32486 .50269 .36764 .48885 .33996 .47854 Metetra
.606 .448 .832 r
.33996 .47854 .36764 .48885 .41112 .47477 .38409 .4641 Metetra
.606 .448 .832 r
.38409 .4641 .41112 .47477 .45532 .46047 .42896 .44942 Metetra
.606 .448 .832 r
.42896 .44942 .45532 .46047 .50024 .44594 .47458 .43449 Metetra
.241 .241 .976 r
.47458 .43449 .50024 .44594 .54571 .39965 .52106 .35586 Metetra
.696 .276 .583 r
.52106 .35586 .54571 .39965 .5917 .3845 .56733 .34019 Metetra
.696 .276 .583 r
.56733 .34019 .5917 .3845 .63846 .3691 .61438 .32425 Metetra
.696 .276 .583 r
.61438 .32425 .63846 .3691 .68601 .35344 .66224 .30804 Metetra
.696 .276 .583 r
.66224 .30804 .68601 .35344 .73438 .33752 .71093 .29154 Metetra
.696 .276 .583 r
.71093 .29154 .73438 .33752 .78357 .32132 .76046 .27476 Metetra
.696 .276 .583 r
.76046 .27476 .78357 .32132 .83363 .30483 .81087 .25769 Metetra
.606 .448 .832 r
.13926 .52472 .17049 .534 .21183 .52047 .18118 .51085 Metetra
.606 .448 .832 r
.18118 .51085 .21183 .52047 .25385 .50672 .22379 .49674 Metetra
.606 .448 .832 r
.22379 .49674 .25385 .50672 .29656 .49275 .2671 .4824 Metetra
.606 .448 .832 r
.2671 .4824 .29656 .49275 .33996 .47854 .31115 .46782 Metetra
.606 .448 .832 r
.31115 .46782 .33996 .47854 .38409 .4641 .35595 .45299 Metetra
.606 .448 .832 r
.35595 .45299 .38409 .4641 .42896 .44942 .4015 .43791 Metetra
.606 .448 .832 r
.4015 .43791 .42896 .44942 .47458 .43449 .44785 .42257 Metetra
.199 .199 .965 r
.44785 .42257 .47458 .43449 .52106 .35586 .49589 .31115 Metetra
.696 .276 .583 r
.49589 .31115 .52106 .35586 .56733 .34019 .54244 .29492 Metetra
.696 .276 .583 r
.54244 .29492 .56733 .34019 .61438 .32425 .58978 .27842 Metetra
.696 .276 .583 r
.58978 .27842 .61438 .32425 .66224 .30804 .63795 .26164 Metetra
.696 .276 .583 r
.63795 .26164 .66224 .30804 .71093 .29154 .68696 .24456 Metetra
.696 .276 .583 r
.68696 .24456 .71093 .29154 .76046 .27476 .73683 .22718 Metetra
.696 .276 .583 r
.73683 .22718 .76046 .27476 .81087 .25769 .78759 .20949 Metetra
.606 .448 .832 r
.10678 .51507 .13926 .52472 .18118 .51085 .14927 .50083 Metetra
.606 .448 .832 r
.14927 .50083 .18118 .51085 .22379 .49674 .19249 .48635 Metetra
.606 .448 .832 r
.19249 .48635 .22379 .49674 .2671 .4824 .23644 .47163 Metetra
.606 .448 .832 r
.23644 .47163 .2671 .4824 .31115 .46782 .28114 .45665 Metetra
.606 .448 .832 r
.28114 .45665 .31115 .46782 .35595 .45299 .32661 .44141 Metetra
.606 .448 .832 r
.32661 .44141 .35595 .45299 .4015 .43791 .37288 .42591 Metetra
.606 .448 .832 r
.37288 .42591 .4015 .43791 .44785 .42257 .41997 .41014 Metetra
.173 .173 .954 r
.41997 .41014 .44785 .42257 .49589 .31115 .47017 .26547 Metetra
.696 .276 .583 r
.47017 .26547 .49589 .31115 .54244 .29492 .517 .24868 Metetra
.696 .276 .583 r
.517 .24868 .54244 .29492 .58978 .27842 .56465 .2316 Metetra
.696 .276 .583 r
.56465 .2316 .58978 .27842 .63795 .26164 .61313 .21421 Metetra
.696 .276 .583 r
.61313 .21421 .63795 .26164 .68696 .24456 .66246 .19653 Metetra
.696 .276 .583 r
.66246 .19653 .68696 .24456 .73683 .22718 .71268 .17852 Metetra
.696 .276 .583 r
.71268 .17852 .73683 .22718 .78759 .20949 .76379 .1602 Metetra
.606 .448 .832 r
.07295 .50502 .10678 .51507 .14927 .50083 .11604 .4904 Metetra
.606 .448 .832 r
.11604 .4904 .14927 .50083 .19249 .48635 .15988 .47553 Metetra
.606 .448 .832 r
.15988 .47553 .19249 .48635 .23644 .47163 .20447 .4604 Metetra
.606 .448 .832 r
.20447 .4604 .23644 .47163 .28114 .45665 .24985 .44501 Metetra
.606 .448 .832 r
.24985 .44501 .28114 .45665 .32661 .44141 .29602 .42934 Metetra
.606 .448 .832 r
.29602 .42934 .32661 .44141 .37288 .42591 .34302 .41339 Metetra
.606 .448 .832 r
.34302 .41339 .37288 .42591 .41997 .41014 .39087 .39716 Metetra
.156 .156 .945 r
.39087 .39716 .41997 .41014 .47017 .26547 .4439 .2188 Metetra
.696 .276 .583 r
.4439 .2188 .47017 .26547 .517 .24868 .49101 .20142 Metetra
.696 .276 .583 r
.49101 .20142 .517 .24868 .56465 .2316 .53896 .18373 Metetra
.696 .276 .583 r
.53896 .18373 .56465 .2316 .61313 .21421 .58775 .16573 Metetra
.696 .276 .583 r
.58775 .16573 .61313 .21421 .66246 .19653 .63741 .14741 Metetra
.696 .276 .583 r
.63741 .14741 .66246 .19653 .71268 .17852 .68797 .12876 Metetra
.696 .276 .583 r
.68797 .12876 .71268 .17852 .76379 .1602 .73945 .10977 Metetra
.606 .448 .832 r
.03771 .49455 .07295 .50502 .11604 .4904 .08141 .47953 Metetra
.606 .448 .832 r
.08141 .47953 .11604 .4904 .15988 .47553 .12587 .46424 Metetra
.606 .448 .832 r
.12587 .46424 .15988 .47553 .20447 .4604 .17113 .44869 Metetra
.606 .448 .832 r
.17113 .44869 .20447 .4604 .24985 .44501 .21719 .43285 Metetra
.606 .448 .832 r
.21719 .43285 .24985 .44501 .29602 .42934 .26409 .41673 Metetra
.606 .448 .832 r
.26409 .41673 .29602 .42934 .34302 .41339 .31184 .40032 Metetra
.606 .448 .832 r
.31184 .40032 .34302 .41339 .39087 .39716 .36047 .3836 Metetra
.143 .143 .938 r
.36047 .3836 .39087 .39716 .4439 .2188 .41704 .17111 Metetra
.696 .276 .583 r
.41704 .17111 .4439 .2188 .49101 .20142 .46445 .15311 Metetra
.696 .276 .583 r
.46445 .15311 .49101 .20142 .53896 .18373 .51269 .1348 Metetra
.696 .276 .583 r
.51269 .1348 .53896 .18373 .58775 .16573 .5618 .11616 Metetra
.696 .276 .583 r
.5618 .11616 .58775 .16573 .63741 .14741 .61179 .09718 Metetra
.696 .276 .583 r
.61179 .09718 .63741 .14741 .68797 .12876 .6627 .07786 Metetra
.696 .276 .583 r
.6627 .07786 .68797 .12876 .73945 .10977 .71454 .05819 Metetra
.606 .448 .832 r
.00095 .48363 .03771 .49455 .08141 .47953 .04527 .46819 Metetra
.606 .448 .832 r
.04527 .46819 .08141 .47953 .12587 .46424 .09038 .45247 Metetra
.606 .448 .832 r
.09038 .45247 .12587 .46424 .17113 .44869 .13631 .43646 Metetra
.606 .448 .832 r
.13631 .43646 .17113 .44869 .21719 .43285 .18308 .42016 Metetra
.606 .448 .832 r
.18308 .42016 .21719 .43285 .26409 .41673 .23072 .40356 Metetra
.606 .448 .832 r
.23072 .40356 .26409 .41673 .31184 .40032 .27924 .38665 Metetra
.606 .448 .832 r
.27924 .38665 .31184 .40032 .36047 .3836 .32868 .36942 Metetra
.134 .134 .932 r
.32868 .36942 .36047 .3836 .41704 .17111 .3896 .12235 Metetra
.696 .276 .583 r
.3896 .12235 .41704 .17111 .46445 .15311 .43729 .10372 Metetra
.696 .276 .583 r
.43729 .10372 .46445 .15311 .51269 .1348 .48583 .08476 Metetra
.696 .276 .583 r
.48583 .08476 .51269 .1348 .5618 .11616 .53526 .06546 Metetra
.696 .276 .583 r
.53526 .06546 .5618 .11616 .61179 .09718 .58558 .0458 Metetra
.696 .276 .583 r
.58558 .0458 .61179 .09718 .6627 .07786 .63684 .02578 Metetra
.696 .276 .583 r
.63684 .02578 .6627 .07786 .71454 .05819 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
gsave
.12586 .2075 -71.3125 -10.9957 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -67.576 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.56863 .04703 m
.57247 .05235 L
s
gsave
.56094 .0364 -66.9236 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.21264e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -10.3125 -6.99571 ]
[.12586 .2075 0 .00429 ]
[.3345 .12542 -6.57601 -7 ]
[.3345 .12542 .48649 0 ]
[.56094 .0364 -5.92363 -7 ]
[.56094 .0364 .95137 0 ]
[.75679 .08071 0 -4.80493 ]
[.75679 .08071 10.3125 2.19507 ]
[.8565 .23339 0 -4.69099 ]
[.8565 .23339 7.0625 2.30901 ]
[.9429 .3657 0 -4.59534 ]
[.9429 .3657 6.875 2.40466 ]
[.01852 .30014 -10.3125 -2.15593 ]
[.01852 .30014 0 4.84407 ]
[.00696 .37264 -7.0625 -2.20375 ]
[.00696 .37264 0 4.79625 ]
[-0.00516 .4486 -6.875 -2.25408 ]
[-0.00516 .4486 0 4.74592 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
gsave
.12586 .2075 -71.3125 -10.9957 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -67.576 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.56863 .04703 m
.57247 .05235 L
s
gsave
.56094 .0364 -66.9236 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
gsave
.75679 .08071 -61 -8.80493 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -8.69099 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.93037 .36962 m
.92411 .37158 L
s
gsave
.9429 .3657 -61 -8.59534 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.76562 .11761 m
.76192 .11896 L
s
.78611 .14895 m
.78241 .15028 L
s
.806 .17938 m
.80229 .18068 L
s
.82531 .20892 m
.82159 .2102 L
s
.86231 .2655 m
.85857 .26675 L
s
.88003 .29262 m
.87629 .29385 L
s
.89727 .31899 m
.89353 .3202 L
s
.91405 .34465 m
.9103 .34584 L
s
.72272 .05198 m
.71904 .05338 L
s
.70024 .0176 m
.69657 .01902 L
s
.94627 .39394 m
.94251 .3951 L
s
.96176 .41762 m
.95799 .41877 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03077 .29543 m
.0369 .29308 L
s
gsave
.01852 .30014 -71.3125 -6.15593 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -68.0625 -6.20375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0072 .4442 m
.01338 .44199 L
s
gsave
-0.00516 .4486 -67.875 -6.25408 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02851 .3097 m
.03219 .30829 L
s
.02623 .32409 m
.02991 .3227 L
s
.02393 .33862 m
.02762 .33723 L
s
.02161 .35328 m
.0253 .3519 L
s
.01689 .38302 m
.02059 .38166 L
s
.01451 .3981 m
.0182 .39675 L
s
.01209 .41332 m
.01579 .41198 L
s
.00966 .42868 m
.01336 .42735 L
s
.03301 .2813 m
.03669 .27988 L
s
.03523 .26729 m
.0389 .26586 L
s
.00472 .45986 m
.00843 .45855 L
s
.00221 .47567 m
.00593 .47437 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.696 .276 .583 r
.37529 .77145 .39806 .80578 .43696 .79556 .41438 .76088 Metetra
.696 .276 .583 r
.41438 .76088 .43696 .79556 .47642 .78519 .45405 .75016 Metetra
.696 .276 .583 r
.45405 .75016 .47642 .78519 .51647 .77466 .4943 .73928 Metetra
.696 .276 .583 r
.4943 .73928 .51647 .77466 .55711 .76398 .53516 .72823 Metetra
.696 .276 .583 r
.53516 .72823 .55711 .76398 .59835 .75314 .57663 .71702 Metetra
.696 .276 .583 r
.57663 .71702 .59835 .75314 .64022 .74214 .61873 .70564 Metetra
.696 .276 .583 r
.61873 .70564 .64022 .74214 .68272 .73097 .66147 .69409 Metetra
.696 .276 .583 r
.66147 .69409 .68272 .73097 .72586 .71964 .70487 .68235 Metetra
.696 .276 .583 r
.70487 .68235 .72586 .71964 .76967 .70812 .74895 .67044 Metetra
.696 .276 .583 r
.74895 .67044 .76967 .70812 .81416 .69643 .79371 .65834 Metetra
.696 .276 .583 r
.79371 .65834 .81416 .69643 .85934 .68456 .83918 .64605 Metetra
.696 .276 .583 r
.83918 .64605 .85934 .68456 .90523 .6725 .88537 .63356 Metetra
.696 .276 .583 r
.88537 .63356 .90523 .6725 .95186 .66025 .93231 .62088 Metetra
.696 .276 .583 r
.93231 .62088 .95186 .66025 .99922 .6478 .98 .60798 Metetra
.696 .276 .583 r
.3521 .73648 .37529 .77145 .41438 .76088 .39139 .72556 Metetra
.696 .276 .583 r
.39139 .72556 .41438 .76088 .45405 .75016 .43125 .71447 Metetra
.696 .276 .583 r
.43125 .71447 .45405 .75016 .4943 .73928 .47172 .70322 Metetra
.696 .276 .583 r
.47172 .70322 .4943 .73928 .53516 .72823 .51279 .6918 Metetra
.696 .276 .583 r
.51279 .6918 .53516 .72823 .57663 .71702 .55449 .68021 Metetra
.696 .276 .583 r
.55449 .68021 .57663 .71702 .61873 .70564 .59682 .66844 Metetra
.696 .276 .583 r
.59682 .66844 .61873 .70564 .66147 .69409 .63981 .65648 Metetra
.696 .276 .583 r
.63981 .65648 .66147 .69409 .70487 .68235 .68347 .64434 Metetra
.696 .276 .583 r
.68347 .64434 .70487 .68235 .74895 .67044 .72781 .63201 Metetra
.696 .276 .583 r
.72781 .63201 .74895 .67044 .79371 .65834 .77286 .61949 Metetra
.696 .276 .583 r
.77286 .61949 .79371 .65834 .83918 .64605 .81862 .60676 Metetra
.696 .276 .583 r
.81862 .60676 .83918 .64605 .88537 .63356 .86511 .59384 Metetra
.696 .276 .583 r
.86511 .59384 .88537 .63356 .93231 .62088 .91236 .5807 Metetra
.696 .276 .583 r
.91236 .5807 .93231 .62088 .98 .60798 .96038 .56735 Metetra
.696 .276 .583 r
.32848 .70087 .3521 .73648 .39139 .72556 .36796 .68958 Metetra
.696 .276 .583 r
.36796 .68958 .39139 .72556 .43125 .71447 .40803 .67812 Metetra
.696 .276 .583 r
.40803 .67812 .43125 .71447 .47172 .70322 .4487 .66648 Metetra
.696 .276 .583 r
.4487 .66648 .47172 .70322 .51279 .6918 .48999 .65467 Metetra
.696 .276 .583 r
.48999 .65467 .51279 .6918 .55449 .68021 .53192 .64268 Metetra
.696 .276 .583 r
.53192 .64268 .55449 .68021 .59682 .66844 .57449 .63051 Metetra
.696 .276 .583 r
.57449 .63051 .59682 .66844 .63981 .65648 .61773 .61814 Metetra
.696 .276 .583 r
.61773 .61814 .63981 .65648 .68347 .64434 .66165 .60558 Metetra
.696 .276 .583 r
.66165 .60558 .68347 .64434 .72781 .63201 .70626 .59282 Metetra
.696 .276 .583 r
.70626 .59282 .72781 .63201 .77286 .61949 .75158 .57985 Metetra
.696 .276 .583 r
.75158 .57985 .77286 .61949 .81862 .60676 .79764 .56668 Metetra
.696 .276 .583 r
.79764 .56668 .81862 .60676 .86511 .59384 .84444 .5533 Metetra
.696 .276 .583 r
.84444 .5533 .86511 .59384 .91236 .5807 .892 .53969 Metetra
.696 .276 .583 r
.892 .53969 .91236 .5807 .96038 .56735 .94035 .52587 Metetra
.696 .276 .583 r
.30442 .66458 .32848 .70087 .36796 .68958 .34409 .65291 Metetra
.696 .276 .583 r
.34409 .65291 .36796 .68958 .40803 .67812 .38436 .64107 Metetra
.696 .276 .583 r
.38436 .64107 .40803 .67812 .4487 .66648 .42524 .62904 Metetra
.696 .276 .583 r
.42524 .62904 .4487 .66648 .48999 .65467 .46675 .61683 Metetra
.696 .276 .583 r
.46675 .61683 .48999 .65467 .53192 .64268 .50891 .60442 Metetra
.696 .276 .583 r
.50891 .60442 .53192 .64268 .57449 .63051 .55172 .59183 Metetra
.696 .276 .583 r
.55172 .59183 .57449 .63051 .61773 .61814 .59521 .57903 Metetra
.696 .276 .583 r
.59521 .57903 .61773 .61814 .66165 .60558 .63939 .56604 Metetra
.696 .276 .583 r
.63939 .56604 .66165 .60558 .70626 .59282 .68427 .55283 Metetra
.696 .276 .583 r
.68427 .55283 .70626 .59282 .75158 .57985 .72988 .53942 Metetra
.696 .276 .583 r
.72988 .53942 .75158 .57985 .79764 .56668 .77622 .52578 Metetra
.696 .276 .583 r
.77622 .52578 .79764 .56668 .84444 .5533 .82333 .51192 Metetra
.696 .276 .583 r
.82333 .51192 .84444 .5533 .892 .53969 .87122 .49784 Metetra
.696 .276 .583 r
.87122 .49784 .892 .53969 .94035 .52587 .9199 .48351 Metetra
.696 .276 .583 r
.2799 .62761 .30442 .66458 .34409 .65291 .31976 .61555 Metetra
.696 .276 .583 r
.31976 .61555 .34409 .65291 .38436 .64107 .36023 .6033 Metetra
.696 .276 .583 r
.36023 .6033 .38436 .64107 .42524 .62904 .40133 .59086 Metetra
.696 .276 .583 r
.40133 .59086 .42524 .62904 .46675 .61683 .44306 .57824 Metetra
.696 .276 .583 r
.44306 .57824 .46675 .61683 .50891 .60442 .48545 .56541 Metetra
.696 .276 .583 r
.48545 .56541 .50891 .60442 .55172 .59183 .5285 .55238 Metetra
.696 .276 .583 r
.5285 .55238 .55172 .59183 .59521 .57903 .57224 .53915 Metetra
.696 .276 .583 r
.57224 .53915 .59521 .57903 .63939 .56604 .61668 .5257 Metetra
.696 .276 .583 r
.61668 .5257 .63939 .56604 .68427 .55283 .66183 .51204 Metetra
.696 .276 .583 r
.66183 .51204 .68427 .55283 .72988 .53942 .70773 .49815 Metetra
.696 .276 .583 r
.70773 .49815 .72988 .53942 .77622 .52578 .75437 .48403 Metetra
.696 .276 .583 r
.75437 .48403 .77622 .52578 .82333 .51192 .80179 .46969 Metetra
.696 .276 .583 r
.80179 .46969 .82333 .51192 .87122 .49784 .85 .4551 Metetra
.696 .276 .583 r
.85 .4551 .87122 .49784 .9199 .48351 .89902 .44026 Metetra
.696 .276 .583 r
.25491 .58993 .2799 .62761 .31976 .61555 .29497 .57746 Metetra
.696 .276 .583 r
.29497 .57746 .31976 .61555 .36023 .6033 .33564 .5648 Metetra
.696 .276 .583 r
.33564 .5648 .36023 .6033 .40133 .59086 .37695 .55194 Metetra
.696 .276 .583 r
.37695 .55194 .40133 .59086 .44306 .57824 .4189 .53889 Metetra
.696 .276 .583 r
.4189 .53889 .44306 .57824 .48545 .56541 .46152 .52562 Metetra
.696 .276 .583 r
.46152 .52562 .48545 .56541 .5285 .55238 .50481 .51215 Metetra
.696 .276 .583 r
.50481 .51215 .5285 .55238 .57224 .53915 .5488 .49845 Metetra
.696 .276 .583 r
.5488 .49845 .57224 .53915 .61668 .5257 .5935 .48454 Metetra
.696 .276 .583 r
.5935 .48454 .61668 .5257 .66183 .51204 .63894 .4704 Metetra
.696 .276 .583 r
.63894 .4704 .66183 .51204 .70773 .49815 .68512 .45603 Metetra
.696 .276 .583 r
.68512 .45603 .70773 .49815 .75437 .48403 .73206 .44141 Metetra
.696 .276 .583 r
.73206 .44141 .75437 .48403 .80179 .46969 .77979 .42656 Metetra
.696 .276 .583 r
.77979 .42656 .80179 .46969 .85 .4551 .82833 .41145 Metetra
.696 .276 .583 r
.82833 .41145 .85 .4551 .89902 .44026 .87769 .39609 Metetra
.696 .276 .583 r
.22944 .55152 .25491 .58993 .29497 .57746 .26969 .53863 Metetra
.696 .276 .583 r
.26969 .53863 .29497 .57746 .33564 .5648 .31056 .52554 Metetra
.696 .276 .583 r
.31056 .52554 .33564 .5648 .37695 .55194 .35208 .51225 Metetra
.696 .276 .583 r
.35208 .51225 .37695 .55194 .4189 .53889 .39426 .49875 Metetra
.696 .276 .583 r
.39426 .49875 .4189 .53889 .46152 .52562 .43711 .48503 Metetra
.696 .276 .583 r
.43711 .48503 .46152 .52562 .50481 .51215 .48064 .47109 Metetra
.696 .276 .583 r
.48064 .47109 .50481 .51215 .5488 .49845 .52489 .45693 Metetra
.696 .276 .583 r
.52489 .45693 .5488 .49845 .5935 .48454 .56985 .44253 Metetra
.696 .276 .583 r
.56985 .44253 .5935 .48454 .63894 .4704 .61556 .4279 Metetra
.696 .276 .583 r
.61556 .4279 .63894 .4704 .68512 .45603 .66203 .41302 Metetra
.696 .276 .583 r
.66203 .41302 .68512 .45603 .73206 .44141 .70928 .39789 Metetra
.696 .276 .583 r
.70928 .39789 .73206 .44141 .77979 .42656 .75733 .38251 Metetra
.696 .276 .583 r
.75733 .38251 .77979 .42656 .82833 .41145 .80619 .36687 Metetra
.696 .276 .583 r
.80619 .36687 .82833 .41145 .87769 .39609 .8559 .35095 Metetra
.696 .276 .583 r
.20347 .51236 .22944 .55152 .26969 .53863 .24391 .49904 Metetra
.696 .276 .583 r
.24391 .49904 .26969 .53863 .31056 .52554 .28499 .48551 Metetra
.696 .276 .583 r
.28499 .48551 .31056 .52554 .35208 .51225 .32672 .47177 Metetra
.696 .276 .583 r
.32672 .47177 .35208 .51225 .39426 .49875 .36912 .4578 Metetra
.696 .276 .583 r
.36912 .4578 .39426 .49875 .43711 .48503 .4122 .44362 Metetra
.696 .276 .583 r
.4122 .44362 .43711 .48503 .48064 .47109 .45598 .4292 Metetra
.696 .276 .583 r
.45598 .4292 .48064 .47109 .52489 .45693 .50048 .41455 Metetra
.696 .276 .583 r
.50048 .41455 .52489 .45693 .56985 .44253 .54571 .39965 Metetra
.696 .276 .583 r
.54571 .39965 .56985 .44253 .61556 .4279 .5917 .3845 Metetra
.696 .276 .583 r
.5917 .3845 .61556 .4279 .66203 .41302 .63846 .3691 Metetra
.696 .276 .583 r
.63846 .3691 .66203 .41302 .70928 .39789 .68601 .35344 Metetra
.696 .276 .583 r
.68601 .35344 .70928 .39789 .75733 .38251 .73438 .33752 Metetra
.696 .276 .583 r
.73438 .33752 .75733 .38251 .80619 .36687 .78357 .32132 Metetra
.696 .276 .583 r
.78357 .32132 .80619 .36687 .8559 .35095 .83363 .30483 Metetra
.696 .276 .583 r
.17699 .47242 .20347 .51236 .24391 .49904 .21762 .45866 Metetra
.696 .276 .583 r
.21762 .45866 .24391 .49904 .28499 .48551 .2589 .44467 Metetra
.696 .276 .583 r
.2589 .44467 .28499 .48551 .32672 .47177 .30085 .43046 Metetra
.696 .276 .583 r
.30085 .43046 .32672 .47177 .36912 .4578 .34347 .41603 Metetra
.696 .276 .583 r
.34347 .41603 .36912 .4578 .4122 .44362 .38678 .40135 Metetra
.696 .276 .583 r
.38678 .40135 .4122 .44362 .45598 .4292 .4308 .38644 Metetra
.696 .276 .583 r
.4308 .38644 .45598 .4292 .50048 .41455 .47556 .37128 Metetra
.696 .276 .583 r
.47556 .37128 .50048 .41455 .54571 .39965 .52106 .35586 Metetra
.696 .276 .583 r
.52106 .35586 .54571 .39965 .5917 .3845 .56733 .34019 Metetra
.696 .276 .583 r
.56733 .34019 .5917 .3845 .63846 .3691 .61438 .32425 Metetra
.696 .276 .583 r
.61438 .32425 .63846 .3691 .68601 .35344 .66224 .30804 Metetra
.696 .276 .583 r
.66224 .30804 .68601 .35344 .73438 .33752 .71093 .29154 Metetra
.696 .276 .583 r
.71093 .29154 .73438 .33752 .78357 .32132 .76046 .27476 Metetra
.696 .276 .583 r
.76046 .27476 .78357 .32132 .83363 .30483 .81087 .25769 Metetra
.696 .276 .583 r
.14998 .4317 .17699 .47242 .21762 .45866 .19081 .41747 Metetra
.696 .276 .583 r
.19081 .41747 .21762 .45866 .2589 .44467 .23229 .40301 Metetra
.696 .276 .583 r
.23229 .40301 .2589 .44467 .30085 .43046 .27444 .38832 Metetra
.696 .276 .583 r
.27444 .38832 .30085 .43046 .34347 .41603 .31729 .37339 Metetra
.696 .276 .583 r
.31729 .37339 .34347 .41603 .38678 .40135 .36083 .35821 Metetra
.696 .276 .583 r
.36083 .35821 .38678 .40135 .4308 .38644 .4051 .34278 Metetra
.696 .276 .583 r
.4051 .34278 .4308 .38644 .47556 .37128 .45012 .3271 Metetra
.696 .276 .583 r
.45012 .3271 .47556 .37128 .52106 .35586 .49589 .31115 Metetra
.696 .276 .583 r
.49589 .31115 .52106 .35586 .56733 .34019 .54244 .29492 Metetra
.696 .276 .583 r
.54244 .29492 .56733 .34019 .61438 .32425 .58978 .27842 Metetra
.696 .276 .583 r
.58978 .27842 .61438 .32425 .66224 .30804 .63795 .26164 Metetra
.696 .276 .583 r
.63795 .26164 .66224 .30804 .71093 .29154 .68696 .24456 Metetra
.696 .276 .583 r
.68696 .24456 .71093 .29154 .76046 .27476 .73683 .22718 Metetra
.696 .276 .583 r
.73683 .22718 .76046 .27476 .81087 .25769 .78759 .20949 Metetra
.696 .276 .583 r
.12243 .39015 .14998 .4317 .19081 .41747 .16344 .37544 Metetra
.696 .276 .583 r
.16344 .37544 .19081 .41747 .23229 .40301 .20513 .3605 Metetra
.696 .276 .583 r
.20513 .3605 .23229 .40301 .27444 .38832 .2475 .34531 Metetra
.696 .276 .583 r
.2475 .34531 .27444 .38832 .31729 .37339 .29056 .32986 Metetra
.696 .276 .583 r
.29056 .32986 .31729 .37339 .36083 .35821 .33434 .31417 Metetra
.696 .276 .583 r
.33434 .31417 .36083 .35821 .4051 .34278 .37886 .29821 Metetra
.696 .276 .583 r
.37886 .29821 .4051 .34278 .45012 .3271 .42413 .28198 Metetra
.696 .276 .583 r
.42413 .28198 .45012 .3271 .49589 .31115 .47017 .26547 Metetra
.696 .276 .583 r
.47017 .26547 .49589 .31115 .54244 .29492 .517 .24868 Metetra
.696 .276 .583 r
.517 .24868 .54244 .29492 .58978 .27842 .56465 .2316 Metetra
.696 .276 .583 r
.56465 .2316 .58978 .27842 .63795 .26164 .61313 .21421 Metetra
.696 .276 .583 r
.61313 .21421 .63795 .26164 .68696 .24456 .66246 .19653 Metetra
.696 .276 .583 r
.66246 .19653 .68696 .24456 .73683 .22718 .71268 .17852 Metetra
.696 .276 .583 r
.71268 .17852 .73683 .22718 .78759 .20949 .76379 .1602 Metetra
.696 .276 .583 r
.09431 .34776 .12243 .39015 .16344 .37544 .13552 .33255 Metetra
.696 .276 .583 r
.13552 .33255 .16344 .37544 .20513 .3605 .17741 .3171 Metetra
.696 .276 .583 r
.17741 .3171 .20513 .3605 .2475 .34531 .21999 .3014 Metetra
.696 .276 .583 r
.21999 .3014 .2475 .34531 .29056 .32986 .26328 .28543 Metetra
.696 .276 .583 r
.26328 .28543 .29056 .32986 .33434 .31417 .30729 .26919 Metetra
.696 .276 .583 r
.30729 .26919 .33434 .31417 .37886 .29821 .35206 .25268 Metetra
.696 .276 .583 r
.35206 .25268 .37886 .29821 .42413 .28198 .39758 .23588 Metetra
.696 .276 .583 r
.39758 .23588 .42413 .28198 .47017 .26547 .4439 .2188 Metetra
.696 .276 .583 r
.4439 .2188 .47017 .26547 .517 .24868 .49101 .20142 Metetra
.696 .276 .583 r
.49101 .20142 .517 .24868 .56465 .2316 .53896 .18373 Metetra
.696 .276 .583 r
.53896 .18373 .56465 .2316 .61313 .21421 .58775 .16573 Metetra
.696 .276 .583 r
.58775 .16573 .61313 .21421 .66246 .19653 .63741 .14741 Metetra
.696 .276 .583 r
.63741 .14741 .66246 .19653 .71268 .17852 .68797 .12876 Metetra
.696 .276 .583 r
.68797 .12876 .71268 .17852 .76379 .1602 .73945 .10977 Metetra
.696 .276 .583 r
.06562 .30449 .09431 .34776 .13552 .33255 .10702 .28878 Metetra
.696 .276 .583 r
.10702 .28878 .13552 .33255 .17741 .3171 .14911 .2728 Metetra
.696 .276 .583 r
.14911 .2728 .17741 .3171 .21999 .3014 .1919 .25656 Metetra
.696 .276 .583 r
.1919 .25656 .21999 .3014 .26328 .28543 .23541 .24005 Metetra
.696 .276 .583 r
.23541 .24005 .26328 .28543 .30729 .26919 .27966 .22325 Metetra
.696 .276 .583 r
.27966 .22325 .30729 .26919 .35206 .25268 .32467 .20617 Metetra
.696 .276 .583 r
.32467 .20617 .35206 .25268 .39758 .23588 .37046 .18879 Metetra
.696 .276 .583 r
.37046 .18879 .39758 .23588 .4439 .2188 .41704 .17111 Metetra
.696 .276 .583 r
.41704 .17111 .4439 .2188 .49101 .20142 .46445 .15311 Metetra
.696 .276 .583 r
.46445 .15311 .49101 .20142 .53896 .18373 .51269 .1348 Metetra
.696 .276 .583 r
.51269 .1348 .53896 .18373 .58775 .16573 .5618 .11616 Metetra
.696 .276 .583 r
.5618 .11616 .58775 .16573 .63741 .14741 .61179 .09718 Metetra
.696 .276 .583 r
.61179 .09718 .63741 .14741 .68797 .12876 .6627 .07786 Metetra
.696 .276 .583 r
.6627 .07786 .68797 .12876 .73945 .10977 .71454 .05819 Metetra
.696 .276 .583 r
.03634 .26033 .06562 .30449 .10702 .28878 .07793 .24409 Metetra
.696 .276 .583 r
.07793 .24409 .10702 .28878 .14911 .2728 .12022 .22757 Metetra
.696 .276 .583 r
.12022 .22757 .14911 .2728 .1919 .25656 .16322 .21077 Metetra
.696 .276 .583 r
.16322 .21077 .1919 .25656 .23541 .24005 .20695 .19369 Metetra
.696 .276 .583 r
.20695 .19369 .23541 .24005 .27966 .22325 .25144 .17632 Metetra
.696 .276 .583 r
.25144 .17632 .27966 .22325 .32467 .20617 .29669 .15864 Metetra
.696 .276 .583 r
.29669 .15864 .32467 .20617 .37046 .18879 .34274 .14065 Metetra
.696 .276 .583 r
.34274 .14065 .37046 .18879 .41704 .17111 .3896 .12235 Metetra
.696 .276 .583 r
.3896 .12235 .41704 .17111 .46445 .15311 .43729 .10372 Metetra
.696 .276 .583 r
.43729 .10372 .46445 .15311 .51269 .1348 .48583 .08476 Metetra
.696 .276 .583 r
.48583 .08476 .51269 .1348 .5618 .11616 .53526 .06546 Metetra
.696 .276 .583 r
.53526 .06546 .5618 .11616 .61179 .09718 .58558 .0458 Metetra
.696 .276 .583 r
.58558 .0458 .61179 .09718 .6627 .07786 .63684 .02578 Metetra
.696 .276 .583 r
.63684 .02578 .6627 .07786 .71454 .05819 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
gsave
.12586 .2075 -71.3125 -10.9957 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -67.576 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.56863 .04703 m
.57247 .05235 L
s
gsave
.56094 .0364 -66.9236 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  FormatType->StandardForm,
  ImageSize->{288, 111.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ka000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001ROol2002<Ool2000^Ool0
051oo`03001oogoo00aoo`D007]oo`03001oogoo00]oo`D002ioo`00D7oo00<007ooOol02Woo1@00
00=I4P000000NWoo00<007ooOol02Goo0P0000Aoo`00001I4P8002eoo`00D7oo00<007ooOol01goo
1@0015TB0`00NGoo00<007ooOol01Woo0`0000=oo`0000000eTB0`00;7oo001@Ool00`00Oomoo`05
Ool50006FA83001iOol00`00Oomoo`04Ool60005FA83000/Ool005Eoo`H00003FA8005TB00EI4P04
001I4P00001lOol300001Woo00000000FA8000EI4P04001I4P00000[Ool0059oo`H000EI4P03001I
4UTB00=I4P05001I4P00Ool0001hOol70005FA800`00FA9I4P02FA801@00FA8007oo0000:Woo001@
Ool70007FA800`00FA9I4P02FA800`00FA800002001fOol600000eTB001I4P05FA800`00FA9I4P02
FA801@00FA8007oo0000:Woo001=Ool50005FA800`00FA9I4P04FA800`00FA9I4P02FA801P00FA80
0000Ool000Aoo`<00003Ool007oo06Qoo`D000II4P03001I4UTB00AI4P03001I4UTB009I4P<00003
Ool007oo00=oo`<0009oo`03001oogoo01eoo`00Bgoo1P001UTB00<005TBFA801ETB00<005TBFA80
0`0000AI4P00Ool000Qoo`03001oogoo06Eoo`H000MI4P03001I4UTB00AI4P03001I4UTB00<00004
FA8007oo0009Ool00`00Oomoo`0MOol004Qoo`D000AI4P03001I4UTB00AI4P03001I4UTB00=I4P@0
0003FA8005TB009I4P03001oo`0000Moo`03001oogoo069oo`D000AI4P03001I4UTB00EI4P03001I
4UTB00=I4P<0009I4P06001I4UTB001oo`0027oo00<007ooOol07Goo0016Ool200000goo00000006
FA800`00FA9I4P04FA800`00FA9I4P030002FA801000FA9I4P000eTB00@007oo000000Ioo`03001o
ogoo061oo`800003Ool0000000II4P03001I4UTB00EI4P03001I4UTB00<00003FA8005TB009I4P05
001I4UTB001oo`020007Ool00`00Oomoo`0MOol003=oo`8000ioo`H00003FA8005TB00II4P03001I
4UTB00=I4P<000II4P03001I4P0000AI4P03001oo`0005Moo`8000eoo`H00003FA8005TB00II4P03
001I4UTB00AI4P<000EI4P04001I4UTB0003FA800`00Ool0000WOol003=oo`03001oo`0000]oo`D0
00EI4P03001I4UTB00AI4P04001I4UTBFA8200000eTB001I4P06FA800`00FA800004FA801000Oomo
o`00EWoo00<007oo00002Woo0P0000=oo`0000001ETB00<005TBFA801ETB00@005TBFA9I4P800003
FA8005TB00EI4P04001I4UTB0003FA801000Oomoo`009Woo000cOol00`00Ool00008Ool500000eTB
001I4P05FA800`00FA9I4P04FA801000FA80000015TB00<005TBFA801ETB0P0015TB0P000Woo00<0
07ooOol0Dgoo00<007oo00001goo1P0000=I4P00FA801ETB00<005TBFA8015TB00@005TB000000AI
4P03001I4UTB00AI4P03001I4P0000=I4P80009oo`03001oogoo02=oo`00=7oo0P001Goo1@001ETB
00<005TBFA8015TB00<005TBFA800eTB0P001eTB00<005TBFA8015TB0P0000II4P00000005TB0002
Ool00`00Oomoo`1DOol20004Ool60005FA800`00FA9I4P03FA800`00FA9I4P04FA820006FA800`00
FA9I4P04FA800`00FA80000300001ETB001oogoo00009Goo000iOol20003Ool00`00FA9I4P05FA80
0`00FA9I4P03FA800`00FA9I4P0300000eTB001I4P06FA800`00FA9I4P04FA830005FA801000Oomo
o`00FGoo0P0000Eoo`00001I4P0000II4P03001I4UTB00AI4P03001I4UTB00<00003FA8005TB00II
4P03001I4UTB00=I4P<000EI4P04001oogoo000TOol003Ioo`@000Aoo`8000II4P03001I4UTB00=I
4P<000EI4P03001I4UTB00EI4P03001I4UTB00<00003FA80000000EI4P05001oogooOol0001EOol6
0004FA800`00FA9I4P04FA800`00FA9I4P03FA830005FA800`00FA9I4P04FA800`00FA9I4P030000
0eTB00000005FA801@00Oomoogoo00008goo000dOol20003Ool01@00Oomoogoo00000Q2M00<005TB
FA8015TB00<005TB00000P0000=I4P00FA801ETB00<005TBFA801ETB0`001ETB00<005TBFA8015TB
00@007ooOol005=oo`80009oo`<000EI4P03001I4UTB00AI4P03001I4UTB00<00003FA8005TB00EI
4P03001I4UTB00AI4P<000EI4P03001I4UTB00AI4P04001oogoo000SOol0035oo`@000Qoo`04000@
WA2M0006FA820005FA800`00FA9I4P04FA801000FA9I4UTB0`0000=I4P00FA801ETB00<005TBFA80
15TB00<007ooOol00P00Cgoo1`0000=I4P00FA801UTB00<005TBFA800eTB0`001ETB00<005TBFA80
15TB00@005TBFA9I4P800003FA8005TB00EI4P03001I4UTB00AI4P03001oogoo0080029oo`00;goo
0P0037oo00D0012M49d@W@00009I4P<00003FA8005TB00EI4P03001I4UTB00=I4P04001I4P000005
FA800`00FA9I4P03FA820005FA820003Ool00`00Oomoo`1:Ool2000017oo000000001ETB00<005TB
FA8015TB00<005TBFA800`0000=I4P00FA801ETB00<005TBFA8015TB00@005TB000000AI4P03001I
4UTB00=I4P8000EI4P8000=oo`03001oogoo01moo`00;7oo10003Goo00<0012M49d00Q2M0P001ETB
00<005TBFA800eTB00<005TBFA800eTB0P001eTB00<005TBFA800eTB0P000UTB0`0000=I4P00Ool0
0Woo00<007ooOol0Agoo1P0000=I4P00FA801UTB00<005TBFA800eTB0`001ETB00<005TBFA8015TB
00<005TBFA800eTB0P001UTB00<005TBFA800eTB0P000UTB0`0000=I4P00Ool00Woo00<007ooOol0
7goo000FOol30002Ool00`00Oomoo`0<Ool2000@Ool00`0049d@W@0349d00`00FA9I4P04FA800`00
FA9I4P04FA800`00FA80000200000eTB001I4P07FA800`00FA9I4P02FA840005FA801@00Oomoogoo
0000<Woo0`000Woo00<007ooOol037oo0P0000=oo`0000001ETB00<005TBFA8015TB00<005TBFA80
0`0000=I4P00FA801ETB00<005TBFA8015TB00<005TBFA800`0000=I4P00FA801UTB00<005TBFA80
0UTB10001ETB00D007ooOomoo`00021oo`006goo00<007ooOol02Goo10004Goo00<0012M49d00a2M
0P001UTB00<005TBFA800eTB0P001ETB00<005TBFA801ETB00<005TBFA800`0000=I4P00FA801ETB
00D007ooOomoo`0003Moo`03001oogoo00Uoo`H00003FA8005TB00EI4P03001I4UTB00=I4P<000EI
4P03001I4UTB00AI4P03001I4UTB00=I4P<000EI4P03001I4UTB00AI4P03001I4UTB00D000II4P05
001oogooOol0000POol001]oo`03001oogoo00Moo`8001Eoo`03000@WA2M008@W@03000@WP0000II
4P03001I4UTB00<00003FA8005TB00EI4P03001I4UTB00AI4P<0009I4P04001I4UTB0006FA801@00
Oomoogoo0000=Woo00<007ooOol01goo0P0000=oo`0000001ETB00<005TBFA800eTB00@005TBFA9I
4P800003FA8005TB00EI4P03001I4UTB00AI4P03001I4UTB00<00003FA8005TB00II4P03001I4UTB
00=I4P<000=I4P03001I4P0000II4P05001oogooOol0000OOol001]oo`03001oogoo00Aoo`@001Io
o`03000@WA2M008@W@04000@WQ2N0005FA830005FA800`00FA9I4P04FA800`00FA9I4P0300000eTB
001I4P02FA801000FA9I4P001UTB00<007ooOol00Woo00<007ooOol0<goo00<007ooOol017oo1P00
00=I4P00FA8015TB00<005TBFA8015TB00<005TB000015TB00<005TBFA8015TB00<005TBFA800eTB
0`001ETB00<005TBFA8015TB00<005TBFA800`0000=I4P00FA800eTB00<005TB00001UTB00<007oo
Ool00Woo00<007ooOol077oo000OOol3000JOol00`0049d@W@0249d0100049h@WP000UTB0`0000=I
4P00FA801ETB00<005TBFA8015TB0`001ETB00@005TBFA8000=I4P03001I4UTB00=I4P8000=oo`03
001oogoo03Moo`H000EI4P03001I4UTB00=I4P03001I4UTB00=I4P8000II4P03001I4UTB00=I4P03
001I4UTB00<00003FA8005TB00EI4P03001I4UTB00AI4P<000EI4P05001I4UTBFA800002FA800`00
FA9I4P03FA820003Ool2000MOol001eoo`800003Ool007oo01Uoo`03000@WA2M00<@W@04000@WQ2N
49h20005FA800`00FA9I4P04FA801000FA9I4UTB0P0000=I4P00FA801ETB00@005TBFA8000=I4P03
001I4UTB00<00003FA8007oo00=oo`03001oogoo009oo`80031oo`D00003FA8005TB00EI4P03001I
4UTB00=I4P03001I4UTB00<00003FA8005TB00EI4P03001I4UTB00=I4P<000EI4P03001I4UTB00AI
4P04001I4UTBFA8200000eTB001I4P05FA801@00FA9I4UTB00000UTB00<005TBFA800`0000=I4P00
Ool00goo00<007ooOol00Woo0P005goo000JOol3000NOol00`0049d@W@0249d00`0049h@WP0249h0
0`00FA9I4P04FA800`00FA9I4P04FA801000FA80000015TB00<005TBFA8015TB00<005TB00000eTB
0`001ETB00<007ooOol00Woo00L007ooOomoo`00Ool0000/Ool50005FA800`00FA9I4P04FA800`00
FA9I4P02FA830005FA800`00FA9I4P04FA800`00FA80000200000eTB001I4P05FA800`00FA9I4P04
FA801000FA80000015TB00<005TBFA8015TB00@005TBFA80009I4P<000EI4P03001oogoo009oo`07
001oogooOol007oo00005Woo000HOol200000goo001oo`0NOol00`0049d@W@0249d00`0049h@WP02
49h20006FA800`00FA9I4P03FA820006FA800`00FA9I4P04FA800`00FA80000300000eTB001I4P05
FA800`00Oomoo`02Ool20002Ool00`00Ool0000ZOol500000eTB001I4P05FA800`00FA9I4P03FA80
0`00FA80000200000eTB001I4P06FA800`00FA9I4P03FA820005FA800`00FA9I4P04FA800`00FA9I
4P03FA820006FA800`00FA9I4P04FA800`00FA9I4P0300000eTB001I4P05FA800`00Oomoo`02Ool2
0002Ool00`00Ool0000FOol001Eoo`<002=oo`03000@WA2M008@W@07000@WQ2N49h0012N00001UTB
00<005TBFA800`0000=I4P00FA801UTB00<005TBFA800eTB0`001ETB00<005TBFA8015TB00@007oo
Oomoo`8000=oo`8002Moo`D000EI4P03001I4UTB00=I4P03001I4UTB00=I4P8000EI4P03001I4UTB
00AI4P03001I4UTB00<00003FA8005TB00EI4P03001I4UTB00=I4P03001I4UTB00<00003FA8005TB
00II4P03001I4UTB00=I4P@000AI4P03001I4UTB00AI4P04001oogooOol20003Ool2000FOol001Ao
o`<002=oo`03000@WA2M008@W@03000@WQ2N008@WP04000@WQ2N0005FA830005FA800`00FA9I4P04
FA800`00FA9I4P060005FA800`00FA9I4P04FA800`00Oomoo`03Ool00`00Oomoo`0XOol400000eTB
001I4P05FA800`00FA9I4P03FA800`00FA80000200000eTB001I4P05FA800`00FA9I4P03FA830005
FA800`00FA9I4P03FA800`00FA9I4P03FA830005FA800`00FA9I4P04FA800`00FA9I4P0500000eTB
001I4P03FA800`00FA9I4P04FA800`00Oomoo`03Ool00`00Oomoo`0HOol001Aoo`03001oo`0002=o
o`03000@WA2M008@W@03000@WQ2N008@WP04000@WQ2N0002FA8300000eTB001I4P06FA800`00FA9I
4P03FA840004FA820004FA800`00FA9I4P03FA830004Ool00`00Oomoo`0XOol00`00FA9I4P03FA80
0`00FA9I4P03FA800`00FA9I4P03FA820005FA800`00FA9I4P04FA800`00FA80000200000eTB001I
4P05FA800`00FA9I4P04FA800`00FA80000200000eTB001I4P06FA800`00FA9I4P03FA850003FA80
0`00FA800004FA800`00FA9I4P03FA820004Ool00`00Oomoo`0HOol001=oo`80009oo`03001oogoo
021oo`03000@WA2M008@W@05000@WQ2N49h0000449h20005FA800`00FA9I4P04FA800`00FA9I4P05
0006FA800`00FA800004FA800`00FA8000020002FA800`00Oomoo`02Ool2000YOol00`00FA9I4P03
FA800`00FA9I4P04FA800`00FA80000200000eTB001I4P05FA800`00FA9I4P03FA820005FA800`00
FA9I4P04FA800`00FA9I4P03FA820005FA800`00FA9I4P04FA800`00FA9I4P050006FA801000FA9I
4P000eTB00<005TBFA800`0000=I4P00Ool017oo00<007ooOol05goo000DOol01@00Oomoogoo0000
8Goo00<0012M49d00Q2M00D0012N49h@WP0000@@WP03001I4UTB00EI4P03001I4UTB00=I4P@000AI
4P03001I4UTB00=I4P04001I4UTB0002FA830006FA800`00Oomoo`02Ool00`00Oomoo`0WOol20005
FA800`00FA9I4P03FA820005FA800`00FA9I4P03FA800`00FA9I4P0300000eTB001I4P04FA800`00
FA9I4P04FA800`00FA9I4P0300000eTB001I4P05FA800`00FA9I4P03FA850003FA800`00FA9I4P04
FA801000FA9I4P000UTB0`001ETB00<007ooOol00Woo00<007ooOol05goo000COol00`00Oomoo`03
Ool00`00Oomoo`0MOol00`0049d@W@0249d00`0049h@WP0249h01`0049h@WQ2N000D_P0000II4P03
001I4UTB00D000II4P03001I4UTB00AI4P03001I4P0000800003FA8005TB00II4P03001oogoo00=o
o`03001oogoo02Ioo`03001oo`0000AI4P03001I4UTB00<00003FA8005TB00EI4P03001I4UTB009I
4P<000EI4P03001I4UTB00=I4P03001I4UTB00=I4P<000EI4P03001I4UTB00=I4P03001I4UTB00D0
00II4P03001I4UTB00AI4P03001I4UTB00<00003FA8005TB00II4P03001oogoo009oo`03001oogoo
01Ioo`004goo0P001Goo00<007ooOol077oo00<0012M49d00Q2M00<0012N49h00Q2N00D0012N49h@
WP00008D_P03001I4UTB00=I4P@000AI4P03001I4UTB00AI4P03001I4UTB009I4P<00003FA8005TB
009I4P03001I4UTB00AI4P03001oogoo00=oo`8002Ioo`800003Ool005TB009I4P@000EI4P03001I
4UTB00=I4P03001I4P0000800003FA8005TB00EI4P03001I4UTB00=I4P03001I4UTB00<00003FA80
05TB00II4P03001I4UTB009I4PD000=I4P03001I4UTB00AI4P03001I4UTB00=I4P<00003FA8005TB
009I4P03001I4UTB00AI4P03001oogoo00=oo`03001oogoo01Eoo`004goo00<007ooOol01Goo00<0
07ooOol06goo00<0012M49d00Q2M00D0012N49h@WP0000@@WP04000D_QBn0002FA850006FA800`00
FA9I4P04FA800`00FA80000200000eTB001I4P02FA801@00FA9I4UTB00001ETB0P001Goo00<007oo
Ool097oo00@007ooOomoo`<0009I4P03001I4UTB00EI4P03001I4UTB009I4P8000EI4P03001I4UTB
00AI4P03001I4UTB009I4P<000EI4P03001I4UTB00AI4P03001I4P0000D000EI4P03001I4UTB00AI
4P03001I4UTB00<00003FA8005TB009I4P05001I4UTBFA800005FA820004Ool00`00Oomoo`0EOol0
00Uoo`<0009oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01Yoo`03000@WA2M008@W@05
000@WQ2N49h0000349h00`005;hD_P025;h40003FA800`00FA9I4P04FA800`00FA9I4P03FA820005
FA801@00FA9I4UTB00000UTB00<005TBFA800`0000=I4P00Ool01Goo00<007ooOol06Goo0`000Woo
00<007ooOol00Woo00D007ooOomoo`0000EI4P03001I4UTB00AI4P03001I4P0000800003FA8005TB
00EI4P03001I4UTB00=I4P03001I4P0000800003FA8005TB00II4P03001I4UTB00=I4PD0009I4P03
001I4UTB00AI4P03001I4UTB00=I4P<000EI4P04001I4UTB0003FA800`00FA9I4P0300000eTB001o
o`04Ool00`00Oomoo`0DOol000ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo01Uoo`05
000@WA2M49d0000449h01@0049h@WQ2N00000QBn0`001UTB00<005TBFA8015TB00<005TBFA800`00
00=I4P00FA801ETB00@005TBFA80009I4P<000EI4P03001oogoo00Aoo`03001oogoo01eoo`03001o
ogoo009oo`03001oogoo009oo`03001I4UTB00=I4P03001I4UTB00=I4P8000EI4P03001I4UTB00=I
4P03001I4UTB00=I4P8000EI4P03001I4UTB00AI4P03001I4UTB00D000EI4P03001I4UTB00AI4P03
001I4UTB00<00003FA8005TB00II4P04001I4UTB0002FA830005FA800`00Oomoo`03Ool00`00Oomo
o`0COol000ioo`04001oogooOol2000:Ool00`00Oomoo`0GOol00`0049d@W@0249d00`0049h@WP02
49h0100049h@WQ2N0`0000@D_P006=h000II4P03001I4UTB00=I4P<000EI4P03001I4UTB00=I4P03
001I4UTB00<00003FA8005TB00EI4P03001oogoo00Aoo`03001oogoo01eoo`03001oogoo009oo`03
001oogoo00=oo`03001I4UTB00=I4P03001I4P0000800003FA8005TB00EI4P03001I4UTB00=I4P03
001I4P0000800003FA8005TB00EI4P03001I4UTB00=I4PD000=I4P03001I4UTB00=I4P03001I4UTB
00=I4P<000EI4P03001I4UTB00AI4P03001I4UTB00<00003FA8005TB00EI4P03001oogoo00=oo`03
001oogoo01=oo`003Woo00@007ooOomoo`8000]oo`03001oogoo01Ioo`03000@WA2M008@W@06000@
WQ2N49h0012N0`0011Bn00<001SN00001UTB00<005TBFA800`0000=I4P00FA801ETB00<005TBFA80
0eTB0`000UTB00@005TBFA8000II4P03001oogoo00Aoo`03001oogoo01aoo`03001oogoo009oo`03
001oogoo00=oo`03001I4UTB00=I4P8000EI4P03001I4UTB00AI4P04001I4UTBFA830005FA800`00
FA9I4P04FA800`00FA8000040006FA800`00FA9I4P03FA800`00FA9I4P0300000eTB001I4P06FA80
0`00FA9I4P03FA830002FA801000FA9I4P001ETB00<007ooOol017oo00<007ooOol04Woo000BOol0
0`00Oomoo`0;Ool00`00Oomoo`0EOol01@0049d@WA2M0000112N0P000Q2N00<001Bn5;h00QBn00@0
01SN6=h000EI4P<000EI4P03001I4UTB00=I4P03001I4UTB00<00003FA8005TB00=I4P03001I4P00
00II4P03001oogoo00Eoo`03001oogoo01moo`8000Ioo`03001I4P0000800003FA8005TB00EI4P03
001I4UTB00=I4P@0009I4P03001I4UTB00AI4P03001I4UTB00=I4P@000=I4P03001I4UTB00AI4P03
001I4UTB009I4P<000EI4P03001I4UTB00AI4P03001I4UTB00<00003FA8005TB009I4P04001I4UTB
0006FA800`00Oomoo`04Ool00`00Oomoo`0AOol0019oo`03001oogoo00aoo`03001oogoo01Aoo`06
000@WA2M49d0012N10000a2N00D001Bn5;hD_P0000<HgP03001I4UTB00<00003FA8005TB00II4P03
001I4UTB009I4P<000EI4P05001I4UTBFA800002FA800`00FA9I4P03FA820006Ool00`00Oomoo`04
Ool00`00Oomoo`0HOol20007Ool00`00FA9I4P03FA800`00FA9I4P03FA800`00FA9I4P0300000eTB
001I4P04FA800`00FA9I4P03FA800`00FA9I4P050005FA800`00FA9I4P04FA800`00FA8000020000
0eTB001I4P06FA800`00FA9I4P03FA830005FA801`00FA9I4UTB001I4P0000EI4P8000Ioo`03001o
ogoo00Aoo`03001oogoo00Yoo`004Woo00<007ooOol03Goo00<007ooOol04Woo00@0012M49d@W@<0
008@WP05000@WQ2N49h000045;h00`006=hHgP026=h20005FA800`00FA9I4P04FA800`00FA800002
00000eTB001I4P05FA800`00FA9I4P02FA800`00FA800002FA8300000eTB001oo`06Ool00`00Oomo
o`03Ool00`00Oomoo`0HOol00`00Oomoo`06Ool00`00FA9I4P04FA800`00FA9I4P02FA830005FA80
0`00FA9I4P03FA800`00FA9I4P02FA850003FA800`00FA9I4P03FA800`00FA9I4P03FA820005FA80
0`00FA9I4P04FA800`00FA9I4P0300000eTB001I4P05FA800`00FA9I4P02FA801000FA8005TB0`00
00=I4P00Ool01Woo00<007ooOol00goo00<007ooOol02Woo000BOol00`00Oomoo`0>Ool00`00Oomo
o`0@Ool500000a2M000@WP0249h01@0049h@WQ2N000011Bn00<001SN6=h00QSN00<005TBFA801ETB
00<005TBFA800eTB0P001ETB00<005TBFA8015TB00<005TBFA800UTB10001ETB00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol067oo0P0027oo00<005TBFA800eTB00<005TB00000P0000=I4P00
FA801ETB00<005TBFA800eTB00<005TB000010001eTB00<005TBFA800UTB00<005TBFA800`0000=I
4P00FA801ETB00<005TBFA800eTB0`001ETB00<005TBFA800eTB00<005TBFA800UTB10001ETB00<0
07ooOol01Goo00<007ooOol00Woo00<007ooOol02Woo000;Ool20004Ool00`00Oomoo`0@Ool00`00
Oomoo`0<Ool5000014gJ00000000112N00D0012N49h@WP0000<D_P03000HgQSN008HgP03000Lo`00
00II4P03001I4UTB00<00003FA8005TB00AI4P03001I4UTB00AI4P03001I4UTB00<00003FA8005TB
00EI4P03001oogoo00Aoo`8000Aoo`03001oogoo015oo`8000Eoo`03001oogoo00Qoo`03001I4UTB
009I4P8000EI4P03001I4UTB00AI4P03001I4UTB009I4P@000=I4P03001I4UTB00AI4P04001I4UTB
FA840005FA800`00FA9I4P03FA800`00FA9I4P0300000eTB001I4P05FA800`00FA9I4P04FA800`00
FA8000040006FA800`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool000]oo`03001oo`00
00=oo`80019oo`03001oogoo00Qoo`D000E=fP<000<@WP04000@WQ2N00045;h00`006=hHgP026=h0
10007?lLo`001ETB0`001ETB00<005TBFA800eTB00<005TBFA800eTB0`000eTB00<005TB00001UTB
00<007ooOol01Goo00<007ooOol05Goo00<007oo000017oo00<007ooOol027oo00<005TB00000P00
00=I4P00FA801ETB00<005TBFA800eTB00<005TB000010001UTB00<005TBFA800eTB10000UTB00<0
05TBFA801ETB00<005TBFA800UTB0`001ETB00<005TBFA8015TB00<005TBFA800UTB0`0015TB0P00
1UTB00<007ooOol01Goo00<007ooOol03Woo000;Ool00`00Ool00003Ool00`00Oomoo`0BOol00`00
Oomoo`04Ool500000dgJ00000002CMX30003CMX3000349h00`005;hD_P025;h01@006=hHgQSN0000
0aco00<005TBFA800`0000=I4P00FA801ETB00<005TBFA800eTB00<005TBFA800`0000=I4P00FA80
15TB00<005TB00001ETB00<007ooOol01Goo0P005Woo00<007oo000017oo00<007ooOol02Goo00<0
05TBFA800eTB00<005TBFA8015TB00@005TBFA9I4P@000AI4P03001I4UTB00=I4P03001I4UTB00<0
0003FA8005TB00AI4P03001I4UTB00AI4P03001I4P0000800003FA8005TB00EI4P03001I4UTB00AI
4P03001I4P0000800003FA8005TB00EI4P8000EI4P03001oogoo00Eoo`8000moo`0037oo0P000goo
00<007ooOol04goo00<007ooOol01P0014gJ0`001dgJ100000<@WP005;h00QBn00D001SN6=hHgP00
00DLo`8000EI4P03001I4UTB00AI4P03001I4UTB009I4P<000EI4P03001I4UTB00=I4P8000=I4P@0
00Moo`03001oogoo01Eoo`8000=oo`8000]oo`03001I4UTB00AI4P03001I4UTB00=I4PL000II4P03
001I4UTB009I4P<000EI4P03001I4UTB00=I4P03001I4UTB00=I4P8000EI4P03001I4UTB00AI4P03
001I4UTB00=I4P8000EI4P03001I4UTB00=I4P8000=I4P@000Moo`03001oogoo00eoo`004Goo00<0
07ooOol04goo20000TgJ0`000dgJ0P000TgJ0`000dgJ0`000aBn00D001SN6=hHgP0000DLo`03001I
4UTB00EI4P03001I4UTB00=I4P03001I4P0000800003FA8005TB00II4P03001I4UTB009I4PD000=I
4P03001oogoo00Ioo`03001oogoo01Uoo`03001oogoo00]oo`03001I4UTB00AI4P03001I4P0000D0
00AI4P03001I4UTB00=I4P03001I4P0000800003FA8005TB00EI4P03001I4UTB00=I4P03001I4UTB
00<00003FA8005TB00EI4P03001I4UTB00=I4P03001I4UTB00<00003FA8005TB00EI4P03001I4UTB
00=I4P@000=I4P03001oogoo00Ioo`03001oogoo00aoo`004Goo00<007ooOol047oo1P0014gJ0`00
1dgJ10000TgJ0`000dgJ0P0000DD_P006=hHgP0000DLo`03000YG`0000II4P04001I4UTBFA840005
FA800`00FA9I4P04FA800`00FA9I4P050006FA800`00Oomoo`05Ool2000JOol00`00Oomoo`0<Ool0
0`00FA9I4P03FA850002FA800`00FA9I4P03FA800`00FA9I4P02FA820005FA800`00FA9I4P04FA80
0`00FA9I4P02FA830005FA800`00FA9I4P03FA801000FA9I4UTB1@001ETB00<005TBFA800eTB00<0
05TBFA800`0000=I4P00FA801ETB00<007ooOol01Goo0P003Goo000@Ool2000?Ool9000014gJ0000
00000dgJ0P000TgJ0`000dgJ0`001dgJ100000<HgP007?l00aco00D002UO:ElYG`0000EI4P@000=I
4P03001I4UTB00AI4P03001I4UTB00=I4P<000AI4P8000EI4P03001oogoo00Ioo`03001oogoo01Qo
o`03001oogoo00eoo`03001I4P0000@000II4P03001I4UTB009I4P03001I4P0000800003FA8005TB
00EI4P03001I4UTB00=I4P03001I4P0000800003FA8005TB00II4P03001I4UTB009I4P@000=I4P03
001I4UTB00AI4P03001I4UTB00=I4P<000AI4P8000II4P03001oogoo00Eoo`03001oogoo00]oo`00
47oo00<007ooOol037oo1@001DgJ100014gJ1@000TgJ0`000dgJ0P000TgJ0`000dgJ0`000aco00<0
02UO:El00RUO00<005TBFA800`0000=I4P00FA801ETB00<005TBFA800eTB00<005TBFA800`0000=I
4P00FA801ETB00<005TBFA800eTB00<007ooOol01Goo0`006Goo00<007ooOol03Woo0`000eTB00<0
05TBFA800eTB00@005TBFA9I4P<000EI4P03001I4UTB00AI4P04001I4UTBFA830005FA800`00FA9I
4P04FA800`00FA80000200000eTB001I4P05FA800`00FA9I4P03FA800`00FA9I4P0300000eTB001I
4P05FA800`00FA9I4P04FA800`00Oomoo`04Ool3000<Ool0011oo`8000Yoo`D00003CMX00000009=
fP<000A=fP@000E=fP@000==fPH0009=fP<000==fP03000Lo`0000DYG`<000EI4P03001I4UTB00=I
4P03001I4UTB00=I4P<000EI4P03001I4UTB00=I4P03001I4UTB00=I4P8000=oo`<0009oo`03001o
ogoo01Ioo`8000ioo`<000II4P03001I4UTB009I4P@0009I4P03001I4UTB00AI4P03001I4UTB00=I
4P@0009I4P03001I4UTB00AI4P03001I4UTB00=I4P8000EI4P03001I4UTB00AI4P03001I4UTB009I
4P<000EI4P03001I4UTB00AI4P03001I4UTB00=I4P80009oo`<0009oo`03001oogoo00Yoo`0047oo
00<007ooOol01Woo1P0014gJ10000dgJ0`000dgJ00<004gJCMX00`000dgJ10001DgJ10000dgJ1P00
00HYG`00000004gJ0006FA800`00FA9I4P03FA800`00FA9I4P0300000eTB001I4P05FA800`00FA9I
4P04FA800`00FA80000200000eTB000000020005Ool00`00Oomoo`0GOol00`00Oomoo`09Ool30003
Ool00`00FA9I4P03FA800`00FA80000200000eTB001I4P04FA800`00FA9I4P03FA800`00FA9I4P03
00000eTB001I4P04FA800`00FA9I4P03FA800`00FA9I4P0300000eTB001I4P04FA800`00FA9I4P04
FA800`00FA80000200000eTB001I4P06FA800`00FA9I4P03FA8200001ETB00000000FA800`001Goo
00<007ooOol02Woo000;Ool00`00Oomoo`02Ool00`00Oomoo`03Ool80002CMX30004CMX30006CMX4
0002CMX30003CMX2000014gJ000000000dgJ10001DgJ10000dgJ00<005TBFA8015TB00<005TBFA80
0UTB0`001ETB00<005TBFA800eTB00@005TBFA9I4PD000EI4P03001oogoo00Eoo`03001oogoo015o
o`03001oogoo009oo`8000Qoo`<000Moo`03001I4UTB009I4P8000EI4P03001I4UTB00=I4P03001I
4UTB009I4P<000EI4P03001I4UTB00=I4P03001I4UTB009I4P<000EI4P03001I4UTB00=I4P03001I
4UTB00=I4P8000EI4P03001I4UTB00AI4P04001I4UTBFA850005FA800`00Oomoo`04Ool00`00Oomo
o`0:Ool000]oo`03001oogoo009oo`04001oogooOol50004CMX50002CMX30003CMX2000014gJ0000
000014gJ0`001TgJ100000A=fP00000000==fP03001=fTgJ00<000==fP<0009=fP03001I4UTB00=I
4P03001I4P0000800003FA8005TB00II4P03001I4UTB009I4P@000=I4P03001I4P0000EI4P03001o
ogoo00Eoo`03001oogoo011oo`03001oogoo009oo`03001oogoo00Aoo`<000Yoo`03001I4P000080
0003FA8005TB00EI4P03001I4UTB009I4P03001I4P0000800003FA8005TB00II4P03001I4UTB009I
4P03001I4P0000800003FA8005TB00II4P03001I4UTB009I4P03001I4UTB00<00003FA8005TB00EI
4P03001I4UTB00=I4P@000=I4P8000EI4P03001oogoo00Eoo`03001oogoo00Uoo`002goo00@007oo
Oomoo`L00004CMX00000CMX30005CMX40004CMX50002CMX30003CMX00`00CMY=fP030003CMX40003
CMX50002CMX30003CMX30003FA840005FA800`00FA9I4P04FA800`00FA80000200000eTB001I4P05
FA820005FA800`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool01000Oomoogoo0`003Woo
00<005TBFA800eTB00<005TBFA800eTB00@005TBFA9I4P<000EI4P03001I4UTB00AI4P04001I4UTB
FA830005FA800`00FA9I4P04FA801000FA9I4UTB10001ETB00<005TBFA800eTB00<005TBFA800`00
00=I4P00FA801ETB0P0015TB00<007ooOol01Goo00<007ooOol02Goo000;Ool01000Oomoogoo1000
14gJ1@000dgJ0`0014gJ10001DgJ10000dgJ1@000TgJ0`000dgJ100014gJ10000TgJ0`0000==fP00
JLh00`000eTB00<005TBFA8015TB00<005TBFA800eTB0P001ETB00<005TBFA8015TB0P0015TB0P00
1Woo00<007ooOol047oo00<007ooOol00Woo10004Goo00<005TBFA8015TB00<005TBFA800UTB1000
0UTB00<005TBFA8015TB00<005TBFA800eTB10000UTB00<005TBFA8015TB00<005TBFA800eTB1000
0UTB00<005TBFA8015TB00<005TBFA800eTB0`001ETB00<005TBFA800eTB00<005TB00000eTB0P00
1Woo00<007ooOol02Goo000?Ool20002Ool40005CMX40003CMX30003CMX00`00CMY=fP030003CMX4
0004CMX5000014gJ000000000dgJ00<004gJ00000P000dgJ10000dgJ0`001UTB00<005TBFA800eTB
00<005TBFA800`0000=I4P00FA8015TB00<005TBFA8015TB00<005TB00000`0000=I4P00Ool01Goo
00<007ooOol05Goo0P0057oo00<005TBFA800eTB00<005TB00000P0000=I4P00FA8015TB00<005TB
FA800eTB00<005TBFA800`0000=I4P00FA8015TB00<005TBFA800eTB00<005TBFA800`0000=I4P00
FA8015TB00<005TBFA800eTB00<005TBFA800`0000=I4P00FA801ETB00<005TBFA800eTB00<005TB
00000`0000=I4P00Ool01Goo00<007ooOol02Goo000AOol00`00Oomoo`02Ool2000014gJ00000000
14gJ100014gJ1@000TgJ0`0014gJ100014gJ10000dgJ1@0000A=fP00000000==fP@0009=fP8000EI
4P03001I4UTB00=I4P<000EI4P03001I4UTB00=I4P03001I4UTB00=I4P@000AI4P03001oogoo00=o
o`03001oogoo01Moo`03001oogoo019oo`03001I4UTB009I4P8000EI4P03001I4UTB00=I4P03001I
4UTB009I4P<000EI4P03001I4UTB00=I4P03001I4UTB009I4P<000EI4P03001I4UTB00=I4P03001I
4UTB009I4P<000EI4P03001I4UTB00=I4P03001I4UTB00=I4P@000AI4P03001oogoo00=oo`03001o
ogoo00Uoo`004Woo00<007ooOol00goo0`000TgJ0`0014gJ10001DgJ10000TgJ0`000dgJ00<004gJ
00000P000dgJ10000dgJ1@0000A=fP00000000==fPH000AI4P03001I4UTB00<00003FA8005TB00EI
4P03001I4UTB00=I4P03001I4UTB00<00004FA8005TB0004FA800`00Oomoo`03Ool00`00Oomoo`0H
Ool00`00Oomoo`0AOol00`00FA80000200000eTB001I4P05FA800`00FA9I4P02FA800`00FA800002
00000eTB001I4P05FA800`00FA9I4P03FA800`00FA80000200000eTB001I4P05FA800`00FA9I4P03
FA800`00FA80000200000eTB001I4P06FA800`00FA9I4P03FA800`00FA80000200001ETB001I4UTB
000015TB00<007ooOol00Woo00<007ooOol02Goo000COol00`00Oomoo`05Ool40002CMX30003CMX2
000014gJ000000000dgJ100014gJ1@0000A=fP00000000==fP@000==fPD00004CMX000000002CMX4
0003FA840005FA800`00FA9I4P03FA801000FA9I4UTB1@001ETB00<005TB00000eTB00<007ooOol0
0goo00<007ooOol06Goo00<007ooOol04Goo00<005TBFA800eTB00<005TBFA800eTB00@005TBFA9I
4P<000EI4P03001I4UTB00=I4P04001I4UTBFA840005FA800`00FA9I4P03FA801000FA9I4UTB1000
1ETB00<005TBFA8015TB00@005TBFA9I4P@000EI4P03001I4P0000AI4P03001oogoo009oo`03001o
ogoo00Uoo`0057oo0P002Goo100014gJ1@0000A=fP00000000A=fP@000==fPD00004CMX000000003
CMX40003CMX4000014gJ000000000dgJ10000UTB00<005TBFA801ETB00<005TBFA800UTB10000eTB
00<005TBFA8015TB00@005TBFA80009I4P8000Eoo`03001oogoo01Uoo`80015oo`03001I4UTB00AI
4P03001I4UTB009I4P@0009I4P03001I4UTB00AI4P03001I4UTB009I4P@000=I4P03001I4UTB00AI
4P03001I4UTB009I4P@000=I4P03001I4UTB00AI4P03001I4UTB00=I4P@0009I4P03001I4UTB00EI
4P03001I4P0000=I4P8000Aoo`03001oogoo00Qoo`005Woo00<007ooOol02Woo10000dgJ1@000TgJ
0`000dgJ10000dgJ1@0000A=fP00000000==fP@0009=fPD00006CMX00000001=fP001ETB00<005TB
FA8015TB00<005TB00000P0000=I4P00FA801ETB00<005TBFA800eTB00<005TBFA800`0000=I4P00
Ool017oo00<007ooOol06goo00<007ooOol03goo00<005TBFA800eTB00<005TB00000P0000=I4P00
FA8015TB00<005TBFA800eTB00<005TB00000P0000=I4P00FA801ETB00<005TBFA800eTB00<005TB
00000P0000=I4P00FA801ETB00<005TBFA800eTB00<005TBFA800`0000=I4P00FA8015TB00<005TB
FA8015TB00<005TBFA800`0000=I4P00Ool00goo00<007ooOol027oo000GOol00`00Oomoo`0=Ool4
0003CMX5000014gJ000000000dgJ10000dgJ1@0000A=fP000000009=fP@000==fP@00003CMX00000
008000EI4P03001I4UTB00=I4P8000EI4P03001I4UTB00AI4P03001I4UTB009I4P<00003FA8005TB
009I4P03001oogoo009oo`03001oogoo01aoo`03001oogoo00moo`04001I4UTBFA830005FA800`00
FA9I4P03FA801000FA9I4UTB0`001ETB00<005TBFA8015TB00<005TBFA800UTB0P001ETB00<005TB
FA8015TB00<005TBFA800UTB0`001ETB00<005TBFA800eTB00<005TBFA800eTB0`0000=I4P00FA80
0UTB00D007ooOomoo`0000Yoo`0067oo00<007ooOol047oo0`000dgJ1@0000A=fP00000000==fP@0
00==fPD00003CMX0000000==fP@0009=fP<000=oo`8000AI4P03001I4UTB00<00003FA8005TB00EI
4P03001I4UTB00=I4P03001I4P0000800003FA8005TB009I4P05001I4UTBFA800003Ool00`00Oomo
o`0MOol00`00Oomoo`0?Ool30002FA800`00FA9I4P04FA800`00FA9I4P02FA840002FA800`00FA9I
4P04FA800`00FA9I4P03FA800`00FA80000200000eTB001I4P05FA800`00FA9I4P03FA800`00FA80
000200000eTB001I4P05FA800`00FA9I4P03FA800`00FA9I4P0300001ETB001I4UTB00000eTB00D0
07ooOomoo`0000Yoo`006Goo00<007ooOol04Woo0`000dgJ1@0000A=fP00000000==fP@000==fP@0
0004CMX000000003CMX30007Ool01000FA9I4UTB10001ETB00<005TBFA800eTB00@005TBFA9I4P@0
00EI4P05001I4UTBFA800002FA801@00Oomoogoo000087oo00<007ooOol03Woo00<005TBFA800eTB
00<005TBFA800eTB00<005TB00000P0000=I4P00FA8015TB00<005TBFA800eTB00@005TBFA9I4P@0
00EI4P03001I4UTB00=I4P04001I4UTBFA840005FA800`00FA9I4P03FA801000FA9I4UTB1@001ETB
00@005TBFA80009I4P05001oogooOol0000:Ool001Yoo`8001Eoo`@0009=fPD00004CMX000000003
CMX40002CMX5000014gJ000000002goo0`000UTB00<005TBFA8015TB00<005TBFA800eTB10000eTB
00<005TBFA8015TB00@005TBFA80009I4P80009oo`03001oogoo01moo`8000moo`03001I4UTB00=I
4P03001I4UTB009I4P8000EI4P03001I4UTB00=I4P03001I4UTB009I4P@000=I4P03001I4UTB00AI
4P03001I4UTB009I4P@000=I4P03001I4UTB00AI4P03001I4UTB009I4P@000=I4P03001I4UTB00AI
4P06001I4UTBFA8005TB0P000Woo00<007ooOol027oo000LOol00`00Oomoo`0FOol30002CMX50000
14gJ000000000dgJ0`000dgJ0`003Woo00<005TBFA800eTB00<005TBFA800eTB00<005TBFA800`00
00=I4P00FA801ETB00<005TBFA800eTB00<005TBFA800`0000EI4P00Oomoo`0002=oo`03001oogoo
00eoo`03001I4UTB009I4P03001I4P0000800003FA8005TB00EI4P03001I4UTB009I4P03001I4P00
00800003FA8005TB00EI4P03001I4UTB00=I4P03001I4P0000800003FA8005TB00EI4P03001I4UTB
00=I4P03001I4P0000800003FA8005TB00EI4P03001I4UTB00=I4P03001I4UTB00<00005FA8007oo
Ool0000:Ool001eoo`03001oogoo01Qoo`<0009=fPD00005CMX00000001=fP05000BOol00`00FA9I
4P03FA801000FA9I4UTB10001ETB00<005TBFA800eTB00<005TBFA800eTB0`000UTB00@005TBFA80
009oo`03001oogoo025oo`03001oogoo00aoo`04001I4UTBFA830005FA800`00FA9I4P03FA801000
FA9I4UTB0`001ETB00<005TBFA800eTB00@005TBFA9I4P@000EI4P03001I4UTB00=I4P04001I4UTB
FA840005FA800`00FA9I4P03FA800`00FA9I4P03FA830002FA801000FA9I4P000Woo00<007ooOol0
1goo000NOol00`00Oomoo`0JOol30002CMX7000GOol00`00FA9I4P03FA840002FA800`00FA9I4P04
FA800`00FA9I4P03FA800`00FA9I4P0300000eTB001I4P03FA800`00FA800002Ool00`00Oomoo`0R
Ool00`00Oomoo`0<Ool30002FA800`00FA9I4P04FA800`00FA9I4P02FA840002FA800`00FA9I4P04
FA800`00FA9I4P02FA840003FA800`00FA9I4P04FA800`00FA9I4P02FA840003FA800`00FA9I4P04
FA800`00FA9I4P02FA800`00FA9I4P0300000eTB001I4P03FA800`00FA800002Ool00`00Oomoo`07
Ool001moo`8001eoo`800004CMX00000000JOol00`00FA9I4P0300000eTB001I4P04FA800`00FA9I
4P03FA801000FA9I4UTB1@001ETB00L005TBFA9I4P00FA800002Ool00`00Oomoo`0SOol2000<Ool0
0`00FA9I4P03FA800`00FA9I4P03FA800`00FA80000200000eTB001I4P04FA800`00FA9I4P03FA80
0`00FA80000200000eTB001I4P05FA800`00FA9I4P03FA800`00FA80000200000eTB001I4P05FA80
0`00FA9I4P03FA801000FA9I4UTB10001ETB00<005TBFA800UTB0P000Woo00<007ooOol01goo000Q
Ool00`00Oomoo`0LOol00`00Oomoo`0LOol20005FA800`00FA9I4P03FA800`00FA9I4P02FA840003
FA800`00FA9I4P04FA800`00FA9I4P02FA8300000goo001oo`0VOol00`00Oomoo`0:Ool00`00FA9I
4P03FA801000FA9I4UTB0`001ETB00<005TBFA800eTB00@005TBFA9I4P<000EI4P03001I4UTB00=I
4P04001I4UTBFA840005FA800`00FA9I4P03FA800`00FA9I4P03FA840002FA800`00FA9I4P05FA80
1000FA9I4UTB0`0000=oo`00Ool027oo000ROol00`00Oomoo`0KOol00`00Oomoo`0LOol00`00FA9I
4P04FA800`00FA9I4P03FA800`00FA80000200000eTB001I4P05FA800`00FA9I4P03FA800`00FA9I
4P0500000goo001oo`0WOol00`00Oomoo`0:Ool00`00FA9I4P02FA840002FA800`00FA9I4P04FA80
0`00FA9I4P02FA840002FA800`00FA9I4P04FA800`00FA9I4P02FA840003FA800`00FA9I4P04FA80
0`00FA9I4P02FA800`00FA9I4P0300000eTB001I4P04FA800`00FA9I4P04FA800`00FA8000040000
0goo001oo`08Ool002=oo`03001oogoo01Yoo`03001oogoo01eoo`03001I4UTB00=I4P04001I4UTB
FA840005FA800`00FA9I4P04FA801000FA9I4UTB100015TB0`00:Goo00<007ooOol02Goo00<005TB
00000P0000=I4P00FA8015TB00<005TBFA800eTB00<005TB00000P0000=I4P00FA8015TB00<005TB
FA800eTB00<005TB00000P0000=I4P00FA801ETB00<005TBFA800eTB00@005TBFA9I4P@000EI4P03
001I4UTB00=I4P04001I4UTBFA840004FA830009Ool002Aoo`8001Yoo`03001oogoo01ioo`03001I
4UTB009I4P@000=I4P03001I4UTB00AI4P03001I4UTB00=I4P@0009I4P03001I4UTB00=I4P<002Yo
o`8000Yoo`03001I4UTB00=I4P03001I4UTB00=I4P04001I4UTBFA830005FA800`00FA9I4P03FA80
1000FA9I4UTB0`001ETB00<005TBFA800eTB00<005TBFA800eTB10000UTB00<005TBFA8015TB00<0
05TBFA800eTB10000eTB00<005TBFA800UTB00<005TB00002Goo000VOol00`00Oomoo`0GOol00`00
Oomoo`0NOol00`00FA80000200000eTB001I4P05FA800`00FA9I4P03FA800`00FA9I4P0300000eTB
001I4P04FA800`00FA9I4P03FA800`00Ool0000[Ool00`00Oomoo`07Ool00`00FA9I4P04FA800`00
FA9I4P02FA840002FA800`00FA9I4P04FA800`00FA9I4P02FA840002FA800`00FA9I4P04FA800`00
FA9I4P02FA800`00FA9I4P0300000eTB001I4P04FA800`00FA9I4P03FA800`00FA9I4P0300000eTB
001I4P05FA800`00FA9I4P02FA830008Ool002Moo`03001oogoo01Ioo`03001oogoo01moo`03001I
4UTB00=I4P03001I4UTB00=I4P04001I4UTBFA850005FA800`00FA9I4P03FA800`00FA9I4P02FA83
000/Ool00`00Oomoo`07Ool00`00FA9I4P03FA800`00FA80000200000eTB001I4P04FA800`00FA9I
4P03FA800`00FA80000200000eTB001I4P04FA800`00FA9I4P03FA801000FA9I4UTB10001ETB00<0
05TBFA800eTB00@005TBFA9I4P@000EI4P03001I4UTB00=I4P03001I4UTB00=I4P8000Qoo`00:7oo
00<007ooOol05Goo00<007ooOol07goo00<005TBFA8015TB00<005TBFA800UTB10000eTB00<005TB
FA8015TB00<005TBFA800eTB00<005TB00001@00;Goo00<007ooOol01goo00@005TBFA9I4P<000EI
4P03001I4UTB00=I4P04001I4UTBFA830005FA800`00FA9I4P03FA800`00FA9I4P02FA840002FA80
0`00FA9I4P04FA800`00FA9I4P03FA840002FA800`00FA9I4P04FA800`00FA9I4P03FA800`00FA9I
4P050008Ool002Uoo`03001oogoo01Aoo`03001oogoo021oo`03001I4UTB00=I4P03001I4P000080
0003FA8005TB00EI4P03001I4UTB00=I4P04001I4UTBFA87000aOol00`00Oomoo`07Ool30002FA80
0`00FA9I4P04FA800`00FA9I4P02FA840002FA800`00FA9I4P04FA800`00FA9I4P02FA800`00FA80
000200000eTB001I4P04FA800`00FA9I4P03FA800`00FA9I4P0300000eTB001I4P04FA800`00FA9I
4P03FA801000FA9I4UTB1`002goo000ZOol2000DOol00`00Oomoo`0QOol01000FA9I4UTB0`001ETB
00<005TBFA800eTB00<005TBFA800eTB1`00=Woo0P001goo00<005TBFA800eTB00<005TBFA800eTB
00<005TB00000P0000=I4P00FA8015TB00<005TBFA800eTB00@005TBFA9I4P<000EI4P03001I4UTB
00=I4P04001I4UTBFA840005FA800`00FA9I4P03FA800`00FA9I4P02FA87000?Ool002aoo`03001o
ogoo015oo`03001oogoo029oo`<0009I4P03001I4UTB00AI4P03001I4UTB009I4P03001I4UTB00H0
03aoo`03001oogoo00Eoo`03001I4UTB00=I4P04001I4UTBFA830005FA800`00FA9I4P03FA801000
FA9I4UTB1@000UTB00<005TBFA8015TB00<005TBFA800UTB10000UTB00<005TBFA8015TB00<005TB
FA800eTB00<005TB00001@004goo000]Ool00`00Oomoo`0@Ool00`00Oomoo`0ROol00`00FA9I4P03
FA800`00FA9I4P03FA801000FA9I4UTB1P00@Goo00<007ooOol01Goo00<005TBFA800UTB10000UTB
00<005TBFA8015TB00<005TBFA800UTB10000UTB00<005TBFA800eTB00<005TBFA800eTB00<005TB
00000P0000=I4P00FA8015TB00<005TBFA800eTB00@005TBFA9I4PL001Ioo`00;Woo00<007ooOol0
3goo00<007ooOol08goo00<005TBFA800eTB00@005TBFA9I4PL004Ioo`03001oogoo00Aoo`03001I
4P0000800003FA8005TB00AI4P03001I4UTB00=I4P03001I4P0000800003FA8005TB00AI4P03001I
4UTB00=I4P04001I4UTBFA830005FA800`00FA9I4P03FA801000FA9I4UTB20006Woo000_Ool2000?
Ool00`00Oomoo`0SOol00`00FA9I4P03FA88001:Ool20005Ool00`00FA9I4P03FA800`00FA9I4P03
FA801000FA9I4UTB0`001ETB00<005TBFA800UTB00@005TBFA9I4PH0009I4P03001I4UTB00AI4P03
001I4UTB009I4PP001ioo`00<Goo00<007ooOol02goo00<007ooOol097oo00<005TBFA801`00D7oo
00<007ooOol00Woo00<005TBFA8015TB00<005TBFA800UTB10000UTB00<005TBFA800eTB00<005TB
FA800UTB10000eTB00<005TBFA800eTB00<005TBFA800eTB00<005TB00001P008Woo000bOol00`00
Oomoo`0:Ool00`00Oomoo`0UOol5001EOol00`00Oomoo`02Ool00`00FA9I4P03FA800`00FA800002
00000eTB001I4P04FA800`00FA9I4P02FA800`00FA80000200000eTB001I4P05FA800`00FA9I4P02
FA801000FA9I4UTB1`009Woo000cOol00`00Oomoo`09Ool00`00Oomoo`0ROol4001JOol00`00Oomo
o`02Ool01000FA9I4UTB0`001ETB00<005TBFA800UTB00@005TBFA9I4P<000EI4P03001I4UTB00=I
4P03001I4UTB009I4PL002Yoo`00=7oo0P002Goo00<007ooOol07Woo1000Ggoo0P000goo0`000UTB
00<005TBFA8015TB00<005TBFA801@000UTB00<005TBFA8015TB00<005TBFA800UTB00<005TB0000
1@00;Woo000fOol00`00Oomoo`06Ool00`00Oomoo`0JOol4001UOol01000Oomoo`001ETB00<005TB
FA800eTB0`000UTB00<005TBFA800eTB00<005TBFA800eTB00@005TBFA9I4PH0035oo`00=goo00<0
07ooOol01Goo00<007ooOol05Woo1000JWoo00@007ooOol000EI4P03001I4P0000800003FA8005TB
00=I4P03001I4UTB00=I4P04001I4UTBFA87000eOol003Qoo`03001oogoo00Aoo`03001oogoo019o
o`@006moo`04001oogoo0003FA830005FA800`00FA9I4P02FA801000FA9I4UTB2000>Goo000iOol0
0`00Oomoo`03Ool00`00Oomoo`0?Ool3001dOol00`00Oomoo`030002FA800`00FA9I4P03FA800`00
FA9I4P02FA88000mOol003Yoo`8000=oo`03001oogoo00]oo`@007Qoo`<000EI4P03001I4UTB009I
4P03001I4P0000H0045oo`00?7oo00@007ooOol000Uoo`@007ioo`8000EI4P03001I4UTB00H004Eo
o`00?Goo00<007oo00001Goo1000Pgoo0P000eTB1`00B7oo000nOol200000goo000000020028Ool7
001<Ool003moo`8008eoo`80051oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {110.188, 0}} -> {-0.0563868, -0.0193168, \
0.00736159, 0.00736159}, {{7.625, 137}, {107.562, 2.625}} -> {-0.12322, \
0.00829902, 0.00785266, 0.00785266}, {{149.938, 279.312}, {107.562, 2.625}} -> \
{-1.24075, 0.00829902, 0.00785266, 0.00785266}}]
}, Closed]],

Cell[TextData[{
  "For this reason, when dealing with complex numbers it is often necessary \
to tolerate odd constructions like ",
  Cell[BoxData[
      \(TraditionalForm\`\@x\^2\)],
    FormatType->StandardForm],
  "\[LongDash]resisting the impulse to simplify ",
  Cell[BoxData[
      \(TraditionalForm\`\@x\^2\)],
    FormatType->StandardForm],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)],
    FormatType->StandardForm],
  "\[LongDash]in order to maintain information about the location of branch \
cuts. This information can often be valuable; see ",
  StyleBox["Analytic Continuation ",
    FontWeight->"Bold"],
  "below ",
  "for an example where this is true."
}], "Text"],

Cell[TextData[{
  StyleBox["Surfaces like the ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[" corkscrew above are called ",
    ZeroWidthTimes->True],
  StyleBox["Riemann surfaces",
    ZeroWidthTimes->True,
    FontSlant->"Italic"],
  StyleBox[". Note that when ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[" is a many-to-one function like ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[", the Riemann surface overlaps itself. In fact, the Riemann \
surface of ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[" overlaps itself an infinite number of times. But the surface can \
be cut into nonoverlapping ",
    ZeroWidthTimes->True],
  StyleBox["sheets",
    ZeroWidthTimes->True,
    FontSlant->"Italic"],
  StyleBox[" such that if ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`f(z\_1)\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[" and ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`f(z\_2)\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[" are on the same sheet, and ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`f(z\_1) = f(z\_2)\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[", then ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`z\_1\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[" must equal ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`z\_2\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[". For example, each revolution of the corkscrew in the plot of ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[" represents a different sheet. Then the ",
    ZeroWidthTimes->True],
  StyleBox["branch points",
    ZeroWidthTimes->True,
    FontSlant->"Italic"],
  StyleBox[" of an analytic function ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`w(z)\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox[" are the points in the complex ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  "-",
  StyleBox["plane where two or more sheets meet. For example, a branch point \
in the finite part of the complex plane of ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`ln(z)\)],
    FormatType->StandardForm],
  StyleBox[" is ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)],
    FormatType->StandardForm,
    ZeroWidthTimes->True],
  StyleBox["; the same is true for ",
    ZeroWidthTimes->True],
  Cell[BoxData[
      \(TraditionalForm\`\@z\)],
    FormatType->StandardForm],
  StyleBox[". (We say \[OpenCurlyDoubleQuote]in the finite part\
\[CloseCurlyDoubleQuote] because it is also possible for a function to have a \
branch point at infinity.)",
    ZeroWidthTimes->True]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot3D[
        Evaluate[{Re[\((w\_r + \[ImaginaryI]\ w\_i)\)\^2], 
            Im[\((w\_r + \[ImaginaryI]\ w\_i)\)\^2], w\_i}], {w\_r, \(-2\), 
          2}, {w\_i, \(-2\), 2}];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92711 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.27751e-16 1.07818 -0.0239423 1.07818 [
[.02605 .17508 -10.2928 -7 ]
[.02605 .17508 .08221 0 ]
[.13851 .13177 -10.2074 -7 ]
[.13851 .13177 .35512 0 ]
[.25429 .08718 -6.64357 -7 ]
[.25429 .08718 .41893 0 ]
[.37355 .04127 -6.51928 -7 ]
[.37355 .04127 .60572 0 ]
[.49645 -0.00604 -6.16945 -7 ]
[.49645 -0.00604 .76805 0 ]
[.64037 .1389 0 -4.76502 ]
[.64037 .1389 10.625 2.23498 ]
[.7865 .32796 0 -4.66513 ]
[.7865 .32796 7.0625 2.33487 ]
[.91535 .49468 0 -4.57987 ]
[.91535 .49468 7.1875 2.42013 ]
[.01175 .19862 -10.5625 -2.15885 ]
[.01175 .19862 0 4.84115 ]
[.00599 .24959 -10.3125 -2.18103 ]
[.00599 .24959 0 4.81897 ]
[.00011 .30171 -7.0625 -2.20375 ]
[.00011 .30171 0 4.79625 ]
[-0.00591 .35501 -6.875 -2.22702 ]
[-0.00591 .35501 0 4.77298 ]
[-0.01207 .40954 -7.125 -2.25086 ]
[-0.01207 .40954 0 4.74914 ]
[ 0 0 0 0 ]
[ 1 .92711 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0249 .18876 m
.51669 0 L
s
.03551 .18468 m
.04023 .18949 L
s
gsave
.02605 .17508 -71.2928 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.1477 .14162 m
.1523 .14655 L
s
gsave
.13851 .13177 -71.2074 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.2632 .09729 m
.26766 .10235 L
s
gsave
.25429 .08718 -67.6436 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.38216 .05164 m
.38646 .05682 L
s
gsave
.37355 .04127 -67.5193 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.50473 .00459 m
.50887 .00991 L
s
gsave
.49645 -0.00604 -67.1694 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.06325 .17404 m
.06607 .17694 L
s
.0912 .16331 m
.094 .16623 L
s
.11935 .15251 m
.12213 .15544 L
s
.17626 .13066 m
.179 .13364 L
s
.20503 .11962 m
.20774 .12262 L
s
.23401 .1085 m
.2367 .11151 L
s
.29261 .08601 m
.29526 .08906 L
s
.32224 .07463 m
.32487 .07771 L
s
.35209 .06318 m
.35469 .06627 L
s
.41246 .04001 m
.41501 .04314 L
s
.44298 .02829 m
.44552 .03144 L
s
.47374 .01649 m
.47625 .01966 L
s
.25 Mabswid
.51669 0 m
.98167 .60103 L
s
.62769 .14348 m
.62136 .14577 L
s
gsave
.64037 .1389 -61 -8.76502 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.77371 .33221 m
.76732 .33434 L
s
gsave
.7865 .32796 -61 -8.66513 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.90247 .49865 m
.89603 .50064 L
s
gsave
.91535 .49468 -61 -8.57987 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.65844 .18322 m
.65463 .18457 L
s
.68839 .22193 m
.68457 .22326 L
s
.71756 .25964 m
.71374 .26095 L
s
.74599 .29639 m
.74216 .29768 L
s
.80074 .36715 m
.7969 .36841 L
s
.82711 .40123 m
.82326 .40248 L
s
.85284 .43449 m
.84898 .43572 L
s
.87795 .46695 m
.87409 .46816 L
s
.59611 .10265 m
.59232 .10405 L
s
.56366 .06071 m
.55987 .06212 L
s
.5303 .01759 m
.52652 .01903 L
s
.92642 .5296 m
.92255 .53078 L
s
.94981 .55984 m
.94594 .561 L
s
.97268 .58939 m
.9688 .59054 L
s
.25 Mabswid
.0249 .18876 m
0 .41054 L
s
.02434 .1938 m
.03063 .19139 L
s
gsave
.01175 .19862 -71.5625 -6.15885 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.0186 .24484 m
.02491 .24246 L
s
gsave
.00599 .24959 -71.3125 -6.18103 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.01275 .29703 m
.01906 .29469 L
s
gsave
.00011 .30171 -68.0625 -6.20375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.00675 .35041 m
.01308 .3481 L
s
gsave
-0.00591 .35501 -67.875 -6.22702 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.00062 .40501 m
.00697 .40275 L
s
gsave
-0.01207 .40954 -68.125 -6.25086 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.0232 .20392 m
.02698 .20247 L
s
.02206 .21408 m
.02584 .21264 L
s
.02091 .22429 m
.02469 .22285 L
s
.01976 .23454 m
.02354 .23311 L
s
.01744 .25518 m
.02123 .25376 L
s
.01628 .26557 m
.02006 .26416 L
s
.0151 .27601 m
.01889 .2746 L
s
.01393 .2865 m
.01772 .28509 L
s
.01156 .30761 m
.01535 .30621 L
s
.01036 .31823 m
.01416 .31684 L
s
.00917 .32891 m
.01296 .32752 L
s
.00796 .33963 m
.01176 .33825 L
s
.00554 .36123 m
.00934 .35985 L
s
.00432 .3721 m
.00812 .37073 L
s
.00309 .38302 m
.00689 .38165 L
s
.00186 .39399 m
.00566 .39263 L
s
.25 Mabswid
.0249 .18876 m
0 .41054 L
s
0 .41054 m
.557 .92711 L
s
.557 .92711 m
.55632 .72604 L
s
.55632 .72604 m
.0249 .18876 L
s
.51669 0 m
.98167 .60103 L
s
.98167 .60103 m
1 .80772 L
s
1 .80772 m
.51554 .22691 L
s
.51554 .22691 m
.51669 0 L
s
.0249 .18876 m
0 .41054 L
s
0 .41054 m
.51554 .22691 L
s
.51554 .22691 m
.51669 0 L
s
.51669 0 m
.0249 .18876 L
s
.55632 .72604 m
.98167 .60103 L
s
.98167 .60103 m
1 .80772 L
s
1 .80772 m
.557 .92711 L
s
.557 .92711 m
.55632 .72604 L
s
0 0 m
1 0 L
1 .92711 L
0 .92711 L
closepath
clip
newpath
.5 Mabswid
.72133 .6295 m .77154 .63731 L .75411 .65873 L p .933 .062 .812 r
F P
0 g
s
.75411 .65873 m .70301 .6494 L .72133 .6295 L p .933 .062 .812 r
F P
0 g
s
.67393 .6207 m .72133 .6295 L .70301 .6494 L p .939 .061 .807 r
F P
0 g
s
.70301 .6494 m .65458 .63908 L .67393 .6207 L p .939 .061 .807 r
F P
0 g
s
.6293 .61088 m .67393 .6207 L .65458 .63908 L p .946 .06 .802 r
F P
0 g
s
.65458 .63908 m .60883 .62774 L .6293 .61088 L p .946 .06 .802 r
F P
0 g
s
.58743 .60004 m .6293 .61088 L .60883 .62774 L p .953 .059 .795 r
F P
0 g
s
.60883 .62774 m .56572 .61536 L .58743 .60004 L p .953 .059 .795 r
F P
0 g
s
.73698 .61003 m .78627 .61625 L .77154 .63731 L p .935 .064 .818 r
F P
0 g
s
.77154 .63731 m .72133 .6295 L .73698 .61003 L p .935 .064 .818 r
F P
0 g
s
.6906 .60282 m .73698 .61003 L .72133 .6295 L p .942 .063 .813 r
F P
0 g
s
.72133 .6295 m .67393 .6207 L .6906 .60282 L p .942 .063 .813 r
F P
0 g
s
.5483 .58814 m .58743 .60004 L .56572 .61536 L p .96 .057 .786 r
F P
0 g
s
.56572 .61536 m .52524 .6019 L .5483 .58814 L p .96 .057 .786 r
F P
0 g
s
.6471 .5946 m .6906 .60282 L .67393 .6207 L p .949 .061 .807 r
F P
0 g
s
.67393 .6207 m .6293 .61088 L .6471 .5946 L p .949 .061 .807 r
F P
0 g
s
.51191 .57515 m .5483 .58814 L .52524 .6019 L p .966 .055 .777 r
F P
0 g
s
.52524 .6019 m .4874 .58734 L .51191 .57515 L p .966 .055 .777 r
F P
0 g
s
.60647 .58536 m .6471 .5946 L .6293 .61088 L p .958 .06 .799 r
F P
0 g
s
.6293 .61088 m .58743 .60004 L .60647 .58536 L p .958 .06 .799 r
F P
0 g
s
.74981 .59103 m .79817 .59558 L .78627 .61625 L p .936 .065 .824 r
F P
0 g
s
.78627 .61625 m .73698 .61003 L .74981 .59103 L p .936 .065 .824 r
F P
0 g
s
.56869 .57507 m .60647 .58536 L .58743 .60004 L p .966 .058 .79 r
F P
0 g
s
.58743 .60004 m .5483 .58814 L .56869 .57507 L p .966 .058 .79 r
F P
0 g
s
.47826 .56104 m .51191 .57515 L .4874 .58734 L p .972 .053 .767 r
F P
0 g
s
.4874 .58734 m .4522 .57164 L .47826 .56104 L p .972 .053 .767 r
F P
0 g
s
.70447 .58548 m .74981 .59103 L .73698 .61003 L p .944 .064 .82 r
F P
0 g
s
.73698 .61003 m .6906 .60282 L .70447 .58548 L p .944 .064 .82 r
F P
0 g
s
.66212 .57892 m .70447 .58548 L .6906 .60282 L p .953 .063 .813 r
F P
0 g
s
.6906 .60282 m .6471 .5946 L .66212 .57892 L p .953 .063 .813 r
F P
0 g
s
.53375 .56371 m .56869 .57507 L .5483 .58814 L p .974 .056 .779 r
F P
0 g
s
.5483 .58814 m .51191 .57515 L .53375 .56371 L p .974 .056 .779 r
F P
0 g
s
.44735 .54578 m .47826 .56104 L .4522 .57164 L p .977 .051 .757 r
F P
0 g
s
.4522 .57164 m .41965 .55476 L .44735 .54578 L p .977 .051 .757 r
F P
0 g
s
.62275 .57134 m .66212 .57892 L .6471 .5946 L p .962 .061 .805 r
F P
0 g
s
.6471 .5946 m .60647 .58536 L .62275 .57134 L p .962 .061 .805 r
F P
0 g
s
.7624 .85336 m .70935 .84443 L .72784 .80863 L p .819 .059 .794 r
F P
0 g
s
.72784 .80863 m .7798 .81614 L .7624 .85336 L p .819 .059 .794 r
F P
0 g
s
.50164 .55125 m .53375 .56371 L .51191 .57515 L p .982 .054 .768 r
F P
0 g
s
.51191 .57515 m .47826 .56104 L .50164 .55125 L p .982 .054 .768 r
F P
0 g
s
.58631 .56273 m .62275 .57134 L .60647 .58536 L p .973 .059 .795 r
F P
0 g
s
.60647 .58536 m .56869 .57507 L .58631 .56273 L p .973 .059 .795 r
F P
0 g
s
.75971 .57254 m .80713 .57536 L .79817 .59558 L p .936 .066 .832 r
F P
0 g
s
.79817 .59558 m .74981 .59103 L .75971 .57254 L p .936 .066 .832 r
F P
0 g
s
.41921 .52933 m .44735 .54578 L .41965 .55476 L p .98 .049 .746 r
F P
0 g
s
.41965 .55476 m .38976 .53666 L .41921 .52933 L p .98 .049 .746 r
F P
0 g
s
.71543 .56872 m .75971 .57254 L .74981 .59103 L p .945 .066 .828 r
F P
0 g
s
.74981 .59103 m .70447 .58548 L .71543 .56872 L p .945 .066 .828 r
F P
0 g
s
.70935 .84443 m .65907 .83454 L .67876 .80016 L p .815 .059 .797 r
F P
0 g
s
.67876 .80016 m .72784 .80863 L .70935 .84443 L p .815 .059 .797 r
F P
0 g
s
.55282 .55305 m .58631 .56273 L .56869 .57507 L p .983 .057 .783 r
F P
0 g
s
.56869 .57507 m .53375 .56371 L .55282 .55305 L p .983 .057 .783 r
F P
0 g
s
.47237 .53766 m .50164 .55125 L .47826 .56104 L p .989 .051 .755 r
F P
0 g
s
.47826 .56104 m .44735 .54578 L .47237 .53766 L p .989 .051 .755 r
F P
0 g
s
.67425 .56389 m .71543 .56872 L .70447 .58548 L p .955 .064 .822 r
F P
0 g
s
.70447 .58548 m .66212 .57892 L .67425 .56389 L p .955 .064 .822 r
F P
0 g
s
.65907 .83454 m .61155 .82367 L .63254 .79072 L p .81 .06 .801 r
F P
0 g
s
.63254 .79072 m .67876 .80016 L .65907 .83454 L p .81 .06 .801 r
F P
0 g
s
.63614 .55804 m .67425 .56389 L .66212 .57892 L p .966 .063 .813 r
F P
0 g
s
.66212 .57892 m .62275 .57134 L .63614 .55804 L p .966 .063 .813 r
F P
0 g
s
.52225 .54229 m .55282 .55305 L .53375 .56371 L p .994 .054 .769 r
F P
0 g
s
.53375 .56371 m .50164 .55125 L .52225 .54229 L p .994 .054 .769 r
F P
0 g
s
.39384 .51165 m .41921 .52933 L .38976 .53666 L p .982 .047 .736 r
F P
0 g
s
.38976 .53666 m .36255 .51729 L .39384 .51165 L p .982 .047 .736 r
F P
0 g
s
.7798 .81614 m .72784 .80863 L .74343 .77303 L p .819 .058 .79 r
F P
0 g
s
.74343 .77303 m .7943 .77904 L .7798 .81614 L p .819 .058 .79 r
F P
0 g
s
.60107 .55115 m .63614 .55804 L .62275 .57134 L p .979 .06 .802 r
F P
0 g
s
.62275 .57134 m .58631 .56273 L .60107 .55115 L p .979 .06 .802 r
F P
0 g
s
.44596 .52291 m .47237 .53766 L .44735 .54578 L p .994 .048 .742 r
F P
0 g
s
.44735 .54578 m .41921 .52933 L .44596 .52291 L p .994 .048 .742 r
F P
0 g
s
.61155 .82367 m .56676 .81181 L .58917 .78028 L p .806 .061 .805 r
F P
0 g
s
.58917 .78028 m .63254 .79072 L .61155 .82367 L p .806 .061 .805 r
F P
0 g
s
.72784 .80863 m .67876 .80016 L .69555 .76606 L p .815 .059 .793 r
F P
0 g
s
.69555 .76606 m .74343 .77303 L .72784 .80863 L p .815 .059 .793 r
F P
0 g
s
.49461 .53043 m .52225 .54229 L .50164 .55125 L p 1 .051 .753 r
F P
0 g
s
.50164 .55125 m .47237 .53766 L .49461 .53043 L p 1 .051 .753 r
F P
0 g
s
.56902 .54322 m .60107 .55115 L .58631 .56273 L p .993 .058 .789 r
F P
0 g
s
.58631 .56273 m .55282 .55305 L .56902 .54322 L p .993 .058 .789 r
F P
0 g
s
.76657 .55461 m .81301 .55562 L .80713 .57536 L p .935 .068 .842 r
F P
0 g
s
.80713 .57536 m .75971 .57254 L .76657 .55461 L p .935 .068 .842 r
F P
0 g
s
.72337 .55259 m .76657 .55461 L .75971 .57254 L p .944 .068 .838 r
F P
0 g
s
.75971 .57254 m .71543 .56872 L .72337 .55259 L p .944 .068 .838 r
F P
0 g
s
.68338 .54954 m .72337 .55259 L .71543 .56872 L p .956 .066 .832 r
F P
0 g
s
.71543 .56872 m .67425 .56389 L .68338 .54954 L p .956 .066 .832 r
F P
0 g
s
.37128 .49269 m .39384 .51165 L .36255 .51729 L p .981 .045 .726 r
F P
0 g
s
.36255 .51729 m .33805 .4966 L .37128 .49269 L p .981 .045 .726 r
F P
0 g
s
.67876 .80016 m .63254 .79072 L .65065 .75812 L p .81 .059 .796 r
F P
0 g
s
.65065 .75812 m .69555 .76606 L .67876 .80016 L p .81 .059 .796 r
F P
0 g
s
.42241 .50696 m .44596 .52291 L .41921 .52933 L p .996 .046 .729 r
F P
0 g
s
.41921 .52933 m .39384 .51165 L .42241 .50696 L p .996 .046 .729 r
F P
0 g
s
.56676 .81181 m .5247 .7989 L .54863 .76882 L p .801 .062 .81 r
F P
0 g
s
.54863 .76882 m .58917 .78028 L .56676 .81181 L p .801 .062 .81 r
F P
0 g
s
.53999 .53421 m .56902 .54322 L .55282 .55305 L p 1 .054 .772 r
F P
0 g
s
.55282 .55305 m .52225 .54229 L .53999 .53421 L p 1 .054 .772 r
F P
0 g
s
.64655 .54548 m .68338 .54954 L .67425 .56389 L p .969 .065 .824 r
F P
0 g
s
.67425 .56389 m .63614 .55804 L .64655 .54548 L p .969 .065 .824 r
F P
0 g
s
.46991 .51742 m .49461 .53043 L .47237 .53766 L p 1 .047 .737 r
F P
0 g
s
.47237 .53766 m .44596 .52291 L .46991 .51742 L p 1 .047 .737 r
F P
0 g
s
.7943 .77904 m .74343 .77303 L .75601 .73768 L p .82 .057 .785 r
F P
0 g
s
.75601 .73768 m .80579 .74211 L .7943 .77904 L p .82 .057 .785 r
F P
0 g
s
.63254 .79072 m .58917 .78028 L .60869 .74919 L p .804 .06 .801 r
F P
0 g
s
.60869 .74919 m .65065 .75812 L .63254 .79072 L p .804 .06 .801 r
F P
0 g
s
.61285 .54038 m .64655 .54548 L .63614 .55804 L p .985 .063 .813 r
F P
0 g
s
.63614 .55804 m .60107 .55115 L .61285 .54038 L p .985 .063 .813 r
F P
0 g
s
.51398 .52411 m .53999 .53421 L .52225 .54229 L p 1 .05 .752 r
F P
0 g
s
.52225 .54229 m .49461 .53043 L .51398 .52411 L p 1 .05 .752 r
F P
0 g
s
.74343 .77303 m .69555 .76606 L .70935 .7323 L p .815 .057 .787 r
F P
0 g
s
.70935 .7323 m .75601 .73768 L .74343 .77303 L p .815 .057 .787 r
F P
0 g
s
.5247 .7989 m .48535 .78494 L .51092 .7563 L p .795 .063 .817 r
F P
0 g
s
.51092 .7563 m .54863 .76882 L .5247 .7989 L p .795 .063 .817 r
F P
0 g
s
.58226 .53423 m .61285 .54038 L .60107 .55115 L p 1 .059 .797 r
F P
0 g
s
.60107 .55115 m .56902 .54322 L .58226 .53423 L p 1 .059 .797 r
F P
0 g
s
.40176 .48977 m .42241 .50696 L .39384 .51165 L p .995 .044 .718 r
F P
0 g
s
.39384 .51165 m .37128 .49269 L .40176 .48977 L p .995 .044 .718 r
F P
0 g
s
.44817 .50325 m .46991 .51742 L .44596 .52291 L p 1 .044 .721 r
F P
0 g
s
.44596 .52291 m .42241 .50696 L .44817 .50325 L p 1 .044 .721 r
F P
0 g
s
.35156 .47239 m .37128 .49269 L .33805 .4966 L p .978 .044 .719 r
F P
0 g
s
.33805 .4966 m .3163 .47453 L .35156 .47239 L p .978 .044 .719 r
F P
0 g
s
.58917 .78028 m .54863 .76882 L .56967 .73924 L p .799 .061 .806 r
F P
0 g
s
.56967 .73924 m .60869 .74919 L .58917 .78028 L p .799 .061 .806 r
F P
0 g
s
.69555 .76606 m .65065 .75812 L .66576 .72593 L p .81 .058 .791 r
F P
0 g
s
.66576 .72593 m .70935 .7323 L .69555 .76606 L p .81 .058 .791 r
F P
0 g
s
.49099 .5129 m .51398 .52411 L .49461 .53043 L p 1 .046 .731 r
F P
0 g
s
.49461 .53043 m .46991 .51742 L .49099 .5129 L p 1 .046 .731 r
F P
0 g
s
.55478 .52703 m .58226 .53423 L .56902 .54322 L p 1 .055 .777 r
F P
0 g
s
.56902 .54322 m .53999 .53421 L .55478 .52703 L p 1 .055 .777 r
F P
0 g
s
.77026 .53727 m .81568 .5364 L .81301 .55562 L p .932 .07 .852 r
F P
0 g
s
.81301 .55562 m .76657 .55461 L .77026 .53727 L p .932 .07 .852 r
F P
0 g
s
.72818 .53711 m .77026 .53727 L .76657 .55461 L p .942 .07 .85 r
F P
0 g
s
.76657 .55461 m .72337 .55259 L .72818 .53711 L p .942 .07 .85 r
F P
0 g
s
.68939 .53592 m .72818 .53711 L .72337 .55259 L p .955 .069 .845 r
F P
0 g
s
.72337 .55259 m .68338 .54954 L .68939 .53592 L p .955 .069 .845 r
F P
0 g
s
.48535 .78494 m .44873 .76987 L .47603 .74271 L p .79 .065 .824 r
F P
0 g
s
.47603 .74271 m .51092 .7563 L .48535 .78494 L p .79 .065 .824 r
F P
0 g
s
.65065 .75812 m .60869 .74919 L .62523 .71858 L p .804 .059 .795 r
F P
0 g
s
.62523 .71858 m .66576 .72593 L .65065 .75812 L p .804 .059 .795 r
F P
0 g
s
.65387 .5337 m .68939 .53592 L .68338 .54954 L p .97 .068 .838 r
F P
0 g
s
.68338 .54954 m .64655 .54548 L .65387 .5337 L p .97 .068 .838 r
F P
0 g
s
.54863 .76882 m .51092 .7563 L .53357 .72825 L p .793 .062 .812 r
F P
0 g
s
.53357 .72825 m .56967 .73924 L .54863 .76882 L p .793 .062 .812 r
F P
0 g
s
.53039 .51874 m .55478 .52703 L .53999 .53421 L p 1 .05 .752 r
F P
0 g
s
.53999 .53421 m .51398 .52411 L .53039 .51874 L p 1 .05 .752 r
F P
0 g
s
.80579 .74211 m .75601 .73768 L .7655 .70263 L p .821 .056 .779 r
F P
0 g
s
.7655 .70263 m .81415 .70538 L .80579 .74211 L p .821 .056 .779 r
F P
0 g
s
.4294 .48787 m .44817 .50325 L .42241 .50696 L p 1 .041 .707 r
F P
0 g
s
.42241 .50696 m .40176 .48977 L .4294 .48787 L p 1 .041 .707 r
F P
0 g
s
.62156 .53044 m .65387 .5337 L .64655 .54548 L p .988 .065 .827 r
F P
0 g
s
.64655 .54548 m .61285 .54038 L .62156 .53044 L p .988 .065 .827 r
F P
0 g
s
.38404 .47129 m .40176 .48977 L .37128 .49269 L p .991 .042 .709 r
F P
0 g
s
.37128 .49269 m .35156 .47239 L .38404 .47129 L p .991 .042 .709 r
F P
0 g
s
.47102 .50054 m .49099 .5129 L .46991 .51742 L p 1 .042 .71 r
F P
0 g
s
.46991 .51742 m .44817 .50325 L .47102 .50054 L p 1 .042 .71 r
F P
0 g
s
.75601 .73768 m .70935 .7323 L .72006 .69891 L p .816 .056 .782 r
F P
0 g
s
.72006 .69891 m .7655 .70263 L .75601 .73768 L p .816 .056 .782 r
F P
0 g
s
.59245 .52613 m .62156 .53044 L .61285 .54038 L p 1 .062 .81 r
F P
0 g
s
.61285 .54038 m .58226 .53423 L .59245 .52613 L p 1 .062 .81 r
F P
0 g
s
.60869 .74919 m .56967 .73924 L .58772 .71021 L p .797 .06 .8 r
F P
0 g
s
.58772 .71021 m .62523 .71858 L .60869 .74919 L p .797 .06 .8 r
F P
0 g
s
.33472 .45072 m .35156 .47239 L .3163 .47453 L p .974 .043 .713 r
F P
0 g
s
.3163 .47453 m .29733 .45103 L .33472 .45072 L p .974 .043 .713 r
F P
0 g
s
.50909 .50936 m .53039 .51874 L .51398 .52411 L p 1 .045 .724 r
F P
0 g
s
.51398 .52411 m .49099 .5129 L .50909 .50936 L p 1 .045 .724 r
F P
0 g
s
.70935 .7323 m .66576 .72593 L .67781 .6942 L p .81 .057 .784 r
F P
0 g
s
.67781 .6942 m .72006 .69891 L .70935 .7323 L p .81 .057 .784 r
F P
0 g
s
.56652 .52077 m .59245 .52613 L .58226 .53423 L p 1 .057 .785 r
F P
0 g
s
.58226 .53423 m .55478 .52703 L .56652 .52077 L p 1 .057 .785 r
F P
0 g
s
.44873 .76987 m .41485 .75366 L .44397 .728 L p .785 .066 .832 r
F P
0 g
s
.44397 .728 m .47603 .74271 L .44873 .76987 L p .785 .066 .832 r
F P
0 g
s
.51092 .7563 m .47603 .74271 L .50039 .71619 L p .786 .064 .82 r
F P
0 g
s
.50039 .71619 m .53357 .72825 L .51092 .7563 L p .786 .064 .82 r
F P
0 g
s
.45411 .487 m .47102 .50054 L .44817 .50325 L p 1 .039 .693 r
F P
0 g
s
.44817 .50325 m .4294 .48787 L .45411 .487 L p 1 .039 .693 r
F P
0 g
s
.56967 .73924 m .53357 .72825 L .55323 .70082 L p .79 .061 .807 r
F P
0 g
s
.55323 .70082 m .58772 .71021 L .56967 .73924 L p .79 .061 .807 r
F P
0 g
s
.41363 .47124 m .4294 .48787 L .40176 .48977 L p 1 .039 .696 r
F P
0 g
s
.40176 .48977 m .38404 .47129 L .41363 .47124 L p 1 .039 .696 r
F P
0 g
s
.66576 .72593 m .62523 .71858 L .6387 .6885 L p .804 .058 .788 r
F P
0 g
s
.6387 .6885 m .67781 .6942 L .66576 .72593 L p .804 .058 .788 r
F P
0 g
s
.54376 .51434 m .56652 .52077 L .55478 .52703 L p 1 .051 .754 r
F P
0 g
s
.55478 .52703 m .53039 .51874 L .54376 .51434 L p 1 .051 .754 r
F P
0 g
s
.4909 .49885 m .50909 .50936 L .49099 .5129 L p 1 .039 .697 r
F P
0 g
s
.49099 .5129 m .47102 .50054 L .4909 .49885 L p 1 .039 .697 r
F P
0 g
s
.36928 .45148 m .38404 .47129 L .35156 .47239 L p .985 .04 .702 r
F P
0 g
s
.35156 .47239 m .33472 .45072 L .36928 .45148 L p .985 .04 .702 r
F P
0 g
s
.72973 .52234 m .77065 .52057 L .77026 .53727 L p .938 .073 .864 r
F P
0 g
s
.77026 .53727 m .72818 .53711 L .72973 .52234 L p .938 .073 .864 r
F P
0 g
s
.81568 .5364 m .77026 .53727 L .77065 .52057 L p .928 .073 .864 r
F P
0 g
s
.69219 .52306 m .72973 .52234 L .72818 .53711 L p .951 .072 .861 r
F P
0 g
s
.72818 .53711 m .68939 .53592 L .69219 .52306 L p .951 .072 .861 r
F P
0 g
s
.77065 .52057 m .81503 .51774 L .81568 .5364 L p .928 .073 .864 r
F P
0 g
s
.658 .52274 m .69219 .52306 L .68939 .53592 L p .967 .071 .856 r
F P
0 g
s
.68939 .53592 m .65387 .5337 L .658 .52274 L p .967 .071 .856 r
F P
0 g
s
.62523 .71858 m .58772 .71021 L .6027 .68179 L p .796 .059 .794 r
F P
0 g
s
.6027 .68179 m .6387 .6885 L .62523 .71858 L p .796 .059 .794 r
F P
0 g
s
.81415 .70538 m .7655 .70263 L .77178 .66793 L p .823 .055 .773 r
F P
0 g
s
.77178 .66793 m .81928 .66892 L .81415 .70538 L p .823 .055 .773 r
F P
0 g
s
.62712 .52137 m .658 .52274 L .65387 .5337 L p .988 .069 .846 r
F P
0 g
s
.65387 .5337 m .62156 .53044 L .62712 .52137 L p .988 .069 .846 r
F P
0 g
s
.47603 .74271 m .44397 .728 L .47014 .70304 L p .78 .066 .829 r
F P
0 g
s
.47014 .70304 m .50039 .71619 L .47603 .74271 L p .78 .066 .829 r
F P
0 g
s
.52416 .50682 m .54376 .51434 L .53039 .51874 L p 1 .043 .716 r
F P
0 g
s
.53039 .51874 m .50909 .50936 L .52416 .50682 L p 1 .043 .716 r
F P
0 g
s
.7655 .70263 m .72006 .69891 L .7276 .66595 L p .817 .055 .775 r
F P
0 g
s
.7276 .66595 m .77178 .66793 L .7655 .70263 L p .817 .055 .775 r
F P
0 g
s
.53357 .72825 m .50039 .71619 L .52174 .69037 L p .783 .063 .816 r
F P
0 g
s
.52174 .69037 m .55323 .70082 L .53357 .72825 L p .783 .063 .816 r
F P
0 g
s
.5995 .51895 m .62712 .52137 L .62156 .53044 L p 1 .066 .828 r
F P
0 g
s
.62156 .53044 m .59245 .52613 L .5995 .51895 L p 1 .066 .828 r
F P
0 g
s
.32082 .4276 m .33472 .45072 L .29733 .45103 L p .967 .042 .709 r
F P
0 g
s
.29733 .45103 m .28121 .42603 L .32082 .4276 L p .967 .042 .709 r
F P
0 g
s
.41485 .75366 m .38371 .73627 L .41476 .71213 L p .78 .068 .841 r
F P
0 g
s
.41476 .71213 m .44397 .728 L .41485 .75366 L p .78 .068 .841 r
F P
0 g
s
.44027 .47226 m .45411 .487 L .4294 .48787 L p 1 .036 .679 r
F P
0 g
s
.4294 .48787 m .41363 .47124 L .44027 .47226 L p 1 .036 .679 r
F P
0 g
s
.72006 .69891 m .67781 .6942 L .68669 .66298 L p .811 .055 .777 r
F P
0 g
s
.68669 .66298 m .7276 .66595 L .72006 .69891 L p .811 .055 .777 r
F P
0 g
s
.47582 .4872 m .4909 .49885 L .47102 .50054 L p 1 .035 .673 r
F P
0 g
s
.47102 .50054 m .45411 .487 L .47582 .4872 L p 1 .035 .673 r
F P
0 g
s
.57514 .51548 m .5995 .51895 L .59245 .52613 L p 1 .06 .801 r
F P
0 g
s
.59245 .52613 m .56652 .52077 L .57514 .51548 L p 1 .06 .801 r
F P
0 g
s
.58772 .71021 m .55323 .70082 L .56982 .67405 L p .788 .06 .8 r
F P
0 g
s
.56982 .67405 m .6027 .68179 L .58772 .71021 L p .788 .06 .8 r
F P
0 g
s
.40091 .45333 m .41363 .47124 L .38404 .47129 L p .999 .038 .689 r
F P
0 g
s
.38404 .47129 m .36928 .45148 L .40091 .45333 L p .999 .038 .689 r
F P
0 g
s
.50772 .4982 m .52416 .50682 L .50909 .50936 L p 1 .036 .678 r
F P
0 g
s
.50909 .50936 m .4909 .49885 L .50772 .4982 L p 1 .036 .678 r
F P
0 g
s
.67781 .6942 m .6387 .6885 L .64902 .659 L p .804 .056 .78 r
F P
0 g
s
.64902 .659 m .68669 .66298 L .67781 .6942 L p .804 .056 .78 r
F P
0 g
s
.55401 .51094 m .57514 .51548 L .56652 .52077 L p 1 .052 .76 r
F P
0 g
s
.56652 .52077 m .54376 .51434 L .55401 .51094 L p 1 .052 .76 r
F P
0 g
s
.50039 .71619 m .47014 .70304 L .49327 .67884 L p .775 .065 .826 r
F P
0 g
s
.49327 .67884 m .52174 .69037 L .50039 .71619 L p .775 .065 .826 r
F P
0 g
s
.35753 .43028 m .36928 .45148 L .33472 .45072 L p .977 .04 .698 r
F P
0 g
s
.33472 .45072 m .32082 .4276 L .35753 .43028 L p .977 .04 .698 r
F P
0 g
s
.6387 .6885 m .6027 .68179 L .61455 .65401 L p .796 .057 .785 r
F P
0 g
s
.61455 .65401 m .64902 .659 L .6387 .6885 L p .796 .057 .785 r
F P
0 g
s
.44397 .728 m .41476 .71213 L .44282 .68876 L p .774 .068 .84 r
F P
0 g
s
.44282 .68876 m .47014 .70304 L .44397 .728 L p .774 .068 .84 r
F P
0 g
s
.55323 .70082 m .52174 .69037 L .54002 .66527 L p .78 .062 .809 r
F P
0 g
s
.54002 .66527 m .56982 .67405 L .55323 .70082 L p .78 .062 .809 r
F P
0 g
s
.5361 .50532 m .55401 .51094 L .54376 .51434 L p 1 .041 .707 r
F P
0 g
s
.54376 .51434 m .52416 .50682 L .5361 .50532 L p 1 .041 .707 r
F P
0 g
s
.46388 .47437 m .47582 .4872 L .45411 .487 L p 1 .031 .656 r
F P
0 g
s
.45411 .487 m .44027 .47226 L .46388 .47437 L p 1 .031 .656 r
F P
0 g
s
.49446 .48846 m .50772 .4982 L .4909 .49885 L p 1 .029 .645 r
F P
0 g
s
.4909 .49885 m .47582 .4872 L .49446 .48846 L p 1 .029 .645 r
F P
0 g
s
.42954 .45627 m .44027 .47226 L .41363 .47124 L p 1 .034 .671 r
F P
0 g
s
.41363 .47124 m .40091 .45333 L .42954 .45627 L p 1 .034 .671 r
F P
0 g
s
.38371 .73627 m .35534 .71765 L .38841 .69506 L p .776 .07 .851 r
F P
0 g
s
.38841 .69506 m .41476 .71213 L .38371 .73627 L p .776 .07 .851 r
F P
0 g
s
.65886 .51264 m .69168 .51101 L .69219 .52306 L p .96 .076 .878 r
F P
0 g
s
.69219 .52306 m .658 .52274 L .65886 .51264 L p .96 .076 .878 r
F P
0 g
s
.72973 .52234 m .69219 .52306 L .69168 .51101 L p .944 .076 .88 r
F P
0 g
s
.81928 .66892 m .77178 .66793 L .77477 .63363 L p .825 .053 .767 r
F P
0 g
s
.77477 .63363 m .82109 .63277 L .81928 .66892 L p .825 .053 .767 r
F P
0 g
s
.62942 .51321 m .65886 .51264 L .658 .52274 L p .982 .074 .871 r
F P
0 g
s
.658 .52274 m .62712 .52137 L .62942 .51321 L p .982 .074 .871 r
F P
0 g
s
.69168 .51101 m .72793 .50831 L .72973 .52234 L p .944 .076 .88 r
F P
0 g
s
.77065 .52057 m .72973 .52234 L .72793 .50831 L p .931 .076 .879 r
F P
0 g
s
.6027 .68179 m .56982 .67405 L .58326 .648 L p .787 .058 .792 r
F P
0 g
s
.58326 .648 m .61455 .65401 L .6027 .68179 L p .787 .058 .792 r
F P
0 g
s
.77178 .66793 m .7276 .66595 L .73187 .63347 L p .82 .053 .767 r
F P
0 g
s
.73187 .63347 m .77477 .63363 L .77178 .66793 L p .82 .053 .767 r
F P
0 g
s
.60333 .51272 m .62942 .51321 L .62712 .52137 L p 1 .071 .856 r
F P
0 g
s
.62712 .52137 m .5995 .51895 L .60333 .51272 L p 1 .071 .856 r
F P
0 g
s
.72793 .50831 m .76765 .50454 L .77065 .52057 L p .931 .076 .879 r
F P
0 g
s
.81503 .51774 m .77065 .52057 L .76765 .50454 L p .922 .075 .877 r
F P
0 g
s
.52141 .49862 m .5361 .50532 L .52416 .50682 L p 1 .03 .649 r
F P
0 g
s
.52416 .50682 m .50772 .4982 L .52141 .49862 L p 1 .03 .649 r
F P
0 g
s
.7276 .66595 m .68669 .66298 L .69233 .6323 L p .814 .054 .769 r
F P
0 g
s
.69233 .6323 m .73187 .63347 L .7276 .66595 L p .814 .054 .769 r
F P
0 g
s
.3099 .40297 m .32082 .4276 L .28121 .42603 L p .96 .041 .707 r
F P
0 g
s
.28121 .42603 m .26799 .39945 L .3099 .40297 L p .96 .041 .707 r
F P
0 g
s
.58055 .51117 m .60333 .51272 L .5995 .51895 L p 1 .065 .825 r
F P
0 g
s
.5995 .51895 m .57514 .51548 L .58055 .51117 L p 1 .065 .825 r
F P
0 g
s
.39127 .43407 m .40091 .45333 L .36928 .45148 L p .989 .037 .685 r
F P
0 g
s
.36928 .45148 m .35753 .43028 L .39127 .43407 L p .989 .037 .685 r
F P
0 g
s
.76765 .50454 m .81093 .49969 L .81503 .51774 L p .922 .075 .877 r
F P
0 g
s
.52174 .69037 m .49327 .67884 L .51331 .65542 L p .77 .064 .821 r
F P
0 g
s
.51331 .65542 m .54002 .66527 L .52174 .69037 L p .77 .064 .821 r
F P
0 g
s
.47014 .70304 m .44282 .68876 L .46782 .6662 L p .768 .068 .838 r
F P
0 g
s
.46782 .6662 m .49327 .67884 L .47014 .70304 L p .768 .068 .838 r
F P
0 g
s
.68669 .66298 m .64902 .659 L .65611 .63012 L p .807 .054 .771 r
F P
0 g
s
.65611 .63012 m .69233 .6323 L .68669 .66298 L p .807 .054 .771 r
F P
0 g
s
.56107 .50855 m .58055 .51117 L .57514 .51548 L p 1 .055 .773 r
F P
0 g
s
.57514 .51548 m .55401 .51094 L .56107 .50855 L p 1 .055 .773 r
F P
0 g
s
.56982 .67405 m .54002 .66527 L .55514 .64094 L p .777 .06 .801 r
F P
0 g
s
.55514 .64094 m .58326 .648 L .56982 .67405 L p .777 .06 .801 r
F P
0 g
s
.48439 .47757 m .49446 .48846 L .47582 .4872 L p 1 .025 .624 r
F P
0 g
s
.47582 .4872 m .46388 .47437 L .48439 .47757 L p 1 .025 .624 r
F P
0 g
s
.45511 .46033 m .46388 .47437 L .44027 .47226 L p 1 .03 .648 r
F P
0 g
s
.44027 .47226 m .42954 .45627 L .45511 .46033 L p 1 .03 .648 r
F P
0 g
s
.64902 .659 m .61455 .65401 L .62318 .62692 L p .798 .055 .775 r
F P
0 g
s
.62318 .62692 m .65611 .63012 L .64902 .659 L p .798 .055 .775 r
F P
0 g
s
.41476 .71213 m .38841 .69506 L .41845 .67331 L p .769 .07 .851 r
F P
0 g
s
.41845 .67331 m .44282 .68876 L .41476 .71213 L p .769 .07 .851 r
F P
0 g
s
.50996 .49081 m .52141 .49862 L .50772 .4982 L p 1 .02 .601 r
F P
0 g
s
.50772 .4982 m .49446 .48846 L .50996 .49081 L p 1 .02 .601 r
F P
0 g
s
.54486 .50487 m .56107 .50855 L .55401 .51094 L p 1 .039 .695 r
F P
0 g
s
.55401 .51094 m .5361 .50532 L .54486 .50487 L p 1 .039 .695 r
F P
0 g
s
.34886 .40763 m .35753 .43028 L .32082 .4276 L p .968 .039 .697 r
F P
0 g
s
.32082 .4276 m .3099 .40297 L .34886 .40763 L p .968 .039 .697 r
F P
0 g
s
.61455 .65401 m .58326 .648 L .5935 .62269 L p .788 .056 .781 r
F P
0 g
s
.5935 .62269 m .62318 .62692 L .61455 .65401 L p .788 .056 .781 r
F P
0 g
s
.42197 .43899 m .42954 .45627 L .40091 .45333 L p 1 .034 .668 r
F P
0 g
s
.40091 .45333 m .39127 .43407 L .42197 .43899 L p 1 .034 .668 r
F P
0 g
s
.53193 .50011 m .54486 .50487 L .5361 .50532 L p 1 .021 .604 r
F P
0 g
s
.5361 .50532 m .52141 .49862 L .53193 .50011 L p 1 .021 .604 r
F P
0 g
s
.49327 .67884 m .46782 .6662 L .4897 .64448 L p .761 .067 .835 r
F P
0 g
s
.4897 .64448 m .51331 .65542 L .49327 .67884 L p .761 .067 .835 r
F P
0 g
s
.54002 .66527 m .51331 .65542 L .53019 .63283 L p .766 .063 .813 r
F P
0 g
s
.53019 .63283 m .55514 .64094 L .54002 .66527 L p .766 .063 .813 r
F P
0 g
s
.35534 .71765 m .32977 .69775 L .36496 .67675 L p .773 .072 .861 r
F P
0 g
s
.36496 .67675 m .38841 .69506 L .35534 .71765 L p .773 .072 .861 r
F P
0 g
s
.50175 .48187 m .50996 .49081 L .49446 .48846 L p 1 .015 .575 r
F P
0 g
s
.49446 .48846 m .48439 .47757 L .50175 .48187 L p 1 .015 .575 r
F P
0 g
s
.44282 .68876 m .41845 .67331 L .4454 .65242 L p .761 .07 .852 r
F P
0 g
s
.4454 .65242 m .46782 .6662 L .44282 .68876 L p .761 .07 .852 r
F P
0 g
s
.47755 .4655 m .48439 .47757 L .46388 .47437 L p 1 .023 .616 r
F P
0 g
s
.46388 .47437 m .45511 .46033 L .47755 .4655 L p 1 .023 .616 r
F P
0 g
s
.58326 .648 m .55514 .64094 L .56706 .61743 L p .776 .058 .79 r
F P
0 g
s
.56706 .61743 m .5935 .62269 L .58326 .648 L p .776 .058 .79 r
F P
0 g
s
.60386 .50746 m .6284 .50598 L .62942 .51321 L p .992 .079 .893 r
F P
0 g
s
.62942 .51321 m .60333 .51272 L .60386 .50746 L p .992 .079 .893 r
F P
0 g
s
.65886 .51264 m .62942 .51321 L .6284 .50598 L p .967 .081 .903 r
F P
0 g
s
.82109 .63277 m .77477 .63363 L .77439 .59977 L p .829 .052 .76 r
F P
0 g
s
.77477 .63363 m .73187 .63347 L .7328 .60152 L p .824 .052 .759 r
F P
0 g
s
.7328 .60152 m .77439 .59977 L .77477 .63363 L p .824 .052 .759 r
F P
0 g
s
.73187 .63347 m .69233 .6323 L .69466 .60223 L p .817 .052 .76 r
F P
0 g
s
.69466 .60223 m .7328 .60152 L .73187 .63347 L p .817 .052 .76 r
F P
0 g
s
.58269 .50787 m .60386 .50746 L .60333 .51272 L p 1 .073 .864 r
F P
0 g
s
.60333 .51272 m .58055 .51117 L .58269 .50787 L p 1 .073 .864 r
F P
0 g
s
.6284 .50598 m .65635 .50342 L .65886 .51264 L p .967 .081 .903 r
F P
0 g
s
.69168 .51101 m .65886 .51264 L .65635 .50342 L p .947 .081 .904 r
F P
0 g
s
.77439 .59977 m .81948 .59699 L .82109 .63277 L p .829 .052 .76 r
F P
0 g
s
.52227 .49425 m .53193 .50011 L .52141 .49862 L p 1 .005 .526 r
F P
0 g
s
.52141 .49862 m .50996 .49081 L .52227 .49425 L p 1 .005 .526 r
F P
0 g
s
.69233 .6323 m .65611 .63012 L .65992 .60192 L p .81 .052 .761 r
F P
0 g
s
.65992 .60192 m .69466 .60223 L .69233 .6323 L p .81 .052 .761 r
F P
0 g
s
.56487 .50721 m .58269 .50787 L .58055 .51117 L p 1 .06 .798 r
F P
0 g
s
.58055 .51117 m .56107 .50855 L .56487 .50721 L p 1 .06 .798 r
F P
0 g
s
.65635 .50342 m .68775 .49979 L .69168 .51101 L p .947 .081 .904 r
F P
0 g
s
.72793 .50831 m .69168 .51101 L .68775 .49979 L p .933 .08 .901 r
F P
0 g
s
.38478 .41343 m .39127 .43407 L .35753 .43028 L p .977 .037 .684 r
F P
0 g
s
.35753 .43028 m .34886 .40763 L .38478 .41343 L p .977 .037 .684 r
F P
0 g
s
.44955 .44504 m .45511 .46033 L .42954 .45627 L p 1 .029 .647 r
F P
0 g
s
.42954 .45627 m .42197 .43899 L .44955 .44504 L p 1 .029 .647 r
F P
0 g
s
.65611 .63012 m .62318 .62692 L .62854 .60057 L p .801 .053 .764 r
F P
0 g
s
.62854 .60057 m .65992 .60192 L .65611 .63012 L p .801 .053 .764 r
F P
0 g
s
.55037 .50548 m .56487 .50721 L .56107 .50855 L p 1 .036 .682 r
F P
0 g
s
.54486 .50487 m .55037 .50548 L p .55752 .50754 L 1 .036 .682 r
F P
0 g
s
.55702 .50763 m .54486 .50487 L p .55752 .50754 L 1 .036 .682 r
F P
0 g
s
.56487 .50721 m .55037 .50548 L .55259 .50718 L p .5 0 .5 r
F P
0 g
s
.56535 .50693 m .56487 .50721 L p .55921 .5072 L .5 0 .5 r
F P
0 g
s
.55259 .50718 m .56003 .50704 L p .55921 .5072 L .5 0 .5 r
F P
0 g
s
.56003 .50704 m .56535 .50693 L p .55921 .5072 L .5 0 .5 r
F P
0 g
s
.56107 .50855 m .55702 .50763 L p .55752 .50754 L 1 .036 .682 r
F P
0 g
s
.68775 .49979 m .72266 .49506 L .72793 .50831 L p .933 .08 .901 r
F P
0 g
s
.76765 .50454 m .72793 .50831 L .72266 .49506 L p .922 .079 .896 r
F P
0 g
s
.51331 .65542 m .4897 .64448 L .50839 .62365 L p .754 .066 .829 r
F P
0 g
s
.50839 .62365 m .53019 .63283 L .51331 .65542 L p .754 .066 .829 r
F P
0 g
s
.38841 .69506 m .36496 .67675 L .39707 .65665 L p .765 .073 .864 r
F P
0 g
s
.39707 .65665 m .41845 .67331 L .38841 .69506 L p .765 .073 .864 r
F P
0 g
s
.30205 .37676 m .3099 .40297 L .26799 .39945 L p .953 .041 .707 r
F P
0 g
s
.26799 .39945 m .25775 .37122 L .30205 .37676 L p .953 .041 .707 r
F P
0 g
s
.55514 .64094 m .53019 .63283 L .54385 .61111 L p .762 .061 .803 r
F P
0 g
s
.54385 .61111 m .56706 .61743 L .55514 .64094 L p .762 .061 .803 r
F P
0 g
s
.62318 .62692 m .5935 .62269 L .60048 .59818 L p .79 .054 .768 r
F P
0 g
s
.60048 .59818 m .62854 .60057 L .62318 .62692 L p .79 .054 .768 r
F P
0 g
s
.53919 .50268 m .55037 .50548 L .54486 .50487 L p 1 .007 .533 r
F P
0 g
s
.54486 .50487 m .53193 .50011 L .53919 .50268 L p 1 .007 .533 r
F P
0 g
s
.46782 .6662 m .4454 .65242 L .46919 .63242 L p .752 .07 .851 r
F P
0 g
s
.46919 .63242 m .4897 .64448 L .46782 .6662 L p .752 .07 .851 r
F P
0 g
s
.72266 .49506 m .76114 .48924 L .76765 .50454 L p .922 .079 .896 r
F P
0 g
s
.81093 .49969 m .76765 .50454 L .76114 .48924 L p .913 .078 .891 r
F P
0 g
s
.4968 .47179 m .50175 .48187 L .48439 .47757 L p 1 .014 .572 r
F P
0 g
s
.48439 .47757 m .47755 .4655 L .4968 .47179 L p 1 .014 .572 r
F P
0 g
s
.51589 .48729 m .52227 .49425 L .50996 .49081 L p 1 0 .5 r
F P
0 g
s
.50996 .49081 m .50175 .48187 L .51589 .48729 L p 1 0 .5 r
F P
0 g
s
.5935 .62269 m .56706 .61743 L .57572 .59476 L p .777 .055 .776 r
F P
0 g
s
.57572 .59476 m .60048 .59818 L .5935 .62269 L p .777 .055 .776 r
F P
0 g
s
.4176 .42038 m .42197 .43899 L .39127 .43407 L p .986 .034 .669 r
F P
0 g
s
.39127 .43407 m .38478 .41343 L .4176 .42038 L p .986 .034 .669 r
F P
0 g
s
.47397 .45222 m .47755 .4655 L .45511 .46033 L p 1 .024 .619 r
F P
0 g
s
.45511 .46033 m .44955 .44504 L .47397 .45222 L p 1 .024 .619 r
F P
0 g
s
.53133 .49879 m .53919 .50268 L .53193 .50011 L p 1 0 .5 r
F P
0 g
s
.53193 .50011 m .52227 .49425 L .53133 .49879 L p 1 0 .5 r
F P
0 g
s
.76114 .48924 m .80325 .4823 L .81093 .49969 L p .913 .078 .891 r
F P
0 g
s
.41845 .67331 m .39707 .65665 L .42603 .63746 L p .756 .073 .866 r
F P
0 g
s
.42603 .63746 m .4454 .65242 L .41845 .67331 L p .756 .073 .866 r
F P
0 g
s
.53019 .63283 m .50839 .62365 L .52386 .60372 L p .747 .064 .821 r
F P
0 g
s
.52386 .60372 m .54385 .61111 L .53019 .63283 L p .747 .064 .821 r
F P
0 g
s
.34332 .38347 m .34886 .40763 L .3099 .40297 L p .958 .039 .697 r
F P
0 g
s
.3099 .40297 m .30205 .37676 L .34332 .38347 L p .958 .039 .697 r
F P
0 g
s
.4897 .64448 m .46919 .63242 L .48977 .61336 L p .742 .07 .849 r
F P
0 g
s
.48977 .61336 m .50839 .62365 L .4897 .64448 L p .742 .07 .849 r
F P
0 g
s
.56706 .61743 m .54385 .61111 L .55425 .59028 L p .761 .058 .788 r
F P
0 g
s
.55425 .59028 m .57572 .59476 L .56706 .61743 L p .761 .058 .788 r
F P
0 g
s
.51282 .4792 m .51589 .48729 L .50175 .48187 L p 1 .002 .508 r
F P
0 g
s
.50175 .48187 m .4968 .47179 L .51282 .4792 L p 1 .002 .508 r
F P
0 g
s
.32977 .69775 m .30705 .67651 L .34444 .65715 L p .771 .074 .871 r
F P
0 g
s
.34444 .65715 m .36496 .67675 L .32977 .69775 L p .771 .074 .871 r
F P
0 g
s
.56535 .50693 m .58149 .50561 L .58269 .50787 L p .975 .068 .841 r
F P
0 g
s
.58269 .50787 m .56487 .50721 L .56535 .50693 L p .975 .068 .841 r
F P
0 g
s
.60386 .50746 m .58269 .50787 L .58149 .50561 L p .975 .084 .92 r
F P
0 g
s
.52678 .49382 m .53133 .49879 L .52227 .49425 L p 1 0 .5 r
F P
0 g
s
.52227 .49425 m .51589 .48729 L .52678 .49382 L p 1 0 .5 r
F P
0 g
s
.7328 .60152 m .69466 .60223 L .6936 .57281 L p .823 .05 .75 r
F P
0 g
s
.69466 .60223 m .65992 .60192 L .66037 .57443 L p .816 .05 .749 r
F P
0 g
s
.66037 .57443 m .6936 .57281 L .69466 .60223 L p .816 .05 .749 r
F P
0 g
s
.58149 .50561 m .60101 .5032 L .60386 .50746 L p .975 .084 .92 r
F P
0 g
s
.6284 .50598 m .60386 .50746 L .60101 .5032 L p .959 .088 .942 r
F P
0 g
s
.65992 .60192 m .62854 .60057 L .63056 .57499 L p .807 .05 .75 r
F P
0 g
s
.63056 .57499 m .66037 .57443 L .65992 .60192 L p .807 .05 .75 r
F P
0 g
s
.77439 .59977 m .7328 .60152 L .73031 .57015 L p .828 .05 .751 r
F P
0 g
s
.6936 .57281 m .73031 .57015 L .7328 .60152 L p .823 .05 .75 r
F P
0 g
s
.44725 .42847 m .44955 .44504 L .42197 .43899 L p .995 .03 .651 r
F P
0 g
s
.42197 .43899 m .4176 .42038 L .44725 .42847 L p .995 .03 .651 r
F P
0 g
s
.49516 .46054 m .4968 .47179 L .47755 .4655 L p 1 .017 .585 r
F P
0 g
s
.47755 .4655 m .47397 .45222 L .49516 .46054 L p 1 .017 .585 r
F P
0 g
s
.62854 .60057 m .60048 .59818 L .60414 .57451 L p .796 .05 .752 r
F P
0 g
s
.60414 .57451 m .63056 .57499 L .62854 .60057 L p .796 .05 .752 r
F P
0 g
s
.60101 .5032 m .62396 .49972 L .6284 .50598 L p .959 .088 .942 r
F P
0 g
s
.65635 .50342 m .6284 .50598 L .62396 .49972 L p .942 .088 .94 r
F P
0 g
s
.54317 .50635 m .55259 .50718 L .55037 .50548 L p .505 .005 .527 r
F P
0 g
s
.55037 .50548 m .53919 .50268 L .54317 .50635 L p .505 .005 .527 r
F P
0 g
s
.81948 .59699 m .77439 .59977 L .77054 .56642 L p .833 .05 .752 r
F P
0 g
s
.73031 .57015 m .77054 .56642 L .77439 .59977 L p .828 .05 .751 r
F P
0 g
s
.4454 .65242 m .42603 .63746 L .4518 .61921 L p .745 .074 .869 r
F P
0 g
s
.4518 .61921 m .46919 .63242 L .4454 .65242 L p .745 .074 .869 r
F P
0 g
s
.60048 .59818 m .57572 .59476 L .58107 .57297 L p .782 .052 .758 r
F P
0 g
s
.58107 .57297 m .60414 .57451 L .60048 .59818 L p .782 .052 .758 r
F P
0 g
s
.62396 .49972 m .65038 .49513 L .65635 .50342 L p .942 .088 .94 r
F P
0 g
s
.68775 .49979 m .65635 .50342 L .65038 .49513 L p .928 .086 .932 r
F P
0 g
s
.54385 .61111 m .52386 .60372 L .53605 .58475 L p .742 .061 .807 r
F P
0 g
s
.53605 .58475 m .55425 .59028 L .54385 .61111 L p .742 .061 .807 r
F P
0 g
s
.5371 .50445 m .54317 .50635 L .53919 .50268 L p .548 .048 .739 r
F P
0 g
s
.53919 .50268 m .53133 .49879 L .5371 .50445 L p .548 .048 .739 r
F P
0 g
s
.3815 .39134 m .38478 .41343 L .34886 .40763 L p .964 .037 .686 r
F P
0 g
s
.34886 .40763 m .34332 .38347 L .3815 .39134 L p .964 .037 .686 r
F P
0 g
s
.77054 .56642 m .81437 .56163 L .81948 .59699 L p .833 .05 .752 r
F P
0 g
s
.50839 .62365 m .48977 .61336 L .5071 .59526 L p .731 .069 .844 r
F P
0 g
s
.5071 .59526 m .52386 .60372 L .50839 .62365 L p .731 .069 .844 r
F P
0 g
s
.52556 .48774 m .52678 .49382 L .51589 .48729 L p 1 0 .5 r
F P
0 g
s
.51589 .48729 m .51282 .4792 L .52556 .48774 L p 1 0 .5 r
F P
0 g
s
.36496 .67675 m .34444 .65715 L .3787 .63873 L p .763 .075 .876 r
F P
0 g
s
.3787 .63873 m .39707 .65665 L .36496 .67675 L p .763 .075 .876 r
F P
0 g
s
.57572 .59476 m .55425 .59028 L .56134 .57039 L p .763 .054 .768 r
F P
0 g
s
.56134 .57039 m .58107 .57297 L .57572 .59476 L p .763 .054 .768 r
F P
0 g
s
.65038 .49513 m .68032 .48945 L .68775 .49979 L p .928 .086 .932 r
F P
0 g
s
.72266 .49506 m .68775 .49979 L .68032 .48945 L p .918 .084 .922 r
F P
0 g
s
.47369 .43771 m .47397 .45222 L .44955 .44504 L p 1 .026 .629 r
F P
0 g
s
.44955 .44504 m .44725 .42847 L .47369 .43771 L p 1 .026 .629 r
F P
0 g
s
.51308 .46998 m .51282 .4792 L .4968 .47179 L p 1 .008 .542 r
F P
0 g
s
.4968 .47179 m .49516 .46054 L .51308 .46998 L p 1 .008 .542 r
F P
0 g
s
.53437 .50146 m .5371 .50445 L .53133 .49879 L p 1 0 .5 r
F P
0 g
s
.53133 .49879 m .52678 .49382 L .53437 .50146 L p 1 0 .5 r
F P
0 g
s
.46919 .63242 m .4518 .61921 L .47433 .60195 L p .732 .074 .872 r
F P
0 g
s
.47433 .60195 m .48977 .61336 L .46919 .63242 L p .732 .074 .872 r
F P
0 g
s
.55425 .59028 m .53605 .58475 L .54493 .56675 L p .74 .057 .787 r
F P
0 g
s
.54493 .56675 m .56134 .57039 L .55425 .59028 L p .74 .057 .787 r
F P
0 g
s
.52386 .60372 m .5071 .59526 L .52113 .57814 L p .72 .067 .835 r
F P
0 g
s
.52113 .57814 m .53605 .58475 L .52386 .60372 L p .72 .067 .835 r
F P
0 g
s
.68032 .48945 m .71384 .48264 L .72266 .49506 L p .918 .084 .922 r
F P
0 g
s
.76114 .48924 m .72266 .49506 L .71384 .48264 L p .909 .083 .913 r
F P
0 g
s
.4165 .40038 m .4176 .42038 L .38478 .41343 L p .97 .035 .673 r
F P
0 g
s
.38478 .41343 m .3815 .39134 L .4165 .40038 L p .97 .035 .673 r
F P
0 g
s
.53499 .49739 m .53437 .50146 L .52678 .49382 L p 1 0 .5 r
F P
0 g
s
.52678 .49382 m .52556 .48774 L .53499 .49739 L p 1 0 .5 r
F P
0 g
s
.39707 .65665 m .3787 .63873 L .40976 .62128 L p .752 .076 .882 r
F P
0 g
s
.40976 .62128 m .42603 .63746 L .39707 .65665 L p .752 .076 .882 r
F P
0 g
s
.54381 .51113 m .55145 .50997 L .55259 .50718 L p .5 0 .5 r
F P
0 g
s
.55259 .50718 m .54317 .50635 L .54381 .51113 L p .5 0 .5 r
F P
0 g
s
.56535 .50693 m .55259 .50718 L .55145 .50997 L p .5 0 .5 r
F P
0 g
s
.66037 .57443 m .63056 .57499 L .62921 .55023 L p .815 .047 .735 r
F P
0 g
s
.63056 .57499 m .60414 .57451 L .60444 .5517 L p .805 .047 .734 r
F P
0 g
s
.60444 .5517 m .62921 .55023 L .63056 .57499 L p .805 .047 .734 r
F P
0 g
s
.29734 .34889 m .30205 .37676 L .25775 .37122 L p .945 .042 .708 r
F P
0 g
s
.25775 .37122 m .25055 .34125 L .29734 .34889 L p .945 .042 .708 r
F P
0 g
s
.55145 .50997 m .56247 .50773 L .56535 .50693 L p .5 0 .5 r
F P
0 g
s
.58149 .50561 m .56535 .50693 L .56247 .50773 L p .5 0 .5 r
F P
0 g
s
.60414 .57451 m .58107 .57297 L .58308 .55211 L p .791 .047 .736 r
F P
0 g
s
.58308 .55211 m .60444 .5517 L .60414 .57451 L p .791 .047 .736 r
F P
0 g
s
.6936 .57281 m .66037 .57443 L .65741 .5477 L p .823 .047 .737 r
F P
0 g
s
.62921 .55023 m .65741 .5477 L .66037 .57443 L p .815 .047 .735 r
F P
0 g
s
.49685 .44808 m .49516 .46054 L .47397 .45222 L p 1 .021 .604 r
F P
0 g
s
.47397 .45222 m .47369 .43771 L .49685 .44808 L p 1 .021 .604 r
F P
0 g
s
.5277 .48054 m .52556 .48774 L .51282 .4792 L p 1 0 .5 r
F P
0 g
s
.51282 .4792 m .51308 .46998 L .5277 .48054 L p 1 0 .5 r
F P
0 g
s
.53954 .51121 m .54381 .51113 L .54317 .50635 L p .544 .044 .722 r
F P
0 g
s
.54317 .50635 m .5371 .50445 L .53954 .51121 L p .544 .044 .722 r
F P
0 g
s
.56247 .50773 m .57688 .5044 L .58149 .50561 L p .5 0 .5 r
F P
0 g
s
.60101 .5032 m .58149 .50561 L .57688 .5044 L p .903 .099 .994 r
F P
0 g
s
.58107 .57297 m .56134 .57039 L .5651 .55146 L p .772 .048 .741 r
F P
0 g
s
.5651 .55146 m .58308 .55211 L .58107 .57297 L p .772 .048 .741 r
F P
0 g
s
.73031 .57015 m .6936 .57281 L .6891 .54409 L p .829 .048 .74 r
F P
0 g
s
.65741 .5477 m .6891 .54409 L .6936 .57281 L p .823 .047 .737 r
F P
0 g
s
.48977 .61336 m .47433 .60195 L .49357 .58568 L p .716 .075 .873 r
F P
0 g
s
.49357 .58568 m .5071 .59526 L .48977 .61336 L p .716 .075 .873 r
F P
0 g
s
.53863 .51022 m .53954 .51121 L .5371 .50445 L p .617 .117 1 r
F P
0 g
s
.5371 .50445 m .53437 .50146 L .53863 .51022 L p .617 .117 1 r
F P
0 g
s
.57688 .5044 m .59473 .49998 L .60101 .5032 L p .903 .099 .994 r
F P
0 g
s
.62396 .49972 m .60101 .5032 L .59473 .49998 L p .913 .099 .997 r
F P
0 g
s
.53605 .58475 m .52113 .57814 L .53183 .56203 L p .711 .064 .818 r
F P
0 g
s
.53183 .56203 m .54493 .56675 L .53605 .58475 L p .711 .064 .818 r
F P
0 g
s
.71384 .48264 m .751 .4747 L .76114 .48924 L p .909 .083 .913 r
F P
0 g
s
.80325 .4823 m .76114 .48924 L .751 .4747 L p .903 .081 .904 r
F P
0 g
s
.56134 .57039 m .54493 .56675 L .55047 .54974 L p .746 .051 .756 r
F P
0 g
s
.55047 .54974 m .5651 .55146 L .56134 .57039 L p .746 .051 .756 r
F P
0 g
s
.77054 .56642 m .73031 .57015 L .72433 .5394 L p .834 .048 .742 r
F P
0 g
s
.6891 .54409 m .72433 .5394 L .73031 .57015 L p .829 .048 .74 r
F P
0 g
s
.44827 .41057 m .44725 .42847 L .4176 .42038 L p .975 .032 .658 r
F P
0 g
s
.4176 .42038 m .4165 .40038 L .44827 .41057 L p .975 .032 .658 r
F P
0 g
s
.54109 .50814 m .53863 .51022 L .53437 .50146 L p 1 0 .5 r
F P
0 g
s
.53437 .50146 m .53499 .49739 L .54109 .50814 L p 1 0 .5 r
F P
0 g
s
.42603 .63746 m .40976 .62128 L .43758 .60482 L p .74 .078 .888 r
F P
0 g
s
.43758 .60482 m .4518 .61921 L .42603 .63746 L p .74 .078 .888 r
F P
0 g
s
.51671 .45958 m .51308 .46998 L .49516 .46054 L p 1 .015 .577 r
F P
0 g
s
.49516 .46054 m .49685 .44808 L .51671 .45958 L p 1 .015 .577 r
F P
0 g
s
.53898 .49221 m .53499 .49739 L .52556 .48774 L p 1 0 .5 r
F P
0 g
s
.52556 .48774 m .5277 .48054 L .53898 .49221 L p 1 0 .5 r
F P
0 g
s
.5071 .59526 m .49357 .58568 L .50948 .57044 L p .698 .075 .873 r
F P
0 g
s
.50948 .57044 m .52113 .57814 L .5071 .59526 L p .698 .075 .873 r
F P
0 g
s
.59473 .49998 m .61605 .49445 L .62396 .49972 L p .913 .099 .997 r
F P
0 g
s
.65038 .49513 m .62396 .49972 L .61605 .49445 L p .91 .096 .979 r
F P
0 g
s
.30705 .67651 m .28721 .65387 L .32689 .6362 L p .771 .076 .881 r
F P
0 g
s
.32689 .6362 m .34444 .65715 L .30705 .67651 L p .771 .076 .881 r
F P
0 g
s
.34101 .35773 m .34332 .38347 L .30205 .37676 L p .949 .04 .699 r
F P
0 g
s
.30205 .37676 m .29734 .34889 L .34101 .35773 L p .949 .04 .699 r
F P
0 g
s
.54493 .56675 m .53183 .56203 L .5392 .54696 L p .709 .057 .787 r
F P
0 g
s
.5392 .54696 m .55047 .54974 L .54493 .56675 L p .709 .057 .787 r
F P
0 g
s
.81437 .56163 m .77054 .56642 L .76316 .53363 L p .838 .049 .745 r
F P
0 g
s
.72433 .5394 m .76316 .53363 L .77054 .56642 L p .834 .048 .742 r
F P
0 g
s
.60444 .5517 m .58308 .55211 L .58172 .5322 L p .806 .042 .71 r
F P
0 g
s
.58308 .55211 m .5651 .55146 L .56549 .53352 L p .79 .042 .708 r
F P
0 g
s
.56549 .53352 m .58172 .5322 L .58308 .55211 L p .79 .042 .708 r
F P
0 g
s
.53709 .53105 m .53435 .52808 L .53863 .51909 L p .607 .107 1 r
F P
0 g
s
.53863 .51909 m .53435 .52808 L p .53772 .52255 L 1 0 .5 r
F P
0 g
s
.53955 .52008 m .53863 .51909 L p .53955 .51564 L .618 .118 1 r
F P
0 g
s
.53954 .51121 m .53863 .51022 L .53955 .52008 L p .618 .118 1 r
F P
0 g
s
.53863 .51909 m .53954 .51121 L p .53955 .51564 L .618 .118 1 r
F P
0 g
s
.54382 .52 m .53955 .52008 L .53932 .51761 L p .963 0 .5 r
F P
0 g
s
.54027 .51636 m .54382 .52 L .53932 .51761 L .963 0 .5 r
F
.54123 .51511 m .54382 .52 L .53909 .51515 L F
.54245 .51407 m .54314 .5126 L p .54164 .51476 L .595 .012 .559 r
F P
0 g
s
.54314 .5126 m .54381 .51113 L p .54123 .51511 L .595 .012 .559 r
F P
0 g
s
.54245 .51407 m .5428 .51555 L p .54123 .51511 L .963 0 .5 r
F P
0 g
s
.5428 .51555 m .54382 .52 L p .54175 .51608 L .963 0 .5 r
F P
0 g
s
.54123 .51511 m .5428 .51555 L .54175 .51608 L .963 0 .5 r
F
.55147 .51884 m .54382 .52 L .5428 .51555 L p .874 .008 .539 r
F P
0 g
s
.54123 .51511 m .54036 .51643 L .54314 .5126 L .595 .012 .559 r
F
.54036 .51643 m .53863 .51909 L .54089 .51584 L F
.54036 .51643 m .54089 .51584 L .54314 .5126 L F
.5428 .51555 m .54245 .51407 L p .54628 .51349 L .874 .008 .539 r
F P
0 g
s
.54381 .51113 m .53954 .51121 L .53909 .51515 L p .595 .012 .559 r
F P
0 g
s
.54381 .51113 m .53909 .51515 L .54123 .51511 L .595 .012 .559 r
F
.54628 .51349 m .55147 .51884 L .5428 .51555 L .874 .008 .539 r
F
.55145 .50997 m .54381 .51113 L .5428 .51333 L p .587 0 .5 r
F P
0 g
s
.5428 .51333 m .54109 .51702 L p .54628 .51349 L .587 0 .5 r
F P
0 g
s
.55145 .50997 m .5428 .51333 L .54628 .51349 L .587 0 .5 r
F
.54919 .51191 m .54957 .51307 L p .54803 .51254 L .874 .008 .539 r
F P
0 g
s
.54957 .51307 m .54976 .51365 L p .54916 .51326 L .874 .008 .539 r
F P
0 g
s
.54803 .51254 m .54957 .51307 L .54916 .51326 L .874 .008 .539 r
F
.54976 .51365 m .55147 .51884 L p .54628 .51349 L F P
0 g
s
.54919 .51191 m .54976 .51143 L p .54753 .51281 L .587 0 .5 r
F P
0 g
s
.54976 .51143 m .55145 .50997 L p .54628 .51349 L .587 0 .5 r
F P
0 g
s
.54628 .51349 m .54753 .51281 L .54976 .51143 L .587 0 .5 r
F
.54109 .50814 m .54803 .51254 L .54628 .51349 L .874 .008 .539 r
F
.54803 .51254 m .54976 .51365 L .54628 .51349 L F
.54628 .51349 m .54455 .51467 L .54753 .51281 L .587 0 .5 r
F
.56247 .50773 m .55145 .50997 L .54919 .51191 L p .5 0 .5 r
F P
0 g
s
.56251 .5166 m .55147 .51884 L .54919 .51191 L p .86 .02 .598 r
F P
0 g
s
.55471 .51079 m .56251 .5166 L .55086 .5125 L .86 .02 .598 r
F
.55471 .51079 m .55086 .5125 L .54919 .51191 L F
.55471 .51079 m .55011 .51173 L .54693 .51386 L .5 0 .5 r
F
.54919 .51191 m .54693 .51386 L p .55011 .51173 L F P
0 g
s
.53863 .51909 m .53955 .52008 L .53709 .53105 L p .607 .107 1 r
F P
0 g
s
.54109 .51702 m .53863 .51909 L p .53772 .52255 L 1 0 .5 r
F P
0 g
s
.53435 .52808 m .53497 .52402 L .54109 .51702 L p 1 0 .5 r
F P
0 g
s
.54319 .53295 m .53709 .53105 L .53955 .52008 L p .715 .033 .667 r
F P
0 g
s
.53955 .52008 m .54382 .52 L .54319 .53295 L p .715 .033 .667 r
F P
0 g
s
.54693 .51386 m .54109 .51702 L .53497 .52402 L p .809 0 .5 r
F P
0 g
s
.53497 .52402 m .53898 .51887 L .54693 .51386 L p .809 0 .5 r
F P
0 g
s
.54693 .51386 m .53898 .51887 L p .54144 .51755 L .63 0 .5 r
F P
0 g
s
.56247 .50773 m .55085 .51139 L .55471 .51079 L .5 0 .5 r
F
.55085 .51139 m .54919 .51191 L .55471 .51079 L F
.5575 .50908 m .55932 .50867 L .558 .50928 L .86 .02 .598 r
F
.54691 .50498 m .55932 .50867 L .5575 .50908 L F
.55932 .50867 m .55985 .50851 L p .5568 .50983 L .5 0 .5 r
F P
0 g
s
.55985 .50851 m .56247 .50773 L p .55471 .51079 L .5 0 .5 r
F P
0 g
s
.54691 .50498 m .558 .50928 L .55471 .51079 L .86 .02 .598 r
F
.54919 .51191 m .54691 .50498 L p .55471 .51079 L F P
0 g
s
.55471 .51079 m .55315 .51141 L .5568 .50983 L .5 0 .5 r
F
.55471 .51079 m .5568 .50983 L .55985 .50851 L F
.558 .50928 m .55985 .50999 L .55471 .51079 L .86 .02 .598 r
F
.57688 .5044 m .56247 .50773 L .55932 .50867 L p .5 0 .5 r
F P
0 g
s
.55853 .50891 m .55932 .50867 L p .55315 .51141 L .5 0 .5 r
F P
0 g
s
.5568 .50983 m .55315 .51141 L .55932 .50867 L .5 0 .5 r
F
.55932 .50867 m .55972 .50966 L p .558 .50928 L .86 .02 .598 r
F P
0 g
s
.55972 .50966 m .55985 .50999 L p .55938 .50981 L .86 .02 .598 r
F P
0 g
s
.558 .50928 m .55972 .50966 L .55938 .50981 L .86 .02 .598 r
F
.54691 .50498 m .55613 .50073 L .55932 .50867 L p F P
0 g
s
.57695 .51328 m .56251 .5166 L .55972 .50966 L p .856 .027 .634 r
F P
0 g
s
.55972 .50966 m .55932 .50867 L p .56654 .507 L .856 .027 .634 r
F P
0 g
s
.56654 .507 m .55932 .50867 L .56506 .50738 L .5 0 .5 r
F
.57688 .5044 m .56108 .50824 L .56654 .507 L F
.57104 .50481 m .57286 .50433 L .57146 .50493 L .856 .027 .634 r
F
.55613 .50073 m .57286 .50433 L .57104 .50481 L F
.59473 .49998 m .57688 .5044 L .57286 .50433 L p .83 .116 1 r
F P
0 g
s
.55613 .50073 m .56877 .49537 L .57286 .50433 L p .856 .027 .634 r
F P
0 g
s
.57286 .50433 m .57337 .50434 L p .56949 .50576 L .5 0 .5 r
F P
0 g
s
.57337 .50434 m .57688 .5044 L p .56654 .507 L .5 0 .5 r
F P
0 g
s
.55613 .50073 m .57146 .50493 L .56654 .507 L .856 .027 .634 r
F
.56654 .507 m .56949 .50576 L .57337 .50434 L .5 0 .5 r
F
.57146 .50493 m .57337 .50545 L .56654 .507 L .856 .027 .634 r
F
.56108 .50824 m .55932 .50867 L .56654 .507 L .5 0 .5 r
F
.55932 .50867 m .55613 .50073 L p .56654 .507 L .856 .027 .634 r
F P
0 g
s
.56654 .507 m .56506 .50738 L .56949 .50576 L .5 0 .5 r
F
.59483 .50887 m .57695 .51328 L .57286 .50433 L p .855 .032 .658 r
F P
0 g
s
.57286 .50433 m .56877 .49537 L p .5818 .50212 L .855 .032 .658 r
F P
0 g
s
.59473 .49998 m .57469 .50397 L .5818 .50212 L .83 .116 1 r
F
.57469 .50397 m .57286 .50433 L .5818 .50212 L F
.56877 .49537 m .58487 .4889 L .58985 .4989 L p .855 .032 .658 r
F P
0 g
s
.56877 .49537 m .58985 .4989 L .58839 .49948 L .855 .032 .658 r
F
.58985 .4989 m .59473 .49998 L p .5818 .50212 L .83 .116 1 r
F P
0 g
s
.56877 .49537 m .59035 .49989 L .5818 .50212 L .855 .032 .658 r
F
.56883 .50427 m .58495 .49781 L .58985 .4989 L p .83 .116 1 r
F P
0 g
s
.5818 .50212 m .56883 .50427 L .58985 .4989 L .83 .116 1 r
F
.58985 .4989 m .59035 .49989 L p .58839 .49948 L .855 .032 .658 r
F P
0 g
s
.59035 .49989 m .59483 .50887 L p .5818 .50212 L .855 .032 .658 r
F P
0 g
s
.5818 .50212 m .59483 .50887 L .57286 .50433 L .855 .032 .658 r
F
.5818 .50212 m .57286 .50433 L .58036 .50236 L .83 .116 1 r
F
.57286 .50433 m .56883 .50427 L p .58036 .50236 L F P
0 g
s
.57219 .50432 m .57286 .50433 L p .56506 .50738 L .5 0 .5 r
F P
0 g
s
.56949 .50576 m .56506 .50738 L .57286 .50433 L .5 0 .5 r
F
.57286 .50433 m .57337 .50545 L p .57146 .50493 L .856 .027 .634 r
F P
0 g
s
.57337 .50545 m .57695 .51328 L p .56654 .507 L .856 .027 .634 r
F P
0 g
s
.56654 .507 m .57695 .51328 L .55972 .50966 L .856 .027 .634 r
F
.55616 .50962 m .56883 .50427 L .57219 .50432 L p .5 0 .5 r
F P
0 g
s
.54693 .51386 m .55616 .50962 L .55853 .50891 L p .5 0 .5 r
F P
0 g
s
.55315 .51141 m .54693 .51386 L .55853 .50891 L .5 0 .5 r
F
.55932 .50867 m .55616 .50962 L p .56506 .50738 L F P
0 g
s
.56506 .50738 m .55616 .50962 L .57219 .50432 L .5 0 .5 r
F
.55985 .50999 m .56251 .5166 L p .55471 .51079 L .86 .02 .598 r
F P
0 g
s
.55616 .50962 m .54693 .51386 L p .54144 .51755 L .63 0 .5 r
F P
0 g
s
.54806 .51289 m .54919 .51191 L p .54455 .51467 L .587 0 .5 r
F P
0 g
s
.54753 .51281 m .54455 .51467 L .54919 .51191 L .587 0 .5 r
F
.54109 .50814 m .54691 .50498 L .54919 .51191 L p .874 .008 .539 r
F P
0 g
s
.54109 .50814 m .54919 .51191 L .54803 .51254 L .874 .008 .539 r
F
.54245 .51407 m .54109 .50814 L p .54455 .51171 L F P
0 g
s
.54455 .51171 m .54628 .51349 L .54245 .51407 L .874 .008 .539 r
F
.54109 .51702 m .54693 .51386 L .54806 .51289 L p .587 0 .5 r
F P
0 g
s
.54455 .51467 m .54109 .51702 L .54806 .51289 L .587 0 .5 r
F
.53863 .51022 m .54109 .50814 L .54245 .51407 L p .963 0 .5 r
F P
0 g
s
.53863 .51022 m .54245 .51407 L .54123 .51511 L .963 0 .5 r
F
.53863 .51909 m .54109 .51702 L .54245 .51407 L p .595 .012 .559 r
F P
0 g
s
.54164 .51476 m .53863 .51909 L .54245 .51407 L .595 .012 .559 r
F
.53932 .51761 m .53909 .51515 L p .54027 .51636 L .963 0 .5 r
F P
0 g
s
.53909 .51515 m .53863 .51022 L p .54123 .51511 L .963 0 .5 r
F P
0 g
s
.53909 .51515 m .53863 .51909 L p .54123 .51511 L .595 .012 .559 r
F P
0 g
s
.54691 .50498 m .54109 .50814 L .53499 .49739 L p .994 0 .5 r
F P
0 g
s
.53499 .49739 m .53898 .49221 L .54691 .50498 L p .994 0 .5 r
F P
0 g
s
.53322 .4722 m .5277 .48054 L .51308 .46998 L p 1 .011 .554 r
F P
0 g
s
.51308 .46998 m .51671 .45958 L .53322 .4722 L p 1 .011 .554 r
F P
0 g
s
.62921 .55023 m .60444 .5517 L .60135 .52981 L p .818 .043 .714 r
F P
0 g
s
.58172 .5322 m .60135 .52981 L .60444 .5517 L p .806 .042 .71 r
F P
0 g
s
.5651 .55146 m .55047 .54974 L .55266 .53377 L p .765 .042 .712 r
F P
0 g
s
.55266 .53377 m .56549 .53352 L .5651 .55146 L p .765 .042 .712 r
F P
0 g
s
.47676 .42191 m .47369 .43771 L .44725 .42847 L p .979 .028 .641 r
F P
0 g
s
.44725 .42847 m .44827 .41057 L .47676 .42191 L p .979 .028 .641 r
F P
0 g
s
.4518 .61921 m .43758 .60482 L .4621 .58938 L p .724 .079 .897 r
F P
0 g
s
.4621 .58938 m .47433 .60195 L .4518 .61921 L p .724 .079 .897 r
F P
0 g
s
.52113 .57814 m .50948 .57044 L .52205 .55624 L p .678 .074 .868 r
F P
0 g
s
.52205 .55624 m .53183 .56203 L .52113 .57814 L p .678 .074 .868 r
F P
0 g
s
.751 .4747 m .79189 .4656 L .80325 .4823 L p .903 .081 .904 r
F P
0 g
s
.65741 .5477 m .62921 .55023 L .62443 .52634 L p .826 .044 .719 r
F P
0 g
s
.60135 .52981 m .62443 .52634 L .62921 .55023 L p .818 .043 .714 r
F P
0 g
s
.55047 .54974 m .5392 .54696 L .54319 .53295 L p .725 .046 .732 r
F P
0 g
s
.54319 .53295 m .55266 .53377 L .55047 .54974 L p .725 .046 .732 r
F P
0 g
s
.61605 .49445 m .64089 .4878 L .65038 .49513 L p .91 .096 .979 r
F P
0 g
s
.68032 .48945 m .65038 .49513 L .64089 .4878 L p .905 .092 .96 r
F P
0 g
s
.54637 .48592 m .53898 .49221 L .5277 .48054 L p .975 .009 .543 r
F P
0 g
s
.5277 .48054 m .53322 .4722 L .54637 .48592 L p .975 .009 .543 r
F P
0 g
s
.53183 .56203 m .52205 .55624 L .53126 .54311 L p .659 .07 .849 r
F P
0 g
s
.53126 .54311 m .5392 .54696 L .53183 .56203 L p .659 .07 .849 r
F P
0 g
s
.34444 .65715 m .32689 .6362 L .36338 .61951 L p .762 .078 .888 r
F P
0 g
s
.36338 .61951 m .3787 .63873 L .34444 .65715 L p .762 .078 .888 r
F P
0 g
s
.76316 .53363 m .80566 .52674 L .81437 .56163 L p .838 .049 .745 r
F P
0 g
s
.6891 .54409 m .65741 .5477 L .65099 .52178 L p .833 .045 .724 r
F P
0 g
s
.62443 .52634 m .65099 .52178 L .65741 .5477 L p .826 .044 .719 r
F P
0 g
s
.56549 .53352 m .55266 .53377 L .55147 .51884 L p .803 .031 .656 r
F P
0 g
s
.55266 .53377 m .54319 .53295 L .54382 .52 L p .776 .029 .646 r
F P
0 g
s
.54382 .52 m .55147 .51884 L .55266 .53377 L p .776 .029 .646 r
F P
0 g
s
.47433 .60195 m .4621 .58938 L .4833 .57498 L p .705 .081 .907 r
F P
0 g
s
.4833 .57498 m .49357 .58568 L .47433 .60195 L p .705 .081 .907 r
F P
0 g
s
.38149 .36775 m .3815 .39134 L .34332 .38347 L p .953 .038 .689 r
F P
0 g
s
.34332 .38347 m .34101 .35773 L .38149 .36775 L p .953 .038 .689 r
F P
0 g
s
.58172 .5322 m .56549 .53352 L .56251 .5166 L p .819 .034 .67 r
F P
0 g
s
.55147 .51884 m .56251 .5166 L .56549 .53352 L p .803 .031 .656 r
F P
0 g
s
.5392 .54696 m .53126 .54311 L .53709 .53105 L p .654 .06 .799 r
F P
0 g
s
.53709 .53105 m .54319 .53295 L .5392 .54696 L p .654 .06 .799 r
F P
0 g
s
.50193 .43439 m .49685 .44808 L .47369 .43771 L p .979 .025 .624 r
F P
0 g
s
.47369 .43771 m .47676 .42191 L .50193 .43439 L p .979 .025 .624 r
F P
0 g
s
.55613 .50073 m .54691 .50498 L .53898 .49221 L p .924 .011 .556 r
F P
0 g
s
.53898 .49221 m .54637 .48592 L .55613 .50073 L p .924 .011 .556 r
F P
0 g
s
.60135 .52981 m .58172 .5322 L .57695 .51328 L p .828 .037 .683 r
F P
0 g
s
.56251 .5166 m .57695 .51328 L .58172 .5322 L p .819 .034 .67 r
F P
0 g
s
.53435 .52808 m .53709 .53105 L .53126 .54311 L p .598 .098 .991 r
F P
0 g
s
.49357 .58568 m .4833 .57498 L .50114 .56163 L p .679 .084 .92 r
F P
0 g
s
.50114 .56163 m .50948 .57044 L .49357 .58568 L p .679 .084 .92 r
F P
0 g
s
.64089 .4878 m .6693 .48002 L .68032 .48945 L p .905 .092 .96 r
F P
0 g
s
.71384 .48264 m .68032 .48945 L .6693 .48002 L p .899 .089 .943 r
F P
0 g
s
.72433 .5394 m .6891 .54409 L .6811 .51612 L p .837 .046 .729 r
F P
0 g
s
.65099 .52178 m .6811 .51612 L .6891 .54409 L p .833 .045 .724 r
F P
0 g
s
.52374 .448 m .51671 .45958 L .49685 .44808 L p .974 .022 .608 r
F P
0 g
s
.49685 .44808 m .50193 .43439 L .52374 .448 L p .974 .022 .608 r
F P
0 g
s
.62443 .52634 m .60135 .52981 L .59483 .50887 L p .835 .039 .694 r
F P
0 g
s
.57695 .51328 m .59483 .50887 L .60135 .52981 L p .828 .037 .683 r
F P
0 g
s
.52667 .53817 m .53126 .54311 L .52205 .55624 L p .597 .092 .96 r
F P
0 g
s
.53126 .54311 m .52667 .53817 L .53435 .52808 L p .598 .098 .991 r
F P
0 g
s
.50948 .57044 m .50114 .56163 L .5156 .54936 L p .645 .087 .937 r
F P
0 g
s
.5156 .54936 m .52205 .55624 L .50948 .57044 L p .645 .087 .937 r
F P
0 g
s
.3787 .63873 m .36338 .61951 L .39661 .60384 L p .751 .079 .896 r
F P
0 g
s
.39661 .60384 m .40976 .62128 L .3787 .63873 L p .751 .079 .896 r
F P
0 g
s
.52205 .55624 m .5156 .54936 L .52667 .53817 L p .597 .092 .96 r
F P
0 g
s
.41873 .37894 m .4165 .40038 L .3815 .39134 L p .956 .036 .678 r
F P
0 g
s
.3815 .39134 m .38149 .36775 L .41873 .37894 L p .956 .036 .678 r
F P
0 g
s
.56877 .49537 m .55613 .50073 L .54637 .48592 L p .898 .021 .607 r
F P
0 g
s
.53497 .52402 m .53435 .52808 L .52667 .53817 L p .666 .166 1 r
F P
0 g
s
.54216 .46271 m .53322 .4722 L .51671 .45958 L p .959 .019 .596 r
F P
0 g
s
.51671 .45958 m .52374 .448 L .54216 .46271 L p .959 .019 .596 r
F P
0 g
s
.61605 .49445 m .59473 .49998 L .58985 .4989 L p .863 .11 1 r
F P
0 g
s
.61619 .50335 m .59483 .50887 L .58985 .4989 L p .855 .035 .676 r
F P
0 g
s
.58985 .4989 m .58487 .4889 L p .60053 .49612 L .855 .035 .676 r
F P
0 g
s
.61605 .49445 m .59173 .49858 L .60053 .49612 L .863 .11 1 r
F
.59173 .49858 m .58985 .4989 L .60053 .49612 L F
.58487 .4889 m .60447 .48129 L .61034 .49234 L p .855 .035 .676 r
F P
0 g
s
.58487 .4889 m .61034 .49234 L .60883 .49292 L .855 .035 .676 r
F
.61034 .49234 m .61605 .49445 L p .60053 .49612 L .863 .11 1 r
F P
0 g
s
.58487 .4889 m .61082 .49326 L .60053 .49612 L .855 .035 .676 r
F
.58495 .49781 m .60459 .49021 L .61034 .49234 L p .863 .11 1 r
F P
0 g
s
.60053 .49612 m .58495 .49781 L .61034 .49234 L .863 .11 1 r
F
.61034 .49234 m .61082 .49326 L p .60883 .49292 L .855 .035 .676 r
F P
0 g
s
.61082 .49326 m .61619 .50335 L p .60053 .49612 L .855 .035 .676 r
F P
0 g
s
.60053 .49612 m .61619 .50335 L .58985 .4989 L .855 .035 .676 r
F
.58985 .4989 m .58495 .49781 L p .60053 .49612 L .863 .11 1 r
F P
0 g
s
.54637 .48592 m .55717 .47851 L .56877 .49537 L p .898 .021 .607 r
F P
0 g
s
.55717 .47851 m .54637 .48592 L .53322 .4722 L p .934 .019 .594 r
F P
0 g
s
.53322 .4722 m .54216 .46271 L .55717 .47851 L p .934 .019 .594 r
F P
0 g
s
.65099 .52178 m .62443 .52634 L .61619 .50335 L p .84 .041 .704 r
F P
0 g
s
.59483 .50887 m .61619 .50335 L .62443 .52634 L p .835 .039 .694 r
F P
0 g
s
.76316 .53363 m .72433 .5394 L .7148 .50934 L p .841 .047 .734 r
F P
0 g
s
.6811 .51612 m .7148 .50934 L .72433 .5394 L p .837 .046 .729 r
F P
0 g
s
.40976 .62128 m .39661 .60384 L .42654 .58921 L p .738 .081 .907 r
F P
0 g
s
.42654 .58921 m .43758 .60482 L .40976 .62128 L p .738 .081 .907 r
F P
0 g
s
.52544 .53214 m .52667 .53817 L .5156 .54936 L p .621 .121 1 r
F P
0 g
s
.52667 .53817 m .52544 .53214 L .53497 .52402 L p .666 .166 1 r
F P
0 g
s
.53898 .51887 m .53497 .52402 L .52544 .53214 L p .681 .181 1 r
F P
0 g
s
.6693 .48002 m .70136 .47108 L .71384 .48264 L p .899 .089 .943 r
F P
0 g
s
.751 .4747 m .71384 .48264 L .70136 .47108 L p .895 .086 .928 r
F P
0 g
s
.45267 .39129 m .44827 .41057 L .4165 .40038 L p .958 .033 .667 r
F P
0 g
s
.4165 .40038 m .41873 .37894 L .45267 .39129 L p .958 .033 .667 r
F P
0 g
s
.53898 .51887 m .54641 .51261 L .55616 .50962 L p .63 0 .5 r
F P
0 g
s
.56883 .50427 m .55616 .50962 L .54641 .51261 L p .678 .139 1 r
F P
0 g
s
.58487 .4889 m .56877 .49537 L .55717 .47851 L p .884 .028 .639 r
F P
0 g
s
.43758 .60482 m .42654 .58921 L .45311 .57563 L p .721 .084 .921 r
F P
0 g
s
.45311 .57563 m .4621 .58938 L .43758 .60482 L p .721 .084 .921 r
F P
0 g
s
.51249 .54136 m .5156 .54936 L .50114 .56163 L p .625 .103 1 r
F P
0 g
s
.5156 .54936 m .51249 .54136 L .52544 .53214 L p .621 .121 1 r
F P
0 g
s
.64089 .4878 m .61605 .49445 L .61034 .49234 L p .875 .102 1 r
F P
0 g
s
.64107 .49671 m .61619 .50335 L .61034 .49234 L p .856 .038 .69 r
F P
0 g
s
.61034 .49234 m .60447 .48129 L p .62278 .489 L .856 .038 .69 r
F P
0 g
s
.64089 .4878 m .61225 .49205 L .62278 .489 L .875 .102 1 r
F
.61225 .49205 m .61034 .49234 L .62278 .489 L F
.60447 .48129 m .62762 .47253 L .63436 .48465 L p .856 .038 .69 r
F P
0 g
s
.60447 .48129 m .63436 .48465 L .63281 .48523 L .856 .038 .69 r
F
.63436 .48465 m .64089 .4878 L p .62278 .489 L .875 .102 1 r
F P
0 g
s
.60447 .48129 m .63484 .48551 L .62278 .489 L .856 .038 .69 r
F
.60459 .49021 m .62778 .48146 L .63436 .48465 L p .875 .102 1 r
F P
0 g
s
.62278 .489 m .60459 .49021 L .63436 .48465 L .875 .102 1 r
F
.63436 .48465 m .63484 .48551 L p .63281 .48523 L .856 .038 .69 r
F P
0 g
s
.63484 .48551 m .64107 .49671 L p .62278 .489 L .856 .038 .69 r
F P
0 g
s
.62278 .489 m .64107 .49671 L .61034 .49234 L .856 .038 .69 r
F
.61034 .49234 m .60459 .49021 L p .62278 .489 L .875 .102 1 r
F P
0 g
s
.6811 .51612 m .65099 .52178 L .64107 .49671 L p .844 .042 .712 r
F P
0 g
s
.61619 .50335 m .64107 .49671 L .65099 .52178 L p .84 .041 .704 r
F P
0 g
s
.4621 .58938 m .45311 .57563 L .47631 .56311 L p .699 .088 .941 r
F P
0 g
s
.47631 .56311 m .4833 .57498 L .4621 .58938 L p .699 .088 .941 r
F P
0 g
s
.49611 .55169 m .50114 .56163 L .4833 .57498 L p .669 .094 .969 r
F P
0 g
s
.50114 .56163 m .49611 .55169 L .51249 .54136 L p .625 .103 1 r
F P
0 g
s
.48326 .4048 m .47676 .42191 L .44827 .41057 L p .958 .031 .654 r
F P
0 g
s
.44827 .41057 m .45267 .39129 L .48326 .4048 L p .958 .031 .654 r
F P
0 g
s
.4833 .57498 m .47631 .56311 L .49611 .55169 L p .669 .094 .969 r
F P
0 g
s
.80566 .52674 m .76316 .53363 L .75217 .50144 L p .844 .048 .738 r
F P
0 g
s
.7148 .50934 m .75217 .50144 L .76316 .53363 L p .841 .047 .734 r
F P
0 g
s
.55717 .47851 m .57145 .46995 L .58487 .4889 L p .884 .028 .639 r
F P
0 g
s
.57145 .46995 m .55717 .47851 L .54216 .46271 L p .911 .026 .629 r
F P
0 g
s
.29585 .31928 m .29734 .34889 L .25055 .34125 L p .937 .042 .709 r
F P
0 g
s
.25055 .34125 m .2465 .30944 L .29585 .31928 L p .937 .042 .709 r
F P
0 g
s
.52544 .53214 m .5276 .52499 L .53898 .51887 L p .681 .181 1 r
F P
0 g
s
.54641 .51261 m .53898 .51887 L .5276 .52499 L p .664 .164 1 r
F P
0 g
s
.5276 .52499 m .52544 .53214 L .51249 .54136 L p .64 .14 1 r
F P
0 g
s
.51045 .41943 m .50193 .43439 L .47676 .42191 L p .954 .029 .643 r
F P
0 g
s
.47676 .42191 m .48326 .4048 L .51045 .41943 L p .954 .029 .643 r
F P
0 g
s
.54641 .51261 m .55727 .50523 L .56883 .50427 L p .678 .139 1 r
F P
0 g
s
.58495 .49781 m .56883 .50427 L .55727 .50523 L p .774 .128 1 r
F P
0 g
s
.54216 .46271 m .55457 .45203 L .57145 .46995 L p .911 .026 .629 r
F P
0 g
s
.55457 .45203 m .54216 .46271 L .52374 .448 L p .932 .025 .627 r
F P
0 g
s
.53423 .43519 m .52374 .448 L .50193 .43439 L p .946 .027 .633 r
F P
0 g
s
.50193 .43439 m .51045 .41943 L .53423 .43519 L p .946 .027 .633 r
F P
0 g
s
.52374 .448 m .53423 .43519 L .55457 .45203 L p .932 .025 .627 r
F P
0 g
s
.28721 .65387 m .27031 .62977 L .31238 .61384 L p .772 .078 .89 r
F P
0 g
s
.31238 .61384 m .32689 .6362 L .28721 .65387 L p .772 .078 .89 r
F P
0 g
s
.60447 .48129 m .58487 .4889 L .57145 .46995 L p .877 .032 .662 r
F P
0 g
s
.7148 .50934 m .6811 .51612 L .66954 .48894 L p .847 .044 .72 r
F P
0 g
s
.64107 .49671 m .66954 .48894 L .6811 .51612 L p .844 .042 .712 r
F P
0 g
s
.70136 .47108 m .73714 .46097 L .751 .4747 L p .895 .086 .928 r
F P
0 g
s
.79189 .4656 m .751 .4747 L .73714 .46097 L p .891 .083 .916 r
F P
0 g
s
.6693 .48002 m .64089 .4878 L .63436 .48465 L p .879 .097 .983 r
F P
0 g
s
.66954 .48894 m .64107 .49671 L .63436 .48465 L p .856 .04 .702 r
F P
0 g
s
.63436 .48465 m .62762 .47253 L p .64859 .48074 L .856 .04 .702 r
F P
0 g
s
.6693 .48002 m .6363 .48439 L .64859 .48074 L .879 .097 .983 r
F
.6363 .48439 m .63436 .48465 L .64859 .48074 L F
.62762 .47253 m .6544 .4626 L .66199 .4758 L p .856 .04 .702 r
F P
0 g
s
.62762 .47253 m .66199 .4758 L .66041 .47638 L .856 .04 .702 r
F
.66199 .4758 m .6693 .48002 L p .64859 .48074 L .879 .097 .983 r
F P
0 g
s
.62762 .47253 m .66246 .47662 L .64859 .48074 L .856 .04 .702 r
F
.62778 .48146 m .65461 .47155 L .66199 .4758 L p .879 .097 .983 r
F P
0 g
s
.64859 .48074 m .62778 .48146 L .66199 .4758 L .879 .097 .983 r
F
.66199 .4758 m .66246 .47662 L p .66041 .47638 L .856 .04 .702 r
F P
0 g
s
.66246 .47662 m .66954 .48894 L p .64859 .48074 L .856 .04 .702 r
F P
0 g
s
.64859 .48074 m .66954 .48894 L .63436 .48465 L .856 .04 .702 r
F
.63436 .48465 m .62778 .48146 L p .64859 .48074 L .879 .097 .983 r
F P
0 g
s
.34199 .33033 m .34101 .35773 L .29734 .34889 L p .94 .04 .702 r
F P
0 g
s
.29734 .34889 m .29585 .31928 L .34199 .33033 L p .94 .04 .702 r
F P
0 g
s
.51275 .53223 m .51249 .54136 L .49611 .55169 L p .629 .115 1 r
F P
0 g
s
.51249 .54136 m .51275 .53223 L .5276 .52499 L p .64 .14 1 r
F P
0 g
s
.75217 .50144 m .79329 .49238 L .80566 .52674 L p .844 .048 .738 r
F P
0 g
s
.5276 .52499 m .53317 .51672 L .54641 .51261 L p .664 .164 1 r
F P
0 g
s
.55727 .50523 m .54641 .51261 L .53317 .51672 L p .665 .146 1 r
F P
0 g
s
.32689 .6362 m .31238 .61384 L .35118 .59894 L p .763 .08 .898 r
F P
0 g
s
.35118 .59894 m .36338 .61951 L .32689 .6362 L p .763 .08 .898 r
F P
0 g
s
.55727 .50523 m .57163 .49671 L .58495 .49781 L p .774 .128 1 r
F P
0 g
s
.60459 .49021 m .58495 .49781 L .57163 .49671 L p .82 .116 1 r
F P
0 g
s
.57145 .46995 m .58924 .46022 L .60447 .48129 L p .877 .032 .662 r
F P
0 g
s
.58924 .46022 m .57145 .46995 L .55457 .45203 L p .897 .031 .654 r
F P
0 g
s
.53317 .51672 m .5276 .52499 L .51275 .53223 L p .642 .142 1 r
F P
0 g
s
.49443 .54059 m .49611 .55169 L .47631 .56311 L p .672 .102 1 r
F P
0 g
s
.49611 .55169 m .49443 .54059 L .51275 .53223 L p .629 .115 1 r
F P
0 g
s
.75217 .50144 m .7148 .50934 L .70166 .48002 L p .849 .045 .726 r
F P
0 g
s
.66954 .48894 m .70166 .48002 L .7148 .50934 L p .847 .044 .72 r
F P
0 g
s
.36338 .61951 m .35118 .59894 L .38664 .5851 L p .752 .082 .909 r
F P
0 g
s
.38664 .5851 m .39661 .60384 L .36338 .61951 L p .752 .082 .909 r
F P
0 g
s
.38486 .34257 m .38149 .36775 L .34101 .35773 L p .942 .039 .694 r
F P
0 g
s
.34101 .35773 m .34199 .33033 L .38486 .34257 L p .942 .039 .694 r
F P
0 g
s
.62762 .47253 m .60447 .48129 L .58924 .46022 L p .872 .036 .679 r
F P
0 g
s
.47265 .55006 m .47631 .56311 L .45311 .57563 L p .702 .094 .969 r
F P
0 g
s
.47631 .56311 m .47265 .55006 L .49443 .54059 L p .672 .102 1 r
F P
0 g
s
.70136 .47108 m .6693 .48002 L .66199 .4758 L p .88 .092 .96 r
F P
0 g
s
.70166 .48002 m .66954 .48894 L .66199 .4758 L p .857 .042 .711 r
F P
0 g
s
.66199 .4758 m .6544 .4626 L p .67804 .47131 L .857 .042 .711 r
F P
0 g
s
.70136 .47108 m .66396 .47557 L .67804 .47131 L .88 .092 .96 r
F
.66396 .47557 m .66199 .4758 L .67804 .47131 L F
.6544 .4626 m .68487 .45147 L .69329 .46578 L p .857 .042 .711 r
F P
0 g
s
.6544 .4626 m .69329 .46578 L .69168 .46636 L .857 .042 .711 r
F
.69329 .46578 m .70136 .47108 L p .67804 .47131 L .88 .092 .96 r
F P
0 g
s
.6544 .4626 m .69375 .46657 L .67804 .47131 L .857 .042 .711 r
F
.65461 .47155 m .68514 .46043 L .69329 .46578 L p .88 .092 .96 r
F P
0 g
s
.67804 .47131 m .65461 .47155 L .69329 .46578 L .88 .092 .96 r
F
.69329 .46578 m .69375 .46657 L p .69168 .46636 L .857 .042 .711 r
F P
0 g
s
.69375 .46657 m .70166 .48002 L p .67804 .47131 L .857 .042 .711 r
F P
0 g
s
.67804 .47131 m .70166 .48002 L .66199 .4758 L .857 .042 .711 r
F
.66199 .4758 m .65461 .47155 L p .67804 .47131 L .88 .092 .96 r
F P
0 g
s
.39661 .60384 m .38664 .5851 L .41873 .57233 L p .739 .085 .923 r
F P
0 g
s
.41873 .57233 m .42654 .58921 L .39661 .60384 L p .739 .085 .923 r
F P
0 g
s
.55457 .45203 m .5705 .44015 L .58924 .46022 L p .897 .031 .654 r
F P
0 g
s
.5705 .44015 m .55457 .45203 L .53423 .43519 L p .914 .03 .651 r
F P
0 g
s
.73714 .46097 m .77673 .44965 L .79189 .4656 L p .891 .083 .916 r
F P
0 g
s
.44741 .56065 m .45311 .57563 L .42654 .58921 L p .723 .088 .942 r
F P
0 g
s
.45311 .57563 m .44741 .56065 L .47265 .55006 L p .702 .094 .969 r
F P
0 g
s
.42654 .58921 m .41873 .57233 L .44741 .56065 L p .723 .088 .942 r
F P
0 g
s
.42439 .35599 m .41873 .37894 L .38149 .36775 L p .943 .037 .685 r
F P
0 g
s
.38149 .36775 m .38486 .34257 L .42439 .35599 L p .943 .037 .685 r
F P
0 g
s
.53317 .51672 m .54219 .5073 L .55727 .50523 L p .665 .146 1 r
F P
0 g
s
.57163 .49671 m .55727 .50523 L .54219 .5073 L p .742 .13 1 r
F P
0 g
s
.51642 .52195 m .51275 .53223 L .49443 .54059 L p .656 .12 1 r
F P
0 g
s
.51275 .53223 m .51642 .52195 L .53317 .51672 L p .642 .142 1 r
F P
0 g
s
.53423 .43519 m .54825 .42112 L .5705 .44015 L p .914 .03 .651 r
F P
0 g
s
.54825 .42112 m .53423 .43519 L .51045 .41943 L p .927 .031 .653 r
F P
0 g
s
.57163 .49671 m .58952 .48702 L .60459 .49021 L p .82 .116 1 r
F P
0 g
s
.62778 .48146 m .60459 .49021 L .58952 .48702 L p .842 .107 1 r
F P
0 g
s
.46053 .37058 m .45267 .39129 L .41873 .37894 L p .943 .035 .676 r
F P
0 g
s
.41873 .37894 m .42439 .35599 L .46053 .37058 L p .943 .035 .676 r
F P
0 g
s
.54219 .5073 m .53317 .51672 L .51642 .52195 L p .676 .133 1 r
F P
0 g
s
.51045 .41943 m .52249 .40317 L .54825 .42112 L p .927 .031 .653 r
F P
0 g
s
.52249 .40317 m .51045 .41943 L .48326 .4048 L p .936 .032 .659 r
F P
0 g
s
.49324 .38631 m .48326 .4048 L .45267 .39129 L p .941 .033 .667 r
F P
0 g
s
.45267 .39129 m .46053 .37058 L .49324 .38631 L p .941 .033 .667 r
F P
0 g
s
.58924 .46022 m .61061 .44929 L .62762 .47253 L p .872 .036 .679 r
F P
0 g
s
.61061 .44929 m .58924 .46022 L .5705 .44015 L p .888 .034 .672 r
F P
0 g
s
.48326 .4048 m .49324 .38631 L .52249 .40317 L p .936 .032 .659 r
F P
0 g
s
.79329 .49238 m .75217 .50144 L .73751 .46991 L p .851 .046 .731 r
F P
0 g
s
.70166 .48002 m .73751 .46991 L .75217 .50144 L p .849 .045 .726 r
F P
0 g
s
.6544 .4626 m .62762 .47253 L .61061 .44929 L p .869 .039 .693 r
F P
0 g
s
.49615 .52831 m .49443 .54059 L .47265 .55006 L p .688 .106 1 r
F P
0 g
s
.49443 .54059 m .49615 .52831 L .51642 .52195 L p .656 .12 1 r
F P
0 g
s
.73714 .46097 m .70136 .47108 L .69329 .46578 L p .879 .088 .941 r
F P
0 g
s
.73751 .46991 m .70166 .48002 L .69329 .46578 L p .858 .044 .719 r
F P
0 g
s
.69329 .46578 m .68487 .45147 L p .71121 .4607 L .858 .044 .719 r
F P
0 g
s
.73714 .46097 m .69528 .46556 L .71121 .4607 L .879 .088 .941 r
F
.69528 .46556 m .69329 .46578 L .71121 .4607 L F
.68487 .45147 m .71912 .43911 L .72834 .45456 L p .858 .044 .719 r
F P
0 g
s
.68487 .45147 m .72834 .45456 L .72671 .45514 L .858 .044 .719 r
F
.72834 .45456 m .73714 .46097 L p .71121 .4607 L .879 .088 .941 r
F P
0 g
s
.68487 .45147 m .7288 .45533 L .71121 .4607 L .858 .044 .719 r
F
.68514 .46043 m .71945 .44808 L .72834 .45456 L p .879 .088 .941 r
F P
0 g
s
.71121 .4607 m .68514 .46043 L .72834 .45456 L .879 .088 .941 r
F
.72834 .45456 m .7288 .45533 L p .72671 .45514 L .858 .044 .719 r
F P
0 g
s
.7288 .45533 m .73751 .46991 L p .71121 .4607 L .858 .044 .719 r
F P
0 g
s
.71121 .4607 m .73751 .46991 L .69329 .46578 L .858 .044 .719 r
F
.69329 .46578 m .68514 .46043 L p .71121 .4607 L .879 .088 .941 r
F P
0 g
s
.54219 .5073 m .55471 .4967 L .57163 .49671 L p .742 .13 1 r
F P
0 g
s
.58952 .48702 m .57163 .49671 L .55471 .4967 L p .788 .117 1 r
F P
0 g
s
.5705 .44015 m .59003 .42702 L .61061 .44929 L p .888 .034 .672 r
F P
0 g
s
.59003 .42702 m .5705 .44015 L .54825 .42112 L p .902 .034 .669 r
F P
0 g
s
.58952 .48702 m .61101 .47615 L .62778 .48146 L p .842 .107 1 r
F P
0 g
s
.65461 .47155 m .62778 .48146 L .61101 .47615 L p .854 .1 .998 r
F P
0 g
s
.47236 .53579 m .47265 .55006 L .44741 .56065 L p .712 .098 .988 r
F P
0 g
s
.47265 .55006 m .47236 .53579 L .49615 .52831 L p .688 .106 1 r
F P
0 g
s
.52354 .51048 m .51642 .52195 L .49615 .52831 L p .694 .119 1 r
F P
0 g
s
.51642 .52195 m .52354 .51048 L .54219 .5073 L p .676 .133 1 r
F P
0 g
s
.55471 .4967 m .54219 .5073 L .52354 .51048 L p .731 .123 1 r
F P
0 g
s
.73751 .46991 m .77717 .45861 L .79329 .49238 L p .851 .046 .731 r
F P
0 g
s
.44504 .5444 m .44741 .56065 L .41873 .57233 L p .73 .092 .958 r
F P
0 g
s
.44741 .56065 m .44504 .5444 L .47236 .53579 L p .712 .098 .988 r
F P
0 g
s
.27031 .62977 m .25641 .60413 L .30096 .59 L p .774 .079 .897 r
F P
0 g
s
.30096 .59 m .31238 .61384 L .27031 .62977 L p .774 .079 .897 r
F P
0 g
s
.61061 .44929 m .63563 .43715 L .6544 .4626 L p .869 .039 .693 r
F P
0 g
s
.63563 .43715 m .61061 .44929 L .59003 .42702 L p .882 .037 .687 r
F P
0 g
s
.54825 .42112 m .56586 .40576 L .59003 .42702 L p .902 .034 .669 r
F P
0 g
s
.56586 .40576 m .54825 .42112 L .52249 .40317 L p .913 .034 .67 r
F P
0 g
s
.68487 .45147 m .6544 .4626 L .63563 .43715 L p .868 .041 .704 r
F P
0 g
s
.2977 .28783 m .29585 .31928 L .2465 .30944 L p .93 .042 .712 r
F P
0 g
s
.2465 .30944 m .24569 .27569 L .2977 .28783 L p .93 .042 .712 r
F P
0 g
s
.41422 .55414 m .41873 .57233 L .38664 .5851 L p .744 .087 .936 r
F P
0 g
s
.41873 .57233 m .41422 .55414 L .44504 .5444 L p .73 .092 .958 r
F P
0 g
s
.31238 .61384 m .30096 .59 L .34215 .57695 L p .766 .081 .907 r
F P
0 g
s
.34215 .57695 m .35118 .59894 L .31238 .61384 L p .766 .081 .907 r
F P
0 g
s
.77673 .44965 m .73714 .46097 L .72834 .45456 L p .879 .085 .927 r
F P
0 g
s
.77717 .45861 m .73751 .46991 L .72834 .45456 L p .858 .045 .725 r
F P
0 g
s
.72834 .45456 m .71912 .43911 L p .74817 .44887 L .858 .045 .725 r
F P
0 g
s
.77673 .44965 m .73036 .45435 L .74817 .44887 L .879 .085 .927 r
F
.73036 .45435 m .72834 .45456 L .74817 .44887 L F
.71912 .43911 m .75725 .42548 L .76724 .4421 L p .858 .045 .725 r
F P
0 g
s
.71912 .43911 m .76724 .4421 L .76558 .44269 L .858 .045 .725 r
F
.76724 .4421 m .77673 .44965 L p .74817 .44887 L .879 .085 .927 r
F P
0 g
s
.71912 .43911 m .76769 .44286 L .74817 .44887 L .858 .045 .725 r
F
.71945 .44808 m .75765 .43448 L .76724 .4421 L p .879 .085 .927 r
F P
0 g
s
.74817 .44887 m .71945 .44808 L .76724 .4421 L .879 .085 .927 r
F
.76724 .4421 m .76769 .44286 L p .76558 .44269 L .858 .045 .725 r
F P
0 g
s
.76769 .44286 m .77717 .45861 L p .74817 .44887 L .858 .045 .725 r
F P
0 g
s
.74817 .44887 m .77717 .45861 L .72834 .45456 L .858 .045 .725 r
F
.72834 .45456 m .71945 .44808 L p .74817 .44887 L .879 .085 .927 r
F P
0 g
s
.37991 .56499 m .38664 .5851 L .35118 .59894 L p .756 .084 .92 r
F P
0 g
s
.38664 .5851 m .37991 .56499 L .41422 .55414 L p .744 .087 .936 r
F P
0 g
s
.35118 .59894 m .34215 .57695 L .37991 .56499 L p .756 .084 .92 r
F P
0 g
s
.55471 .4967 m .57079 .48491 L .58952 .48702 L p .788 .117 1 r
F P
0 g
s
.61101 .47615 m .58952 .48702 L .57079 .48491 L p .815 .108 1 r
F P
0 g
s
.50131 .5148 m .49615 .52831 L .47236 .53579 L p .712 .107 1 r
F P
0 g
s
.49615 .52831 m .50131 .5148 L .52354 .51048 L p .694 .119 1 r
F P
0 g
s
.52249 .40317 m .53812 .38555 L .56586 .40576 L p .913 .034 .67 r
F P
0 g
s
.53812 .38555 m .52249 .40317 L .49324 .38631 L p .922 .035 .673 r
F P
0 g
s
.34638 .30119 m .34199 .33033 L .29585 .31928 L p .931 .041 .706 r
F P
0 g
s
.29585 .31928 m .2977 .28783 L .34638 .30119 L p .931 .041 .706 r
F P
0 g
s
.61101 .47615 m .63617 .46406 L .65461 .47155 L p .854 .1 .998 r
F P
0 g
s
.68514 .46043 m .65461 .47155 L .63617 .46406 L p .86 .094 .971 r
F P
0 g
s
.49324 .38631 m .50681 .36641 L .53812 .38555 L p .922 .035 .673 r
F P
0 g
s
.50681 .36641 m .49324 .38631 L .46053 .37058 L p .927 .036 .678 r
F P
0 g
s
.39169 .31574 m .38486 .34257 L .34199 .33033 L p .932 .04 .699 r
F P
0 g
s
.34199 .33033 m .34638 .30119 L .39169 .31574 L p .932 .04 .699 r
F P
0 g
s
.52354 .51048 m .53417 .49781 L .55471 .4967 L p .731 .123 1 r
F P
0 g
s
.57079 .48491 m .55471 .4967 L .53417 .49781 L p .77 .114 1 r
F P
0 g
s
.59003 .42702 m .61323 .41262 L .63563 .43715 L p .882 .037 .687 r
F P
0 g
s
.61323 .41262 m .59003 .42702 L .56586 .40576 L p .894 .037 .684 r
F P
0 g
s
.53417 .49781 m .52354 .51048 L .50131 .5148 L p .731 .114 1 r
F P
0 g
s
.46053 .37058 m .47194 .34838 L .50681 .36641 L p .927 .036 .678 r
F P
0 g
s
.47194 .34838 m .46053 .37058 L .42439 .35599 L p .931 .037 .685 r
F P
0 g
s
.43356 .33148 m .42439 .35599 L .38486 .34257 L p .932 .038 .692 r
F P
0 g
s
.38486 .34257 m .39169 .31574 L .43356 .33148 L p .932 .038 .692 r
F P
0 g
s
.42439 .35599 m .43356 .33148 L .47194 .34838 L p .931 .037 .685 r
F P
0 g
s
.47549 .52025 m .47236 .53579 L .44504 .5444 L p .727 .099 .996 r
F P
0 g
s
.47236 .53579 m .47549 .52025 L .50131 .5148 L p .712 .107 1 r
F P
0 g
s
.71912 .43911 m .68487 .45147 L .66439 .42375 L p .866 .043 .713 r
F P
0 g
s
.63563 .43715 m .66439 .42375 L .68487 .45147 L p .868 .041 .704 r
F P
0 g
s
.66439 .42375 m .63563 .43715 L .61323 .41262 L p .878 .04 .699 r
F P
0 g
s
.57079 .48491 m .5905 .47188 L .61101 .47615 L p .815 .108 1 r
F P
0 g
s
.63617 .46406 m .61101 .47615 L .5905 .47188 L p .832 .101 1 r
F P
0 g
s
.56586 .40576 m .58716 .38907 L .61323 .41262 L p .894 .037 .684 r
F P
0 g
s
.58716 .38907 m .56586 .40576 L .53812 .38555 L p .903 .037 .683 r
F P
0 g
s
.44607 .52685 m .44504 .5444 L .41422 .55414 L p .741 .093 .966 r
F P
0 g
s
.44504 .5444 m .44607 .52685 L .47549 .52025 L p .727 .099 .996 r
F P
0 g
s
.63617 .46406 m .66509 .45072 L .68514 .46043 L p .86 .094 .971 r
F P
0 g
s
.71945 .44808 m .68514 .46043 L .66509 .45072 L p .864 .09 .951 r
F P
0 g
s
.50997 .50004 m .50131 .5148 L .47549 .52025 L p .737 .106 1 r
F P
0 g
s
.50131 .5148 m .50997 .50004 L .53417 .49781 L p .731 .114 1 r
F P
0 g
s
.53417 .49781 m .54837 .48389 L .57079 .48491 L p .77 .114 1 r
F P
0 g
s
.5905 .47188 m .57079 .48491 L .54837 .48389 L p .797 .106 1 r
F P
0 g
s
.41306 .53458 m .41422 .55414 L .37991 .56499 L p .752 .089 .944 r
F P
0 g
s
.41422 .55414 m .41306 .53458 L .44607 .52685 L p .741 .093 .966 r
F P
0 g
s
.54837 .48389 m .53417 .49781 L .50997 .50004 L p .762 .108 1 r
F P
0 g
s
.53812 .38555 m .55743 .36653 L .58716 .38907 L p .903 .037 .683 r
F P
0 g
s
.55743 .36653 m .53812 .38555 L .50681 .36641 L p .911 .037 .685 r
F P
0 g
s
.61323 .41262 m .64018 .39691 L .66439 .42375 L p .878 .04 .699 r
F P
0 g
s
.64018 .39691 m .61323 .41262 L .58716 .38907 L p .888 .039 .695 r
F P
0 g
s
.75725 .42548 m .71912 .43911 L .69696 .40906 L p .865 .044 .72 r
F P
0 g
s
.66439 .42375 m .69696 .40906 L .71912 .43911 L p .866 .043 .713 r
F P
0 g
s
.37648 .54346 m .37991 .56499 L .34215 .57695 L p .762 .085 .927 r
F P
0 g
s
.37991 .56499 m .37648 .54346 L .41306 .53458 L p .752 .089 .944 r
F P
0 g
s
.69696 .40906 m .66439 .42375 L .64018 .39691 L p .875 .042 .708 r
F P
0 g
s
.33635 .55347 m .34215 .57695 L .30096 .59 L p .771 .083 .914 r
F P
0 g
s
.34215 .57695 m .33635 .55347 L .37648 .54346 L p .762 .085 .927 r
F P
0 g
s
.50681 .36641 m .52404 .34503 L .55743 .36653 L p .911 .037 .685 r
F P
0 g
s
.52404 .34503 m .50681 .36641 L .47194 .34838 L p .917 .038 .688 r
F P
0 g
s
.48211 .50342 m .47549 .52025 L .44607 .52685 L p .746 .099 .995 r
F P
0 g
s
.47549 .52025 m .48211 .50342 L .50997 .50004 L p .737 .106 1 r
F P
0 g
s
.5905 .47188 m .61392 .45758 L .63617 .46406 L p .832 .101 1 r
F P
0 g
s
.66509 .45072 m .63617 .46406 L .61392 .45758 L p .843 .095 .977 r
F P
0 g
s
.25641 .60413 m .2456 .57687 L .29271 .56461 L p .778 .081 .903 r
F P
0 g
s
.29271 .56461 m .30096 .59 L .25641 .60413 L p .778 .081 .903 r
F P
0 g
s
.30096 .59 m .29271 .56461 L .33635 .55347 L p .771 .083 .914 r
F P
0 g
s
.66509 .45072 m .69785 .43609 L .71945 .44808 L p .864 .09 .951 r
F P
0 g
s
.75765 .43448 m .71945 .44808 L .69785 .43609 L p .867 .087 .934 r
F P
0 g
s
.47194 .34838 m .487 .32462 L .52404 .34503 L p .917 .038 .688 r
F P
0 g
s
.487 .32462 m .47194 .34838 L .43356 .33148 L p .92 .039 .693 r
F P
0 g
s
.58716 .38907 m .61223 .37099 L .64018 .39691 L p .888 .039 .695 r
F P
0 g
s
.61223 .37099 m .58716 .38907 L .55743 .36653 L p .896 .039 .694 r
F P
0 g
s
.30299 .25444 m .2977 .28783 L .24569 .27569 L p .923 .043 .715 r
F P
0 g
s
.24569 .27569 m .24825 .2399 L .30299 .25444 L p .923 .043 .715 r
F P
0 g
s
.52221 .48399 m .50997 .50004 L .48211 .50342 L p .761 .103 1 r
F P
0 g
s
.50997 .50004 m .52221 .48399 L .54837 .48389 L p .762 .108 1 r
F P
0 g
s
.43356 .33148 m .44634 .30532 L .487 .32462 L p .92 .039 .693 r
F P
0 g
s
.44634 .30532 m .43356 .33148 L .39169 .31574 L p .923 .04 .698 r
F P
0 g
s
.54837 .48389 m .56622 .46869 L .5905 .47188 L p .797 .106 1 r
F P
0 g
s
.61392 .45758 m .5905 .47188 L .56622 .46869 L p .816 .1 1 r
F P
0 g
s
.45056 .50794 m .44607 .52685 L .41306 .53458 L p .754 .094 .968 r
F P
0 g
s
.44607 .52685 m .45056 .50794 L .48211 .50342 L p .746 .099 .995 r
F P
0 g
s
.35429 .27021 m .34638 .30119 L .2977 .28783 L p .924 .042 .71 r
F P
0 g
s
.2977 .28783 m .30299 .25444 L .35429 .27021 L p .924 .042 .71 r
F P
0 g
s
.39169 .31574 m .40209 .28718 L .44634 .30532 L p .923 .04 .698 r
F P
0 g
s
.40209 .28718 m .39169 .31574 L .34638 .30119 L p .924 .041 .704 r
F P
0 g
s
.56622 .46869 m .54837 .48389 L .52221 .48399 L p .786 .103 1 r
F P
0 g
s
.34638 .30119 m .35429 .27021 L .40209 .28718 L p .924 .041 .704 r
F P
0 g
s
.69696 .40906 m .73346 .39305 L .75725 .42548 L p .865 .044 .72 r
F P
0 g
s
.64018 .39691 m .67099 .37984 L .69696 .40906 L p .875 .042 .708 r
F P
0 g
s
.67099 .37984 m .64018 .39691 L .61223 .37099 L p .883 .041 .705 r
F P
0 g
s
.73346 .39305 m .69696 .40906 L .67099 .37984 L p .873 .043 .716 r
F P
0 g
s
.55743 .36653 m .58052 .34605 L .61223 .37099 L p .896 .039 .694 r
F P
0 g
s
.58052 .34605 m .55743 .36653 L .52404 .34503 L p .903 .039 .695 r
F P
0 g
s
.61392 .45758 m .64113 .44198 L .66509 .45072 L p .843 .095 .977 r
F P
0 g
s
.69785 .43609 m .66509 .45072 L .64113 .44198 L p .85 .091 .956 r
F P
0 g
s
.41534 .51361 m .41306 .53458 L .37648 .54346 L p .762 .089 .947 r
F P
0 g
s
.41306 .53458 m .41534 .51361 L .45056 .50794 L p .754 .094 .968 r
F P
0 g
s
.69785 .43609 m .73456 .42015 L .75765 .43448 L p .867 .087 .934 r
F P
0 g
s
.49229 .48523 m .48211 .50342 L .45056 .50794 L p .764 .098 .988 r
F P
0 g
s
.48211 .50342 m .49229 .48523 L .52221 .48399 L p .761 .103 1 r
F P
0 g
s
.37644 .52045 m .37648 .54346 L .33635 .55347 L p .77 .086 .931 r
F P
0 g
s
.37648 .54346 m .37644 .52045 L .41534 .51361 L p .762 .089 .947 r
F P
0 g
s
.52404 .34503 m .54505 .32211 L .58052 .34605 L p .903 .039 .695 r
F P
0 g
s
.54505 .32211 m .52404 .34503 L .487 .32462 L p .908 .04 .698 r
F P
0 g
s
.56622 .46869 m .58779 .45216 L .61392 .45758 L p .816 .1 1 r
F P
0 g
s
.64113 .44198 m .61392 .45758 L .58779 .45216 L p .829 .095 .976 r
F P
0 g
s
.61223 .37099 m .64118 .35149 L .67099 .37984 L p .883 .041 .705 r
F P
0 g
s
.64118 .35149 m .61223 .37099 L .58052 .34605 L p .89 .041 .704 r
F P
0 g
s
.5381 .4666 m .52221 .48399 L .49229 .48523 L p .781 .099 .996 r
F P
0 g
s
.52221 .48399 m .5381 .4666 L .56622 .46869 L p .786 .103 1 r
F P
0 g
s
.58779 .45216 m .56622 .46869 L .5381 .4666 L p .805 .098 .992 r
F P
0 g
s
.33389 .52844 m .33635 .55347 L .29271 .56461 L p .776 .084 .918 r
F P
0 g
s
.33635 .55347 m .33389 .52844 L .37644 .52045 L p .77 .086 .931 r
F P
0 g
s
.487 .32462 m .50583 .29923 L .54505 .32211 L p .908 .04 .698 r
F P
0 g
s
.50583 .29923 m .487 .32462 L .44634 .30532 L p .912 .04 .701 r
F P
0 g
s
.28771 .5376 m .29271 .56461 L .2456 .57687 L p .783 .081 .907 r
F P
0 g
s
.29271 .56461 m .28771 .5376 L .33389 .52844 L p .776 .084 .918 r
F P
0 g
s
.4586 .48761 m .45056 .50794 L .41534 .51361 L p .768 .093 .966 r
F P
0 g
s
.45056 .50794 m .4586 .48761 L .49229 .48523 L p .764 .098 .988 r
F P
0 g
s
.67099 .37984 m .70577 .36137 L .73346 .39305 L p .873 .043 .716 r
F P
0 g
s
.70577 .36137 m .67099 .37984 L .64118 .35149 L p .88 .043 .713 r
F P
0 g
s
.64113 .44198 m .67224 .42503 L .69785 .43609 L p .85 .091 .956 r
F P
0 g
s
.73456 .42015 m .69785 .43609 L .67224 .42503 L p .855 .088 .939 r
F P
0 g
s
.2456 .57687 m .23795 .5479 L .28771 .5376 L p .783 .081 .907 r
F P
0 g
s
.44634 .30532 m .46286 .27745 L .50583 .29923 L p .912 .04 .701 r
F P
0 g
s
.46286 .27745 m .44634 .30532 L .40209 .28718 L p .915 .041 .705 r
F P
0 g
s
.58052 .34605 m .60751 .32406 L .64118 .35149 L p .89 .041 .704 r
F P
0 g
s
.60751 .32406 m .58052 .34605 L .54505 .32211 L p .896 .041 .704 r
F P
0 g
s
.40209 .28718 m .41619 .25679 L .46286 .27745 L p .915 .041 .705 r
F P
0 g
s
.41619 .25679 m .40209 .28718 L .35429 .27021 L p .916 .042 .709 r
F P
0 g
s
.50613 .46564 m .49229 .48523 L .4586 .48761 L p .78 .095 .977 r
F P
0 g
s
.49229 .48523 m .50613 .46564 L .5381 .4666 L p .781 .099 .996 r
F P
0 g
s
.42112 .49116 m .41534 .51361 L .37644 .52045 L p .773 .089 .947 r
F P
0 g
s
.41534 .51361 m .42112 .49116 L .4586 .48761 L p .768 .093 .966 r
F P
0 g
s
.58779 .45216 m .6132 .43427 L .64113 .44198 L p .829 .095 .976 r
F P
0 g
s
.67224 .42503 m .64113 .44198 L .6132 .43427 L p .838 .091 .957 r
F P
0 g
s
.35429 .27021 m .36584 .2373 L .41619 .25679 L p .916 .042 .709 r
F P
0 g
s
.36584 .2373 m .35429 .27021 L .30299 .25444 L p .917 .043 .714 r
F P
0 g
s
.30299 .25444 m .31185 .219 L .36584 .2373 L p .917 .043 .714 r
F P
0 g
s
.31185 .219 m .30299 .25444 L .24825 .2399 L p .917 .044 .718 r
F P
0 g
s
.24825 .2399 m .25429 .20192 L .31185 .219 L p .917 .044 .718 r
F P
0 g
s
.55774 .44782 m .5381 .4666 L .50613 .46564 L p .798 .096 .979 r
F P
0 g
s
.5381 .4666 m .55774 .44782 L .58779 .45216 L p .805 .098 .992 r
F P
0 g
s
.6132 .43427 m .58779 .45216 L .55774 .44782 L p .818 .094 .971 r
F P
0 g
s
.64118 .35149 m .67413 .3305 L .70577 .36137 L p .88 .043 .713 r
F P
0 g
s
.67413 .3305 m .64118 .35149 L .60751 .32406 L p .886 .042 .712 r
F P
0 g
s
.54505 .32211 m .56996 .2976 L .60751 .32406 L p .896 .041 .704 r
F P
0 g
s
.56996 .2976 m .54505 .32211 L .50583 .29923 L p .901 .041 .706 r
F P
0 g
s
.37986 .49588 m .37644 .52045 L .33389 .52844 L p .778 .086 .932 r
F P
0 g
s
.37644 .52045 m .37986 .49588 L .42112 .49116 L p .773 .089 .947 r
F P
0 g
s
.67224 .42503 m .70736 .40669 L .73456 .42015 L p .855 .088 .939 r
F P
0 g
s
.47028 .46582 m .4586 .48761 L .42112 .49116 L p .781 .092 .96 r
F P
0 g
s
.4586 .48761 m .47028 .46582 L .50613 .46564 L p .78 .095 .977 r
F P
0 g
s
.33484 .50178 m .33389 .52844 L .28771 .5376 L p .783 .084 .92 r
F P
0 g
s
.33389 .52844 m .33484 .50178 L .37986 .49588 L p .778 .086 .932 r
F P
0 g
s
.50583 .29923 m .52854 .27215 L .56996 .2976 L p .901 .041 .706 r
F P
0 g
s
.52854 .27215 m .50583 .29923 L .46286 .27745 L p .905 .042 .708 r
F P
0 g
s
.6132 .43427 m .64255 .41495 L .67224 .42503 L p .838 .091 .957 r
F P
0 g
s
.70736 .40669 m .67224 .42503 L .64255 .41495 L p .845 .088 .941 r
F P
0 g
s
.60751 .32406 m .63852 .30049 L .67413 .3305 L p .886 .042 .712 r
F P
0 g
s
.63852 .30049 m .60751 .32406 L .56996 .2976 L p .891 .042 .712 r
F P
0 g
s
.28606 .50887 m .28771 .5376 L .23795 .5479 L p .788 .082 .909 r
F P
0 g
s
.28771 .5376 m .28606 .50887 L .33484 .50178 L p .783 .084 .92 r
F P
0 g
s
.52372 .44459 m .50613 .46564 L .47028 .46582 L p .794 .093 .965 r
F P
0 g
s
.50613 .46564 m .52372 .44459 L .55774 .44782 L p .798 .096 .979 r
F P
0 g
s
.46286 .27745 m .48325 .24776 L .52854 .27215 L p .905 .042 .708 r
F P
0 g
s
.48325 .24776 m .46286 .27745 L .41619 .25679 L p .908 .042 .711 r
F P
0 g
s
.55774 .44782 m .58123 .4276 L .6132 .43427 L p .818 .094 .971 r
F P
0 g
s
.64255 .41495 m .6132 .43427 L .58123 .4276 L p .828 .091 .954 r
F P
0 g
s
.43052 .46717 m .42112 .49116 L .37986 .49588 L p .784 .089 .944 r
F P
0 g
s
.42112 .49116 m .43052 .46717 L .47028 .46582 L p .781 .092 .96 r
F P
0 g
s
.58123 .4276 m .55774 .44782 L .52372 .44459 L p .811 .093 .963 r
F P
0 g
s
.23795 .5479 m .23357 .51713 L .28606 .50887 L p .788 .082 .909 r
F P
0 g
s
.41619 .25679 m .43412 .22448 L .48325 .24776 L p .908 .042 .711 r
F P
0 g
s
.43412 .22448 m .41619 .25679 L .36584 .2373 L p .91 .043 .714 r
F P
0 g
s
.56996 .2976 m .5989 .2714 L .63852 .30049 L p .891 .042 .712 r
F P
0 g
s
.5989 .2714 m .56996 .2976 L .52854 .27215 L p .896 .043 .713 r
F P
0 g
s
.36584 .2373 m .38117 .20234 L .43412 .22448 L p .91 .043 .714 r
F P
0 g
s
.38117 .20234 m .36584 .2373 L .31185 .219 L p .911 .044 .718 r
F P
0 g
s
.38687 .46969 m .37986 .49588 L .33484 .50178 L p .787 .086 .931 r
F P
0 g
s
.37986 .49588 m .38687 .46969 L .43052 .46717 L p .784 .089 .944 r
F P
0 g
s
.4857 .44249 m .47028 .46582 L .43052 .46717 L p .793 .09 .952 r
F P
0 g
s
.47028 .46582 m .4857 .44249 L .52372 .44459 L p .794 .093 .965 r
F P
0 g
s
.64255 .41495 m .67595 .39416 L .70736 .40669 L p .845 .088 .941 r
F P
0 g
s
.31185 .219 m .32444 .18138 L .38117 .20234 L p .911 .044 .718 r
F P
0 g
s
.32444 .18138 m .31185 .219 L .25429 .20192 L p .912 .044 .722 r
F P
0 g
s
.25429 .20192 m .26398 .16164 L .32444 .18138 L p .912 .044 .722 r
F P
0 g
s
.52854 .27215 m .55528 .24328 L .5989 .2714 L p .896 .043 .713 r
F P
0 g
s
.55528 .24328 m .52854 .27215 L .48325 .24776 L p .9 .043 .714 r
F P
0 g
s
.54518 .42202 m .52372 .44459 L .4857 .44249 L p .806 .091 .953 r
F P
0 g
s
.52372 .44459 m .54518 .42202 L .58123 .4276 L p .811 .093 .963 r
F P
0 g
s
.33931 .47341 m .33484 .50178 L .28606 .50887 L p .79 .084 .92 r
F P
0 g
s
.33484 .50178 m .33931 .47341 L .38687 .46969 L p .787 .086 .931 r
F P
0 g
s
.58123 .4276 m .60869 .40588 L .64255 .41495 L p .828 .091 .954 r
F P
0 g
s
.67595 .39416 m .64255 .41495 L .60869 .40588 L p .836 .088 .94 r
F P
0 g
s
.60869 .40588 m .58123 .4276 L .54518 .42202 L p .821 .09 .949 r
F P
0 g
s
.44365 .44155 m .43052 .46717 L .38687 .46969 L p .794 .088 .939 r
F P
0 g
s
.43052 .46717 m .44365 .44155 L .4857 .44249 L p .793 .09 .952 r
F P
0 g
s
.28787 .47833 m .28606 .50887 L .23357 .51713 L p .794 .082 .91 r
F P
0 g
s
.28606 .50887 m .28787 .47833 L .33931 .47341 L p .79 .084 .92 r
F P
0 g
s
.48325 .24776 m .50766 .21617 L .55528 .24328 L p .9 .043 .714 r
F P
0 g
s
.50766 .21617 m .48325 .24776 L .43412 .22448 L p .903 .043 .716 r
F P
0 g
s
.23357 .51713 m .23257 .48446 L .28787 .47833 L p .794 .082 .91 r
F P
0 g
s
.50499 .41755 m .4857 .44249 L .44365 .44155 L p .804 .089 .943 r
F P
0 g
s
.4857 .44249 m .50499 .41755 L .54518 .42202 L p .806 .091 .953 r
F P
0 g
s
.43412 .22448 m .45603 .19014 L .50766 .21617 L p .903 .043 .716 r
F P
0 g
s
.45603 .19014 m .43412 .22448 L .38117 .20234 L p .905 .044 .719 r
F P
0 g
s
.39756 .44179 m .38687 .46969 L .33931 .47341 L p .795 .086 .928 r
F P
0 g
s
.38687 .46969 m .39756 .44179 L .44365 .44155 L p .794 .088 .939 r
F P
0 g
s
.60869 .40588 m .64026 .38259 L .67595 .39416 L p .836 .088 .94 r
F P
0 g
s
.57062 .39786 m .54518 .42202 L .50499 .41755 L p .816 .088 .942 r
F P
0 g
s
.54518 .42202 m .57062 .39786 L .60869 .40588 L p .821 .09 .949 r
F P
0 g
s
.38117 .20234 m .40044 .16522 L .45603 .19014 L p .905 .044 .719 r
F P
0 g
s
.40044 .16522 m .38117 .20234 L .32444 .18138 L p .906 .044 .722 r
F P
0 g
s
.64026 .38259 m .60869 .40588 L .57062 .39786 L p .829 .087 .936 r
F P
0 g
s
.34743 .44323 m .33931 .47341 L .28787 .47833 L p .797 .084 .918 r
F P
0 g
s
.33931 .47341 m .34743 .44323 L .39756 .44179 L p .795 .086 .928 r
F P
0 g
s
.32444 .18138 m .3409 .14146 L .40044 .16522 L p .906 .044 .722 r
F P
0 g
s
.3409 .14146 m .32444 .18138 L .26398 .16164 L p .907 .045 .725 r
F P
0 g
s
.46063 .41423 m .44365 .44155 L .39756 .44179 L p .803 .087 .933 r
F P
0 g
s
.44365 .44155 m .46063 .41423 L .50499 .41755 L p .804 .089 .943 r
F P
0 g
s
.26398 .16164 m .27747 .1189 L .3409 .14146 L p .907 .045 .725 r
F P
0 g
s
.29326 .44588 m .28787 .47833 L .23257 .48446 L p .8 .082 .909 r
F P
0 g
s
.28787 .47833 m .29326 .44588 L .34743 .44323 L p .797 .084 .918 r
F P
0 g
s
.52827 .39093 m .50499 .41755 L .46063 .41423 L p .813 .087 .935 r
F P
0 g
s
.50499 .41755 m .52827 .39093 L .57062 .39786 L p .816 .088 .942 r
F P
0 g
s
.60019 .37204 m .57062 .39786 L .52827 .39093 L p .824 .086 .932 r
F P
0 g
s
.57062 .39786 m .60019 .37204 L .64026 .38259 L p .829 .087 .936 r
F P
0 g
s
.41208 .41208 m .39756 .44179 L .34743 .44323 L p .803 .085 .924 r
F P
0 g
s
.39756 .44179 m .41208 .41208 L .46063 .41423 L p .803 .087 .933 r
F P
0 g
s
.23257 .48446 m .23507 .44976 L .29326 .44588 L p .8 .082 .909 r
F P
0 g
s
.4816 .38512 m .46063 .41423 L .41208 .41208 L p .811 .085 .927 r
F P
0 g
s
.46063 .41423 m .4816 .38512 L .52827 .39093 L p .813 .087 .935 r
F P
0 g
s
.35933 .41113 m .34743 .44323 L .29326 .44588 L p .804 .083 .915 r
F P
0 g
s
.34743 .44323 m .35933 .41113 L .41208 .41208 L p .803 .085 .924 r
F P
0 g
s
.5557 .36253 m .52827 .39093 L .4816 .38512 L p .821 .085 .926 r
F P
0 g
s
.52827 .39093 m .5557 .36253 L .60019 .37204 L p .824 .086 .932 r
F P
0 g
s
.30237 .4114 m .29326 .44588 L .23507 .44976 L p .806 .082 .908 r
F P
0 g
s
.29326 .44588 m .30237 .4114 L .35933 .41113 L p .804 .083 .915 r
F P
0 g
s
.43057 .38047 m .41208 .41208 L .35933 .41113 L p .811 .084 .919 r
F P
0 g
s
.41208 .41208 m .43057 .38047 L .4816 .38512 L p .811 .085 .927 r
F P
0 g
s
.23507 .44976 m .24121 .41291 L .30237 .4114 L p .806 .082 .908 r
F P
0 g
s
.50671 .35412 m .4816 .38512 L .43057 .38047 L p .819 .084 .92 r
F P
0 g
s
.4816 .38512 m .50671 .35412 L .5557 .36253 L p .821 .085 .926 r
F P
0 g
s
.37516 .37701 m .35933 .41113 L .30237 .4114 L p .811 .082 .912 r
F P
0 g
s
.35933 .41113 m .37516 .37701 L .43057 .38047 L p .811 .084 .919 r
F P
0 g
s
.31536 .37477 m .30237 .4114 L .24121 .41291 L p .812 .081 .905 r
F P
0 g
s
.30237 .4114 m .31536 .37477 L .37516 .37701 L p .811 .082 .912 r
F P
0 g
s
.45319 .34685 m .43057 .38047 L .37516 .37701 L p .817 .083 .914 r
F P
0 g
s
.43057 .38047 m .45319 .34685 L .50671 .35412 L p .819 .084 .92 r
F P
0 g
s
.24121 .41291 m .25116 .37377 L .31536 .37477 L p .812 .081 .905 r
F P
0 g
s
.3951 .34074 m .37516 .37701 L .31536 .37477 L p .817 .082 .908 r
F P
0 g
s
.37516 .37701 m .3951 .34074 L .45319 .34685 L p .817 .083 .914 r
F P
0 g
s
.3324 .33584 m .31536 .37477 L .25116 .37377 L p .817 .08 .902 r
F P
0 g
s
.31536 .37477 m .3324 .33584 L .3951 .34074 L p .817 .082 .908 r
F P
0 g
s
.25116 .37377 m .26509 .33218 L .3324 .33584 L p .817 .08 .902 r
F P
0 g
s
.25 Mabswid
.51669 0 m
.98167 .60103 L
s
.98167 .60103 m
1 .80772 L
s
1 .80772 m
.51554 .22691 L
s
.51554 .22691 m
.51669 0 L
s
.0249 .18876 m
0 .41054 L
s
0 .41054 m
.51554 .22691 L
s
.51554 .22691 m
.51669 0 L
s
.51669 0 m
.0249 .18876 L
s
.0249 .18876 m
.51669 0 L
s
.03551 .18468 m
.04023 .18949 L
s
gsave
.02605 .17508 -71.2928 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.1477 .14162 m
.1523 .14655 L
s
gsave
.13851 .13177 -71.2074 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.2632 .09729 m
.26766 .10235 L
s
gsave
.25429 .08718 -67.6436 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.38216 .05164 m
.38646 .05682 L
s
gsave
.37355 .04127 -67.5193 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.50473 .00459 m
.50887 .00991 L
s
gsave
.49645 -0.00604 -67.1694 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.06325 .17404 m
.06607 .17694 L
s
.0912 .16331 m
.094 .16623 L
s
.11935 .15251 m
.12213 .15544 L
s
.17626 .13066 m
.179 .13364 L
s
.20503 .11962 m
.20774 .12262 L
s
.23401 .1085 m
.2367 .11151 L
s
.29261 .08601 m
.29526 .08906 L
s
.32224 .07463 m
.32487 .07771 L
s
.35209 .06318 m
.35469 .06627 L
s
.41246 .04001 m
.41501 .04314 L
s
.44298 .02829 m
.44552 .03144 L
s
.47374 .01649 m
.47625 .01966 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  FormatType->StandardForm,
  ImageSize->{180, 166.875},
  ImageMargins->{{102, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002d0000YQ000`40O003h00O]7oo002dOol00;Ao
o`00FWoo00<007ooOol0Egoo001IOol3001HOol005]oo`03001oogoo05Ioo`00]7oo002dOol005mo
o`8005=oo`00G7oo0`0000=oo`00Ool0DWoo001JOol20003Ool3001BOol004Aoo`80015oo`@000Eo
o`04001oo`00001@Ool004Eoo`03001oogoo00aoo`<000Uoo`04001oogoo001@Ool004Ioo`03001o
ogoo00Uoo`<000]oo`04001oogoo001@Ool004Eoo`8000Qoo`<000ioo`05001oogooOol0001?Ool0
04eoo`<0011oo`03001oogoo009oo`03001oogoo04aoo`00BWoo0`004goo00<007ooOol00goo00<0
07ooOol0Bgoo0017Ool4000EOol00`00Oomoo`04Ool00`00Oomoo`1:Ool004Eoo`8000=oo`03001o
ogoo01=oo`03001oogoo00Aoo`8004]oo`00;goo0P004Goo10006Woo00<007ooOol01Goo00<007oo
Ool0BGoo000_Ool00`00Ool0000>Ool2000NOol00`00Oomoo`06Ool00`00Oomoo`18Ool002moo`03
001oo`0000]oo`@001moo`03001oogoo00Moo`03001oogoo04Moo`00<7oo0P0027oo0`008goo00<0
07ooOol01goo00<007ooOol0Agoo000hOol4000TOol00`00Oomoo`08Ool00`00Oomoo`16Ool003Eo
o`<002Qoo`03001oogoo00Uoo`03001oogoo04Eoo`00<goo0P0000=oo`00Ool0:7oo00<007ooOol0
2Woo0P00AGoo000HOol300000goo0000000BOol3000]Ool00`00Oomoo`0:Ool20015Ool001eoo`03
001oogoo00eoo`<00003Ool007oo02eoo`03001oogoo00]oo`03001oogoo04=oo`007Woo00<007oo
Ool02Woo0P002goo0P009Woo00<007ooOol037oo00<007ooOol0@Woo000MOol20009Ool300000goo
001oo`0:Ool00`00M3L00002000SOol00`00Oomoo`0=Ool00`00Oomoo`11Ool002Ioo`80011oo`03
001d=g@g009d=`<0021oo`03001oogoo00ioo`03001oogoo00=oo`<00004Ool00000000fOol002=o
o`<00003Ool007oo00ioo`03001d=g@g00Id=`<001eoo`03001oogoo00ioo`03001oogoo00Uoo`03
001oogoo03Aoo`0087oo0`0057oo00<007@gM3L02G@g0P006goo00<007ooOol03goo0P0027oo00<0
07ooOol0=Goo000NOol20003Ool00`00Oomoo`0AOol00`00M3Md=`09M3L00`00L3L00002000HOol0
0`00Oomoo`0?Ool20009Ool00`00Oomoo`0dOol000Eoo`<00003Ool007oo011oo`@001Moo`03001d
=g@g00Ud=`03001`=g0g00=`=`8001Ioo`03001oogoo015oo`03001oogoo03eoo`0027oo0`003Woo
0P006goo00<007@gM3L02G@g00<0070gL3L01G0g0`004goo00<007ooOol04Woo00<007ooOol0?7oo
000:Ool00`00Oomoo`09Ool4000LOol00`00M3L000020006M3L00`00L3M`=`09L3L2000AOol00`00
Oomoo`0BOol00`00Oomoo`0lOol001=oo`<0021oo`03001d=g@g009d=`8000Ad=`03001`=g0g00U`
=`04001`=`00000?Ool00`00Oomoo`0COol00`00Oomoo`0kOol0015oo`800003Ool007oo01moo`03
001d=g@g00Ed=`<00003M3L0070g00U`=`03001`=g0g009`=`<000aoo`03001oogoo01Aoo`03001o
ogoo03Yoo`003Woo0`0097oo00<007@gM3L027@g00<0070g0000270g00<0070gL3L01W0g0P002Woo
00<007ooOol05Goo0P00>Woo000=Ool200000goo001oo`0SOol00`00M3Md=`08M3L00`00M3Id=P03
0005L3L00`00L3M`=`08L3L20008Ool00`00Oomoo`0EOol00`00Oomoo`0iOol000eoo`03001oogoo
02Aoo`03001d=g@g00Qd=`03001d=W@f00Ad=P<00003L3L0070g00Y`=`04001`=P000006Ool00`00
Oomoo`0FOol00`00Oomoo`0hOol0009oo`<00003Ool0000000Eoo`8002Eoo`03001d=`0000Qd=`03
001d=W@f00Md=P03001`=g0g00U`=`03001`=W0f009`=P8000Aoo`03001oogoo01Moo`03001oogoo
03Moo`001goo00<007ooOol00goo00<007oo000097oo00<007@fM3H00`001G@g00<007@fM3H01g@f
00@007@f000000M`=`03001`=W0f00E`=P05001oogooOol0000JOol00`00Oomoo`0fOol000Qoo`03
001oogoo009oo`04001oogoo000SOol00`00M3Id=P03M3H300000g@g001d=P08M3H00`00M3Id=P02
M3H30004L3L00`00L3I`=P06L3H200000goo001oo`0IOol00`00Oomoo`0fOol000Moo`8000Aoo`05
001oogooOol0000ROol00`00M3Id=P06M3H200000g@f001d=P06M3H00`00M3Id=P05M3H200000g0g
001`=P0:L3H2000KOol00`00Oomoo`0eOol000aoo`8000Aoo`03001oogoo01ioo`03001d=W@f00Qd
=P03001d=W@f00<000Ad=P03001d=W@f00Md=P03001`=W0f00Y`=P@001Yoo`8003Eoo`0037oo0P00
1Goo00<007ooOol07Goo00<007@fM3H01g@f00<007@fM3H017@f10002W@f00@007@f000000I`=P<0
0004L3H0070fL3H2000IOol00`00Oomoo`0cOol000aoo`03001oogoo00Eoo`03001oogoo01aoo`03
001d=W@f00Md=P03001d=W@f00Md=P03001d=W@f00Md=P03001d=W@f009d=PH00003L3H0070f009`
=P04001`=W0fL3H2000HOol00`00Oomoo`0bOol000aoo`8000Moo`03001oogoo01]oo`<000Md=P03
001d=W@f00Md=P03001d=P00008000Ad=P03001d=W@f00=d=PD00003L3H0070f00A`=P03001`=W0f
009`=P8001Ioo`03001oogoo039oo`0037oo00<007ooOol01goo00<007ooOol06Woo00<007@fM3H0
1@0000=d=P00M3H027@f00<007@fM3H00g@f0`0000=d=P00M3H00W@f0P001G@f00<0070fL3H01G0f
00@0070fL3H0009`=P03001oogoo01Aoo`03001oogoo035oo`000Woo0`0000=oo`00Ool017oo00<0
07ooOol027oo00<007ooOol06Goo00<007@fM3H01G@f0P0000=d=P00M3H01W@f00<007@fM3H01W@f
00<007@f00000P001g@f00@0070f000000E`=P8000A`=P8001Eoo`03001oogoo031oo`001Woo00<0
07ooOol00goo00<007ooOol02Goo00<007ooOol067oo00<007@fM3H01W@f00<007@fM3H00`0017@f
00<007@fM3H01G@f1@001g@f00<0070fL3H00W0f00<0070fL3H00W0f0P001W0f00<007ooOol04goo
0P00<7oo0006Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0FOol00`00M3Id=P07M3H0
0`00M3Id=P03M3H40006M3H30004M3H20004M3H00`00L3I`=P04L3H20000170f001`=P001g0f00<0
07ooOol04Woo00<007ooOol0;goo0006Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0E
Ool00`00M3Id=P07M3H00`00M3Id=P06M3H01000M3Id=W@f0`000W@f00<007@fM3H017@f0P0000=d
=P00L3H0270f00D0070fL3I`=P0000M`=P8001=oo`03001oogoo02ioo`002goo0P003Woo00<007oo
Ool057oo0`001W@f00<007@fM3H01g@f1@0017@f00<007@fM3H01W@f00<0070fL3H0270f00H0070f
0000070f0005L3H01000L3I`=P004goo00<007ooOol0;Goo000;Ool2000?Ool00`00Oomoo`0COol0
0`00M3Id=P0500000g@f001d=P06M3H30004M3H40009M3H01000M3H000001W0f00<0070fL3H00W0f
0`000g0f00<0070fL3H00W0f0P004Woo00<007ooOol0;7oo000;Ool00`00Oomoo`0?Ool00`00Oomo
o`0BOol00`00M3Id=P05M3H200000g@f001d=P02M3H200000g@f001d=P07M3H00`00M3Id=P06M3H0
0`00M3Id=P02M3H20003L3H00`00L3I`=P05L3H200000g0f001`=P06L3H00`00Oomoo`0@Ool00`00
Oomoo`0[Ool000]oo`80015oo`03001oogoo019oo`03001d=W@f00Ed=P03001d=W@f00D00003M3H0
07@f00Md=P03001d=P00008000Ad=P03001d=W@f00Ad=P800003L3H0070f00Q`=P03001`=W0f00M`
=P03001oogoo00moo`8002aoo`002goo00<007ooOol04Goo00<007ooOol04Goo00<007@fM3H01G@f
0`001G@f0P0000=d=P00M3H017@f00<007@fM3H00g@f0`0000=d=P00M3H01g@f00<0070fL3H01g0f
0P0000=`=P00L3H01g0f0P0047oo00<007ooOol0:Woo0004Ool20005Ool00`00Oomoo`0BOol00`00
Oomoo`0@Ool30003M3H30008M3H00`00M3Id=P030002M3H00`00M3Id=P06M3H00`00M3Id=P06M3H0
1000M3Id=P001W0f00H0070fL3H0070f0005L3H01@00L3I`=W0f000047oo00<007ooOol0:Goo0004
Ool00`00Ool00004Ool00`00Oomoo`0COol00`00Oomoo`0?Ool00`00M3Id=P0400000g@f001d=P07
M3H00`00M3Id=P03M3H20009M3H01000M3H0000017@f00<007@fM3H00W@f0P000g0f00<0070fL3H0
0W0f00<0070f00000g0f00<0070fL3H00g0f00<007ooOol03Woo00<007ooOol0:7oo0004Ool00`00
Ool00004Ool00`00Oomoo`0DOol00`00Oomoo`0>Ool30004M3H200000g@f001d=P04M3H00`00M3Id
=P05M3H00`00M3H000020004M3H00`00M3Id=P02M3H200000g@f001d=P06M3H00`00L3H00006L3H0
1@00L3H0070f00001g0f00<007ooOol03Goo00<007ooOol017oo0P008Woo0005Ool20004Ool00`00
Oomoo`0EOol00`00Oomoo`0:Ool40007M3H00`00N3Ih=P0400000g@f001d=P06M3H00`00M3Id=P02
M3H200000g@f001d=P06M3H00`00M3Id=P07M3H00`00L3I`=P06L3H00`00L3H00009L3H00`00Oomo
o`0=Ool00`00Oomoo`03Ool00`00Ool0000QOol000Yoo`8001Qoo`03001oogoo00Moo`8000=oo`03
001d=W@f00L000Eh=P@000Ad=P03001d=W@f00Ed=P03001d=W@f00Id=P03001d=P00008000Ad=P04
001`=W0f0006L3H20002L3H00`00L3I`=P06L3H2000>Ool20003Ool00`00Ool0000QOol000Yoo`80
01Uoo`03001oogoo00=oo`<000Eoo`04001d=W@f0006J5`<00000g@f001d=P06M3H00`00M3D00002
0003M3H00`00M3Id=P03M3H200000g@f001`=P03L3H20003L3H01000L3I`=P000W0f00<0070fL3H0
0g0f00D0070fL3I`=P0000eoo`8000Aoo`80025oo`002Woo00<007ooOol06Goo00<007oo00000P00
27oo0`002fQL00<006QMJ5d016QM2`0017@e0P0000=d=P00M3H01W@f00<0070fL3H01G0f00<0070f
00000g0f00D0070fL3I`=P0000=`=P03001`=W0f00=`=P03001oogoo00aoo`03001oogoo02Aoo`00
2Woo0P006Woo0P002goo00<007Pf00002VQL00<006QMJ5d02FQM00<006QMJ5d00fQM2P001W@f00<0
07@e00001W0f00<0070fL3H00g0f00L0070fL3I`=P00L3H00007L3H00`00Oomoo`0;Ool00`00Oomo
o`0TOol000Yoo`03001oogoo01Ioo`<0009oo`03001oogoo00Uoo`03001XG6QL00UXG003001XGFQM
00QXG@03001XGFQM00QXG@03001XGFQM00=XG@P00003M3D0070f009`=P05001`=W0fL3H00004L3H0
1@00L3I`=W0f00002G0f00<007ooOol02goo00<007ooOol08goo0004Ool00`00Oomoo`03Ool00`00
Oomoo`0COol30006Ool00`00Oomoo`08Ool00`00J5aXG008J5`00`00J5eXG@08J5d00`00J5eXG@08
J5d00`00J5eXG@07J5d00`00J5eXG@02J5d60004L3H20003L3H20003L3H00`00L3I`=P06L3H00`00
Oomoo`0;Ool00`00Oomoo`0ROol000Aoo`03001oogoo00=oo`03001oogoo011oo`<000Yoo`03001o
ogoo00Moo`03001XG6QL00QXG003001XGFQM00QXG@03001XGFQM00MXG@03001XGFQM00MXG@03001X
GFQM00EXG@04001XGFQMJ5d40002L3H01@00L3H0070f0000170f00<0070fL3H00W0f0P0000=/=P00
Ool03Goo0P008Woo0004Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool2000>Ool00`00Oomoo`05Ool7
0005J5`00`00J5eXG@07J5d00`00J5eXG@07J5d00`00J5eXG@07J5d00`00J5eXG@05J5d00`00J5eX
G@06J5d40003L3H00`00L3I`=P02L3H01000L3H0000016`f00<007ooOol02goo00<007ooOol08Goo
0004Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool3000AOol00`00Oomoo`04Ool00`00I5aTG004I5`I
00000fQM000000020004J5d00`00J5eXG@05J5d00`00J5eXG@06J5d00`00J5eXG@02J5d40005L3H0
0`00K3I/=P05K3H00`00Oomoo`0;Ool00`00Oomoo`0POol000Uoo`8000Yoo`<001Eoo`03001oogoo
00=oo`03001TG6AL00QTG003001TGFAM00MTG@03001TGFAM00MTG@03001TGFAM00=TG@@00004J5d0
00000003J5d00`00J5eXG@06J5d00`00J5eXG@06J5d500000f`f001/=P06K3H00`00Oomoo`0<Ool0
0`00Oomoo`0OOol000Uoo`03001oogoo00Moo`8001Uoo`03001oogoo009oo`03001TG6AL00MTG003
001TGFAM00MTG@03001TGFAM00MTG@03001TGFAM00MTG@03001XGFQM009XG@<00004J5d000000004
J5d00`00J5eXG@05J5d01000J5iXGVQN100000=/=P00K3H01V`f00<007ooOol037oo00<007ooOol0
7Woo0009Ool20005Ool3000LOol01000Oomoo`002VAL00<006AMI5d01fAM00<006AMI5d01fAM00<0
06AMI5d01VAM00<006QMJ5d01FQM00<006QNJ5h00VQN10001fQM00<006QNJ5h00fQN00<006QNJ5h0
0`001f`f00<007ooOol037oo00<007ooOol07Goo0009Ool20002Ool3000POol00`00Ool0000:I5`0
0`00I5eTG@07I5d00`00I5eTG@06I5d00`00I5eTG@06I5d00`00J5eXG@05J5d00`00J5iXGP05J5h0
1000J5iXGVQN0`0000=XG@00J5h01VQN0P000faN1P0000=/=`00Ool03Goo0P007Woo0009Ool4000T
Ool20009I5`00`00I5eTG@07I5d00`00I5eTG@07I5d00`00I5eTG@05I5d00`00J5eXG@05J5d00`00
J5iXGP05J5h00`00J5iXGP05J5h01000J5iXGP000fQN0P0000=/GP00K5h01FaN0P000f`g00<007oo
Ool037oo00<007ooOol077oo0002Ool20005Ool2000WOolZ0003J5d00`00J5iXGP05J5h00`00J5iX
GP04J5h00`00J5iXGP03J5h30003K5h01000K5i/GVaN0P000faN0P000V`g00<007ooOol037oo00<0
07ooOol06goo0003Ool00`00Oomoo`05Ool00`00Oomoo`0TOol00`00I5eTG@07I5d00`00I5eTG@07
I5d00`00I5eTG@06I5d00`00I5eTG@05I5d00`00I5iTGP02I5h3000016QN000000000fQN00<006QN
J5h00fQN00<006QNJ5h01FQN00@006QNJ5iXGPH000M/GP800003K3L007oo00eoo`03001oogoo01Yo
o`0017oo00<007ooOol01Goo00<007ooOol08goo00<006AMI5d01fAM00<006AMI5d01VAM00<006AM
I5d01VAM00<006AMI5d01FAM00<006ANI5h01FAN00<006ANI5h00VAN0`0000=XGP0000000`001fQN
00<006QNJ5h01FQN0P001FaN0P000faM00<006`g00003Goo00<007ooOol06Woo0003Ool20008Ool0
0`00Oomoo`0ROol00`00I5eTG@07I5d00`00I5eTG@06I5d00`00I5eTG@05I5d00`00I5eTG@05I5d0
0`00I5iTGP05I5h00`00I5iTGP04I5h00`00I5iTGP03I5h01000J7mXOfQo0`0000=XGP00J5h01FQN
00@006aNK5i/GP800003K5h0000000I/G@8000ioo`03001oogoo01Uoo`003Woo00<007ooOol087oo
00<006AMI5d01fAM00<006AMI5d01fAM00<006AMI5d01FAM00<006AMI5d01FAM00<006ANI5h016AN
00<006ANI5h016AN00<006ANI5h00fAN00<006QoJ7l01FQo00@006QNJ5h0009XGP03001/GVaN00A/
GP8000U/G@8000ioo`8001Uoo`003goo00<007ooOol07goo00<006AMI5d01fAM00<006AMI5d00VAM
700000=TGP000000100000=TGP0000000VAN00<006QoJ7l016Qo00<006QoJ7l00fQo0P0016aN0`00
00=/GP00K5h00P000VaM0`000g1M0P003Goo00<007ooOol05goo000@Ool00`00Oomoo`0NOol?0004
I5d00`00I5eTG@05I5d00`00I5iTGP05I5h00`00I5iTGP04I5h00`00I5iTGP04I5h01000I7mTOfAo
0P000VQo00D006QoJ7mXO`0000EXO`03001XOfQo009XO`8000A/GP04001/GVaNK5h20005L5d016`g
001`G@0037oo00<007ooOol05goo000AOol00`00Oomoo`0MOol00`00I5eTG@07I5d00`00I5eTG@05
I5d00`00I5eTG@05I5d00`00I5iTGP05I5h00`00I5iTGP04I5h00`00I5iTGP04I5h00`00I7mTO`02
I7l00`00I7mTO`02I7l300001FQo001XOfQo00001FQo00D006aoK7m/O`00009/GP<0009`GP03001`
GF`g00E/=`8000eoo`03001oogoo01Ioo`004Woo00<007ooOol077oo00<006AMI5d01fAM00<006AM
I5d01FAM00<006AMI5d01FAM00<006ANI5h01FAN00<006ANI5h016AN00<006ANI5h00fAN00<006Ao
I7l00VAo00<006AoI7l00fAo00<006QoJ7l00VQo0P0000EXO`00J7mXO`0000I/O`80009`GP04001`
GV`g0008K3L2000=Ool00`00Oomoo`0EOol001=oo`03001oogoo01]oo`03001TGFAM00ITG@03001T
GFAM00ITG@03001TGFAM00ETG@03001TGVAN01L00003I7l00000008000AXO`8000AXO`8000=/O`<0
009`GP05001`GV`gK3L00002K3L00`00K3M/=`030002K3L00`00L5d0000=Ool2000EOol001Aoo`03
001oogoo01Uoo`03001TGFAM00MTG@04001TGFAMI5d@0004I5h00`00H5iPGP04H5h00`00H7mPO`02
H7l00`00H7mPO`02H7l00`00I7mTO`02I7l01000I7mTOfAo0P000fQo0`0016ao00<0071NL5h00W1N
0V`f00D006`gK3M/=`00009/=`8000I/=`8000ioo`03001oogoo01=oo`005Goo00<007ooOol067oo
00<006AMI5d00VAM2@0016AM00<006AMI5d01FAM00<006ANI5h016AN00<0061NH5h0161N00<0061o
H7l00V1o00<0061oH7l00V1o00<006AoI7l00VAo00D006AoI7mTO`0000AXO`04001/OfaoK7l30002
L7l00`00L5i/=P04K3H3000016`g001/=`001f`g00<0071L00003Goo00<007ooOol04goo000FOol2
000HOol50005I5d00`00I5eTG@05I5d00`00I5eTG@05I5d00`00I5iTGP04I5h00`00H5iPGP04H5h0
0`00H7l0000<000016Ao000000000fQo00<006QoJ7l00VQo0P0000E`Of`fK3I/=P00009/=P<00003
K3L006`g009/=`04001/=f`g0006K3L200000g1L001oo`0<Ool00`00Oomoo`04Ool3000;Ool001Qo
o`03001oogoo01Eoo`03001TGFAM00MTG@03001TGFAM00ETG@03001TGFAM00ATG@04001TGVANI5h=
0002H7l00`00H7mPO`02H7l00`00H7mPO`04H7l00`00I7mTO`02I7l01000J7mXO`000Vao0V`f00<0
06`fK3H00V`f0P001F`g00L006`gK3M/=`00K3L00005K3L300000gAL001oo`0=Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool001Uoo`03001oogoo01Aoo`03001TGFAM00ITG@03001TGFAM00ITG@04001T
GFAMI5d70003H5h00`00H5iPGP04H5h01@00H7mPOf1o0000161o00D0061o0000061o00<0009TO`80
0005J7l006aoK7l00003K3H40002K3H00`00K3M/=`04K3L00`00K3M/=`02K3L20002K3L30002K3L0
1000M5adG0003Woo00<007ooOol00goo00<007ooOol02Woo000JOol00`00Oomoo`0COol00`00I5eT
G@06I5d00`00I5eTG@02I5d80003H5d00`00H5iPGP04H5h00`00H5iPGP03H5h00`00H7l000080002
G7l01000G7mLO`000UbO0V2O0VQo00<006`eK3D010000VPf00<006`fK3H00V`f00<006`gK3L00f`g
00@006`gK3M/=`D000I/=`03001dG00000ioo`8000Eoo`03001oogoo00Uoo`006goo00<007ooOol0
4Woo00<006AMI5d016AM1`0016AM00<0061MH5d0161M00<0061NH5h00f1N00<0061NH5h01P000eao
00D005aoG7mLO`00009LO`03001LO`0000@00004?0l006`eK3D300000fPf001X=P03J3H00`00K3I/
=P02K3H01000K3M/=f`g1P000fPg00<006`gK3L01F`g00<007AL00003goo00<007ooOol03goo000L
Ool00`00Oomoo`0AOol00`00I5d000040002I5d00`00I5eTG@06I5d00`00H5ePG@04H5d00`00H5iP
GP060003H7h00`00G7mLO`02G7l00`00G7l0000800001EBO000l3`00K1@00`0000=X=@00J3H00VPf
00<006PfJ3H00VPf00<006`fK3H01@000fPg00<006PgJ3L016Pg00<006`gK3L01F`g00<007AL0000
3goo00<007ooOol03Woo000MOol00`00Oomoo`0@Ool20007I5d00`00I5eTG@05I5d00`00H5ePG@03
H5d50003H5h00`00H7iPOP02H7h00`00G7mLO`050002F7l00`00F7mHO`0900001FPe001X=FPe0000
0fPf00<006PfJ3H01@000VPg00<006PgJ3L016Pg00<006PgJ3L00fPg0P001V`g00<007AL000047oo
00<007ooOol03Goo000NOol00`00Oomoo`0?Ool00`00I5eTG@07I5d00`00I5eTG@04I5d00`00H5d0
00030002H5d00`00H5iPGP03H5h01000H7iPOV1n10000Uao00/005QoF7mHO`00F7m@O`00D9l005Bo
00<00003I1@006Pe009X=@05001X=FPe001X=P040002J3L00`00J3MX=`03J3L00`00J3MX=`03J3L0
0`00J3MX=`03J3L20003K3L6000AOol00`00Oomoo`0<Ool001moo`03001oogoo00ioo`03001TGFAM
00MTG@04001TGFAMI5d50006H5d00`00H5iPGP03H5h01P00H7h00000G5h000ALO`03001HO`000080
009@O`04001@W`00E;l=0002J3H01@00J3MX=fPg00001FPg00<006PgJ3L00fPg00@006PgJ3MX=`L0
00AX=`80015oo`8000eoo`0087oo00<007ooOol03Woo00<006AMI5d016AM1P000f1M00<0061MH5d0
1F1M00<0061NH5h0100015aN00<005aoG7l010000UQo00L0051oD7l0052O001<O`02000015`g001P
=P001F@f00D006PfJ3IX=P0000AX=`03001X=fPg009X=`04001X=fPgJ3L60003J3L00`00J3L00005
J3L2000BOol00`00Oomoo`0;Ool0025oo`03001oogoo00eoo`03001TG@0000@0009TG@03001PGF1M
00APG@03001PGF1M00=PG@D000=PGP04001LGUaNG5h40002F7l00`00F7l000020002D7l00`00C7m<
GP0200001E`g001P=V0f00000V@f00@006@fI3H000AX=P05001X=fPgJ3L00002J3L60003J3L00`00
J3MX=`04J3L00`00J3L00004J3L2000COol00`00Oomoo`0:Ool0029oo`03001oogoo00aoo`8000MT
G@03001PGF1M00EPG@03001PG@000080009PG@03001PGV1N00=PGP06001LGP00001LGP000eQo0`00
0UAo00L0051oC7l004aN001DF`0700001F@f001T=V@f00000VPf2@000fPg00<006PgJ3L00fPg00<0
06PgJ3L016Pg00@006PgJ3L000AX=`03001oogoo019oo`03001oogoo00Uoo`008goo00<007ooOol0
2goo00<006AMI5d01VAM00<0061MH5d00f1M10001F1M00<0061NH5h00V1N0P001EaN00D005Qo001H
O`00009DO`80009<O`07D5d00000E5/005Pi00000U`h00<0060gH3L01P000V@g00D006PgJ3MX=`00
00EX=`03001X=fPg00=X=`03001X=fPg00AX=`05001X=fPgJ3L00003J3L00`00Oomoo`0BOol00`00
Oomoo`09Ool002Aoo`8000]oo`03001TGFAM00ITG@03001PG@0000<0009PG@03001PGF1M00APG@03
001PGP0000800003G5d005aN00=LGP8000=HO`<00003E7l00000009@G@03001DF`00008000=L>004
001P=f0g0002I3L00`00I3MT=`02I3L01@00J3MX=fPg00001VPg00<006PgJ3L00fPg00<006PgJ3L0
16Pg00<006PgJ3L01@005Goo0P002Goo000VOol00`00Oomoo`09Ool00`00I5eTG@03I5d40006H5d0
0`00H5ePG@03H5d30005G5d01P00G5h00000G5h0009HO`03001HGP00009DO`04E5d0051M0002E5/0
1P00F5X00000G3P0009P=`05001T=f@gI3L00004I3L00`00J3MX=`02J3L00`00J3MX=`03J3L00`00
J3MX=`03J3L01000J3MX=fPg20000VPh00<007ooOol057oo00<007ooOol01goo000WOol00`00Oomo
o`08Ool00`00I5d000030002H5`00`00H5ePG@06H5d00`00H5d0000200000f1M001LG@04G5d20005
G5h20002F5h20003E5d200001EAK001HFUQJ00000U`i8@000fPh00<006PhJ3P00VPh00<006Ph0000
5goo00<007ooOol01Woo000XOol00`00Oomoo`07Ool20007H5`00`00H5ePG@03H5d40005H5d00`00
G5d0000200000eaM001LGP03G5h20002F5h01P00F5eHG@00E5d0009HF`@000=L>@04001P>60h0003
I3P00`00I3QT>002I3P00`00I3MT=`02I3L00`00J3MX=`03J3L00`00J3MX=`03J3L00`00J3QX>004
J3P00`00J3QX>003J3P2000HOol00`00Oomoo`05Ool002Uoo`03001oogoo00Ioo`03001PG61L00IP
G003001PGF1M00<0009PG@03001PGF1M00=PG@<000ELG@08001LGP00001LG@00F5h000=HG@8000=H
F`03001LFUaJ00800003G3T0060h009P>005001T>6@hI3P00004I3P00`00I3MT=`02I3L00`00J3MX
=`03J3L00`00J3MX=`03J3L00`00J3QX>004J3P00`00J3QX>004J3P2000GOol00`00Oomoo`05Ool0
02Yoo`03001oogoo00Ioo`03001PG61L00APG0@000EPG@04001PGF1MH5d200000f1M001LG@04G5d2
0004G5d20003F5d01P00F5]HF`00F5/000=LFP03001L>E`i00800003H3P006@h00=T>005001T>6@h
I3P00005I3L00`00J3MX=`03J3L00`00J3MX=`03J3L00`00J3QX>004J3P00`00J3QX>005J3P00`00
Oomoo`0FOol20005Ool002]oo`03001oogoo00Eoo`03001PG61L00@0009PG003001PGF1M00EPG@03
001PG@0000APG@03001LG@0000800003G5d005aM009LG@06001LG5aL001HG@0015QK0`0000=LFP00
G3T00U`i00<0060iH3T0200000=T>000I3L016@g00<006PgJ3L00fPg00<006PgJ3L00fPg00<006Ph
J3P016Ph00@006PhJ3QX>0D001Uoo`03001oogoo00=oo`00;7oo00<007ooOol01Goo0P001f1L00<0
061MH5d00f1M0P001V1M0P001EaM00<005aM00000eaL0`000eQK00@005aKG5]LF`80009L>@05001P
>F0iH3T00004H3P00`00I3QT>00N0004J3P2000GOol30004Ool002eoo`03001oogoo00Aoo`03001P
G61L00IPG003001PGF1M00<00003H5`0061M00=PG@800003H5`005aM00ALG@8000=LG007001LFeaK
G5/005QK000015aK00D005aJ001L>@0000=P>@03001P>60h009P>005001T>6@hI3P00005I3P00`00
I3QT>003I3P00`00J3QX>003J3P00`00J3QX>004J3P00`00J3QX>005J3P00`00Ool0000COol30002
Ool00`00Oomoo`02Ool002ioo`03001oogoo00Aoo`03001PG61L00EPG0<000EPG004001PG@000004
H5`00`00G5d000020002G5`00`00G5`00004G5/30003G5/01000G5YLFUaJ0`0000=P>@00H3P00f0h
00<006@hI3P00V@h00<006@hI3P00f@h00<006@hI3P00f@h00<006PhJ3P00fPh00<006PhJ3P016Ph
00<006PhJ3P01FPh00@007ooOol000ioo`@000Eoo`03001oogoo009oo`00;goo00<007ooOol017oo
00@0061LH5aPG0<00003H5`0061L00EPG08000IPG08000ELG0<000=LF`07001LFeaKG5/005aK0000
15aJ00<0060iH3T01@0000=P>000I3P00f@h00<006@hI3P00V@h00<006@hI3P00f@h00<006PhJ3P0
16Ph00<006PhJ3P016Ph00<006PhJ3P01FPh00D007ooOomoo`0000Yoo`<000Uoo`03001oogoo009o
o`00<7oo00<007ooOol00goo00@0061L000000EPG004001PG61LH5`20002H5`01000H5aPG61L0P00
0V1L00D005aLG5aLG00000=LF`03001LF`0000ELF`<0009LFP03001P>F0i009P>@04001P>F0iH3T:
00000f@h001T>004I3P00`00J3QX>004J3P00`00J3QX>004J3P00`00J3QX>005J3P00`00Oomoo`02
Ool00`00Oomoo`04Ool3000<Ool00`00Oomoo`02Ool0035oo`8000Aoo`03001PG61L00EPG004001P
G0000005H5`00`00H5`00005H5`00`00G5`00005G5/20004G5/01000H5YPFV1J0`000f0i00<0060i
H3T00f0i00<006@hI3P00V@h00@006@hI3QT>1h000Aoo`03001oogoo00@0011oo`03001oogoo005o
o`00<goo00D007ooOomoo`0000MPG08000MPG08000IPG08000ELF`03001PFf1K00800003G5/0061J
00APFP03001PFP00009P>@03001P>F0i009P>@03001T>6@h009T>003001T>6@h00=T>003001T>6@h
00=T>003001X>6Ph00AX>003001X>6Ph00AX>003001X>6Ph00EX>003001oogoo009oo`<001Aoo`03
001oogoo005oo`00=7oo00D007ooOomoo`0000APG080009PG003001PG61L009PG080009PG004001P
G61LH5`20002H5/01@00G5]LFeaK00001F1K0P00161J00<0061JH5X00V1J10000V0i00<006@hI3P0
0V@h00<006@hI3P00f@h00<006@hI3P00f@h00<006PhJ3P016Ph00<006PhJ3P016Ph00<006PhJ3P0
1FPh1@000Woo00<007ooOol04Woo00<007ooOol00Goo000eOol01P00Oomoogoo001PG08000EPG004
001PG0000005H5`00`00H5`00005H5/00`00G5/00005H5/00`00H5YPFP0200000f1J001PFP04H5X0
1000H3UP>F0i1@000V@h00<006@hI3P00V@h00<006@hI3P00f@h00<006PhJ3P01FPh00<006PhJ3P0
16Ph00<006PhJ3P01FPh00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00Goo000fOol01@00
Oomoogoo00001f1L0P001f1L0`001F1K0`00161K00<0061JH5X00f1J0P00161J00<0060iH3T00f0i
00@006@iI3UT>@D0009T>003001T>6@h00=T>003001X>6Ph00AX>003001X>6Ph00EX>003001X>6Ph
00EX>003001oogoo00Ioo`03001oogoo011oo`03001oogoo005oo`00=goo00@007ooOol000IPG004
001PFf1K0005H5`01@00H5]PFf1K00000f1K00@0061KH5]PF`800003H5/0061J00EPFP06001PFP00
001PFP001F0i00<006@iI3T00f@i00@006@iI3UT>@d0009X>003001X>6Ph00EX>003001X>6Ph00EX
>003001oogoo00Moo`03001oogoo00moo`03001oogoo005oo`00>7oo00@007ooOol000=PG08000AP
F`05001PG61LH5`00005H5/00`00H5/00006H5/20005H5X00`00H5YPFP02H5X40002H3T00`00I3UT
>@03I3T00`00I3UT>@04I3T00`00I3QT>003I3P00`00I3QT>002I3PC0009Ool00`00Oomoo`0?Ool0
0`00Oomoo`01Ool003Uoo`06001oogoo001PG0001f1K00<0061L00001V1K0`001F1K00<0061JH5X0
0`0000=PFP00H5X0161J00@0060iH3UP>@@000AT>@03001T>F@i00=T>@03001T>6@h00AT>003001T
>6@h00AT>003001X>6Ph00EX>003001X>6Ph00EX>003001oogoo00Qoo`03001oogoo00ioo`03001o
ogoo005oo`00>Woo00<007ooOol00P001f1K0`001F1K00D0061KH5]PF`0000=PF`03001PFV1J00AP
FP8000APFP03001P>F0i00=P>@03001T>F@i0080009T>@03001T>F@i00=T>@03001T>6@h00AT>003
001T>6@h00AT>003001X>6Ph00EX>003001X>6Ph00EX>003001oogoo00Uoo`03001oogoo00eoo`03
001oogoo005oo`00>goo00D007ooOomoo`0000APF`8000=PF`05001PFf1KH5/00005H5/00`00H5/0
0006H5X00`00H5YPFP0200000f1J001P>@04H3T00`00I3UT>@04I3T40003I3T00`00I3QT>003I3P0
0`00I3QT>005I3P00`00J3QX>005J3P00`00J3QX>005J3P00`00Oomoo`0:Ool00`00Oomoo`0=Ool1
0001Ool1Ool003aoo`06001oogooOol0061K0P001V1K00<0061K00001V1K0`001F1J00<0061JH5X0
0f1J0`00160i00<006@iI3T016@i00@006@iI3UT>@L0009T>003001T>6@h00AT>003001X>6Ph00EX
>003001X>6Ph00EX>003001oogoo00aoo`03001oogoo00aoo`40005oo`5oo`00?Goo00D007ooOomo
o`0000QPF`<000EPF`04001PFV1JH5X300000f1J001PFP05H5X00`00I5YTFP020002H3T00`00I3UT
>@03I3T00`00I3UT>@04I3T00`00I3UT>@02I3T70002I3P00`00J3QX>005J3P00`00J3QX>005J3P0
0`00Oomoo`0=Ool00`00Oomoo`0;Ool10001Ool1Ool003ioo`05001oogooOol00006H5/01@00H5]P
Ff1K00000f1K00<0061JH5X0161J0`001F1J00<006AJI5X016AJ10000f@i00<006@iI3T00f@i00<0
06@iI3T01F@i00<006@iI3T00V@i3`000fPh00<007ooOol03Goo00<007ooOol02goo0@000Goo0Goo
000oOol20002Ool01000H5]PFf1K0P001F1K00<0061K00001V1J00@0061JH5YPFP<00003H5X006AJ
00ETFP03001T>F@i009T>@D000AT>@03001T>F@i00AT>@03001T>F@i00ET>@03001X>FPi00EX>@03
001X>6Ph009X>0@0011oo`03001oogoo00Yoo`40005oo`5oo`00@Goo00H007ooOol0061K0007H5/3
0005H5X00`00H5YPFP05H5X20005I5X00`00I3UT>@05I3T00`00I3UT>@020002I3T00`00I3UT>@04
I3T00`00I3UT>@04I3T00`00J3UX>@05J3T00`00J3QX>006J3P00`00Oomoo`0?Ool00`00Oomoo`09
Ool10001Ool1Ool0049oo`03001oogoo008000IPF`04001PFV1JH5X300000f1J001PFP07H5X00`00
I5X0000200000fAJ001T>@06I3T00`00I3UT>@04I3T50003I3T00`00I3UT>@04I3T00`00J3UX>@05
J3T00`00J3QX>006J3P00`00Oomoo`0@Ool00`00Oomoo`08Ool10001Ool1Ool004=oo`04001oogoo
Ool20003H5/00`00H5YPFP05H5X20007H5X00`00I5YTFP03I5X30005I3T00`00I3UT>@05I3T00`00
I3UT>@02I3T70003I3T00`00J3UX>@05J3T00`00J3QX>006J3P00`00Oomoo`0AOol00`00Oomoo`07
Ool10001Ool1Ool004Aoo`03001oogoo009oo`03001PF`0000MPFP03001TFVAJ008000APFP03001T
FVAJ00ATFP03001T>F@i00<00003I3T006@i00IT>@03001T>F@i00ET>@03001T>F@i009T>@L000=X
>@03001X>6Ph00IX>003001oogoo01=oo`03001oogoo00Ioo`40005oo`5oo`00AGoo00<007ooOol0
0Woo0P001V1J00<006AJI5X00fAJ0P0000=PFP00I5X01FAJ00<006@iI3T016@i0`001F@i00<006@i
I3T01F@i00<006@iI3T01F@i00<006PiJ3T00VPi2@000fPh00<007ooOol057oo00<007ooOol01Woo
0@000Goo0016Ool00`00Oomoo`03Ool20003H5X00`00I5YTFP06I5X30004I5X00`00I3UT>@05I3T0
0`00I3UT>@030002I3T00`00I3UT>@05I3T00`00I3UT>@04I3T00`00J3UX>@06J3T00`00J3UX>@03
J3T4000FOol00`00Oomoo`06Ool10001Ool004Moo`03001oogoo00Aoo`03001PFP0000QTFP04001T
FVAJI5X300000fAJ001T>@05I3T00`00I3UT>@04I3T40005I3T00`00I3UT>@05I3T00`00J3UX>@05
J3T00`00J3UX>@07J3T00`00Oomoo`0EOol00`00Oomoo`05Ool10001Ool004Qoo`03001oogoo00Ao
o`8000MTFP03001TFVAJ00ETFP<000AT>@03001T>F@i00IT>@03001T>F@i00<0009T>@03001T>F@i
00ET>@03001X>FPi00EX>@03001X>FPi00IX>@03001oogoo01Moo`03001oogoo00Aoo`40005oo`00
BGoo00<007ooOol01Goo0P0016AJ00<006AJI5X01FAJ00@006AJI5YTFP80009T>@03001T>F@i00ET
>@03001T>F@i00AT>@H000=T>@03001X>FPi00IX>@03001X>FPi00IX>@03001oogoo01Qoo`03001o
ogoo00=oo`40005oo`00BWoo00<007ooOol01Woo0P0000=TFP00I5X01VAJ00<006AJI5X01FAJ0`00
1F@i00<006@iI3T01V@i00<006@iI3T00V@i20000fPi00<006PiJ3T01fPi00<007ooOol06Goo00<0
07ooOol00Woo0@000Goo001;Ool00`00Oomoo`07Ool30005I5X00`00I5YTFP06I5X00`00I3UT>@03
0002I3T00`00I3UT>@05I3T00`00I3UT>@06I3T00`00J3UX>@02J3T90003J3T00`00Oomoo`0KOol0
1@00Oomoogoo00000Goo001<Ool2000:Ool300000fAJ001TFP07I5X00`00I3UT>@04I3T40005I3T0
0`00I3UT>@06I3T00`00J3UX>@06J3T00`00J3UX>@03J3T4000MOol01@00Oomoogoo00000Goo001>
Ool00`00Oomoo`0:Ool30006I5X00`00I3UT>@06I3T00`00I3UT>@030002I3T00`00I3UT>@06I3T0
0`00J3UX>@05J3T00`00J3UX>@07J3T00`00Oomoo`0LOol01000Oomoo`000Goo001?Ool00`00Oomo
o`0<Ool30002I5X00`00I3UT>@06I3T00`00I3UT>@04I3T40006I3T00`00J3UX>@06J3T00`00J3UX
>@06J3T00`00Oomoo`0NOol00`00Oomoo`010000051oo`03001oogoo00ioo`<000MT>@03001T>F@i
00IT>@03001T>F@i00@0009T>@03001X>FPi00EX>@03001X>FPi00MX>@03001oogoo01moo`40005o
o`400000DGoo00<007ooOol047oo0`0016@i00<006@iI3T01F@i00<006@iI3T01F@i1P0016Pi00<0
06PiJ3T01VPi00<007ooOol08Goo0P00001BOol00`00Oomoo`0BOol01000I3UT>@0026@i00<006@i
I3T01V@i00<006PiJ3T00VPi2@0016Pi00<007ooOol087oo0`00001COol00`00Oomoo`0AOol00`00
Ool000020006I3T00`00I3UT>@06I3T00`00J3UX>@06J3T00`00J3UX>@03J3T4000OOol40003Ool0
05Aoo`03001oogoo011oo`03001oogoo009oo`@0009T>@03001T>F@i00IT>@03001X>FPi00EX>@03
001X>FPi00MX>@03001oogoo01Uoo`@000Moo`00EGoo00<007ooOol03goo00<007ooOol01Woo1000
1V@i00<006PiJ3T01VPi00<006PiJ3T01VPi00<007ooOol05goo0`002goo001FOol00`00Oomoo`0>
Ool00`00Oomoo`0:Ool40002I3T00`00J3UX>@05J3T00`00J3UX>@07J3T00`00Oomoo`0COol4000>
Ool005Moo`03001oogoo00eoo`03001oogoo00ioo`H000AX>@03001X>FPi00IX>@03001oogoo011o
o`@0019oo`00F7oo00<007ooOol037oo00<007ooOol057oo1P001fPi00<007ooOol037oo10005Woo
001IOol00`00Oomoo`0;Ool00`00Oomoo`0JOol50002J3T00`00Oomoo`08Ool4000JOol005Yoo`80
00]oo`03001oogoo01moo`8000Qoo`<001ioo`00G7oo00<007ooOol027oo00<007ooOol09Goo1000
8Goo001MOol00`00Oomoo`07Ool00`00Oomoo`0QOol4000UOol005ioo`03001oogoo00Ioo`03001o
ogoo01eoo`@002Uoo`00Ggoo00<007ooOol01Goo00<007ooOol06Goo1000;Goo001POol00`00Oomo
o`04Ool00`00Oomoo`0FOol3000aOol0065oo`03001oogoo00=oo`03001oogoo019oo`@003Aoo`00
HWoo00<007ooOol00Woo00<007ooOol03Woo1000>7oo001SOol01@00Oomoogoo000037oo1000?7oo
001TOol01000Oomoo`0027oo1000@7oo001UOol00`00Ool00005Ool30014Ool006Ioo`800003Ool0
0000008004Moo`00Igoo0P00Bgoo0000\
\>"],
  ImageRangeCache->{{{0, 179}, {165.875, 0}} -> {-0.0508108, -0.0230671, \
0.00546539, 0.00546539}}]
}, Closed]],

Cell[TextData[{
  "Many functions have more than one branch point. As an example, consider ",
  Cell[BoxData[
      \(TraditionalForm\`\(sec\^\(-1\)\)(z)\)],
    FormatType->StandardForm],
  ", a function that can be reduced to square roots and logarithms."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ArcSec[z] // TrigToExp\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(\[Pi]\/2 + \[ImaginaryI]\ Log[\@\(1 - 1\/z\^2\) + \[ImaginaryI]\/z]\)], \
"Output",
  CellLabel->"Out[7]="]
}, Closed]],

Cell[TextData[{
  "So the branch points in the finite part of ",
  Cell[BoxData[
      \(TraditionalForm\`\(sec\^\(-1\)\)(z)\)],
    FormatType->StandardForm],
  ", if they occur, must appear at one of the locations determined by the \
arguments of ",
  StyleBox["Log", "MR"],
  " and ",
  StyleBox["Sqrt", "MR"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[
      1 - 1\/z\^2 \[Equal] 0 || \@\(1 - 1\/z\^2\) + \[ImaginaryI]\/z \[Equal] 
          0 || 1\/\(1 - 1\/z\^2\) \[Equal] 0 || 
        1\/\(\@\(1 - 1\/z\^2\) + \[ImaginaryI]\/z\) \[Equal] 0, z]\)], "Input",\

  CellLabel->"In[8]:="],

Cell[BoxData[
    \({{z \[Rule] \(-1\)}, {z \[Rule] 0}, {z \[Rule] 1}}\)], "Output",
  CellLabel->"Out[8]="]
}, Closed]],

Cell[TextData[{
  "Inspection of the graph of ",
  StyleBox["ArcSec", "MR"],
  " shows that ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)],
    FormatType->StandardForm],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0\)],
    FormatType->StandardForm],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`1\)],
    FormatType->StandardForm],
  " are all branch points."
}], "Text"],

Cell[TextData[{
  "The treatment of branch cuts has many important ramifications for computer \
algebra. When working with paper and pencil, one often has the freedom to \
choose the location of a branch cut, as we showed in the example of ",
  Cell[BoxData[
      \(TraditionalForm\`ln(z)\)],
    FormatType->StandardForm],
  ". However, since the majority of special functions in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " have integral representations with integrands built of either power \
functions, logs, or meromorphic functions, the branch cuts of these special \
functions are determined uniquely by the branch cuts of their integrands. (",
  StyleBox["Meromorphic functions",
    FontSlant->"Italic"],
  " are analytic in the finite plane except some finite set of  poles of \
finite order.)"
}], "Text"],

Cell[TextData[{
  "For example, for the function ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(w\^2 - 1\)\)],
    FormatType->StandardForm],
  " virtually every textbook chooses the branch cut to extend from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)],
    FormatType->StandardForm],
  " to 1. But that choice is inconsistent with the branch cut structure of ",
  Cell[BoxData[
      \(TraditionalForm\`\@z\)],
    FormatType->StandardForm],
  " described above. The value of ",
  Cell[BoxData[
      \(TraditionalForm\`w\^2 - 1\)],
    FormatType->StandardForm],
  " is negative for all purely imaginary values of ",
  Cell[BoxData[
      \(TraditionalForm\`w\)],
    FormatType->StandardForm],
  " and so we must also have a branch cut along the imaginary axis, as shown \
here."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[
        Im[\@\(\((x + \[ImaginaryI]\ y)\)\^2 - 1\)], {x, \(-2\), 
          2}, {y, \(-2\), 2}];\)\)], "Input",
  CellLabel->"In[7]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
9.02522e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -10.5625 -6.76881 ]
[.02757 .24618 0 .23119 ]
[.17646 .18758 -10.1397 -7 ]
[.17646 .18758 .17284 0 ]
[.3345 .12542 -6.57601 -7 ]
[.3345 .12542 .48649 0 ]
[.50253 .05935 -6.04308 -7 ]
[.50253 .05935 .83192 0 ]
[.68156 -0.01098 -5.89145 -7 ]
[.68156 -0.01098 1.23355 0 ]
[.70096 -0.00478 0 -4.87049 ]
[.70096 -0.00478 10.5625 2.12951 ]
[.78313 .12104 0 -4.77445 ]
[.78313 .12104 10.3125 2.22555 ]
[.8565 .23339 0 -4.69099 ]
[.8565 .23339 7.0625 2.30901 ]
[.9224 .33431 0 -4.61779 ]
[.9224 .33431 6.875 2.38221 ]
[.98191 .42546 0 -4.55306 ]
[.98191 .42546 7.125 2.44694 ]
[.02236 .2761 -10.5625 -2.14013 ]
[.02236 .2761 0 4.85987 ]
[.01478 .32362 -10.3125 -2.1714 ]
[.01478 .32362 0 4.8286 ]
[.00696 .37264 -7.0625 -2.20375 ]
[.00696 .37264 0 4.79625 ]
[-0.00111 .42321 -6.875 -2.23723 ]
[-0.00111 .42321 0 4.76277 ]
[-0.00944 .47541 -7.125 -2.27191 ]
[-0.00944 .47541 0 4.72809 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -71.5625 -10.7688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -71.1397 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -67.576 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -67.0431 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -66.8915 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -8.87049 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -8.77445 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -8.69099 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -8.61779 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -8.55306 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03459 .27134 m
.04071 .26897 L
s
gsave
.02236 .2761 -71.5625 -6.14013 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02704 .31897 m
.03318 .31664 L
s
gsave
.01478 .32362 -71.3125 -6.1714 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -68.0625 -6.20375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01123 .41875 m
.0174 .41653 L
s
gsave
-0.00111 .42321 -67.875 -6.23723 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.00294 .47106 m
.00913 .46889 L
s
gsave
-0.00944 .47541 -68.125 -6.27191 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.0331 .28075 m
.03677 .27933 L
s
.0316 .29022 m
.03527 .2888 L
s
.03009 .29974 m
.03377 .29833 L
s
.02857 .30933 m
.03225 .30792 L
s
.02551 .32867 m
.02919 .32728 L
s
.02396 .33843 m
.02765 .33704 L
s
.0224 .34825 m
.02609 .34687 L
s
.02084 .35814 m
.02453 .35676 L
s
.01768 .37809 m
.02137 .37673 L
s
.01608 .38816 m
.01978 .3868 L
s
.01447 .39829 m
.01817 .39694 L
s
.01286 .40849 m
.01656 .40715 L
s
.00959 .42908 m
.0133 .42775 L
s
.00795 .43948 m
.01166 .43815 L
s
.00629 .44994 m
.01 .44862 L
s
.00462 .46047 m
.00833 .45916 L
s
.03607 .26199 m
.03974 .26056 L
s
.00125 .48173 m
.00497 .48043 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.613 .43 .827 r
.38842 .60231 .40496 .60828 .43206 .5996 .41577 .59342 Metetra
.613 .429 .827 r
.41577 .59342 .43206 .5996 .45941 .5908 .44338 .58437 Metetra
.614 .427 .826 r
.44338 .58437 .45941 .5908 .48704 .58188 .47126 .57519 Metetra
.615 .425 .824 r
.47126 .57519 .48704 .58188 .51494 .57288 .49942 .5659 Metetra
.617 .424 .822 r
.49942 .5659 .51494 .57288 .54311 .56382 .52786 .55654 Metetra
.621 .422 .819 r
.52786 .55654 .54311 .56382 .57157 .55473 .55659 .54716 Metetra
.625 .422 .815 r
.55659 .54716 .57157 .55473 .60031 .54565 .5856 .5378 Metetra
.63 .421 .811 r
.5856 .5378 .60031 .54565 .62935 .53662 .61492 .52852 Metetra
.635 .422 .806 r
.61492 .52852 .62935 .53662 .6587 .52764 .64454 .51934 Metetra
.008 .008 .829 r
.64454 .51934 .6587 .52764 .69854 .72682 .6831 .70202 Metetra
.695 .289 .604 r
.6831 .70202 .69854 .72682 .73043 .71824 .71515 .69318 Metetra
.692 .288 .605 r
.71515 .69318 .73043 .71824 .76267 .70939 .74756 .68401 Metetra
.69 .287 .606 r
.74756 .68401 .76267 .70939 .79526 .70028 .78031 .67455 Metetra
.688 .286 .606 r
.78031 .67455 .79526 .70028 .8282 .69097 .81341 .66484 Metetra
.687 .285 .605 r
.81341 .66484 .8282 .69097 .8615 .68147 .84687 .65495 Metetra
.687 .284 .604 r
.84687 .65495 .8615 .68147 .89517 .67183 .88071 .64493 Metetra
.687 .283 .602 r
.88071 .64493 .89517 .67183 .92922 .66209 .91492 .63481 Metetra
.687 .282 .601 r
.91492 .63481 .92922 .66209 .96365 .65226 .94953 .62463 Metetra
.688 .282 .599 r
.94953 .62463 .96365 .65226 .99848 .64237 .98454 .6144 Metetra
.61 .43 .83 r
.37148 .59627 .38842 .60231 .41577 .59342 .39908 .58714 Metetra
.61 .428 .83 r
.39908 .58714 .41577 .59342 .44338 .58437 .42695 .57783 Metetra
.61 .426 .829 r
.42695 .57783 .44338 .58437 .47126 .57519 .4551 .56835 Metetra
.611 .424 .827 r
.4551 .56835 .47126 .57519 .49942 .5659 .48353 .55873 Metetra
.614 .422 .824 r
.48353 .55873 .49942 .5659 .52786 .55654 .51224 .54902 Metetra
.618 .42 .82 r
.51224 .54902 .52786 .55654 .55659 .54716 .54123 .53928 Metetra
.623 .419 .815 r
.54123 .53928 .55659 .54716 .5856 .5378 .57053 .52959 Metetra
.629 .418 .81 r
.57053 .52959 .5856 .5378 .61492 .52852 .60012 .52001 Metetra
.636 .419 .804 r
.60012 .52001 .61492 .52852 .64454 .51934 .63003 .51061 Metetra
.001 .001 .823 r
.63003 .51061 .64454 .51934 .6831 .70202 .66743 .6771 Metetra
.694 .29 .607 r
.66743 .6771 .6831 .70202 .71515 .69318 .69965 .66796 Metetra
.691 .289 .608 r
.69965 .66796 .71515 .69318 .74756 .68401 .73221 .65843 Metetra
.688 .287 .609 r
.73221 .65843 .74756 .68401 .78031 .67455 .76512 .64855 Metetra
.686 .286 .609 r
.76512 .64855 .78031 .67455 .81341 .66484 .79839 .63839 Metetra
.685 .284 .607 r
.79839 .63839 .81341 .66484 .84687 .65495 .83202 .62804 Metetra
.685 .283 .606 r
.83202 .62804 .84687 .65495 .88071 .64493 .86601 .61757 Metetra
.685 .282 .604 r
.86601 .61757 .88071 .64493 .91492 .63481 .9004 .60704 Metetra
.686 .281 .601 r
.9004 .60704 .91492 .63481 .94953 .62463 .93518 .59648 Metetra
.687 .281 .599 r
.93518 .59648 .94953 .62463 .98454 .6144 .97037 .58591 Metetra
.607 .43 .832 r
.35412 .59017 .37148 .59627 .39908 .58714 .38197 .58081 Metetra
.606 .428 .833 r
.38197 .58081 .39908 .58714 .42695 .57783 .41011 .57122 Metetra
.606 .426 .832 r
.41011 .57122 .42695 .57783 .4551 .56835 .43853 .5614 Metetra
.607 .423 .831 r
.43853 .5614 .4551 .56835 .48353 .55873 .46723 .55138 Metetra
.609 .42 .828 r
.46723 .55138 .48353 .55873 .51224 .54902 .49622 .54124 Metetra
.614 .417 .823 r
.49622 .54124 .51224 .54902 .54123 .53928 .5255 .53106 Metetra
.621 .415 .816 r
.5255 .53106 .54123 .53928 .57053 .52959 .55507 .52095 Metetra
.629 .415 .809 r
.55507 .52095 .57053 .52959 .60012 .52001 .58495 .51102 Metetra
.637 .415 .802 r
.58495 .51102 .60012 .52001 .63003 .51061 .61515 .50135 Metetra
0 0 .824 r
.61515 .50135 .63003 .51061 .66743 .6771 .65152 .6521 Metetra
.693 .292 .61 r
.65152 .6521 .66743 .6771 .69965 .66796 .68391 .64264 Metetra
.688 .29 .613 r
.68391 .64264 .69965 .66796 .73221 .65843 .71664 .63268 Metetra
.685 .288 .613 r
.71664 .63268 .73221 .65843 .76512 .64855 .74971 .62229 Metetra
.682 .286 .613 r
.74971 .62229 .76512 .64855 .79839 .63839 .78314 .61159 Metetra
.681 .284 .611 r
.78314 .61159 .79839 .63839 .83202 .62804 .81692 .60071 Metetra
.682 .283 .608 r
.81692 .60071 .83202 .62804 .86601 .61757 .85108 .58973 Metetra
.683 .281 .605 r
.85108 .58973 .86601 .61757 .9004 .60704 .88563 .57874 Metetra
.684 .281 .602 r
.88563 .57874 .9004 .60704 .93518 .59648 .92059 .56778 Metetra
.686 .28 .599 r
.92059 .56778 .93518 .59648 .97037 .58591 .95596 .55686 Metetra
.603 .431 .835 r
.33631 .58406 .35412 .59017 .38197 .58081 .36443 .57446 Metetra
.601 .429 .837 r
.36443 .57446 .38197 .58081 .41011 .57122 .39284 .56457 Metetra
.6 .425 .837 r
.39284 .56457 .41011 .57122 .43853 .5614 .42154 .55437 Metetra
.6 .422 .836 r
.42154 .55437 .43853 .5614 .46723 .55138 .45053 .54388 Metetra
.602 .417 .833 r
.45053 .54388 .46723 .55138 .49622 .54124 .47981 .5332 Metetra
.608 .414 .827 r
.47981 .5332 .49622 .54124 .5255 .53106 .50937 .52245 Metetra
.616 .411 .818 r
.50937 .52245 .5255 .53106 .55507 .52095 .53923 .51181 Metetra
.627 .41 .808 r
.53923 .51181 .55507 .52095 .58495 .51102 .5694 .50144 Metetra
.638 .41 .798 r
.5694 .50144 .58495 .51102 .61515 .50135 .59988 .49145 Metetra
0 0 .826 r
.59988 .49145 .61515 .50135 .65152 .6521 .63537 .62715 Metetra
.691 .294 .616 r
.63537 .62715 .65152 .6521 .68391 .64264 .66793 .61731 Metetra
.685 .291 .619 r
.66793 .61731 .68391 .64264 .71664 .63268 .70082 .60683 Metetra
.68 .289 .619 r
.70082 .60683 .71664 .63268 .74971 .62229 .73406 .59581 Metetra
.677 .286 .618 r
.73406 .59581 .74971 .62229 .78314 .61159 .76764 .58443 Metetra
.677 .284 .615 r
.76764 .58443 .78314 .61159 .81692 .60071 .80158 .57289 Metetra
.678 .282 .61 r
.80158 .57289 .81692 .60071 .85108 .58973 .8359 .56133 Metetra
.68 .28 .606 r
.8359 .56133 .85108 .58973 .88563 .57874 .87062 .54984 Metetra
.682 .28 .602 r
.87062 .54984 .88563 .57874 .92059 .56778 .90575 .53847 Metetra
.685 .279 .599 r
.90575 .53847 .92059 .56778 .95596 .55686 .9413 .52719 Metetra
.6 .433 .838 r
.31804 .57797 .33631 .58406 .36443 .57446 .34643 .56816 Metetra
.596 .43 .841 r
.34643 .56816 .36443 .57446 .39284 .56457 .37512 .55797 Metetra
.592 .426 .843 r
.37512 .55797 .39284 .56457 .42154 .55437 .40412 .54735 Metetra
.59 .42 .844 r
.40412 .54735 .42154 .55437 .45053 .54388 .4334 .5363 Metetra
.592 .415 .84 r
.4334 .5363 .45053 .54388 .47981 .5332 .46298 .52492 Metetra
.598 .409 .832 r
.46298 .52492 .47981 .5332 .50937 .52245 .49284 .51341 Metetra
.609 .405 .821 r
.49284 .51341 .50937 .52245 .53923 .51181 .52299 .50206 Metetra
.624 .403 .807 r
.52299 .50206 .53923 .51181 .5694 .50144 .55345 .49111 Metetra
.64 .403 .793 r
.55345 .49111 .5694 .50144 .59988 .49145 .58423 .48073 Metetra
0 0 .829 r
.58423 .48073 .59988 .49145 .63537 .62715 .61896 .6024 Metetra
.689 .297 .623 r
.61896 .6024 .63537 .62715 .66793 .61731 .6517 .59211 Metetra
.68 .293 .627 r
.6517 .59211 .66793 .61731 .70082 .60683 .68477 .58096 Metetra
.673 .29 .628 r
.68477 .58096 .70082 .60683 .73406 .59581 .71817 .56913 Metetra
.67 .286 .625 r
.71817 .56913 .73406 .59581 .76764 .58443 .7519 .55688 Metetra
.67 .282 .619 r
.7519 .55688 .76764 .58443 .80158 .57289 .78599 .54451 Metetra
.673 .28 .613 r
.78599 .54451 .80158 .57289 .8359 .56133 .82046 .53226 Metetra
.677 .279 .606 r
.82046 .53226 .8359 .56133 .87062 .54984 .85534 .52024 Metetra
.681 .278 .601 r
.85534 .52024 .87062 .54984 .90575 .53847 .89064 .50845 Metetra
.684 .278 .598 r
.89064 .50845 .90575 .53847 .9413 .52719 .92639 .49685 Metetra
.596 .435 .841 r
.29928 .57194 .31804 .57797 .34643 .56816 .32795 .56198 Metetra
.59 .432 .846 r
.32795 .56198 .34643 .56816 .37512 .55797 .35693 .55154 Metetra
.583 .427 .851 r
.35693 .55154 .37512 .55797 .40412 .54735 .38622 .5405 Metetra
.577 .42 .854 r
.38622 .5405 .40412 .54735 .4334 .5363 .41582 .52878 Metetra
.576 .412 .852 r
.41582 .52878 .4334 .5363 .46298 .52492 .44572 .51644 Metetra
.583 .403 .842 r
.44572 .51644 .46298 .52492 .49284 .51341 .47589 .50386 Metetra
.599 .397 .825 r
.47589 .50386 .49284 .51341 .52299 .50206 .50635 .49153 Metetra
.619 .394 .805 r
.50635 .49153 .52299 .50206 .55345 .49111 .53709 .47982 Metetra
.641 .394 .786 r
.53709 .47982 .55345 .49111 .58423 .48073 .56816 .46897 Metetra
0 0 .833 r
.56816 .46897 .58423 .48073 .61896 .6024 .6023 .57806 Metetra
.685 .301 .633 r
.6023 .57806 .61896 .6024 .6517 .59211 .63522 .56723 Metetra
.672 .296 .639 r
.63522 .56723 .6517 .59211 .68477 .58096 .66846 .55524 Metetra
.663 .29 .64 r
.66846 .55524 .68477 .58096 .71817 .56913 .70202 .5423 Metetra
.659 .285 .635 r
.70202 .5423 .71817 .56913 .7519 .55688 .73589 .52884 Metetra
.661 .28 .626 r
.73589 .52884 .7519 .55688 .78599 .54451 .77012 .51539 Metetra
.667 .278 .615 r
.77012 .51539 .78599 .54451 .82046 .53226 .80474 .50234 Metetra
.674 .276 .605 r
.80474 .50234 .82046 .53226 .85534 .52024 .83978 .48979 Metetra
.68 .276 .599 r
.83978 .48979 .85534 .52024 .89064 .50845 .87527 .47764 Metetra
.684 .276 .595 r
.87527 .47764 .89064 .50845 .92639 .49685 .9112 .46577 Metetra
.594 .439 .843 r
.28001 .56601 .29928 .57194 .32795 .56198 .30895 .556 Metetra
.585 .436 .85 r
.30895 .556 .32795 .56198 .35693 .55154 .33822 .54545 Metetra
.573 .431 .86 r
.33822 .54545 .35693 .55154 .38622 .5405 .36782 .53409 Metetra
.559 .422 .869 r
.36782 .53409 .38622 .5405 .41582 .52878 .39776 .5216 Metetra
.55 .408 .872 r
.39776 .5216 .41582 .52878 .44572 .51644 .428 .50791 Metetra
.558 .395 .857 r
.428 .50791 .44572 .51644 .47589 .50386 .45852 .49369 Metetra
.583 .385 .83 r
.45852 .49369 .47589 .50386 .50635 .49153 .48929 .47994 Metetra
.613 .381 .801 r
.48929 .47994 .50635 .49153 .53709 .47982 .52033 .46726 Metetra
.642 .382 .776 r
.52033 .46726 .53709 .47982 .56816 .46897 .55169 .45584 Metetra
0 0 .839 r
.55169 .45584 .56816 .46897 .6023 .57806 .58535 .55443 Metetra
.679 .307 .647 r
.58535 .55443 .6023 .57806 .63522 .56723 .61847 .54298 Metetra
.661 .3 .656 r
.61847 .54298 .63522 .56723 .66846 .55524 .65191 .52991 Metetra
.647 .292 .658 r
.65191 .52991 .66846 .55524 .70202 .5423 .68562 .51543 Metetra
.641 .283 .65 r
.68562 .51543 .70202 .5423 .73589 .52884 .71962 .50017 Metetra
.647 .277 .633 r
.71962 .50017 .73589 .52884 .77012 .51539 .75395 .48521 Metetra
.66 .273 .614 r
.75395 .48521 .77012 .51539 .80474 .50234 .78871 .47128 Metetra
.672 .273 .601 r
.78871 .47128 .80474 .50234 .83978 .48979 .82392 .45831 Metetra
.68 .274 .594 r
.82392 .45831 .83978 .48979 .87527 .47764 .8596 .44595 Metetra
.685 .275 .591 r
.8596 .44595 .87527 .47764 .9112 .46577 .89574 .43392 Metetra
.594 .443 .843 r
.26021 .56019 .28001 .56601 .30895 .556 .28941 .55028 Metetra
.583 .443 .851 r
.28941 .55028 .30895 .556 .33822 .54545 .31896 .53987 Metetra
.565 .439 .866 r
.31896 .53987 .33822 .54545 .36782 .53409 .34887 .52856 Metetra
.536 .429 .888 r
.34887 .52856 .36782 .53409 .39776 .5216 .37915 .51549 Metetra
.502 .405 .907 r
.37915 .51549 .39776 .5216 .428 .50791 .4098 .49964 Metetra
.513 .381 .884 r
.4098 .49964 .428 .50791 .45852 .49369 .44072 .48254 Metetra
.562 .368 .833 r
.44072 .48254 .45852 .49369 .48929 .47994 .47183 .46679 Metetra
.607 .365 .79 r
.47183 .46679 .48929 .47994 .52033 .46726 .50317 .45296 Metetra
.644 .367 .759 r
.50317 .45296 .52033 .46726 .55169 .45584 .53481 .44094 Metetra
0 0 .847 r
.53481 .44094 .55169 .45584 .58535 .55443 .56811 .5319 Metetra
.673 .315 .666 r
.56811 .5319 .58535 .55443 .61847 .54298 .60145 .51979 Metetra
.647 .306 .679 r
.60145 .51979 .61847 .54298 .65191 .52991 .63509 .50548 Metetra
.622 .294 .685 r
.63509 .50548 .65191 .52991 .68562 .51543 .66896 .48884 Metetra
.608 .28 .677 r
.66896 .48884 .68562 .51543 .71962 .50017 .70304 .4705 Metetra
.626 .27 .643 r
.70304 .4705 .71962 .50017 .75395 .48521 .73744 .45321 Metetra
.657 .267 .607 r
.73744 .45321 .75395 .48521 .78871 .47128 .77235 .4386 Metetra
.675 .268 .591 r
.77235 .4386 .78871 .47128 .82392 .45831 .80776 .42561 Metetra
.683 .271 .587 r
.80776 .42561 .82392 .45831 .8596 .44595 .84365 .4133 Metetra
.688 .273 .586 r
.84365 .4133 .8596 .44595 .89574 .43392 .88001 .40127 Metetra
.597 .449 .839 r
.23984 .55442 .26021 .56019 .28941 .55028 .26931 .54478 Metetra
.587 .451 .846 r
.26931 .54478 .28941 .55028 .31896 .53987 .29912 .53485 Metetra
.568 .454 .859 r
.29912 .53485 .31896 .53987 .34887 .52856 .32929 .52441 Metetra
.526 .452 .89 r
.32929 .52441 .34887 .52856 .37915 .51549 .35986 .51243 Metetra
.402 .402 .979 r
.35986 .51243 .37915 .51549 .4098 .49964 .39106 .49241 Metetra
.422 .354 .931 r
.39106 .49241 .4098 .49964 .44072 .48254 .42252 .46918 Metetra
.55 .342 .817 r
.42252 .46918 .44072 .48254 .47183 .46679 .45398 .4512 Metetra
.609 .344 .766 r
.45398 .4512 .47183 .46679 .50317 .45296 .48562 .43639 Metetra
.648 .35 .736 r
.48562 .43639 .50317 .45296 .53481 .44094 .51753 .42386 Metetra
0 0 .856 r
.51753 .42386 .53481 .44094 .56811 .5319 .55054 .51086 Metetra
.666 .327 .69 r
.55054 .51086 .56811 .5319 .60145 .51979 .58413 .49821 Metetra
.632 .316 .708 r
.58413 .49821 .60145 .51979 .63509 .50548 .61802 .48285 Metetra
.591 .3 .724 r
.61802 .48285 .63509 .50548 .66896 .48884 .65209 .46383 Metetra
.536 .274 .735 r
.65209 .46383 .66896 .48884 .70304 .4705 .68612 .43901 Metetra
.587 .256 .658 r
.68612 .43901 .70304 .4705 .73744 .45321 .72048 .41735 Metetra
.671 .256 .573 r
.72048 .41735 .73744 .45321 .77235 .4386 .75563 .40383 Metetra
.685 .264 .572 r
.75563 .40383 .77235 .4386 .80776 .42561 .79128 .39165 Metetra
.69 .269 .576 r
.79128 .39165 .80776 .42561 .84365 .4133 .82741 .37975 Metetra
.692 .272 .579 r
.82741 .37975 .84365 .4133 .88001 .40127 .864 .36789 Metetra
.603 .453 .832 r
.2189 .54857 .23984 .55442 .26931 .54478 .24862 .53927 Metetra
.597 .459 .833 r
.24862 .53927 .26931 .54478 .29912 .53485 .27868 .53003 Metetra
.586 .469 .832 r
.27868 .53003 .29912 .53485 .32929 .52441 .30906 .52109 Metetra
.563 .488 .805 r
.30906 .52109 .32929 .52441 .35986 .51243 .33974 .51349 Metetra
.036 0 .028 r
.33974 .51349 .35986 .51243 .39106 .49241 .37044 .51391 Metetra
.37 0 .193 r
.37044 .51391 .39106 .49241 .42252 .46918 .40158 .51757 Metetra
.497 0 .144 r
.40158 .51757 .42252 .46918 .45398 .4512 .43352 .51565 Metetra
.528 0 .129 r
.43352 .51565 .45398 .4512 .48562 .43639 .46605 .5102 Metetra
.542 0 .12 r
.46605 .5102 .48562 .43639 .51753 .42386 .4991 .50207 Metetra
.945 0 0 r
.4991 .50207 .51753 .42386 .55054 .51086 .53237 .39355 Metetra
.659 .142 .356 r
.53237 .39355 .55054 .51086 .58413 .49821 .56529 .38479 Metetra
.669 .145 .351 r
.56529 .38479 .58413 .49821 .61802 .48285 .59871 .37837 Metetra
.686 .151 .346 r
.59871 .37837 .61802 .48285 .65209 .46383 .63275 .37523 Metetra
.723 .166 .336 r
.63275 .37523 .65209 .46383 .68612 .43901 .66762 .37757 Metetra
.743 .202 .389 r
.66762 .37757 .68612 .43901 .72048 .41735 .70305 .37672 Metetra
.712 .247 .514 r
.70305 .37672 .72048 .41735 .75563 .40383 .7386 .36759 Metetra
.702 .263 .552 r
.7386 .36759 .75563 .40383 .79128 .39165 .77454 .35684 Metetra
.699 .269 .566 r
.77454 .35684 .79128 .39165 .82741 .37975 .81091 .34553 Metetra
.698 .273 .574 r
.81091 .34553 .82741 .37975 .864 .36789 .84773 .33389 Metetra
.612 .456 .824 r
.19737 .54247 .2189 .54857 .24862 .53927 .22735 .53344 Metetra
.61 .463 .82 r
.22735 .53344 .24862 .53927 .27868 .53003 .25766 .52472 Metetra
.608 .473 .809 r
.25766 .52472 .27868 .53003 .30906 .52109 .28829 .5167 Metetra
.605 .489 .771 r
.28829 .5167 .30906 .52109 .33974 .51349 .31921 .5103 Metetra
.592 .499 .676 r
.31921 .5103 .33974 .51349 .37044 .51391 .35042 .50662 Metetra
.722 .491 .661 r
.35042 .50662 .37044 .51391 .40158 .51757 .38208 .50406 Metetra
.779 .43 .668 r
.38208 .50406 .40158 .51757 .43352 .51565 .41432 .49989 Metetra
.75 .399 .682 r
.41432 .49989 .43352 .51565 .46605 .5102 .44713 .49344 Metetra
.718 .381 .701 r
.44713 .49344 .46605 .5102 .4991 .50207 .48046 .48481 Metetra
.16 .16 .898 r
.48046 .48481 .4991 .50207 .53237 .39355 .51458 .37124 Metetra
.717 .333 .646 r
.51458 .37124 .53237 .39355 .56529 .38479 .54772 .36196 Metetra
.746 .337 .621 r
.54772 .36196 .56529 .38479 .59871 .37837 .58135 .35454 Metetra
.777 .339 .59 r
.58135 .35454 .59871 .37837 .63275 .37523 .61553 .34913 Metetra
.795 .329 .555 r
.61553 .34913 .63275 .37523 .66762 .37757 .65032 .34515 Metetra
.768 .29 .526 r
.65032 .34515 .66762 .37757 .70305 .37672 .68566 .33993 Metetra
.731 .266 .527 r
.68566 .33993 .70305 .37672 .7386 .36759 .72141 .33183 Metetra
.714 .269 .549 r
.72141 .33183 .7386 .36759 .77454 .35684 .75757 .32187 Metetra
.707 .272 .563 r
.75757 .32187 .77454 .35684 .81091 .34553 .79416 .31093 Metetra
.703 .274 .571 r
.79416 .31093 .81091 .34553 .84773 .33389 .83121 .29943 Metetra
.62 .456 .817 r
.17525 .53598 .19737 .54247 .22735 .53344 .2055 .52707 Metetra
.622 .462 .811 r
.2055 .52707 .22735 .53344 .25766 .52472 .23608 .51851 Metetra
.627 .47 .8 r
.23608 .51851 .25766 .52472 .28829 .5167 .267 .51058 Metetra
.638 .478 .778 r
.267 .51058 .28829 .5167 .31921 .5103 .29826 .50364 Metetra
.662 .482 .749 r
.29826 .50364 .31921 .5103 .35042 .50662 .32989 .49777 Metetra
.707 .468 .73 r
.32989 .49777 .35042 .50662 .38208 .50406 .36197 .49225 Metetra
.73 .44 .72 r
.36197 .49225 .38208 .50406 .41432 .49989 .39456 .48601 Metetra
.722 .414 .721 r
.39456 .48601 .41432 .49989 .44713 .49344 .42769 .47837 Metetra
.702 .397 .73 r
.42769 .47837 .44713 .49344 .48046 .48481 .46132 .4691 Metetra
.156 .156 .907 r
.46132 .4691 .48046 .48481 .51458 .37124 .49642 .34661 Metetra
.712 .319 .631 r
.49642 .34661 .51458 .37124 .54772 .36196 .52978 .33668 Metetra
.732 .321 .613 r
.52978 .33668 .54772 .36196 .58135 .35454 .56359 .32804 Metetra
.749 .318 .592 r
.56359 .32804 .58135 .35454 .61553 .34913 .59792 .32052 Metetra
.755 .309 .571 r
.59792 .32052 .61553 .34913 .65032 .34515 .63279 .31351 Metetra
.746 .292 .555 r
.63279 .31351 .65032 .34515 .68566 .33993 .66818 .30596 Metetra
.731 .28 .551 r
.66818 .30596 .68566 .33993 .72141 .33183 .70406 .29714 Metetra
.718 .276 .558 r
.70406 .29714 .72141 .33183 .75757 .32187 .74039 .2871 Metetra
.711 .276 .566 r
.74039 .2871 .75757 .32187 .79416 .31093 .77718 .27618 Metetra
.706 .276 .572 r
.77718 .27618 .79416 .31093 .83121 .29943 .81444 .26464 Metetra
.626 .455 .812 r
.15252 .52903 .17525 .53598 .2055 .52707 .18305 .52006 Metetra
.63 .459 .807 r
.18305 .52006 .2055 .52707 .23608 .51851 .21393 .51138 Metetra
.637 .463 .797 r
.21393 .51138 .23608 .51851 .267 .51058 .24517 .50314 Metetra
.65 .466 .784 r
.24517 .50314 .267 .51058 .29826 .50364 .27678 .49542 Metetra
.668 .464 .77 r
.27678 .49542 .29826 .50364 .32989 .49777 .30879 .48814 Metetra
.689 .455 .757 r
.30879 .48814 .32989 .49777 .36197 .49225 .34126 .4809 Metetra
.7 .439 .75 r
.34126 .4809 .36197 .49225 .39456 .48601 .37422 .47315 Metetra
.698 .422 .748 r
.37422 .47315 .39456 .48601 .42769 .47837 .40769 .46446 Metetra
.686 .409 .753 r
.40769 .46446 .42769 .47837 .46132 .4691 .44165 .45456 Metetra
.15 .15 .913 r
.44165 .45456 .46132 .4691 .49642 .34661 .47793 .32002 Metetra
.708 .308 .621 r
.47793 .32002 .49642 .34661 .52978 .33668 .51148 .30944 Metetra
.721 .309 .608 r
.51148 .30944 .52978 .33668 .56359 .32804 .54549 .29972 Metetra
.731 .307 .594 r
.54549 .29972 .56359 .32804 .59792 .32052 .57997 .29066 Metetra
.735 .301 .58 r
.57997 .29066 .59792 .32052 .63279 .31351 .61497 .28185 Metetra
.732 .292 .57 r
.61497 .28185 .63279 .31351 .66818 .30596 .65048 .27276 Metetra
.725 .285 .566 r
.65048 .27276 .66818 .30596 .70406 .29714 .68649 .26302 Metetra
.718 .281 .567 r
.68649 .26302 .70406 .29714 .74039 .2871 .72299 .25251 Metetra
.712 .279 .57 r
.72299 .25251 .74039 .2871 .77718 .27618 .75997 .24132 Metetra
.707 .279 .574 r
.75997 .24132 .77718 .27618 .81444 .26464 .79742 .22956 Metetra
.63 .453 .81 r
.12916 .52158 .15252 .52903 .18305 .52006 .15998 .51244 Metetra
.635 .455 .805 r
.15998 .51244 .18305 .52006 .21393 .51138 .19118 .50349 Metetra
.642 .457 .798 r
.19118 .50349 .21393 .51138 .24517 .50314 .22275 .4948 Metetra
.652 .457 .789 r
.22275 .4948 .24517 .50314 .27678 .49542 .25471 .48636 Metetra
.664 .454 .78 r
.25471 .48636 .27678 .49542 .30879 .48814 .2871 .47805 Metetra
.675 .447 .773 r
.2871 .47805 .30879 .48814 .34126 .4809 .31994 .46964 Metetra
.681 .437 .768 r
.31994 .46964 .34126 .4809 .37422 .47315 .35327 .46081 Metetra
.68 .426 .767 r
.35327 .46081 .37422 .47315 .40769 .46446 .38709 .45127 Metetra
.673 .416 .77 r
.38709 .45127 .40769 .46446 .44165 .45456 .4214 .44082 Metetra
.144 .144 .916 r
.4214 .44082 .44165 .45456 .47793 .32002 .45909 .29182 Metetra
.704 .301 .614 r
.45909 .29182 .47793 .32002 .51148 .30944 .49285 .28065 Metetra
.713 .302 .605 r
.49285 .28065 .51148 .30944 .54549 .29972 .52704 .27005 Metetra
.72 .3 .595 r
.52704 .27005 .54549 .29972 .57997 .29066 .5617 .25986 Metetra
.723 .296 .586 r
.5617 .25986 .57997 .29066 .61497 .28185 .59686 .2498 Metetra
.723 .291 .578 r
.59686 .2498 .61497 .28185 .65048 .27276 .63251 .2396 Metetra
.719 .287 .574 r
.63251 .2396 .65048 .27276 .68649 .26302 .66868 .229 Metetra
.715 .283 .574 r
.66868 .229 .68649 .26302 .72299 .25251 .70534 .21789 Metetra
.711 .281 .575 r
.70534 .21789 .72299 .25251 .75997 .24132 .74249 .20627 Metetra
.708 .28 .577 r
.74249 .20627 .75997 .24132 .79742 .22956 .78015 .19418 Metetra
.633 .45 .809 r
.10514 .51367 .12916 .52158 .15998 .51244 .13627 .50428 Metetra
.637 .451 .804 r
.13627 .50428 .15998 .51244 .19118 .50349 .16779 .49499 Metetra
.643 .452 .799 r
.16779 .49499 .19118 .50349 .22275 .4948 .1997 .48583 Metetra
.65 .451 .793 r
.1997 .48583 .22275 .4948 .25471 .48636 .23202 .47674 Metetra
.658 .448 .788 r
.23202 .47674 .25471 .48636 .2871 .47805 .26477 .46765 Metetra
.665 .443 .783 r
.26477 .46765 .2871 .47805 .31994 .46964 .29799 .45837 Metetra
.668 .436 .78 r
.29799 .45837 .31994 .46964 .35327 .46081 .33168 .44873 Metetra
.667 .429 .779 r
.33168 .44873 .35327 .46081 .38709 .45127 .36587 .43851 Metetra
.662 .422 .782 r
.36587 .43851 .38709 .45127 .4214 .44082 .40054 .42759 Metetra
.138 .138 .917 r
.40054 .42759 .4214 .44082 .45909 .29182 .43993 .26227 Metetra
.701 .296 .609 r
.43993 .26227 .45909 .29182 .49285 .28065 .47387 .25059 Metetra
.708 .296 .603 r
.47387 .25059 .49285 .28065 .52704 .27005 .50825 .23928 Metetra
.713 .295 .596 r
.50825 .23928 .52704 .27005 .5617 .25986 .54309 .22821 Metetra
.716 .293 .589 r
.54309 .22821 .5617 .25986 .59686 .2498 .57842 .21722 Metetra
.716 .29 .584 r
.57842 .21722 .59686 .2498 .63251 .2396 .61425 .20612 Metetra
.715 .287 .58 r
.61425 .20612 .63251 .2396 .66868 .229 .65057 .19477 Metetra
.712 .285 .579 r
.65057 .19477 .66868 .229 .70534 .21789 .68741 .18305 Metetra
.71 .283 .579 r
.68741 .18305 .70534 .21789 .74249 .20627 .72475 .17093 Metetra
.707 .282 .58 r
.72475 .17093 .74249 .20627 .78015 .19418 .7626 .15843 Metetra
.634 .448 .808 r
.08044 .50532 .10514 .51367 .13627 .50428 .11188 .49563 Metetra
.638 .448 .805 r
.11188 .49563 .13627 .50428 .16779 .49499 .14372 .48598 Metetra
.643 .448 .801 r
.14372 .48598 .16779 .49499 .1997 .48583 .17598 .47636 Metetra
.648 .447 .797 r
.17598 .47636 .1997 .48583 .23202 .47674 .20865 .46672 Metetra
.653 .444 .793 r
.20865 .46672 .23202 .47674 .26477 .46765 .24178 .45698 Metetra
.657 .441 .79 r
.24178 .45698 .26477 .46765 .29799 .45837 .27536 .44703 Metetra
.658 .436 .788 r
.27536 .44703 .29799 .45837 .33168 .44873 .30943 .43673 Metetra
.658 .43 .788 r
.30943 .43673 .33168 .44873 .36587 .43851 .34399 .42596 Metetra
.654 .425 .79 r
.34399 .42596 .36587 .43851 .40054 .42759 .37904 .41462 Metetra
.133 .133 .917 r
.37904 .41462 .40054 .42759 .43993 .26227 .42044 .23159 Metetra
.7 .293 .605 r
.42044 .23159 .43993 .26227 .47387 .25059 .45456 .21945 Metetra
.704 .293 .601 r
.45456 .21945 .47387 .25059 .50825 .23928 .48913 .20753 Metetra
.708 .292 .596 r
.48913 .20753 .50825 .23928 .54309 .22821 .52415 .19576 Metetra
.71 .291 .591 r
.52415 .19576 .54309 .22821 .57842 .21722 .55966 .18402 Metetra
.711 .289 .587 r
.55966 .18402 .57842 .21722 .61425 .20612 .59566 .17218 Metetra
.711 .287 .584 r
.59566 .17218 .61425 .20612 .65057 .19477 .63216 .16015 Metetra
.71 .285 .582 r
.63216 .16015 .65057 .19477 .68741 .18305 .66918 .14784 Metetra
.708 .284 .582 r
.66918 .14784 .68741 .18305 .72475 .17093 .70671 .13521 Metetra
.706 .283 .582 r
.70671 .13521 .72475 .17093 .7626 .15843 .74475 .12225 Metetra
.635 .446 .808 r
.05501 .49656 .08044 .50532 .11188 .49563 .08678 .48656 Metetra
.638 .446 .806 r
.08678 .48656 .11188 .49563 .14372 .48598 .11895 .47654 Metetra
.641 .446 .803 r
.11895 .47654 .14372 .48598 .17598 .47636 .15155 .46648 Metetra
.645 .444 .8 r
.15155 .46648 .17598 .47636 .20865 .46672 .18459 .45634 Metetra
.648 .442 .797 r
.18459 .45634 .20865 .46672 .24178 .45698 .21808 .44606 Metetra
.651 .439 .795 r
.21808 .44606 .24178 .45698 .27536 .44703 .25204 .43554 Metetra
.652 .435 .794 r
.25204 .43554 .27536 .44703 .30943 .43673 .28649 .42471 Metetra
.651 .432 .795 r
.28649 .42471 .30943 .43673 .34399 .42596 .32143 .41347 Metetra
.648 .428 .797 r
.32143 .41347 .34399 .42596 .37904 .41462 .35687 .40174 Metetra
.128 .128 .916 r
.35687 .40174 .37904 .41462 .42044 .23159 .40061 .19991 Metetra
.698 .29 .603 r
.40061 .19991 .42044 .23159 .45456 .21945 .43491 .18735 Metetra
.702 .29 .599 r
.43491 .18735 .45456 .21945 .48913 .20753 .46966 .17491 Metetra
.705 .29 .596 r
.46966 .17491 .48913 .20753 .52415 .19576 .50487 .16254 Metetra
.707 .289 .592 r
.50487 .16254 .52415 .19576 .55966 .18402 .54056 .15016 Metetra
.708 .288 .589 r
.54056 .15016 .55966 .18402 .59566 .17218 .57675 .13768 Metetra
.708 .286 .587 r
.57675 .13768 .59566 .17218 .63216 .16015 .61343 .12504 Metetra
.707 .285 .585 r
.61343 .12504 .63216 .16015 .66918 .14784 .65064 .11216 Metetra
.706 .284 .584 r
.65064 .11216 .66918 .14784 .70671 .13521 .68836 .09902 Metetra
.705 .283 .584 r
.68836 .09902 .70671 .13521 .74475 .12225 .72661 .08559 Metetra
.635 .445 .809 r
.02883 .48742 .05501 .49656 .08678 .48656 .06092 .4771 Metetra
.637 .444 .807 r
.06092 .4771 .08678 .48656 .11895 .47654 .09343 .46672 Metetra
.64 .444 .805 r
.09343 .46672 .11895 .47654 .15155 .46648 .12638 .45625 Metetra
.642 .442 .802 r
.12638 .45625 .15155 .46648 .18459 .45634 .15978 .44565 Metetra
.644 .441 .801 r
.15978 .44565 .18459 .45634 .21808 .44606 .19364 .43489 Metetra
.646 .438 .799 r
.19364 .43489 .21808 .44606 .25204 .43554 .22798 .42389 Metetra
.646 .436 .799 r
.22798 .42389 .25204 .43554 .28649 .42471 .26281 .41258 Metetra
.645 .433 .8 r
.26281 .41258 .28649 .42471 .32143 .41347 .29814 .40092 Metetra
.643 .43 .801 r
.29814 .40092 .32143 .41347 .35687 .40174 .33398 .38884 Metetra
.123 .123 .914 r
.33398 .38884 .35687 .40174 .40061 .19991 .38043 .16735 Metetra
.698 .288 .601 r
.38043 .16735 .40061 .19991 .43491 .18735 .41492 .15438 Metetra
.7 .289 .598 r
.41492 .15438 .43491 .18735 .46966 .17491 .44985 .14147 Metetra
.702 .288 .595 r
.44985 .14147 .46966 .17491 .50487 .16254 .48524 .12856 Metetra
.704 .288 .593 r
.48524 .12856 .50487 .16254 .54056 .15016 .52112 .11561 Metetra
.705 .287 .59 r
.52112 .11561 .54056 .15016 .57675 .13768 .55749 .10256 Metetra
.705 .286 .588 r
.55749 .10256 .57675 .13768 .61343 .12504 .59437 .08935 Metetra
.705 .285 .587 r
.59437 .08935 .61343 .12504 .65064 .11216 .63177 .07594 Metetra
.705 .284 .586 r
.63177 .07594 .65064 .11216 .68836 .09902 .66969 .06229 Metetra
.704 .283 .586 r
.66969 .06229 .68836 .09902 .72661 .08559 .70814 .04837 Metetra
.634 .443 .809 r
.00186 .47791 .02883 .48742 .06092 .4771 .03428 .46727 Metetra
.636 .443 .808 r
.03428 .46727 .06092 .4771 .09343 .46672 .06713 .45653 Metetra
.638 .442 .806 r
.06713 .45653 .09343 .46672 .12638 .45625 .10043 .44566 Metetra
.64 .441 .805 r
.10043 .44566 .12638 .45625 .15978 .44565 .13419 .43465 Metetra
.641 .44 .803 r
.13419 .43465 .15978 .44565 .19364 .43489 .16843 .42345 Metetra
.642 .438 .803 r
.16843 .42345 .19364 .43489 .22798 .42389 .20315 .41201 Metetra
.642 .436 .803 r
.20315 .41201 .22798 .42389 .26281 .41258 .23837 .40029 Metetra
.641 .434 .803 r
.23837 .40029 .26281 .41258 .29814 .40092 .27411 .38823 Metetra
.64 .432 .804 r
.27411 .38823 .29814 .40092 .33398 .38884 .31036 .3758 Metetra
.119 .119 .913 r
.31036 .3758 .33398 .38884 .38043 .16735 .35991 .13395 Metetra
.697 .287 .599 r
.35991 .13395 .38043 .16735 .41492 .15438 .39457 .12059 Metetra
.699 .287 .597 r
.39457 .12059 .41492 .15438 .44985 .14147 .42968 .10723 Metetra
.701 .287 .595 r
.42968 .10723 .44985 .14147 .48524 .12856 .46527 .09384 Metetra
.702 .287 .593 r
.46527 .09384 .48524 .12856 .52112 .11561 .50133 .08037 Metetra
.703 .286 .591 r
.50133 .08037 .52112 .11561 .55749 .10256 .53789 .06679 Metetra
.704 .286 .59 r
.53789 .06679 .55749 .10256 .59437 .08935 .57497 .05305 Metetra
.704 .285 .588 r
.57497 .05305 .59437 .08935 .63177 .07594 .61256 .03911 Metetra
.703 .284 .588 r
.61256 .03911 .63177 .07594 .66969 .06229 .65069 .02496 Metetra
.703 .283 .587 r
.65069 .02496 .66969 .06229 .70814 .04837 .68935 .01056 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -71.5625 -10.7688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -71.1397 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -67.576 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -67.0431 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -66.8915 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[79]:=",
  FormatType->StandardForm,
  ImageSize->{180, 145.938},
  ImageMargins->{{102, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002d0000TA000`40O003h00O]7oo002dOol00;Ao
o`00MWoo0P00?7oo001gOol00`00Oomoo`0jOol007Qoo`03001oogoo03Uoo`00Mgoo0P001Woo1@00
<7oo0023Ool00`00Oomoo`0^Ool008Aoo`03001oogoo02eoo`00NWoo0P001goo0P00;goo001gOol3
00000goo001oo`0gOol007Eoo`80009oo`@003Moo`00LWoo1`000UTb00<007oo0000=Woo001_Ool3
000017oo000000001ETb1000=Goo001]Ool300001Goo000005Tb00001UTb1000=Goo001IOol00`00
Oomoo`0>Ool30002Ool20004FC800`00FC9I<P03FC801@00FC8007oo0000=7oo001IOol00`00Oomo
o`0<Ool20003Ool20006FC800`00FC9I<P03FC801@00FC8007oo0000=7oo001IOol00`00Oomoo`09
Ool300000goo0000000200000eTb001I<P06FC800`00FC9I<P02FC8400000goo001oo`0bOol005Uo
o`03001oogoo00Ioo`<0009oo`<000EI<P03001I<UTb00AI<P03001I<UTb00<0009I<P04001oo`00
000bOol0061oo`800003Ool0000000800003FC8005Tb00EI<P03001I<UTb00AI<P<0009I<P07001I
<UTbFC8007oo0000<Woo001MOol3000017oo000000001ETb00<005TbFC8015Tb00@005TbFC9I<P80
0003FC8005Tb00=I<P04001I<UTb0002Ool00`00Oomoo`0_Ool005]oo`H00003FC8005Tb00EI<P03
001I<UTb00AI<P04001I<P000004FC801@00FC9I<UTb00000eTb00<007oo0000<Goo001HOol70004
FC800`00FC9I<P04FC800`00FC9I<P03FC820007FC801000FC9I<P000eTb00@007oo0000031oo`00
EGoo1P0000=I<P00FC801ETb00<005TbFC8015Tb00<005TbFC800`0000=I<P00FC801UTb00@005Tb
FC8000=I<P80009oo`03001oogoo02eoo`00Dgoo0P000Woo0P0015Tb00<005TbFC8015Tb00<005Tb
FC800eTb0`001ETb00<005TbFC801ETb00<005Tb00000`0000EI<P00Oomoo`0002moo`00D7oo0`00
0Woo0P001UTb00<005TbFC8015Tb00<005TbFC800`0000=I<P00FC801ETb00<005TbFC801ETb0`00
1ETb00@007ooOol002ioo`00>goo0P004Goo0P000Woo0`0000=I<`00FC801UTb00<005TbFC800eTb
0`001ETb00<005TbFC8015Tb00@005TbFC9I<P<00003FC80000000EI<P03001oogoo008002eoo`00
>goo00<007oo00003Goo0`0000Aoo`00000000EI<`03001I<UTb00AI<P03001I<UTb00<00003FC80
05Tb00EI<P03001I<UTb00AI<P04001I<P000005FC800`00FC9I<P04FC801000Oomoo`001Goo0`00
0Woo00<007ooOol087oo000kOol00`00Ool0000:Ool300001Woo00000000FC<000MI<`03001I<UTb
00=I<P<000EI<P03001I<UTb00AI<P03001I<UTb00=I<P8000MI<P03001I<UTb00AI<P05001oogoo
Ool00009Ool00`00Oomoo`0POol003aoo`8000Qoo`800004Ool000000005FC<00`00FC=I<`04FC<0
0`00FC9I<P0300000eTb001I<P05FC800`00FC9I<P04FC800`00FC9I<P0300000eTb001I<P06FC82
0005FC820003Ool00`00Oomoo`06Ool00`00Oomoo`0POol004=oo`H00003FC<005Tc00EI<`03001I
<eTc00AI<`<000EI<P03001I<UTb00AI<P03001I<UTb00=I<P<000EI<P03001I<UTb00AI<P8000=I
<P800004FC8007ooOol20008Ool00`00Oomoo`0POol0045oo`800003Ool0000000EI<`03001I<eTc
00AI<`04001I<eTcFC<200000eTc001I<P05FC800`00FC9I<P04FC800`00FC9I<P0300000eTb001I
<P05FC800`00FC9I<P04FC8200000eTb00000004FC801@00Oomoogoo0000:Woo000nOol500000goo
001I<`05FC<00`00FC=I<`04FC<01000FC<0000015Tc00<005TbFC8015Tb00<005TbFC800eTb0`00
1ETb00<005TbFC8015Tb00<005TbFC800eTb0`001UTb00<007ooOol00Woo00<007ooOol09goo000k
Ool30006Ool20006FC<00`00FC=I<`03FC<20006FC<00`00FC9I<P04FC800`00FC9I<P0300000eTb
001I<P05FC800`00FC9I<P04FC800`00FC9I<P0400000eTb001I<P06FC801@00Oomoogoo0000:Goo
000iOol200000goo001oo`05Ool00`0037d00006FC<00`00FC=I<`0300000eTc001I<`06FC<00`00
FC9I<P03FC830005FC800`00FC9I<P04FC800`00FC9I<P03FC830003FC801000FC9I<P001UTb00@0
07ooOomoo`8002Qoo`00=Woo0`002Woo00@000am37d000EI<`<000EI<`03001I<eTc00AI<`03001I
<UTb00<00003FC8005Tb00EI<P03001I<UTb00AI<P03001I<UTb00<00003FC8005Tb00=I<P05001I
<UTbFC800005FC820004Ool00`00Oomoo`0UOol001eoo`<0009oo`03001oogoo00moo`800003Ool0
07oo00Yoo`04000<O@am0002FC<300000eTc001I<`06FC<00`00FC=I<`03FC<30005FC800`00FC9I
<P04FC800`00FC9I<P03FC830005FC801@00FC9I<UTb00000eTb00<005TbFC800`0000=I<P00Ool0
0goo00<007ooOol09Goo000ROol00`00Oomoo`0<Ool3000?Ool0100037d<O@am0P001ETc00<005Tc
FC<015Tc00<005TcFC<00`0000=I<`00FC801ETb00<005TbFC8015Tb00<005TbFC800`0000=I<P00
FC801UTb00@005TbFC80009I<P@000EI<P03001oogoo009oo`03001oogoo02Aoo`008Woo00<007oo
Ool02Goo1@0047oo00D000am37d<O@0000MI<`03001I<eTc00=I<`<000EI<`03001I<UTb00AI<P03
001I<UTb00=I<P<000EI<P03001I<UTb00AI<P03001I<UTb00<0009I<P03001I<UTb00AI<P03001o
ogoo009oo`03001oogoo02Aoo`008Woo00<007ooOol01goo0P0057oo00<000am37d00Pam0P001UTc
00<005TcFC<00`0000=I<`00FC<01ETc00<005TbFC8015Tb00<005TbFC800`0000=I<P00FC801UTb
00<005TbFC800eTb10001ETb00<005TbFC8015Tb00<007ooOol00Woo00<007ooOol08goo000YOol5
000DOol00`0037d<O@0237d00`0037d00005FC<30005FC<00`00FC=I<`04FC<00`00FC9I<P03FC83
0005FC800`00FC9I<P04FC800`00FC9I<P03000015Tb001I<P001ETb00<005TbFC8015Tb00<007oo
Ool00goo00<007ooOol08Woo000WOol2000IOol01@0037d<O@am00000`am00<005Tc00000P0000=I
<`00FC<01ETc00<005TcFC<015Tc00<005TbFC800`0000=I<P00FC801UTb00<005TbFC800eTb0`00
1ETb00<005Tb00001ETb00<005TbFC800eTb0P0017oo0P008goo000TOol4000JOol01@0037d<O@am
000010am00<005TcFC<00eTc00<005TcFC<015Tc00<005TcFC<00eTc0`001ETb00<005TbFC8015Tb
00<005TbFC800`0000=I<P00FC801ETb00<005Tb00001ETb00<005TbFC800`0000=I4P00Ool00goo
0P008goo000QOol30004Ool00`00Oomoo`0GOol01@0037d<O@am000010am00<005TcFC<015Tc00<0
05TcFC<00eTc00<005TcFC<00`0000=I<`00FC801UTb00<005TbFC800eTb0`001ETb00<005TbFC80
15Tb0P0015Tb10001ETB00<007ooOol00goo00<007ooOol087oo000OOol200000goo001oo`0MOol0
0`0037d<O@0237d00`0037d<O@0237d20005FC<00`00FC=I<`03FC<30005FC<00`00FC9I<P04FC80
0`00FC9I<P0300000eTb001I<P05FC800`00FC9I<P04FC82000015Tb000000000UTB00<005TBFA80
15TB00<007ooOol00goo00<007ooOol087oo000LOol3000ROol00`0037d<O@0237d01`0037d<O@am
000@W@0000II<`03001I<`0000800003FC<005Tc00II<`03001I<UTb00=I<P<000EI<P03001I<UTb
00AI<P03001I<UTb00=I<P<000II4P03001I4UTB00AI4P03001oogoo00=oo`03001oogoo01moo`00
17oo0`0000=oo`00000047oo0P0000=oo`00Ool08Woo00D000am37d<O@0000@<O@04000@WA2M0005
FC<20005FC<00`00FC=I<`04FC<00`00FC9I<P0300000eTb001I<P05FC800`00FC9I<P04FC800`00
FC9I<P0300000eTb001I4P06FA800`00FA9I4P04FA800`00Oomoo`04Ool00`00Oomoo`03Ool2000I
Ool000Uoo`03001oogoo00]oo`<002Moo`05000<O@am37d0000437d0100049d@W@000UTc0`0000=I
<`00FC<01ETc00<005TcFC<00eTc0`001ETb00<005TbFC8015Tb00<005TbFC800eTb0`0015Tb0P00
1UTB00<005TBFA800eTB0`001Goo00<007ooOol00goo00<007oo000067oo000:Ool00`00Oomoo`07
Ool300000goo0000000WOol01@0037d<O@am000010am00@0012M49d@W@8000EI<`03001I<eTc00AI
<`03001I<`0000800003FC<005Tb00EI<P03001I<UTb00AI<P03001I<UTb00<00003GC8005Tb00AI
<P8000MI4P03001I4P000080009I4P03001oogoo00Aoo`03001oogoo009oo`03001oo`0001Qoo`00
2Goo0P001goo0P00;7oo00<000am37d00Pam00<000am37d00Pam00D0012M49d@W@0000MI<`03001I
<eTc00=I<`8000EI<`03001I<UTb00AI<P03001I<UTb00=I<P<000EM<P03001I<UTb009I<P03001I
<P0000EI4P<000II4P03001oogoo009oo`<000Aoo`8001Qoo`003goo0`0000=oo`000000:goo00<0
00am37d00Pam00D000am37d<O@0000@@W@8000II<`03001I<eTc00<00003FC<005Tc00EI<`03001I
<UTb00=I<P03001I<UTb00<00003GC8005db00EM<P04001I<UTbFC82000015Tb001I4UTB0`0000=I
4P00FA801UTB00<007ooOol017oo00<007ooOol077oo000>Ool2000`Ool01@0037d<O@am000010am
00D0012M49d@W@00008@W@03001I<eTc00=I<`<000EI<`03001I<eTc00AI<`04001I<UTbFC840005
GC800`00GC9M<P04GC8300000eTb001I<P030005FA800`00FA9I4P05FA800`00Oomoo`04Ool00`00
Oomoo`0KOol000ioo`<002moo`05000<O@am37d0000437d01@0049d@WA2M00000Q2M00<005TcFC<0
0`0000=I<`00FC<01UTc00<005TcFC<00eTc10000Udb00<005dbGC801Edb00<005dbGC8010000UTb
0`0000=I4P00FA801ETB00<005TBFA801ETB00<007ooOol017oo0P0077oo000>Ool01000Oomoo`00
;Woo00D000am37d<O@0000@<O@05000@WA2M49d0000349d20005FC<00`00FC=I<`04FC<00`00FC=I
<`0300000edc001M<P04GC800`00GC9M<P04GC8300000edb000000030003FA800`00FA800006FA80
0`00FA9I4P03FA830006Ool00`00Oomoo`0JOol000ioo`80009oo`03001oogoo02Yoo`03000<O@am
008<O@03000<O@am008<O@05000@WA2M49d0000349d00`00FC=I<`05FC<00`00FC=I<`03FC<30005
GC<00`00GC9M<P03GC800`00GC9M<P070003GC800`00FA9I4P03FA820006FA800`00FA9I4P030002
FA800`00Oomoo`05Ool00`00Oomoo`0IOol000eoo`8000Aoo`03001oogoo02Uoo`03000<O@am008<
O@05000<O@am37d0000349d00`0049d@W@0249d20006FC<00`00FC=I<`0300000eTc001M<`06GC<0
0`00GC9M<P02GC8600000edb001M<P05GC800`00FA9I4P02FA800`00FA800005FA830006FA800`00
Oomoo`04Ool2000JOol000=oo`<00003Ool0000000Aoo`8000Eoo`03001oogoo02Qoo`05000<O@am
37d0000437d01@0049d@WA2M00000a2M00@0012M49d000EI<`<000EI<`03001M<edc00AM<`03001M
<P0000D000EM<P03001M<Udb00AM<P03001I4UTB009I4P80009I4P<00003FA8005TB00II4P03001o
ogoo00Aoo`8001Yoo`0027oo00<007ooOol00Woo0P001Woo00<007ooOol09goo00D000am37d<O@00
00@<O@05000@WA2M49d0000349d0100049d@W@000UTc0`0000=I<`00FC<01UTc00<005dcGC<00Udc
1@000Udb00<005dbGC8015db00<005dbGC8015db00@005TBFA9I4PD000EI4P03001I4UTB00AI4P03
001oogoo00Ioo`03001oogoo01Moo`002Goo00D007ooOomoo`0000Qoo`03001oogoo02Ioo`05000<
O@am37d0000437d01@0049d@WA2M00000a2M00@0012M49d@W@8000EI<`03001I<eTc00AI<`03001M
<`0000<00003GC<005db00AM<P03001M<Udb00AM<P03001M<Udb00=M<P@0009I4@8000II4P03001I
4UTB00EI4P03001oogoo00Eoo`03001oogoo01Moo`0027oo0P000goo0P0027oo00<007ooOol097oo
00<000am37d00Pam00<000am37d00Pam00D0012M49d@W@0000<@W@04000@WA2M49d20006FC<01000
FC=I<eTc1@001Edc00<005dbGC800edb00<005dbGC800edb00<005dbGC800`0000=M4@00FA4015TA
0P001UTB00<005TBFA800eTB0P0027oo00<007ooOol05Woo000=Ool20009Ool00`00Oomoo`0SOol0
0`0037d<O@0237d01@0037d<O@am00000a2M00<0012M49d00Q2M00L0012M49d@W@0049d00005FC<5
0002GC<00`00GC=M<`05GC<00`00GC9M<P02GC801000GC9M<Udb1@001EdA00<005TAFA400eTA00<0
05TBFA8015TB00<005TBFA800`0000=I4P00Ool027oo00<007ooOol05Goo000=Ool00`00Oomoo`09
Ool00`00Oomoo`0ROol00`0037d<O@0237d01@0037d<O@am00000a2M00D0012M49d@W@0000<@W@06
000@WA2M49d005Tc1@001Udc00<005dcGC<015dc00@005dbGC9M<PD000=M<@03001M4EdA00AM4@03
001I4ETA00AI4@03001I4UTB00=I4P<000EI4P03001oogoo00Ioo`03001oogoo01Eoo`0037oo0`00
2goo00<007ooOol08Goo00D000am37d<O@0000@<O@05000@WA2M49d0000349d01@0049d@WA2M0000
112M0`000eTc00<005dcGC<015dc00<005dcGC<00edc10000V4b00<005daGC4015da00<005dAGA40
15dA00<005TAFA400eTA00<005TBFA800`0000=I4P00FA801ETB00<007ooOol01goo00<007ooOol0
57oo000<Ool2000=Ool00`00Oomoo`0POol01@0037d<O@am000010am00D0012M49d@W@0000<@W@05
000@WA2M49d0000249d30006FC<00`00GC=M<`03GC<00`00GC=M<`0300000eeB001Q<P04HC800`00
GC5M<@03GC400`00GA5M4@04GA401000FA5I4ETA1@001ETB00<005TBFA8015TB00<007ooOol01goo
00<007ooOol00goo00<007ooOol03Goo0002Ool30002Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool0
0`00Oomoo`0NOol00`0037d<O@0237d00`0037d<O@0237d0100049d@W@00112M00@0012M49d@W@<0
008@W@8000EI<`04001M<edcGC<50005GE800`00HC9Q<P03HC800`00GC5M<@03GC400`00GA5M4@03
GA440003FA420006FA800`00FA9I4P03FA800`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0=
Ool000Moo`03001oogoo009oo`8000moo`8001ioo`03000<O@am008<O@05000<O@am37d0000349d0
1P0049d@WA2M000@W@<000@@W@04000@WA2M0004FC<40003GE<00`00GE9MDP04GE800`00HC9Q<P03
HC800`00GC5M<@03GC400`00GA5M4@0300000ed@001I4@05FA400`00FA9I4P04FA801000FA9I4UTB
10002Goo00<007ooOol00Woo00<007ooOol03Goo0007Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool0
0`00Oomoo`0KOol00`0037d<O@0237d01@0037d<O@am00000a2M00<0012M49d00`000Q2M00<0012M
49d00Q2M00D0012M49d005Tc00<00003FE@005eC00EMD`03001MDUeB00=MDP04001Q<V4bHC8;0005
GA000`00FA5I4@04FA400`00FA9I4P03FA840003FA800`00Oomoo`06Ool00`00Ool00003Ool00`00
Oomoo`0=Ool000Moo`03001oogoo009oo`80019oo`03001oogoo01Yoo`05000<O@am37d0000437d0
100049d@WA2M0`0000<@W@0049d00Q2M00<0012M49d00Q2M00D0012M49d@W@0000EIE003001MDeeC
00AMD`04001MDUeBGE850003IE400`00HC1Q<003HC000`00GA1M4004GA000`00FA5I4@04FA420000
1UTB00000000FA8000II4P03001oogoo00Moo`03001oogoo015oo`002goo0P0057oo00<007ooOol0
6Goo00D000am37d<O@0000@<O@@000@@W@05000@WA2M49d0000449d01@0049d@WA2M00001UUD00@0
05eCGE=MD`H0009QDP03001UDFEA00AUD@03001Q<64`00=Q<003001M45d@00AM4003001I4ETA00=I
4@<000EI4P03001I4UTB00AI4P03001oogoo00Moo`03001oogoo011oo`002goo0P005Goo00<007oo
Ool05goo00<000am37d00Pam00<000am37d00`000Q2M00<0012M49d00Q2M00@0012M49d000@@W@03
000@WA2M008@W@8000EIE0@000=MD`03001QDV5B00=QDP03001UDFEA00=UD@03001Q<64`00=Q<003
001M45d@00AM4003001I4ETA00<00003FA40000000EI4P03001I4UTB00AI4P03001oogoo00Moo`80
015oo`002goo0P005Woo00<007ooOol05Woo00<000am37d00Pam0`0000<<O@0049d00Q2M00D0012M
49d@W@0000<@W@03000@WA2M008@W@05000@WA2M49d0000249d00`00FE@0000200000eUD001MD`05
GE<00`00HE9QDP03HE800`00IE5UD@03IE400`00HC1Q<003HC000`00GA1M4003GA030005FA420005
FA800`00FA9I4P03FA820009Ool00`00Oomoo`0?Ool000]oo`03001oogoo01Ioo`03001oogoo01Ao
o`L000<<O@05000@WA2M49d0000349d01@0049d@WA2M0000112M00D0012M49d@W@0000<@W@03001I
E5UD00=IE003001MDeeC00AMD`04001QDV5BHE8600000fEA001Q<004HC000`00GA1M400300000eS`
001I4@05FA400`00FA800004FA800`00FA9I4P0300000eTB001oo`09Ool00`00Oomoo`0>Ool000Ao
o`8000Eoo`8001Qoo`03001oogoo015oo`H0000337d000am00<<O@05000@WA2M49d0000349d01@00
49d@WA2M0000112M00D0012M49d@W@0000<@W@8000EIE004001MDeeCGE<60002E8/01000G:YLZUbZ
2P001ES`00<005TAFA4015TA0P0015TB0`001ETB00<007ooOol01goo00<007ooOol03Woo0004Ool0
0`00Ool00004Ool00`00Oomoo`0HOol00`00Oomoo`0>Ool40004DKT2000437d0100049d@W@00112M
00@0012M49d000@@W@05000@WA2M49d0000449d00`005;`00003FE@50003E8/00`00E8]DR`02E8/0
0`00G:YLZP03G:X00`00G<aLc003G<`00`00F?1Hl004F?000`00FA5I4@04FA400`00FA8000030000
0eTB001I4P05FA800`00Oomoo`08Ool00`00Oomoo`0=Ool000Aoo`03001oo`0000Aoo`03001oogoo
01Uoo`03001oogoo00]oo`<000MA^@<000<<O@04000@WA2M000349d01@0049d@WA2M0000112M00D0
012M49d@W@0000<@W@04000D_1Bl5;`30002E8/00`00E8]DR`03E8/00`00E8]DR`03E8/00`00G:YL
ZP02G:X00`00G<aLc004G<`00`00F?1Hl004F?000`00FA5I4@03FA440004FA800`00FA9I4P03FA80
0`00Oomoo`09Ool00`00Oomoo`0<Ool000Eoo`8000=oo`8001aoo`03001oogoo00Moo`<000=A^@80
009A^@<000=A^@<000<@W@05000@WA2M49d0000349d00`0049d@W@0249d01@0049d@WA2M00000a2M
00D001Bl5;`D_00000ADR`03001DReB;00=DR`03001DReB;00=DR`03001LZUbZ00=LZP03001Lc5c<
00=Lc003001Hl5S`00AHl003001I4ETA00<00005EA8005TBFA800003FA800`00FA9I4P04FA800`00
Oomoo`08Ool00`00Oomoo`0<Ool000Yoo`03001oogoo01aoo`03001oogoo00=oo`<000MA^@<000MA
^@<0008@W@05000@WA2M49d0000349d01@0049d@WA2M00000a2M00<0012M49d00Q2M00<001Bl5;`0
0P0015B;00<005B;E8/015B;00<005B;E8/00UB;00<005bZG:X00ebZ00<005c<G<`015c<00<005S`
F?000eS`0`001EDB00<005TB00000eTB00<005TBFA800eTB0P002goo00<007ooOol02goo000:Ool2
000NOol00`00Ool000020003DKT20002DKT30003DKT20002DKT30003DKT2000449d0100049d@W@00
112M00D0012M49d@W@0000<@W@04000D_1Bl5;`20005E8/00`00E8]DR`03E8/00`00E8]DR`02E8/0
0`00G:YLZP03G:X00`00G<aLc004G<`00`00F?1Hl00300000eDB001E4P05EA801000FA9I4P000eTB
00<005TB00000P0000=I4P00Ool02goo00<007ooOol02Woo000:Ool2000KOol60004DKT50007DKT3
0006DKT3000349d0100049d@W@00112M00D0012M49d@W@0000<@W@07000D_1Bl5;`007P0000015B;
00<005B;E8/00eB;00<005B;E8/00eB;00<005bZG:X00ebZ00<005c<G<`00ec<0`001EDB00<005DB
EA800eDB00H005TBFA9I4P00FA830005FA800`00Oomoo`09Ool00`00Oomoo`03Ool20005Ool000Yo
o`03001oogoo01Ioo`L000=Af@@000EA^@80009A^@<000=A^@03001A^E6i00<000=A^@<000<@W@03
000@WA2M008@W@05000@WA2M49d0000349d010005;`D_0000WP000<005B;E8/00UB;00<005B;E8/0
0eB;00<005B;E8/00eB;00<005bZG:X00ebZ00<005c<G<`00Uc<00<004TE00001UDB00<005DBEA80
15DB00<005TB00000P0000=E4P00FA801UTB00<007ooOol02Goo00<007ooOol00goo00<007ooOol0
0goo0004Ool00`00Oomoo`03Ool00`00Oomoo`0COol300000e7I000000020002DMT30003DMT20003
DKT50006DKT30007DKT3000249d01@0049d@WA2M00000a2M00D0012M49d@W@0000<D_004001h07P0
0004E8/00`00E8]DR`03E8/00`00E8]DR`03E8/00`00G:YLZP03G:X00`00G<aLc0020003BAD00`00
EA9E4P04EA800`00EA9E4P02EA830002EA801000EA9E4P001UTB00<007ooOol027oo0`001Goo00<0
07ooOol00Woo0004Ool00`00Oomoo`02Ool00`00Oomoo`0AOol30000157I000000000e7I0`001e7I
10001E6i0P0000AA^@00000000=E^@80009A^@<000=E^@8000@@W@05000@WA2M49d0000349d01@00
5;`D_1Bl00000WP000<005B;E8/00UB;00<005B;E8/015B;00<005B;E8/00eB;00<005bZG:X00ebZ
0P001DTE00<005DBEA8015DB00<005DB00000P0000=E4P00EA800eDB00@005DBEA8000EI4P8000Io
o`<00003Ool0000000Aoo`8000Aoo`0017oo00<007ooOol00Woo0P003goo0`0000=Af@0000000`00
00AAf@00000000=Af@80009Af@<000=Af@8000=A^@D000IE^@<000IE^@<000<@W@05000@WA2M49d0
000349d00`005;`D_0020002N0000`00E8]DR`02E8/00`00E8]DR`04E8/00`00E8]DR`03E8/00`00
G:YLZP02G:X20007BAD00`00EA9E4P03EA820005EA800`00EA9E4P02EA800`00EA800002FA830000
0eDB001oo`02Ool30005Ool00`00Oomoo`08Ool000Aoo`03001oogoo009oo`03001oogoo00aoo`H0
00AAf@<000IAf@<000MAf@@000EE^@03001E^EFi00<000=E^0800004EKT000000003EKP0100049d@
W@000Q2M00D0012M49d@W@0000<D_080009h0003001DReB;00=DR`03001DReB;00=DR`03001DReB;
00=DR`07001LZUbZG:X004DG00001dTE00<005DBEA800`0000=E4`00EA801EDB00H005DBEA9E4P00
EA830005EA830008Ool00`00Oomoo`08Ool000Uoo`8000Yoo`P0009Af@<000=Af@800004DMT00000
0003DMT20002DMT30003EMT20003EKT40007EKP30006EKP2000349d01@0049d@WA2M00000aBl00D0
055h001h000000EDR`03001DReB;00=DR`03001DReB;00=DR`04001LZUbZ0003AAL00`00BAE95@04
BAD30005EA<00`00EA9E4P03EA800`00EA9E4P0300000eDC001E4P06EA800`00Oomoo`07Ool00`00
Oomoo`08Ool000Uoo`8000Moo`H000AAf@<000MAf@<000IAf@<000MEf@@000AE^080009E^0<000=E
^004001E^5FhEKP5000249d01@0049d@WA2M00000QBl00@0055hDGP0009h0003001DReB;009DR`03
001DReB;00=DR`03001DReB;00ADR`8000E55`0400195DTEBAD200000e4D001E4`05EA<00`00EA9E
4P03EA830003EA<00`00EA<00006EA800`00Oomoo`08Ool00`00Oomoo`07Ool000Uoo`03001oogoo
00=oo`T00004DMT000000003DMT20002DMT30003DMT20000157I000000000e7I0P000UGI0`000eGI
00@005FhEKQE^0D000IE^0@000EE^08000<@W@04000D_1Bl5;`200001E5h000007P0000015B;00<0
05B;E8/00eB;00<005B;E8/00eB;0P001TDG00@004TE000000AA5003001E4eDC00=E4`03001E4UDB
00<00003EA<005DC00AE4`03001E4`0000EE4P8000Uoo`03001oogoo00Moo`002Goo0P0000=oo`00
000010000e7I1P00157I1@00157I1P00157I1@0015GI1@001EFh00<005FhEKP00`000UVg00<005Fh
EKP015Fh0P000a2M00@001Bl5;`D_0<00004DIP007P00004E8/00`00E8]DR`04E8/00`00E8]DR`02
00000dTg00155`05AAL20006DA@00`00EA=E4`03EA<30005EA<00`00EA=E4`02EA<00`00EA<00002
EA8300000eDC001oo`08Ool00`00Oomoo`07Ool000Qoo`L0009Af@@000IAf@@000EAf@@000IAf@@0
00EEf@@000AEf08000=E^0@000II]`03001E^5Fh00<0009IU`04000@WA2M00025;`20002CIT20000
0gP0001DR`03E8/00`00E8]DR`04E8/30004BCL01000AAM55dDG0P0000==5@00DA@01E4D00@005DC
EA=E4`800003EA<005DC00IE4`03001E4eDC009E4`@000EE4`03001oogoo00Ioo`03001oogoo00Mo
o`000Woo0P0017oo1@0000AAf@00000000=Af@<00004DMT000000003DMT20000157I000000000e7I
0P000U7I0`000e7I0P0000AEf@00000000=Ef08000=Ef0D000AIe`8000=I]`@000IIU`8000<D_004
001=VDfICIT40004E8/00`00E8]DR`03E8/20006BCL01000AAL0000014dE00<0054DDA@0154D0`00
15DC00<005DCEA<015DC00<005DCEA<01@001UDC00<007ooOol01Woo00<007ooOol01goo0003Ool0
0`00Oomoo`02Ool20003Ool20007DMT40004DMT50004DMT50004DMT60003EMP60004FMP01000FMMI
eeWG1P0015fg0P000eVG10000QBl10000TfI0P001EB;00<005B;E8/00P0000=AEP00BCL01DTg0P00
1ddE00<0054DDA@00U4D0P001UDC00<005DCEA<015DC0`000eDC00<005DC00001EDC00<007ooOol0
1Woo00<007ooOol01goo0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20002DMT30004DMT40005
DMT40005DMT40005DMT40005EMP01000FMQIf5WH1@001EgG00@005fgGKMM]`H000AIUPD000==V@80
00EDR`<000AAEP040019=dTgBCL200000dde001=5@06CAD00`00DA@0000200000e4D001E4`06EA<0
1000EA=E4eDC0P0000=E4`00EA<015DC0P001UDC00<007ooOol01Goo00<007ooOol01goo0003Ool2
0006Ool00`00Oomoo`03Ool40002DMT30003DMT20000157I000000000e7I0P0000AAf@00000000=A
f@800004DMT000000003DMT20003EMP50004FML20003GML50004GID00`00FIIIUP03FIH20002CIX4
00000dfI00000003E8/20007DEH00`00BCL00004CCD00`00CAE=5@04CAD20005DA@00`00EA=E4`04
EA<01000EA<0000015DC00<005DCEA<00eDC00<005DCEA<00eDC0P0027oo00<007ooOol01Woo000<
Ool00`00Oomoo`06Ool40004DMT50004DMT50004DMT50004DMT50003EOL;0003HKD00`00GIEMU@04
GID00`00FIH00002000014fJ000000000dfJ00<004fI000010000UEF00<0055FDEH0155F0P001Tde
00@004dECAE=5@800003DC@0054D00EA5003001E4eDC00=E4`8000IE4`03001E4eDC00AE4`03001E
4`0000800003EA<007oo00Moo`03001oogoo00Ioo`003Goo0P002Woo10001E7I1000157I1@000e7I
1P000e7h4000166e00@005fEGIEMU@@00099VP<000E=VP800003DKT005EF00EEEP03001AEU5F00<0
0003DCD004de00E==@04001=5@000004DC@00`00DAAA5003DA@00`00EA=E4`0300000eDC001E4`05
EA<01000EA=E4eDC1@001EDC00<007ooOol01Goo00<007ooOol01Woo000?Ool00`00Oomoo`0:Ool2
0000157I00000000157I1000157I1000157i1@000Tgh1P000d7L3`0000A9VP00000000==^P03001=
VP000080009=^P03001A^@0000EEEP<000EA=@03001==Dde00===@8000IA=003001A554D00=A50<0
00EE4`03001E4eDC00=E4`@000=E4`8000IE4`03001oogoo00Aoo`03001oogoo00Ioo`0047oo00<0
07ooOol02goo0`000U7I0`000e7I00<0057I00000P0014gI100014gi200000A1g000000000=5_0@0
0004AK/000000003BK/30005CKX40002CKX500001UEF00000000EED000MA=@03001==@0000800003
DCD0054d00EA=003001A554D00<00003EA@005DC00IE4`03001E4`0000800003EA<005DC00EE4`80
00EE4`03001oogoo00Aoo`03001oogoo00Ioo`004Goo00<007ooOol03Goo10000e7I1@000TgI0`00
14gJ100000A9nP00000000=9f`@00004AK`000000003AK/4000014Vk000000000dVj00<004fj0000
0P000dfj0`0014fj0P001EEE00<0054eDCD0154e0P001E4e00<0054dDC@00e4d0`001EDD00<005DC
EA<015DC0P001EDC00<005DCEA<015DC0P0015DC0P001Goo00<007ooOol01Woo000BOol00`00Oomo
o`0@Ool30004CMX50002CMX30003CMX4000014WK000000000dWK100000A5^`00000000=9^`@000=9
^PD00004CKX000000002CKX00`00CKX0000200000dfj001EE@05EED00`00DCEA=@0300000eDd001A
=@05DCD00`00DC@0000200000eDd001E5006EA@01000EA=E4eDC0P0000=E4`00EA<01EDC00<005DC
EA<00eDC0P0000IE4`00000005DC0005Ool00`00Oomoo`06Ool001=oo`8001=oo`@000A=fPD00004
CMX000000002BM/5000014WK000000000dVk100000A9^`00000000=9^`@000A=^P<000==^PD00004
CKX000000005EED30005EC@00`00DCEA=@03DCD20005EC@00`00EAAE5004EA@01000EA<0000015DC
00<005DCEA<00eDC00@005DCEA=E4`D000EE4`03001oogoo009oo`03001oogoo00Ioo`005Goo00<0
07ooOol057oo10000dgJ20000dWK1@000TVk0P000dVk100000A9^`00000000==^P03001=^P000080
009=^P@000A=^P<00004CKX005EEEED300000eDd001E=005EC@00`00DCEA=@0300000eDd001E=005
EC@00`00EAAE5003EA@20006EA<00`00EA=E4`03EA<40003EA<00`00EA<00004EA<00`00Oomoo`03
Ool00`00Oomoo`05Ool001Ioo`03001oogoo01Moo`<00004CMX000000004CMX40003BK/500000dVk
00000003BKX40003CKX500000dfj00000003CKX00`00CKX000020002CKX50005EC@00`00ECAE=003
EC@30005EC@00`00ECAE=003EC@00`00EAAE500300000eDc001E4`05EA<00`00EA=E4`0300000eDC
001E4`05EA<20004EA<00`00Oomoo`03Ool00`00Oomoo`05Ool001Moo`03001oogoo01Uoo`<0009=
fP<000==fP@000=9^`@00004BKX000000003CKX40003CKX40003CKX4000014fj000000000goo00<0
05DdEC@01EDd00<005Dd00000P0000=E=000EC@01UDd00<005DdEC@00UDd0`001EDc00<005DCEA<0
0eDC0`001EDC00<005DCEA<00eDC00@005DC001E4`@000Aoo`03001oogoo00Eoo`0067oo0P0077oo
100000A=fP00000000==^P@000==^P@00004CKX000000003CKX40003CKX40002CKX30007Ool00`00
ECAE=004EC@20005EC@00`00ECAE=004EC@00`00EC@0000200000eDc001E<`05EC<00`00EA=E4`03
00000eDc001E4`05EA<00`00EA=E4`03EA<40003EA<00`00Oomoo`02Ool00`00Oomoo`05Ool001Yo
o`03001oogoo01eoo`<00004CKX000000003CKX01000CKX000000dfj100000A=^P00000000==^P04
001=^P000003CKX3000;Ool00`00ECAE=00300000eDd001E=005EC@00`00ECAE=003EC@20005EC<0
0`00EC=E<`03EC<30005EC<00`00EA=E4`03EA<00`00EA=E4`0300001EDC001E4eDC00000eDC00D0
07ooOomoo`0000Moo`006goo00<007ooOol07goo0`000dfj1@0000==^P0000000dfj10000dfj1000
00A=^P00000000moo`8000EE=003001E=5Dd00=E=003001E=5Dd00<00003EC@005Dc00EE<`03001E
<`0000800003EC<005Dc00IE<`03001E4eDC009E4`<000EE4`03001E4`0000=E4`05001oogooOol0
0007Ool001aoo`03001oogoo025oo`<000==^PD00003CKX0000000==^P@0009=^P<0019oo`03001E
=5Dd00AE=004001E=5DdEC@50005EC@00`00EC=E<`03EC<20005EC<00`00EC=E<`04EC<00`00EA<0
000200000eDC001E4`06EA<00`00EA<00002EA<20002Ool00`00Oomoo`05Ool001eoo`03001oogoo
02=oo`<000==^P@00004CKX000000003CKX3000FOol00`00ECAE=003EC@40003EC@00`00ECAE=004
EC@00`00EC=E<`0300000eDc001E<`05EC<00`00EC=E<`03EC<20005EA<00`00EA=E4`04EA<00`00
EA<0000200001EDC001oogoo00001goo000NOol2000VOol30002CKX5000014fj000000006Woo00<0
05Dd00000P0000=I<`00EC@01EDd00<005DdEC@00eDd0`001EDc00<005DcEC<00eDc00<005DcEC<0
0`0000=E<`00EA<01EDC00<005DCEA<00eDC0P0000=E4`00EA<00UDC00@007ooOol000Ioo`0087oo
00<007ooOol09Woo0P000dfj0`007Woo00<005TcFC<00eTc00<005DdEC@015Dd00<005Dd00000P00
00=E<`00EC<01EDc00<005DcEC<00eDc0`001EDc00<005DCEA<00eDC00<005DCEA<00`0000EE4`00
EA=E4`0000=E4`03001oo`0000Ioo`008Goo00<007ooOol09goo0`008Goo00<005TcFC<015Tc00<0
05DdEC@00eDd0P001EDc00<005DcEC<00eDc00<005DcEC<00`0000=E<`00EC<01EDc00<005DCEA<0
0eDC0`001EDC00@005DCEA<0009E4`03001oo`0000Ioo`008Woo00<007ooOol09goo00<007ooOol0
8Goo00<005TcFC<00eTc00<005DdEC@00`0000=E<`00EC<01EDc00@005DcEC=E<`@000EE<`03001E
<eDc00=E<`03001E4eDC00<00003EC<005DC00EE4`06001E4eDCEA<005DC0`001Woo000SOol2000W
Ool00`00Oomoo`0ROol01000FC=I<eTc10001EDc00<005DcEC<00eDc10000UDc00<005DcEC<015Dc
00@005DcEC=E<`D000EE<`03001E4eDC00=E4`03001E4eDC00<00003FC<0000000Ioo`009Goo00<0
07ooOol097oo00<007ooOol08goo0`000UTc00<005DcEC<015Dc00<005DcEC<00`0000=E<`00EC<0
15Dc00<005DcEC<00eDc10000eDc00<005DcEC<015Dc00<005DCEA<00eDC0`000UTc00@005TcFC<0
00Ioo`009Woo00<007ooOol08goo00<007ooOol08goo00<005TcFC<00eTc00<005DcEC<00eDc0`00
1EDc00<005DcEC<00eDc00<005Dc00000P0000=E<`00EC<01EDc00<005DcEC<00eDc00<005DCEA<0
0`0000=E<`00FC<00eTc00<005Tc00001Woo000WOol00`00Oomoo`0ROol00`00Oomoo`0TOol00`00
FC=I<`03FC<00`00EC<0000200000eTc001E<`05EC<00`00EC=E<`03EC<20005EC<00`00EC=E<`04
EC<01000EC=E<eDc10001EDc00H005TcFC=I<`00FC<20005Ool002Qoo`03001oogoo025oo`03001o
ogoo02Aoo`04001I<eTcFC<40005FC<00`00EC=E<`03EC<00`00EC=E<`0300000eDc001E<`05EC<0
0`00EC=E<`03EC<40002EC<00`00EC=E<`04EC<01000FC=I<eTc10001Goo000YOol2000QOol00`00
Oomoo`0UOol30003FC<00`00FC=I<`04FC<01000EC=E<eDc10001EDc00<005DcEC<00eDc00<005Dc
EC<00`0000=E<`00EC<015Dc00<005DcEC<00eDc10000Woo0P001Goo000[Ool00`00Oomoo`0NOol0
0`00Oomoo`0UOol00`00FC=I<`04FC<00`00FC=I<`03FC<40002FC<00`00EC=E<`04EC<00`00EC=E
<`03EC<30005EC<00`00EC=E<`03EC<00`00EC<000020005Ool30005Ool002aoo`03001oogoo01ao
o`03001oogoo02Moo`03001I<eTc00=I<`03001I<eTc00<00003FC<005Tc00AI<`03001E<eDc00=E
<`03001E<eDc00<00003EC<005Dc00EE<`03001E<eDc00=E<`8000Aoo`@000Qoo`00;Goo00<007oo
Ool06goo00<007ooOol0:7oo00<005TcFC<00UTc0`001ETc00<005TcFC<00eTc00@005DcEC=E<`@0
00EE<`03001E<eDc00=E<`03001E<eDc00<0009oo`@000aoo`00;Woo0P006goo00<007ooOol0:7oo
00<005Tc00000P0000=I<`00FC<01ETc00<005TcFC<00eTc10000UTc00<005DcEC<015Dc00@005Dc
EC=E<`D0009oo`<0011oo`00<7oo00<007ooOol067oo00<007ooOol0:Goo00<005TcFC<00eTc00<0
05TcFC<00eTc00<005TcFC<00`0000=I<`00FC<015Tc00<005DcEC<00eDc10000goo10004goo000a
Ool00`00Oomoo`0GOol00`00Oomoo`0YOol00`00FC=I<`04FC<01000FC=I<eTc10001ETc00<005Tc
FC<00eTc00<005Dc00000P000goo10005goo000bOol00`00Oomoo`0FOol00`00Oomoo`0ZOol00`00
FC=I<`03FC<40002FC<00`00FC=I<`04FC<01000FC=I<eTc10000Woo10006goo000cOol00`00Oomo
o`0EOol00`00Oomoo`0[Ool00`00FC<0000200000eTc001I<`04FC<00`00FC=I<`03FC<40002Ool4
000OOol003Aoo`8001Eoo`03001oogoo02aoo`03001I<eTc00=I<`03001I<eTc00=I<`03001I<`00
0080009oo`@002=oo`00=Woo00<007ooOol04Woo00<007ooOol0;7oo00<005TcFC<015Tc00@005Tc
FC=I<`<00003Ool00000008002Moo`00=goo00<007ooOol04Goo00<007ooOol0;Goo00<005TcFC<0
0eTc100000Aoo`00000002]oo`00>7oo00<007ooOol047oo00<007ooOol0;Goo00<005TcFC<00`00
00=oo`0000000P00;Woo000iOol2000@Ool00`00Oomoo`0^Ool6000bOol003]oo`03001oogoo00eo
o`03001oogoo02aoo`@003Ioo`00?7oo00<007ooOol037oo00<007ooOol0:7oo1000>Woo000mOol0
0`00Oomoo`0;Ool00`00Oomoo`0TOol4000nOol003ioo`03001oogoo00Yoo`03001oogoo025oo`<0
049oo`00?goo0P002Woo00<007ooOol07Goo1000AGoo0011Ool00`00Oomoo`06Ool00`00Oomoo`0J
Ool40019Ool0049oo`03001oogoo00Eoo`03001oogoo01Ioo`@004eoo`00@goo00<007ooOol017oo
00<007ooOol04Woo1000DGoo0014Ool20004Ool00`00Oomoo`0>Ool4001EOol004Ioo`05001oogoo
Ool0000<Ool4001IOol004Moo`04001oogoo0009Ool3001MOol004Qoo`03001oo`0000Eoo`@0061o
o`00BGoo0P0000=oo`0000000P00I7oo001:Ool2001XOol00001\
\>"],
  ImageRangeCache->{{{0, 179}, {144.938, 0}} -> {-0.0498382, 0.0103903, \
0.00573207, 0.00573207}}]
}, Closed]],

Cell["\<\
Here is the same function, displayed without the steep vertical \
walls.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(With[{\[CurlyEpsilon] = 1\/10\^10}, 
        Show[Block[{$DisplayFunction = Identity}, 
            Apply[Plot3D[
                  Im[\@\(\((x + \[ImaginaryI]\ y)\)\^2 - 1\)], ##1] &, {{{x, \
\[CurlyEpsilon], 2}, {y, \[CurlyEpsilon], 
                    2}}, {{x, \(-\[CurlyEpsilon]\), \(-2\)}, {y, \
\[CurlyEpsilon], 2}}, {{x, \[CurlyEpsilon], 
                    2}, {y, \(-\[CurlyEpsilon]\), \(-2\)}}, {{x, \(-\
\[CurlyEpsilon]\), \(-2\)}, {y, \(-\[CurlyEpsilon]\), \(-2\)}}}, \
{1}]]]];\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.2768e-17 1.04977 -0.0679587 1.04977 [
[.04138 .24075 -10.5625 -6.7994 ]
[.04138 .24075 0 .2006 ]
[.18378 .18471 -10.1141 -7 ]
[.18378 .18471 .19843 0 ]
[.3345 .12542 -6.57601 -7 ]
[.3345 .12542 .48649 0 ]
[.49429 .06259 -6.06015 -7 ]
[.49429 .06259 .81485 0 ]
[.664 -0.00409 -5.92682 -7 ]
[.664 -0.00409 1.19818 0 ]
[.7092 .00785 0 -4.86073 ]
[.7092 .00785 10.5625 2.13927 ]
[.78681 .12668 0 -4.77021 ]
[.78681 .12668 10.3125 2.22979 ]
[.8565 .23339 0 -4.69099 ]
[.8565 .23339 7.0625 2.30901 ]
[.91941 .32973 0 -4.62107 ]
[.91941 .32973 6.875 2.37893 ]
[.97649 .41716 0 -4.5589 ]
[.97649 .41716 7.125 2.4411 ]
[.02236 .27612 -10.5625 -2.14014 ]
[.02236 .27612 0 4.85986 ]
[.01478 .32363 -10.3125 -2.17141 ]
[.01478 .32363 0 4.82859 ]
[.00696 .37264 -7.0625 -2.20375 ]
[.00696 .37264 0 4.79625 ]
[-0.00111 .4232 -6.875 -2.23722 ]
[-0.00111 .4232 0 4.76278 ]
[-0.00944 .47538 -7.125 -2.27189 ]
[-0.00944 .47538 0 4.72811 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.05093 .24975 m
.0557 .25425 L
s
gsave
.04138 .24075 -71.5625 -10.7994 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.19287 .19417 m
.19742 .1989 L
s
gsave
.18378 .18471 -71.1141 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -67.576 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.50225 .07302 m
.50623 .07824 L
s
gsave
.49429 .06259 -67.0601 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.67126 .00684 m
.67489 .01231 L
s
gsave
.664 -0.00409 -66.9268 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07869 .23888 m
.08153 .2416 L
s
.10676 .22788 m
.10957 .23064 L
s
.13514 .21677 m
.13793 .21955 L
s
.16384 .20553 m
.1666 .20834 L
s
.22223 .18267 m
.22493 .18554 L
s
.25192 .17104 m
.25459 .17394 L
s
.28195 .15928 m
.28459 .16221 L
s
.31233 .14739 m
.31494 .15034 L
s
.37416 .12318 m
.37669 .12619 L
s
.40562 .11086 m
.40812 .1139 L
s
.43745 .0984 m
.43991 .10147 L
s
.46966 .08579 m
.47208 .08889 L
s
.53524 .06011 m
.53759 .06327 L
s
.56863 .04703 m
.57093 .05022 L
s
.60242 .0338 m
.60468 .03702 L
s
.63663 .0204 m
.63885 .02365 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69697 .0126 m
.69086 .01498 L
s
gsave
.7092 .00785 -61 -8.86073 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.77448 .13116 m
.76831 .13339 L
s
gsave
.78681 .12668 -61 -8.77021 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -8.69099 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.90691 .33374 m
.90067 .33574 L
s
gsave
.91941 .32973 -61 -8.62107 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.96393 .42096 m
.95765 .42286 L
s
gsave
.97649 .41716 -61 -8.5589 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.71317 .03738 m
.7095 .03879 L
s
.72901 .0616 m
.72533 .063 L
s
.7445 .0853 m
.74081 .08667 L
s
.75965 .10848 m
.75596 .10983 L
s
.78899 .15335 m
.78528 .15468 L
s
.8032 .17508 m
.79948 .1764 L
s
.81711 .19636 m
.81339 .19766 L
s
.83073 .2172 m
.82701 .21848 L
s
.85715 .25762 m
.85342 .25887 L
s
.86996 .27722 m
.86623 .27846 L
s
.88252 .29643 m
.87878 .29766 L
s
.89484 .31527 m
.89109 .31648 L
s
.91876 .35185 m
.915 .35304 L
s
.93037 .36962 m
.92662 .3708 L
s
.94177 .38706 m
.93801 .38822 L
s
.95296 .40417 m
.94919 .40532 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03459 .27136 m
.0407 .26899 L
s
gsave
.02236 .27612 -71.5625 -6.14014 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02704 .31898 m
.03318 .31665 L
s
gsave
.01478 .32363 -71.3125 -6.17141 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -68.0625 -6.20375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01123 .41874 m
.01741 .41652 L
s
gsave
-0.00111 .4232 -67.875 -6.23722 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.00295 .47104 m
.00914 .46887 L
s
gsave
-0.00944 .47538 -68.125 -6.27189 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.0331 .28077 m
.03677 .27935 L
s
.0316 .29024 m
.03527 .28882 L
s
.03009 .29976 m
.03377 .29835 L
s
.02857 .30934 m
.03225 .30794 L
s
.02551 .32868 m
.02919 .32729 L
s
.02396 .33844 m
.02764 .33705 L
s
.0224 .34826 m
.02609 .34688 L
s
.02084 .35814 m
.02453 .35676 L
s
.01768 .37809 m
.02137 .37672 L
s
.01608 .38815 m
.01978 .3868 L
s
.01448 .39829 m
.01817 .39694 L
s
.01286 .40848 m
.01656 .40714 L
s
.0096 .42907 m
.0133 .42774 L
s
.00795 .43946 m
.01166 .43814 L
s
.00629 .44992 m
.01 .4486 L
s
.00462 .46044 m
.00834 .45913 L
s
.03607 .26201 m
.03974 .26058 L
s
.00126 .4817 m
.00497 .4804 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.42094 .58305 m .43737 .58899 L .40993 .59786 L p .605 .434 .834 r
F P
0 g
s
.40993 .59786 m .39324 .59215 L .42094 .58305 L p .605 .434 .834 r
F P
0 g
s
.44891 .5738 m .46508 .58 L .43737 .58899 L p .605 .433 .834 r
F P
0 g
s
.43737 .58899 m .42094 .58305 L .44891 .5738 L p .605 .433 .834 r
F P
0 g
s
.47717 .5644 m .49307 .57089 L .46508 .58 L p .606 .431 .833 r
F P
0 g
s
.46508 .58 m .44891 .5738 L .47717 .5644 L p .606 .431 .833 r
F P
0 g
s
.40409 .57704 m .42094 .58305 L .39324 .59215 L p .602 .435 .837 r
F P
0 g
s
.39324 .59215 m .37613 .58638 L .40409 .57704 L p .602 .435 .837 r
F P
0 g
s
.5057 .55489 m .52133 .56169 L .49307 .57089 L p .608 .429 .831 r
F P
0 g
s
.49307 .57089 m .47717 .5644 L .5057 .55489 L p .608 .429 .831 r
F P
0 g
s
.43234 .56749 m .44891 .5738 L .42094 .58305 L p .602 .432 .837 r
F P
0 g
s
.42094 .58305 m .40409 .57704 L .43234 .56749 L p .602 .432 .837 r
F P
0 g
s
.53453 .54533 m .54988 .55245 L .52133 .56169 L p .611 .428 .828 r
F P
0 g
s
.52133 .56169 m .5057 .55489 L .53453 .54533 L p .611 .428 .828 r
F P
0 g
s
.46087 .55776 m .47717 .5644 L .44891 .5738 L p .602 .43 .836 r
F P
0 g
s
.44891 .5738 m .43234 .56749 L .46087 .55776 L p .602 .43 .836 r
F P
0 g
s
.38681 .57098 m .40409 .57704 L .37613 .58638 L p .598 .435 .84 r
F P
0 g
s
.37613 .58638 m .35858 .58057 L .38681 .57098 L p .598 .435 .84 r
F P
0 g
s
.56364 .53576 m .57872 .5432 L .54988 .55245 L p .616 .426 .824 r
F P
0 g
s
.54988 .55245 m .53453 .54533 L .56364 .53576 L p .616 .426 .824 r
F P
0 g
s
.48968 .54789 m .5057 .55489 L .47717 .5644 L p .604 .428 .834 r
F P
0 g
s
.47717 .5644 m .46087 .55776 L .48968 .54789 L p .604 .428 .834 r
F P
0 g
s
.41534 .56112 m .43234 .56749 L .40409 .57704 L p .597 .432 .84 r
F P
0 g
s
.40409 .57704 m .38681 .57098 L .41534 .56112 L p .597 .432 .84 r
F P
0 g
s
.59305 .52625 m .60785 .53397 L .57872 .5432 L p .621 .426 .82 r
F P
0 g
s
.57872 .5432 m .56364 .53576 L .59305 .52625 L p .621 .426 .82 r
F P
0 g
s
.51879 .53793 m .53453 .54533 L .5057 .55489 L p .608 .425 .831 r
F P
0 g
s
.5057 .55489 m .48968 .54789 L .51879 .53793 L p .608 .425 .831 r
F P
0 g
s
.44415 .55101 m .46087 .55776 L .43234 .56749 L p .597 .429 .84 r
F P
0 g
s
.43234 .56749 m .41534 .56112 L .44415 .55101 L p .597 .429 .84 r
F P
0 g
s
.62278 .51685 m .63728 .52481 L .60785 .53397 L p .626 .425 .815 r
F P
0 g
s
.60785 .53397 m .59305 .52625 L .62278 .51685 L p .626 .425 .815 r
F P
0 g
s
.54818 .52798 m .56364 .53576 L .53453 .54533 L p .613 .424 .826 r
F P
0 g
s
.53453 .54533 m .51879 .53793 L .54818 .52798 L p .613 .424 .826 r
F P
0 g
s
.36908 .56494 m .38681 .57098 L .35858 .58057 L p .594 .436 .843 r
F P
0 g
s
.35858 .58057 m .34057 .57478 L .36908 .56494 L p .594 .436 .843 r
F P
0 g
s
.47326 .54069 m .48968 .54789 L .46087 .55776 L p .599 .426 .838 r
F P
0 g
s
.46087 .55776 m .44415 .55101 L .47326 .54069 L p .599 .426 .838 r
F P
0 g
s
.65282 .50759 m .66703 .51574 L .63728 .52481 L p .632 .426 .81 r
F P
0 g
s
.63728 .52481 m .62278 .51685 L .65282 .50759 L p .632 .426 .81 r
F P
0 g
s
.57788 .51812 m .59305 .52625 L .56364 .53576 L p .619 .422 .82 r
F P
0 g
s
.56364 .53576 m .54818 .52798 L .57788 .51812 L p .619 .422 .82 r
F P
0 g
s
.39789 .55475 m .41534 .56112 L .38681 .57098 L p .592 .433 .845 r
F P
0 g
s
.38681 .57098 m .36908 .56494 L .39789 .55475 L p .592 .433 .845 r
F P
0 g
s
.50265 .53025 m .51879 .53793 L .48968 .54789 L p .602 .423 .834 r
F P
0 g
s
.48968 .54789 m .47326 .54069 L .50265 .53025 L p .602 .423 .834 r
F P
0 g
s
.427 .54421 m .44415 .55101 L .41534 .56112 L p .59 .429 .846 r
F P
0 g
s
.41534 .56112 m .39789 .55475 L .427 .54421 L p .59 .429 .846 r
F P
0 g
s
.6079 .50843 m .62278 .51685 L .59305 .52625 L p .627 .422 .813 r
F P
0 g
s
.59305 .52625 m .57788 .51812 L .6079 .50843 L p .627 .422 .813 r
F P
0 g
s
.53234 .51981 m .54818 .52798 L .51879 .53793 L p .609 .42 .828 r
F P
0 g
s
.51879 .53793 m .50265 .53025 L .53234 .51981 L p .609 .42 .828 r
F P
0 g
s
.35088 .55899 m .36908 .56494 L .34057 .57478 L p .59 .438 .846 r
F P
0 g
s
.34057 .57478 m .32208 .56904 L .35088 .55899 L p .59 .438 .846 r
F P
0 g
s
.45641 .53334 m .47326 .54069 L .44415 .55101 L p .59 .424 .845 r
F P
0 g
s
.44415 .55101 m .427 .54421 L .45641 .53334 L p .59 .424 .845 r
F P
0 g
s
.63824 .49897 m .65282 .50759 L .62278 .51685 L p .634 .423 .807 r
F P
0 g
s
.62278 .51685 m .6079 .50843 L .63824 .49897 L p .634 .423 .807 r
F P
0 g
s
.56233 .50951 m .57788 .51812 L .54818 .52798 L p .617 .418 .82 r
F P
0 g
s
.54818 .52798 m .53234 .51981 L .56233 .50951 L p .617 .418 .82 r
F P
0 g
s
.37998 .54849 m .39789 .55475 L .36908 .56494 L p .585 .434 .85 r
F P
0 g
s
.36908 .56494 m .35088 .55899 L .37998 .54849 L p .585 .434 .85 r
F P
0 g
s
.4861 .52226 m .50265 .53025 L .47326 .54069 L p .594 .42 .84 r
F P
0 g
s
.47326 .54069 m .45641 .53334 L .4861 .52226 L p .594 .42 .84 r
F P
0 g
s
.59263 .49947 m .6079 .50843 L .57788 .51812 L p .627 .418 .812 r
F P
0 g
s
.57788 .51812 m .56233 .50951 L .59263 .49947 L p .627 .418 .812 r
F P
0 g
s
.4094 .53746 m .427 .54421 L .39789 .55475 L p .581 .429 .854 r
F P
0 g
s
.39789 .55475 m .37998 .54849 L .4094 .53746 L p .581 .429 .854 r
F P
0 g
s
.51609 .51117 m .53234 .51981 L .50265 .53025 L p .602 .415 .832 r
F P
0 g
s
.50265 .53025 m .4861 .52226 L .51609 .51117 L p .602 .415 .832 r
F P
0 g
s
.33217 .55323 m .35088 .55899 L .32208 .56904 L p .586 .44 .849 r
F P
0 g
s
.32208 .56904 m .30308 .56341 L .33217 .55323 L p .586 .44 .849 r
F P
0 g
s
.62328 .48977 m .63824 .49897 L .6079 .50843 L p .637 .419 .803 r
F P
0 g
s
.6079 .50843 m .59263 .49947 L .62328 .48977 L p .637 .419 .803 r
F P
0 g
s
.43911 .52591 m .45641 .53334 L .427 .54421 L p .578 .423 .854 r
F P
0 g
s
.427 .54421 m .4094 .53746 L .43911 .52591 L p .578 .423 .854 r
F P
0 g
s
.54637 .50029 m .56233 .50951 L .53234 .51981 L p .613 .413 .822 r
F P
0 g
s
.53234 .51981 m .51609 .51117 L .54637 .50029 L p .613 .413 .822 r
F P
0 g
s
.36157 .54249 m .37998 .54849 L .35088 .55899 L p .578 .437 .856 r
F P
0 g
s
.35088 .55899 m .33217 .55323 L .36157 .54249 L p .578 .437 .856 r
F P
0 g
s
.46912 .51398 m .4861 .52226 L .45641 .53334 L p .581 .416 .85 r
F P
0 g
s
.45641 .53334 m .43911 .52591 L .46912 .51398 L p .581 .416 .85 r
F P
0 g
s
.57697 .48981 m .59263 .49947 L .56233 .50951 L p .626 .412 .81 r
F P
0 g
s
.56233 .50951 m .54637 .50029 L .57697 .48981 L p .626 .412 .81 r
F P
0 g
s
.39131 .53099 m .4094 .53746 L .37998 .54849 L p .569 .431 .863 r
F P
0 g
s
.37998 .54849 m .36157 .54249 L .39131 .53099 L p .569 .431 .863 r
F P
0 g
s
.49942 .50199 m .51609 .51117 L .4861 .52226 L p .591 .409 .839 r
F P
0 g
s
.4861 .52226 m .46912 .51398 L .49942 .50199 L p .591 .409 .839 r
F P
0 g
s
.31292 .54776 m .33217 .55323 L .30308 .56341 L p .584 .445 .85 r
F P
0 g
s
.30308 .56341 m .28355 .55792 L .31292 .54776 L p .584 .445 .85 r
F P
0 g
s
.60792 .47984 m .62328 .48977 L .59263 .49947 L p .64 .413 .798 r
F P
0 g
s
.59263 .49947 m .57697 .48981 L .60792 .47984 L p .64 .413 .798 r
F P
0 g
s
.42136 .51858 m .43911 .52591 L .4094 .53746 L p .561 .422 .868 r
F P
0 g
s
.4094 .53746 m .39131 .53099 L .42136 .51858 L p .561 .422 .868 r
F P
0 g
s
.53001 .49032 m .54637 .50029 L .51609 .51117 L p .606 .405 .824 r
F P
0 g
s
.51609 .51117 m .49942 .50199 L .53001 .49032 L p .606 .405 .824 r
F P
0 g
s
.34263 .53698 m .36157 .54249 L .33217 .55323 L p .573 .443 .859 r
F P
0 g
s
.33217 .55323 m .31292 .54776 L .34263 .53698 L p .573 .443 .859 r
F P
0 g
s
.4517 .50542 m .46912 .51398 L .43911 .52591 L p .56 .411 .865 r
F P
0 g
s
.43911 .52591 m .42136 .51858 L .4517 .50542 L p .56 .411 .865 r
F P
0 g
s
.56091 .47926 m .57697 .48981 L .54637 .50029 L p .625 .404 .806 r
F P
0 g
s
.54637 .50029 m .53001 .49032 L .56091 .47926 L p .625 .404 .806 r
F P
0 g
s
.37268 .52519 m .39131 .53099 L .36157 .54249 L p .556 .437 .873 r
F P
0 g
s
.36157 .54249 m .34263 .53698 L .37268 .52519 L p .556 .437 .873 r
F P
0 g
s
.48233 .49212 m .49942 .50199 L .46912 .51398 L p .573 .401 .849 r
F P
0 g
s
.46912 .51398 m .4517 .50542 L .48233 .49212 L p .573 .401 .849 r
F P
0 g
s
.2931 .54262 m .31292 .54776 L .28355 .55792 L p .585 .45 .848 r
F P
0 g
s
.28355 .55792 m .26346 .55257 L .2931 .54262 L p .585 .45 .848 r
F P
0 g
s
.59215 .46898 m .60792 .47984 L .57697 .48981 L p .644 .405 .79 r
F P
0 g
s
.57697 .48981 m .56091 .47926 L .59215 .46898 L p .644 .405 .79 r
F P
0 g
s
.40309 .51179 m .42136 .51858 L .39131 .53099 L p .535 .424 .888 r
F P
0 g
s
.39131 .53099 m .37268 .52519 L .40309 .51179 L p .535 .424 .888 r
F P
0 g
s
.51322 .47934 m .53001 .49032 L .49942 .50199 L p .596 .395 .826 r
F P
0 g
s
.49942 .50199 m .48233 .49212 L .51322 .47934 L p .596 .395 .826 r
F P
0 g
s
.32309 .53218 m .34263 .53698 L .31292 .54776 L p .572 .451 .857 r
F P
0 g
s
.31292 .54776 m .2931 .54262 L .32309 .53218 L p .572 .451 .857 r
F P
0 g
s
.43382 .49669 m .4517 .50542 L .42136 .51858 L p .523 .406 .891 r
F P
0 g
s
.42136 .51858 m .40309 .51179 L .43382 .49669 L p .523 .406 .891 r
F P
0 g
s
.54442 .46753 m .56091 .47926 L .53001 .49032 L p .623 .393 .801 r
F P
0 g
s
.53001 .49032 m .51322 .47934 L .54442 .46753 L p .623 .393 .801 r
F P
0 g
s
.35346 .52077 m .37268 .52519 L .34263 .53698 L p .549 .449 .875 r
F P
0 g
s
.34263 .53698 m .32309 .53218 L .35346 .52077 L p .549 .449 .875 r
F P
0 g
s
.4648 .48127 m .48233 .49212 L .4517 .50542 L p .543 .389 .866 r
F P
0 g
s
.4517 .50542 m .43382 .49669 L .4648 .48127 L p .543 .389 .866 r
F P
0 g
s
.57596 .45687 m .59215 .46898 L .56091 .47926 L p .649 .395 .779 r
F P
0 g
s
.56091 .47926 m .54442 .46753 L .57596 .45687 L p .649 .395 .779 r
F P
0 g
s
.27269 .53767 m .2931 .54262 L .26346 .55257 L p .59 .456 .841 r
F P
0 g
s
.26346 .55257 m .24279 .54724 L .27269 .53767 L p .59 .456 .841 r
F P
0 g
s
.49603 .46694 m .51322 .47934 L .48233 .49212 L p .582 .38 .827 r
F P
0 g
s
.48233 .49212 m .4648 .48127 L .49603 .46694 L p .582 .38 .827 r
F P
0 g
s
.38424 .5068 m .40309 .51179 L .37268 .52519 L p .502 .435 .912 r
F P
0 g
s
.37268 .52519 m .35346 .52077 L .38424 .5068 L p .502 .435 .912 r
F P
0 g
s
.69232 .68976 m .70791 .71545 L .6759 .72402 L p .696 .287 .599 r
F P
0 g
s
.6759 .72402 m .66016 .69858 L .69232 .68976 L p .696 .287 .599 r
F P
0 g
s
.30295 .52798 m .32309 .53218 L .2931 .54262 L p .579 .461 .846 r
F P
0 g
s
.2931 .54262 m .27269 .53767 L .30295 .52798 L p .579 .461 .846 r
F P
0 g
s
.41546 .48788 m .43382 .49669 L .40309 .51179 L p .443 .397 .946 r
F P
0 g
s
.40309 .51179 m .38424 .5068 L .41546 .48788 L p .443 .397 .946 r
F P
0 g
s
.52752 .4542 m .54442 .46753 L .51322 .47934 L p .62 .378 .792 r
F P
0 g
s
.51322 .47934 m .49603 .46694 L .52752 .4542 L p .62 .378 .792 r
F P
0 g
s
.72483 .68057 m .74026 .70657 L .70791 .71545 L p .693 .286 .601 r
F P
0 g
s
.70791 .71545 m .69232 .68976 L .72483 .68057 L p .693 .286 .601 r
F P
0 g
s
.6765 .66395 m .69232 .68976 L .66016 .69858 L p .696 .288 .602 r
F P
0 g
s
.66016 .69858 m .64418 .67303 L .6765 .66395 L p .696 .288 .602 r
F P
0 g
s
.44687 .46869 m .4648 .48127 L .43382 .49669 L p .491 .368 .89 r
F P
0 g
s
.43382 .49669 m .41546 .48788 L .44687 .46869 L p .491 .368 .89 r
F P
0 g
s
.33355 .51819 m .35346 .52077 L .32309 .53218 L p .559 .468 .852 r
F P
0 g
s
.32309 .53218 m .30295 .52798 L .33355 .51819 L p .559 .468 .852 r
F P
0 g
s
.55935 .44312 m .57596 .45687 L .54442 .46753 L p .654 .381 .763 r
F P
0 g
s
.54442 .46753 m .52752 .4542 L .55935 .44312 L p .654 .381 .763 r
F P
0 g
s
.75769 .67105 m .77296 .69741 L .74026 .70657 L p .69 .285 .602 r
F P
0 g
s
.74026 .70657 m .72483 .68057 L .75769 .67105 L p .69 .285 .602 r
F P
0 g
s
.25169 .53257 m .27269 .53767 L .24279 .54724 L p .598 .46 .832 r
F P
0 g
s
.24279 .54724 m .22152 .54176 L .25169 .53257 L p .598 .46 .832 r
F P
0 g
s
.47842 .45244 m .49603 .46694 L .4648 .48127 L p .568 .358 .818 r
F P
0 g
s
.4648 .48127 m .44687 .46869 L .47842 .45244 L p .568 .358 .818 r
F P
0 g
s
.70917 .6544 m .72483 .68057 L .69232 .68976 L p .692 .287 .605 r
F P
0 g
s
.69232 .68976 m .6765 .66395 L .70917 .6544 L p .692 .287 .605 r
F P
0 g
s
.36451 .50827 m .38424 .5068 L .35346 .52077 L p .513 .479 .86 r
F P
0 g
s
.35346 .52077 m .33355 .51819 L .36451 .50827 L p .513 .479 .86 r
F P
0 g
s
.66045 .6381 m .6765 .66395 L .64418 .67303 L p .695 .29 .606 r
F P
0 g
s
.64418 .67303 m .62796 .64747 L .66045 .6381 L p .695 .29 .606 r
F P
0 g
s
.51021 .43876 m .52752 .4542 L .49603 .46694 L p .62 .358 .772 r
F P
0 g
s
.49603 .46694 m .47842 .45244 L .51021 .43876 L p .62 .358 .772 r
F P
0 g
s
.79091 .66124 m .80602 .68801 L .77296 .69741 L p .688 .284 .602 r
F P
0 g
s
.77296 .69741 m .75769 .67105 L .79091 .66124 L p .688 .284 .602 r
F P
0 g
s
.2822 .52366 m .30295 .52798 L .27269 .53767 L p .592 .467 .829 r
F P
0 g
s
.27269 .53767 m .25169 .53257 L .2822 .52366 L p .592 .467 .829 r
F P
0 g
s
.39669 .47629 m .41546 .48788 L .38424 .5068 L p .353 .353 1 r
F P
0 g
s
.38424 .5068 m .36451 .50827 L .39669 .47629 L p .353 .353 1 r
F P
0 g
s
.7422 .64444 m .75769 .67105 L .72483 .68057 L p .688 .285 .606 r
F P
0 g
s
.72483 .68057 m .70917 .6544 L .7422 .64444 L p .688 .285 .606 r
F P
0 g
s
.54232 .42725 m .55935 .44312 L .52752 .4542 L p .659 .364 .741 r
F P
0 g
s
.52752 .4542 m .51021 .43876 L .54232 .42725 L p .659 .364 .741 r
F P
0 g
s
.69328 .62812 m .70917 .6544 L .6765 .66395 L p .689 .289 .609 r
F P
0 g
s
.6765 .66395 m .66045 .6381 L .69328 .62812 L p .689 .289 .609 r
F P
0 g
s
.42857 .45242 m .44687 .46869 L .41546 .48788 L p .463 .327 .87 r
F P
0 g
s
.41546 .48788 m .39669 .47629 L .42857 .45242 L p .463 .327 .87 r
F P
0 g
s
.8245 .65121 m .83945 .67841 L .80602 .68801 L p .687 .282 .602 r
F P
0 g
s
.80602 .68801 m .79091 .66124 L .8245 .65121 L p .687 .282 .602 r
F P
0 g
s
.31302 .51552 m .33355 .51819 L .30295 .52798 L p .584 .48 .815 r
F P
0 g
s
.30295 .52798 m .2822 .52366 L .31302 .51552 L p .584 .48 .815 r
F P
0 g
s
.64415 .61233 m .66045 .6381 L .62796 .64747 L p .694 .293 .611 r
F P
0 g
s
.62796 .64747 m .61149 .62203 L .64415 .61233 L p .694 .293 .611 r
F P
0 g
s
.46044 .43493 m .47842 .45244 L .44687 .46869 L p .576 .328 .777 r
F P
0 g
s
.44687 .46869 m .42857 .45242 L .46044 .43493 L p .576 .328 .777 r
F P
0 g
s
.77557 .63415 m .79091 .66124 L .75769 .67105 L p .685 .284 .606 r
F P
0 g
s
.75769 .67105 m .7422 .64444 L .77557 .63415 L p .685 .284 .606 r
F P
0 g
s
.2301 .52698 m .25169 .53257 L .22152 .54176 L p .607 .462 .823 r
F P
0 g
s
.22152 .54176 m .19965 .53594 L .2301 .52698 L p .607 .462 .823 r
F P
0 g
s
.72647 .61763 m .7422 .64444 L .70917 .6544 L p .685 .286 .611 r
F P
0 g
s
.70917 .6544 m .69328 .62812 L .72647 .61763 L p .685 .286 .611 r
F P
0 g
s
.85845 .64103 m .87324 .66865 L .83945 .67841 L p .686 .281 .601 r
F P
0 g
s
.83945 .67841 m .8245 .65121 L .85845 .64103 L p .686 .281 .601 r
F P
0 g
s
.49251 .42067 m .51021 .43876 L .47842 .45244 L p .627 .336 .74 r
F P
0 g
s
.47842 .45244 m .46044 .43493 L .49251 .42067 L p .627 .336 .74 r
F P
0 g
s
.34411 .5098 m .36451 .50827 L .33355 .51819 L p .559 .497 .743 r
F P
0 g
s
.33355 .51819 m .31302 .51552 L .34411 .5098 L p .559 .497 .743 r
F P
0 g
s
.67715 .60184 m .69328 .62812 L .66045 .6381 L p .686 .291 .616 r
F P
0 g
s
.66045 .6381 m .64415 .61233 L .67715 .60184 L p .686 .291 .616 r
F P
0 g
s
.80931 .62363 m .8245 .65121 L .79091 .66124 L p .684 .282 .605 r
F P
0 g
s
.79091 .66124 m .77557 .63415 L .80931 .62363 L p .684 .282 .605 r
F P
0 g
s
.6276 .58683 m .64415 .61233 L .61149 .62203 L p .693 .297 .619 r
F P
0 g
s
.61149 .62203 m .59476 .5969 L .6276 .58683 L p .693 .297 .619 r
F P
0 g
s
.26087 .51844 m .2822 .52366 L .25169 .53257 L p .607 .469 .816 r
F P
0 g
s
.25169 .53257 m .2301 .52698 L .26087 .51844 L p .607 .469 .816 r
F P
0 g
s
.76 .60675 m .77557 .63415 L .7422 .64444 L p .681 .284 .611 r
F P
0 g
s
.7422 .64444 m .72647 .61763 L .76 .60675 L p .681 .284 .611 r
F P
0 g
s
.52489 .40885 m .54232 .42725 L .51021 .43876 L p .666 .345 .713 r
F P
0 g
s
.51021 .43876 m .49251 .42067 L .52489 .40885 L p .666 .345 .713 r
F P
0 g
s
.89279 .63076 m .90741 .65877 L .87324 .66865 L p .686 .28 .599 r
F P
0 g
s
.87324 .66865 m .85845 .64103 L .89279 .63076 L p .686 .28 .599 r
F P
0 g
s
.37542 .50902 m .39497 .5205 L .36451 .50827 L p .059 0 0 r
F P
0 g
s
.36451 .50827 m .34411 .5098 L .37542 .50902 L p .059 0 0 r
F P
0 g
s
.7105 .59067 m .72647 .61763 L .69328 .62812 L p .679 .288 .618 r
F P
0 g
s
.69328 .62812 m .67715 .60184 L .7105 .59067 L p .679 .288 .618 r
F P
0 g
s
.84343 .61297 m .85845 .64103 L .8245 .65121 L p .684 .281 .603 r
F P
0 g
s
.8245 .65121 m .80931 .62363 L .84343 .61297 L p .684 .281 .603 r
F P
0 g
s
.66078 .57568 m .67715 .60184 L .64415 .61233 L p .681 .293 .626 r
F P
0 g
s
.64415 .61233 m .6276 .58683 L .66078 .57568 L p .681 .293 .626 r
F P
0 g
s
.79389 .59562 m .80931 .62363 L .77557 .63415 L p .68 .282 .609 r
F P
0 g
s
.77557 .63415 m .76 .60675 L .79389 .59562 L p .68 .282 .609 r
F P
0 g
s
.29198 .51075 m .31302 .51552 L .2822 .52366 L p .609 .478 .799 r
F P
0 g
s
.2822 .52366 m .26087 .51844 L .29198 .51075 L p .609 .478 .799 r
F P
0 g
s
.92752 .62042 m .94198 .64881 L .90741 .65877 L p .687 .28 .597 r
F P
0 g
s
.90741 .65877 m .89279 .63076 L .92752 .62042 L p .687 .28 .597 r
F P
0 g
s
.61079 .56188 m .6276 .58683 L .59476 .5969 L p .69 .302 .63 r
F P
0 g
s
.59476 .5969 m .57776 .57238 L .61079 .56188 L p .69 .302 .63 r
F P
0 g
s
.74418 .57902 m .76 .60675 L .72647 .61763 L p .675 .284 .617 r
F P
0 g
s
.72647 .61763 m .7105 .59067 L .74418 .57902 L p .675 .284 .617 r
F P
0 g
s
.2079 .52072 m .2301 .52698 L .19965 .53594 L p .615 .461 .818 r
F P
0 g
s
.19965 .53594 m .17718 .52965 L .2079 .52072 L p .615 .461 .818 r
F P
0 g
s
.87793 .60224 m .89279 .63076 L .85845 .64103 L p .684 .28 .6 r
F P
0 g
s
.85845 .64103 m .84343 .61297 L .87793 .60224 L p .684 .28 .6 r
F P
0 g
s
.69428 .56362 m .7105 .59067 L .67715 .60184 L p .672 .289 .628 r
F P
0 g
s
.67715 .60184 m .66078 .57568 L .69428 .56362 L p .672 .289 .628 r
F P
0 g
s
.82816 .5844 m .84343 .61297 L .80931 .62363 L p .68 .28 .606 r
F P
0 g
s
.80931 .62363 m .79389 .59562 L .82816 .5844 L p .68 .28 .606 r
F P
0 g
s
.32341 .50453 m .34411 .5098 L .31302 .51552 L p .615 .49 .762 r
F P
0 g
s
.31302 .51552 m .29198 .51075 L .32341 .50453 L p .615 .49 .762 r
F P
0 g
s
.96266 .61005 m .97694 .63879 L .94198 .64881 L p .688 .279 .596 r
F P
0 g
s
.94198 .64881 m .92752 .62042 L .96266 .61005 L p .688 .279 .596 r
F P
0 g
s
.77823 .56714 m .79389 .59562 L .76 .60675 L p .674 .281 .614 r
F P
0 g
s
.76 .60675 m .74418 .57902 L .77823 .56714 L p .674 .281 .614 r
F P
0 g
s
.64415 .5499 m .66078 .57568 L .6276 .58683 L p .674 .297 .639 r
F P
0 g
s
.6276 .58683 m .61079 .56188 L .64415 .5499 L p .674 .297 .639 r
F P
0 g
s
.23898 .51216 m .26087 .51844 L .2301 .52698 L p .619 .466 .81 r
F P
0 g
s
.2301 .52698 m .2079 .52072 L .23898 .51216 L p .619 .466 .81 r
F P
0 g
s
.91283 .5915 m .92752 .62042 L .89279 .63076 L p .685 .279 .598 r
F P
0 g
s
.89279 .63076 m .87793 .60224 L .91283 .5915 L p .685 .279 .598 r
F P
0 g
s
.40729 .5084 m .42645 .52456 L .39497 .5205 L p .823 .466 .603 r
F P
0 g
s
.39497 .5205 m .37542 .50902 L .40729 .5084 L p .823 .466 .603 r
F P
0 g
s
.72812 .55095 m .74418 .57902 L .7105 .59067 L p .667 .284 .626 r
F P
0 g
s
.7105 .59067 m .69428 .56362 L .72812 .55095 L p .667 .284 .626 r
F P
0 g
s
.86282 .57318 m .87793 .60224 L .84343 .61297 L p .681 .279 .602 r
F P
0 g
s
.84343 .61297 m .82816 .5844 L .86282 .57318 L p .681 .279 .602 r
F P
0 g
s
.59371 .53787 m .61079 .56188 L .57776 .57238 L p .687 .31 .645 r
F P
0 g
s
.57776 .57238 m .56047 .54884 L .59371 .53787 L p .687 .31 .645 r
F P
0 g
s
.54006 .37779 m .55765 .39926 L .52489 .40885 L p .705 .336 .663 r
F P
0 g
s
.52489 .40885 m .50706 .3877 L .54006 .37779 L p .705 .336 .663 r
F P
0 g
s
.81264 .55525 m .82816 .5844 L .79389 .59562 L p .675 .279 .609 r
F P
0 g
s
.79389 .59562 m .77823 .56714 L .81264 .55525 L p .675 .279 .609 r
F P
0 g
s
.67782 .5366 m .69428 .56362 L .66078 .57568 L p .66 .291 .643 r
F P
0 g
s
.66078 .57568 m .64415 .5499 L .67782 .5366 L p .66 .291 .643 r
F P
0 g
s
.35522 .4999 m .37542 .50902 L .34411 .5098 L p .645 .494 .716 r
F P
0 g
s
.34411 .5098 m .32341 .50453 L .35522 .4999 L p .645 .494 .716 r
F P
0 g
s
.94814 .58076 m .96266 .61005 L .92752 .62042 L p .686 .278 .596 r
F P
0 g
s
.92752 .62042 m .91283 .5915 L .94814 .58076 L p .686 .278 .596 r
F P
0 g
s
.27042 .50419 m .29198 .51075 L .26087 .51844 L p .626 .471 .798 r
F P
0 g
s
.26087 .51844 m .23898 .51216 L .27042 .50419 L p .626 .471 .798 r
F P
0 g
s
.7623 .53808 m .77823 .56714 L .74418 .57902 L p .666 .28 .62 r
F P
0 g
s
.74418 .57902 m .72812 .55095 L .7623 .53808 L p .666 .28 .62 r
F P
0 g
s
.89789 .562 m .91283 .5915 L .87793 .60224 L p .683 .278 .599 r
F P
0 g
s
.87793 .60224 m .86282 .57318 L .89789 .562 L p .683 .278 .599 r
F P
0 g
s
.62727 .52487 m .64415 .5499 L .61079 .56188 L p .663 .303 .659 r
F P
0 g
s
.61079 .56188 m .59371 .53787 L .62727 .52487 L p .663 .303 .659 r
F P
0 g
s
.1851 .51378 m .2079 .52072 L .17718 .52965 L p .621 .459 .814 r
F P
0 g
s
.17718 .52965 m .15406 .52286 L .1851 .51378 L p .621 .459 .814 r
F P
0 g
s
.57352 .3701 m .59088 .39215 L .55765 .39926 L p .74 .345 .637 r
F P
0 g
s
.55765 .39926 m .54006 .37779 L .57352 .3701 L p .74 .345 .637 r
F P
0 g
s
.84746 .54347 m .86282 .57318 L .82816 .5844 L p .678 .278 .603 r
F P
0 g
s
.82816 .5844 m .81264 .55525 L .84746 .54347 L p .678 .278 .603 r
F P
0 g
s
.71179 .52247 m .72812 .55095 L .69428 .56362 L p .652 .284 .64 r
F P
0 g
s
.69428 .56362 m .67782 .5366 L .71179 .52247 L p .652 .284 .64 r
F P
0 g
s
.43982 .5045 m .45872 .52188 L .42645 .52456 L p .795 .405 .639 r
F P
0 g
s
.42645 .52456 m .40729 .5084 L .43982 .5045 L p .795 .405 .639 r
F P
0 g
s
.57633 .51531 m .59371 .53787 L .56047 .54884 L p .683 .322 .666 r
F P
0 g
s
.56047 .54884 m .54286 .52673 L .57633 .51531 L p .683 .322 .666 r
F P
0 g
s
.79686 .52538 m .81264 .55525 L .77823 .56714 L p .669 .277 .612 r
F P
0 g
s
.77823 .56714 m .7623 .53808 L .79686 .52538 L p .669 .277 .612 r
F P
0 g
s
.30222 .49698 m .32341 .50453 L .29198 .51075 L p .641 .476 .779 r
F P
0 g
s
.29198 .51075 m .27042 .50419 L .30222 .49698 L p .641 .476 .779 r
F P
0 g
s
.93338 .55089 m .94814 .58076 L .91283 .5915 L p .685 .277 .596 r
F P
0 g
s
.91283 .5915 m .89789 .562 L .93338 .55089 L p .685 .277 .596 r
F P
0 g
s
.6611 .5099 m .67782 .5366 L .64415 .5499 L p .642 .294 .666 r
F P
0 g
s
.64415 .5499 m .62727 .52487 L .6611 .5099 L p .642 .294 .666 r
F P
0 g
s
.5221 .35356 m .54006 .37779 L .50706 .3877 L p .704 .321 .643 r
F P
0 g
s
.50706 .3877 m .48888 .36393 L .5221 .35356 L p .704 .321 .643 r
F P
0 g
s
.38752 .49543 m .40729 .5084 L .37542 .50902 L p .727 .472 .705 r
F P
0 g
s
.37542 .50902 m .35522 .4999 L .38752 .49543 L p .727 .472 .705 r
F P
0 g
s
.2165 .50498 m .23898 .51216 L .2079 .52072 L p .626 .462 .808 r
F P
0 g
s
.2079 .52072 m .1851 .51378 L .2165 .50498 L p .626 .462 .808 r
F P
0 g
s
.74609 .50823 m .7623 .53808 L .72812 .55095 L p .654 .278 .629 r
F P
0 g
s
.72812 .55095 m .71179 .52247 L .74609 .50823 L p .654 .278 .629 r
F P
0 g
s
.8827 .53185 m .89789 .562 L .86282 .57318 L p .681 .277 .599 r
F P
0 g
s
.86282 .57318 m .84746 .54347 L .8827 .53185 L p .681 .277 .599 r
F P
0 g
s
.60753 .36507 m .6247 .38835 L .59088 .39215 L p .782 .352 .601 r
F P
0 g
s
.59088 .39215 m .57352 .3701 L .60753 .36507 L p .782 .352 .601 r
F P
0 g
s
.61012 .50129 m .62727 .52487 L .59371 .53787 L p .65 .312 .685 r
F P
0 g
s
.59371 .53787 m .57633 .51531 L .61012 .50129 L p .65 .312 .685 r
F P
0 g
s
.83183 .513 m .84746 .54347 L .81264 .55525 L p .674 .276 .604 r
F P
0 g
s
.81264 .55525 m .79686 .52538 L .83183 .513 L p .674 .276 .604 r
F P
0 g
s
.69519 .49346 m .71179 .52247 L .67782 .5366 L p .629 .283 .661 r
F P
0 g
s
.67782 .5366 m .6611 .5099 L .69519 .49346 L p .629 .283 .661 r
F P
0 g
s
.47291 .49765 m .49156 .51558 L .45872 .52188 L p .748 .381 .671 r
F P
0 g
s
.45872 .52188 m .43982 .5045 L .47291 .49765 L p .748 .381 .671 r
F P
0 g
s
.55576 .34488 m .57352 .3701 L .54006 .37779 L p .73 .325 .623 r
F P
0 g
s
.54006 .37779 m .5221 .35356 L .55576 .34488 L p .73 .325 .623 r
F P
0 g
s
.33444 .49036 m .35522 .4999 L .32341 .50453 L p .667 .474 .76 r
F P
0 g
s
.32341 .50453 m .30222 .49698 L .33444 .49036 L p .667 .474 .76 r
F P
0 g
s
.78079 .49454 m .79686 .52538 L .7623 .53808 L p .662 .274 .615 r
F P
0 g
s
.7623 .53808 m .74609 .50823 L .78079 .49454 L p .662 .274 .615 r
F P
0 g
s
.24828 .49652 m .27042 .50419 L .23898 .51216 L p .634 .464 .799 r
F P
0 g
s
.23898 .51216 m .2165 .50498 L .24828 .49652 L p .634 .464 .799 r
F P
0 g
s
.91836 .52037 m .93338 .55089 L .89789 .562 L p .684 .276 .595 r
F P
0 g
s
.89789 .562 m .8827 .53185 L .91836 .52037 L p .684 .276 .595 r
F P
0 g
s
.55862 .4947 m .57633 .51531 L .54286 .52673 L p .678 .337 .692 r
F P
0 g
s
.54286 .52673 m .52489 .50646 L .55862 .4947 L p .678 .337 .692 r
F P
0 g
s
.42037 .48956 m .43982 .5045 L .40729 .5084 L p .746 .43 .703 r
F P
0 g
s
.40729 .5084 m .38752 .49543 L .42037 .48956 L p .746 .43 .703 r
F P
0 g
s
.64415 .48425 m .6611 .5099 L .62727 .52487 L p .617 .299 .698 r
F P
0 g
s
.62727 .52487 m .61012 .50129 L .64415 .48425 L p .617 .299 .698 r
F P
0 g
s
.16165 .50625 m .1851 .51378 L .15406 .52286 L p .625 .456 .813 r
F P
0 g
s
.15406 .52286 m .1303 .51557 L .16165 .50625 L p .625 .456 .813 r
F P
0 g
s
.86724 .50094 m .8827 .53185 L .84746 .54347 L p .679 .275 .598 r
F P
0 g
s
.84746 .54347 m .83183 .513 L .86724 .50094 L p .679 .275 .598 r
F P
0 g
s
.72958 .47712 m .74609 .50823 L .71179 .52247 L p .634 .274 .642 r
F P
0 g
s
.71179 .52247 m .69519 .49346 L .72958 .47712 L p .634 .274 .642 r
F P
0 g
s
.50378 .327 m .5221 .35356 L .48888 .36393 L p .702 .309 .628 r
F P
0 g
s
.48888 .36393 m .47036 .33787 L .50378 .327 L p .702 .309 .628 r
F P
0 g
s
.64221 .36312 m .65936 .39113 L .6247 .38835 L p .829 .354 .551 r
F P
0 g
s
.6247 .38835 m .60753 .36507 L .64221 .36312 L p .829 .354 .551 r
F P
0 g
s
.81592 .48157 m .83183 .513 L .79686 .52538 L p .671 .273 .603 r
F P
0 g
s
.79686 .52538 m .78079 .49454 L .81592 .48157 L p .671 .273 .603 r
F P
0 g
s
.50651 .48821 m .52489 .50646 L .49156 .51558 L p .708 .367 .696 r
F P
0 g
s
.49156 .51558 m .47291 .49765 L .50651 .48821 L p .708 .367 .696 r
F P
0 g
s
.58993 .33785 m .60753 .36507 L .57352 .3701 L p .754 .326 .597 r
F P
0 g
s
.57352 .3701 m .55576 .34488 L .58993 .33785 L p .754 .326 .597 r
F P
0 g
s
.6783 .46381 m .69519 .49346 L .6611 .5099 L p .584 .281 .701 r
F P
0 g
s
.6611 .5099 m .64415 .48425 L .6783 .46381 L p .584 .281 .701 r
F P
0 g
s
.59268 .48007 m .61012 .50129 L .57633 .51531 L p .64 .326 .714 r
F P
0 g
s
.57633 .51531 m .55862 .4947 L .59268 .48007 L p .64 .326 .714 r
F P
0 g
s
.28045 .48841 m .30222 .49698 L .27042 .50419 L p .647 .465 .788 r
F P
0 g
s
.27042 .50419 m .24828 .49652 L .28045 .48841 L p .647 .465 .788 r
F P
0 g
s
.36714 .48367 m .38752 .49543 L .35522 .4999 L p .697 .459 .747 r
F P
0 g
s
.35522 .4999 m .33444 .49036 L .36714 .48367 L p .697 .459 .747 r
F P
0 g
s
.7644 .46231 m .78079 .49454 L .74609 .50823 L p .653 .269 .615 r
F P
0 g
s
.74609 .50823 m .72958 .47712 L .7644 .46231 L p .653 .269 .615 r
F P
0 g
s
.90309 .48914 m .91836 .52037 L .8827 .53185 L p .683 .275 .594 r
F P
0 g
s
.8827 .53185 m .86724 .50094 L .90309 .48914 L p .683 .275 .594 r
F P
0 g
s
.19338 .49709 m .2165 .50498 L .1851 .51378 L p .63 .458 .808 r
F P
0 g
s
.1851 .51378 m .16165 .50625 L .19338 .49709 L p .63 .458 .808 r
F P
0 g
s
.53764 .31732 m .55576 .34488 L .5221 .35356 L p .719 .311 .613 r
F P
0 g
s
.5221 .35356 m .50378 .327 L .53764 .31732 L p .719 .311 .613 r
F P
0 g
s
.45377 .48173 m .47291 .49765 L .43982 .5045 L p .725 .403 .712 r
F P
0 g
s
.43982 .5045 m .42037 .48956 L .45377 .48173 L p .725 .403 .712 r
F P
0 g
s
.8515 .46917 m .86724 .50094 L .83183 .513 L p .678 .273 .595 r
F P
0 g
s
.83183 .513 m .81592 .48157 L .8515 .46917 L p .678 .273 .595 r
F P
0 g
s
.71269 .44341 m .72958 .47712 L .69519 .49346 L p .595 .265 .665 r
F P
0 g
s
.69519 .49346 m .6783 .46381 L .71269 .44341 L p .595 .265 .665 r
F P
0 g
s
.62698 .46171 m .64415 .48425 L .61012 .50129 L p .595 .312 .737 r
F P
0 g
s
.61012 .50129 m .59268 .48007 L .62698 .46171 L p .595 .312 .737 r
F P
0 g
s
.48512 .2986 m .50378 .327 L .47036 .33787 L p .7 .3 .617 r
F P
0 g
s
.47036 .33787 m .45151 .30993 L .48512 .2986 L p .7 .3 .617 r
F P
0 g
s
.7997 .44896 m .81592 .48157 L .78079 .49454 L p .67 .268 .597 r
F P
0 g
s
.78079 .49454 m .7644 .46231 L .7997 .44896 L p .67 .268 .597 r
F P
0 g
s
.31306 .48048 m .33444 .49036 L .30222 .49698 L p .663 .461 .777 r
F P
0 g
s
.30222 .49698 m .28045 .48841 L .31306 .48048 L p .663 .461 .777 r
F P
0 g
s
.67752 .36097 m .6952 .4024 L .65936 .39113 L p .815 .321 .522 r
F P
0 g
s
.65936 .39113 m .64221 .36312 L .67752 .36097 L p .815 .321 .522 r
F P
0 g
s
.62467 .332 m .64221 .36312 L .60753 .36507 L p .77 .318 .569 r
F P
0 g
s
.60753 .36507 m .58993 .33785 L .62467 .332 L p .77 .318 .569 r
F P
0 g
s
.40035 .47617 m .42037 .48956 L .38752 .49543 L p .708 .437 .742 r
F P
0 g
s
.38752 .49543 m .36714 .48367 L .40035 .47617 L p .708 .437 .742 r
F P
0 g
s
.22551 .4881 m .24828 .49652 L .2165 .50498 L p .637 .458 .802 r
F P
0 g
s
.2165 .50498 m .19338 .49709 L .22551 .4881 L p .637 .458 .802 r
F P
0 g
s
.74765 .42796 m .7644 .46231 L .72958 .47712 L p .65 .26 .601 r
F P
0 g
s
.72958 .47712 m .71269 .44341 L .74765 .42796 L p .65 .26 .601 r
F P
0 g
s
.66125 .43634 m .6783 .46381 L .64415 .48425 L p .521 .285 .765 r
F P
0 g
s
.64415 .48425 m .62698 .46171 L .66125 .43634 L p .521 .285 .765 r
F P
0 g
s
.88754 .45713 m .90309 .48914 L .86724 .50094 L p .683 .273 .59 r
F P
0 g
s
.86724 .50094 m .8515 .46917 L .88754 .45713 L p .683 .273 .59 r
F P
0 g
s
.57197 .30863 m .58993 .33785 L .55576 .34488 L p .734 .31 .596 r
F P
0 g
s
.55576 .34488 m .53764 .31732 L .57197 .30863 L p .734 .31 .596 r
F P
0 g
s
.13751 .49821 m .16165 .50625 L .1303 .51557 L p .627 .454 .813 r
F P
0 g
s
.1303 .51557 m .10584 .50783 L .13751 .49821 L p .627 .454 .813 r
F P
0 g
s
.48766 .47184 m .50651 .48821 L .47291 .49765 L p .696 .387 .727 r
F P
0 g
s
.47291 .49765 m .45377 .48173 L .48766 .47184 L p .696 .387 .727 r
F P
0 g
s
.83547 .43642 m .8515 .46917 L .81592 .48157 L p .68 .27 .588 r
F P
0 g
s
.81592 .48157 m .7997 .44896 L .83547 .43642 L p .68 .27 .588 r
F P
0 g
s
.51917 .28806 m .53764 .31732 L .50378 .327 L p .712 .302 .607 r
F P
0 g
s
.50378 .327 m .48512 .2986 L .51917 .28806 L p .712 .302 .607 r
F P
0 g
s
.6952 .4024 m .71269 .44341 L .6783 .46381 L p .463 .246 .756 r
F P
0 g
s
.6783 .46381 m .66125 .43634 L .6952 .4024 L p .463 .246 .756 r
F P
0 g
s
.78315 .41493 m .7997 .44896 L .7644 .46231 L p .676 .263 .581 r
F P
0 g
s
.7644 .46231 m .74765 .42796 L .78315 .41493 L p .676 .263 .581 r
F P
0 g
s
.34615 .47237 m .36714 .48367 L .33444 .49036 L p .677 .451 .769 r
F P
0 g
s
.33444 .49036 m .31306 .48048 L .34615 .47237 L p .677 .451 .769 r
F P
0 g
s
.46613 .26872 m .48512 .2986 L .45151 .30993 L p .698 .295 .61 r
F P
0 g
s
.45151 .30993 m .43233 .28049 L .46613 .26872 L p .698 .295 .61 r
F P
0 g
s
.25806 .47924 m .28045 .48841 L .24828 .49652 L p .646 .457 .794 r
F P
0 g
s
.24828 .49652 m .22551 .4881 L .25806 .47924 L p .646 .457 .794 r
F P
0 g
s
.73053 .39109 m .74765 .42796 L .71269 .44341 L p .69 .242 .528 r
F P
0 g
s
.71269 .44341 m .6952 .4024 L .73053 .39109 L p .69 .242 .528 r
F P
0 g
s
.43408 .46735 m .45377 .48173 L .42037 .48956 L p .7 .417 .744 r
F P
0 g
s
.42037 .48956 m .40035 .47617 L .43408 .46735 L p .7 .417 .744 r
F P
0 g
s
.16959 .48866 m .19338 .49709 L .16165 .50625 L p .631 .454 .809 r
F P
0 g
s
.16165 .50625 m .13751 .49821 L .16959 .48866 L p .631 .454 .809 r
F P
0 g
s
.65996 .32583 m .67752 .36097 L .64221 .36312 L p .761 .297 .545 r
F P
0 g
s
.64221 .36312 m .62467 .332 L .65996 .32583 L p .761 .297 .545 r
F P
0 g
s
.87171 .42429 m .88754 .45713 L .8515 .46917 L p .685 .271 .585 r
F P
0 g
s
.8515 .46917 m .83547 .43642 L .87171 .42429 L p .685 .271 .585 r
F P
0 g
s
.60683 .30051 m .62467 .332 L .58993 .33785 L p .742 .304 .578 r
F P
0 g
s
.58993 .33785 m .57197 .30863 L .60683 .30051 L p .742 .304 .578 r
F P
0 g
s
.81914 .40266 m .83547 .43642 L .7997 .44896 L p .685 .267 .578 r
F P
0 g
s
.7997 .44896 m .78315 .41493 L .81914 .40266 L p .685 .267 .578 r
F P
0 g
s
.55368 .27813 m .57197 .30863 L .53764 .31732 L p .721 .301 .595 r
F P
0 g
s
.53764 .31732 m .51917 .28806 L .55368 .27813 L p .721 .301 .595 r
F P
0 g
s
.76631 .37963 m .78315 .41493 L .74765 .42796 L p .693 .258 .553 r
F P
0 g
s
.74765 .42796 m .73053 .39109 L .76631 .37963 L p .693 .258 .553 r
F P
0 g
s
.71319 .35373 m .73053 .39109 L .6952 .4024 L p .73 .248 .496 r
F P
0 g
s
.6952 .4024 m .67752 .36097 L .71319 .35373 L p .73 .248 .496 r
F P
0 g
s
.50036 .25747 m .51917 .28806 L .48512 .2986 L p .707 .296 .603 r
F P
0 g
s
.48512 .2986 m .46613 .26872 L .50036 .25747 L p .707 .296 .603 r
F P
0 g
s
.29105 .47037 m .31306 .48048 L .28045 .48841 L p .656 .453 .788 r
F P
0 g
s
.28045 .48841 m .25806 .47924 L .29105 .47037 L p .656 .453 .788 r
F P
0 g
s
.37972 .46367 m .40035 .47617 L .36714 .48367 L p .684 .438 .765 r
F P
0 g
s
.36714 .48367 m .34615 .47237 L .37972 .46367 L p .684 .438 .765 r
F P
0 g
s
.4683 .45699 m .48766 .47184 L .45377 .48173 L p .682 .402 .753 r
F P
0 g
s
.45377 .48173 m .43408 .46735 L .4683 .45699 L p .682 .402 .753 r
F P
0 g
s
.20207 .47916 m .22551 .4881 L .19338 .49709 L p .637 .454 .804 r
F P
0 g
s
.19338 .49709 m .16959 .48866 L .20207 .47916 L p .637 .454 .804 r
F P
0 g
s
.44681 .23762 m .46613 .26872 L .43233 .28049 L p .697 .291 .605 r
F P
0 g
s
.43233 .28049 m .41283 .24979 L .44681 .23762 L p .697 .291 .605 r
F P
0 g
s
.85561 .39064 m .87171 .42429 L .83547 .43642 L p .689 .27 .579 r
F P
0 g
s
.83547 .43642 m .81914 .40266 L .85561 .39064 L p .689 .27 .579 r
F P
0 g
s
.11267 .48972 m .13751 .49821 L .10584 .50783 L p .628 .451 .813 r
F P
0 g
s
.10584 .50783 m .08067 .49966 L .11267 .48972 L p .628 .451 .813 r
F P
0 g
s
.64221 .29222 m .65996 .32583 L .62467 .332 L p .74 .293 .563 r
F P
0 g
s
.62467 .332 m .60683 .30051 L .64221 .29222 L p .74 .293 .563 r
F P
0 g
s
.69573 .3179 m .71319 .35373 L .67752 .36097 L p .737 .275 .536 r
F P
0 g
s
.67752 .36097 m .65996 .32583 L .69573 .3179 L p .737 .275 .536 r
F P
0 g
s
.58868 .26852 m .60683 .30051 L .57197 .30863 L p .727 .297 .583 r
F P
0 g
s
.57197 .30863 m .55368 .27813 L .58868 .26852 L p .727 .297 .583 r
F P
0 g
s
.80254 .36804 m .81914 .40266 L .78315 .41493 L p .694 .265 .565 r
F P
0 g
s
.78315 .41493 m .76631 .37963 L .80254 .36804 L p .694 .265 .565 r
F P
0 g
s
.74923 .34383 m .76631 .37963 L .73053 .39109 L p .711 .261 .539 r
F P
0 g
s
.73053 .39109 m .71319 .35373 L .74923 .34383 L p .711 .261 .539 r
F P
0 g
s
.53505 .24661 m .55368 .27813 L .51917 .28806 L p .713 .295 .595 r
F P
0 g
s
.51917 .28806 m .50036 .25747 L .53505 .24661 L p .713 .295 .595 r
F P
0 g
s
.32451 .46126 m .34615 .47237 L .31306 .48048 L p .664 .447 .783 r
F P
0 g
s
.31306 .48048 m .29105 .47037 L .32451 .46126 L p .664 .447 .783 r
F P
0 g
s
.41381 .45401 m .43408 .46735 L .40035 .47617 L p .68 .424 .766 r
F P
0 g
s
.40035 .47617 m .37972 .46367 L .41381 .45401 L p .68 .424 .766 r
F P
0 g
s
.23499 .46966 m .25806 .47924 L .22551 .4881 L p .643 .452 .799 r
F P
0 g
s
.22551 .4881 m .20207 .47916 L .23499 .46966 L p .643 .452 .799 r
F P
0 g
s
.48123 .22578 m .50036 .25747 L .46613 .26872 L p .703 .292 .6 r
F P
0 g
s
.46613 .26872 m .44681 .23762 L .48123 .22578 L p .703 .292 .6 r
F P
0 g
s
.14509 .47978 m .16959 .48866 L .13751 .49821 L p .631 .451 .81 r
F P
0 g
s
.13751 .49821 m .11267 .48972 L .14509 .47978 L p .631 .451 .81 r
F P
0 g
s
.83923 .35629 m .85561 .39064 L .81914 .40266 L p .695 .269 .572 r
F P
0 g
s
.81914 .40266 m .80254 .36804 L .83923 .35629 L p .695 .269 .572 r
F P
0 g
s
.42716 .20548 m .44681 .23762 L .41283 .24979 L p .697 .288 .601 r
F P
0 g
s
.41283 .24979 m .393 .21802 L .42716 .20548 L p .697 .288 .601 r
F P
0 g
s
.67809 .28314 m .69573 .3179 L .65996 .32583 L p .73 .283 .557 r
F P
0 g
s
.65996 .32583 m .64221 .29222 L .67809 .28314 L p .73 .283 .557 r
F P
0 g
s
.78569 .33289 m .80254 .36804 L .76631 .37963 L p .704 .267 .558 r
F P
0 g
s
.76631 .37963 m .74923 .34383 L .78569 .33289 L p .704 .267 .558 r
F P
0 g
s
.73195 .30828 m .74923 .34383 L .71319 .35373 L p .72 .27 .547 r
F P
0 g
s
.71319 .35373 m .69573 .3179 L .73195 .30828 L p .72 .27 .547 r
F P
0 g
s
.6242 .25884 m .64221 .29222 L .60683 .30051 L p .727 .291 .574 r
F P
0 g
s
.60683 .30051 m .58868 .26852 L .6242 .25884 L p .727 .291 .574 r
F P
0 g
s
.57022 .23593 m .58868 .26852 L .55368 .27813 L p .717 .293 .586 r
F P
0 g
s
.55368 .27813 m .53505 .24661 L .57022 .23593 L p .717 .293 .586 r
F P
0 g
s
.44839 .44322 m .4683 .45699 L .43408 .46735 L p .668 .413 .772 r
F P
0 g
s
.43408 .46735 m .41381 .45401 L .44839 .44322 L p .668 .413 .772 r
F P
0 g
s
.35847 .45166 m .37972 .46367 L .34615 .47237 L p .667 .438 .78 r
F P
0 g
s
.34615 .47237 m .32451 .46126 L .35847 .45166 L p .667 .438 .78 r
F P
0 g
s
.26836 .46006 m .29105 .47037 L .25806 .47924 L p .649 .449 .795 r
F P
0 g
s
.25806 .47924 m .23499 .46966 L .26836 .46006 L p .649 .449 .795 r
F P
0 g
s
.5161 .21418 m .53505 .24661 L .50036 .25747 L p .708 .291 .594 r
F P
0 g
s
.50036 .25747 m .48123 .22578 L .5161 .21418 L p .708 .291 .594 r
F P
0 g
s
.17793 .46981 m .20207 .47916 L .16959 .48866 L p .635 .451 .807 r
F P
0 g
s
.16959 .48866 m .14509 .47978 L .17793 .46981 L p .635 .451 .807 r
F P
0 g
s
.46176 .19313 m .48123 .22578 L .44681 .23762 L p .701 .289 .597 r
F P
0 g
s
.44681 .23762 m .42716 .20548 L .46176 .19313 L p .701 .289 .597 r
F P
0 g
s
.82261 .3214 m .83923 .35629 L .80254 .36804 L p .701 .27 .567 r
F P
0 g
s
.80254 .36804 m .78569 .33289 L .82261 .3214 L p .701 .27 .567 r
F P
0 g
s
.08707 .48084 m .11267 .48972 L .08067 .49966 L p .628 .45 .813 r
F P
0 g
s
.08067 .49966 m .05473 .49111 L .08707 .48084 L p .628 .45 .813 r
F P
0 g
s
.76861 .29756 m .78569 .33289 L .74923 .34383 L p .71 .271 .558 r
F P
0 g
s
.74923 .34383 m .73195 .30828 L .76861 .29756 L p .71 .271 .558 r
F P
0 g
s
.71446 .27308 m .73195 .30828 L .69573 .3179 L p .72 .277 .558 r
F P
0 g
s
.69573 .3179 m .67809 .28314 L .71446 .27308 L p .72 .277 .558 r
F P
0 g
s
.66022 .24873 m .67809 .28314 L .64221 .29222 L p .723 .285 .568 r
F P
0 g
s
.64221 .29222 m .6242 .25884 L .66022 .24873 L p .723 .285 .568 r
F P
0 g
s
.40717 .17241 m .42716 .20548 L .393 .21802 L p .696 .286 .598 r
F P
0 g
s
.393 .21802 m .37284 .18532 L .40717 .17241 L p .696 .286 .598 r
F P
0 g
s
.6059 .22521 m .6242 .25884 L .58868 .26852 L p .718 .289 .58 r
F P
0 g
s
.58868 .26852 m .57022 .23593 L .6059 .22521 L p .718 .289 .58 r
F P
0 g
s
.39292 .44134 m .41381 .45401 L .37972 .46367 L p .665 .429 .782 r
F P
0 g
s
.37972 .46367 m .35847 .45166 L .39292 .44134 L p .665 .429 .782 r
F P
0 g
s
.55144 .20268 m .57022 .23593 L .53505 .24661 L p .711 .29 .588 r
F P
0 g
s
.53505 .24661 m .5161 .21418 L .55144 .20268 L p .711 .29 .588 r
F P
0 g
s
.30221 .45019 m .32451 .46126 L .29105 .47037 L p .654 .444 .792 r
F P
0 g
s
.29105 .47037 m .26836 .46006 L .30221 .45019 L p .654 .444 .792 r
F P
0 g
s
.21122 .45976 m .23499 .46966 L .20207 .47916 L p .64 .449 .803 r
F P
0 g
s
.20207 .47916 m .17793 .46981 L .21122 .45976 L p .64 .449 .803 r
F P
0 g
s
.4968 .1809 m .5161 .21418 L .48123 .22578 L p .704 .288 .593 r
F P
0 g
s
.48123 .22578 m .46176 .19313 L .4968 .1809 L p .704 .288 .593 r
F P
0 g
s
.11984 .47051 m .14509 .47978 L .11267 .48972 L p .63 .449 .811 r
F P
0 g
s
.11267 .48972 m .08707 .48084 L .11984 .47051 L p .63 .449 .811 r
F P
0 g
s
.80574 .28615 m .82261 .3214 L .78569 .33289 L p .705 .273 .566 r
F P
0 g
s
.78569 .33289 m .76861 .29756 L .80574 .28615 L p .705 .273 .566 r
F P
0 g
s
.7513 .26218 m .76861 .29756 L .73195 .30828 L p .712 .275 .563 r
F P
0 g
s
.73195 .30828 m .71446 .27308 L .7513 .26218 L p .712 .275 .563 r
F P
0 g
s
.44194 .15959 m .46176 .19313 L .42716 .20548 L p .699 .287 .596 r
F P
0 g
s
.42716 .20548 m .40717 .17241 L .44194 .15959 L p .699 .287 .596 r
F P
0 g
s
.69674 .23802 m .71446 .27308 L .67809 .28314 L p .717 .281 .567 r
F P
0 g
s
.67809 .28314 m .66022 .24873 L .69674 .23802 L p .717 .281 .567 r
F P
0 g
s
.64207 .21423 m .66022 .24873 L .6242 .25884 L p .717 .285 .575 r
F P
0 g
s
.6242 .25884 m .6059 .22521 L .64207 .21423 L p .717 .285 .575 r
F P
0 g
s
.42787 .43015 m .44839 .44322 L .41381 .45401 L p .657 .421 .786 r
F P
0 g
s
.41381 .45401 m .39292 .44134 L .42787 .43015 L p .657 .421 .786 r
F P
0 g
s
.38684 .13848 m .40717 .17241 L .37284 .18532 L p .696 .285 .596 r
F P
0 g
s
.37284 .18532 m .35234 .15176 L .38684 .13848 L p .696 .285 .596 r
F P
0 g
s
.58728 .19113 m .6059 .22521 L .57022 .23593 L p .712 .287 .583 r
F P
0 g
s
.57022 .23593 m .55144 .20268 L .58728 .19113 L p .712 .287 .583 r
F P
0 g
s
.33655 .4399 m .35847 .45166 L .32451 .46126 L p .656 .438 .791 r
F P
0 g
s
.32451 .46126 m .30221 .45019 L .33655 .4399 L p .656 .438 .791 r
F P
0 g
s
.24498 .44955 m .26836 .46006 L .23499 .46966 L p .644 .446 .801 r
F P
0 g
s
.23499 .46966 m .21122 .45976 L .24498 .44955 L p .644 .446 .801 r
F P
0 g
s
.53233 .16872 m .55144 .20268 L .5161 .21418 L p .707 .288 .589 r
F P
0 g
s
.5161 .21418 m .4968 .1809 L .53233 .16872 L p .707 .288 .589 r
F P
0 g
s
.15305 .4601 m .17793 .46981 L .14509 .47978 L p .634 .448 .809 r
F P
0 g
s
.14509 .47978 m .11984 .47051 L .15305 .4601 L p .634 .448 .809 r
F P
0 g
s
.47717 .14683 m .4968 .1809 L .46176 .19313 L p .702 .286 .593 r
F P
0 g
s
.46176 .19313 m .44194 .15959 L .47717 .14683 L p .702 .286 .593 r
F P
0 g
s
.78862 .25064 m .80574 .28615 L .76861 .29756 L p .707 .275 .568 r
F P
0 g
s
.76861 .29756 m .7513 .26218 L .78862 .25064 L p .707 .275 .568 r
F P
0 g
s
.06068 .47159 m .08707 .48084 L .05473 .49111 L p .627 .448 .814 r
F P
0 g
s
.05473 .49111 m .028 .4822 L .06068 .47159 L p .627 .448 .814 r
F P
0 g
s
.73375 .22671 m .7513 .26218 L .71446 .27308 L p .712 .278 .569 r
F P
0 g
s
.71446 .27308 m .69674 .23802 L .73375 .22671 L p .712 .278 .569 r
F P
0 g
s
.67875 .20285 m .69674 .23802 L .66022 .24873 L p .714 .282 .573 r
F P
0 g
s
.66022 .24873 m .64207 .21423 L .67875 .20285 L p .714 .282 .573 r
F P
0 g
s
.42179 .12523 m .44194 .15959 L .40717 .17241 L p .698 .285 .594 r
F P
0 g
s
.40717 .17241 m .38684 .13848 L .42179 .12523 L p .698 .285 .594 r
F P
0 g
s
.37138 .42903 m .39292 .44134 L .35847 .45166 L p .654 .432 .792 r
F P
0 g
s
.35847 .45166 m .33655 .4399 L .37138 .42903 L p .654 .432 .792 r
F P
0 g
s
.62362 .1794 m .64207 .21423 L .6059 .22521 L p .712 .285 .58 r
F P
0 g
s
.6059 .22521 m .58728 .19113 L .62362 .1794 L p .712 .285 .58 r
F P
0 g
s
.27921 .43908 m .30221 .45019 L .26836 .46006 L p .646 .443 .799 r
F P
0 g
s
.26836 .46006 m .24498 .44955 L .27921 .43908 L p .646 .443 .799 r
F P
0 g
s
.56834 .15648 m .58728 .19113 L .55144 .20268 L p .708 .286 .586 r
F P
0 g
s
.55144 .20268 m .53233 .16872 L .56834 .15648 L p .708 .286 .586 r
F P
0 g
s
.18671 .44957 m .21122 .45976 L .17793 .46981 L p .637 .447 .807 r
F P
0 g
s
.17793 .46981 m .15305 .4601 L .18671 .44957 L p .637 .447 .807 r
F P
0 g
s
.51288 .13406 m .53233 .16872 L .4968 .1809 L p .704 .286 .59 r
F P
0 g
s
.4968 .1809 m .47717 .14683 L .51288 .13406 L p .704 .286 .59 r
F P
0 g
s
.0938 .46089 m .11984 .47051 L .08707 .48084 L p .629 .448 .812 r
F P
0 g
s
.08707 .48084 m .06068 .47159 L .0938 .46089 L p .629 .448 .812 r
F P
0 g
s
.77126 .21486 m .78862 .25064 L .7513 .26218 L p .708 .277 .571 r
F P
0 g
s
.7513 .26218 m .73375 .22671 L .77126 .21486 L p .708 .277 .571 r
F P
0 g
s
.4572 .11198 m .47717 .14683 L .44194 .15959 L p .7 .285 .592 r
F P
0 g
s
.44194 .15959 m .42179 .12523 L .4572 .11198 L p .7 .285 .592 r
F P
0 g
s
.71594 .19104 m .73375 .22671 L .69674 .23802 L p .711 .28 .573 r
F P
0 g
s
.69674 .23802 m .67875 .20285 L .71594 .19104 L p .711 .28 .573 r
F P
0 g
s
.40672 .41749 m .42787 .43015 L .39292 .44134 L p .649 .427 .796 r
F P
0 g
s
.39292 .44134 m .37138 .42903 L .40672 .41749 L p .649 .427 .796 r
F P
0 g
s
.66047 .16738 m .67875 .20285 L .64207 .21423 L p .711 .283 .578 r
F P
0 g
s
.64207 .21423 m .62362 .1794 L .66047 .16738 L p .711 .283 .578 r
F P
0 g
s
.31394 .42822 m .33655 .4399 L .30221 .45019 L p .647 .439 .798 r
F P
0 g
s
.30221 .45019 m .27921 .43908 L .31394 .42822 L p .647 .439 .798 r
F P
0 g
s
.60486 .1441 m .62362 .1794 L .58728 .19113 L p .708 .285 .583 r
F P
0 g
s
.58728 .19113 m .56834 .15648 L .60486 .1441 L p .708 .285 .583 r
F P
0 g
s
.22085 .43884 m .24498 .44955 L .21122 .45976 L p .639 .445 .805 r
F P
0 g
s
.21122 .45976 m .18671 .44957 L .22085 .43884 L p .639 .445 .805 r
F P
0 g
s
.54907 .12122 m .56834 .15648 L .53233 .16872 L p .705 .285 .587 r
F P
0 g
s
.53233 .16872 m .51288 .13406 L .54907 .12122 L p .705 .285 .587 r
F P
0 g
s
.12738 .45007 m .15305 .4601 L .11984 .47051 L p .632 .447 .811 r
F P
0 g
s
.11984 .47051 m .0938 .46089 L .12738 .45007 L p .632 .447 .811 r
F P
0 g
s
.49308 .09868 m .51288 .13406 L .47717 .14683 L p .702 .285 .59 r
F P
0 g
s
.47717 .14683 m .4572 .11198 L .49308 .09868 L p .702 .285 .59 r
F P
0 g
s
.75363 .17878 m .77126 .21486 L .73375 .22671 L p .708 .279 .574 r
F P
0 g
s
.73375 .22671 m .71594 .19104 L .75363 .17878 L p .708 .279 .574 r
F P
0 g
s
.69784 .15503 m .71594 .19104 L .67875 .20285 L p .709 .281 .577 r
F P
0 g
s
.67875 .20285 m .66047 .16738 L .69784 .15503 L p .709 .281 .577 r
F P
0 g
s
.34916 .41689 m .37138 .42903 L .33655 .4399 L p .646 .434 .799 r
F P
0 g
s
.33655 .4399 m .31394 .42822 L .34916 .41689 L p .646 .434 .799 r
F P
0 g
s
.64189 .13148 m .66047 .16738 L .62362 .1794 L p .708 .283 .581 r
F P
0 g
s
.62362 .1794 m .60486 .1441 L .64189 .13148 L p .708 .283 .581 r
F P
0 g
s
.25547 .42786 m .27921 .43908 L .24498 .44955 L p .641 .442 .804 r
F P
0 g
s
.24498 .44955 m .22085 .43884 L .25547 .42786 L p .641 .442 .804 r
F P
0 g
s
.58577 .10823 m .60486 .1441 L .56834 .15648 L p .706 .284 .585 r
F P
0 g
s
.56834 .15648 m .54907 .12122 L .58577 .10823 L p .706 .284 .585 r
F P
0 g
s
.16142 .43909 m .18671 .44957 L .15305 .4601 L p .634 .446 .809 r
F P
0 g
s
.15305 .4601 m .12738 .45007 L .16142 .43909 L p .634 .446 .809 r
F P
0 g
s
.52946 .08529 m .54907 .12122 L .51288 .13406 L p .703 .284 .588 r
F P
0 g
s
.51288 .13406 m .49308 .09868 L .52946 .08529 L p .703 .284 .588 r
F P
0 g
s
.73572 .14231 m .75363 .17878 L .71594 .19104 L p .707 .28 .577 r
F P
0 g
s
.71594 .19104 m .69784 .15503 L .73572 .14231 L p .707 .28 .577 r
F P
0 g
s
.38489 .40501 m .40672 .41749 L .37138 .42903 L p .642 .43 .802 r
F P
0 g
s
.37138 .42903 m .34916 .41689 L .38489 .40501 L p .642 .43 .802 r
F P
0 g
s
.67944 .11859 m .69784 .15503 L .66047 .16738 L p .707 .282 .58 r
F P
0 g
s
.66047 .16738 m .64189 .13148 L .67944 .11859 L p .707 .282 .58 r
F P
0 g
s
.2906 .41652 m .31394 .42822 L .27921 .43908 L p .641 .439 .804 r
F P
0 g
s
.27921 .43908 m .25547 .42786 L .2906 .41652 L p .641 .439 .804 r
F P
0 g
s
.62299 .09505 m .64189 .13148 L .60486 .1441 L p .706 .283 .583 r
F P
0 g
s
.60486 .1441 m .58577 .10823 L .62299 .09505 L p .706 .283 .583 r
F P
0 g
s
.19595 .42791 m .22085 .43884 L .18671 .44957 L p .636 .444 .808 r
F P
0 g
s
.18671 .44957 m .16142 .43909 L .19595 .42791 L p .636 .444 .808 r
F P
0 g
s
.56635 .07176 m .58577 .10823 L .54907 .12122 L p .704 .283 .586 r
F P
0 g
s
.54907 .12122 m .52946 .08529 L .56635 .07176 L p .704 .283 .586 r
F P
0 g
s
.71751 .10539 m .73572 .14231 L .69784 .15503 L p .705 .281 .58 r
F P
0 g
s
.69784 .15503 m .67944 .11859 L .71751 .10539 L p .705 .281 .58 r
F P
0 g
s
.32623 .40478 m .34916 .41689 L .31394 .42822 L p .64 .436 .805 r
F P
0 g
s
.31394 .42822 m .2906 .41652 L .32623 .40478 L p .64 .436 .805 r
F P
0 g
s
.66072 .08163 m .67944 .11859 L .64189 .13148 L p .705 .282 .582 r
F P
0 g
s
.64189 .13148 m .62299 .09505 L .66072 .08163 L p .705 .282 .582 r
F P
0 g
s
.23097 .41647 m .25547 .42786 L .22085 .43884 L p .637 .442 .807 r
F P
0 g
s
.22085 .43884 m .19595 .42791 L .23097 .41647 L p .637 .442 .807 r
F P
0 g
s
.60375 .05804 m .62299 .09505 L .58577 .10823 L p .704 .283 .585 r
F P
0 g
s
.58577 .10823 m .56635 .07176 L .60375 .05804 L p .704 .283 .585 r
F P
0 g
s
.36237 .39257 m .38489 .40501 L .34916 .41689 L p .637 .433 .807 r
F P
0 g
s
.34916 .41689 m .32623 .40478 L .36237 .39257 L p .637 .433 .807 r
F P
0 g
s
.69899 .06795 m .71751 .10539 L .67944 .11859 L p .704 .281 .581 r
F P
0 g
s
.67944 .11859 m .66072 .08163 L .69899 .06795 L p .704 .281 .581 r
F P
0 g
s
.26649 .40471 m .2906 .41652 L .25547 .42786 L p .636 .439 .808 r
F P
0 g
s
.25547 .42786 m .23097 .41647 L .26649 .40471 L p .636 .439 .808 r
F P
0 g
s
.64168 .04411 m .66072 .08163 L .62299 .09505 L p .703 .282 .584 r
F P
0 g
s
.62299 .09505 m .60375 .05804 L .64168 .04411 L p .703 .282 .584 r
F P
0 g
s
.30253 .39259 m .32623 .40478 L .2906 .41652 L p .635 .437 .809 r
F P
0 g
s
.2906 .41652 m .26649 .40471 L .30253 .39259 L p .635 .437 .809 r
F P
0 g
s
.68015 .02993 m .69899 .06795 L .66072 .08163 L p .703 .281 .583 r
F P
0 g
s
.66072 .08163 m .64168 .04411 L .68015 .02993 L p .703 .281 .583 r
F P
0 g
s
.3391 .38006 m .36237 .39257 L .32623 .40478 L p .633 .435 .811 r
F P
0 g
s
.32623 .40478 m .30253 .39259 L .3391 .38006 L p .633 .435 .811 r
F P
0 g
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.05093 .24975 m
.0557 .25425 L
s
gsave
.04138 .24075 -71.5625 -10.7994 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.19287 .19417 m
.19742 .1989 L
s
gsave
.18378 .18471 -71.1141 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -67.576 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.50225 .07302 m
.50623 .07824 L
s
gsave
.49429 .06259 -67.0601 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.67126 .00684 m
.67489 .01231 L
s
gsave
.664 -0.00409 -66.9268 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07869 .23888 m
.08153 .2416 L
s
.10676 .22788 m
.10957 .23064 L
s
.13514 .21677 m
.13793 .21955 L
s
.16384 .20553 m
.1666 .20834 L
s
.22223 .18267 m
.22493 .18554 L
s
.25192 .17104 m
.25459 .17394 L
s
.28195 .15928 m
.28459 .16221 L
s
.31233 .14739 m
.31494 .15034 L
s
.37416 .12318 m
.37669 .12619 L
s
.40562 .11086 m
.40812 .1139 L
s
.43745 .0984 m
.43991 .10147 L
s
.46966 .08579 m
.47208 .08889 L
s
.53524 .06011 m
.53759 .06327 L
s
.56863 .04703 m
.57093 .05022 L
s
.60242 .0338 m
.60468 .03702 L
s
.63663 .0204 m
.63885 .02365 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  FormatType->StandardForm,
  ImageSize->{180, 145.938},
  ImageMargins->{{103, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002d0000TA000`40O003h00O]7oo002dOol00;Ao
o`00Lgoo0P00?goo001dOol00`00Oomoo`0mOol007Eoo`03001oogoo03aoo`00M7oo0P00?Woo002d
Ool007Yoo`8000Eoo`D002ioo`00Mgoo0`0000=oo`00Ool027oo00<007ooOol0;7oo001eOol20002
Ool00`00Ool000020008Ool00`00Oomoo`0[Ool0079oo`<000Ioo`<000Moo`8002eoo`00L7oo0P00
00=oo`00Ool01Woo00<007oo0000=Woo001]Ool30008Ool40002Ool00`00Oomoo`0cOol006]oo`<0
00Moo`<0009I4P8000=oo`03001oogoo039oo`00F7oo00<007ooOol03Goo0`001goo0`001UTB00D0
07ooOomoo`0003Aoo`00F7oo00<007ooOol02Woo10001goo0P0000=I<P00FA801UTB0P000goo00<0
07ooOol0<Goo001HOol00`00Oomoo`08Ool20009Ool20004FC800`00FA9I4P05FA800`00Oomoo`02
Ool00`00Oomoo`0`Ool005Qoo`03001oogoo00Eoo`<000Uoo`8000II<P03001I4UTB00EI4P03001o
ogoo009oo`80035oo`00GWoo0P000Woo00<007ooOol017oo0`0000=I<P00FC801UTb00<005TBFA80
15TB0P000goo0P00<Goo001KOol30008Ool30005FC800`00FC9I<P05FC801000FA9I4UTB10001Goo
00<007ooOol0;Woo001IOol20002Ool00`00Oomoo`03Ool300000eTb001I<P05FC800`00FC9I<P05
FC801000FA8000000UTB00<005TB000017oo00<007ooOol0;Woo001FOol30007Ool30005FC800`00
FC9I<P04FC800`00FC9I<P03FC830004FA800`00FA800005Ool2000^Ool005Aoo`800003Ool007oo
00Eoo`800003FC8005Tb00EI<P03001I<UTb00AI<P03001I<UTb00<0009I<P03001I4UTB009I4P04
001I4UTB0004Ool00`00Oomoo`0]Ool0055oo`<000Qoo`8000AI<P03001I<UTb00AI<P03001I<UTb
00=I<P<000II<P05001I4UTBFA800002FA800`00Oomoo`03Ool00`00Oomoo`0/Ool003aoo`80015o
o`@000Moo`8000II<P03001I<UTb00AI<P03001I<UTb00<00003FC8005Tb00II<P05001I4UTBFA80
0002FA800`00Oomoo`04Ool00`00Oomoo`0[Ool003aoo`03001oo`0000eoo`<000Qoo`<00003FC80
05Tb00II<P03001I<UTb00=I<P<000EI<P03001I<UTb00EI<P04001I4UTB0002FA820005Ool2000/
Ool003aoo`03001oo`0000]oo`<000Moo`<000EI<P03001I<UTb00AI<P03001I<UTb00<00003FC80
05Tb00EI<P03001I<UTb00EI<P03001I4UTB00<00003FA8007oo00Eoo`03001oogoo00Aoo`<00003
Ool007oo021oo`00?Goo0P0027oo0`001goo0`0000=I<P00FC801ETb00<005TbFC8015Tb0`001ETb
00<005TbFC8015Tb00<005TbFC800eTb1@0015TB00<007ooOol017oo00<007ooOol01goo00<007oo
Ool07goo0014Ool40006Ool30005FC800`00FC9I<P04FC801000FC9I<UTb0P0000=I<P00FC801ETb
00<005TbFC8015Tb00<005TbFC800`000UTb00@005TBFA8000=I4P03001oogoo00Aoo`03001oogoo
00Moo`03001oogoo01moo`00@Woo0P001goo0`0000=I<`00FC801ETb00<005TbFC8015Tb00@005Tb
000000AI<P03001I<UTb00AI<P03001I<UTb00=I<P<000II<P03001I4P0000AI4P03001oogoo00Ao
o`8000Moo`03001oogoo01moo`00?goo10001Goo0`001ETc00<005TbFC8015Tb00<005TbFC800eTb
0P001UTb00<005TbFC8015Tb00<005TbFC800`0000=I<P00FC801UTb00<005TB000015TB00<007oo
Ool01Goo00<007ooOol09goo000mOol20003Ool00`00Oomoo`0300000eTc001I<`05FC<00`00FC9I
<P04FC800`00FC9I<P0300000eTb001I<P06FC800`00FC9I<P03FC830005FC800`00FC9I<P05FC82
0004FA820006Ool00`00Oomoo`0WOol003Yoo`@000Eoo`8000EI<`03001I<eTc00AI<`03001I<UTb
00=I<P<000EI<P03001I<UTb00AI<P03001I<UTb00<00003FC8005Tb00II<P03001I<UTb00AI<P80
0006FA800000001I4P001goo00<007ooOol09Woo000hOol20009Ool00`00FC=I<`04FC<00`00FC=I
<`04FC<00`00FC9I<P0300000eTb001I<P06FC800`00FC9I<P03FC830005FC800`00FC9I<P04FC80
0`00FC9I<P04FC830005FA800`00Oomoo`04Ool2000WOol001moo`<00003Ool007oo011oo`@000]o
o`03001I<eTc00AI<`03001I<eTc00=I<`<000EI<P03001I<UTb00AI<P03001I<UTb00<00003FC80
05Tb00EI<P03001I<UTb00EI<P03001I<UTb00<00003FA8005TB00EI4P03001oogoo00Eoo`03001o
ogoo02Eoo`008goo00<007ooOol03Goo0P0047oo00<005TcFC<00eTc00<005TcFC<00`0000=I<`00
FC801UTb00<005TbFC800eTb0`001ETb00<005TbFC8015Tb00<005TbFC800eTb100015TB0P001UTB
00<007ooOol01Goo00<007ooOol097oo000SOol00`00Oomoo`0:Ool4000AOol00`00FC=I<`03FC<3
0005FC<00`00FC9I<P04FC800`00FC9I<P0300000eTb001I<P05FC800`00FC9I<P04FC800`00FC9I
<P030002FC800`00FA9I4P03FA820006FA800`00Oomoo`06Ool00`00Oomoo`0SOol002=oo`03001o
ogoo00Qoo`8001Ioo`03001I<`0000800003FC<005Tc00II<`03001I<UTb00=I<P<000EI<P03001I
<UTb00AI<P03001I<UTb00=I<P<000II<P03001I4UTB009I4P03001I4P0000EI4P8000Moo`03001o
ogoo02=oo`00:goo100067oo00<005TcFC<00eTc00<005TcFC<015Tc00<005TbFC800`0000=I<P00
FC801ETb00<005TbFC8015Tb00<005TbFC800`0000=I<P00FC801UTb00<005TBFA800UTB00<005TB
00000UTB0`0000=I4P00Ool01goo00<007ooOol08Woo000YOol2000LOol00`00FC=I<`04FC<00`00
FC=I<`03FC<30005FC800`00FC9I<P04FC800`00FC9I<P03FC830005FC800`00FC9I<P05FC801P00
FA9I4UTB001I4P<000EI4P03001oogoo00Ioo`03001oogoo025oo`009Woo10007Woo00<005TcFC<0
15Tc00<005Tc00000P0000=I<`00FC801ETb00<005TbFC8015Tb00<005TbFC800`0000=I<P00FC80
1ETb00<005TbFC801ETb00<005TBFA800`0000=I4P00FA801ETB00<007ooOol01Woo0P008Woo000T
Ool2000ROol00`00FC=I<`04FC<20005FC<00`00FC9I<P04FC800`00FC9I<P03FC830005FC800`00
FC9I<P04FC800`00FC9I<P03FC8400000eTB001I4P02FA800`00FA9I4P04FA800`00Oomoo`06Ool0
0`00Oomoo`0POol0025oo`@002Aoo`04001I<eTcFC<200000eTc001I<`05FC<00`00FC9I<P03FC80
0`00FC9I<P0300000eTb001I<P05FC800`00FC9I<P04FC800`00FC9I<P030002FC801@00FA9I4UTB
00000UTB00<005TBFA8015TB00<007ooOol01goo00<007ooOol07goo000NOol3000XOol01000FC<0
000015Tc00<005TcFC<00eTc00<005TbFC800eTb0`001ETb00<005TbFC8015Tb00<005TbFC800eTb
0`001UTb00@005TBFA8000=I4P03001I4UTB00=I4P8000Qoo`80021oo`001goo1@0047oo0P0000=o
o`00Ool0:Goo00<005TcFC<015Tc00<005TcFC<015Tc00<005Tb00000P0000=I<`00FC801ETb00<0
05TbFC8015Tb00<005TbFC800`0000=I<P00FC801UTb00@005TBFA8000=I4P03001I4UTB00<00003
FA8007oo00Moo`8000Eoo`8001Uoo`002goo00<007ooOol02goo0`00;Woo00<005TcFC<01ETc00<0
05TcFC<00eTc0P001ETc00<005TbFC8015Tb00<005TbFC800eTb0`001ETb00<005TbFC801ETb00<0
05TB00000eTB0`001ETB00<007ooOol01Woo00<007ooOol00goo00<007oo000067oo000<Ool00`00
Oomoo`08Ool20002Ool00`00Oomoo`0]Ool00`00FC=I<`04FC<00`00FC=I<`0300000eTc001I<`05
FC<00`00FC9I<P03FC800`00FC9I<P0300000eTb001I<P06FC800`00FC9I<P04FC800`00FA800003
00000eTB001I4P05FA800`00Oomoo`07Ool00`00Oomoo`02Ool00`00Ool0000HOol000]oo`8000Mo
o`<003Eoo`03001I<eTc00=I<`<000EI<`03001I<eTc00AI<`04001I<UTbFC840005FC800`00FC9I
<P04FC800`00FC9I<P04FC830005FA800`00FA9I4P04FA800`00Oomoo`06Ool20004Ool2000HOol0
019oo`8003Qoo`03001I<eTc00<00003FC<005Tc00II<`03001I<eTc00=I<`@0009I<P03001I<UTb
00EI<P03001I<UTb00AI<P03001I<UTb00<00003FA80000000EI4P03001I4UTB00AI4P03001oogoo
00Moo`03001oogoo01aoo`003goo0`00>goo0P001ETc00<005TcFC<015Tc00<005TcFC<00`0000=I
<`00FC8015Tb00<005TbFC801ETb00@005TbFC9I<PD00006FA800000001I4P001UTB00<005TBFA80
0eTB0P002Goo00<007ooOol06goo000>Ool20002Ool00`00Oomoo`0hOol00`00FC=I<`05FC<00`00
FC=I<`03FC<30005FC<00`00FC9I<P03FC800`00FC9I<P04FC840003GC830004FA820005FA800`00
FA9I4P0300000eTB001oo`09Ool00`00Oomoo`0JOol000ioo`<003eoo`03001I<eTc00AI<`03001I
<eTc00<00003FC<005Tc00EI<`03001I<UTb00AI<P03001I<UTb00<00004GC8005dbGC8300000edb
001I4P05FA820004FA830005FA800`00Oomoo`07Ool00`00Oomoo`0JOol000ioo`800003Ool007oo
03aoo`03001I<eTc00=I<`<000EI<`03001I<eTc00AI<`03001I<UTb00=I<P<000AM<P<000EM<P03
001I4UTB00=I4P03001I4P0000<00003FA8005TB00EI4P03001oogoo00Qoo`03001oogoo01Uoo`00
3Woo00D007ooOomoo`0003aoo`03001I<eTc00<00003FC<005Tc00II<`03001I<eTc00=I<`03001I
<UTb00<00004GC8005dbGC8300000edb001M<P05GC801000FA9I4UTB1@001ETB00<005TBFA8015TB
00<007ooOol027oo0P006Goo0003Ool300000goo00000004Ool20004Ool00`00Oomoo`0jOol20005
FC<00`00FC=I<`04FC<01000FC=I<eTc1@0015db0`001Edb00<005dbGC800edb10000edA00<005TB
000015TB00<005TBFA8015TB00<007ooOol027oo00<007ooOol067oo0008Ool00`00Oomoo`02Ool2
0005Ool00`00Oomoo`0iOol00`00FC=I<`05FC<00`00FC=I<`03FC<40003GC<00`00GC9M<P030002
GC800`00GC9M<P03GC800`00GC9M<P0300000eda001M4@05GA400`00FA800004FA800`00FA9I4P03
FA82000:Ool00`00Oomoo`0GOol000Uoo`05001oogooOol00007Ool00`00Oomoo`0iOol00`00FC=I
<`04FC<00`00FC=I<`0300000eTc001M<`05GC<20005GC801000GC9M<Udb1@001Eda00<005dAGA40
0edA00<005TB000015TB00<005TBFA800`0000=I4P00Ool02Woo00<007ooOol05Woo0008Ool20003
Ool20007Ool00`00Oomoo`0iOol00`00FC=I<`03FC<30005FC<00`00GC=M<`0300000edc001M<P04
GC840003GC800`00GC5M<@04GC400`00GA5M4@04GA400`00FA800003FA830005FA800`00Oomoo`08
Ool2000GOol000eoo`03001oogoo00Moo`03001oogoo03Uoo`03001I<`0000800003FC<005Tc00EI
<`<000AM<`03001M<Udb00<00003GC8005db00EM<P03001M<Eda00=M<@03001M4EdA00AM4@03001I
4UTB00<00003FA4005TB00EI4P03001oogoo00Uoo`03001oogoo01Eoo`003Goo0P002Goo00<007oo
Ool0>Goo00<005TcFC<00eTc00<005TcFC<00`0000=I<`00GC<00Udc1@001Edb00<005dbGC800edb
00<005daGC4015da00@005dAGA5M4@D00003FA4005TA009I4@03001I4UTB00AI4P03001oogoo00Uo
o`03001oogoo01Aoo`003Goo0P002Woo00<007ooOol0>7oo00<005TcFC<00eTc0`0015Tc10000edc
00<005dbGC8015db00<005dbGC800edb00<005daGC400eda1@000edA00@005TAFA4000=I4@03001I
4UTB00AI4P03001oogoo00Uoo`8001Eoo`0037oo00<007ooOol02goo0P00>Goo00<005Tc00000P00
00AI<`00FC=I<`<00003GC<005dc00EM<`03001M<Udb00AM<P03001M<Udb00=M<P03001M<@000080
0003GA4005dA00IM4@04001I4ETA0002FA400`00FA9I4P03FA83000;Ool00`00Oomoo`04Ool00`00
Oomoo`0<Ool0009oo`<0009oo`03001oogoo009oo`8000ioo`03001oogoo03Eoo`<000AI<`<000EM
<`03001M<edc00AM<`03001M<Udb00=M<P04001M<UdbGC840005GA400`00GA5M4@04GA401@00FA5I
4ETA00000UTA00<005TB00000P000UTB00<007ooOol02Woo00<007ooOol00goo00<007ooOol037oo
0007Ool00`00Oomoo`02Ool2000?Ool00`00Oomoo`0aOol30002Ool00`00FC<0000200000eTd001M
<`06GC<00`00GC=M<`03GC<01000GC9M<Udb1P000V4a00<005dAGA4015dA00<005dAGA4015dA00H0
05TAFA5I4@00FA430006FA800`00Oomoo`09Ool20004Ool00`00Oomoo`0<Ool000Moo`03001oogoo
009oo`03001oogoo00moo`03001oogoo02ioo`8000Ioo`03001I=5Td00=I=003001M<edc00AM<`04
001M<edcGC<60003HE800`00HC5Q<@03HC400`00GA5M4@04GA400`00GA5M4@04GA400`00FA400002
00000eTA001I4P06FA800`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool000Moo`03001o
ogoo009oo`80015oo`03001oogoo02Yoo`<000Qoo`03001I=5Td00AI=004001M<edcGC<60003HE<0
0`00HE9QDP04HE800`00HC5Q<@03HC400`00GA5M4@03GA401000GA5M4EdA1@000eTA00<005TA0000
1UTB00<007ooOol02goo00<007ooOol047oo000<Ool00`00Oomoo`0AOol00`00Oomoo`0VOol3000<
Ool00`00FCAI=003FC@40003GE<00`00HE=QD`04HE<00`00HE9QDP04HE800`00HC5Q<@02HC401000
GA5M4EdA1P000eTA00<005TAFA400eTA0P001eTB00<007ooOol02Woo0P004Goo000;Ool2000DOol0
0`00Oomoo`0ROol3000@Ool00`00FC@0000200000eUD001MD`05GE<00`00HE=QD`04HE<00`00HE9Q
DP03HE801000HC5Q<F4a1@000ec_00<005TAFA4015TA00<005TAFA400UTA00<005TA00001ETB0P00
3Goo00<007ooOol03goo000;Ool2000EOol00`00Oomoo`0NOol3000DOol00`00FEAIE003FE@00`00
GE=MD`04GE<01000HE=QDf5C30000VU@00<005c_G>l015c_00<005TAFA400eTA00<005TAFA400eTA
0P000UTB0`0000=I4P00Ool037oo00<007ooOol03goo000;Ool00`00Oomoo`0EOol00`00Oomoo`0J
Ool3000GOol00`00FEAIE004FE@01000GE=MDeeC1P000fEc00<006UaJG400fUa00<006U@JE000fU@
00<005c_G>l00ec_00<005TAFA4015TA00<005TAFA400eTA0`001ETB00<007ooOol02goo0P003goo
0004Ool20005Ool2000GOol00`00Oomoo`0FOol3000KOol00`00FEAIE003FE@40003GG@00`00IG=U
L`04IG<00`00JG5YL@03JG400`00JE1YD002JE000`00G>mLk`04G>l00`00FA5I4@03FA400`00FA5I
4@050007FA800`00Oomoo`0;Ool00`00Oomoo`0=Ool000Aoo`03001oo`0000Aoo`03001oogoo01Mo
o`03001oogoo019oo`<000=oo`<001Uoo`03001IE00000800003FED005ed00EMM003001ULfEc00AU
L`03001YLFUa009YL@03001YD6U@00=YD003001Lkec_00=Lk`04001I4ETAFA450004FA820006FA80
0`00Oomoo`0;Ool00`00Oomoo`0=Ool000Aoo`03001oo`0000Aoo`8001Uoo`03001oogoo00ioo`<0
00=oo`<000=A^@8001Qoo`03001IEEUE00=IE@03001MM5ed00AMM004001ULfEcIG<;0002JE000`00
G>mLk`03G>l40003FA400`00FA9I4P04FA820005FA82000=Ool2000=Ool000Eoo`8000Aoo`03001o
ogoo01Uoo`8000aoo`8000=oo`<000MA^@<001Moo`03001IEEUE00=IE@04001MM5edGG@6000;Ool3
0002G>l300000eS`001I4@05FA400`00FA9I4P04FA800`00FA9I4P0300000eTB001oo`0=Ool00`00
Oomoo`0;Ool000Yoo`8001eoo`03001oogoo00Ioo`<0009oo`<000=A^@80009A^@<000=A^@8001Io
o`04001IEEUEFED5000DOol20005F?000`00FA5I4@04FA400`00FA9I4P03FA830005FA800`00Oomo
o`0;Ool00`00Oomoo`0;Ool000Yoo`8001ioo`03001oogoo009oo`<0009oo`<000MA^@<000MA^@<0
01Aoo`@001Uoo`03001Hl5S`00AHl003001I4ETA00AI4@03001I4UTB00<00003EA8005TB00EI4P03
001oogoo00aoo`03001oogoo00=oo`8000Eoo`002Woo00<007ooOol07Woo10000Woo0`000e7I0P00
0U6i0`000e6i0P000U6i0`000e6i00<007ooOol03Woo0`000UEf00<007ooOol05goo00<003Sh0000
1US`00<005TAFA400eTA0`001EDB00<005TBFA8015TB00<007ooOol037oo00<007ooOol00goo00<0
07ooOol00goo000:Ool2000MOol4000017oo000000001e7I0`001e6i0`001U6i0`0037oo0P001UEf
00<007ooOol05Goo00@003Sh>?P000IHl004001I4ETAFA4200000eDB001E4P05EA820005FA800`00
Oomoo`0<Ool20005Ool00`00Oomoo`02Ool000Yoo`03001oogoo01Uoo`<0009oo`<000=Af@80009A
f@<000=Af@80009A^@<000=A^@03001A^E6i00<000=A^@8000Qoo`800003DEL005Ef00EEMP8001Eo
o`03000hn3Sh008hn003001Hl5S`00=Hl004001I4@000004EA800`00EA9E4P04EA800`00FA9I4P03
FA82000=Ool20004Ool20004Ool000Aoo`03001oogoo00=oo`03001oogoo01Ioo`T000AAf@H000AA
f@D000IA^@<000MA^@<000Aoo`8000AAE`03001EMUEf00<0009EM`03001oogoo015oo`03000hn3Sh
00<hn003001Hl5S`00=Hl08000IE4P03001E4UDB00AE4P800006FA800000001E4P003Goo0`002Goo
0004Ool00`00Oomoo`02Ool2000EOol60006DMT40006DMT40005DMT00`00DKUA^@030003DKT20002
DKT30003EKT01000Ool000001U5G0`001UEg00<007ooOol03Woo0P001SSh00<005S`F?000`0000=A
4`00EA801UDB00<005DBEA800eDB0`001EDB00<007ooOol01goo0`000Woo00<007ooOol01goo0004
Ool00`00Oomoo`02Ool2000COol40003DMT20002DMT30003DMT20002DMT30003DMT20003DMT40007
DKT30006EKT300000dUH001AE`02DEL20002CGP00`00EGMEM`04EGL2000>Ool00`00@CP00006>?P3
0005DA<00`00EA9E4P04EA800`00EA9E4P0300000eDB00000006EA800`00Oomoo`03Ool30005Ool0
0`00Oomoo`07Ool000Aoo`03001oogoo009oo`80011oo`@000MAf@<000MAf@<000MAf@@000AAf@80
009A^@<000=E^@03001E^EFi00<000=E^0050019F000DEL00005CGP00`00EGMEM`030002DIP00`00
Oomoo`09Ool20003@CP00`00>?Phn002>?P00`00CAD00007DA<00`00EA9E4P03EA830005EA820005
EA800`00Ool000030008Ool00`00Oomoo`07Ool000Uoo`03001oogoo00aoo`@000=Af@<00004DMT0
00000003DMT20002DMT30003DMT20002DMT30003DMT01000DMUAfE7I1@001UFi0`001UFh1@001Deh
0`001E6H0`0027oo00<0044h@CP0144h00@003Sh>?P000==5@03001A4e4C00AA4`03001E4UDB00<0
0003EA<005DB00EE4P03001E4P0000=E4P<000aoo`03001oogoo00Moo`002Goo0P002Woo1@001e7I
0`001U7I0`001e7I0`001U7I10001EGH0P0000AE^@00000000=E^0800004EKP000000003EIP01000
BGX004eh0`000dfI00<0056HDIP00P000e6H00<007ooOol00goo0P001d4h00<003Sh000014dE00<0
054CDA<0154C0`001EDC00<005DBEA800eDB00<005DBEA800`000UDB00<007ooOol02goo00<007oo
Ool01Woo0009Ool20007Ool50003DMT20002DMT30003DMT20000157I000000000e7I0P000U7I0`00
0e7I0P0000AAf@00000000=Ef@8000=Ef0D000IE^08000MEV0@000E=V@<000EAV0<00005Ool00000
CCL00007@CP20006CAD01000DA=A4e4C0P0000=A4`00EA<01EDC00<005DBEA800eDB10001EDB00<0
07ooOol02Woo00<007ooOol01Woo0009Ool00`00Oomoo`03Ool70004DMT50004DMT60004DMT50004
DMT60004EMT50005EMP00`00EKQE^0030002FKL00`00EIQEV004EIP20002BIX00`00CIT000020003
CIT00`00DIP000020002DIT20004CCL00`00@CQ1>002@CP200000dTF001=5@05CAD01000DA<00000
154C00<005DCEA<015DC00<005DBEA800P0000EE4`00EA9E4P0000AE4P03001oogoo00Yoo`03001o
ogoo00Ioo`000Woo0P0017oo0P000Woo1@001E7J10001E7I10001U7I10001E7I10001U7I100015GH
0P000eGH10001UVg00<005FHEIP00`000UVG00<004VJ00000P001DfI0`000U6I0P001ddg00@0044h
000000A95P03001=5DdE00==5@8000IA4`03001E4eDC00AE4`03001E4P0000AE4`04001E4UDB0003
EA800`00Oomoo`0:Ool00`00Oomoo`06Ool000=oo`03001oogoo009oo`@00004Ool000000003DMX3
0003DMX20000157I000000000e7I0`0000AAf@00000000=Af@800004DMT000000003DMT20002DMT3
0003EMP01000EMQEf5GH1P0015Vg00@005VgFKMI]`D000IIU`06001=VTfJCIX004fI0`000dfI0P00
00=AEP00CCL01Tdg0P001TTF00@004dECAE=5@800003DA@0054C00IA4`03001E4eDC00=E4`8000EE
4`04001E4UDB0004EA800`00Oomoo`09Ool00`00Oomoo`06Ool000Aoo`04001oogooOol20006Ool3
0007DMX40004DMT60004DMT50004DMT50004EMP50005FML01000FKMI]eVg1@001EfF00@005VGFIMI
U`@0009=VP<000A=V@03001AEU5F009AEP03001==ddg009==`800003CCH004TF00E95P04001=5@00
0004DA@00`00DA=A4`04DA<00`00EA=E4`0300000eDC001E4`05EA<01000EA9E4P000UDB0P002goo
00<007ooOol01Woo0003Ool20005Ool00`00Oomoo`06Ool30000157J00000000157J10001U7I1000
0e7I1P000e7I1P0015Gh0P000eWG1@0015ff0P000efF1@0015Uf0P000dfJ00@004fI000000IAEP04
001==`000004CCH00`00BAI95P03BAH20007DA@00`00DA=A4`03DA<30005EA<00`00EA=E4`03EA<0
0`00EA9E4P0300000eDC001oo`0:Ool00`00Oomoo`06Ool000]oo`03001oogoo00Qoo`<0009AfP<0
00=AfP80009Af@<000=Af@@000EAf@@000AAn0/000AMmP04001M]UffGKH60003GID00`00FGIIMP04
FGH00`00CIY=VP030002EEH00`00DEIAEP03DEH20007CCH00`00BAH0000200000e4e001A5006DA@0
0`00DA=A4`0300000eDC001E4`05EA<00`00EA=E4`03EA<30002EA<01000EA=E4`002goo00<007oo
Ool01Goo000<Ool00`00Oomoo`0:Ool40004DMX50003DMT20003DMT20002DMT20004DOT40004COP?
0004II@00`00GIEMU@03GID01000FGIIMUUf1@001UEF00<0055F00000P0000=A=@00CCH01Tdf0P00
1E4e00<0054DDA@0154D0`001EDC00<005DCEA<00eDC00<005DCEA<00`0000=E4`00EA<00UDC00D0
05DCEA=E4`0000Yoo`03001oogoo00Eoo`003Goo0P003Woo100014gJ1@00157I1@000U7i0`0014gi
10000TGg0P0000=1n`0000000`000fWC00<006FDII@016FD00@005fEGIEMU@X000IEEP8000EA=@03
001==Tdf009==P800003DCD0054e00EA=@03001A554D00<00003DA@005DC00EE4`03001E4eDC00=E
4`<000EE4`05001E4eDCEA<00002EA<00`00Oomoo`08Ool00`00Oomoo`05Ool000moo`03001oogoo
00moo`@000E=fP@000A=f@D0009=n@<00099nPP00091_@L000=UU0X000A=^P<0009EEP<00003EED0
054e00EA=@04001==P000004DCD00`00DCEA=@03DCD30005DA@00`00EA=E4`03EA<00`00EA=E4`03
00000eDC001E4`06EA<01P00EA=E4eDC001E4`8000Uoo`03001oogoo00Eoo`0047oo00<007ooOol0
4Goo0P0000A=fP00000000A=fP@000==nPT00095f`8000=5f`@000=5_0P00099^`8000==^P03001=
^Tfj008000==^P8000EEE@03001A=E4e00=A=@8000IA=@04001A=E4eDCD200000e4d001A5006DA@0
0`00EA=E4`02EA<30005EA<00`00EA=E4`04EA<00`00EA=E4`0300000eDC001oo`08Ool00`00Oomo
o`05Ool0015oo`03001oogoo019oo`<0009=fP<000==fP@00099fP<000=9f`@00095f`8000A5^`@0
0095^`800099^`@000==^PD0009=^P<000IEE@03001A=E4e00<00003ECD0054e00EA=@04001A=@00
0004DC@00`00DAAA5004DA@00`00EA<0000200000eDC001E4`06EA<00`00EA=E4`03EA<30002EA<0
1000EA=E4`0027oo00<007ooOol01Goo000BOol2000EOol40002CMX20004CMX40002BM/20003BM/4
0002AK/30003BK/40002BK/01000BK]9^dVk100014fj10000Tfj00<005EEEED00eEE0`001EDe00<0
054eDCD00e4e0P001e4d00<0054DDA@00e4D0P001EDC00<005DCEA<015DC00<005DCEA<00`0000=E
4`00EA<00eDC00<005DC000027oo00<007ooOol01Goo000DOol00`00Oomoo`0FOol30002CMX30002
BMX50002BM/20004BM/40002BK/20003BK/30002BK/20003CKX00`00CKY=^P020003CKX300000dfj
001EE@0300000eDd001E=@06ECD00`00DCD0000200000eDd001A=006DC@00`00DAAA500300000eDC
001E4`05EA<00`00EA=E4`03EA<30005EA<00`00EA=E4`02EA<20009Ool00`00Oomoo`04Ool001Eo
o`03001oogoo01Qoo`L000=9f`D00099f`<000=9^`@00099^`800099^`@000==^PD0009=^P80009=
^P@000EE=003001E=EDe00AE=@8000EE=003001A=54d00AA=0<000EE4`03001E4eDC00=E4`03001E
4eDC00<00003EA<005DC00EE4`03001E4eDC009E4`<000Qoo`03001oogoo00Aoo`005Woo00<007oo
Ool07Woo10000dWK1@000TVk0P000dVk10000TVk00@004fjCKY=^P@000==^P@0009=^P@00003Ool0
05Dd00EE=003001E=EDe00<00003EC@005Dd00EE=003001A=54d00<00003EC@005DC00EE4`03001E
4eDC00=E4`<000EE4`03001E4eDC00=E4`03001E4eDC00D000Qoo`03001oogoo00Aoo`005goo0P00
8Woo0`000dWK1@000TVk0P000dVk0`000Tfj0P000dfj10000Tfj1@001Goo00<005DdEC@00eDd0`00
1EDd00<005DdEC@00eDd0`001EDd00<005DCEA<00eDC00<005DCEA<00`0000=E4`00EA<01EDC00<0
05DCEA<00eDC0`0015DC0P001goo00<007ooOol017oo000IOol00`00Oomoo`0ROol30003BM/50002
BK/20002CKX40002CKX20003CKX4000:Ool00`00EC@0000200000eTd001E=006EC@00`00EC@00002
00000eDd001E=006EC@00`00EA=E4`02EA<30005EA<00`00EA=E4`03EA<00`00EA=E4`0300000eDC
001E4`05EA<20006Ool00`00Oomoo`04Ool001Yoo`03001oogoo02Aoo`<000==^PD0009=^P04001=
^TfjCKX40002CKX3000>Ool00`00FCAI=003FC@00`00ECAE=004EC@20005EC@00`00ECAE=004EC@0
0`00EA<0000200000eDC001E4`06EA<00`00EA=E4`02EA<30005EA<00`00EA=E4`03EA<20006Ool0
0`00Oomoo`04Ool001]oo`03001oogoo02Ioo`<000==^PD00003CKX0000000==^P<0015oo`03001I
=5Td00AI=003001E=5Dd00<00003EC@005Dd00EE=003001E=5Dd00=E=08000EE4`03001E4eDC00AE
4`03001E4`0000800003EA<005DC00IE4`03001E4eDC00=E4`8000Eoo`03001oogoo00Aoo`0077oo
00<007ooOol0:7oo0`000dfj10000Tfj0P005Goo00<005TdFC@00eTd0`001EDd00<005DdEC@00eDd
00<005DdEC@00`0000=E<`00EA<01EDC00<005DCEA<00eDC0P001EDC00<005DCEA<015DC00<005DC
EA<00`0000=E4`00Ool017oo00<007ooOol017oo000MOol2000[Ool30002CKX3000IOol00`00FC@0
000200000eTc001E=005EC@00`00ECAE=003EC@30005EC<00`00EA=E4`03EA<00`00EA=E4`030000
0eDC001E4`05EA<00`00EA=E4`03EA<30004EA<20005Ool00`00Oomoo`03Ool001moo`03001oogoo
02Yoo`<001eoo`03001I<eTc00=I<`03001E=5Dd00=E=003001E=5Dd00<00003EC<005Dc00EE<`04
001E4eDCEA<50005EA<00`00EA=E4`03EA<00`00EA=E4`0300000eDC001E4`05EA<00`00Oomoo`03
Ool00`00Oomoo`03Ool0021oo`03001oogoo02Uoo`03001oogoo01eoo`03001I<eTc00AI<`04001E
=5DdEC@40005EC<00`00EC=E<`03EC<40003EC<00`00EA=E4`04EA<00`00EA=E4`03EA<30005EA<0
0`00EA=E4`03EA<20004Ool00`00Oomoo`03Ool0025oo`03001oogoo02Qoo`03001oogoo01ioo`03
001I<eTc00=I<`@0009E<`03001E<eDc00EE<`03001E<`0000800003EC<005Dc00EE<`03001E4eDC
00=E4`03001E4eDC00<00003EA<005DC00EE4`03001E4eDC00=E4`<000=oo`03001oogoo00=oo`00
8Woo0P00:7oo00<007ooOol07Woo00<005TcFC<00`0000=I<`00EC<015Dc00<005DcEC<015Dc0P00
1EDc00<005DcEC<00eDc00@005DCEA=E4`D000EE4`03001E4eDC00=E4`03001E4eDC00<00003FA<0
000000=oo`03001oogoo00=oo`0097oo00<007ooOol09Goo00<007ooOol07goo0P001ETc00<005Dc
EC<00eDc00<005DcEC<00`0000=E<`00EC<01EDc00<005DcEC<00UDc10000eDC00<005DCEA<015DC
00<005DCEA<00eDC0`001ETC0P000Woo00<007ooOol00goo000UOol00`00Oomoo`0TOol00`00Oomo
o`0OOol00`00FC=I<`05FC<00`00EC=E<`02EC<30005EC<00`00EC=E<`03EC<00`00EC<000020000
0eDc001E4`05EA<00`00EA=E4`03EA<00`00EA=E4`0300000eDC001I4`05FA<01@00Ool007oo0000
1Goo000VOol00`00Oomoo`0SOol00`00Oomoo`0POol00`00FC=I<`04FC<00`00EC<0000200000eTc
001E<`05EC<00`00EC=E<`03EC<20005EC<00`00EA=E4`04EA<01000EA=E4eDC10001EDC00<005TC
FA<00eTC00<007oo00000Woo00<007ooOol00Woo000WOol2000SOol00`00Oomoo`0QOol01000FC=I
<eTc10001ETc00<005DcEC<00eDc00<005DcEC<00`0000=E<`00EC<01EDc00<005DCEA<00eDC1000
0UDC00<005DCEA<01EDC00<005TCFA<00UTC0P0000Aoo`00Ool000Aoo`00:Goo00<007ooOol087oo
00<007ooOol08Woo0`000eTc00<005TcFC<015Tc00@005DcEC=E<`@000EE<`03001E<eDc00=E<`03
001E4eDC00<00003EA<005DC00AE4`03001E4eDC00AE4`03001I4`00008000Aoo`8000Aoo`00:Woo
00<007ooOol07goo00<007ooOol08Woo00<005TcFC<015Tc00<005TcFC<00eTc10000UTc00<005Dc
EC<015Dc00<005DcEC<00eDc0`001EDC00<005DCEA<00eDC00@005DCEA=E4`@000Ioo`<000Aoo`00
:goo00<007ooOol07Woo00<007ooOol08goo00<005TcFC<00eTc00<005TcFC<00`0000=I<`00FC<0
15Tc00<005DcEC<00eDc00<005DcEC<00`0000=E<`00EA<01EDC00<005DCEA<00eDC10001Woo1000
1goo000/Ool2000NOol00`00Oomoo`0TOol00`00FC=I<`02FC<30005FC<00`00FC=I<`03FC<01000
EC=E<eDc10001EDc00<005DCEA<00eDC00<005DCEA<00`001goo0`002goo000^Ool00`00Oomoo`0K
Ool00`00Oomoo`0TOol00`00FC<0000200000eTc001I<`05FC<00`00FC=I<`03FC<40002FC<00`00
EC=E<`04EC<01000EA=E4eDC1@001Woo10003Woo000_Ool00`00Oomoo`0JOol00`00Oomoo`0UOol0
0`00FC=I<`03FC<00`00FC=I<`03FC<00`00FC=I<`0300000eTc001I<`04FC<00`00EC=E<`03EC<4
0007Ool4000BOol0031oo`03001oogoo01Uoo`03001oogoo02Eoo`03001I<eTc00AI<`04001I<eTc
FC<40005FC<00`00FC=I<`03FC<00`00EC<000020008Ool3000FOol0035oo`8001Uoo`03001oogoo
02Ioo`03001I<eTc00=I<`@0009I<`03001I<eTc00AI<`03001I<eTc00=I<`8000Moo`@001Uoo`00
<goo00<007ooOol05Woo00<007ooOol09goo00<005Tc00000P0000=I<`00FC<015Tc00<005TcFC<0
0eTc00<005TcFC<00`001Goo10007Goo000dOol00`00Oomoo`0EOol00`00Oomoo`0XOol00`00FC=I
<`03FC<00`00FC=I<`03FC<01000FC=I<eTc10001Goo0`008Goo000eOol00`00Oomoo`0DOol00`00
Oomoo`0XOol00`00FC=I<`03FC<00`00FC=I<`03FC<40005Ool4000TOol003Ioo`8001=oo`03001o
ogoo02Yoo`03001I<eTc009I<`03001I<eTc00<000Eoo`@002Qoo`00>7oo00<007ooOol047oo00<0
07ooOol0:Woo00@005TcFC=I<`@000Aoo`@002aoo`00>Goo00<007ooOol03goo00<007ooOol0:goo
0`001Goo0`00<7oo000jOol00`00Oomoo`0>Ool00`00Oomoo`0_Ool4000cOol003]oo`03001oogoo
00eoo`03001oogoo02]oo`@003Moo`00?7oo0P003Goo00<007ooOol0:7oo0`00>goo000nOol00`00
Oomoo`0:Ool00`00Oomoo`0TOol4000nOol003moo`03001oogoo00Uoo`03001oogoo021oo`@0049o
o`00@7oo00<007ooOol027oo00<007ooOol077oo1000AWoo0011Ool20008Ool00`00Oomoo`0IOol3
001:Ool004=oo`03001oogoo00Eoo`03001oogoo01Eoo`@004eoo`00A7oo00<007ooOol017oo00<0
07ooOol04Goo1000DGoo0015Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool3001EOol004Ioo`8000=o
o`03001oogoo00Yoo`@005Qoo`00B7oo00@007ooOol000Qoo`@005aoo`00BGoo00<007oo00001Goo
0`00H7oo001:Ool200000goo00000002001SOol004]oo`8006Moo`00\
\>"],
  ImageRangeCache->{{{0, 179}, {144.938, 0}} -> {-0.0496149, 0.0160528, \
0.00570073, 0.00570073}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analytic Continuation", "Title"],

Cell[TextData[{
  "Series representations given for many of the functions on this poster \
converge only over certain parts of the complex plane. Nevertheless, it is \
possible to find values of the function at points outside the region of \
convergence using the process of ",
  StyleBox["analytic continuation",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell["Extending the Domain of an Analytic Function", "SectionFirst"],

Cell[TextData[{
  "The mathematical property that makes analytic continuation possible is the \
remarkable ",
  StyleBox["identity theorem for analytic functions",
    FontSlant->"Italic"],
  ". This theorem says that if two functions are analytic in a given region \
\[ScriptCapitalR], and if they are identical in some neighborhood of a point \
",
  Cell[BoxData[
      \(TraditionalForm\`z\_0 \[Element] \[ScriptCapitalR]\)],
    FormatType->StandardForm],
  ", no matter how small the neighborhood, then the two functions are \
identical ",
  StyleBox["everywhere",
    FontSlant->"Italic"],
  " in \[ScriptCapitalR]. S",
  "ee \[OpenCurlyDoubleQuote]Analytic Functions\[CloseCurlyDoubleQuote] in",
  " the essay ",
  StyleBox["Mathematical Functions",
    FontWeight->"Bold"],
  " on this panel for more information."
}], "Text",
  ZeroWidthTimes->True],

Cell[TextData[{
  "As a simple example, consider ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["h",
              FontWeight->"Plain"], "(", 
            StyleBox["z",
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(\[Sum]\+\(n = 0\)\%\[Infinity] z\^\(2  n\)\),
            FontWeight->"Plain"]}], TraditionalForm]],
    FormatType->StandardForm],
  ". This series converges only inside the unit circle (that is, when ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] < 1\)],
    FormatType->StandardForm],
  "); the value of the infinite sum is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["h",
                FontWeight->"Plain"], "a"], "(", 
            StyleBox["z",
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], "=", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", 
                SuperscriptBox[
                  StyleBox["z",
                    FontWeight->"Plain"], "2"]}], ")"}], \(-1\)]}], 
        TraditionalForm]],
    FormatType->StandardForm],
  ". Now we can also use this same closed form to define ",
  Cell[BoxData[
      \(TraditionalForm\`h(z) = \(\(h\_a\)(z) = \((1 - z\^2)\)\^\(-1\)\)\)],
    FormatType->StandardForm],
  "and calculate values outside the unit circle."
}], "Text",
  ZeroWidthTimes->True],

Cell["\<\
Another approach to the same example is to do the following chain \
of formal operations:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Sum]\+\(n = 0\)\%\[Infinity]\), 
        RowBox[{
          
          RowBox[{\(\((z\^2)\)\^n\), 
            "\[DoubleLongRightArrow]", \(1\/\(1 - z\^2\)\), 
            "\[DoubleLongRightArrow]", 
            FractionBox["1", 
              RowBox[{\(z\^2\), 
                RowBox[{"(", 
                  RowBox[{"1", "-", 
                    FractionBox["1", 
                      AdjustmentBox[\(z\^2\),
                        BoxMargins->{{0, 0}, {-0.285714, 0.285714}},
                        BoxBaselineShift->0.285714]]}], ")"}]}]], 
            "\[DoubleLongRightArrow]", \(-\(1\/z\^2\)\)}], " ", 
          RowBox[{
            FractionBox["1", 
              RowBox[{"1", "-", 
                FractionBox["1", 
                  AdjustmentBox[\(z\^2\),
                    BoxMargins->{{0, 0}, {-0.285714, 0.285714}},
                    BoxBaselineShift->0.285714]]}]], 
            "\[DoubleLongRightArrow]", \(-\(1\/z\^2\)\)}], 
          " ", \(\[Sum]\+\(n = \
0\)\%\[Infinity]\(\(\((1\/z\^2)\)\^n\)\(.\)\)\)}]}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontFamily->"Janson Text"],

Cell[TextData[{
  "The resulting sum now converges for all ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] > 1\)],
    FormatType->StandardForm],
  ", giving us ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(-z\^\(-2\)\), 
          StyleBox[\(\[Sum]\+\(n = 0\)\%\[Infinity] z\^\(\(-2\) n\)\),
            FontWeight->"Plain"]}], TraditionalForm]],
    FormatType->StandardForm],
  " as the analytic continuation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = 0\)\%\[Infinity] z\^\(2  n\)\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[TextData[{
  "Either result allows us to continue the function ",
  Cell[BoxData[
      \(TraditionalForm\`h(z)\)],
    FormatType->StandardForm],
  " to the whole complex plane, excluding only the points on the unit circle. \
(The behavior ",
  StyleBox["on",
    FontSlant->"Italic"],
  " the unit circle is more complicated; it converges at some points but not \
others, and finding which is which requires higher math than discussed \
here.)"
}], "Text"],

Cell[CellGroupData[{

Cell["Example: The Circle-Chain Method", "Section"],

Cell[TextData[{
  "One well-known method for analytic continuation, the ",
  StyleBox["circle-chain method",
    FontSlant->"Italic"],
  ", is due to Karl Weierstrass. We start with an arbitrary analytic function \
",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " having a Taylor expansion around ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  ". (We will use the superscript ",
  Cell[BoxData[
      \(TraditionalForm\`\((n)\)\)],
    FormatType->StandardForm],
  " on the ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(a\_i\%\((n)\)\),
          FontWeight->"Plain"], TraditionalForm]],
    FormatType->StandardForm],
  " terms to mean that we are starting with an expansion around the point ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n\)],
    FormatType->StandardForm],
  ".) The Taylor expansion is"
}], "Text"],

Cell[BoxData[
    \(f \((z\_0 + \[Delta])\) = \[Sum]\+\(i = 0\)\%\[Infinity]\( 
              a\_i\%\((0)\)\) \(\(\[Delta]\^i\)\(.\)\)\)], "DisplayFormula",
  SingleLetterItalics->True,
  FontFamily->"Janson Text"],

Cell[TextData[{
  "Because the function is analytic at ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  ", there is a disk of convergence centered on ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  " in which the function is analytic. We can then choose another point ",
  Cell[BoxData[
      \(TraditionalForm\`z\_1\)],
    FormatType->StandardForm],
  " from inside the disk and re-expand ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " around ",
  Cell[BoxData[
      \(TraditionalForm\`z\_1\)],
    FormatType->StandardForm],
  ". Because ",
  Cell[BoxData[
      \(TraditionalForm\`z\_1\)],
    FormatType->StandardForm],
  " must be an analytic point for ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " has derivatives of all orders there, so there is a Taylor expansion with \
coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\%\((1)\)\)],
    FormatType->StandardForm],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`f(
        z\_1 + \[Delta]) = \[Sum]\+\(i = 0\)\%\[Infinity]\( 
              a\_i\%\((1)\)\) \(\(\[Delta]\^i\)\(.\)\)\)], "DisplayFormula",
  FormatType->StandardForm],

Cell[TextData[{
  "How are these two expansions related? Using elementary arithmetic, we can \
show that the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\%\((1)\)\)],
    FormatType->StandardForm],
  "can be expressed using the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\%\((0)\)\)],
    FormatType->StandardForm],
  " as"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(a\_i\%\((1)\)\), "=", 
        RowBox[{\(\[Sum]\+\(j = i\)\%\[Infinity]\), 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"j"},
                  {"i"}
                  }], 
              ")"}], \(\(\(\(a\_j\%\((0)\)\) \((z\_1 - z\_0)\)\)\^\(j - 
                    i\)\)\(.\)\)}]}]}], TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm],

Cell[TextData[{
  "For an illustration, we can use this method to examine the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(z) = \@\(1 + z\)\%3\)],
    FormatType->StandardForm],
  ", which is analytic everywhere except the branch point ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(-1. \)\)],
    FormatType->StandardForm],
  " For the purposes of this example, we will temporarily \
\[OpenCurlyDoubleQuote]forget\[CloseCurlyDoubleQuote] this closed form of the \
function and treat the Taylor expansion instead. The ",
  StyleBox["i",
    FontSlant->"Italic"],
  "th coefficient (",
  Cell[BoxData[
      \(TraditionalForm\`i > 0\)],
    FormatType->StandardForm],
  ") of the Taylor series expansion around the point ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)],
    FormatType->StandardForm],
  " is given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          AdjustmentBox["(",
            BoxMargins->{{0.14359, -0.14359}, {0, 0}}], 
          StyleBox[GridBox[{
                {
                  AdjustmentBox[\(1/3\),
                    BoxMargins->{{0, 0}, {-0.333333, 0.333333}},
                    BoxBaselineShift->0.333333]},
                {
                  AdjustmentBox["i",
                    BoxMargins->{{0, 0}, {0.333333, -0.333333}},
                    BoxBaselineShift->-0.333333]}
                }],
            FontSize->8], 
          AdjustmentBox[")",
            BoxMargins->{{-0.14359, 0.14359}, {0, 0}}]}], TraditionalForm]],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[\@\(1 + z\)\%3, {z, 0, 4}]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", \(z\/3\), "-", \(z\^2\/9\), "+", \(\(5\ z\^3\)\/81\), 
        "-", \(\(10\ z\^4\)\/243\), "+", 
        InterpretationBox[\(O[z]\^5\),
          SeriesData[ z, 0, {}, 0, 5, 1]]}],
      SeriesData[ z, 0, {1, 
        Rational[ 1, 3], 
        Rational[ -1, 9], 
        Rational[ 5, 81], 
        Rational[ -10, 243]}, 0, 5, 1]]], "Output",
  CellLabel->"Out[1]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[\[Sum]\+\(i = 0\)\%\[Infinity] Binomial[1\/3, 
            i]\ z\^i]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\((1 + z)\)\^\(1/3\)\)], "Output",
  CellLabel->"Out[2]="]
}, Closed]],

Cell[TextData[{
  "Unfortunately, we cannot use this sum over the entire complex plane. \
Although it converges when ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] < 1\)],
    FormatType->StandardForm],
  ", it diverges for points outside the unit circle."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(With[{z = 0.9}, 
      NSum[Binomial[1\/3, i]\ z\^i, {i, 0, \[Infinity]}]]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(1.2385623296301709`\)], "Output",
  CellLabel->"Out[3]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(With[{z = 1.3}, 
      NSum[Binomial[1\/3, i]\ z\^i, {i, 0, \[Infinity]}]]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    InterpretationBox["ComplexInfinity",
      DirectedInfinity[ ]]], "Output",
  CellLabel->"Out[4]="]
}, Closed]],

Cell[TextData[{
  "We can use analytic continuation to extend the domain of this function. \
The following function, ",
  StyleBox["analyticContinuation", "Input",
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FontWeight->"Plain"],
  ", uses the formula described above to calculate the coefficients of a new \
Taylor series from an existing Taylor series. The plan goes like this: \
starting with our original domain (shown below in red) centered at the \
origin, we will choose another point and use that as the point of expansion \
for a new Taylor series. This second Taylor series, calculated from the \
original series using ",
  StyleBox["analyticContinuation", "Input",
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FontWeight->"Plain"],
  ", will give us a new area (in orange) for which ",
  Cell[BoxData[
      \(TraditionalForm\`f(z)\)],
    FormatType->StandardForm],
  " is defined. By repeating this process, we can eventually cover the entire \
complex plane, excluding only the branch point ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(-1\)\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.5 0.238095 [
[.02381 -0.0125 -5.21875 -7 ]
[.02381 -0.0125 5.21875 0 ]
[.2619 -0.0125 -5.28125 -7 ]
[.2619 -0.0125 5.28125 0 ]
[.5 -0.0125 -5.15625 -7 ]
[.5 -0.0125 5.15625 0 ]
[.7381 -0.0125 -3.53125 -7 ]
[.7381 -0.0125 3.53125 0 ]
[.97619 -0.0125 -3.4375 -7 ]
[.97619 -0.0125 3.4375 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -10.5625 -3.5 ]
[-0.0125 .02381 0 3.5 ]
[-0.0125 .2619 -10.3125 -3.5 ]
[-0.0125 .2619 0 3.5 ]
[-0.0125 .5 -7.0625 -3.5 ]
[-0.0125 .5 0 3.5 ]
[-0.0125 .7381 -6.875 -3.5 ]
[-0.0125 .7381 0 3.5 ]
[-0.0125 .97619 -7.125 -3.5 ]
[-0.0125 .97619 0 3.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.2188 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -66.2812 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.1562 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -64.5312 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -64.4375 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -71.5625 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .2619 m
.00625 .2619 L
s
gsave
-0.0125 .2619 -71.3125 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -68.0625 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .7381 m
.00625 .7381 L
s
gsave
-0.0125 .7381 -67.875 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .97619 m
.00625 .97619 L
s
gsave
-0.0125 .97619 -68.125 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .21429 m
.00375 .21429 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .40476 m
.00375 .40476 L
s
0 .45238 m
.00375 .45238 L
s
0 .54762 m
.00375 .54762 L
s
0 .59524 m
.00375 .59524 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .78571 m
.00375 .78571 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.2619 .99375 m
.2619 1 L
s
.5 .99375 m
.5 1 L
s
.7381 .99375 m
.7381 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.07143 .99625 m
.07143 1 L
s
.11905 .99625 m
.11905 1 L
s
.16667 .99625 m
.16667 1 L
s
.21429 .99625 m
.21429 1 L
s
.30952 .99625 m
.30952 1 L
s
.35714 .99625 m
.35714 1 L
s
.40476 .99625 m
.40476 1 L
s
.45238 .99625 m
.45238 1 L
s
.54762 .99625 m
.54762 1 L
s
.59524 .99625 m
.59524 1 L
s
.64286 .99625 m
.64286 1 L
s
.69048 .99625 m
.69048 1 L
s
.78571 .99625 m
.78571 1 L
s
.83333 .99625 m
.83333 1 L
s
.88095 .99625 m
.88095 1 L
s
.92857 .99625 m
.92857 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .2619 m
1 .2619 L
s
.99375 .5 m
1 .5 L
s
.99375 .7381 m
1 .7381 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .40476 m
1 .40476 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .59524 m
1 .59524 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .78571 m
1 .78571 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
1 0 0 r
.7381 .5 m
.7381 .5 .2381 0 365.73 arc
F
0 g
.002 w
newpath
.7381 .5 .2381 0 365.73 arc
s
1 .6 0 r
.66836 .66836 m
.66836 .66836 .2381 0 365.73 arc
F
0 g
newpath
.66836 .66836 .2381 0 365.73 arc
s
.8 1 0 r
.5 .7381 m
.5 .7381 .2381 0 365.73 arc
F
0 g
newpath
.5 .7381 .2381 0 365.73 arc
s
.2 1 0 r
.33164 .66836 m
.33164 .66836 .2381 0 365.73 arc
F
0 g
newpath
.33164 .66836 .2381 0 365.73 arc
s
0 1 .4 r
.2619 .5 m
.2619 .5 .2381 0 365.73 arc
F
0 g
newpath
.2619 .5 .2381 0 365.73 arc
s
0 1 1 r
.33164 .33164 m
.33164 .33164 .2381 0 365.73 arc
F
0 g
newpath
.33164 .33164 .2381 0 365.73 arc
s
0 .4 1 r
.5 .2619 m
.5 .2619 .2381 0 365.73 arc
F
0 g
newpath
.5 .2619 .2381 0 365.73 arc
s
[ .01 .01 ] 0 setdash
newpath
.7381 .5 .2381 0 365.73 arc
s
newpath
.66836 .66836 .2381 0 365.73 arc
s
newpath
.5 .7381 .2381 0 365.73 arc
s
newpath
.33164 .66836 .2381 0 365.73 arc
s
newpath
.2619 .5 .2381 0 365.73 arc
s
newpath
.33164 .33164 .2381 0 365.73 arc
s
newpath
.5 .2619 .2381 0 365.73 arc
s
.5 g
.005 w
.7381 .5 m
.66836 .66836 L
.5 .7381 L
.33164 .66836 L
.2619 .5 L
.33164 .33164 L
.5 .2619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  FormatType->StandardForm,
  ImageSize->{146, 146},
  ImageMargins->{{115, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002B0000TQ000`40O003h00OTWoo002BOol0099o
o`00TWoo002BOol000aoo`H001Uoo`<00003Ool0000001Yoo`<00003Ool007oo01]oo`8001moo`03
001oogoo009oo`004Goo00<007ooOol077oo00<007ooOol077oo00<007ooOol06Woo00<007oo0000
7Woo00<007ooOol00Woo000AOol00`00Oomoo`0MOol00`00Oomoo`0KOol00`00Oomoo`0JOol00`00
Ool0000NOol00`00Oomoo`02Ool0011oo`8001ioo`8001eoo`03001oogoo01]oo`8001ioo`03001o
ogoo009oo`00TWoo002BOol000aoohD0005oo`0037oo00@007ooOol001ioo`03001oogoo01eoo`03
001oogoo01eoo`03001oogoo01aoo`04001oogoo0001Ool000aoo`03001oogoo085oo`40005oo`00
0Woo1@001Goo0P00>goo2`00>goo0P000Goo0006Ool00`00Oomoo`03Ool00`00Oomoo`0fOol4000:
0Il7000fOol10001Ool000Moo`03001oogoo009oo`03001oogoo03=oo`@00181W`<003Eoo`40005o
o`001Woo0P0017oo00<007ooOol0<Goo0`00606O0P00<goo0@000Goo000<Ool00`00Oomoo`0_Ool3
000K0Il3000aOol10001Ool000aoo`03001oogoo02ioo`030001W`6O01h1W`<002moo`40005oo`00
37oo00<007ooOol0;7oo0P008`6O0P00;Woo0@000Goo000<Ool00`00Oomoo`0[Ool00`000Il1W`0T
0Il2000]Ool10001Ool000aoo`03001oogoo02Yoo`030001W`6O02H1W`8002aoo`40005oo`0037oo
00<007ooOol09Woo1P00:06O0P00:goo0@000Goo000<Ool00`00Oomoo`0POol600020ol01P000Il1
W`6O0001W`@002@1W`03001oogoo02Qoo`40005oo`0037oo00<007ooOol07Woo0P001`?o0P002@6O
0`008P6O0P00:7oo0@000Goo000<Ool00`00Oomoo`0KOol300080ol2000=0Il00`000Il1W`0O0Il2
000XOol10001Ool000aoo`03001oogoo01Uoo`8000/3o`030001W`6O00d1W`030001W`0001l1W`80
02Moo`40005oo`0037oo00<007ooOol067oo0P002`?o00<0006O0Il04@6O0P007P6O00<007ooOol0
9Goo0@000Goo000<Ool00`00Oomoo`0FOol2000<0ol00`000Il1W`0D0Il00`000Il1W`0K0Il00`00
Oomoo`0UOol10001Ool000aoo`03001oogoo01Eoo`8000`3o`8001L1W`030001W`6O01/1W`03001o
ogoo02Aoo`40005oo`0037oo00<007ooOol057oo00<000?o0ol030?o00<0006O0Il05`6O00<0006O
0Il06`6O00<007ooOol08goo0@000Goo000<Ool00`00Oomoo`0COol00`000ol3o`0=0ol00`000Il1
W`0H0Il2000K0Il00`00Oomoo`0SOol10001Ool000aoo`03001oogoo019oo`030003o`?o00d3o`80
01/1W`030001W`6O01X1W`03001oogoo029oo`40005oo`0037oo00<007ooOol04Goo0P003`?o00<0
006O0Il06`6O00<0006O0Il06@6O00<007ooOol08Woo0@000Goo000<Ool00`00Oomoo`0@Ool2000?
0ol00`000Il1W`0M0Il00`000Il1W`0H0Il2000SOol10001Ool000aoo`03001oogoo00moo`800103
o`030001W`6O01h1W`030001W`6O01P1W`03001oogoo025oo`40005oo`0037oo00<007ooOol03goo
00<000?o0ol03P?o00<0006O0Il07`6O00<0006O0Il0606O00<007ooOol08Goo0@000Goo000<Ool0
0`00Oomoo`0>Ool00`000ol3o`0?0ol00`000Il1W`0P0Il00`000Il1W`0H0Il00`00Oomoo`0POol1
0001Ool000aoo`03001oogoo00eoo`800143o`030001W`6O0241W`030001W`6O01L1W`03001oogoo
021oo`40005oo`0037oo00<007ooOol03Goo00<000?o0ol040?o00<0006O0Il08@6O00<0006O0Il0
5`6O00<007ooOol087oo0@000Goo000<Ool00`00Oomoo`0<Ool2000B0ol00`000Il1W`0R0Il00`00
0Il1W`0F0Il00`00Oomoo`0POol10001Ool000aoo`03001oogoo00aoo`030003o`?o0143o`030001
W`6O03/1W`03001oogoo021oo`40005oo`0037oo00<007ooOol02goo00<000?o0ol04P?o00<0006O
0Il08`6O00<0006O0Il05@6O00<007ooOol087oo0@000Goo000<Ool00`00Oomoo`0;Ool00`000ol3
o`0A0ol00`000Il1W`0T0Il00`000Il1W`0E0Il00`00Oomoo`0POol10001Ool0009oo`<00003Ool0
07oo00Aoo`03001oogoo00]oo`030003o`?o0143o`030001W`6O02D1W`030001W`6O01@1W`03001o
ogoo021oo`40005oo`001Woo00<007ooOol00goo0P002goo0P0030?o2@0000<1W`0000000`005P6O
0Sg_206O00<0006O0Il03@6O100000<1W`0000002@006Goo0P000Goo0006Ool00`00Oomoo`03Ool0
0`00Oomoo`0:Ool00`000ol3o`080ol300070ol00`000Il1W`050Il200000`6O0001W`0?0Il2?NlG
0Il300070Il00`00O01l0005O004000GOol10001Ool000Ioo`03001oogoo00=oo`03001oogoo00Yo
o`030003o`?o00D3o`@000T3o`8000X1W`8000/1W`<mk``1W`030001W`6O00P1W`8000X1W`03001l
07`000Ul00<001Aoo`40005oo`0037oo00<007ooOol02Woo00<000?o0ol010?o0P003@?o00<0006O
0Il02P6O0`001P6O0Sg_406O00<0006O0Il01@6O0P00306O00<007`0O0002g`00`004Woo0@000Goo
000<Ool00`00Oomoo`09Ool00`000ol3o`030ol2000?0ol00`000Il1W`0=0Il00`000Il1W`03?NlB
0Il00`000Il1W`030Il2000>0Il00`00O01l000>O0000`00Oomoo`0?Ool10001Ool000aoo`03001o
ogoo00Uoo`030003o`?o0083o`030003o`?o00l3o`030001W`6O00h1W`8mkaD1W`030001W`6O0081
W`030001W`6O00h1W`03001l07`000ml008000moo`40005oo`0037oo00<007ooOol02Goo00D000?o
0ol3o`000183o`030001W`6O00`1W`8mk`030Il0000001P1W`030001W`6O00l1W`03001l07`0011l
008000ioo`40005oo`0037oo00<007ooOol02Goo00@000?o0ol001<3o`030001W`6O00T1W`8mk`H1
W`030001W`6O0141W`040001W`6O000A0Il2000DO0000`00Oomoo`0;Ool10001Ool000aoo`03001o
ogoo00Uoo`8001D3o`030001W`6O00L1W`8mk`T1W`030001W`6O0101W`<00181W`8001El0003001o
ogoo00Yoo`40005oo`0037oo00<007ooOol02Goo00<000?o0ol05@?o00<0006O0Il01@6O00<mk`6O
0Il02@6O0P004@6O00<0006O0Il04P6O00<007`0O0005G`000<007ooOol02Goo0@000Goo000<Ool0
0`00Oomoo`08Ool2000G0ol00`000Il1W`040Il00cg_0Il1W`0<0Il00`000Il1W`0=0Il2000D0Il0
0`00O01l000FO0000`00Oomoo`08Ool10001Ool000aoo`03001oogoo00Moo`030003k00001L3o`80
01D1W`030001W`6O00/1W`030001W`0001<1W`03001l07`001Ql0003001oogoo00Moo`40005oo`00
37oo00<007ooOol01Woo00@000?/0n`001P3o`030001W`6O00<1W`03?Nl1W`6O00d1W`030001W`6O
00X1W`040001W`6O000C0Il00`00O01l000HO0020008Ool10001Ool000aoo`03001oogoo00Ioo`04
0003k0?/000I0ol01@000Il1W`6O?Nl04@6O00<0006O0Il0206O00D0006O0Il1W`0001<1W`03001l
07`001Ul008000Moo`40005oo`0037oo00<007ooOol01Goo00D000?/0n`3k00001T3o`050001W`6O
0Ilmk`0B0Il00`000Il1W`070Il01@000Il1W`6O00004P6O00<007`0O0006g`000<007ooOol01Goo
0@000Goo000<Ool00`00Oomoo`05Ool00`000n`3k0020n`00`000ol3o`0F0ol200000`6O?Nl1W`0C
0Il00`000Il1W`060Il00`000Il1W`02000B0Il00`00O01l000LO0000`00Oomoo`04Ool10001Ool0
00aoo`03001oogoo00Aoo`030003k0?/00<3k0030003o`?o01L3o`030001Wcg_01@1W`030001W`6O
00D1W`030001W`6O01@1W`03001l07`001el0003001oogoo00Aoo`40005oo`0037oo00<007ooOol0
0goo00<000?/0n`010?/00<000?o0ol05`?o0P0000<mk`6O0Il04P6O00<0006O0Il0106O00<0006O
0Il00P6O00<0006O0Il03`6O00<007`0O0007W`000<007ooOol017oo0@000Goo000<Ool00`00Oomo
o`03Ool00`000n`3k0040n`2000I0ol00cg_0Il1W`0D0Il00`000Il1W`030Il00`000Il1W`020Il0
0`000Il1W`0>0Il2000QO0000`00Oomoo`03Ool10001Ool000aoo`03001oogoo009oo`030003k0?/
00H3k0030003o`?o01H3o`03?Nl3o`0001D1W`030001W`6O0081W`030001W`6O0081W`030001W`6O
00l1W`03001l07`0021l008000Aoo`40005oo`0037oo00<007ooOol00Woo00<000?/0n`01P?/00<0
00?o0ol05P?o00@mk`?o0ol001D1W`030001W`6O00H1W`030001W`6O00h1W`03001l07`0029l0003
001oogoo009oo`40005oo`0037oo00<007ooOol00Woo00<000?/0n`01P?/0P005P?o00<mk`?o0ol0
0P?o00<0006O0Il04P6O00D0006O0Il1W`0000@1W`030001W`6O00d1W`03001l07`002=l008000=o
o`40005oo`0037oo00D007ooOomoo`0000X3k0030003o`?o01@3o`03?Nl000?o00L000030Il0006O
00h1W`030001W`0000@1W`030001W`6O00P1W``0025l0005001oogooOol00001Ool000aoo`05001o
ogooOol0000:0n`00`000ol3o`0@0ol400000cg_0ol3o`040ol200030Il3000<0Il00`000Il00004
0Il00`000Il1W`040Il300050Il00`00OV1nH005OV05000LO0001@00Oomoogoo00000Goo000<Ool0
1@00Oomoogoo00002`?/00<000?o0ol03@?o0`000P?o00<mk`?o0ol01P?o0P001P6O0P002@6O00<0
006O00000`6O00<0006O0Il00P6O00<0006O00001P6O0P002giP1@006G`000D007ooOomoo`00005o
o`0037oo00D007ooOomoo`0000`3k0030003o`?o00T3o`030003o`0000D3o`03?Nl3o`?o00L3o`80
00L1W`8000L1W`030001W`6O00<1W`030001W`6O008000P1W`8000mnH0<001Ql0005001oogooOol0
0001Ool000aoo`04001oogoo000=0n`00`000ol3o`080ol00`000ol3o`050ol00cg_0ol3o`0:0ol0
0`000Il1W`070Il200050Il01@000Il1W`6O00000P6O00<0006O0Il01P6O0`004WiP0P0067`000@0
07ooOol0005oo`0037oo00@007ooOol000h3k0030003o`?o00D3o`8000P3o`03?Nl3o`?o00/3o`<0
00P1W`030001W`6O0081W`030001W`6O00@000P1W`8001InH08001Il0004001oogoo0001Ool000ao
o`04001oogoo000?0n`00`000ol3o`030ol00`000ol3o`0H0ol300070Il01@000Il1W`6O00000P6O
00<0006O0Il01`6O0P006WiP00<007`0O0004g`000@007ooOol0005oo`0037oo00@007ooOol00103
k0050003o`?o0ol0000:0ol00cg_0ol3o`0@0ol200070Il20000106O0001W`001`6O0`007GiP0P00
4g`000@007ooOol0005oo`0037oo00@007ooOol00103k08000030ol000?o00X3o`03?Nl3o`?o0183
o`@000D1W`<000@1W`D0021nH080019l0004001oogoo0001Ool000Eoo`8000Eoo`800003Ool000?/
0103k08000/3o`03?Nl3o`?o01L3o`d001UnH003?NmnH7iP00UnH080015l0004001oo`000001Ool0
00Eoo`03001oo`0000Aoo`04001oogoo000A0n`3000;0ol00cg_0ol3o`0D0ol300040ol30003In07
000COV000cg_OV1nH00;OV02000@O0001000Oomoo`000Goo0005Ool00`00Ool00004Ool01000Oomo
o`0040?/00<000?/0n`00P007P?o0`001P?o0`0000<Kh000In001VOP0`008GiP00<007`0O0003W`0
00@007ooOol0005oo`001Woo0P0017oo00@007ooOol000l3k0030003k0?/0083k0<000P3o`03?Nl3
o`?o00l3o`8000L3o`<000030n`001_P008000UWh08000mnH003?NmnH7iP00enH08000ml0004001o
ogoo0001Ool000aoo`04001oogoo000>0n`00`000n`3k0040n`00`000n`000080ol00cg_0ol3o`0<
0ol200070ol400020n`010006n0Kh0002VOP0`003GiP00<mkgiPOV003WiP0P003W`000@007ooOol0
005oo`0037oo00@007ooOol000h3k0030003k0?/00L3k08000H3o`03?Nl3o`?o00X3o`030003o`?o
00L3o`8000040n`000?/0n`200036n000`00In1Wh009In03000:OV000cg_OV1nH00@OV02000=O000
1000Oomoo`000Goo000<Ool01000Oomoo`003@?/00<000?/0n`02@?/0P001P?o00<mk`?o0ol01`?o
0P0020?o0P000P?/00L000?/0n`3k0006n0000026n000`00In1Wh00;In020009OV000cg_OV1nH00A
OV000`00O01l000:O0001@00Oomoogoo00000Goo000<Ool01000Oomoo`0030?/00<000?/0n`030?/
0`000`?o00<mk`?o0ol01P?o00<000?o0ol01@?o0`0010?/00D000?/0n`3k00000DKh003001Wh6OP
00]Wh08001anH08000]l0005001oogooOol00001Ool000aoo`05001oogooOol0000;0n`00`000n`3
k00?0n`300000cg_0ol3o`050ol00`000ol3o`040ol200060n`00`000n`3k0020n`00`006n000003
6n000`00In1Wh00<In020006OV000cg_OV1nH00COV000`00O01l0009O0001@00Oomoogoo00000Goo
000<Ool01@00Oomoogoo00002P?/00<000?/0n`04P?/0P0000<mk`0000002`0020?/00<000?/0n`0
0P?/00<001_P000011_P00<006OPIn0036OP0P001GiP00<mkgiPOV0057iP00<007`0O00027`000D0
07ooOomoo`00005oo`0037oo00@007ooOomoo`8000T3k0030003k0?/01@3k003?Nl3k0?/0083k003
0003k0?/00h3k0030003k0?/0083k004000Kh1_P00046n000`00In1Wh00<In020003OV000cg_OV1n
H00EOV000`00O01l0008O0001@00Oomoogoo00000Goo000<Ool00`00Oomoo`02Ool00`000n`3k006
0n`00`000n`3k00F0n`013g_0n`3k00040?/00<000?/0n`00P?/00D001_P6n0Kh00000@Kh003001W
h6OP00eWh080009nH003?NmnH7iP01EnH08000Ql0003001oogoo009oo`40005oo`0037oo00<007oo
Ool00Woo00<000?/0n`01P?/00<000?/0n`05P?/00<mk`?/00004@?/00@000?/0n`3k08000<Kh003
000Kh1_P00<Kh003001Wh6OP00eWh003001nH3g_01UnH003001l07`000Il0003001oogoo009oo`40
005oo`0037oo00<007ooOol00Woo0P001`?/00<000?/0n`05P?/00<mk`?/000040?/00<000?/0n`0
0P?/00<001_P6n000a_P00<001_P6n000Q_P00<006OPIn003VOP00<003g_OV0067iP00<007`0O000
1G`00P0017oo0@000Goo000<Ool00`00Oomoo`03Ool00`000n`3k0040n`00`000n`3k00H0n`00cg_
0n`3k00?0n`010000n`3k0?/0P001A_P00<001_P6n000Q_P00<006OPIn003fOP00<mkgiPOV005giP
0P001W`000<007ooOol00goo0@000Goo000<Ool00`00Oomoo`03Ool200050n`00`000n`3k00G0n`0
0`00?Nl3k00@0n`01@000n`3k0?/00001a_P00D001_P6n0Kh000011Wh003?Nl007iP01UnH003001l
07`000=l0003001oogoo00Aoo`40005oo`0037oo00<007ooOol017oo00<000?/0n`00`?/00<000?/
0n`05P?/00@000?/0n`mk`l3k0030003k0?/0083k003000Kh1_P00DKh003000Kh1_P008Kh003001W
h6OP00eWh003?NmWh00001UnH003001l07`000=l0003001oogoo00Aoo`40005oo`0037oo00<007oo
Ool01Goo00<000?/0n`00P?/00<000?/0n`05P?/00@000?/0n`mk`l3k0050003k0?/0n`000096n00
1@006n0Kh1_P00003VOP00DmkfOPIn1Wh00001QnH003001l07`0009l0003001oogoo00Eoo`40005o
o`0037oo00<007ooOol01Goo00D000?/0n`3k00001d3k003?Nl3k0?/00`3k0030003k0?/008000TK
h005000Kh1_P6n00000>In001Cg_In1Wh6OP000067iP00<007`0O0000W`000<007ooOol01Goo0@00
0Goo000<Ool00`00Oomoo`06Ool00`000n`3k00I0n`00`000n`3k00D0n`00`006n0Kh0096n001000
6n0Kh0003VOP00<mkfOPIn000VOP00<007iPOV005WiP00@007`0O00000Qoo`40005oo`0037oo00<0
07ooOol01Woo0P0000<3k0000n`05`?/00<000?/0n`00P?/00<mk`?/0n`030?/00<000?/00003A_P
00<001_P00003FOP00<mkfOPIn000fOP00<007iPOV005WiP00<007`000002Goo0@000Goo000<Ool0
0`00Oomoo`07Ool00`000n`0000G0n`00`000n`3k0040n`00cg_0n`3k00;0n`2000>6n000`006n00
000=In000cg_In1Wh003In02000GOV030009Ool10001Ool000aoo`03001oogoo00Qoo`8001L3k003
0003k0?/00@3k08mk``3k003000Kh1_P00hKh08000aWh003?NmWh6OP00EWh003001nH7iP01EnH080
00Yoo`40005oo`0037oo00<007ooOol02Goo0P007P?/00<mk`?/?Nl02@?/0P004A_P0P002FOP0Sg_
26OP00<007iPOV0057iP0P002goo0@000Goo000<Ool00`00Oomoo`09Ool00`006n00000D0n`00`00
0n`3k0090n`2?Nl60n`00`006n00000A6n000`00In000005In03?Nl;In000`00OV1nH00COV02000;
Ool10001Ool000aoo`03001oogoo00Uoo`04000Kh1_P000C0n`00`000n`3k00;0n`013g_0n`mk`?/
0P000Q_P00<001_P6n003a_P00@006OPIn00009Wh08mk`iWh003001nH7iP011nH005001nH000OV00
000;Ool10001Ool000aoo`03001oogoo00Uoo`04000Kh1_P6n03000@0n`00`000n`3k00>0n`2?Nl3
6n000`006n0Kh00?6n001000In1Wh6OP0Sg_46OP00<007iPOV003giP00<007iPOV000WiP00<007oo
Ool02Goo0@000Goo000<Ool00`00Oomoo`09Ool00`006n0Kh0026n03000?0n`00`000n`3k00=0n`2
00001A_P?Nlmkcg_00004A_P00D003g_In0mkfOP00<000iWh003001nH7iP00inH003001nH7iP009n
H003001oogoo00Yoo`40005oo`0037oo00<007ooOol02Goo00<001_P6n001A_P00<000?/0n`06@?/
0`001Q_P0Sg_3a_P0Sg_1fOP00<006OPIn002fOP00<007iPOV0037iP0P001GiP00<007ooOol02Woo
0@000Goo000<Ool00`00Oomoo`0:Ool00`006n0Kh0056n03000;0n`00`000n`3k0090n`200086n00
0`006n0mk`02?Nl96n000cg_6n0mk`020008In02000;In000`00OV1nH00:OV020007OV000`00Oomo
o`0:Ool10001Ool000aoo`03001oogoo00Yoo`03000Kh1_P00LKh0<000P3k0030003k0?/00L3k0<0
00/Kh004000Kh1_P6n02?Nl66n001Cg_6n0Kh1_P00002fOP00<006OP000026OP00<007iPOV001giP
0`002GiP00<007ooOol02Woo0@000Goo0006Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`006n0K
h00:6n0600020n`010000n`3k0?/1`003A_P00<001_P6n000a_P0Sg_0Q_P0Sg_11_P00<006OPIn00
36OP0`0000=Wh00000000VOP00@007iPOV1nH0H000anH003001oogoo00Yoo`40005oo`001Woo00<0
07ooOol00goo0P0037oo00<001_P6n003Q_P20006a_P0Sg_1Q_P00<006OPIn004FOP1P0000=nH000
OV003giP00<007ooOol02Woo0P000Goo0006Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`006n0K
h00A6n000`006n0Kh00E6n02000=6n02000FIn000`00OV1nH00BOV000`00Oomoo`0;Ool10001Ool0
00Ioo`03001oogoo00=oo`03001oogoo00]oo`03000Kh1_P018Kh003000Kh1_P01DKh003000Kh1_P
00/Kh003001Wh6OP01EWh003001nH7iP015nH08000eoo`40005oo`0037oo00<007ooOol037oo00<0
01_P6n004A_P00<001_P6n005A_P00<001_P6n002Q_P0P005fOP00<007iPOV004GiP00<007ooOol0
37oo0@000Goo000<Ool00`00Oomoo`0<Ool00`006n0Kh00Z6n000`006n0Kh0096n02000GIn000`00
OV1nH00AOV000`00Oomoo`0<Ool10001Ool000aoo`03001oogoo00aoo`80018Kh003000Kh1_P01LK
h003000Kh1_P00PKh003001Wh6OP01IWh003001nH7iP011nH003001oogoo00eoo`40005oo`0037oo
00<007ooOol03Goo00<001_P6n0041_P00<001_P6n005a_P00<001_P6n001a_P00<006OPIn005fOP
00<007iPOV0047iP00<007ooOol03Goo0@000Goo000<Ool00`00Oomoo`0>Ool00`006n0Kh00?6n00
0`006n0Kh00G6n000`006n0Kh0076n000`00In1Wh00GIn000`00OV1nH00?OV000`00Oomoo`0>Ool1
0001Ool000aoo`03001oogoo00ioo`03000Kh1_P00lKh003000Kh1_P01PKh003000Kh1_P00DKh003
001Wh6OP01MWh080011nH003001oogoo00moo`40005oo`0037oo00<007ooOol03goo00<001_P6n00
3a_P00<001_P6n0061_P00<001_P6n000a_P0P006FOP00<007iPOV003giP00<007ooOol03goo0@00
0Goo000<Ool00`00Oomoo`0@Ool00`006n0Kh00>6n000`006n0Kh00H6n000`006n0Kh0026n02000J
In000`00OV1nH00>OV000`00Oomoo`0@Ool10001Ool000aoo`03001oogoo015oo`03000Kh1_P00hK
h003000Kh1_P01PKh003000Kh1_P008001YWh003001nH7iP00inH003001oogoo015oo`40005oo`00
37oo00<007ooOol04Goo0P003a_P00<001_P6n006A_P00<001_P00006fOP00<007iPOV003GiP00<0
07ooOol04Woo0@000Goo000<Ool00`00Oomoo`0BOol2000?6n000`006n0Kh00H6n02000LIn000`00
OV1nH00<OV000`00Oomoo`0COol10001Ool000aoo`03001oogoo01=oo`8000hKh003000Kh1_P01LK
h0800003In0006OP01UWh003001nH7iP00anH003001oogoo01Aoo`40005oo`0037oo00<007ooOol0
57oo0P003A_P00<001_P6n005Q_P0P000fOP0P0066OP00<007iPOV002WiP0P005goo0@000Goo000<
Ool00`00Oomoo`0FOol2000<6n000`006n0Kh00D6n020006In000`00In1Wh00DIn000`00OV1nH00:
OV02000HOol10001Ool000aoo`03001oogoo01Qoo`03000Kh1_P00XKh003000Kh1_P014Kh08000UW
h003001Wh6OP019Wh003001nH7iP00YnH003001oogoo01Qoo`40005oo`0037oo00<007ooOol06Goo
0`002A_P00<001_P6n003a_P0P0036OP0`0046OP0P002WiP0P006goo0@000Goo000<Ool00`00Oomo
o`0KOol400076n000`006n0Kh00=6n02000@In02000>In000`00OV1nH008OV02000LOol10001Ool0
00aoo`03001oogoo01eoo`03001oo`0000LKh003000Kh1_P00TKh0<001AWh0<000YWh003001nH7iP
00InH0<001ioo`40005oo`0037oo00<007ooOol087oo100011_P00<001_P6n0011_P10006VOP0`00
1VOP00<007iPOV000giP10008Goo0@000Goo000<Ool00`00Oomoo`0SOol<000QIn0<000UOol10001
Ool000aoo`03001oogoo02Yoo`8002QWh003001oogoo02Yoo`40005oo`0037oo00<007ooOol0:goo
0P009FOP0P00;Goo0@000Goo000<Ool00`00Oomoo`0/Ool2000SIn02000^Ool10001Ool000aoo`03
001oogoo02eoo`80021Wh0<002moo`40005oo`0037oo00<007ooOol0;goo0`0076OP0P00<Goo0@00
0Goo000<Ool00`00Oomoo`0`Ool4000HIn02000cOol10001Ool000aoo`03001oogoo03=oo`8001AW
h0<003Eoo`40005oo`0037oo00<007ooOol0=Goo100036OP1@00=goo0@000Goo0005Ool20005Ool2
000jOol=000jOol20001Ool000Ioo`03001oogoo00=oo`03001oogoo085oo`40005oo`001goo00<0
07ooOol00Woo00<007ooOol0PGoo0@000Goo0006Ool20004Oon50001Ool0099oo`00TWoo0000\
\>"],
  ImageRangeCache->{{{0, 145}, {145, 0}} -> {-3.48734, -2.42989, 0.0316988, \
0.0316988}}],

Cell[TextData[{
  "We represent a series of terms using the form ",
  StyleBox["SeriesTerms[", "MR"],
  Cell[BoxData[
      FormBox[
        StyleBox["term0",
          FontSlant->"Italic"], TraditionalForm]],
    FormatType->StandardForm],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox["termi",
          FontSlant->"Italic"], TraditionalForm]],
    FormatType->StandardForm],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`i\)],
    FormatType->StandardForm],
  StyleBox["]", "MR"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)],
    FormatType->StandardForm],
  " is the index variable, not the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-1\)\)],
    FormatType->StandardForm],
  ". (",
  StyleBox["SeriesTerms", "MR"],
  " is a user-defined data type, not a built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function.) Using ",
  StyleBox["SeriesTerms", "MR"],
  ", ",
  StyleBox["analyticContinuation", "MR"],
  " calculates the series terms around the next expansion point, using \
\[Delta] to represent the difference between the next point and the current \
one. Because the zeroth-order term takes a different form than the others, we \
include it separately in ",
  StyleBox["SeriesTerms", "MR"],
  "."
}], "Text"],

Cell[TextData[{
  "Note that this function makes heavy use of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyQuote]",
  "s symbolic summation capabilities."
}], "Text"],

Cell[BoxData[
    \(analyticContinuation[SeriesTerms[term0_, termi_, i], \[Delta]_] := 
      Module[{j}, 
        Simplify[
          SeriesTerms[
            term0 + \[Sum]\+\(j = 1\)\%\[Infinity]\((termi \
/. \[InvisibleSpace]i \[Rule] 
                        j)\)\ \[Delta]\^j, \[Sum]\+\(j = i\)\%\[Infinity] 
                  Binomial[j, 
                  i]\ \((termi /. \[InvisibleSpace]i \[Rule] 
                      j)\)\ \[Delta]\^\(j - i\), i]]]\)], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[{
  "Here is the first step of the analytic continuation, with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta] = z\_1 - z\_0\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a1 = 
      FullSimplify[
        analyticContinuation[
          SeriesTerms[1, Binomial[1/3, i], i], \[Delta]]]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(SeriesTerms[\((1 + \[Delta])\)\^\(1/3\), \(\((1 + \[Delta])\)\^\(1\/3 - \
i\)\ Gamma[4\/3]\)\/\(Gamma[4\/3 - i]\ Gamma[1 + i]\), i]\)], "Output",
  CellLabel->"Out[6]="]
}, Closed]],

Cell[TextData[{
  "Using these series terms in the new series form ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Sum]\+\(i = 0\)\%\[Infinity]\( 
                  a\_i\%\((1)\)\) \[Delta]\^i\),
          FontWeight->"Plain"], TraditionalForm]],
    FormatType->StandardForm],
  ", we can now calculate function values outside the previous limit. This is \
the value we were unable to calculate above because the original Taylor \
series diverged."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(With[{z = 0.8, \[Delta] = 0.5}, \((\[Delta] + 1)\)\^\(1/3\) + 
        NSum[\(\((\((\[Delta] + 1)\)\^\(1\/3 - i\)\ Gamma[4\/3])\)\ \
z\^i\)\/\(Gamma[4\/3 - i]\ Gamma[i + 1]\), {i, 1, \[Infinity]}]]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(1.3200061217959125`\)], "Output",
  CellLabel->"Out[7]="]
}, Closed]],

Cell[TextData[{
  "We can check this value against our \[OpenCurlyDoubleQuote]forgotten\
\[CloseCurlyDoubleQuote] definition ",
  Cell[BoxData[
      \(TraditionalForm\`f(z) = \@\(1 + z\)\%3\)],
    FormatType->StandardForm],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`z = 1.3\)],
    FormatType->StandardForm],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\@\(1 + 1.3\)\%3\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(1.3200061217959123`\)], "Output",
  CellLabel->"Out[8]="]
}, Closed]],

Cell[TextData[{
  "The process of analytic continuation can be performed again, this time \
choosing another point within the newly acquired area. We take the previous \
result, ",
  StyleBox["a1", "MR"],
  ", and use it to find the Taylor series expansion around ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\&~ = z\_2 - \[Delta]\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[analyticContinuation[a1, \[Delta]\&~]]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(SeriesTerms[\((\[Delta] + 1)\)\^\(1/3\)\ \((\[Delta]\&~\/\(\[Delta] + 1\
\) + 1)\)\^\(1/3\), \(-\(\(\@3\ \((\[Delta] + 1)\)\^\(1/3\)\ Gamma[
                4\/3]\ Gamma[
                i - 1\/3]\ \[Delta]\&~\^\(-i\)\ \((\(-\(\[Delta]\&~\/\(\
\[Delta] + 1\)\)\))\)\^i\ \((\[Delta]\&~\/\(\[Delta] + 1\) + 1)\)\^\(1\/3 - i\
\)\)\/\(2\ \[Pi]\ Gamma[i + 1]\)\)\), i]\)], "Output",
  CellLabel->"Out[9]="]
}, Closed]],

Cell[TextData[{
  "By repeating the process of analytic continuation, we can cover the whole \
Riemann surface of the function under consideration, even when the function \
is multivalued. (See ",
  StyleBox["Branch Cuts and Branch Points",
    FontWeight->"Bold"],
  " for more on Riemann surfaces.) As an example, we carry out the analytic \
continuation repeatedly along a path formed by ten points ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)],
    FormatType->StandardForm],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(z\_1\),
            "TraditionalForm"], ",", "\[Ellipsis]", ",", \(z\_10\)}], 
        TraditionalForm]],
    FormatType->StandardForm],
  " circling the branch point ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(-1\)\)],
    FormatType->StandardForm],
  ". We start by deriving a symbolic result that does not depend on the \
numeric values of ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[BoxData[
    \(\(logSeriesTerms = 
        FoldList[analyticContinuation, 
          SeriesTerms[1, Binomial[1\/3, i], i], {z\_1 - z\_0, z\_2 - z\_1, 
            z\_3 - z\_2, z\_4 - z\_3, z\_5 - z\_4, z\_6 - z\_5, z\_7 - z\_6, 
            z\_8 - z\_7, z\_9 - z\_8, z\_10 - z\_9}];\)\)], "InputOnly",
  CellLabel->"In[10]:="],

Cell[TextData[{
  "We can now use ",
  StyleBox["Sum", "MR"],
  " to get closed-form expressions for all the series. "
}], "Text"],

Cell[BoxData[
    \(summedSeries[SeriesTerms[s0_, si_, i_], z_] := 
      s0 + \[Sum]\+\(i = 1\)\%\[Infinity] si\ z\^i\)], "InputOnly",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(\(summedCubeRootSeries = \(Simplify[summedSeries[#, z]] &\) /@ 
          logSeriesTerms;\)\)], "InputOnly",
  CellLabel->"In[12]:="],

Cell["\<\
Here are the first three coefficients in the series; they are \
products of cube root terms.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[Take[summedCubeRootSeries, 3]]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({\((1 + z)\)\^\(1/3\), \((1 - z\_0 + z\_1)\)\^\(1/3\)\ \((1 + z\/\(1 - \
z\_0 + z\_1\))\)\^\(1/3\), \((1 - z\_0 + z\_1)\)\^\(1/3\)\ \((\(1 - z\_0 + \
z\_2\)\/\(1 - z\_0 + z\_1\))\)\^\(1/3\)\ \((1 + z\/\(1 - z\_0 + \
z\_2\))\)\^\(1/3\)}\)], "Output",
  CellLabel->"Out[13]="]
}, Closed]],

Cell[TextData[{
  "Expressed in this form, the terms include branch cut information. If we \
could neglect branch cuts, then each of the terms would simply reduce to  ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(1 + z - z\_0 + z\_i\)\%3\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[PowerExpand /@ Rest[summedCubeRootSeries]]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({\((1 + z - z\_0 + z\_1)\)\^\(1/3\), \((1 + z - z\_0 + \
z\_2)\)\^\(1/3\), \((1 + z - z\_0 + z\_3)\)\^\(1/3\), \((1 + z - z\_0 + z\_4)\
\)\^\(1/3\), \((1 + z - z\_0 + z\_5)\)\^\(1/3\), \((1 + z - z\_0 + \
z\_6)\)\^\(1/3\), \((1 + z - z\_0 + z\_7)\)\^\(1/3\), \((1 + z - z\_0 + z\_8)\
\)\^\(1/3\), \((1 + z - z\_0 + z\_9)\)\^\(1/3\), \((1 + z - z\_0 + z\_10)\)\^\
\(1/3\)}\)], "Output",
  CellLabel->"Out[14]="]
}, Closed]],

Cell[TextData[{
  "Now we plug explicit expansion points into our symbolic result. We will \
proceed counterclockwise around ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(-1\)\)],
    FormatType->StandardForm],
  ", the branch point of ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(1 + z\)\%3\)],
    FormatType->StandardForm],
  ". Because the radius of convergence of the starting power series is 1, we \
must choose the next expansion point within a distance 1 from the origin."
}], "Text"],

Cell[BoxData[
    \(\(z\_j_ = \(-1\) + \[ExponentialE]\^\(1\/8\ j\ \[ImaginaryI]\ 2\ \
\[Pi]\);\)\)], "InputOnly",
  CellLabel->"In[15]:="],

Cell[TextData[{
  "For each successive application of analytic continuation, we define a \
function ",
  StyleBox["cubeRoot", "MR"],
  " to represent the summed forms of the series. The result will be an array \
of ",
  StyleBox["cubeRoot", "MR"],
  " functions, where each element represents one step in the analytic \
continuation."
}], "Text"],

Cell[BoxData[
    \(Do[cubeRoot[j - 1, z_] = 
        summedCubeRootSeries\[LeftDoubleBracket]j\[RightDoubleBracket], {j, 
        11}]\)], "InputOnly",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(\(With[{rMax = 1 - 1\/10\^6, ppr = 16, pp\[CurlyPhi] = 24}, 
        Do[points[i] = 
            Table[{Re[
                  z\_i + \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\ r], 
                Im[z\_i + \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\ \
r], Im[cubeRoot[i, r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)]]}, {r, 
                0. , rMax, rMax\/ppr}, {\[CurlyPhi], 0, 
                2\ \[Pi], \(2\ \[Pi]\)\/pp\[CurlyPhi]}], {i, 0, 
            10}]];\)\)], "InputOnly",
  CellLabel->"In[17]:="],

Cell[TextData[{
  "We can look at the resulting Riemann surface by showing the various ",
  StyleBox["cubeRoot ", "MR"],
  "values inside their disks of convergence."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        Graphics3D[{{Thickness[0.001], 
              Table[{Hue[0.06\ i], Line /@ points[i], 
                  Line /@ Transpose[points[i]]}, {i, 0, 10}]}, {Thickness[
                0.01], GrayLevel[0.3], 
              Line[{{\(-1\), 0, \(-1\)}, {\(-1\), 0, 1}}]}}]];\)\)], "Input",
  CellLabel->"In[18]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.47515 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.24957 1.49914 -0.0239862 1.49914 [
[.10557 1.49364 -4.35628 0 ]
[.10557 1.49364 6.08122 7 ]
[.3028 1.49383 -4.84485 0 ]
[.3028 1.49383 5.71765 7 ]
[.5 1.49389 -5.15625 0 ]
[.5 1.49389 5.15625 7 ]
[.6972 1.49383 -3.82304 0 ]
[.6972 1.49383 3.23946 7 ]
[.89443 1.49364 -4.00559 0 ]
[.89443 1.49364 2.86941 7 ]
[.5 1.58759 -3.40625 0 ]
[.5 1.58759 3.40625 7 ]
[-0.01639 1.01241 -10.5625 -3.5 ]
[-0.01639 1.01241 0 3.5 ]
[.00591 1.14096 -10.3125 -3.5 ]
[.00591 1.14096 0 3.5 ]
[.02631 1.25847 -7.0625 -3.5 ]
[.02631 1.25847 0 3.5 ]
[.04502 1.36632 -6.875 -3.5 ]
[.04502 1.36632 0 3.5 ]
[.06226 1.46565 -7.125 -3.5 ]
[.06226 1.46565 0 3.5 ]
[-0.06739 1.25847 -7 -3.6875 ]
[-0.06739 1.25847 0 3.6875 ]
[.07541 .0193 -10.3125 -3.5 ]
[.07541 .0193 0 3.5 ]
[.05821 .19821 -14.9375 -3.5 ]
[.05821 .19821 0 3.5 ]
[.0395 .39294 -7.0625 -3.5 ]
[.0395 .39294 0 3.5 ]
[.01905 .60569 -11.5 -3.5 ]
[.01905 .60569 0 3.5 ]
[-0.00338 .8391 -6.875 -3.5 ]
[-0.00338 .8391 0 3.5 ]
[-0.05934 .44641 -27.0625 -5.40625 ]
[-0.05934 .44641 0 5.40625 ]
[ 0 0 0 0 ]
[ 1 1.47515 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08264 1.47515 m
.91736 1.47515 L
s
.10252 1.47515 m
.10099 1.46591 L
s
gsave
.10557 1.49364 -65.3563 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.30126 1.47515 m
.30049 1.46582 L
s
gsave
.3028 1.49383 -65.8448 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 1.47515 m
.5 1.46578 L
s
gsave
.5 1.49389 -66.1562 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.69874 1.47515 m
.69951 1.46582 L
s
gsave
.6972 1.49383 -64.823 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.89748 1.47515 m
.89901 1.46591 L
s
gsave
.89443 1.49364 -65.0056 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14227 1.47515 m
.14144 1.46959 L
s
.18201 1.47515 m
.18128 1.46958 L
s
.22176 1.47515 m
.22112 1.46957 L
s
.26151 1.47515 m
.26096 1.46956 L
s
.34101 1.47515 m
.34064 1.46954 L
s
.38076 1.47515 m
.38048 1.46954 L
s
.4205 1.47515 m
.42032 1.46953 L
s
.46025 1.47515 m
.46016 1.46953 L
s
.53975 1.47515 m
.53984 1.46953 L
s
.5795 1.47515 m
.57968 1.46953 L
s
.61924 1.47515 m
.61952 1.46954 L
s
.65899 1.47515 m
.65936 1.46954 L
s
.73849 1.47515 m
.73904 1.46956 L
s
.77824 1.47515 m
.77888 1.46957 L
s
.81799 1.47515 m
.81872 1.46958 L
s
.85773 1.47515 m
.85856 1.46959 L
s
gsave
.5 1.58759 -64.4062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
65.812 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .99889 m
.08264 1.47515 L
s
.00235 1.01241 m
.01172 1.01241 L
s
gsave
-0.01639 1.01241 -71.5625 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02465 1.14096 m
.03402 1.14096 L
s
gsave
.00591 1.14096 -71.3125 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.04505 1.25847 m
.05441 1.25847 L
s
gsave
.02631 1.25847 -68.0625 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.06376 1.36632 m
.07313 1.36632 L
s
gsave
.04502 1.36632 -67.875 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.081 1.46565 m
.09037 1.46565 L
s
gsave
.06226 1.46565 -68.125 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.00697 1.03907 m
.0126 1.03907 L
s
.01152 1.06525 m
.01714 1.06525 L
s
.01597 1.09094 m
.0216 1.09094 L
s
.02035 1.11618 m
.02597 1.11618 L
s
.02888 1.16529 m
.0345 1.16529 L
s
.03303 1.1892 m
.03865 1.1892 L
s
.0371 1.2127 m
.04272 1.2127 L
s
.04111 1.23578 m
.04673 1.23578 L
s
.04892 1.28078 m
.05454 1.28078 L
s
.05272 1.3027 m
.05834 1.3027 L
s
.05646 1.32427 m
.06208 1.32427 L
s
.06014 1.34547 m
.06576 1.34547 L
s
.06732 1.38684 m
.07294 1.38684 L
s
.07082 1.40702 m
.07644 1.40702 L
s
.07427 1.42688 m
.07989 1.42688 L
s
.07766 1.44642 m
.08328 1.44642 L
s
gsave
-0.06739 1.25847 -68 -7.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15.375 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
66.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.096 0 m
0 .99889 L
s
.09414 .0193 m
.10351 .0193 L
s
gsave
.07541 .0193 -71.3125 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.07695 .19821 m
.08632 .19821 L
s
gsave
.05821 .19821 -75.9375 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.05824 .39294 m
.06761 .39294 L
s
gsave
.0395 .39294 -68.0625 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.03779 .60569 m
.04716 .60569 L
s
gsave
.01905 .60569 -72.5 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.01536 .8391 m
.02473 .8391 L
s
gsave
-0.00338 .8391 -67.875 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.09082 .05391 m
.09644 .05391 L
s
.08744 .08909 m
.09306 .08909 L
s
.084 .12486 m
.08962 .12486 L
s
.08051 .16122 m
.08613 .16122 L
s
.07334 .23582 m
.07896 .23582 L
s
.06966 .27408 m
.07528 .27408 L
s
.06592 .31301 m
.07154 .31301 L
s
.06211 .35262 m
.06773 .35262 L
s
.05429 .43397 m
.05991 .43397 L
s
.05028 .47574 m
.0559 .47574 L
s
.04619 .51827 m
.05181 .51827 L
s
.04203 .56158 m
.04765 .56158 L
s
.03347 .65063 m
.03909 .65063 L
s
.02907 .69642 m
.03469 .69642 L
s
.02459 .74307 m
.03021 .74307 L
s
.02002 .79063 m
.02564 .79063 L
s
.01061 .88853 m
.01623 .88853 L
s
.00576 .93893 m
.01138 .93893 L
s
.00082 .99035 m
.00644 .99035 L
s
gsave
-0.05934 .44641 -88.0625 -9.40625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 18.8125 translate 1 -1 scale
63.000 11.875 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.312 9.438 moveto
(\") show
67.938 9.438 moveto
(########) show
75.438 9.438 moveto
(####) show
79.188 9.438 moveto
(####) show
82.938 9.438 moveto
(#) show
83.875 9.438 moveto
(#) show
68.312 11.875 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
72.938 11.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
78.188 11.875 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
82.000 11.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
63.000 9.188 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
86.062 11.875 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.096 0 m
0 .99889 L
s
0 .99889 m
.08264 1.47515 L
s
.08264 1.47515 m
.15172 .53521 L
s
.15172 .53521 m
.096 0 L
s
.904 0 m
.84828 .53521 L
s
.84828 .53521 m
.91736 1.47515 L
s
.91736 1.47515 m
1 .99889 L
s
1 .99889 m
.904 0 L
s
.096 0 m
0 .99889 L
s
0 .99889 m
1 .99889 L
s
1 .99889 m
.904 0 L
s
.904 0 m
.096 0 L
s
.15172 .53521 m
.84828 .53521 L
s
.84828 .53521 m
.91736 1.47515 L
s
.91736 1.47515 m
.08264 1.47515 L
s
.08264 1.47515 m
.15172 .53521 L
s
0 0 m
1 0 L
1 1.47515 L
0 1.47515 L
closepath
clip
newpath
.3 g
.01 w
.5 .30652 m
.5 1.10541 L
s
1 .36 0 r
.001 w
.72128 .99864 m
.72681 1.00677 L
s
.72681 1.00677 m
.68151 1.03729 L
s
.76621 .96842 m
.72681 1.00677 L
s
.67876 1.02765 m
.68151 1.03729 L
s
.68151 1.03729 m
.63316 1.05902 L
s
0 .4 1 r
.41169 1.09274 m
.40597 1.09933 L
s
.40597 1.09933 m
.36684 1.05902 L
s
.4513 1.13224 m
.40597 1.09933 L
s
1 .72 0 r
.58831 1.09274 m
.59403 1.09933 L
s
.59403 1.09933 m
.5487 1.13224 L
s
.63316 1.05902 m
.59403 1.09933 L
s
0 .4 1 r
.45426 1.12413 m
.4513 1.13224 L
s
.5 1.15685 m
.4513 1.13224 L
s
1 .72 0 r
.54574 1.12413 m
.5487 1.13224 L
s
.5487 1.13224 m
.5 1.15685 L
s
1 .36 0 r
.71574 .99042 m
.72128 .99864 L
s
.72128 .99864 m
.67876 1.02765 L
s
.75825 .96221 m
.72128 .99864 L
s
.676 1.01788 m
.67876 1.02765 L
s
.67876 1.02765 m
.63337 1.04828 L
s
.75825 .96221 m
.76621 .96842 L
s
.79714 .92361 m
.76621 .96842 L
s
.63337 1.04828 m
.63316 1.05902 L
s
.63316 1.05902 m
.58479 1.0713 L
s
0 .4 1 r
.37495 1.05438 m
.36684 1.05902 L
s
.36684 1.05902 m
.33641 1.01255 L
s
1 .72 0 r
.62505 1.05438 m
.63316 1.05902 L
s
.66359 1.01255 m
.63316 1.05902 L
s
0 .4 1 r
.41742 1.08614 m
.41169 1.09274 L
s
.41169 1.09274 m
.37495 1.05438 L
s
.45426 1.12413 m
.41169 1.09274 L
s
1 .72 0 r
.58258 1.08614 m
.58831 1.09274 L
s
.58831 1.09274 m
.54574 1.12413 L
s
.62505 1.05438 m
.58831 1.09274 L
s
1 .36 0 r
.71017 .98211 m
.71574 .99042 L
s
.71574 .99042 m
.676 1.01788 L
s
.75026 .95595 m
.71574 .99042 L
s
.75026 .95595 m
.75825 .96221 L
s
.78723 .91968 m
.75825 .96221 L
s
0 .4 1 r
.45723 1.11596 m
.45426 1.12413 L
s
.5 1.14766 m
.45426 1.12413 L
s
1 .72 0 r
.54277 1.11596 m
.54574 1.12413 L
s
.54574 1.12413 m
.5 1.14766 L
s
1 .36 0 r
.67323 1.00798 m
.676 1.01788 L
s
.676 1.01788 m
.63357 1.03739 L
s
.63357 1.03739 m
.63337 1.04828 L
s
.63337 1.04828 m
.58796 1.05989 L
s
0 .4 1 r
.38309 1.04979 m
.37495 1.05438 L
s
.37495 1.05438 m
.34642 1.01029 L
s
1 .72 0 r
.61691 1.04979 m
.62505 1.05438 L
s
.65358 1.01029 m
.62505 1.05438 L
s
0 .4 1 r
.5 1.14766 m
.5 1.15685 L
s
.54907 1.17263 m
.5 1.15685 L
s
1 .72 0 r
.5 1.15685 m
.45093 1.17263 L
s
0 .4 1 r
.42318 1.07953 m
.41742 1.08614 L
s
.41742 1.08614 m
.38309 1.04979 L
s
.45723 1.11596 m
.41742 1.08614 L
s
1 .72 0 r
.57682 1.07953 m
.58258 1.08614 L
s
.58258 1.08614 m
.54277 1.11596 L
s
.61691 1.04979 m
.58258 1.08614 L
s
1 .36 0 r
.74225 .94965 m
.75026 .95595 L
s
.77729 .91575 m
.75026 .95595 L
s
.70459 .97369 m
.71017 .98211 L
s
.71017 .98211 m
.67323 1.00798 L
s
.74225 .94965 m
.71017 .98211 L
s
.67044 .99793 m
.67323 1.00798 L
s
.67323 1.00798 m
.63377 1.02633 L
s
0 .4 1 r
.46021 1.10773 m
.45723 1.11596 L
s
.5 1.13836 m
.45723 1.11596 L
s
1 .72 0 r
.53979 1.10773 m
.54277 1.11596 L
s
.54277 1.11596 m
.5 1.13836 L
s
1 .36 0 r
.78723 .91968 m
.79714 .92361 L
s
.81747 .87404 m
.79714 .92361 L
s
0 .4 1 r
.34642 1.01029 m
.33641 1.01255 L
s
.33641 1.01255 m
.31676 .96159 L
s
1 .72 0 r
.65358 1.01029 m
.66359 1.01255 L
s
.68324 .96159 m
.66359 1.01255 L
s
1 .36 0 r
.63377 1.02633 m
.63357 1.03739 L
s
.63357 1.03739 m
.59114 1.04831 L
s
0 .4 1 r
.39126 1.04525 m
.38309 1.04979 L
s
.38309 1.04979 m
.35646 1.00811 L
s
1 .72 0 r
.60874 1.04525 m
.61691 1.04979 L
s
.64354 1.00811 m
.61691 1.04979 L
s
0 .4 1 r
.5 1.13836 m
.5 1.14766 L
s
.54607 1.16279 m
.5 1.14766 L
s
1 .72 0 r
.5 1.14766 m
.45393 1.16279 L
s
1 .36 0 r
.73421 .94329 m
.74225 .94965 L
s
.76734 .91182 m
.74225 .94965 L
s
.69898 .96517 m
.70459 .97369 L
s
.70459 .97369 m
.67044 .99793 L
s
.73421 .94329 m
.70459 .97369 L
s
.77729 .91575 m
.78723 .91968 L
s
.80623 .87271 m
.78723 .91968 L
s
0 .4 1 r
.42896 1.07292 m
.42318 1.07953 L
s
.42318 1.07953 m
.39126 1.04525 L
s
.46021 1.10773 m
.42318 1.07953 L
s
1 .72 0 r
.57104 1.07292 m
.57682 1.07953 L
s
.57682 1.07953 m
.53979 1.10773 L
s
.60874 1.04525 m
.57682 1.07953 L
s
1 .36 0 r
.66764 .98772 m
.67044 .99793 L
s
.67044 .99793 m
.63397 1.01509 L
s
.58796 1.05989 m
.58479 1.0713 L
s
.58479 1.0713 m
.53942 1.07382 L
s
1 .72 0 r
.64354 1.00811 m
.65358 1.01029 L
s
.67197 .96205 m
.65358 1.01029 L
s
0 .4 1 r
.35646 1.00811 m
.34642 1.01029 L
s
.34642 1.01029 m
.32803 .96205 L
s
1 .36 0 r
.63397 1.01509 m
.63377 1.02633 L
s
.63377 1.02633 m
.59432 1.03653 L
s
0 .4 1 r
.4632 1.09944 m
.46021 1.10773 L
s
.5 1.12897 m
.46021 1.10773 L
s
1 .72 0 r
.5368 1.09944 m
.53979 1.10773 L
s
.53979 1.10773 m
.5 1.12897 L
s
.60054 1.04076 m
.60874 1.04525 L
s
.63348 1.00604 m
.60874 1.04525 L
s
0 .4 1 r
.39946 1.04076 m
.39126 1.04525 L
s
.39126 1.04525 m
.36652 1.00604 L
s
1 .36 0 r
.72616 .93687 m
.73421 .94329 L
s
.75736 .90789 m
.73421 .94329 L
s
.76734 .91182 m
.77729 .91575 L
s
.79498 .87142 m
.77729 .91575 L
s
0 .4 1 r
.5 1.12897 m
.5 1.13836 L
s
.54307 1.15283 m
.5 1.13836 L
s
1 .72 0 r
.5 1.13836 m
.45693 1.15283 L
s
1 .36 0 r
.69336 .95654 m
.69898 .96517 L
s
.69898 .96517 m
.66764 .98772 L
s
.72616 .93687 m
.69898 .96517 L
s
.59114 1.04831 m
.58796 1.05989 L
s
.58796 1.05989 m
.5454 1.06214 L
s
.66483 .97736 m
.66764 .98772 L
s
.66764 .98772 m
.63417 1.00366 L
s
0 .4 1 r
.36652 1.00604 m
.35646 1.00811 L
s
.35646 1.00811 m
.33932 .96266 L
s
1 .72 0 r
.63348 1.00604 m
.64354 1.00811 L
s
.66068 .96266 m
.64354 1.00811 L
s
0 .4 1 r
.43476 1.0663 m
.42896 1.07292 L
s
.42896 1.07292 m
.39946 1.04076 L
s
.4632 1.09944 m
.42896 1.07292 L
s
1 .72 0 r
.56524 1.0663 m
.57104 1.07292 L
s
.57104 1.07292 m
.5368 1.09944 L
s
.60054 1.04076 m
.57104 1.07292 L
s
1 .36 0 r
.63417 1.00366 m
.63397 1.01509 L
s
.63397 1.01509 m
.59751 1.02455 L
s
.75736 .90789 m
.76734 .91182 L
s
.78371 .87017 m
.76734 .91182 L
s
.71807 .9304 m
.72616 .93687 L
s
.74736 .90397 m
.72616 .93687 L
s
0 .4 1 r
.54607 1.16279 m
.54907 1.17263 L
s
.59545 1.17938 m
.54907 1.17263 L
s
1 .72 0 r
.45393 1.16279 m
.45093 1.17263 L
s
.45093 1.17263 m
.40455 1.17938 L
s
0 .4 1 r
.4662 1.09109 m
.4632 1.09944 L
s
.5 1.11948 m
.4632 1.09944 L
s
1 .72 0 r
.5338 1.09109 m
.5368 1.09944 L
s
.5368 1.09944 m
.5 1.11948 L
s
0 .4 1 r
.40768 1.03633 m
.39946 1.04076 L
s
.39946 1.04076 m
.37661 1.00409 L
s
1 .72 0 r
.59232 1.03633 m
.60054 1.04076 L
s
.62339 1.00409 m
.60054 1.04076 L
s
1 .36 0 r
.59432 1.03653 m
.59114 1.04831 L
s
.59114 1.04831 m
.5514 1.05027 L
s
.68771 .94778 m
.69336 .95654 L
s
.69336 .95654 m
.66483 .97736 L
s
.71807 .9304 m
.69336 .95654 L
s
0 .4 1 r
.5 1.11948 m
.5 1.12897 L
s
.54005 1.14275 m
.5 1.12897 L
s
1 .72 0 r
.5 1.12897 m
.45995 1.14275 L
s
0 .4 1 r
.37661 1.00409 m
.36652 1.00604 L
s
.36652 1.00604 m
.35064 .96344 L
s
1 .72 0 r
.62339 1.00409 m
.63348 1.00604 L
s
.64936 .96344 m
.63348 1.00604 L
s
1 .36 0 r
.74736 .90397 m
.75736 .90789 L
s
.77243 .86898 m
.75736 .90789 L
s
.66201 .96683 m
.66483 .97736 L
s
.66483 .97736 m
.63436 .99204 L
s
0 .4 1 r
.32803 .96205 m
.31676 .96159 L
s
.31676 .96159 m
.30935 .90814 L
s
1 .72 0 r
.67197 .96205 m
.68324 .96159 L
s
.69065 .90814 m
.68324 .96159 L
s
1 .36 0 r
.63436 .99204 m
.63417 1.00366 L
s
.63417 1.00366 m
.60071 1.01236 L
s
.80623 .87271 m
.81747 .87404 L
s
.82565 .82179 m
.81747 .87404 L
s
.70997 .92388 m
.71807 .9304 L
s
.73734 .90004 m
.71807 .9304 L
s
0 .4 1 r
.44058 1.05969 m
.43476 1.0663 L
s
.43476 1.0663 m
.40768 1.03633 L
s
.4662 1.09109 m
.43476 1.0663 L
s
1 .72 0 r
.55942 1.05969 m
.56524 1.0663 L
s
.56524 1.0663 m
.5338 1.09109 L
s
.59232 1.03633 m
.56524 1.0663 L
s
1 .36 0 r
.59751 1.02455 m
.59432 1.03653 L
s
.59432 1.03653 m
.55741 1.03819 L
s
0 .4 1 r
.54307 1.15283 m
.54607 1.16279 L
s
.58959 1.16934 m
.54607 1.16279 L
s
1 .72 0 r
.45693 1.15283 m
.45393 1.16279 L
s
.45393 1.16279 m
.41041 1.16934 L
s
1 .36 0 r
.79498 .87142 m
.80623 .87271 L
s
.81382 .82328 m
.80623 .87271 L
s
1 .72 0 r
.66068 .96266 m
.67197 .96205 L
s
.67885 .91163 m
.67197 .96205 L
s
0 .4 1 r
.33932 .96266 m
.32803 .96205 L
s
.32803 .96205 m
.32115 .91163 L
s
1 .36 0 r
.73734 .90004 m
.74736 .90397 L
s
.76114 .86784 m
.74736 .90397 L
s
0 .4 1 r
.41592 1.03197 m
.40768 1.03633 L
s
.40768 1.03633 m
.38673 1.00227 L
s
1 .72 0 r
.58408 1.03197 m
.59232 1.03633 L
s
.61327 1.00227 m
.59232 1.03633 L
s
1 .36 0 r
.68204 .9389 m
.68771 .94778 L
s
.68771 .94778 m
.66201 .96683 L
s
.70997 .92388 m
.68771 .94778 L
s
0 .4 1 r
.46922 1.08269 m
.4662 1.09109 L
s
.5 1.10988 m
.4662 1.09109 L
s
1 .72 0 r
.53078 1.08269 m
.5338 1.09109 L
s
.5338 1.09109 m
.5 1.10988 L
s
0 .4 1 r
.38673 1.00227 m
.37661 1.00409 L
s
.37661 1.00409 m
.36197 .96439 L
s
1 .72 0 r
.61327 1.00227 m
.62339 1.00409 L
s
.63803 .96439 m
.62339 1.00409 L
s
1 .36 0 r
.65917 .95611 m
.66201 .96683 L
s
.66201 .96683 m
.63454 .9802 L
s
.63454 .9802 m
.63436 .99204 L
s
.63436 .99204 m
.60391 .99995 L
s
0 .4 1 r
.5 1.10988 m
.5 1.11948 L
s
.53703 1.13252 m
.5 1.11948 L
s
1 .72 0 r
.5 1.11948 m
.46297 1.13252 L
s
1 .36 0 r
.78371 .87017 m
.79498 .87142 L
s
.80199 .82485 m
.79498 .87142 L
s
.70184 .91729 m
.70997 .92388 L
s
.7273 .89613 m
.70997 .92388 L
s
.60071 1.01236 m
.59751 1.02455 L
s
.59751 1.02455 m
.56342 1.02591 L
s
1 .72 0 r
.64936 .96344 m
.66068 .96266 L
s
.66705 .91533 m
.66068 .96266 L
s
0 .4 1 r
.35064 .96344 m
.33932 .96266 L
s
.33932 .96266 m
.33295 .91533 L
s
1 .36 0 r
.7273 .89613 m
.73734 .90004 L
s
.74983 .86677 m
.73734 .90004 L
s
0 .4 1 r
.44642 1.05308 m
.44058 1.05969 L
s
.44058 1.05969 m
.41592 1.03197 L
s
.46922 1.08269 m
.44058 1.05969 L
s
1 .72 0 r
.55358 1.05308 m
.55942 1.05969 L
s
.55942 1.05969 m
.53078 1.08269 L
s
.58408 1.03197 m
.55942 1.05969 L
s
1 .36 0 r
.77243 .86898 m
.78371 .87017 L
s
.79015 .8265 m
.78371 .87017 L
s
0 .4 1 r
.54005 1.14275 m
.54307 1.15283 L
s
.58372 1.15915 m
.54307 1.15283 L
s
1 .72 0 r
.45995 1.14275 m
.45693 1.15283 L
s
.45693 1.15283 m
.41628 1.15915 L
s
1 .36 0 r
.67636 .92988 m
.68204 .9389 L
s
.68204 .9389 m
.65917 .95611 L
s
.70184 .91729 m
.68204 .9389 L
s
1 .72 0 r
.5758 1.02769 m
.58408 1.03197 L
s
.60313 1.00058 m
.58408 1.03197 L
s
0 .4 1 r
.4242 1.02769 m
.41592 1.03197 L
s
.41592 1.03197 m
.39687 1.00058 L
s
.39687 1.00058 m
.38673 1.00227 L
s
.38673 1.00227 m
.37332 .96554 L
s
1 .72 0 r
.60313 1.00058 m
.61327 1.00227 L
s
.62668 .96554 m
.61327 1.00227 L
s
1 .36 0 r
.63472 .96814 m
.63454 .9802 L
s
.63454 .9802 m
.60711 .98731 L
s
.65632 .94519 m
.65917 .95611 L
s
.65917 .95611 m
.63472 .96814 L
s
1 .72 0 r
.52776 1.07422 m
.53078 1.08269 L
s
.53078 1.08269 m
.5 1.10018 L
s
0 .4 1 r
.47224 1.07422 m
.46922 1.08269 L
s
.5 1.10018 m
.46922 1.08269 L
s
1 .36 0 r
.69369 .91063 m
.70184 .91729 L
s
.71724 .89222 m
.70184 .91729 L
s
.76114 .86784 m
.77243 .86898 L
s
.77832 .82826 m
.77243 .86898 L
s
1 0 0 r
.7368 .87706 m
.73956 .88874 L
s
.73956 .88874 m
.69065 .90814 L
s
.78554 .85958 m
.73956 .88874 L
s
1 .36 0 r
.5454 1.06214 m
.53942 1.07382 L
s
.53942 1.07382 m
.5 1.06653 L
s
.60391 .99995 m
.60071 1.01236 L
s
.60071 1.01236 m
.56944 1.01341 L
s
0 .4 1 r
.36197 .96439 m
.35064 .96344 L
s
.35064 .96344 m
.34476 .91925 L
s
1 .72 0 r
.63803 .96439 m
.64936 .96344 L
s
.65524 .91925 m
.64936 .96344 L
s
1 .36 0 r
.71724 .89222 m
.7273 .89613 L
s
.73851 .86577 m
.7273 .89613 L
s
0 .4 1 r
.5 1.10018 m
.5 1.10988 L
s
.534 1.12215 m
.5 1.10988 L
s
1 .72 0 r
.5 1.10988 m
.466 1.12215 L
s
1 0 0 r
.77995 .84957 m
.78554 .85958 L
s
.82565 .82179 m
.78554 .85958 L
s
1 .36 0 r
.74983 .86677 m
.76114 .86784 L
s
.76648 .83013 m
.76114 .86784 L
s
0 .4 1 r
.53703 1.13252 m
.54005 1.14275 L
s
.57783 1.14881 m
.54005 1.14275 L
s
1 .72 0 r
.46297 1.13252 m
.45995 1.14275 L
s
.45995 1.14275 m
.42217 1.14881 L
s
1 .36 0 r
.67065 .92072 m
.67636 .92988 L
s
.67636 .92988 m
.65632 .94519 L
s
.69369 .91063 m
.67636 .92988 L
s
.5514 1.05027 m
.5454 1.06214 L
s
.5454 1.06214 m
.50848 1.05493 L
s
1 .72 0 r
.54772 1.04649 m
.55358 1.05308 L
s
.55358 1.05308 m
.52776 1.07422 L
s
.5758 1.02769 m
.55358 1.05308 L
s
0 .4 1 r
.45228 1.04649 m
.44642 1.05308 L
s
.44642 1.05308 m
.4242 1.02769 L
s
.47224 1.07422 m
.44642 1.05308 L
s
1 .36 0 r
.6349 .95585 m
.63472 .96814 L
s
.63472 .96814 m
.61031 .97444 L
s
.60711 .98731 m
.60391 .99995 L
s
.60391 .99995 m
.57547 1.0007 L
s
0 .4 1 r
.37332 .96554 m
.36197 .96439 L
s
.36197 .96439 m
.35659 .92342 L
s
1 .72 0 r
.62668 .96554 m
.63803 .96439 L
s
.64341 .92342 m
.63803 .96439 L
s
0 .4 1 r
.40704 .99906 m
.39687 1.00058 L
s
.39687 1.00058 m
.3847 .96689 L
s
1 .72 0 r
.59296 .99906 m
.60313 1.00058 L
s
.6153 .96689 m
.60313 1.00058 L
s
1 .36 0 r
.70715 .88832 m
.71724 .89222 L
s
.72718 .86485 m
.71724 .89222 L
s
.68551 .90391 m
.69369 .91063 L
s
.70715 .88832 m
.69369 .91063 L
s
.65345 .93407 m
.65632 .94519 L
s
.65632 .94519 m
.6349 .95585 L
s
1 0 0 r
.73402 .86517 m
.7368 .87706 L
s
.7368 .87706 m
.69087 .89514 L
s
.77995 .84957 m
.7368 .87706 L
s
0 .4 1 r
.4325 1.0235 m
.4242 1.02769 L
s
.4242 1.02769 m
.40704 .99906 L
s
1 .72 0 r
.5675 1.0235 m
.5758 1.02769 L
s
.59296 .99906 m
.5758 1.02769 L
s
1 .36 0 r
.73851 .86577 m
.74983 .86677 L
s
.75464 .83212 m
.74983 .86677 L
s
1 0 0 r
.77433 .8394 m
.77995 .84957 L
s
.81757 .81384 m
.77995 .84957 L
s
0 .4 1 r
.32115 .91163 m
.30935 .90814 L
s
.30935 .90814 m
.31492 .85448 L
s
1 .72 0 r
.67885 .91163 m
.69065 .90814 L
s
.68508 .85448 m
.69065 .90814 L
s
1 0 0 r
.69087 .89514 m
.69065 .90814 L
s
.69065 .90814 m
.64183 .91688 L
s
1 .36 0 r
.55741 1.03819 m
.5514 1.05027 L
s
.5514 1.05027 m
.51697 1.04313 L
s
0 .4 1 r
.47528 1.0657 m
.47224 1.07422 L
s
.5 1.09035 m
.47224 1.07422 L
s
1 .72 0 r
.52472 1.0657 m
.52776 1.07422 L
s
.52776 1.07422 m
.5 1.09035 L
s
0 .4 1 r
.5 1.09035 m
.5 1.10018 L
s
.53095 1.11163 m
.5 1.10018 L
s
1 .72 0 r
.5 1.10018 m
.46905 1.11163 L
s
1 .36 0 r
.72718 .86485 m
.73851 .86577 L
s
.74279 .83424 m
.73851 .86577 L
s
.61031 .97444 m
.60711 .98731 L
s
.60711 .98731 m
.58151 .98777 L
s
.69705 .88445 m
.70715 .88832 L
s
.71583 .86402 m
.70715 .88832 L
s
.66492 .9114 m
.67065 .92072 L
s
.67065 .92072 m
.65345 .93407 L
s
.68551 .90391 m
.67065 .92072 L
s
1 0 0 r
.51807 .54641 m
.5065 .52664 L
s
.5065 .52664 m
.5257 .47904 L
s
.5 .67346 m
.5065 .52664 L
s
0 .4 1 r
.3847 .96689 m
.37332 .96554 L
s
.37332 .96554 m
.36843 .92784 L
s
1 .72 0 r
.6153 .96689 m
.62668 .96554 L
s
.63157 .92784 m
.62668 .96554 L
s
1 .36 0 r
.81382 .82328 m
.82565 .82179 L
s
.82086 .76923 m
.82565 .82179 L
s
1 0 0 r
.81757 .81384 m
.82565 .82179 L
s
.85728 .77689 m
.82565 .82179 L
s
0 .4 1 r
.534 1.12215 m
.53703 1.13252 L
s
.57192 1.13831 m
.53703 1.13252 L
s
1 .72 0 r
.466 1.12215 m
.46297 1.13252 L
s
.46297 1.13252 m
.42808 1.13831 L
s
0 .4 1 r
.33295 .91533 m
.32115 .91163 L
s
.32115 .91163 m
.32643 .86126 L
s
1 .72 0 r
.66705 .91533 m
.67885 .91163 L
s
.67357 .86126 m
.67885 .91163 L
s
1 .36 0 r
.63507 .94331 m
.6349 .95585 L
s
.6349 .95585 m
.61352 .96132 L
s
.67731 .89712 m
.68551 .90391 L
s
.69705 .88445 m
.68551 .90391 L
s
1 0 0 r
.73122 .85307 m
.73402 .86517 L
s
.73402 .86517 m
.69109 .88191 L
s
.77433 .8394 m
.73402 .86517 L
s
1 .36 0 r
.56342 1.02591 m
.55741 1.03819 L
s
.55741 1.03819 m
.52546 1.03114 L
s
.80199 .82485 m
.81382 .82328 L
s
.80925 .77365 m
.81382 .82328 L
s
.65057 .92272 m
.65345 .93407 L
s
.65345 .93407 m
.63507 .94331 L
s
0 .4 1 r
.41724 .9977 m
.40704 .99906 L
s
.40704 .99906 m
.3961 .96847 L
s
1 .72 0 r
.58276 .9977 m
.59296 .99906 L
s
.6039 .96847 m
.59296 .99906 L
s
1 0 0 r
.7687 .82905 m
.77433 .8394 L
s
.80946 .80576 m
.77433 .8394 L
s
0 .4 1 r
.45817 1.03992 m
.45228 1.04649 L
s
.45228 1.04649 m
.4325 1.0235 L
s
.47528 1.0657 m
.45228 1.04649 L
s
1 .72 0 r
.54183 1.03992 m
.54772 1.04649 L
s
.54772 1.04649 m
.52472 1.0657 L
s
.5675 1.0235 m
.54772 1.04649 L
s
1 0 0 r
.69109 .88191 m
.69087 .89514 L
s
.69087 .89514 m
.64506 .9029 L
s
1 .36 0 r
.79015 .8265 m
.80199 .82485 L
s
.79764 .77819 m
.80199 .82485 L
s
0 .4 1 r
.58959 1.16934 m
.59545 1.17938 L
s
.63616 1.17725 m
.59545 1.17938 L
s
1 .72 0 r
.41041 1.16934 m
.40455 1.17938 L
s
.40455 1.17938 m
.36384 1.17725 L
s
1 .36 0 r
.71583 .86402 m
.72718 .86485 L
s
.73094 .8365 m
.72718 .86485 L
s
0 .4 1 r
.34476 .91925 m
.33295 .91533 L
s
.33295 .91533 m
.33793 .86831 L
s
1 .72 0 r
.65524 .91925 m
.66705 .91533 L
s
.66207 .86831 m
.66705 .91533 L
s
0 .4 1 r
.44083 1.01942 m
.4325 1.0235 L
s
.4325 1.0235 m
.41724 .9977 L
s
1 .72 0 r
.55917 1.01942 m
.5675 1.0235 L
s
.58276 .9977 m
.5675 1.0235 L
s
1 .36 0 r
.77832 .82826 m
.79015 .8265 L
s
.78605 .78286 m
.79015 .8265 L
s
.61352 .96132 m
.61031 .97444 L
s
.61031 .97444 m
.58755 .97461 L
s
.68692 .88059 m
.69705 .88445 L
s
.70446 .86328 m
.69705 .88445 L
s
.56944 1.01341 m
.56342 1.02591 L
s
.56342 1.02591 m
.53395 1.01895 L
s
1 0 0 r
.80946 .80576 m
.81757 .81384 L
s
.8472 .77133 m
.81757 .81384 L
s
0 .4 1 r
.3961 .96847 m
.3847 .96689 L
s
.3847 .96689 m
.38028 .93253 L
s
1 .72 0 r
.6039 .96847 m
.6153 .96689 L
s
.61972 .93253 m
.6153 .96689 L
s
1 .36 0 r
.76648 .83013 m
.77832 .82826 L
s
.77447 .78768 m
.77832 .82826 L
s
0 .4 1 r
.47833 1.05712 m
.47528 1.0657 L
s
.5 1.0804 m
.47528 1.0657 L
s
1 .72 0 r
.52167 1.05712 m
.52472 1.0657 L
s
.52472 1.0657 m
.5 1.0804 L
s
1 .36 0 r
.63524 .9305 m
.63507 .94331 L
s
.63507 .94331 m
.61673 .94794 L
s
.65917 .90191 m
.66492 .9114 L
s
.66492 .9114 m
.65057 .92272 L
s
.67731 .89712 m
.66492 .9114 L
s
0 .4 1 r
.5 1.0804 m
.5 1.09035 L
s
.5279 1.10095 m
.5 1.09035 L
s
1 .72 0 r
.5 1.09035 m
.4721 1.10095 L
s
1 0 0 r
.72841 .84074 m
.73122 .85307 L
s
.73122 .85307 m
.69131 .86845 L
s
.7687 .82905 m
.73122 .85307 L
s
1 .36 0 r
.70446 .86328 m
.71583 .86402 L
s
.71909 .83891 m
.71583 .86402 L
s
0 .4 1 r
.53095 1.11163 m
.534 1.12215 L
s
.566 1.12764 m
.534 1.12215 L
s
1 .72 0 r
.46905 1.11163 m
.466 1.12215 L
s
.466 1.12215 m
.434 1.12764 L
s
1 .36 0 r
.66909 .89025 m
.67731 .89712 L
s
.68692 .88059 m
.67731 .89712 L
s
0 .4 1 r
.35659 .92342 m
.34476 .91925 L
s
.34476 .91925 m
.34944 .87564 L
s
1 .72 0 r
.64341 .92342 m
.65524 .91925 L
s
.65056 .87564 m
.65524 .91925 L
s
1 0 0 r
.76305 .81851 m
.7687 .82905 L
s
.80134 .79755 m
.7687 .82905 L
s
1 .36 0 r
.75464 .83212 m
.76648 .83013 L
s
.76289 .79265 m
.76648 .83013 L
s
.64768 .91113 m
.65057 .92272 L
s
.65057 .92272 m
.63524 .9305 L
s
1 0 0 r
.69131 .86845 m
.69109 .88191 L
s
.69109 .88191 m
.64828 .88869 L
s
1 .36 0 r
.57547 1.0007 m
.56944 1.01341 L
s
.56944 1.01341 m
.54245 1.00658 L
s
0 .4 1 r
.58372 1.15915 m
.58959 1.16934 L
s
.62774 1.1674 m
.58959 1.16934 L
s
1 .72 0 r
.41628 1.15915 m
.41041 1.16934 L
s
.41041 1.16934 m
.37226 1.1674 L
s
0 .4 1 r
.42747 .99653 m
.41724 .9977 L
s
.41724 .9977 m
.40752 .9703 L
s
1 .72 0 r
.57253 .99653 m
.58276 .9977 L
s
.59248 .9703 m
.58276 .9977 L
s
1 .36 0 r
.61673 .94794 m
.61352 .96132 L
s
.61352 .96132 m
.59359 .96123 L
s
.74279 .83424 m
.75464 .83212 L
s
.75133 .79779 m
.75464 .83212 L
s
.67677 .87676 m
.68692 .88059 L
s
.69309 .86266 m
.68692 .88059 L
s
1 0 0 r
.80134 .79755 m
.80946 .80576 L
s
.83709 .76569 m
.80946 .80576 L
s
1 .36 0 r
.69309 .86266 m
.70446 .86328 L
s
.70723 .84151 m
.70446 .86328 L
s
0 .4 1 r
.36843 .92784 m
.35659 .92342 L
s
.35659 .92342 m
.36095 .88326 L
s
1 .72 0 r
.63157 .92784 m
.64341 .92342 L
s
.63905 .88326 m
.64341 .92342 L
s
1 .36 0 r
.73094 .8365 m
.74279 .83424 L
s
.73977 .8031 m
.74279 .83424 L
s
0 .4 1 r
.40752 .9703 m
.3961 .96847 L
s
.3961 .96847 m
.39215 .93749 L
s
1 .72 0 r
.59248 .9703 m
.6039 .96847 L
s
.60785 .93749 m
.6039 .96847 L
s
0 .4 1 r
.46407 1.03338 m
.45817 1.03992 L
s
.45817 1.03992 m
.44083 1.01942 L
s
.47833 1.05712 m
.45817 1.03992 L
s
1 .72 0 r
.53593 1.03338 m
.54183 1.03992 L
s
.54183 1.03992 m
.52167 1.05712 L
s
.55917 1.01942 m
.54183 1.03992 L
s
1 .36 0 r
.6354 .91741 m
.63524 .9305 L
s
.63524 .9305 m
.61993 .93429 L
s
.58151 .98777 m
.57547 1.0007 L
s
.57547 1.0007 m
.55095 .99403 L
s
0 .4 1 r
.44919 1.01547 m
.44083 1.01942 L
s
.44083 1.01942 m
.42747 .99653 L
s
1 .72 0 r
.55081 1.01547 m
.55917 1.01942 L
s
.57253 .99653 m
.55917 1.01942 L
s
1 0 0 r
.72558 .82819 m
.72841 .84074 L
s
.72841 .84074 m
.69151 .85475 L
s
.76305 .81851 m
.72841 .84074 L
s
1 .36 0 r
.6534 .89223 m
.65917 .90191 L
s
.65917 .90191 m
.64768 .91113 L
s
.66909 .89025 m
.65917 .90191 L
s
.66084 .88329 m
.66909 .89025 L
s
.67677 .87676 m
.66909 .89025 L
s
1 0 0 r
.75737 .80778 m
.76305 .81851 L
s
.79318 .7892 m
.76305 .81851 L
s
.69151 .85475 m
.69131 .86845 L
s
.69131 .86845 m
.6515 .87423 L
s
1 .36 0 r
.71909 .83891 m
.73094 .8365 L
s
.72822 .80862 m
.73094 .8365 L
s
.61993 .93429 m
.61673 .94794 L
s
.61673 .94794 m
.59964 .94763 L
s
0 .4 1 r
.5279 1.10095 m
.53095 1.11163 L
s
.56007 1.1168 m
.53095 1.11163 L
s
1 .72 0 r
.4721 1.10095 m
.46905 1.11163 L
s
.46905 1.11163 m
.43993 1.1168 L
s
1 .36 0 r
.64477 .89927 m
.64768 .91113 L
s
.64768 .91113 m
.6354 .91741 L
s
1 .72 0 r
.42217 1.14881 m
.41628 1.15915 L
s
.41628 1.15915 m
.3807 1.15739 L
s
0 .4 1 r
.57783 1.14881 m
.58372 1.15915 L
s
.6193 1.15739 m
.58372 1.15915 L
s
1 0 0 r
.52971 .56452 m
.51807 .54641 L
s
.51807 .54641 m
.53613 .49514 L
s
.51209 .67346 m
.51807 .54641 L
s
0 .4 1 r
.5 1.07032 m
.5 1.0804 L
s
.52483 1.0901 m
.5 1.0804 L
s
1 .72 0 r
.5 1.0804 m
.47517 1.0901 L
s
1 0 0 r
.64506 .9029 m
.64183 .91688 L
s
.64183 .91688 m
.59621 .91427 L
s
1 .36 0 r
.68169 .86217 m
.69309 .86266 L
s
.69537 .84429 m
.69309 .86266 L
s
0 .4 1 r
.48139 1.04847 m
.47833 1.05712 L
s
.5 1.07032 m
.47833 1.05712 L
s
1 .72 0 r
.51861 1.04847 m
.52167 1.05712 L
s
.52167 1.05712 m
.5 1.07032 L
s
0 .4 1 r
.38028 .93253 m
.36843 .92784 L
s
.36843 .92784 m
.37246 .89119 L
s
1 .72 0 r
.61972 .93253 m
.63157 .92784 L
s
.62754 .89119 m
.63157 .92784 L
s
1 0 0 r
.79318 .7892 m
.80134 .79755 L
s
.82697 .75997 m
.80134 .79755 L
s
1 .36 0 r
.6666 .87297 m
.67677 .87676 L
s
.68169 .86217 m
.67677 .87676 L
s
.58755 .97461 m
.58151 .98777 L
s
.58151 .98777 m
.55945 .9813 L
s
.70723 .84151 m
.71909 .83891 L
s
.71667 .81434 m
.71909 .83891 L
s
0 .4 1 r
.43772 .99558 m
.42747 .99653 L
s
.42747 .99653 m
.41897 .97238 L
s
1 .72 0 r
.56228 .99558 m
.57253 .99653 L
s
.58103 .97238 m
.57253 .99653 L
s
1 0 0 r
.8472 .77133 m
.85728 .77689 L
s
.87823 .72671 m
.85728 .77689 L
s
1 .36 0 r
.63555 .90402 m
.6354 .91741 L
s
.6354 .91741 m
.62314 .92038 L
s
0 .4 1 r
.41897 .97238 m
.40752 .9703 L
s
.40752 .9703 m
.40403 .94275 L
s
1 .72 0 r
.58103 .97238 m
.59248 .9703 L
s
.59597 .94275 m
.59248 .9703 L
s
1 0 0 r
.72274 .8154 m
.72558 .82819 L
s
.72558 .82819 m
.69171 .84081 L
s
.75737 .80778 m
.72558 .82819 L
s
1 .36 0 r
.69537 .84429 m
.70723 .84151 L
s
.70514 .8203 m
.70723 .84151 L
s
1 0 0 r
.69171 .84081 m
.69151 .85475 L
s
.69151 .85475 m
.65472 .85954 L
s
1 .36 0 r
.62314 .92038 m
.61993 .93429 L
s
.61993 .93429 m
.60569 .93381 L
s
.59359 .96123 m
.58755 .97461 L
s
.58755 .97461 m
.56795 .9684 L
s
1 0 0 r
.75167 .79684 m
.75737 .80778 L
s
.785 .78069 m
.75737 .80778 L
s
.64828 .88869 m
.64506 .9029 L
s
.64506 .9029 m
.60226 .89954 L
s
1 .36 0 r
.67028 .86183 m
.68169 .86217 L
s
.6835 .84729 m
.68169 .86217 L
s
.64761 .88235 m
.6534 .89223 L
s
.6534 .89223 m
.64477 .89927 L
s
.66084 .88329 m
.6534 .89223 L
s
.65257 .87625 m
.66084 .88329 L
s
.6666 .87297 m
.66084 .88329 L
s
0 .4 1 r
.39215 .93749 m
.38028 .93253 L
s
.38028 .93253 m
.38398 .89943 L
s
1 .72 0 r
.60785 .93749 m
.61972 .93253 L
s
.61602 .89943 m
.61972 .93253 L
s
0 .4 1 r
.57192 1.13831 m
.57783 1.14881 L
s
.61085 1.14722 m
.57783 1.14881 L
s
1 .72 0 r
.42808 1.13831 m
.42217 1.14881 L
s
.42217 1.14881 m
.38915 1.14722 L
s
1 0 0 r
.785 .78069 m
.79318 .7892 L
s
.81682 .75415 m
.79318 .7892 L
s
1 .36 0 r
.64185 .88713 m
.64477 .89927 L
s
.64477 .89927 m
.63555 .90402 L
s
0 .4 1 r
.47 1.02687 m
.46407 1.03338 L
s
.46407 1.03338 m
.44919 1.01547 L
s
.48139 1.04847 m
.46407 1.03338 L
s
1 .72 0 r
.53 1.02687 m
.53593 1.03338 L
s
.53593 1.03338 m
.51861 1.04847 L
s
.55081 1.01547 m
.53593 1.03338 L
s
0 .4 1 r
.32643 .86126 m
.31492 .85448 L
s
.31492 .85448 m
.33331 .80314 L
s
1 .72 0 r
.67357 .86126 m
.68508 .85448 L
s
.66669 .80314 m
.68508 .85448 L
s
1 .36 0 r
.65641 .86922 m
.6666 .87297 L
s
.67028 .86183 m
.6666 .87297 L
s
.6835 .84729 m
.69537 .84429 L
s
.6936 .8265 m
.69537 .84429 L
s
0 .4 1 r
.45758 1.01165 m
.44919 1.01547 L
s
.44919 1.01547 m
.43772 .99558 L
s
1 .72 0 r
.54242 1.01165 m
.55081 1.01547 L
s
.56228 .99558 m
.55081 1.01547 L
s
1 0 0 r
.83709 .76569 m
.8472 .77133 L
s
.86677 .72383 m
.8472 .77133 L
s
0 .4 1 r
.52483 1.0901 m
.5279 1.10095 L
s
.55412 1.10576 m
.5279 1.10095 L
s
1 .72 0 r
.47517 1.0901 m
.4721 1.10095 L
s
.4721 1.10095 m
.44588 1.10576 L
s
1 .36 0 r
.59964 .94763 m
.59359 .96123 L
s
.59359 .96123 m
.57645 .95535 L
s
.92 1 0 r
.45422 1.10625 m
.4603 1.11131 L
s
.4603 1.11131 m
.41397 1.14848 L
s
.5 1.06653 m
.4603 1.11131 L
s
0 .76 1 r
.54578 1.10625 m
.5397 1.11131 L
s
.5397 1.11131 m
.5 1.06653 L
s
.58603 1.14848 m
.5397 1.11131 L
s
0 .4 1 r
.33793 .86831 m
.32643 .86126 L
s
.32643 .86126 m
.34371 .81344 L
s
1 .72 0 r
.66207 .86831 m
.67357 .86126 L
s
.65629 .81344 m
.67357 .86126 L
s
0 .4 1 r
.5 1.06011 m
.5 1.07032 L
s
.52176 1.07907 m
.5 1.07032 L
s
1 .72 0 r
.5 1.07032 m
.47824 1.07907 L
s
1 .36 0 r
.62635 .90618 m
.62314 .92038 L
s
.62314 .92038 m
.61174 .91978 L
s
1 0 0 r
.6515 .87423 m
.64828 .88869 L
s
.64828 .88869 m
.60831 .88458 L
s
1 .36 0 r
.6357 .89032 m
.63555 .90402 L
s
.63555 .90402 m
.62635 .90618 L
s
1 0 0 r
.6919 .82662 m
.69171 .84081 L
s
.69171 .84081 m
.65794 .84463 L
s
1 .36 0 r
.65886 .86165 m
.67028 .86183 L
s
.67163 .85052 m
.67028 .86183 L
s
1 0 0 r
.71988 .80236 m
.72274 .8154 L
s
.72274 .8154 m
.6919 .82662 L
s
.75167 .79684 m
.72274 .8154 L
s
1 .36 0 r
.77447 .78768 m
.78605 .78286 L
s
.76289 .79265 m
.77447 .78768 L
s
.76101 .7493 m
.77447 .78768 L
s
.75133 .79779 m
.76289 .79265 L
s
.75051 .75735 m
.76289 .79265 L
s
.67163 .85052 m
.6835 .84729 L
s
.68207 .83297 m
.6835 .84729 L
s
0 .4 1 r
.48446 1.03977 m
.48139 1.04847 L
s
.5 1.06011 m
.48139 1.04847 L
s
1 .72 0 r
.51554 1.03977 m
.51861 1.04847 L
s
.51861 1.04847 m
.5 1.06011 L
s
1 .36 0 r
.78605 .78286 m
.79764 .77819 L
s
.77152 .74145 m
.78605 .78286 L
s
.73977 .8031 m
.75133 .79779 L
s
.74004 .7656 m
.75133 .79779 L
s
1 .72 0 r
.59597 .94275 m
.60785 .93749 L
s
.60449 .90796 m
.60785 .93749 L
s
0 .4 1 r
.40403 .94275 m
.39215 .93749 L
s
.39215 .93749 m
.39551 .90796 L
s
1 .36 0 r
.79764 .77819 m
.80925 .77365 L
s
.78205 .73378 m
.79764 .77819 L
s
0 .4 1 r
.43045 .97474 m
.41897 .97238 L
s
.41897 .97238 m
.41594 .94831 L
s
1 .72 0 r
.56955 .97474 m
.58103 .97238 L
s
.58406 .94831 m
.58103 .97238 L
s
1 0 0 r
.74594 .78569 m
.75167 .79684 L
s
.7768 .77203 m
.75167 .79684 L
s
1 .36 0 r
.72822 .80862 m
.73977 .8031 L
s
.72958 .77407 m
.73977 .8031 L
s
0 .4 1 r
.34944 .87564 m
.33793 .86831 L
s
.33793 .86831 m
.3541 .82408 L
s
1 .72 0 r
.65056 .87564 m
.66207 .86831 L
s
.6459 .82408 m
.66207 .86831 L
s
1 .36 0 r
.60569 .93381 m
.59964 .94763 L
s
.59964 .94763 m
.58496 .94217 L
s
0 .4 1 r
.44801 .99485 m
.43772 .99558 L
s
.43772 .99558 m
.43045 .97474 L
s
1 .72 0 r
.55199 .99485 m
.56228 .99558 L
s
.56955 .97474 m
.56228 .99558 L
s
1 .36 0 r
.80925 .77365 m
.82086 .76923 L
s
.79259 .72627 m
.80925 .77365 L
s
.71667 .81434 m
.72822 .80862 L
s
.71913 .78278 m
.72822 .80862 L
s
1 0 0 r
.82697 .75997 m
.83709 .76569 L
s
.8553 .72092 m
.83709 .76569 L
s
.7768 .77203 m
.785 .78069 L
s
.80665 .74823 m
.785 .78069 L
s
1 .36 0 r
.80316 .71892 m
.82086 .76923 L
s
0 .4 1 r
.566 1.12764 m
.57192 1.13831 L
s
.60239 1.13688 m
.57192 1.13831 L
s
1 .72 0 r
.434 1.12764 m
.42808 1.13831 L
s
.42808 1.13831 m
.39761 1.13688 L
s
1 .36 0 r
.70514 .8203 m
.71667 .81434 L
s
.7087 .79172 m
.71667 .81434 L
s
.6418 .87224 m
.64761 .88235 L
s
.64761 .88235 m
.64185 .88713 L
s
.65257 .87625 m
.64761 .88235 L
s
.64428 .86912 m
.65257 .87625 L
s
.65641 .86922 m
.65257 .87625 L
s
.50848 1.05493 m
.5 1.06653 L
s
.5 1.06653 m
.46925 1.04956 L
s
0 .76 1 r
.50849 1.06372 m
.5 1.06653 L
s
.5 1.06653 m
.46945 1.01529 L
s
.92 1 0 r
.49151 1.06372 m
.5 1.06653 L
s
.53055 1.01529 m
.5 1.06653 L
s
1 0 0 r
.53613 .49514 m
.5257 .47904 L
s
.5257 .47904 m
.55658 .44802 L
s
1 .36 0 r
.6462 .86552 m
.65641 .86922 L
s
.65886 .86165 m
.65641 .86922 L
s
.63892 .87468 m
.64185 .88713 L
s
.64185 .88713 m
.6357 .89032 L
s
.6936 .8265 m
.70514 .8203 L
s
.69828 .80092 m
.70514 .8203 L
s
1 .72 0 r
.63905 .88326 m
.65056 .87564 L
s
.63552 .83505 m
.65056 .87564 L
s
0 .4 1 r
.36095 .88326 m
.34944 .87564 L
s
.34944 .87564 m
.36448 .83505 L
s
1 0 0 r
.65472 .85954 m
.6515 .87423 L
s
.6515 .87423 m
.61436 .86942 L
s
1 .36 0 r
.65975 .85401 m
.67163 .85052 L
s
.67054 .83973 m
.67163 .85052 L
s
.62956 .8917 m
.62635 .90618 L
s
.62635 .90618 m
.61779 .90556 L
s
.61174 .91978 m
.60569 .93381 L
s
.60569 .93381 m
.59346 .92889 L
s
1 0 0 r
.54138 .58035 m
.52971 .56452 L
s
.52971 .56452 m
.54659 .51116 L
s
.52418 .67346 m
.52971 .56452 L
s
1 .36 0 r
.51697 1.04313 m
.50848 1.05493 L
s
.50848 1.05493 m
.47973 1.03831 L
s
.68207 .83297 m
.6936 .8265 L
s
.68787 .81039 m
.6936 .8265 L
s
.64742 .86166 m
.65886 .86165 L
s
.65975 .85401 m
.65886 .86165 L
s
0 .76 1 r
.58933 1.14169 m
.58603 1.14848 L
s
.63616 1.17725 m
.58603 1.14848 L
s
.92 1 0 r
.41067 1.14169 m
.41397 1.14848 L
s
.41397 1.14848 m
.36384 1.17725 L
s
0 .4 1 r
.52176 1.07907 m
.52483 1.0901 L
s
.54815 1.09452 m
.52483 1.0901 L
s
1 .72 0 r
.47824 1.07907 m
.47517 1.0901 L
s
.47517 1.0901 m
.45185 1.09452 L
s
1 0 0 r
.69208 .81218 m
.6919 .82662 L
s
.6919 .82662 m
.66116 .82952 L
s
1 .36 0 r
.63583 .87628 m
.6357 .89032 L
s
.6357 .89032 m
.62956 .8917 L
s
1 0 0 r
.81682 .75415 m
.82697 .75997 L
s
.84382 .71796 m
.82697 .75997 L
s
.717 .78907 m
.71988 .80236 L
s
.71988 .80236 m
.69208 .81218 L
s
.74594 .78569 m
.71988 .80236 L
s
0 .4 1 r
.41594 .94831 m
.40403 .94275 L
s
.40403 .94275 m
.40705 .91679 L
s
1 .72 0 r
.58406 .94831 m
.59597 .94275 L
s
.59295 .91679 m
.59597 .94275 L
s
1 .36 0 r
.67054 .83973 m
.68207 .83297 L
s
.67748 .82013 m
.68207 .83297 L
s
0 .4 1 r
.37246 .89119 m
.36095 .88326 L
s
.36095 .88326 m
.37487 .84636 L
s
1 .72 0 r
.62754 .89119 m
.63905 .88326 L
s
.62513 .84636 m
.63905 .88326 L
s
1 .36 0 r
.52546 1.03114 m
.51697 1.04313 L
s
.51697 1.04313 m
.4902 1.02688 L
s
.61779 .90556 m
.61174 .91978 L
s
.61174 .91978 m
.60196 .91552 L
s
1 0 0 r
.7402 .7743 m
.74594 .78569 L
s
.76858 .76319 m
.74594 .78569 L
s
.76858 .76319 m
.7768 .77203 L
s
.79647 .74221 m
.7768 .77203 L
s
0 .4 1 r
.47596 1.02042 m
.47 1.02687 L
s
.47 1.02687 m
.45758 1.01165 L
s
.48446 1.03977 m
.47 1.02687 L
s
1 .72 0 r
.52404 1.02042 m
.53 1.02687 L
s
.53 1.02687 m
.51554 1.03977 L
s
.54242 1.01165 m
.53 1.02687 L
s
0 .4 1 r
.466 1.00799 m
.45758 1.01165 L
s
.45758 1.01165 m
.44801 .99485 L
s
1 .72 0 r
.534 1.00799 m
.54242 1.01165 L
s
.55199 .99485 m
.54242 1.01165 L
s
1 .36 0 r
.64786 .85779 m
.65975 .85401 L
s
.65902 .84679 m
.65975 .85401 L
s
1 0 0 r
.65794 .84463 m
.65472 .85954 L
s
.65472 .85954 m
.62041 .8541 L
s
1 .36 0 r
.53395 1.01895 m
.52546 1.03114 L
s
.52546 1.03114 m
.50067 1.0153 L
s
.63276 .87693 m
.62956 .8917 L
s
.62956 .8917 m
.62385 .89115 L
s
1 .72 0 r
.43993 1.1168 m
.434 1.12764 L
s
.434 1.12764 m
.40609 1.12635 L
s
0 .4 1 r
.56007 1.1168 m
.566 1.12764 L
s
.59391 1.12635 m
.566 1.12764 L
s
1 .36 0 r
.65902 .84679 m
.67054 .83973 L
s
.66709 .83015 m
.67054 .83973 L
s
0 .4 1 r
.5 1.04975 m
.5 1.06011 L
s
.51868 1.06784 m
.5 1.06011 L
s
1 .72 0 r
.5 1.06011 m
.48132 1.06784 L
s
0 .4 1 r
.44195 .97739 m
.43045 .97474 L
s
.43045 .97474 m
.42786 .95417 L
s
1 .72 0 r
.55805 .97739 m
.56955 .97474 L
s
.57214 .95417 m
.56955 .97474 L
s
1 .36 0 r
.63596 .86189 m
.64428 .86912 L
s
.64428 .86912 m
.6418 .87224 L
s
.6462 .86552 m
.64428 .86912 L
s
.63596 .86189 m
.6418 .87224 L
s
.6418 .87224 m
.63892 .87468 L
s
.62385 .89115 m
.61779 .90556 L
s
.61779 .90556 m
.61046 .9021 L
s
1 .72 0 r
.61602 .89943 m
.62754 .89119 L
s
.61475 .85799 m
.62754 .89119 L
s
0 .4 1 r
.38398 .89943 m
.37246 .89119 L
s
.37246 .89119 m
.38525 .85799 L
s
1 .36 0 r
.54245 1.00658 m
.53395 1.01895 L
s
.53395 1.01895 m
.51113 1.00357 L
s
.63596 .86189 m
.6462 .86552 L
s
.64742 .86166 m
.6462 .86552 L
s
.63596 .86189 m
.63892 .87468 L
s
.63892 .87468 m
.63583 .87628 L
s
1 0 0 r
.80665 .74823 m
.81682 .75415 L
s
.83232 .71496 m
.81682 .75415 L
s
.92 1 0 r
.4481 1.10128 m
.45422 1.10625 L
s
.45422 1.10625 m
.41067 1.14169 L
s
.49151 1.06372 m
.45422 1.10625 L
s
0 .76 1 r
.5519 1.10128 m
.54578 1.10625 L
s
.54578 1.10625 m
.50849 1.06372 L
s
.58933 1.14169 m
.54578 1.10625 L
s
1 0 0 r
.69226 .79752 m
.69208 .81218 L
s
.69208 .81218 m
.66438 .81422 L
s
1 .36 0 r
.63596 .86189 m
.64742 .86166 L
s
.64786 .85779 m
.64742 .86166 L
s
1 0 0 r
.54659 .51116 m
.53613 .49514 L
s
.53613 .49514 m
.56514 .46333 L
s
1 .36 0 r
.64749 .85417 m
.65902 .84679 L
s
.65671 .84045 m
.65902 .84679 L
s
0 .4 1 r
.45834 .99437 m
.44801 .99485 L
s
.44801 .99485 m
.44195 .97739 L
s
1 .72 0 r
.54166 .99437 m
.55199 .99485 L
s
.55805 .97739 m
.55199 .99485 L
s
0 .4 1 r
.48755 1.03101 m
.48446 1.03977 L
s
.5 1.04975 m
.48446 1.03977 L
s
1 .72 0 r
.51245 1.03101 m
.51554 1.03977 L
s
.51554 1.03977 m
.5 1.04975 L
s
1 .36 0 r
.63596 .86189 m
.63583 .87628 L
s
.63583 .87628 m
.63276 .87693 L
s
.55095 .99403 m
.54245 1.00658 L
s
.54245 1.00658 m
.52158 .99172 L
s
.63596 .86189 m
.64786 .85779 L
s
.64749 .85417 m
.64786 .85779 L
s
.62991 .87659 m
.62385 .89115 L
s
.62385 .89115 m
.61896 .88867 L
s
1 0 0 r
.66116 .82952 m
.65794 .84463 L
s
.65794 .84463 m
.62646 .83864 L
s
.71411 .77552 m
.717 .78907 L
s
.717 .78907 m
.69226 .79752 L
s
.7402 .7743 m
.717 .78907 L
s
1 .36 0 r
.55945 .9813 m
.55095 .99403 L
s
.55095 .99403 m
.53202 .97976 L
s
0 .4 1 r
.42786 .95417 m
.41594 .94831 L
s
.41594 .94831 m
.4186 .92591 L
s
1 .72 0 r
.57214 .95417 m
.58406 .94831 L
s
.5814 .92591 m
.58406 .94831 L
s
1 0 0 r
.76032 .75418 m
.76858 .76319 L
s
.78626 .73607 m
.76858 .76319 L
s
1 .36 0 r
.63596 .86189 m
.63276 .87693 L
s
.63276 .87693 m
.62991 .87659 L
s
.68787 .81039 m
.69828 .80092 L
s
.67748 .82013 m
.68787 .81039 L
s
.67857 .79705 m
.68787 .81039 L
s
.66709 .83015 m
.67748 .82013 L
s
.67003 .80966 m
.67748 .82013 L
s
.69828 .80092 m
.7087 .79172 L
s
.68712 .78467 m
.69828 .80092 L
s
1 0 0 r
.73443 .76267 m
.7402 .7743 L
s
.76032 .75418 m
.7402 .7743 L
s
1 .36 0 r
.56795 .9684 m
.55945 .9813 L
s
.55945 .9813 m
.54245 .96773 L
s
0 .4 1 r
.51868 1.06784 m
.52176 1.07907 L
s
.54218 1.08307 m
.52176 1.07907 L
s
1 .72 0 r
.48132 1.06784 m
.47824 1.07907 L
s
.47824 1.07907 m
.45782 1.08307 L
s
1 .36 0 r
.65671 .84045 m
.66709 .83015 L
s
.6615 .82247 m
.66709 .83015 L
s
.7087 .79172 m
.71913 .78278 L
s
.69568 .77251 m
.7087 .79172 L
s
0 .4 1 r
.39551 .90796 m
.38398 .89943 L
s
.38398 .89943 m
.39564 .8699 L
s
1 .72 0 r
.60449 .90796 m
.61602 .89943 L
s
.60436 .8699 m
.61602 .89943 L
s
1 .36 0 r
.63596 .86189 m
.64749 .85417 L
s
.64634 .85104 m
.64749 .85417 L
s
.57645 .95535 m
.56795 .9684 L
s
.56795 .9684 m
.55288 .95565 L
s
.64634 .85104 m
.65671 .84045 L
s
.65298 .83547 m
.65671 .84045 L
s
.71913 .78278 m
.72958 .77407 L
s
.70426 .76059 m
.71913 .78278 L
s
.92 1 0 r
.48298 1.06108 m
.49151 1.06372 L
s
.52018 1.01528 m
.49151 1.06372 L
s
0 .76 1 r
.51702 1.06108 m
.50849 1.06372 L
s
.50849 1.06372 m
.47982 1.01528 L
s
1 .36 0 r
.63596 .86189 m
.62991 .87659 L
s
.62991 .87659 m
.62746 .87525 L
s
1 0 0 r
.79647 .74221 m
.80665 .74823 L
s
.82082 .71192 m
.80665 .74823 L
s
0 .4 1 r
.55412 1.10576 m
.56007 1.1168 L
s
.58542 1.11564 m
.56007 1.1168 L
s
1 .72 0 r
.44588 1.10576 m
.43993 1.1168 L
s
.43993 1.1168 m
.41458 1.11564 L
s
1 .36 0 r
.58496 .94217 m
.57645 .95535 L
s
.57645 .95535 m
.56329 .94357 L
s
.59346 .92889 m
.58496 .94217 L
s
.58496 .94217 m
.57369 .93151 L
s
.72958 .77407 m
.74004 .7656 L
s
.71285 .74891 m
.72958 .77407 L
s
.63596 .86189 m
.64634 .85104 L
s
.64447 .84862 m
.64634 .85104 L
s
.60196 .91552 m
.59346 .92889 L
s
.59346 .92889 m
.58408 .91952 L
s
.61046 .9021 m
.60196 .91552 L
s
.60196 .91552 m
.59447 .90764 L
s
1 0 0 r
.69243 .78262 m
.69226 .79752 L
s
.69226 .79752 m
.6676 .79876 L
s
1 .36 0 r
.61896 .88867 m
.61046 .9021 L
s
.61046 .9021 m
.60485 .8959 L
s
1 0 0 r
.66438 .81422 m
.66116 .82952 L
s
.66116 .82952 m
.63252 .8231 L
s
0 .76 1 r
.47982 1.01528 m
.46945 1.01529 L
s
.46945 1.01529 m
.45006 .95906 L
s
.92 1 0 r
.52018 1.01528 m
.53055 1.01529 L
s
.54994 .95906 m
.53055 1.01529 L
s
1 .36 0 r
.62746 .87525 m
.61896 .88867 L
s
.61896 .88867 m
.61522 .88434 L
s
.63596 .86189 m
.62746 .87525 L
s
.62746 .87525 m
.62559 .873 L
s
.74004 .7656 m
.75051 .75735 L
s
.72146 .73746 m
.74004 .7656 L
s
.63596 .86189 m
.64447 .84862 L
s
.63596 .86189 m
.64203 .84709 L
s
.63596 .86189 m
.63916 .84657 L
s
.63596 .86189 m
.63609 .84713 L
s
.63596 .86189 m
.633 .84872 L
s
.63596 .86189 m
.63011 .85126 L
s
.63596 .86189 m
.62762 .85454 L
s
.63596 .86189 m
.62571 .85834 L
s
.63596 .86189 m
.62449 .86237 L
s
.63596 .86189 m
.62406 .86634 L
s
.63596 .86189 m
.62443 .86996 L
s
.63596 .86189 m
.62559 .873 L
s
.63596 .86189 m
.63596 .86189 L
s
.64447 .84862 m
.65298 .83547 L
s
.64203 .84709 m
.64447 .84862 L
s
0 .4 1 r
.45349 .98034 m
.44195 .97739 L
s
.44195 .97739 m
.43981 .96034 L
s
1 .72 0 r
.54651 .98034 m
.55805 .97739 L
s
.56019 .96034 m
.55805 .97739 L
s
0 .4 1 r
.40705 .91679 m
.39551 .90796 L
s
.39551 .90796 m
.40602 .88207 L
s
1 .72 0 r
.59295 .91679 m
.60449 .90796 L
s
.59398 .88207 m
.60449 .90796 L
s
1 .36 0 r
.65298 .83547 m
.6615 .82247 L
s
.64809 .83222 m
.65298 .83547 L
s
1 0 0 r
.55309 .59385 m
.54138 .58035 L
s
.54138 .58035 m
.55708 .52689 L
s
.53627 .67346 m
.54138 .58035 L
s
0 .76 1 r
.59264 1.13494 m
.58933 1.14169 L
s
.63644 1.16924 m
.58933 1.14169 L
s
.92 1 0 r
.40736 1.13494 m
.41067 1.14169 L
s
.41067 1.14169 m
.36356 1.16924 L
s
1 0 0 r
.75205 .74496 m
.76032 .75418 L
s
.77603 .7298 m
.76032 .75418 L
s
.7112 .76171 m
.71411 .77552 L
s
.71411 .77552 m
.69243 .78262 L
s
.73443 .76267 m
.71411 .77552 L
s
1 .36 0 r
.75051 .75735 m
.76101 .7493 L
s
.73009 .72626 m
.75051 .75735 L
s
.6615 .82247 m
.67003 .80966 L
s
.65416 .81732 m
.6615 .82247 L
s
0 .4 1 r
.5 1.03925 m
.5 1.04975 L
s
.51559 1.0564 m
.5 1.04975 L
s
1 .72 0 r
.5 1.04975 m
.48441 1.0564 L
s
1 .36 0 r
.62559 .873 m
.61522 .88434 L
s
.62559 .873 m
.62443 .86996 L
s
0 .4 1 r
.47445 1.00452 m
.466 1.00799 L
s
.466 1.00799 m
.45834 .99437 L
s
.47596 1.02042 m
.466 1.00799 L
s
1 .72 0 r
.52555 1.00452 m
.534 1.00799 L
s
.534 1.00799 m
.52404 1.02042 L
s
.54166 .99437 m
.534 1.00799 L
s
0 .4 1 r
.48193 1.01404 m
.47596 1.02042 L
s
.48755 1.03101 m
.47596 1.02042 L
s
1 .72 0 r
.51807 1.01404 m
.52404 1.02042 L
s
.52404 1.02042 m
.51245 1.03101 L
s
1 0 0 r
.55708 .52689 m
.54659 .51116 L
s
.54659 .51116 m
.57371 .47878 L
s
.78626 .73607 m
.79647 .74221 L
s
.8093 .70882 m
.79647 .74221 L
s
.72864 .75079 m
.73443 .76267 L
s
.75205 .74496 m
.73443 .76267 L
s
1 .36 0 r
.64203 .84709 m
.64809 .83222 L
s
.63916 .84657 m
.64203 .84709 L
s
1 .72 0 r
.56019 .96034 m
.57214 .95417 L
s
.56983 .93529 m
.57214 .95417 L
s
0 .4 1 r
.43981 .96034 m
.42786 .95417 L
s
.42786 .95417 m
.43017 .93529 L
s
1 .36 0 r
.67003 .80966 m
.67857 .79705 L
s
.66023 .80243 m
.67003 .80966 L
s
1 0 0 r
.6676 .79876 m
.66438 .81422 L
s
.66438 .81422 m
.63857 .80752 L
s
.86677 .72383 m
.87823 .72671 L
s
.88688 .67346 m
.87823 .72671 L
s
1 .36 0 r
.76101 .7493 m
.77152 .74145 L
s
.73874 .71528 m
.76101 .7493 L
s
.62443 .86996 m
.61289 .87839 L
s
.62443 .86996 m
.62406 .86634 L
s
.61522 .88434 m
.60485 .8959 L
s
.61522 .88434 m
.61289 .87839 L
s
.67857 .79705 m
.68712 .78467 L
s
.66631 .78758 m
.67857 .79705 L
s
.63916 .84657 m
.64236 .831 L
s
.63609 .84713 m
.63916 .84657 L
s
1 0 0 r
.60226 .89954 m
.59621 .91427 L
s
.59621 .91427 m
.55674 .89954 L
s
1 .72 0 r
.45185 1.09452 m
.44588 1.10576 L
s
.44588 1.10576 m
.42308 1.10472 L
s
0 .4 1 r
.54815 1.09452 m
.55412 1.10576 L
s
.57692 1.10472 m
.55412 1.10576 L
s
1 .36 0 r
.64809 .83222 m
.65416 .81732 L
s
.64236 .831 m
.64809 .83222 L
s
0 .4 1 r
.4687 .99417 m
.45834 .99437 L
s
.45834 .99437 m
.45349 .98034 L
s
1 .72 0 r
.5313 .99417 m
.54166 .99437 L
s
.54651 .98034 m
.54166 .99437 L
s
1 0 0 r
.69259 .7675 m
.69243 .78262 L
s
.69243 .78262 m
.67081 .78317 L
s
0 .4 1 r
.51559 1.0564 m
.51868 1.06784 L
s
.53619 1.07139 m
.51868 1.06784 L
s
1 .72 0 r
.48441 1.0564 m
.48132 1.06784 L
s
.48132 1.06784 m
.46381 1.07139 L
s
1 .36 0 r
.54596 .62587 m
.53986 .59944 L
s
.53986 .59944 m
.58659 .58647 L
s
.5 .67449 m
.53986 .59944 L
s
.62406 .86634 m
.61213 .87117 L
s
.62406 .86634 m
.62449 .86237 L
s
.68712 .78467 m
.69568 .77251 L
s
.6724 .77283 m
.68712 .78467 L
s
.63609 .84713 m
.6362 .83198 L
s
.633 .84872 m
.63609 .84713 L
s
0 .4 1 r
.49064 1.0222 m
.48755 1.03101 L
s
.5 1.03925 m
.48755 1.03101 L
s
1 .72 0 r
.50936 1.0222 m
.51245 1.03101 L
s
.51245 1.03101 m
.5 1.03925 L
s
0 .4 1 r
.4186 .92591 m
.40705 .91679 L
s
.40705 .91679 m
.41642 .89447 L
s
1 .72 0 r
.5814 .92591 m
.59295 .91679 L
s
.58358 .89447 m
.59295 .91679 L
s
1 .36 0 r
.77152 .74145 m
.78205 .73378 L
s
.74742 .70452 m
.77152 .74145 L
s
1 0 0 r
.8553 .72092 m
.86677 .72383 L
s
.87479 .67346 m
.86677 .72383 L
s
1 .72 0 r
.65629 .81344 m
.66669 .80314 L
s
.63658 .75669 m
.66669 .80314 L
s
0 .4 1 r
.34371 .81344 m
.33331 .80314 L
s
.33331 .80314 m
.36342 .75669 L
s
1 .36 0 r
.60485 .8959 m
.59447 .90764 L
s
.60485 .8959 m
.60135 .88719 L
s
1 0 0 r
.60831 .88458 m
.60226 .89954 L
s
.60226 .89954 m
.56527 .88404 L
s
.77603 .7298 m
.78626 .73607 L
s
.79776 .70566 m
.78626 .73607 L
s
1 .36 0 r
.633 .84872 m
.63001 .83515 L
s
.63011 .85126 m
.633 .84872 L
s
.65416 .81732 m
.66023 .80243 L
s
.64556 .81519 m
.65416 .81732 L
s
.62449 .86237 m
.613 .86314 L
s
.62449 .86237 m
.62571 .85834 L
s
1 0 0 r
.74375 .73553 m
.75205 .74496 L
s
.76577 .7234 m
.75205 .74496 L
s
0 .4 1 r
.3541 .82408 m
.34371 .81344 L
s
.34371 .81344 m
.37194 .77088 L
s
1 .72 0 r
.6459 .82408 m
.65629 .81344 L
s
.62806 .77088 m
.65629 .81344 L
s
0 .76 1 r
.55805 1.09644 m
.5519 1.10128 L
s
.5519 1.10128 m
.51702 1.06108 L
s
.59264 1.13494 m
.5519 1.10128 L
s
.92 1 0 r
.44195 1.09644 m
.4481 1.10128 L
s
.4481 1.10128 m
.40736 1.13494 L
s
.48298 1.06108 m
.4481 1.10128 L
s
1 0 0 r
.67081 .78317 m
.6676 .79876 L
s
.6676 .79876 m
.64463 .79196 L
s
1 .36 0 r
.69568 .77251 m
.70426 .76059 L
s
.67849 .75819 m
.69568 .77251 L
s
.63011 .85126 m
.62424 .84031 L
s
.62762 .85454 m
.63011 .85126 L
s
.62571 .85834 m
.61543 .8549 L
s
.62571 .85834 m
.62762 .85454 L
s
1 0 0 r
.70828 .74763 m
.7112 .76171 L
s
.7112 .76171 m
.69259 .7675 L
s
.72864 .75079 m
.7112 .76171 L
s
1 .36 0 r
.62762 .85454 m
.61926 .84708 L
s
.64236 .831 m
.64556 .81519 L
s
.6362 .83198 m
.64236 .831 L
s
.61289 .87839 m
.60135 .88719 L
s
.61289 .87839 m
.61213 .87117 L
s
.78205 .73378 m
.79259 .72627 L
s
.75611 .69397 m
.78205 .73378 L
s
1 0 0 r
.72283 .73863 m
.72864 .75079 L
s
.74375 .73553 m
.72864 .75079 L
s
0 .4 1 r
.36448 .83505 m
.3541 .82408 L
s
.3541 .82408 m
.38046 .78547 L
s
1 .72 0 r
.63552 .83505 m
.6459 .82408 L
s
.61954 .78547 m
.6459 .82408 L
s
1 0 0 r
.61436 .86942 m
.60831 .88458 L
s
.60831 .88458 m
.5738 .8684 L
s
1 .72 0 r
.37226 1.1674 m
.36384 1.17725 L
s
.36384 1.17725 m
.33157 1.16667 L
s
0 .4 1 r
.62774 1.1674 m
.63616 1.17725 L
s
.66843 1.16667 m
.63616 1.17725 L
s
0 .76 1 r
.63644 1.16924 m
.63616 1.17725 L
s
.68705 1.19719 m
.63616 1.17725 L
s
.92 1 0 r
.36356 1.16924 m
.36384 1.17725 L
s
.36384 1.17725 m
.31295 1.19719 L
s
1 0 0 r
.84382 .71796 m
.8553 .72092 L
s
.8627 .67346 m
.8553 .72092 L
s
1 .36 0 r
.59447 .90764 m
.58408 .91952 L
s
.59447 .90764 m
.58979 .89635 L
s
.66023 .80243 m
.66631 .78758 L
s
.64875 .79918 m
.66023 .80243 L
s
.70426 .76059 m
.71285 .74891 L
s
.6846 .74371 m
.70426 .76059 L
s
1 0 0 r
.69274 .75218 m
.69259 .7675 L
s
.69259 .7675 m
.67403 .76748 L
s
0 .4 1 r
.37487 .84636 m
.36448 .83505 L
s
.36448 .83505 m
.38897 .80043 L
s
1 .72 0 r
.62513 .84636 m
.63552 .83505 L
s
.61103 .80043 m
.63552 .83505 L
s
0 .4 1 r
.45179 .96681 m
.43981 .96034 L
s
.43981 .96034 m
.44176 .94492 L
s
1 .72 0 r
.54821 .96681 m
.56019 .96034 L
s
.55824 .94492 m
.56019 .96034 L
s
0 .4 1 r
.46506 .98362 m
.45349 .98034 L
s
.45349 .98034 m
.45179 .96681 L
s
1 .72 0 r
.53494 .98362 m
.54651 .98034 L
s
.54821 .96681 m
.54651 .98034 L
s
1 0 0 r
.56758 .54214 m
.55708 .52689 L
s
.55708 .52689 m
.58228 .49432 L
s
0 .76 1 r
.52559 1.05865 m
.51702 1.06108 L
s
.51702 1.06108 m
.49022 1.01553 L
s
.92 1 0 r
.47441 1.05865 m
.48298 1.06108 L
s
.50978 1.01553 m
.48298 1.06108 L
s
1 0 0 r
.62041 .8541 m
.61436 .86942 L
s
.61436 .86942 m
.58233 .8527 L
s
0 .4 1 r
.43017 .93529 m
.4186 .92591 L
s
.4186 .92591 m
.42683 .90703 L
s
1 .72 0 r
.56983 .93529 m
.5814 .92591 L
s
.57317 .90703 m
.5814 .92591 L
s
1 .36 0 r
.6362 .83198 m
.6363 .81643 L
s
.63001 .83515 m
.6362 .83198 L
s
0 .4 1 r
.54218 1.08307 m
.54815 1.09452 L
s
.5684 1.09359 m
.54815 1.09452 L
s
1 .72 0 r
.45782 1.08307 m
.45185 1.09452 L
s
.45185 1.09452 m
.4316 1.09359 L
s
0 .76 1 r
.49022 1.01553 m
.47982 1.01528 L
s
.47982 1.01528 m
.46165 .96245 L
s
.92 1 0 r
.50978 1.01553 m
.52018 1.01528 L
s
.53835 .96245 m
.52018 1.01528 L
s
1 0 0 r
.76577 .7234 m
.77603 .7298 L
s
.78622 .70244 m
.77603 .7298 L
s
1 .36 0 r
.79259 .72627 m
.80316 .71892 L
s
.76483 .68362 m
.79259 .72627 L
s
1 0 0 r
.67403 .76748 m
.67081 .78317 L
s
.67081 .78317 m
.65069 .77647 L
s
1 .36 0 r
.66631 .78758 m
.6724 .77283 L
s
.65194 .78299 m
.66631 .78758 L
s
.64556 .81519 m
.64875 .79918 L
s
.6363 .81643 m
.64556 .81519 L
s
1 0 0 r
.83232 .71496 m
.84382 .71796 L
s
.85061 .67346 m
.84382 .71796 L
s
1 .36 0 r
.61213 .87117 m
.6002 .87642 L
s
.61213 .87117 m
.613 .86314 L
s
.58408 .91952 m
.57369 .93151 L
s
.58408 .91952 m
.57822 .90587 L
s
.71285 .74891 m
.72146 .73746 L
s
.69072 .72941 m
.71285 .74891 L
s
0 .4 1 r
.38525 .85799 m
.37487 .84636 L
s
.37487 .84636 m
.39748 .8157 L
s
1 .72 0 r
.61475 .85799 m
.62513 .84636 L
s
.60252 .8157 m
.62513 .84636 L
s
1 0 0 r
.56481 .60532 m
.55309 .59385 L
s
.55309 .59385 m
.56758 .54214 L
s
.54836 .67346 m
.55309 .59385 L
s
0 .4 1 r
.5 1.02858 m
.5 1.03925 L
s
.51249 1.04475 m
.5 1.03925 L
s
1 .72 0 r
.5 1.03925 m
.48751 1.04475 L
s
1 0 0 r
.73542 .72587 m
.74375 .73553 L
s
.7555 .71685 m
.74375 .73553 L
s
.62646 .83864 m
.62041 .8541 L
s
.62041 .8541 m
.59084 .83702 L
s
1 .36 0 r
.60135 .88719 m
.58979 .89635 L
s
.60135 .88719 m
.6002 .87642 L
s
.63001 .83515 m
.62701 .82112 L
s
.62424 .84031 m
.63001 .83515 L
s
0 .4 1 r
.6193 1.15739 m
.62774 1.1674 L
s
.65791 1.15736 m
.62774 1.1674 L
s
1 .72 0 r
.3807 1.15739 m
.37226 1.1674 L
s
.37226 1.1674 m
.34209 1.15736 L
s
1 0 0 r
.70534 .73329 m
.70828 .74763 L
s
.70828 .74763 m
.69274 .75218 L
s
.72283 .73863 m
.70828 .74763 L
s
0 .4 1 r
.51249 1.04475 m
.51559 1.0564 L
s
.53018 1.05946 m
.51559 1.0564 L
s
1 .72 0 r
.48751 1.04475 m
.48441 1.0564 L
s
.48441 1.0564 m
.46982 1.05946 L
s
1 .36 0 r
.6724 .77283 m
.67849 .75819 L
s
.65513 .76667 m
.6724 .77283 L
s
1 0 0 r
.63252 .8231 m
.62646 .83864 L
s
.62646 .83864 m
.59935 .82145 L
s
1 .36 0 r
.613 .86314 m
.60149 .86426 L
s
.613 .86314 m
.61543 .8549 L
s
.77357 .67346 m
.80316 .71892 L
s
1 0 0 r
.82082 .71192 m
.83232 .71496 L
s
.83852 .67346 m
.83232 .71496 L
s
0 .4 1 r
.48293 1.00125 m
.47445 1.00452 L
s
.47445 1.00452 m
.4687 .99417 L
s
.48193 1.01404 m
.47445 1.00452 L
s
1 .72 0 r
.51707 1.00125 m
.52555 1.00452 L
s
.52555 1.00452 m
.51807 1.01404 L
s
.5313 .99417 m
.52555 1.00452 L
s
1 0 0 r
.71699 .7262 m
.72283 .73863 L
s
.73542 .72587 m
.72283 .73863 L
s
0 .4 1 r
.48793 1.00774 m
.48193 1.01404 L
s
.49064 1.0222 m
.48193 1.01404 L
s
1 .72 0 r
.51207 1.00774 m
.51807 1.01404 L
s
.51807 1.01404 m
.50936 1.0222 L
s
1 .36 0 r
.57369 .93151 m
.56329 .94357 L
s
.57369 .93151 m
.56663 .91571 L
s
0 .4 1 r
.39564 .8699 m
.38525 .85799 L
s
.38525 .85799 m
.40599 .8312 L
s
1 .72 0 r
.60436 .8699 m
.61475 .85799 L
s
.59401 .8312 m
.61475 .85799 L
s
1 .36 0 r
.64875 .79918 m
.65194 .78299 L
s
.63639 .80048 m
.64875 .79918 L
s
.62424 .84031 m
.61834 .82901 L
s
.61926 .84708 m
.62424 .84031 L
s
.72146 .73746 m
.73009 .72626 L
s
.69685 .7153 m
.72146 .73746 L
s
1 0 0 r
.67725 .75174 m
.67403 .76748 L
s
.67403 .76748 m
.65676 .76111 L
s
.69289 .73669 m
.69274 .75218 L
s
.69274 .75218 m
.67725 .75174 L
s
.7555 .71685 m
.76577 .7234 L
s
.77466 .69915 m
.76577 .7234 L
s
0 .76 1 r
.59598 1.12824 m
.59264 1.13494 L
s
.63673 1.16122 m
.59264 1.13494 L
s
.92 1 0 r
.40402 1.12824 m
.40736 1.13494 L
s
.40736 1.13494 m
.36327 1.16122 L
s
1 .36 0 r
.61543 .8549 m
.60513 .85159 L
s
.61543 .8549 m
.61926 .84708 L
s
1 0 0 r
.63857 .80752 m
.63252 .8231 L
s
.63252 .8231 m
.60786 .80609 L
s
1 .36 0 r
.6363 .81643 m
.63639 .80048 L
s
.62701 .82112 m
.6363 .81643 L
s
.61926 .84708 m
.61088 .83948 L
s
0 .4 1 r
.47909 .99427 m
.4687 .99417 L
s
.4687 .99417 m
.46506 .98362 L
s
1 .72 0 r
.52091 .99427 m
.5313 .99417 L
s
.53494 .98362 m
.5313 .99417 L
s
0 .4 1 r
.44176 .94492 m
.43017 .93529 L
s
.43017 .93529 m
.43724 .9197 L
s
1 .72 0 r
.55824 .94492 m
.56983 .93529 L
s
.56276 .9197 m
.56983 .93529 L
s
1 .36 0 r
.67849 .75819 m
.6846 .74371 L
s
.65833 .75028 m
.67849 .75819 L
s
1 0 0 r
.8093 .70882 m
.82082 .71192 L
s
.82643 .67346 m
.82082 .71192 L
s
.64463 .79196 m
.63857 .80752 L
s
.63857 .80752 m
.61637 .791 L
s
0 .4 1 r
.53619 1.07139 m
.54218 1.08307 L
s
.55988 1.08224 m
.54218 1.08307 L
s
1 .72 0 r
.46381 1.07139 m
.45782 1.08307 L
s
.45782 1.08307 m
.44012 1.08224 L
s
0 .4 1 r
.49375 1.01333 m
.49064 1.0222 L
s
.5 1.02858 m
.49064 1.0222 L
s
1 .72 0 r
.50625 1.01333 m
.50936 1.0222 L
s
.50936 1.0222 m
.5 1.02858 L
s
1 0 0 r
.72707 .71596 m
.73542 .72587 L
s
.74521 .71014 m
.73542 .72587 L
s
0 .4 1 r
.40602 .88207 m
.39564 .8699 L
s
.39564 .8699 m
.4145 .84685 L
s
1 .72 0 r
.59398 .88207 m
.60436 .8699 L
s
.5855 .84685 m
.60436 .8699 L
s
0 .4 1 r
.61085 1.14722 m
.6193 1.15739 L
s
.64739 1.1479 m
.6193 1.15739 L
s
1 .72 0 r
.38915 1.14722 m
.3807 1.15739 L
s
.3807 1.15739 m
.35261 1.1479 L
s
1 .36 0 r
.56329 .94357 m
.55288 .95565 L
s
.56329 .94357 m
.55502 .92585 L
s
1 0 0 r
.5781 .55676 m
.56758 .54214 L
s
.56758 .54214 m
.59087 .50987 L
s
1 .36 0 r
.65194 .78299 m
.65513 .76667 L
s
.63647 .78413 m
.65194 .78299 L
s
.73009 .72626 m
.73874 .71528 L
s
.703 .70141 m
.73009 .72626 L
s
.58979 .89635 m
.57822 .90587 L
s
.58979 .89635 m
.58825 .88214 L
s
0 .4 1 r
.4638 .97357 m
.45179 .96681 L
s
.45179 .96681 m
.45336 .95475 L
s
1 .72 0 r
.5362 .97357 m
.54821 .96681 L
s
.54664 .95475 m
.54821 .96681 L
s
1 .36 0 r
.6002 .87642 m
.58825 .88214 L
s
.6002 .87642 m
.60149 .86426 L
s
.55208 .65132 m
.54596 .62587 L
s
.54596 .62587 m
.58975 .60676 L
s
.50861 .71996 m
.54596 .62587 L
s
1 0 0 r
.65069 .77647 m
.64463 .79196 L
s
.64463 .79196 m
.62488 .77627 L
s
.68048 .73597 m
.67725 .75174 L
s
.67725 .75174 m
.66284 .7459 L
s
1 .36 0 r
.62701 .82112 m
.62399 .80661 L
s
.61834 .82901 m
.62701 .82112 L
s
1 0 0 r
.70238 .7187 m
.70534 .73329 L
s
.70534 .73329 m
.69289 .73669 L
s
.71699 .7262 m
.70534 .73329 L
s
.79776 .70566 m
.8093 .70882 L
s
.81434 .67346 m
.8093 .70882 L
s
.74521 .71014 m
.7555 .71685 L
s
.7631 .69579 m
.7555 .71685 L
s
1 .36 0 r
.6846 .74371 m
.69072 .72941 L
s
.66152 .73385 m
.6846 .74371 L
s
.63639 .80048 m
.63647 .78413 L
s
.62399 .80661 m
.63639 .80048 L
s
1 0 0 r
.71114 .71348 m
.71699 .7262 L
s
.72707 .71596 m
.71699 .7262 L
s
.65676 .76111 m
.65069 .77647 L
s
.65069 .77647 m
.6334 .76193 L
s
.69303 .72104 m
.69289 .73669 L
s
.69289 .73669 m
.68048 .73597 L
s
0 .4 1 r
.47667 .98723 m
.46506 .98362 L
s
.46506 .98362 m
.4638 .97357 L
s
1 .72 0 r
.52333 .98723 m
.53494 .98362 L
s
.5362 .97357 m
.53494 .98362 L
s
1 .36 0 r
.55288 .95565 m
.54245 .96773 L
s
.55288 .95565 m
.54339 .93626 L
s
0 .4 1 r
.41642 .89447 m
.40602 .88207 L
s
.40602 .88207 m
.42302 .86255 L
s
1 .72 0 r
.58358 .89447 m
.59398 .88207 L
s
.57698 .86255 m
.59398 .88207 L
s
1 .36 0 r
.65513 .76667 m
.65833 .75028 L
s
.63654 .76739 m
.65513 .76667 L
s
1 0 0 r
.57653 .61517 m
.56481 .60532 L
s
.56481 .60532 m
.5781 .55676 L
s
.56045 .67346 m
.56481 .60532 L
s
1 .36 0 r
.73874 .71528 m
.74742 .70452 L
s
.70917 .68775 m
.73874 .71528 L
s
1 0 0 r
.78622 .70244 m
.79776 .70566 L
s
.80225 .67346 m
.79776 .70566 L
s
0 .76 1 r
.56422 1.09174 m
.55805 1.09644 L
s
.55805 1.09644 m
.52559 1.05865 L
s
.59598 1.12824 m
.55805 1.09644 L
s
.92 1 0 r
.43578 1.09174 m
.44195 1.09644 L
s
.44195 1.09644 m
.40402 1.12824 L
s
.47441 1.05865 m
.44195 1.09644 L
s
0 .76 1 r
.46165 .96245 m
.45006 .95906 L
s
.45006 .95906 m
.44326 .89954 L
s
.92 1 0 r
.53835 .96245 m
.54994 .95906 L
s
.55674 .89954 m
.54994 .95906 L
s
1 .36 0 r
.61834 .82901 m
.61242 .81731 L
s
.61088 .83948 m
.61834 .82901 L
s
1 0 0 r
.66284 .7459 m
.65676 .76111 L
s
.65676 .76111 m
.64193 .74802 L
s
1 .36 0 r
.60149 .86426 m
.58995 .86577 L
s
.60149 .86426 m
.60513 .85159 L
s
0 .4 1 r
.60239 1.13688 m
.61085 1.14722 L
s
.63687 1.13827 m
.61085 1.14722 L
s
1 .72 0 r
.39761 1.13688 m
.38915 1.14722 L
s
.38915 1.14722 m
.36313 1.13827 L
s
0 .4 1 r
.45336 .95475 m
.44176 .94492 L
s
.44176 .94492 m
.44767 .93245 L
s
1 .72 0 r
.54664 .95475 m
.55824 .94492 L
s
.55233 .93245 m
.55824 .94492 L
s
0 .76 1 r
.63673 1.16122 m
.63644 1.16924 L
s
.68425 1.18845 m
.63644 1.16924 L
s
.92 1 0 r
.36327 1.16122 m
.36356 1.16924 L
s
.36356 1.16924 m
.31575 1.18845 L
s
0 .4 1 r
.50938 1.03285 m
.51249 1.04475 L
s
.52417 1.04727 m
.51249 1.04475 L
s
1 .72 0 r
.49062 1.03285 m
.48751 1.04475 L
s
.48751 1.04475 m
.47583 1.04727 L
s
1 0 0 r
.7187 .70579 m
.72707 .71596 L
s
.7349 .70324 m
.72707 .71596 L
s
.68371 .72022 m
.68048 .73597 L
s
.68048 .73597 m
.66893 .73091 L
s
1 .36 0 r
.69072 .72941 m
.69685 .7153 L
s
.66472 .71745 m
.69072 .72941 L
s
0 .4 1 r
.5 1.01773 m
.5 1.02858 L
s
.50938 1.03285 m
.5 1.02858 L
s
1 .72 0 r
.5 1.02858 m
.49062 1.03285 L
s
1 0 0 r
.7349 .70324 m
.74521 .71014 L
s
.75152 .69234 m
.74521 .71014 L
s
0 .76 1 r
.50067 1.01609 m
.49022 1.01553 L
s
.49022 1.01553 m
.47327 .96623 L
s
.92 1 0 r
.49933 1.01609 m
.50978 1.01553 L
s
.52673 .96623 m
.50978 1.01553 L
s
1 .36 0 r
.61088 .83948 m
.60247 .83173 L
s
.60513 .85159 m
.61088 .83948 L
s
.60513 .85159 m
.5948 .84845 L
s
0 .4 1 r
.53018 1.05946 m
.53619 1.07139 L
s
.55135 1.07065 m
.53619 1.07139 L
s
1 .72 0 r
.46982 1.05946 m
.46381 1.07139 L
s
.46381 1.07139 m
.44865 1.07065 L
s
1 .36 0 r
.63647 .78413 m
.63654 .76739 L
s
.62096 .79155 m
.63647 .78413 L
s
1 0 0 r
.66893 .73091 m
.66284 .7459 L
s
.66284 .7459 m
.65047 .73454 L
s
1 .36 0 r
.54245 .96773 m
.53202 .97976 L
s
.54245 .96773 m
.53174 .94688 L
s
.65833 .75028 m
.66152 .73385 L
s
.6366 .75028 m
.65833 .75028 L
s
.57822 .90587 m
.56663 .91571 L
s
.57822 .90587 m
.57627 .88834 L
s
1 0 0 r
.77466 .69915 m
.78622 .70244 L
s
.79016 .67346 m
.78622 .70244 L
s
0 .76 1 r
.53419 1.05644 m
.52559 1.05865 L
s
.52559 1.05865 m
.50067 1.01609 L
s
.92 1 0 r
.46581 1.05644 m
.47441 1.05865 L
s
.49933 1.01609 m
.47441 1.05865 L
s
0 .4 1 r
.42683 .90703 m
.41642 .89447 L
s
.41642 .89447 m
.43155 .87823 L
s
1 .72 0 r
.57317 .90703 m
.58358 .89447 L
s
.56845 .87823 m
.58358 .89447 L
s
1 0 0 r
.69942 .70385 m
.70238 .7187 L
s
.70238 .7187 m
.69303 .72104 L
s
.71114 .71348 m
.70238 .7187 L
s
1 .36 0 r
.62399 .80661 m
.62096 .79155 L
s
.61242 .81731 m
.62399 .80661 L
s
1 0 0 r
.58863 .57063 m
.5781 .55676 L
s
.5781 .55676 m
.59945 .52533 L
s
.69317 .70526 m
.69303 .72104 L
s
.69303 .72104 m
.68371 .72022 L
s
.70526 .70045 m
.71114 .71348 L
s
.7187 .70579 m
.71114 .71348 L
s
1 .36 0 r
.74742 .70452 m
.75611 .69397 L
s
.71536 .67432 m
.74742 .70452 L
s
.58825 .88214 m
.57627 .88834 L
s
.58825 .88214 m
.58995 .86577 L
s
0 .4 1 r
.59391 1.12635 m
.60239 1.13688 L
s
.62634 1.12847 m
.60239 1.13688 L
s
1 .72 0 r
.40609 1.12635 m
.39761 1.13688 L
s
.39761 1.13688 m
.37366 1.12847 L
s
1 0 0 r
.67504 .71614 m
.66893 .73091 L
s
.66893 .73091 m
.65903 .72151 L
s
1 .36 0 r
.69685 .7153 m
.703 .70141 L
s
.66793 .70112 m
.69685 .7153 L
s
1 0 0 r
.7631 .69579 m
.77466 .69915 L
s
.77807 .67346 m
.77466 .69915 L
s
.68694 .70453 m
.68371 .72022 L
s
.68371 .72022 m
.67504 .71614 L
s
0 .4 1 r
.47583 .98062 m
.4638 .97357 L
s
.4638 .97357 m
.46499 .96476 L
s
1 .72 0 r
.52417 .98062 m
.5362 .97357 L
s
.53501 .96476 m
.5362 .97357 L
s
1 .36 0 r
.66152 .73385 m
.66472 .71745 L
s
.63665 .73283 m
.66152 .73385 L
s
.53202 .97976 m
.52158 .99172 L
s
.53202 .97976 m
.52006 .95767 L
s
1 0 0 r
.72456 .69615 m
.7349 .70324 L
s
.73992 .6888 m
.7349 .70324 L
s
1 .36 0 r
.63654 .76739 m
.6366 .75028 L
s
.61791 .77589 m
.63654 .76739 L
s
1 0 0 r
.7103 .69533 m
.7187 .70579 L
s
.72456 .69615 m
.7187 .70579 L
s
0 .4 1 r
.49145 .99822 m
.48293 1.00125 L
s
.48293 1.00125 m
.47909 .99427 L
s
.48793 1.00774 m
.48293 1.00125 L
s
1 .72 0 r
.50855 .99822 m
.51707 1.00125 L
s
.51707 1.00125 m
.51207 1.00774 L
s
.52091 .99427 m
.51707 1.00125 L
s
0 .4 1 r
.49395 1.00154 m
.48793 1.00774 L
s
.49375 1.01333 m
.48793 1.00774 L
s
1 .72 0 r
.50605 1.00154 m
.51207 1.00774 L
s
.51207 1.00774 m
.50625 1.01333 L
s
1 0 0 r
.58825 .62374 m
.57653 .61517 L
s
.57653 .61517 m
.58863 .57063 L
s
.57254 .67346 m
.57653 .61517 L
s
0 .4 1 r
.43724 .9197 m
.42683 .90703 L
s
.42683 .90703 m
.44008 .89379 L
s
1 .72 0 r
.56276 .9197 m
.57317 .90703 L
s
.55992 .89379 m
.57317 .90703 L
s
0 .4 1 r
.46499 .96476 m
.45336 .95475 L
s
.45336 .95475 m
.45811 .9452 L
s
1 .72 0 r
.53501 .96476 m
.54664 .95475 L
s
.54189 .9452 m
.54664 .95475 L
s
1 .36 0 r
.61242 .81731 m
.60648 .80513 L
s
.60247 .83173 m
.61242 .81731 L
s
0 .4 1 r
.48953 .99469 m
.47909 .99427 L
s
.47909 .99427 m
.47667 .98723 L
s
1 .72 0 r
.51047 .99469 m
.52091 .99427 L
s
.52333 .98723 m
.52091 .99427 L
s
1 0 0 r
.75152 .69234 m
.7631 .69579 L
s
.76598 .67346 m
.7631 .69579 L
s
.68115 .70164 m
.67504 .71614 L
s
.67504 .71614 m
.6676 .70891 L
s
.64193 .74802 m
.6334 .76193 L
s
.65047 .73454 m
.64193 .74802 L
s
.64193 .74802 m
.63053 .72824 L
s
0 .4 1 r
.37194 .77088 m
.36342 .75669 L
s
.36342 .75669 m
.40322 .71771 L
s
1 .72 0 r
.62806 .77088 m
.63658 .75669 L
s
.59678 .71771 m
.63658 .75669 L
s
1 0 0 r
.65903 .72151 m
.65047 .73454 L
s
.65047 .73454 m
.64098 .71792 L
s
1 .36 0 r
.62096 .79155 m
.61791 .77589 L
s
.60648 .80513 m
.62096 .79155 L
s
1 0 0 r
.6334 .76193 m
.62488 .77627 L
s
.6334 .76193 m
.6201 .73919 L
s
1 .36 0 r
.58975 .60676 m
.58659 .58647 L
s
.58659 .58647 m
.63699 .58998 L
s
1 0 0 r
.69643 .68876 m
.69942 .70385 L
s
.69942 .70385 m
.69317 .70526 L
s
.70526 .70045 m
.69942 .70385 L
s
0 .4 1 r
.52417 1.04727 m
.53018 1.05946 L
s
.5428 1.05882 m
.53018 1.05946 L
s
1 .72 0 r
.47583 1.04727 m
.46982 1.05946 L
s
.46982 1.05946 m
.4572 1.05882 L
s
1 0 0 r
.69331 .68939 m
.69317 .70526 L
s
.69317 .70526 m
.68694 .70453 L
s
1 .36 0 r
.75611 .69397 m
.76483 .68362 L
s
.72157 .66111 m
.75611 .69397 L
s
0 .4 1 r
.38046 .78547 m
.37194 .77088 L
s
.37194 .77088 m
.40923 .73672 L
s
1 .72 0 r
.61954 .78547 m
.62806 .77088 L
s
.59077 .73672 m
.62806 .77088 L
s
1 0 0 r
.56514 .46333 m
.55658 .44802 L
s
.55658 .44802 m
.59724 .43007 L
s
1 .36 0 r
.52158 .99172 m
.51113 1.00357 L
s
.52158 .99172 m
.50836 .96857 L
s
0 .4 1 r
.49687 1.00442 m
.49375 1.01333 L
s
.5 1.01773 m
.49375 1.01333 L
s
1 .72 0 r
.50313 1.00442 m
.50625 1.01333 L
s
.50625 1.01333 m
.5 1.01773 L
s
0 .4 1 r
.58542 1.11564 m
.59391 1.12635 L
s
.6158 1.11849 m
.59391 1.12635 L
s
1 .72 0 r
.41458 1.11564 m
.40609 1.12635 L
s
.40609 1.12635 m
.3842 1.11849 L
s
1 .36 0 r
.66472 .71745 m
.66793 .70112 L
s
.6367 .71512 m
.66472 .71745 L
s
1 0 0 r
.6676 .70891 m
.65903 .72151 L
s
.65903 .72151 m
.65144 .70815 L
s
1 .36 0 r
.703 .70141 m
.70917 .68775 L
s
.67114 .68492 m
.703 .70141 L
s
0 .76 1 r
.59932 1.1216 m
.59598 1.12824 L
s
.63702 1.15319 m
.59598 1.12824 L
s
.92 1 0 r
.40068 1.1216 m
.40402 1.12824 L
s
.40402 1.12824 m
.36298 1.15319 L
s
1 .36 0 r
.6366 .75028 m
.63665 .73283 L
s
.61483 .7596 m
.6366 .75028 L
s
1 0 0 r
.62488 .77627 m
.61637 .791 L
s
.62488 .77627 m
.60968 .75085 L
s
.69936 .68711 m
.70526 .70045 L
s
.7103 .69533 m
.70526 .70045 L
s
1 .36 0 r
.5582 .67491 m
.55208 .65132 L
s
.55208 .65132 m
.59291 .62721 L
s
.51722 .73612 m
.55208 .65132 L
s
.56663 .91571 m
.55502 .92585 L
s
.56663 .91571 m
.56428 .89505 L
s
.58995 .86577 m
.5784 .86774 L
s
.58995 .86577 m
.5948 .84845 L
s
1 0 0 r
.71421 .68884 m
.72456 .69615 L
s
.72832 .68516 m
.72456 .69615 L
s
.69019 .68894 m
.68694 .70453 L
s
.68694 .70453 m
.68115 .70164 L
s
.59915 .58374 m
.58863 .57063 L
s
.58863 .57063 m
.60804 .54062 L
s
.73992 .6888 m
.75152 .69234 L
s
.75389 .67346 m
.75152 .69234 L
s
0 .4 1 r
.38897 .80043 m
.38046 .78547 L
s
.38046 .78547 m
.41524 .75618 L
s
1 .72 0 r
.61103 .80043 m
.61954 .78547 L
s
.58476 .75618 m
.61954 .78547 L
s
0 .4 1 r
.50626 1.02068 m
.50938 1.03285 L
s
.51814 1.0348 m
.50938 1.03285 L
s
1 .72 0 r
.49374 1.02068 m
.49062 1.03285 L
s
.49062 1.03285 m
.48186 1.0348 L
s
1 .36 0 r
.60247 .83173 m
.59404 .82382 L
s
.5948 .84845 m
.60247 .83173 L
s
1 0 0 r
.6762 .69672 m
.6676 .70891 L
s
.6676 .70891 m
.66191 .69888 L
s
0 .4 1 r
.48831 .99118 m
.47667 .98723 L
s
.47667 .98723 m
.47583 .98062 L
s
1 .72 0 r
.51169 .99118 m
.52333 .98723 L
s
.52417 .98062 m
.52333 .98723 L
s
1 0 0 r
.61637 .791 m
.60786 .80609 L
s
.61637 .791 m
.59926 .76329 L
s
.70188 .68456 m
.7103 .69533 L
s
.71421 .68884 m
.7103 .69533 L
s
1 .36 0 r
.59291 .62721 m
.58975 .60676 L
s
.58975 .60676 m
.63693 .60741 L
s
1 0 0 r
.68729 .68741 m
.68115 .70164 L
s
.68115 .70164 m
.6762 .69672 L
s
0 .4 1 r
.44767 .93245 m
.43724 .9197 L
s
.43724 .9197 m
.44862 .90916 L
s
1 .72 0 r
.55233 .93245 m
.56276 .9197 L
s
.55138 .90916 m
.56276 .9197 L
s
1 .36 0 r
.5948 .84845 m
.58446 .84552 L
s
1 0 0 r
.57371 .47878 m
.56514 .46333 L
s
.56514 .46333 m
.60328 .44513 L
s
0 .76 1 r
.47327 .96623 m
.46165 .96245 L
s
.46165 .96245 m
.4553 .90713 L
s
.92 1 0 r
.52673 .96623 m
.53835 .96245 L
s
.5447 .90713 m
.53835 .96245 L
s
1 .36 0 r
.63665 .73283 m
.6367 .71512 L
s
.61175 .74262 m
.63665 .73283 L
s
1 0 0 r
.59997 .63131 m
.58825 .62374 L
s
.58825 .62374 m
.59915 .58374 L
s
.58463 .67346 m
.58825 .62374 L
s
.72832 .68516 m
.73992 .6888 L
s
.7418 .67346 m
.73992 .6888 L
s
0 .4 1 r
.39748 .8157 m
.38897 .80043 L
s
.38897 .80043 m
.42125 .77589 L
s
1 .72 0 r
.60252 .8157 m
.61103 .80043 L
s
.57875 .77589 m
.61103 .80043 L
s
1 .36 0 r
.51113 1.00357 m
.50067 1.0153 L
s
.51113 1.00357 m
.49663 .97954 L
s
.66793 .70112 m
.67114 .68492 L
s
.63674 .69719 m
.66793 .70112 L
s
.61791 .77589 m
.61483 .7596 L
s
.60052 .79241 m
.61791 .77589 L
s
1 0 0 r
.60786 .80609 m
.59935 .82145 L
s
.60786 .80609 m
.58885 .77656 L
s
.68481 .68491 m
.6762 .69672 L
s
.6762 .69672 m
.6724 .69005 L
s
.65144 .70815 m
.64098 .71792 L
s
.66191 .69888 m
.65144 .70815 L
s
.65144 .70815 m
.64667 .69168 L
s
0 .4 1 r
.57692 1.10472 m
.58542 1.11564 L
s
.60527 1.10832 m
.58542 1.11564 L
s
1 .72 0 r
.42308 1.10472 m
.41458 1.11564 L
s
.41458 1.11564 m
.39473 1.10832 L
s
1 0 0 r
.70384 .68129 m
.71421 .68884 L
s
.71671 .6814 m
.71421 .68884 L
s
1 .36 0 r
.57627 .88834 m
.56428 .89505 L
s
.57627 .88834 m
.5784 .86774 L
s
1 0 0 r
.64098 .71792 m
.63053 .72824 L
s
.64098 .71792 m
.63501 .69695 L
s
0 .4 1 r
.5 1.0067 m
.5 1.01773 L
s
.50626 1.02068 m
.5 1.01773 L
s
1 .72 0 r
.5 1.01773 m
.49374 1.02068 L
s
1 0 0 r
.6724 .69005 m
.66191 .69888 L
s
.66191 .69888 m
.65835 .68675 L
s
1 .36 0 r
.70917 .68775 m
.71536 .67432 L
s
.67436 .66888 m
.70917 .68775 L
s
.59607 .64762 m
.59291 .62721 L
s
.59291 .62721 m
.63689 .62511 L
s
.76483 .68362 m
.77357 .67346 L
s
.72779 .64813 m
.76483 .68362 L
s
1 0 0 r
.69344 .67346 m
.69331 .68939 L
s
.69331 .68939 m
.69019 .68894 L
s
.69643 .68876 m
.69331 .68939 L
s
1 .36 0 r
.60648 .80513 m
.60052 .79241 L
s
.59404 .82382 m
.60648 .80513 L
s
1 0 0 r
.69344 .67346 m
.69643 .68876 L
s
.69936 .68711 m
.69643 .68876 L
s
.71671 .6814 m
.72832 .68516 L
s
.72971 .67346 m
.72832 .68516 L
s
.63053 .72824 m
.6201 .73919 L
s
.63053 .72824 m
.62335 .70263 L
s
.58228 .49432 m
.57371 .47878 L
s
.57371 .47878 m
.60932 .46039 L
s
.69344 .67346 m
.69019 .68894 L
s
.69019 .68894 m
.68729 .68741 L
s
1 .72 0 r
.52336 .97491 m
.53501 .96476 L
s
.53143 .95792 m
.53501 .96476 L
s
0 .4 1 r
.47664 .97491 m
.46499 .96476 L
s
.46499 .96476 m
.46857 .95792 L
s
.40599 .8312 m
.39748 .8157 L
s
.39748 .8157 m
.42726 .79562 L
s
1 .72 0 r
.59401 .8312 m
.60252 .8157 L
s
.57274 .79562 m
.60252 .8157 L
s
1 0 0 r
.69344 .67346 m
.69936 .68711 L
s
.70188 .68456 m
.69936 .68711 L
s
1 .36 0 r
.6367 .71512 m
.63674 .69719 L
s
.60864 .72493 m
.6367 .71512 L
s
1 0 0 r
.69344 .67346 m
.68729 .68741 L
s
.68729 .68741 m
.68481 .68491 L
s
.68291 .68159 m
.6724 .69005 L
s
.6724 .69005 m
.67004 .6821 L
s
1 .36 0 r
.50067 1.0153 m
.4902 1.02688 L
s
.50067 1.0153 m
.48487 .99052 L
s
0 .4 1 r
.51814 1.0348 m
.52417 1.04727 L
s
.53425 1.04672 m
.52417 1.04727 L
s
1 .72 0 r
.48186 1.0348 m
.47583 1.04727 L
s
.47583 1.04727 m
.46575 1.04672 L
s
1 0 0 r
.60968 .59608 m
.59915 .58374 L
s
.59915 .58374 m
.61663 .55566 L
s
.69344 .67346 m
.70188 .68456 L
s
.70384 .68129 m
.70188 .68456 L
s
.59935 .82145 m
.59084 .83702 L
s
.59935 .82145 m
.57844 .79068 L
s
0 .4 1 r
.4879 .98793 m
.47583 .98062 L
s
.47583 .98062 m
.47664 .97491 L
s
1 .72 0 r
.5121 .98793 m
.52417 .98062 L
s
.52336 .97491 m
.52417 .98062 L
s
1 0 0 r
.69344 .67346 m
.68481 .68491 L
s
.68481 .68491 m
.68291 .68159 L
s
0 .4 1 r
.45811 .9452 m
.44767 .93245 L
s
.44767 .93245 m
.45717 .9243 L
s
1 .72 0 r
.54189 .9452 m
.55233 .93245 L
s
.54283 .9243 m
.55233 .93245 L
s
1 0 0 r
.61169 .63811 m
.59997 .63131 L
s
.59997 .63131 m
.60968 .59608 L
s
.59672 .67346 m
.59997 .63131 L
s
.70508 .67751 m
.71671 .6814 L
s
.71762 .67346 m
.71671 .6814 L
s
0 .76 1 r
.51116 1.01695 m
.50067 1.01609 L
s
.50067 1.01609 m
.48493 .97041 L
s
.92 1 0 r
.48884 1.01695 m
.49933 1.01609 L
s
.51507 .97041 m
.49933 1.01609 L
s
1 0 0 r
.6201 .73919 m
.60968 .75085 L
s
.6201 .73919 m
.6117 .70882 L
s
0 .76 1 r
.63702 1.15319 m
.63673 1.16122 L
s
.68145 1.17966 m
.63673 1.16122 L
s
.92 1 0 r
.36298 1.15319 m
.36327 1.16122 L
s
.36327 1.16122 m
.31855 1.17966 L
s
1 .36 0 r
.61483 .7596 m
.61175 .74262 L
s
.59454 .77903 m
.61483 .7596 L
s
.67114 .68492 m
.67436 .66888 L
s
.63677 .67914 m
.67114 .68492 L
s
1 0 0 r
.69344 .67346 m
.70384 .68129 L
s
.70508 .67751 m
.70384 .68129 L
s
.64667 .69168 m
.63501 .69695 L
s
.65835 .68675 m
.64667 .69168 L
s
.64667 .69168 m
.64508 .67346 L
s
1 .36 0 r
.59923 .66776 m
.59607 .64762 L
s
.59607 .64762 m
.63685 .64301 L
s
.5582 .67491 m
.59607 .64762 L
s
1 0 0 r
.67004 .6821 m
.65835 .68675 L
s
.65835 .68675 m
.65717 .67346 L
s
1 .36 0 r
.63674 .69719 m
.63677 .67914 L
s
.60552 .70653 m
.63674 .69719 L
s
0 .76 1 r
.57043 1.08718 m
.56422 1.09174 L
s
.56422 1.09174 m
.53419 1.05644 L
s
.59932 1.1216 m
.56422 1.09174 L
s
.92 1 0 r
.42957 1.08718 m
.43578 1.09174 L
s
.43578 1.09174 m
.40068 1.1216 L
s
.46581 1.05644 m
.43578 1.09174 L
s
1 .36 0 r
.55502 .92585 m
.54339 .93626 L
s
.55502 .92585 m
.55225 .9023 L
s
1 0 0 r
.63501 .69695 m
.62335 .70263 L
s
.63501 .69695 m
.63299 .67346 L
s
.69344 .67346 m
.68291 .68159 L
s
.68291 .68159 m
.68173 .67768 L
s
0 .4 1 r
.5684 1.09359 m
.57692 1.10472 L
s
.59473 1.09797 m
.57692 1.10472 L
s
1 .72 0 r
.4316 1.09359 m
.42308 1.10472 L
s
.42308 1.10472 m
.40527 1.09797 L
s
1 0 0 r
.68173 .67768 m
.67004 .6821 L
s
.67004 .6821 m
.66926 .67346 L
s
0 .4 1 r
.4145 .84685 m
.40599 .8312 L
s
.40599 .8312 m
.43329 .81515 L
s
1 .72 0 r
.5855 .84685 m
.59401 .8312 L
s
.56671 .81515 m
.59401 .8312 L
s
1 0 0 r
.59087 .50987 m
.58228 .49432 L
s
.58228 .49432 m
.61535 .4758 L
s
.69344 .67346 m
.70508 .67751 L
s
.70553 .67346 m
.70508 .67751 L
s
1 .36 0 r
.4902 1.02688 m
.47973 1.03831 L
s
.4902 1.02688 m
.47309 1.00146 L
s
1 0 0 r
.62335 .70263 m
.6117 .70882 L
s
.62335 .70263 m
.6209 .67346 L
s
.69344 .67346 m
.68173 .67768 L
s
.68173 .67768 m
.68135 .67346 L
s
.59084 .83702 m
.58233 .8527 L
s
.59084 .83702 m
.56802 .80563 L
s
1 .36 0 r
.63677 .67914 m
.63681 .66105 L
s
.60238 .68744 m
.63677 .67914 L
s
.60238 .68744 m
.59923 .66776 L
s
.59923 .66776 m
.63681 .66105 L
s
.56431 .69636 m
.59923 .66776 L
s
1 0 0 r
.6234 .64428 m
.61169 .63811 L
s
.61169 .63811 m
.6202 .60768 L
s
.60881 .67346 m
.61169 .63811 L
s
1 .36 0 r
.61175 .74262 m
.60864 .72493 L
s
.58854 .76487 m
.61175 .74262 L
s
.71536 .67432 m
.72157 .66111 L
s
.6776 .65303 m
.71536 .67432 L
s
0 .76 1 r
.54284 1.05446 m
.53419 1.05644 L
s
.53419 1.05644 m
.51116 1.01695 L
s
.92 1 0 r
.45716 1.05446 m
.46581 1.05644 L
s
.48884 1.01695 m
.46581 1.05644 L
s
1 .36 0 r
.59404 .82382 m
.58558 .81571 L
s
.58446 .84552 m
.59404 .82382 L
s
1 0 0 r
.60968 .75085 m
.59926 .76329 L
s
.60968 .75085 m
.60006 .71565 L
s
1 .36 0 r
.73404 .63537 m
.77357 .67346 L
s
1 0 0 r
.87479 .67346 m
.88688 .67346 L
s
.8627 .67346 m
.87479 .67346 L
s
.85061 .67346 m
.8627 .67346 L
s
.83852 .67346 m
.85061 .67346 L
s
.82643 .67346 m
.83852 .67346 L
s
.81434 .67346 m
.82643 .67346 L
s
.80225 .67346 m
.81434 .67346 L
s
.79016 .67346 m
.80225 .67346 L
s
.77807 .67346 m
.79016 .67346 L
s
.76598 .67346 m
.77807 .67346 L
s
.75389 .67346 m
.76598 .67346 L
s
.7418 .67346 m
.75389 .67346 L
s
.72971 .67346 m
.7418 .67346 L
s
.71762 .67346 m
.72971 .67346 L
s
.70553 .67346 m
.71762 .67346 L
s
.69344 .67346 m
.70553 .67346 L
s
.69344 .67346 m
.70516 .66942 L
s
.69344 .67346 m
.70399 .66563 L
s
.69344 .67346 m
.7021 .66235 L
s
.69344 .67346 m
.69961 .6598 L
s
.69344 .67346 m
.69671 .65814 L
s
.69344 .67346 m
.69358 .65751 L
s
.69344 .67346 m
.69044 .65797 L
s
.69344 .67346 m
.6875 .6595 L
s
.69344 .67346 m
.68498 .66201 L
s
.69344 .67346 m
.68303 .66533 L
s
.69344 .67346 m
.68179 .66925 L
s
.51209 .67346 m
.5 .67346 L
s
.52418 .67346 m
.51209 .67346 L
s
.53627 .67346 m
.52418 .67346 L
s
.54836 .67346 m
.53627 .67346 L
s
.56045 .67346 m
.54836 .67346 L
s
.57254 .67346 m
.56045 .67346 L
s
.58463 .67346 m
.57254 .67346 L
s
.59672 .67346 m
.58463 .67346 L
s
.60881 .67346 m
.59672 .67346 L
s
.6209 .67346 m
.60881 .67346 L
s
.63299 .67346 m
.6209 .67346 L
s
.64508 .67346 m
.63299 .67346 L
s
.65717 .67346 m
.64508 .67346 L
s
.66926 .67346 m
.65717 .67346 L
s
.68135 .67346 m
.66926 .67346 L
s
.69344 .67346 m
.68135 .67346 L
s
.88238 .61963 m
.88688 .67346 L
s
.50669 .82448 m
.5 .67346 L
s
.87048 .62258 m
.87479 .67346 L
s
.51847 .80333 m
.51209 .67346 L
s
.85859 .62557 m
.8627 .67346 L
s
.53019 .7842 m
.52418 .67346 L
s
.84671 .62859 m
.85061 .67346 L
s
.54187 .76768 m
.53627 .67346 L
s
.83485 .63165 m
.83852 .67346 L
s
.55352 .75373 m
.54836 .67346 L
s
.823 .63475 m
.82643 .67346 L
s
.56516 .74198 m
.56045 .67346 L
s
.81116 .6379 m
.81434 .67346 L
s
.57679 .73196 m
.57254 .67346 L
s
.79933 .6411 m
.80225 .67346 L
s
.58842 .72328 m
.58463 .67346 L
s
.78752 .64436 m
.79016 .67346 L
s
.60006 .71565 m
.59672 .67346 L
s
.77572 .64768 m
.77807 .67346 L
s
.6117 .70882 m
.60881 .67346 L
s
.76393 .65107 m
.76598 .67346 L
s
.6209 .67346 m
.6234 .64428 L
s
.75215 .65454 m
.75389 .67346 L
s
.63299 .67346 m
.63509 .64996 L
s
.74039 .6581 m
.7418 .67346 L
s
.64508 .67346 m
.64678 .65523 L
s
.72863 .66175 m
.72971 .67346 L
s
.65717 .67346 m
.65846 .66017 L
s
.71689 .66552 m
.71762 .67346 L
s
.66926 .67346 m
.67013 .66483 L
s
.70516 .66942 m
.70553 .67346 L
s
.68135 .67346 m
.68179 .66925 L
s
.69344 .67346 m
.69344 .67346 L
s
.6202 .60768 m
.60968 .59608 L
s
.60968 .59608 m
.62522 .57038 L
s
0 .4 1 r
.50313 1.00823 m
.50626 1.02068 L
s
.5121 1.02203 m
.50626 1.02068 L
s
1 .72 0 r
.49687 1.00823 m
.49374 1.02068 L
s
.49374 1.02068 m
.4879 1.02203 L
s
1 0 0 r
.6117 .70882 m
.60006 .71565 L
s
1 .36 0 r
.5784 .86774 m
.56682 .87025 L
s
.5784 .86774 m
.58446 .84552 L
s
.56431 .69636 m
.5582 .67491 L
s
.52583 .74906 m
.5582 .67491 L
s
.60052 .79241 m
.59454 .77903 L
s
.58558 .81571 m
.60052 .79241 L
s
0 .4 1 r
.42302 .86255 m
.4145 .84685 L
s
.4145 .84685 m
.43932 .83431 L
s
1 .72 0 r
.57698 .86255 m
.5855 .84685 L
s
.56068 .83431 m
.5855 .84685 L
s
1 0 0 r
.59945 .52533 m
.59087 .50987 L
s
.59087 .50987 m
.62139 .49136 L
s
1 .36 0 r
.60552 .70653 m
.60238 .68744 L
s
.5704 .71579 m
.60238 .68744 L
s
.47973 1.03831 m
.46925 1.04956 L
s
.47973 1.03831 m
.46128 1.01233 L
s
0 .4 1 r
.46857 .95792 m
.45811 .9452 L
s
.45811 .9452 m
.46573 .93916 L
s
1 .72 0 r
.53143 .95792 m
.54189 .9452 L
s
.53427 .93916 m
.54189 .9452 L
s
1 .36 0 r
.60864 .72493 m
.60552 .70653 L
s
.58251 .74976 m
.60864 .72493 L
s
.67436 .66888 m
.6776 .65303 L
s
.63681 .66105 m
.67436 .66888 L
s
1 0 0 r
.68179 .66925 m
.67013 .66483 L
s
.68179 .66925 m
.68303 .66533 L
s
1 .36 0 r
.63681 .66105 m
.63685 .64301 L
s
1 0 0 r
.63509 .64996 m
.6234 .64428 L
s
.6234 .64428 m
.63071 .61862 L
s
0 .4 1 r
.55988 1.08224 m
.5684 1.09359 L
s
.58419 1.08741 m
.5684 1.09359 L
s
1 .72 0 r
.44012 1.08224 m
.4316 1.09359 L
s
.4316 1.09359 m
.41581 1.08741 L
s
1 0 0 r
.70516 .66942 m
.71689 .66552 L
s
.70399 .66563 m
.70516 .66942 L
s
1 .36 0 r
.50861 .71996 m
.5 .67449 L
s
.4684 .87573 m
.5 .67449 L
s
.57647 .73348 m
.60552 .70653 L
s
1 0 0 r
.58233 .8527 m
.5738 .8684 L
s
.58233 .8527 m
.55758 .82133 L
s
0 .4 1 r
.5121 1.02203 m
.51814 1.0348 L
s
.5257 1.03435 m
.51814 1.0348 L
s
1 .72 0 r
.4879 1.02203 m
.48186 1.0348 L
s
.48186 1.0348 m
.4743 1.03435 L
s
0 .4 1 r
.5 .99547 m
.49145 .99822 L
s
.49145 .99822 m
.48953 .99469 L
s
.49395 1.00154 m
.49145 .99822 L
s
1 .72 0 r
.5 .99547 m
.50855 .99822 L
s
.50855 .99822 m
.50605 1.00154 L
s
.51047 .99469 m
.50855 .99822 L
s
1 0 0 r
.67013 .66483 m
.65846 .66017 L
s
.67013 .66483 m
.6726 .65686 L
s
1 .36 0 r
.58446 .84552 m
.57409 .84287 L
s
0 .4 1 r
.5 .99547 m
.49395 1.00154 L
s
.49687 1.00442 m
.49395 1.00154 L
s
1 .72 0 r
.5 .99547 m
.50605 1.00154 L
s
.50605 1.00154 m
.50313 1.00442 L
s
1 0 0 r
.68303 .66533 m
.6726 .65686 L
s
.68303 .66533 m
.68498 .66201 L
s
.64678 .65523 m
.63509 .64996 L
s
.63509 .64996 m
.6412 .62894 L
s
0 .4 1 r
.48831 .98516 m
.47664 .97491 L
s
.47664 .97491 m
.47903 .97057 L
s
1 .72 0 r
.51169 .98516 m
.52336 .97491 L
s
.52097 .97057 m
.52336 .97491 L
s
1 0 0 r
.65846 .66017 m
.64678 .65523 L
s
.65846 .66017 m
.66215 .64801 L
s
0 .4 1 r
.5 .99547 m
.48953 .99469 L
s
.48953 .99469 m
.48831 .99118 L
s
1 .72 0 r
.5 .99547 m
.51047 .99469 L
s
.51169 .99118 m
.51047 .99469 L
s
1 0 0 r
.64678 .65523 m
.65168 .63872 L
s
.70399 .66563 m
.71456 .65806 L
s
.7021 .66235 m
.70399 .66563 L
s
.63071 .61862 m
.6202 .60768 L
s
.6202 .60768 m
.6338 .58474 L
s
0 .4 1 r
.5 .76108 m
.5 .67545 L
s
.5 .67545 m
.55229 .90122 L
s
.44989 .68873 m
.5 .67545 L
s
1 .72 0 r
.5 .67545 m
.55011 .68873 L
s
.44771 .90122 m
.5 .67545 L
s
1 0 0 r
.71689 .66552 m
.72863 .66175 L
s
.71456 .65806 m
.71689 .66552 L
s
.60006 .71565 m
.58842 .72328 L
s
1 .36 0 r
.46925 1.04956 m
.44945 1.02309 L
s
.63685 .64301 m
.63689 .62511 L
s
.63685 .64301 m
.6776 .65303 L
s
1 0 0 r
.68498 .66201 m
.67649 .65017 L
s
.68498 .66201 m
.6875 .6595 L
s
0 .4 1 r
.5 .99547 m
.49687 1.00442 L
s
.5 1.0067 m
.49687 1.00442 L
s
1 .72 0 r
.5 .99547 m
.50313 1.00442 L
s
.50313 1.00442 m
.5 1.0067 L
s
1 0 0 r
.60804 .54062 m
.59945 .52533 L
s
.59945 .52533 m
.62743 .50703 L
s
0 .4 1 r
.43155 .87823 m
.42302 .86255 L
s
.42302 .86255 m
.44537 .85298 L
s
1 .72 0 r
.56845 .87823 m
.57698 .86255 L
s
.55463 .85298 m
.57698 .86255 L
s
1 .36 0 r
.56428 .89505 m
.55225 .9023 L
s
.56428 .89505 m
.56682 .87025 L
s
1 0 0 r
.7021 .66235 m
.71078 .65155 L
s
.69961 .6598 m
.7021 .66235 L
s
.59926 .76329 m
.58885 .77656 L
s
.59926 .76329 m
.58842 .72328 L
s
0 .4 1 r
.40923 .73672 m
.40322 .71771 L
s
.40322 .71771 m
.44989 .68873 L
s
1 .72 0 r
.59077 .73672 m
.59678 .71771 L
s
.55011 .68873 m
.59678 .71771 L
s
1 0 0 r
.6726 .65686 m
.66215 .64801 L
s
.6726 .65686 m
.67649 .65017 L
s
.6875 .6595 m
.68155 .64522 L
s
.6875 .6595 m
.69044 .65797 L
s
.92 1 0 r
.49127 .79276 m
.5 .67627 L
s
.5 .67627 m
.53098 .77595 L
s
.45757 .90891 m
.5 .67627 L
s
0 .76 1 r
.50873 .79276 m
.5 .67627 L
s
.5 .67627 m
.54243 .90891 L
s
.46902 .77595 m
.5 .67627 L
s
0 .4 1 r
.5 .99547 m
.48831 .99118 L
s
.48831 .99118 m
.4879 .98793 L
s
1 .72 0 r
.5 .99547 m
.51169 .99118 L
s
.5121 .98793 m
.51169 .99118 L
s
0 .4 1 r
.55135 1.07065 m
.55988 1.08224 L
s
.57365 1.07665 m
.55988 1.08224 L
s
1 .72 0 r
.44865 1.07065 m
.44012 1.08224 L
s
.44012 1.08224 m
.42635 1.07665 L
s
1 0 0 r
.69961 .6598 m
.70581 .64641 L
s
.69671 .65814 m
.69961 .6598 L
s
.69044 .65797 m
.68742 .64232 L
s
.69044 .65797 m
.69358 .65751 L
s
.5738 .8684 m
.56527 .88404 L
s
.5738 .8684 m
.54713 .83763 L
s
.6412 .62894 m
.63071 .61862 L
s
.63071 .61862 m
.64237 .59869 L
s
.72863 .66175 m
.74039 .6581 L
s
.72514 .65072 m
.72863 .66175 L
s
1 .36 0 r
.72157 .66111 m
.72779 .64813 L
s
.68084 .63741 m
.72157 .66111 L
s
1 0 0 r
.69671 .65814 m
.69999 .64299 L
s
.69358 .65751 m
.69671 .65814 L
s
.69358 .65751 m
.69371 .64158 L
s
0 1 .88 r
.51244 .81376 m
.5 .6769 L
s
.5 .6769 m
.50703 .90964 L
s
.50671 .8446 m
.5 .6769 L
s
.56 1 0 r
.48756 .81376 m
.5 .6769 L
s
.49297 .90964 m
.5 .6769 L
s
.5 .6769 m
.49329 .8446 L
s
0 .76 1 r
.48493 .97041 m
.47327 .96623 L
s
.47327 .96623 m
.46738 .91526 L
s
.92 1 0 r
.51507 .97041 m
.52673 .96623 L
s
.53262 .91526 m
.52673 .96623 L
s
1 .36 0 r
.54339 .93626 m
.53174 .94688 L
s
.54339 .93626 m
.5402 .9101 L
s
1 0 0 r
.66215 .64801 m
.65168 .63872 L
s
.66215 .64801 m
.66799 .63794 L
s
1 .72 0 r
.52097 .97057 m
.53143 .95792 L
s
.52571 .95372 m
.53143 .95792 L
s
0 .4 1 r
.47903 .97057 m
.46857 .95792 L
s
.46857 .95792 m
.47429 .95372 L
s
1 .36 0 r
.6776 .65303 m
.68084 .63741 L
s
.63689 .62511 m
.63693 .60741 L
s
.63689 .62511 m
.68084 .63741 L
s
0 1 .52 r
.50884 .82513 m
.5 .6773 L
s
.5 .6773 m
.46734 .90946 L
s
.5414 .88684 m
.5 .6773 L
s
.2 1 0 r
.49116 .82513 m
.5 .6773 L
s
.5 .6773 m
.4586 .88684 L
s
.53266 .90946 m
.5 .6773 L
s
1 .36 0 r
.59454 .77903 m
.58854 .76487 L
s
.57711 .80739 m
.59454 .77903 L
s
1 0 0 r
.65168 .63872 m
.6412 .62894 L
s
.6412 .62894 m
.65092 .6122 L
s
0 .4 1 r
.5 .99547 m
.5 1.0067 L
s
.50313 1.00823 m
.5 1.0067 L
s
1 .72 0 r
.5 1.0067 m
.49687 1.00823 L
s
1 0 0 r
.71456 .65806 m
.72514 .65072 L
s
.71078 .65155 m
.71456 .65806 L
s
0 1 .16 r
.5 .82864 m
.5 .67744 L
s
.5 .67744 m
.44744 .90521 L
s
.55256 .90521 m
.5 .67744 L
s
1 0 0 r
.65168 .63872 m
.65946 .62529 L
s
.67649 .65017 m
.66799 .63794 L
s
.67649 .65017 m
.68155 .64522 L
s
.61663 .55566 m
.60804 .54062 L
s
.60804 .54062 m
.63347 .52276 L
s
0 .4 1 r
.44008 .89379 m
.43155 .87823 L
s
.43155 .87823 m
.45143 .87107 L
s
1 .72 0 r
.55992 .89379 m
.56845 .87823 L
s
.54857 .87107 m
.56845 .87823 L
s
0 .76 1 r
.60269 1.11503 m
.59932 1.1216 L
s
.63731 1.14516 m
.59932 1.1216 L
s
.92 1 0 r
.39731 1.11503 m
.40068 1.1216 L
s
.40068 1.1216 m
.36269 1.14516 L
s
1 .72 0 r
.5 .99547 m
.5121 .98793 L
s
.51169 .98516 m
.5121 .98793 L
s
0 .4 1 r
.5 .99547 m
.4879 .98793 L
s
.4879 .98793 m
.48831 .98516 L
s
1 0 0 r
.74039 .6581 m
.75215 .65454 L
s
.73575 .64357 m
.74039 .6581 L
s
.58842 .72328 m
.57679 .73196 L
s
0 .4 1 r
.45293 .71646 m
.44989 .68873 L
s
1 .72 0 r
.54707 .71646 m
.55011 .68873 L
s
0 .4 1 r
.41524 .75618 m
.40923 .73672 L
s
.40923 .73672 m
.45293 .71646 L
s
1 .72 0 r
.58476 .75618 m
.59077 .73672 L
s
.54707 .71646 m
.59077 .73672 L
s
0 .4 1 r
.5428 1.05882 m
.55135 1.07065 L
s
.56312 1.06568 m
.55135 1.07065 L
s
1 .72 0 r
.4572 1.05882 m
.44865 1.07065 L
s
.44865 1.07065 m
.43688 1.06568 L
s
0 .4 1 r
.50606 1.00892 m
.5121 1.02203 L
s
.51713 1.02169 m
.5121 1.02203 L
s
1 .72 0 r
.49394 1.00892 m
.4879 1.02203 L
s
.4879 1.02203 m
.48287 1.02169 L
s
1 .36 0 r
.5704 .71579 m
.56431 .69636 L
s
.53442 .76044 m
.56431 .69636 L
s
1 0 0 r
.56527 .88404 m
.55674 .89954 L
s
.56527 .88404 m
.53665 .85433 L
s
0 .76 1 r
.68425 1.18845 m
.68705 1.19719 L
s
.73558 1.20819 m
.68705 1.19719 L
s
.92 1 0 r
.31575 1.18845 m
.31295 1.19719 L
s
.31295 1.19719 m
.26442 1.20819 L
s
1 .36 0 r
.58558 .81571 m
.57711 .80739 L
s
.57409 .84287 m
.58558 .81571 L
s
1 0 0 r
.68155 .64522 m
.67558 .63065 L
s
.68155 .64522 m
.68742 .64232 L
s
1 .36 0 r
.63693 .60741 m
.63699 .58998 L
s
.63693 .60741 m
.6841 .62203 L
s
1 0 0 r
.71078 .65155 m
.71948 .64102 L
s
.70581 .64641 m
.71078 .65155 L
s
.62522 .57038 m
.61663 .55566 L
s
.61663 .55566 m
.6395 .53851 L
s
.66799 .63794 m
.65946 .62529 L
s
.66799 .63794 m
.67558 .63065 L
s
0 .4 1 r
.5 .99547 m
.50313 1.00823 L
s
.50606 1.00892 m
.50313 1.00823 L
s
1 .72 0 r
.5 .99547 m
.49687 1.00823 L
s
.49687 1.00823 m
.49394 1.00892 L
s
1 0 0 r
.75215 .65454 m
.76393 .65107 L
s
.74638 .63662 m
.75215 .65454 L
s
0 .4 1 r
.44862 .90916 m
.44008 .89379 L
s
.44008 .89379 m
.45749 .88856 L
s
1 .72 0 r
.55138 .90916 m
.55992 .89379 L
s
.54251 .88856 m
.55992 .89379 L
s
1 0 0 r
.58885 .77656 m
.57844 .79068 L
s
.58885 .77656 m
.57679 .73196 L
s
.68742 .64232 m
.6844 .62653 L
s
.68742 .64232 m
.69371 .64158 L
s
.72514 .65072 m
.73575 .64357 L
s
.71948 .64102 m
.72514 .65072 L
s
1 .36 0 r
.58854 .76487 m
.58251 .74976 L
s
.56861 .7988 m
.58854 .76487 L
s
0 .4 1 r
.48951 .98309 m
.47903 .97057 L
s
.47903 .97057 m
.48286 .96796 L
s
1 .72 0 r
.51049 .98309 m
.52097 .97057 L
s
.51714 .96796 m
.52097 .97057 L
s
1 0 0 r
.70581 .64641 m
.71202 .63328 L
s
.69999 .64299 m
.70581 .64641 L
s
.6338 .58474 m
.62522 .57038 L
s
.62522 .57038 m
.64554 .55422 L
s
0 .4 1 r
.5 .99547 m
.48831 .98516 L
s
.48831 .98516 m
.48951 .98309 L
s
1 .72 0 r
.5 .99547 m
.51169 .98516 L
s
.51049 .98309 m
.51169 .98516 L
s
1 0 0 r
.65946 .62529 m
.65092 .6122 L
s
.65946 .62529 m
.66959 .6158 L
s
0 .4 1 r
.53425 1.04672 m
.5428 1.05882 L
s
.55258 1.0545 m
.5428 1.05882 L
s
1 .72 0 r
.46575 1.04672 m
.4572 1.05882 L
s
.4572 1.05882 m
.44742 1.0545 L
s
1 .36 0 r
.68084 .63741 m
.6841 .62203 L
s
1 0 0 r
.55674 .89954 m
.52614 .8712 L
s
0 .76 1 r
.4553 .90713 m
.44326 .89954 L
s
.44326 .89954 m
.44967 .83835 L
s
.92 1 0 r
.5447 .90713 m
.55674 .89954 L
s
.55033 .83835 m
.55674 .89954 L
s
1 0 0 r
.69371 .64158 m
.69385 .62569 L
s
.69371 .64158 m
.69999 .64299 L
s
.69999 .64299 m
.70328 .62803 L
s
1 .36 0 r
.72779 .64813 m
.73404 .63537 L
s
.6841 .62203 m
.72779 .64813 L
s
1 0 0 r
.64237 .59869 m
.6338 .58474 L
s
.6338 .58474 m
.65156 .56986 L
s
.65092 .6122 m
.64237 .59869 L
s
.65092 .6122 m
.66359 .60069 L
s
1 .36 0 r
.63699 .58998 m
.68738 .6069 L
s
1 0 0 r
.64237 .59869 m
.65758 .58537 L
s
.67558 .63065 m
.66959 .6158 L
s
.67558 .63065 m
.6844 .62653 L
s
1 .36 0 r
.56682 .87025 m
.55521 .87338 L
s
.56682 .87025 m
.57409 .84287 L
s
0 .4 1 r
.42125 .77589 m
.41524 .75618 L
s
.41524 .75618 m
.45599 .744 L
s
1 .72 0 r
.57875 .77589 m
.58476 .75618 L
s
.54401 .744 m
.58476 .75618 L
s
1 .36 0 r
.57647 .73348 m
.5704 .71579 L
s
.543 .77087 m
.5704 .71579 L
s
1 0 0 r
.76393 .65107 m
.77572 .64768 L
s
.75703 .62982 m
.76393 .65107 L
s
0 .4 1 r
.45717 .9243 m
.44862 .90916 L
s
.44862 .90916 m
.46357 .90544 L
s
1 .72 0 r
.54283 .9243 m
.55138 .90916 L
s
.53643 .90544 m
.55138 .90916 L
s
0 .76 1 r
.52169 1.01814 m
.51116 1.01695 L
s
.51116 1.01695 m
.49663 .975 L
s
.92 1 0 r
.47831 1.01814 m
.48884 1.01695 L
s
.50337 .975 m
.48884 1.01695 L
s
1 .36 0 r
.58251 .74976 m
.57647 .73348 L
s
.56009 .78991 m
.58251 .74976 L
s
.57409 .84287 m
.56369 .84058 L
s
0 .4 1 r
.5257 1.03435 m
.53425 1.04672 L
s
.54205 1.04311 m
.53425 1.04672 L
s
1 .72 0 r
.4743 1.03435 m
.46575 1.04672 L
s
.46575 1.04672 m
.45795 1.04311 L
s
1 0 0 r
.57679 .73196 m
.56516 .74198 L
s
0 .76 1 r
.63731 1.14516 m
.63702 1.15319 L
s
.67864 1.17082 m
.63702 1.15319 L
s
.92 1 0 r
.36269 1.14516 m
.36298 1.15319 L
s
.36298 1.15319 m
.32136 1.17082 L
s
0 .4 1 r
.5 .99547 m
.50606 1.00892 L
s
.50857 1.00874 m
.50606 1.00892 L
s
1 .72 0 r
.5 .99547 m
.49394 1.00892 L
s
.49394 1.00892 m
.49143 1.00874 L
s
1 .36 0 r
.55155 .78063 m
.57647 .73348 L
s
1 0 0 r
.71948 .64102 m
.72821 .63075 L
s
.71202 .63328 m
.71948 .64102 L
s
.73575 .64357 m
.74638 .63662 L
s
.72821 .63075 m
.73575 .64357 L
s
1 .36 0 r
.53174 .94688 m
.52006 .95767 L
s
.53174 .94688 m
.52812 .91842 L
s
0 .4 1 r
.5 .99547 m
.48951 .98309 L
s
.48951 .98309 m
.49143 .98188 L
s
1 .72 0 r
.5 .99547 m
.51049 .98309 L
s
.50857 .98188 m
.51049 .98309 L
s
0 .4 1 r
.46573 .93916 m
.45717 .9243 L
s
.45717 .9243 m
.46964 .92172 L
s
1 .72 0 r
.53427 .93916 m
.54283 .9243 L
s
.53036 .92172 m
.54283 .9243 L
s
1 0 0 r
.6844 .62653 m
.68138 .61065 L
s
.6844 .62653 m
.69385 .62569 L
s
.77572 .64768 m
.78752 .64436 L
s
.7677 .62316 m
.77572 .64768 L
s
1 .36 0 r
.55225 .9023 m
.5402 .9101 L
s
.55225 .9023 m
.55521 .87338 L
s
0 .4 1 r
.51713 1.02169 m
.5257 1.03435 L
s
.53153 1.0315 m
.5257 1.03435 L
s
1 .72 0 r
.48287 1.02169 m
.4743 1.03435 L
s
.4743 1.03435 m
.46847 1.0315 L
s
1 0 0 r
.66959 .6158 m
.66359 .60069 L
s
.66959 .6158 m
.68138 .61065 L
s
0 .76 1 r
.57666 1.08279 m
.57043 1.08718 L
s
.57043 1.08718 m
.54284 1.05446 L
s
.60269 1.11503 m
.57043 1.08718 L
s
.92 1 0 r
.42334 1.08279 m
.42957 1.08718 L
s
.42957 1.08718 m
.39731 1.11503 L
s
.45716 1.05446 m
.42957 1.08718 L
s
1 .36 0 r
.6841 .62203 m
.68738 .6069 L
s
1 0 0 r
.71202 .63328 m
.71826 .62042 L
s
.70328 .62803 m
.71202 .63328 L
s
0 .4 1 r
.47429 .95372 m
.46573 .93916 L
s
.46573 .93916 m
.47572 .93745 L
s
1 .72 0 r
.52571 .95372 m
.53427 .93916 L
s
.52428 .93745 m
.53427 .93916 L
s
1 0 0 r
.69385 .62569 m
.694 .60988 L
s
.69385 .62569 m
.70328 .62803 L
s
0 .4 1 r
.42726 .79562 m
.42125 .77589 L
s
.42125 .77589 m
.45907 .77029 L
s
1 .72 0 r
.57274 .79562 m
.57875 .77589 L
s
.54093 .77029 m
.57875 .77589 L
s
0 .4 1 r
.50857 1.00874 m
.51713 1.02169 L
s
.52101 1.01969 m
.51713 1.02169 L
s
1 .72 0 r
.49143 1.00874 m
.48287 1.02169 L
s
.48287 1.02169 m
.47899 1.01969 L
s
1 .36 0 r
.57711 .80739 m
.56861 .7988 L
s
.56369 .84058 m
.57711 .80739 L
s
1 0 0 r
.57844 .79068 m
.56802 .80563 L
s
.57844 .79068 m
.56516 .74198 L
s
0 .76 1 r
.55152 1.05273 m
.54284 1.05446 L
s
.54284 1.05446 m
.52169 1.01814 L
s
.92 1 0 r
.44848 1.05273 m
.45716 1.05446 L
s
.47831 1.01814 m
.45716 1.05446 L
s
1 0 0 r
.70328 .62803 m
.70658 .61327 L
s
0 .4 1 r
.48286 .96796 m
.47429 .95372 L
s
.47429 .95372 m
.48179 .95265 L
s
1 .72 0 r
.51714 .96796 m
.52571 .95372 L
s
.51821 .95265 m
.52571 .95372 L
s
1 0 0 r
.78752 .64436 m
.79933 .6411 L
s
.77839 .61664 m
.78752 .64436 L
s
0 .4 1 r
.5 .99547 m
.50857 1.00874 L
s
.5105 1.00767 m
.50857 1.00874 L
s
1 .72 0 r
.5 .99547 m
.49143 1.00874 L
s
.49143 1.00874 m
.4895 1.00767 L
s
1 0 0 r
.66359 .60069 m
.65758 .58537 L
s
.66359 .60069 m
.67834 .59471 L
s
1 .36 0 r
.68738 .6069 m
.73404 .63537 L
s
0 .4 1 r
.49143 .98188 m
.48286 .96796 L
s
.48286 .96796 m
.48787 .96736 L
s
1 .72 0 r
.50857 .98188 m
.51714 .96796 L
s
.51213 .96736 m
.51714 .96796 L
s
0 .4 1 r
.5 .99547 m
.51214 1.00321 L
s
.5 .99547 m
.51173 1.00009 L
s
.5 .99547 m
.51052 .99661 L
s
.5 .99547 m
.50859 .99302 L
s
.5 .99547 m
.50607 .98956 L
s
.5 .99547 m
.50314 .98648 L
s
.5 .99547 m
.5 .98401 L
s
.5 .99547 m
.49686 .98235 L
s
.5 .99547 m
.49394 .98162 L
s
.5 .99547 m
.49143 .98188 L
s
.5 .99547 m
.5105 1.00767 L
s
.5 .99547 m
.51172 1.0058 L
s
.5 .99547 m
.5 .99547 L
s
1 .72 0 r
.5 .99547 m
.50857 .98188 L
s
.5 .99547 m
.50606 .98162 L
s
.5 .99547 m
.50314 .98235 L
s
.5 .99547 m
.49686 .98648 L
s
.5 .99547 m
.49393 .98956 L
s
.5 .99547 m
.49141 .99302 L
s
.5 .99547 m
.48948 .99661 L
s
.5 .99547 m
.48827 1.00009 L
s
.5 .99547 m
.48786 1.00321 L
s
.5 .99547 m
.48828 1.0058 L
s
.5 .99547 m
.4895 1.00767 L
s
1 0 0 r
.74638 .63662 m
.75703 .62982 L
s
.73696 .62072 m
.74638 .63662 L
s
0 .4 1 r
.49143 .98188 m
.49394 .98162 L
s
1 .72 0 r
.50606 .98162 m
.50857 .98188 L
s
1 0 0 r
.68138 .61065 m
.67834 .59471 L
s
.68138 .61065 m
.694 .60988 L
s
.92 1 0 r
.50337 .975 m
.51507 .97041 L
s
.52051 .9239 m
.51507 .97041 L
s
0 .76 1 r
.49663 .975 m
.48493 .97041 L
s
.48493 .97041 m
.47949 .9239 L
s
1 0 0 r
.72821 .63075 m
.73696 .62072 L
s
.71826 .62042 m
.72821 .63075 L
s
.65758 .58537 m
.65156 .56986 L
s
.65758 .58537 m
.67531 .57876 L
s
.79933 .6411 m
.81116 .6379 L
s
.78911 .61024 m
.79933 .6411 L
s
.56516 .74198 m
.55352 .75373 L
s
1 .72 0 r
.56671 .81515 m
.57274 .79562 L
s
.53782 .7948 m
.57274 .79562 L
s
0 .4 1 r
.43329 .81515 m
.42726 .79562 L
s
.42726 .79562 m
.46218 .7948 L
s
.45599 .744 m
.45293 .71646 L
s
.45293 .71646 m
.5 .76108 L
s
1 .72 0 r
.54401 .744 m
.54707 .71646 L
s
.5 .76108 m
.54707 .71646 L
s
0 .4 1 r
.5105 1.00767 m
.52101 1.01969 L
s
.51172 1.0058 m
.5105 1.00767 L
s
1 .72 0 r
.4895 1.00767 m
.47899 1.01969 L
s
.4895 1.00767 m
.48828 1.0058 L
s
1 0 0 r
.694 .60988 m
.69415 .59417 L
s
.694 .60988 m
.70658 .61327 L
s
.65156 .56986 m
.64554 .55422 L
s
.65156 .56986 m
.67227 .56283 L
s
0 .76 1 r
.46738 .91526 m
.4553 .90713 L
s
.4553 .90713 m
.46135 .85158 L
s
.92 1 0 r
.53262 .91526 m
.5447 .90713 L
s
.53865 .85158 m
.5447 .90713 L
s
0 .76 1 r
.68145 1.17966 m
.68425 1.18845 L
s
.72981 1.1992 m
.68425 1.18845 L
s
.92 1 0 r
.31855 1.17966 m
.31575 1.18845 L
s
.31575 1.18845 m
.27019 1.1992 L
s
1 0 0 r
.71826 .62042 m
.72451 .6078 L
s
.70658 .61327 m
.71826 .62042 L
s
1 .36 0 r
.52006 .95767 m
.50836 .96857 L
s
.52006 .95767 m
.51599 .92724 L
s
0 .4 1 r
.49394 .98162 m
.48787 .96736 L
s
.49394 .98162 m
.49686 .98235 L
s
1 .72 0 r
.50606 .98162 m
.51213 .96736 L
s
.50314 .98235 m
.50606 .98162 L
s
1 0 0 r
.75703 .62982 m
.7677 .62316 L
s
.74573 .61089 m
.75703 .62982 L
s
.81116 .6379 m
.823 .63475 L
s
.79984 .60394 m
.81116 .6379 L
s
.70658 .61327 m
.70991 .59871 L
s
.67834 .59471 m
.67531 .57876 L
s
.67834 .59471 m
.69415 .59417 L
s
.64554 .55422 m
.6395 .53851 L
s
.64554 .55422 m
.66923 .54695 L
s
1 .36 0 r
.56369 .84058 m
.55327 .83876 L
s
.55521 .87338 m
.56369 .84058 L
s
.55521 .87338 m
.54357 .87723 L
s
.56861 .7988 m
.56009 .78991 L
s
.55327 .83876 m
.56861 .7988 L
s
0 .76 1 r
.60608 1.10854 m
.60269 1.11503 L
s
.6376 1.13714 m
.60269 1.11503 L
s
.92 1 0 r
.39392 1.10854 m
.39731 1.11503 L
s
.39731 1.11503 m
.3624 1.13714 L
s
1 0 0 r
.56802 .80563 m
.55758 .82133 L
s
.56802 .80563 m
.55352 .75373 L
s
.73696 .62072 m
.74573 .61089 L
s
.72451 .6078 m
.73696 .62072 L
s
0 .4 1 r
.43932 .83431 m
.43329 .81515 L
s
.43329 .81515 m
.4653 .81746 L
s
1 .72 0 r
.56068 .83431 m
.56671 .81515 L
s
.5347 .81746 m
.56671 .81515 L
s
0 .4 1 r
.52101 1.01969 m
.53153 1.0315 L
s
.52346 1.01611 m
.52101 1.01969 L
s
1 .72 0 r
.47899 1.01969 m
.46847 1.0315 L
s
.47899 1.01969 m
.47654 1.01611 L
s
1 0 0 r
.6395 .53851 m
.63347 .52276 L
s
.6395 .53851 m
.66619 .53116 L
s
.823 .63475 m
.83485 .63165 L
s
.8106 .59773 m
.823 .63475 L
s
0 .4 1 r
.51172 1.0058 m
.52346 1.01611 L
s
.51214 1.00321 m
.51172 1.0058 L
s
1 .72 0 r
.48828 1.0058 m
.47654 1.01611 L
s
.48828 1.0058 m
.48786 1.00321 L
s
0 .4 1 r
.48787 .96736 m
.48179 .95265 L
s
.48787 .96736 m
.49371 .96885 L
s
1 .72 0 r
.51213 .96736 m
.51821 .95265 L
s
.50629 .96885 m
.51213 .96736 L
s
1 .36 0 r
.5402 .9101 m
.52812 .91842 L
s
.5402 .9101 m
.54357 .87723 L
s
0 .4 1 r
.49686 .98235 m
.49371 .96885 L
s
.49686 .98235 m
.5 .98401 L
s
1 .72 0 r
.50314 .98235 m
.50629 .96885 L
s
.5 .98401 m
.50314 .98235 L
s
1 0 0 r
.63347 .52276 m
.62743 .50703 L
s
.63347 .52276 m
.66315 .51548 L
s
.7677 .62316 m
.77839 .61664 L
s
.75453 .60126 m
.7677 .62316 L
s
.69415 .59417 m
.69431 .57859 L
s
.69415 .59417 m
.70991 .59871 L
s
.67531 .57876 m
.67227 .56283 L
s
.67531 .57876 m
.69431 .57859 L
s
0 .76 1 r
.53227 1.01966 m
.52169 1.01814 L
s
.52169 1.01814 m
.50838 .97998 L
s
.92 1 0 r
.46773 1.01966 m
.47831 1.01814 L
s
.49162 .97998 m
.47831 1.01814 L
s
0 .4 1 r
.53153 1.0315 m
.54205 1.04311 L
s
.53522 1.02638 m
.53153 1.0315 L
s
1 .72 0 r
.46847 1.0315 m
.45795 1.04311 L
s
.46847 1.0315 m
.46478 1.02638 L
s
0 .4 1 r
.44537 .85298 m
.43932 .83431 L
s
.43932 .83431 m
.46844 .83844 L
s
1 .72 0 r
.55463 .85298 m
.56068 .83431 L
s
.53156 .83844 m
.56068 .83431 L
s
1 0 0 r
.72451 .6078 m
.73079 .59541 L
s
.70991 .59871 m
.72451 .6078 L
s
.83485 .63165 m
.84671 .62859 L
s
.82138 .59162 m
.83485 .63165 L
s
.62743 .50703 m
.62139 .49136 L
s
.62743 .50703 m
.66011 .49994 L
s
0 .76 1 r
.6376 1.13714 m
.63731 1.14516 L
s
.67581 1.16192 m
.63731 1.14516 L
s
.92 1 0 r
.3624 1.13714 m
.36269 1.14516 L
s
.36269 1.14516 m
.32419 1.16192 L
s
0 .4 1 r
.48179 .95265 m
.47572 .93745 L
s
.48179 .95265 m
.49056 .95492 L
s
1 .72 0 r
.51821 .95265 m
.52428 .93745 L
s
.50944 .95492 m
.51821 .95265 L
s
0 .4 1 r
.51214 1.00321 m
.52431 1.01114 L
s
.51173 1.00009 m
.51214 1.00321 L
s
1 .72 0 r
.48786 1.00321 m
.47569 1.01114 L
s
.48786 1.00321 m
.48827 1.00009 L
s
1 0 0 r
.70991 .59871 m
.71324 .58436 L
s
0 .4 1 r
.5 .98401 m
.5 .97232 L
s
.5 .98401 m
.50314 .98648 L
s
1 .72 0 r
.49686 .98648 m
.5 .98401 L
s
1 0 0 r
.62139 .49136 m
.61535 .4758 L
s
.62139 .49136 m
.65708 .48455 L
s
0 .4 1 r
.54205 1.04311 m
.55258 1.0545 L
s
.54701 1.03657 m
.54205 1.04311 L
s
1 .72 0 r
.45795 1.04311 m
.44742 1.0545 L
s
.45795 1.04311 m
.45299 1.03657 L
s
1 0 0 r
.74573 .61089 m
.75453 .60126 L
s
.73079 .59541 m
.74573 .61089 L
s
.55352 .75373 m
.54187 .76768 L
s
1 .36 0 r
.50836 .96857 m
.49663 .97954 L
s
.50836 .96857 m
.50383 .93652 L
s
0 .4 1 r
.45143 .87107 m
.44537 .85298 L
s
.44537 .85298 m
.4716 .85796 L
s
1 .72 0 r
.54857 .87107 m
.55463 .85298 L
s
.5284 .85796 m
.55463 .85298 L
s
1 .36 0 r
.56009 .78991 m
.55155 .78063 L
s
.54282 .83757 m
.56009 .78991 L
s
0 .4 1 r
.47572 .93745 m
.46964 .92172 L
s
.47572 .93745 m
.4874 .94049 L
s
1 .72 0 r
.52428 .93745 m
.53036 .92172 L
s
.5126 .94049 m
.52428 .93745 L
s
1 0 0 r
.84671 .62859 m
.85859 .62557 L
s
.83219 .58558 m
.84671 .62859 L
s
0 .4 1 r
.51173 1.00009 m
.5235 1.00503 L
s
.51052 .99661 m
.51173 1.00009 L
s
1 .72 0 r
.48827 1.00009 m
.4765 1.00503 L
s
.48827 1.00009 m
.48948 .99661 L
s
1 0 0 r
.67227 .56283 m
.66923 .54695 L
s
.67227 .56283 m
.69447 .56315 L
s
0 .4 1 r
.50314 .98648 m
.5063 .97747 L
s
.50314 .98648 m
.50607 .98956 L
s
1 .72 0 r
.49686 .98648 m
.4937 .97747 L
s
.49393 .98956 m
.49686 .98648 L
s
1 0 0 r
.77839 .61664 m
.78911 .61024 L
s
.76336 .59181 m
.77839 .61664 L
s
0 .76 1 r
.58293 1.07858 m
.57666 1.08279 L
s
.57666 1.08279 m
.55152 1.05273 L
s
.60608 1.10854 m
.57666 1.08279 L
s
.92 1 0 r
.41707 1.07858 m
.42334 1.08279 L
s
.42334 1.08279 m
.39392 1.10854 L
s
.44848 1.05273 m
.42334 1.08279 L
s
1 0 0 r
.61535 .4758 m
.60932 .46039 L
s
.61535 .4758 m
.65405 .46933 L
s
.92 1 0 r
.49162 .97998 m
.50337 .975 L
s
.50836 .93301 m
.50337 .975 L
s
0 .76 1 r
.50838 .97998 m
.49663 .975 L
s
.49663 .975 m
.49164 .93301 L
s
0 .4 1 r
.45749 .88856 m
.45143 .87107 L
s
.45143 .87107 m
.47475 .87625 L
s
1 .72 0 r
.54251 .88856 m
.54857 .87107 L
s
.52525 .87625 m
.54857 .87107 L
s
0 .4 1 r
.46964 .92172 m
.46357 .90544 L
s
.46964 .92172 m
.48424 .92551 L
s
1 .72 0 r
.53036 .92172 m
.53643 .90544 L
s
.51576 .92551 m
.53036 .92172 L
s
0 .4 1 r
.55258 1.0545 m
.56312 1.06568 L
s
.55882 1.04667 m
.55258 1.0545 L
s
1 .72 0 r
.44742 1.0545 m
.43688 1.06568 L
s
.44742 1.0545 m
.44118 1.04667 L
s
1 0 0 r
.55758 .82133 m
.54713 .83763 L
s
.55758 .82133 m
.54187 .76768 L
s
0 .4 1 r
.52346 1.01611 m
.53522 1.02638 L
s
.52431 1.01114 m
.52346 1.01611 L
s
1 .72 0 r
.47654 1.01611 m
.46478 1.02638 L
s
.47654 1.01611 m
.47569 1.01114 L
s
1 0 0 r
.69431 .57859 m
.69447 .56315 L
s
.69431 .57859 m
.71324 .58436 L
s
0 .4 1 r
.51052 .99661 m
.52108 .99815 L
s
.50859 .99302 m
.51052 .99661 L
s
1 .72 0 r
.48948 .99661 m
.47892 .99815 L
s
.48948 .99661 m
.49141 .99302 L
s
0 .76 1 r
.47949 .9239 m
.46738 .91526 L
s
.46738 .91526 m
.47306 .86554 L
s
.92 1 0 r
.52051 .9239 m
.53262 .91526 L
s
.52694 .86554 m
.53262 .91526 L
s
0 .76 1 r
.56025 1.05128 m
.55152 1.05273 L
s
.55152 1.05273 m
.53227 1.01966 L
s
.92 1 0 r
.43975 1.05128 m
.44848 1.05273 L
s
.46773 1.01966 m
.44848 1.05273 L
s
0 .4 1 r
.50607 .98956 m
.51217 .98384 L
s
.50607 .98956 m
.50859 .99302 L
s
1 .72 0 r
.49393 .98956 m
.48783 .98384 L
s
.49141 .99302 m
.49393 .98956 L
s
0 .4 1 r
.49371 .96885 m
.49056 .95492 L
s
.49371 .96885 m
.5 .97232 L
s
1 .72 0 r
.50629 .96885 m
.50944 .95492 L
s
.5 .97232 m
.50629 .96885 L
s
0 .4 1 r
.46357 .90544 m
.45749 .88856 L
s
.45749 .88856 m
.47792 .8935 L
s
1 .72 0 r
.53643 .90544 m
.54251 .88856 L
s
.52208 .8935 m
.54251 .88856 L
s
0 .4 1 r
.46357 .90544 m
.48108 .90988 L
s
1 .72 0 r
.51892 .90988 m
.53643 .90544 L
s
0 .4 1 r
.50859 .99302 m
.51721 .99092 L
s
1 .72 0 r
.49141 .99302 m
.48279 .99092 L
s
0 .4 1 r
.45907 .77029 m
.45599 .744 L
s
.45599 .744 m
.5 .78983 L
s
1 .72 0 r
.54093 .77029 m
.54401 .744 L
s
.5 .78983 m
.54401 .744 L
s
1 0 0 r
.85859 .62557 m
.87048 .62258 L
s
.84301 .57962 m
.85859 .62557 L
s
.60932 .46039 m
.60328 .44513 L
s
.60932 .46039 m
.65101 .45428 L
s
0 .4 1 r
.56312 1.06568 m
.57365 1.07665 L
s
.57065 1.05666 m
.56312 1.06568 L
s
1 .72 0 r
.43688 1.06568 m
.42635 1.07665 L
s
.43688 1.06568 m
.42935 1.05666 L
s
1 0 0 r
.73079 .59541 m
.7371 .58324 L
s
.71324 .58436 m
.73079 .59541 L
s
1 .36 0 r
.55327 .83876 m
.54282 .83757 L
s
.54357 .87723 m
.55327 .83876 L
s
0 .76 1 r
.67864 1.17082 m
.68145 1.17966 L
s
.72403 1.19012 m
.68145 1.17966 L
s
.92 1 0 r
.32136 1.17082 m
.31855 1.17966 L
s
.31855 1.17966 m
.27597 1.19012 L
s
1 0 0 r
.71324 .58436 m
.7166 .57022 L
s
.66923 .54695 m
.66619 .53116 L
s
.66923 .54695 m
.69464 .54788 L
s
0 .4 1 r
.57365 1.07665 m
.58419 1.08741 L
s
.5825 1.06651 m
.57365 1.07665 L
s
1 .72 0 r
.42635 1.07665 m
.41581 1.08741 L
s
.42635 1.07665 m
.4175 1.06651 L
s
1 .36 0 r
.54357 .87723 m
.5319 .88189 L
s
1 0 0 r
.75453 .60126 m
.76336 .59181 L
s
.7371 .58324 m
.75453 .60126 L
s
.78911 .61024 m
.79984 .60394 L
s
.77222 .58252 m
.78911 .61024 L
s
.60328 .44513 m
.59724 .43007 L
s
.60328 .44513 m
.64798 .4394 L
s
.87048 .62258 m
.88238 .61963 L
s
.85386 .57372 m
.87048 .62258 L
s
1 .36 0 r
.55155 .78063 m
.543 .77087 L
s
.53235 .83725 m
.55155 .78063 L
s
.52812 .91842 m
.51599 .92724 L
s
.52812 .91842 m
.5319 .88189 L
s
0 .4 1 r
.58419 1.08741 m
.59473 1.09797 L
s
.59437 1.07622 m
.58419 1.08741 L
s
1 .72 0 r
.41581 1.08741 m
.40527 1.09797 L
s
.41581 1.08741 m
.40563 1.07622 L
s
0 .76 1 r
.46135 .85158 m
.44967 .83835 L
s
.44967 .83835 m
.46902 .77595 L
s
.92 1 0 r
.53865 .85158 m
.55033 .83835 L
s
.53098 .77595 m
.55033 .83835 L
s
1 .36 0 r
.49663 .97954 m
.48487 .99052 L
s
.49663 .97954 m
.49162 .94618 L
s
0 .4 1 r
.59473 1.09797 m
.60527 1.10832 L
s
.60626 1.08578 m
.59473 1.09797 L
s
1 .72 0 r
.40527 1.09797 m
.39473 1.10832 L
s
.40527 1.09797 m
.39374 1.08578 L
s
1 0 0 r
.69447 .56315 m
.69464 .54788 L
s
.69447 .56315 m
.7166 .57022 L
s
.59724 .43007 m
.64495 .4247 L
s
0 .4 1 r
.65791 1.15736 m
.66843 1.16667 L
s
.68987 1.14831 m
.66843 1.16667 L
s
1 .72 0 r
.34209 1.15736 m
.33157 1.16667 L
s
.33157 1.16667 m
.31013 1.14831 L
s
0 .4 1 r
.60527 1.10832 m
.6158 1.11849 L
s
.61816 1.09518 m
.60527 1.10832 L
s
1 .72 0 r
.39473 1.10832 m
.3842 1.11849 L
s
.39473 1.10832 m
.38184 1.09518 L
s
0 .4 1 r
.52431 1.01114 m
.53652 1.01919 L
s
.5235 1.00503 m
.52431 1.01114 L
s
1 .72 0 r
.47569 1.01114 m
.46348 1.01919 L
s
.47569 1.01114 m
.4765 1.00503 L
s
0 .4 1 r
.5 .97232 m
.5 .96036 L
s
.5 .97232 m
.5063 .97747 L
s
1 .72 0 r
.4937 .97747 m
.5 .97232 L
s
0 .4 1 r
.53522 1.02638 m
.54701 1.03657 L
s
.53652 1.01919 m
.53522 1.02638 L
s
1 .72 0 r
.46478 1.02638 m
.45299 1.03657 L
s
.46478 1.02638 m
.46348 1.01919 L
s
0 .4 1 r
.49056 .95492 m
.4874 .94049 L
s
.49056 .95492 m
.5 .96036 L
s
1 .72 0 r
.50944 .95492 m
.5126 .94049 L
s
.5 .96036 m
.50944 .95492 L
s
0 .4 1 r
.64739 1.1479 m
.65791 1.15736 L
s
.67789 1.13984 m
.65791 1.15736 L
s
1 .72 0 r
.35261 1.1479 m
.34209 1.15736 L
s
.34209 1.15736 m
.32211 1.13984 L
s
0 .4 1 r
.6158 1.11849 m
.62634 1.12847 L
s
.63008 1.10443 m
.6158 1.11849 L
s
1 .72 0 r
.3842 1.11849 m
.37366 1.12847 L
s
.3842 1.11849 m
.36992 1.10443 L
s
1 0 0 r
.86473 .56788 m
.88238 .61963 L
s
0 .4 1 r
.63687 1.13827 m
.64739 1.1479 L
s
.66592 1.13122 m
.64739 1.1479 L
s
1 .72 0 r
.36313 1.13827 m
.35261 1.1479 L
s
.35261 1.1479 m
.33408 1.13122 L
s
1 0 0 r
.66619 .53116 m
.66315 .51548 L
s
.66619 .53116 m
.69482 .53277 L
s
0 .4 1 r
.62634 1.12847 m
.63687 1.13827 L
s
.64202 1.11352 m
.62634 1.12847 L
s
1 .72 0 r
.37366 1.12847 m
.36313 1.13827 L
s
.37366 1.12847 m
.35798 1.11352 L
s
0 .76 1 r
.60948 1.10216 m
.60608 1.10854 L
s
.6379 1.12912 m
.60608 1.10854 L
s
.92 1 0 r
.39052 1.10216 m
.39392 1.10854 L
s
.39392 1.10854 m
.3621 1.12912 L
s
0 .4 1 r
.65396 1.12245 m
.63687 1.13827 L
s
1 .72 0 r
.36313 1.13827 m
.34604 1.12245 L
s
1 0 0 r
.7371 .58324 m
.74343 .57127 L
s
.7166 .57022 m
.7371 .58324 L
s
.79984 .60394 m
.8106 .59773 L
s
.78109 .57337 m
.79984 .60394 L
s
.54713 .83763 m
.53665 .85433 L
s
.54713 .83763 m
.53019 .7842 L
s
.7166 .57022 m
.71997 .55627 L
s
.76336 .59181 m
.77222 .58252 L
s
.74343 .57127 m
.76336 .59181 L
s
1 .36 0 r
.543 .77087 m
.53442 .76044 L
s
.52184 .8381 m
.543 .77087 L
s
0 .76 1 r
.5429 1.02153 m
.53227 1.01966 L
s
.53227 1.01966 m
.52017 .98536 L
s
.92 1 0 r
.4571 1.02153 m
.46773 1.01966 L
s
.47983 .98536 m
.46773 1.01966 L
s
1 0 0 r
.54187 .76768 m
.53019 .7842 L
s
0 .76 1 r
.6379 1.12912 m
.6376 1.13714 L
s
.67298 1.15298 m
.6376 1.13714 L
s
.92 1 0 r
.3621 1.12912 m
.3624 1.13714 L
s
.3624 1.13714 m
.32702 1.15298 L
s
0 .4 1 r
.46218 .7948 m
.45907 .77029 L
s
.45907 .77029 m
.5 .81229 L
s
1 .72 0 r
.53782 .7948 m
.54093 .77029 L
s
.5 .81229 m
.54093 .77029 L
s
0 .4 1 r
.5063 .97747 m
.50946 .96845 L
s
.5063 .97747 m
.51217 .98384 L
s
1 .72 0 r
.4937 .97747 m
.49054 .96845 L
s
.48783 .98384 m
.4937 .97747 L
s
0 .4 1 r
.5235 1.00503 m
.53532 1.01028 L
s
.52108 .99815 m
.5235 1.00503 L
s
1 .72 0 r
.4765 1.00503 m
.46468 1.01028 L
s
.4765 1.00503 m
.47892 .99815 L
s
1 0 0 r
.66315 .51548 m
.66011 .49994 L
s
.66315 .51548 m
.69501 .51783 L
s
0 .76 1 r
.49164 .93301 m
.47949 .9239 L
s
.47949 .9239 m
.48481 .88007 L
s
.92 1 0 r
.50836 .93301 m
.52051 .9239 L
s
.51519 .88007 m
.52051 .9239 L
s
1 0 0 r
.69464 .54788 m
.69482 .53277 L
s
.69464 .54788 m
.71997 .55627 L
s
0 .4 1 r
.4874 .94049 m
.48424 .92551 L
s
.4874 .94049 m
.5 .94811 L
s
1 .72 0 r
.5126 .94049 m
.51576 .92551 L
s
.5 .94811 m
.5126 .94049 L
s
0 .76 1 r
.52017 .98536 m
.50838 .97998 L
s
.50838 .97998 m
.50383 .94254 L
s
.92 1 0 r
.47983 .98536 m
.49162 .97998 L
s
.49617 .94254 m
.49162 .97998 L
s
1 .36 0 r
.48487 .99052 m
.47309 1.00146 L
s
.48487 .99052 m
.47936 .95615 L
s
0 .4 1 r
.54701 1.03657 m
.55882 1.04667 L
s
.54877 1.02736 m
.54701 1.03657 L
s
1 .72 0 r
.45299 1.03657 m
.44118 1.04667 L
s
.45299 1.03657 m
.45123 1.02736 L
s
1 .36 0 r
.54282 .83757 m
.53235 .83725 L
s
.5319 .88189 m
.54282 .83757 L
s
1 0 0 r
.8106 .59773 m
.82138 .59162 L
s
.79 .56436 m
.8106 .59773 L
s
1 .36 0 r
.53442 .76044 m
.52583 .74906 L
s
.51128 .84056 m
.53442 .76044 L
s
0 .76 1 r
.67581 1.16192 m
.67864 1.17082 L
s
.71823 1.18095 m
.67864 1.17082 L
s
.92 1 0 r
.32419 1.16192 m
.32136 1.17082 L
s
.32136 1.17082 m
.28177 1.18095 L
s
1 .72 0 r
.48783 .98384 m
.4817 .97837 L
s
.48279 .99092 m
.48783 .98384 L
s
0 .4 1 r
.51217 .98384 m
.5183 .97837 L
s
.51217 .98384 m
.51721 .99092 L
s
.52108 .99815 m
.53169 1.00009 L
s
.51721 .99092 m
.52108 .99815 L
s
1 .72 0 r
.47892 .99815 m
.46831 1.00009 L
s
.47892 .99815 m
.48279 .99092 L
s
1 .36 0 r
.51722 .73612 m
.50861 .71996 L
s
.47926 .86274 m
.50861 .71996 L
s
1 0 0 r
.74343 .57127 m
.74978 .55949 L
s
.71997 .55627 m
.74343 .57127 L
s
0 .76 1 r
.58924 1.07458 m
.58293 1.07858 L
s
.58293 1.07858 m
.56025 1.05128 L
s
.60948 1.10216 m
.58293 1.07858 L
s
.92 1 0 r
.41076 1.07458 m
.41707 1.07858 L
s
.41707 1.07858 m
.39052 1.10216 L
s
.43975 1.05128 m
.41707 1.07858 L
s
1 0 0 r
.77222 .58252 m
.78109 .57337 L
s
.74978 .55949 m
.77222 .58252 L
s
0 .4 1 r
.51721 .99092 m
.52588 .98921 L
s
1 .72 0 r
.48279 .99092 m
.47412 .98921 L
s
0 .76 1 r
.47306 .86554 m
.46135 .85158 L
s
.46135 .85158 m
.47952 .79934 L
s
.92 1 0 r
.52694 .86554 m
.53865 .85158 L
s
.52048 .79934 m
.53865 .85158 L
s
1 .36 0 r
.51599 .92724 m
.50383 .93652 L
s
.51599 .92724 m
.52018 .88745 L
s
0 .76 1 r
.56903 1.05012 m
.56025 1.05128 L
s
.56025 1.05128 m
.5429 1.02153 L
s
.92 1 0 r
.43097 1.05012 m
.43975 1.05128 L
s
.4571 1.02153 m
.43975 1.05128 L
s
1 .36 0 r
.5319 .88189 m
.52018 .88745 L
s
1 0 0 r
.71997 .55627 m
.72336 .54252 L
s
.66011 .49994 m
.65708 .48455 L
s
.66011 .49994 m
.6952 .50307 L
s
0 .4 1 r
.5 .96036 m
.5 .94811 L
s
.5 .96036 m
.50946 .96845 L
s
1 .72 0 r
.49054 .96845 m
.5 .96036 L
s
0 .4 1 r
.53652 1.01919 m
.54877 1.02736 L
s
.53532 1.01028 m
.53652 1.01919 L
s
1 .72 0 r
.46348 1.01919 m
.45123 1.02736 L
s
.46348 1.01919 m
.46468 1.01028 L
s
1 .36 0 r
.52583 .74906 m
.51722 .73612 L
s
.50068 .84515 m
.52583 .74906 L
s
0 .4 1 r
.48424 .92551 m
.48108 .90988 L
s
.48424 .92551 m
.5 .93553 L
s
1 .72 0 r
.51576 .92551 m
.51892 .90988 L
s
.5 .93553 m
.51576 .92551 L
s
1 0 0 r
.53665 .85433 m
.52614 .8712 L
s
.53665 .85433 m
.51847 .80333 L
s
.69482 .53277 m
.69501 .51783 L
s
.69482 .53277 m
.72336 .54252 L
s
1 .36 0 r
.49001 .85244 m
.51722 .73612 L
s
1 0 0 r
.82138 .59162 m
.83219 .58558 L
s
.79893 .55546 m
.82138 .59162 L
s
0 .4 1 r
.4653 .81746 m
.46218 .7948 L
s
.46218 .7948 m
.5 .8317 L
s
1 .72 0 r
.5347 .81746 m
.53782 .7948 L
s
.5 .8317 m
.53782 .7948 L
s
0 .4 1 r
.55882 1.04667 m
.57065 1.05666 L
s
.56106 1.03558 m
.55882 1.04667 L
s
1 .72 0 r
.44118 1.04667 m
.42935 1.05666 L
s
.44118 1.04667 m
.43894 1.03558 L
s
1 .36 0 r
.47309 1.00146 m
.46128 1.01233 L
s
.47309 1.00146 m
.46705 .96633 L
s
1 0 0 r
.65708 .48455 m
.65405 .46933 L
s
.65708 .48455 m
.69541 .48849 L
s
0 .4 1 r
.48108 .90988 m
.47792 .8935 L
s
.48108 .90988 m
.5 .92257 L
s
1 .72 0 r
.51892 .90988 m
.52208 .8935 L
s
.5 .92257 m
.51892 .90988 L
s
1 0 0 r
.78109 .57337 m
.79 .56436 L
s
.75616 .54788 m
.78109 .57337 L
s
.92 1 0 r
.52048 .79934 m
.53098 .77595 L
s
0 .76 1 r
.47952 .79934 m
.46902 .77595 L
s
1 0 0 r
.74978 .55949 m
.75616 .54788 L
s
.72336 .54252 m
.74978 .55949 L
s
.92 1 0 r
.3871 1.09589 m
.39052 1.10216 L
s
.39052 1.10216 m
.3618 1.12113 L
s
0 .76 1 r
.6129 1.09589 m
.60948 1.10216 L
s
.6382 1.12113 m
.60948 1.10216 L
s
1 0 0 r
.72336 .54252 m
.72677 .52896 L
s
0 .76 1 r
.50383 .94254 m
.49164 .93301 L
s
.49164 .93301 m
.4966 .89494 L
s
.92 1 0 r
.49617 .94254 m
.50836 .93301 L
s
.5034 .89494 m
.50836 .93301 L
s
1 0 0 r
.83219 .58558 m
.84301 .57962 L
s
.80789 .54668 m
.83219 .58558 L
s
0 .4 1 r
.46844 .83844 m
.4653 .81746 L
s
.4653 .81746 m
.5 .84923 L
s
1 .72 0 r
.53156 .83844 m
.5347 .81746 L
s
.5 .84923 m
.5347 .81746 L
s
0 .4 1 r
.50946 .96845 m
.51264 .95945 L
s
.50946 .96845 m
.5183 .97837 L
s
1 .72 0 r
.49054 .96845 m
.48736 .95945 L
s
.4817 .97837 m
.49054 .96845 L
s
1 0 0 r
.69501 .51783 m
.6952 .50307 L
s
.69501 .51783 m
.72677 .52896 L
s
0 .76 1 r
.55357 1.02375 m
.5429 1.02153 L
s
.5429 1.02153 m
.53201 .9911 L
s
.92 1 0 r
.44643 1.02375 m
.4571 1.02153 L
s
.46799 .9911 m
.4571 1.02153 L
s
0 .4 1 r
.47792 .8935 m
.47475 .87625 L
s
.47792 .8935 m
.5 .90917 L
s
1 .72 0 r
.52208 .8935 m
.52525 .87625 L
s
.5 .90917 m
.52208 .8935 L
s
0 .4 1 r
.53532 1.01028 m
.54719 1.01582 L
s
.53169 1.00009 m
.53532 1.01028 L
s
1 .72 0 r
.46468 1.01028 m
.45281 1.01582 L
s
.46468 1.01028 m
.46831 1.00009 L
s
0 .76 1 r
.6382 1.12113 m
.6379 1.12912 L
s
.67013 1.14399 m
.6379 1.12912 L
s
.92 1 0 r
.3618 1.12113 m
.3621 1.12912 L
s
.3621 1.12912 m
.32987 1.14399 L
s
1 0 0 r
.53019 .7842 m
.51847 .80333 L
s
0 .4 1 r
.5 .94811 m
.5 .93553 L
s
.5 .94811 m
.51264 .95945 L
s
1 .72 0 r
.48736 .95945 m
.5 .94811 L
s
1 .36 0 r
.53235 .83725 m
.52184 .8381 L
s
.52018 .88745 m
.53235 .83725 L
s
0 .76 1 r
.53201 .9911 m
.52017 .98536 L
s
.52017 .98536 m
.51607 .95241 L
s
.92 1 0 r
.46799 .9911 m
.47983 .98536 L
s
.48393 .95241 m
.47983 .98536 L
s
0 .4 1 r
.57065 1.05666 m
.5825 1.06651 L
s
.57339 1.04385 m
.57065 1.05666 L
s
1 .72 0 r
.42935 1.05666 m
.4175 1.06651 L
s
.42935 1.05666 m
.42661 1.04385 L
s
1 0 0 r
.65405 .46933 m
.65101 .45428 L
s
.65405 .46933 m
.69563 .47407 L
s
0 .4 1 r
.4716 .85796 m
.46844 .83844 L
s
.46844 .83844 m
.5 .86547 L
s
1 .72 0 r
.5284 .85796 m
.53156 .83844 L
s
.5 .86547 m
.53156 .83844 L
s
0 .4 1 r
.47475 .87625 m
.4716 .85796 L
s
.47475 .87625 m
.5 .89527 L
s
1 .72 0 r
.52525 .87625 m
.5284 .85796 L
s
.5 .89527 m
.52525 .87625 L
s
.92 1 0 r
.32702 1.15298 m
.32419 1.16192 L
s
.32419 1.16192 m
.28759 1.17169 L
s
0 .76 1 r
.67298 1.15298 m
.67581 1.16192 L
s
.71241 1.17169 m
.67581 1.16192 L
s
1 0 0 r
.52614 .8712 m
.50669 .82448 L
s
0 .4 1 r
.54877 1.02736 m
.56106 1.03558 L
s
.54719 1.01582 m
.54877 1.02736 L
s
1 .72 0 r
.45123 1.02736 m
.43894 1.03558 L
s
.45123 1.02736 m
.45281 1.01582 L
s
0 .4 1 r
.4716 .85796 m
.5 .88075 L
s
1 .72 0 r
.5 .88075 m
.5284 .85796 L
s
0 .76 1 r
.48481 .88007 m
.47306 .86554 L
s
.47306 .86554 m
.49007 .82341 L
s
.92 1 0 r
.51519 .88007 m
.52694 .86554 L
s
.50993 .82341 m
.52694 .86554 L
s
1 .36 0 r
.50383 .93652 m
.49162 .94618 L
s
.50383 .93652 m
.50842 .89398 L
s
.46128 1.01233 m
.44945 1.02309 L
s
.46128 1.01233 m
.4547 .97664 L
s
1 0 0 r
.79 .56436 m
.79893 .55546 L
s
.76256 .53644 m
.79 .56436 L
s
.84301 .57962 m
.85386 .57372 L
s
.81688 .538 m
.84301 .57962 L
s
0 .4 1 r
.5183 .97837 m
.52445 .9732 L
s
.5183 .97837 m
.52588 .98921 L
s
1 .72 0 r
.4817 .97837 m
.47555 .9732 L
s
.47412 .98921 m
.4817 .97837 L
s
0 .76 1 r
.72981 1.1992 m
.73558 1.20819 L
s
.77867 1.21053 m
.73558 1.20819 L
s
.92 1 0 r
.27019 1.1992 m
.26442 1.20819 L
s
.26442 1.20819 m
.22133 1.21053 L
s
0 .4 1 r
.53169 1.00009 m
.54235 1.00245 L
s
.52588 .98921 m
.53169 1.00009 L
s
1 .72 0 r
.46831 1.00009 m
.45765 1.00245 L
s
.46831 1.00009 m
.47412 .98921 L
s
1 0 0 r
.75616 .54788 m
.76256 .53644 L
s
.72677 .52896 m
.75616 .54788 L
s
1 .36 0 r
.52018 .88745 m
.50842 .89398 L
s
1 0 0 r
.72677 .52896 m
.73019 .51558 L
s
.6952 .50307 m
.69541 .48849 L
s
.6952 .50307 m
.73019 .51558 L
s
0 .4 1 r
.52588 .98921 m
.53459 .98794 L
s
1 .72 0 r
.47412 .98921 m
.46541 .98794 L
s
0 .76 1 r
.59558 1.07081 m
.58924 1.07458 L
s
.58924 1.07458 m
.56903 1.05012 L
s
.6129 1.09589 m
.58924 1.07458 L
s
.92 1 0 r
.40442 1.07081 m
.41076 1.07458 L
s
.41076 1.07458 m
.3871 1.09589 L
s
.43097 1.05012 m
.41076 1.07458 L
s
1 0 0 r
.65101 .45428 m
.64798 .4394 L
s
.65101 .45428 m
.69585 .45983 L
s
0 .4 1 r
.5825 1.06651 m
.59437 1.07622 L
s
.58576 1.05211 m
.5825 1.06651 L
s
1 .72 0 r
.4175 1.06651 m
.40563 1.07622 L
s
.4175 1.06651 m
.41424 1.05211 L
s
0 .76 1 r
.57785 1.04927 m
.56903 1.05012 L
s
.56903 1.05012 m
.55357 1.02375 L
s
.92 1 0 r
.42215 1.04927 m
.43097 1.05012 L
s
.44643 1.02375 m
.43097 1.05012 L
s
1 0 0 r
.85386 .57372 m
.86473 .56788 L
s
.82589 .52941 m
.85386 .57372 L
s
0 .4 1 r
.5 .93553 m
.5 .92257 L
s
.5 .93553 m
.51583 .9505 L
s
1 .72 0 r
.48417 .9505 m
.5 .93553 L
s
1 .36 0 r
.44945 1.02309 m
.44229 .98699 L
s
1 0 0 r
.79893 .55546 m
.80789 .54668 L
s
.76899 .52514 m
.79893 .55546 L
s
0 .76 1 r
.51607 .95241 m
.50383 .94254 L
s
.50383 .94254 m
.50844 .90994 L
s
.92 1 0 r
.48393 .95241 m
.49617 .94254 L
s
.49156 .90994 m
.49617 .94254 L
s
0 .4 1 r
.51264 .95945 m
.51583 .9505 L
s
.51264 .95945 m
.52445 .9732 L
s
1 .72 0 r
.48736 .95945 m
.48417 .9505 L
s
.47555 .9732 m
.48736 .95945 L
s
1 0 0 r
.64798 .4394 m
.64495 .4247 L
s
.64798 .4394 m
.69608 .44574 L
s
.76256 .53644 m
.76899 .52514 L
s
.73019 .51558 m
.76256 .53644 L
s
0 .4 1 r
.56106 1.03558 m
.57339 1.04385 L
s
.55911 1.02161 m
.56106 1.03558 L
s
1 .72 0 r
.43894 1.03558 m
.42661 1.04385 L
s
.43894 1.03558 m
.44089 1.02161 L
s
.40563 1.07622 m
.39374 1.08578 L
s
.40563 1.07622 m
.40184 1.06034 L
s
0 .4 1 r
.59437 1.07622 m
.60626 1.08578 L
s
.59816 1.06034 m
.59437 1.07622 L
s
1 0 0 r
.69541 .48849 m
.69563 .47407 L
s
.69541 .48849 m
.73363 .50236 L
s
0 .4 1 r
.54719 1.01582 m
.55911 1.02161 L
s
.54235 1.00245 m
.54719 1.01582 L
s
1 .72 0 r
.45281 1.01582 m
.44089 1.02161 L
s
.45281 1.01582 m
.45765 1.00245 L
s
1 0 0 r
.73019 .51558 m
.73363 .50236 L
s
0 .76 1 r
.61634 1.08975 m
.6129 1.09589 L
s
.6385 1.11317 m
.6129 1.09589 L
s
.92 1 0 r
.38366 1.08975 m
.3871 1.09589 L
s
.3871 1.09589 m
.3615 1.11317 L
s
0 .76 1 r
.6385 1.11317 m
.6382 1.12113 L
s
.66727 1.13495 m
.6382 1.12113 L
s
.92 1 0 r
.3615 1.11317 m
.3618 1.12113 L
s
.3618 1.12113 m
.33273 1.13495 L
s
0 .76 1 r
.72403 1.19012 m
.72981 1.1992 L
s
.77022 1.20171 m
.72981 1.1992 L
s
.92 1 0 r
.27597 1.19012 m
.27019 1.1992 L
s
.27019 1.1992 m
.22978 1.20171 L
s
0 .76 1 r
.67013 1.14399 m
.67298 1.15298 L
s
.70657 1.16234 m
.67298 1.15298 L
s
.92 1 0 r
.32987 1.14399 m
.32702 1.15298 L
s
.32702 1.15298 m
.29343 1.16234 L
s
0 .76 1 r
.56431 1.02632 m
.55357 1.02375 L
s
.55357 1.02375 m
.54391 .99719 L
s
.92 1 0 r
.43569 1.02632 m
.44643 1.02375 L
s
.45609 .99719 m
.44643 1.02375 L
s
0 .76 1 r
.54391 .99719 m
.53201 .9911 L
s
.53201 .9911 m
.52836 .96252 L
s
.92 1 0 r
.45609 .99719 m
.46799 .9911 L
s
.47164 .96252 m
.46799 .9911 L
s
1 0 0 r
.83493 .52091 m
.86473 .56788 L
s
1 .36 0 r
.52184 .8381 m
.51128 .84056 L
s
.50842 .89398 m
.52184 .8381 L
s
0 .76 1 r
.4966 .89494 m
.48481 .88007 L
s
.48481 .88007 m
.50068 .84701 L
s
.92 1 0 r
.5034 .89494 m
.51519 .88007 L
s
.49932 .84701 m
.51519 .88007 L
s
0 .76 1 r
.49007 .82341 m
.47952 .79934 L
s
.47952 .79934 m
.50873 .79276 L
s
.92 1 0 r
.50993 .82341 m
.52048 .79934 L
s
.49127 .79276 m
.52048 .79934 L
s
1 .36 0 r
.49162 .94618 m
.47936 .95615 L
s
.49162 .94618 m
.4966 .90151 L
s
1 0 0 r
.80789 .54668 m
.81688 .538 L
s
.77544 .51398 m
.80789 .54668 L
s
0 .4 1 r
.5 .92257 m
.5 .90917 L
s
.5 .92257 m
.51904 .94165 L
s
1 .72 0 r
.48096 .94165 m
.5 .92257 L
s
1 0 0 r
.64495 .4247 m
.69632 .4318 L
s
1 .72 0 r
.39374 1.08578 m
.38184 1.09518 L
s
.39374 1.08578 m
.3894 1.06853 L
s
0 .4 1 r
.60626 1.08578 m
.61816 1.09518 L
s
.6106 1.06853 m
.60626 1.08578 L
s
1 0 0 r
.51847 .80333 m
.50669 .82448 L
s
0 .4 1 r
.52445 .9732 m
.53063 .96839 L
s
.52445 .9732 m
.53459 .98794 L
s
1 .72 0 r
.47555 .9732 m
.46937 .96839 L
s
.46541 .98794 m
.47555 .9732 L
s
1 .36 0 r
.50842 .89398 m
.4966 .90151 L
s
0 .4 1 r
.54235 1.00245 m
.55307 1.00523 L
s
.53459 .98794 m
.54235 1.00245 L
s
1 .72 0 r
.45765 1.00245 m
.44693 1.00523 L
s
.45765 1.00245 m
.46541 .98794 L
s
1 0 0 r
.69563 .47407 m
.69585 .45983 L
s
.69563 .47407 m
.73709 .4893 L
s
.76899 .52514 m
.77544 .51398 L
s
.73363 .50236 m
.76899 .52514 L
s
.73363 .50236 m
.73709 .4893 L
s
0 .4 1 r
.53459 .98794 m
.54335 .98714 L
s
1 .72 0 r
.46541 .98794 m
.45665 .98714 L
s
0 .4 1 r
.57339 1.04385 m
.58576 1.05211 L
s
.57108 1.02761 m
.57339 1.04385 L
s
1 .72 0 r
.42661 1.04385 m
.41424 1.05211 L
s
.42661 1.04385 m
.42892 1.02761 L
s
0 .76 1 r
.60195 1.06728 m
.59558 1.07081 L
s
.59558 1.07081 m
.57785 1.04927 L
s
.61634 1.08975 m
.59558 1.07081 L
s
.92 1 0 r
.39805 1.06728 m
.40442 1.07081 L
s
.40442 1.07081 m
.38366 1.08975 L
s
.42215 1.04927 m
.40442 1.07081 L
s
0 .76 1 r
.58672 1.04873 m
.57785 1.04927 L
s
.57785 1.04927 m
.56431 1.02632 L
s
.92 1 0 r
.41328 1.04873 m
.42215 1.04927 L
s
.43569 1.02632 m
.42215 1.04927 L
s
0 .76 1 r
.52836 .96252 m
.51607 .95241 L
s
.51607 .95241 m
.52033 .92486 L
s
.92 1 0 r
.47164 .96252 m
.48393 .95241 L
s
.47967 .92486 m
.48393 .95241 L
s
.28177 1.18095 m
.27597 1.19012 L
s
.27597 1.19012 m
.23825 1.19278 L
s
0 .76 1 r
.71823 1.18095 m
.72403 1.19012 L
s
.76175 1.19278 m
.72403 1.19012 L
s
0 .4 1 r
.61816 1.09518 m
.63008 1.10443 L
s
.62308 1.07664 m
.61816 1.09518 L
s
1 .72 0 r
.38184 1.09518 m
.36992 1.10443 L
s
.38184 1.09518 m
.37692 1.07664 L
s
0 .4 1 r
.51583 .9505 m
.51904 .94165 L
s
.51583 .9505 m
.53063 .96839 L
s
1 .72 0 r
.48417 .9505 m
.48096 .94165 L
s
.46937 .96839 m
.48417 .9505 L
s
1 0 0 r
.81688 .538 m
.82589 .52941 L
s
.78191 .50295 m
.81688 .538 L
s
0 .4 1 r
.5 .90917 m
.5 .89527 L
s
.5 .90917 m
.52225 .93295 L
s
1 .72 0 r
.47775 .93295 m
.5 .90917 L
s
0 .76 1 r
.66727 1.13495 m
.67013 1.14399 L
s
.70071 1.15289 m
.67013 1.14399 L
s
.92 1 0 r
.33273 1.13495 m
.32987 1.14399 L
s
.32987 1.14399 m
.29929 1.15289 L
s
0 .4 1 r
.55911 1.02161 m
.57108 1.02761 L
s
.55307 1.00523 m
.55911 1.02161 L
s
1 .72 0 r
.44089 1.02161 m
.42892 1.02761 L
s
.44089 1.02161 m
.44693 1.00523 L
s
0 .76 1 r
.50844 .90994 m
.4966 .89494 L
s
.4966 .89494 m
.51135 .86938 L
s
.92 1 0 r
.49156 .90994 m
.5034 .89494 L
s
.48865 .86938 m
.5034 .89494 L
s
1 0 0 r
.69585 .45983 m
.69608 .44574 L
s
.69585 .45983 m
.74057 .47639 L
s
1 .36 0 r
.47936 .95615 m
.46705 .96633 L
s
.47936 .95615 m
.48472 .91 L
s
1 0 0 r
.77544 .51398 m
.78191 .50295 L
s
.73709 .4893 m
.77544 .51398 L
s
.92 1 0 r
.36119 1.10525 m
.3615 1.11317 L
s
.3615 1.11317 m
.33559 1.12586 L
s
0 .76 1 r
.63881 1.10525 m
.6385 1.11317 L
s
.66441 1.12586 m
.6385 1.11317 L
s
.55585 1.00357 m
.54391 .99719 L
s
.54391 .99719 m
.5407 .97279 L
s
.92 1 0 r
.44415 1.00357 m
.45609 .99719 L
s
.4593 .97279 m
.45609 .99719 L
s
1 .72 0 r
.36992 1.10443 m
.35798 1.11352 L
s
.36992 1.10443 m
.36441 1.08466 L
s
0 .4 1 r
.63008 1.10443 m
.64202 1.11352 L
s
.63559 1.08466 m
.63008 1.10443 L
s
1 0 0 r
.73709 .4893 m
.74057 .47639 L
s
0 .76 1 r
.6198 1.08376 m
.61634 1.08975 L
s
.63881 1.10525 m
.61634 1.08975 L
s
.92 1 0 r
.3802 1.08376 m
.38366 1.08975 L
s
.38366 1.08975 m
.36119 1.10525 L
s
0 .76 1 r
.57509 1.02922 m
.56431 1.02632 L
s
.56431 1.02632 m
.55585 1.00357 L
s
.92 1 0 r
.42491 1.02922 m
.43569 1.02632 L
s
.44415 1.00357 m
.43569 1.02632 L
s
1 .36 0 r
.51128 .84056 m
.50068 .84515 L
s
.4966 .90151 m
.51128 .84056 L
s
1 0 0 r
.82589 .52941 m
.83493 .52091 L
s
.78842 .49203 m
.82589 .52941 L
s
0 .76 1 r
.71241 1.17169 m
.71823 1.18095 L
s
.75325 1.18373 m
.71823 1.18095 L
s
.92 1 0 r
.28759 1.17169 m
.28177 1.18095 L
s
.28177 1.18095 m
.24675 1.18373 L
s
0 .4 1 r
.58576 1.05211 m
.59816 1.06034 L
s
.58311 1.03381 m
.58576 1.05211 L
s
1 .72 0 r
.41424 1.05211 m
.40184 1.06034 L
s
.41424 1.05211 m
.41689 1.03381 L
s
0 .4 1 r
.5 .89527 m
.5 .88075 L
s
.5 .89527 m
.52549 .9245 L
s
1 .72 0 r
.47451 .9245 m
.5 .89527 L
s
.35798 1.11352 m
.34604 1.12245 L
s
.35798 1.11352 m
.35186 1.09258 L
s
0 .4 1 r
.64202 1.11352 m
.65396 1.12245 L
s
.64814 1.09258 m
.64202 1.11352 L
s
0 .76 1 r
.50068 .84701 m
.49007 .82341 L
s
.49007 .82341 m
.51754 .82855 L
s
.92 1 0 r
.49932 .84701 m
.50993 .82341 L
s
.48246 .82855 m
.50993 .82341 L
s
0 .4 1 r
.53063 .96839 m
.53685 .96402 L
s
.53063 .96839 m
.54335 .98714 L
s
1 .72 0 r
.46937 .96839 m
.46315 .96402 L
s
.45665 .98714 m
.46937 .96839 L
s
1 0 0 r
.69608 .44574 m
.69632 .4318 L
s
.69608 .44574 m
.74407 .46362 L
s
0 .4 1 r
.55307 1.00523 m
.56384 1.00842 L
s
.54335 .98714 m
.55307 1.00523 L
s
1 .72 0 r
.44693 1.00523 m
.43616 1.00842 L
s
.44693 1.00523 m
.45665 .98714 L
s
1 .36 0 r
.4966 .90151 m
.48472 .91 L
s
0 .76 1 r
.5407 .97279 m
.52836 .96252 L
s
.52836 .96252 m
.53226 .93954 L
s
.92 1 0 r
.4593 .97279 m
.47164 .96252 L
s
.46774 .93954 m
.47164 .96252 L
s
1 0 0 r
.78191 .50295 m
.78842 .49203 L
s
.74057 .47639 m
.78191 .50295 L
s
0 .4 1 r
.51904 .94165 m
.52225 .93295 L
s
.51904 .94165 m
.53685 .96402 L
s
1 .72 0 r
.48096 .94165 m
.47775 .93295 L
s
.46315 .96402 m
.48096 .94165 L
s
0 .4 1 r
.5 .78983 m
.5 .76108 L
s
.5 .76108 m
.54878 .89559 L
s
1 .72 0 r
.45122 .89559 m
.5 .76108 L
s
1 0 0 r
.74057 .47639 m
.74407 .46362 L
s
0 .76 1 r
.66441 1.12586 m
.66727 1.13495 L
s
.69484 1.14334 m
.66727 1.13495 L
s
.92 1 0 r
.33559 1.12586 m
.33273 1.13495 L
s
.33273 1.13495 m
.30516 1.14334 L
s
0 .4 1 r
.65396 1.12245 m
.66592 1.13122 L
s
.66072 1.10039 m
.65396 1.12245 L
s
1 .72 0 r
.34604 1.12245 m
.33408 1.13122 L
s
.34604 1.12245 m
.33928 1.10039 L
s
0 .4 1 r
.54335 .98714 m
.55216 .98688 L
s
1 .72 0 r
.45665 .98714 m
.44784 .98688 L
s
1 0 0 r
.79494 .48122 m
.83493 .52091 L
s
0 .76 1 r
.60836 1.06402 m
.60195 1.06728 L
s
.60195 1.06728 m
.58672 1.04873 L
s
.6198 1.08376 m
.60195 1.06728 L
s
.92 1 0 r
.39164 1.06402 m
.39805 1.06728 L
s
.39805 1.06728 m
.3802 1.08376 L
s
.41328 1.04873 m
.39805 1.06728 L
s
0 .4 1 r
.5 .88075 m
.5 .86547 L
s
.5 .88075 m
.52873 .91644 L
s
1 .72 0 r
.47127 .91644 m
.5 .88075 L
s
0 .76 1 r
.59564 1.04853 m
.58672 1.04873 L
s
.58672 1.04873 m
.57509 1.02922 L
s
.92 1 0 r
.40436 1.04853 m
.41328 1.04873 L
s
.42491 1.02922 m
.41328 1.04873 L
s
0 .76 1 r
.52033 .92486 m
.50844 .90994 L
s
.50844 .90994 m
.52206 .89026 L
s
.92 1 0 r
.47967 .92486 m
.49156 .90994 L
s
.47794 .89026 m
.49156 .90994 L
s
0 .4 1 r
.57108 1.02761 m
.58311 1.03381 L
s
.56384 1.00842 m
.57108 1.02761 L
s
1 .72 0 r
.42892 1.02761 m
.41689 1.03381 L
s
.42892 1.02761 m
.43616 1.00842 L
s
1 .36 0 r
.46705 .96633 m
.4547 .97664 L
s
.46705 .96633 m
.47277 .91936 L
s
0 .76 1 r
.70657 1.16234 m
.71241 1.17169 L
s
.74474 1.17457 m
.71241 1.17169 L
s
.92 1 0 r
.29343 1.16234 m
.28759 1.17169 L
s
.28759 1.17169 m
.25526 1.17457 L
s
0 .76 1 r
.63912 1.09738 m
.63881 1.10525 L
s
.66153 1.11674 m
.63881 1.10525 L
s
.92 1 0 r
.36088 1.09738 m
.36119 1.10525 L
s
.36119 1.10525 m
.33847 1.11674 L
s
0 .76 1 r
.56786 1.0102 m
.55585 1.00357 L
s
.55585 1.00357 m
.55308 .98314 L
s
.92 1 0 r
.43214 1.0102 m
.44415 1.00357 L
s
.44692 .98314 m
.44415 1.00357 L
s
0 .4 1 r
.66592 1.13122 m
.67789 1.13984 L
s
.67334 1.10807 m
.66592 1.13122 L
s
1 .72 0 r
.33408 1.13122 m
.32211 1.13984 L
s
.33408 1.13122 m
.32666 1.10807 L
s
1 0 0 r
.69632 .4318 m
.74758 .45098 L
s
0 .4 1 r
.59816 1.06034 m
.6106 1.06853 L
s
.59519 1.04014 m
.59816 1.06034 L
s
1 .72 0 r
.40184 1.06034 m
.3894 1.06853 L
s
.40184 1.06034 m
.40481 1.04014 L
s
1 0 0 r
.78842 .49203 m
.79494 .48122 L
s
.74407 .46362 m
.78842 .49203 L
s
0 .4 1 r
.5 .86547 m
.5 .84923 L
s
.5 .86547 m
.532 .90898 L
s
1 .72 0 r
.468 .90898 m
.5 .86547 L
s
0 .76 1 r
.62329 1.07795 m
.6198 1.08376 L
s
.63912 1.09738 m
.6198 1.08376 L
s
.92 1 0 r
.37671 1.07795 m
.3802 1.08376 L
s
.3802 1.08376 m
.36088 1.09738 L
s
0 .76 1 r
.58594 1.03245 m
.57509 1.02922 L
s
.57509 1.02922 m
.56786 1.0102 L
s
.92 1 0 r
.41406 1.03245 m
.42491 1.02922 L
s
.43214 1.0102 m
.42491 1.02922 L
s
1 0 0 r
.74407 .46362 m
.74758 .45098 L
s
0 .4 1 r
.67789 1.13984 m
.68987 1.14831 L
s
.68598 1.11563 m
.67789 1.13984 L
s
1 .72 0 r
.32211 1.13984 m
.31013 1.14831 L
s
.32211 1.13984 m
.31402 1.11563 L
s
0 .76 1 r
.55308 .98314 m
.5407 .97279 L
s
.5407 .97279 m
.54423 .95386 L
s
.92 1 0 r
.44692 .98314 m
.4593 .97279 L
s
.45577 .95386 m
.4593 .97279 L
s
0 .4 1 r
.5 .81229 m
.5 .78983 L
s
.5 .78983 m
.54534 .89312 L
s
1 .72 0 r
.45466 .89312 m
.5 .78983 L
s
1 .36 0 r
.50068 .84515 m
.49001 .85244 L
s
.48472 .91 m
.50068 .84515 L
s
0 .4 1 r
.5 .84923 m
.5 .8317 L
s
.5 .84923 m
.53528 .9024 L
s
1 .72 0 r
.46472 .9024 m
.5 .84923 L
s
0 .4 1 r
.52225 .93295 m
.52549 .9245 L
s
.52225 .93295 m
.5431 .96019 L
s
1 .72 0 r
.47775 .93295 m
.47451 .9245 L
s
.4569 .96019 m
.47775 .93295 L
s
0 .76 1 r
.66153 1.11674 m
.66441 1.12586 L
s
.68894 1.1337 m
.66441 1.12586 L
s
.92 1 0 r
.33847 1.11674 m
.33559 1.12586 L
s
.33559 1.12586 m
.31106 1.1337 L
s
0 .4 1 r
.53685 .96402 m
.5431 .96019 L
s
.53685 .96402 m
.55216 .98688 L
s
1 .72 0 r
.46315 .96402 m
.4569 .96019 L
s
.44784 .98688 m
.46315 .96402 L
s
0 .4 1 r
.69866 1.12305 m
.68987 1.14831 L
s
1 .72 0 r
.31013 1.14831 m
.30134 1.12305 L
s
0 .76 1 r
.51135 .86938 m
.50068 .84701 L
s
.50068 .84701 m
.52638 .85541 L
s
.92 1 0 r
.48865 .86938 m
.49932 .84701 L
s
.47362 .85541 m
.49932 .84701 L
s
0 .76 1 r
.70071 1.15289 m
.70657 1.16234 L
s
.7362 1.16529 m
.70657 1.16234 L
s
.92 1 0 r
.29929 1.15289 m
.29343 1.16234 L
s
.29343 1.16234 m
.2638 1.16529 L
s
0 .4 1 r
.56384 1.00842 m
.57468 1.012 L
s
.55216 .98688 m
.56384 1.00842 L
s
1 .72 0 r
.43616 1.00842 m
.42532 1.012 L
s
.43616 1.00842 m
.44784 .98688 L
s
0 .4 1 r
.5 .8317 m
.5 .81229 L
s
.5 .8317 m
.5386 .89716 L
s
1 .72 0 r
.4614 .89716 m
.5 .8317 L
s
0 .76 1 r
.53226 .93954 m
.52033 .92486 L
s
.52033 .92486 m
.53281 .90966 L
s
.92 1 0 r
.46774 .93954 m
.47967 .92486 L
s
.46719 .90966 m
.47967 .92486 L
s
1 .72 0 r
.45806 .89383 m
.5 .81229 L
s
0 .4 1 r
.5 .81229 m
.54194 .89383 L
s
1 .36 0 r
.48472 .91 m
.47277 .91936 L
s
0 .4 1 r
.6106 1.06853 m
.62308 1.07664 L
s
.60732 1.04658 m
.6106 1.06853 L
s
1 .72 0 r
.3894 1.06853 m
.37692 1.07664 L
s
.3894 1.06853 m
.39268 1.04658 L
s
1 0 0 r
.74758 .45098 m
.79494 .48122 L
s
1 .36 0 r
.4547 .97664 m
.44229 .98699 L
s
.4547 .97664 m
.46075 .9294 L
s
0 .4 1 r
.58311 1.03381 m
.59519 1.04014 L
s
.57468 1.012 m
.58311 1.03381 L
s
1 .72 0 r
.41689 1.03381 m
.40481 1.04014 L
s
.41689 1.03381 m
.42532 1.012 L
s
0 .4 1 r
.55216 .98688 m
.56102 .98717 L
s
1 .72 0 r
.44784 .98688 m
.43898 .98717 L
s
0 .76 1 r
.61482 1.06105 m
.60836 1.06402 L
s
.60836 1.06402 m
.59564 1.04853 L
s
.62329 1.07795 m
.60836 1.06402 L
s
.92 1 0 r
.38518 1.06105 m
.39164 1.06402 L
s
.39164 1.06402 m
.37671 1.07795 L
s
.40436 1.04853 m
.39164 1.06402 L
s
0 .76 1 r
.60461 1.04865 m
.59564 1.04853 L
s
.59564 1.04853 m
.58594 1.03245 L
s
.92 1 0 r
.39539 1.04865 m
.40436 1.04853 L
s
.41406 1.03245 m
.40436 1.04853 L
s
0 .76 1 r
.63943 1.08959 m
.63912 1.09738 L
s
.65864 1.10759 m
.63912 1.09738 L
s
.92 1 0 r
.36057 1.08959 m
.36088 1.09738 L
s
.36088 1.09738 m
.34136 1.10759 L
s
0 .76 1 r
.57992 1.01703 m
.56786 1.0102 L
s
.56786 1.0102 m
.56552 .99347 L
s
.92 1 0 r
.42008 1.01703 m
.43214 1.0102 L
s
.43448 .99347 m
.43214 1.0102 L
s
0 .76 1 r
.69484 1.14334 m
.70071 1.15289 L
s
.72765 1.15587 m
.70071 1.15289 L
s
.92 1 0 r
.30516 1.14334 m
.29929 1.15289 L
s
.29929 1.15289 m
.27235 1.15587 L
s
0 .76 1 r
.62679 1.07234 m
.62329 1.07795 L
s
.63943 1.08959 m
.62329 1.07795 L
s
.92 1 0 r
.37321 1.07234 m
.37671 1.07795 L
s
.37671 1.07795 m
.36057 1.08959 L
s
0 .76 1 r
.56552 .99347 m
.55308 .98314 L
s
.55308 .98314 m
.55624 .96775 L
s
.92 1 0 r
.43448 .99347 m
.44692 .98314 L
s
.44376 .96775 m
.44692 .98314 L
s
0 .76 1 r
.59684 1.03598 m
.58594 1.03245 L
s
.58594 1.03245 m
.57992 1.01703 L
s
.92 1 0 r
.40316 1.03598 m
.41406 1.03245 L
s
.42008 1.01703 m
.41406 1.03245 L
s
0 .76 1 r
.65864 1.10759 m
.66153 1.11674 L
s
.68302 1.12394 m
.66153 1.11674 L
s
.92 1 0 r
.34136 1.10759 m
.33847 1.11674 L
s
.33847 1.11674 m
.31698 1.12394 L
s
0 .4 1 r
.62308 1.07664 m
.63559 1.08466 L
s
.61951 1.05309 m
.62308 1.07664 L
s
1 .72 0 r
.37692 1.07664 m
.36441 1.08466 L
s
.37692 1.07664 m
.38049 1.05309 L
s
0 .4 1 r
.52549 .9245 m
.52873 .91644 L
s
.52549 .9245 m
.54939 .95699 L
s
1 .72 0 r
.47451 .9245 m
.47127 .91644 L
s
.45061 .95699 m
.47451 .9245 L
s
0 .76 1 r
.54423 .95386 m
.53226 .93954 L
s
.53226 .93954 m
.54359 .92771 L
s
.92 1 0 r
.45577 .95386 m
.46774 .93954 L
s
.45641 .92771 m
.46774 .93954 L
s
0 1 .88 r
.51868 .86019 m
.50671 .8446 L
s
.5264 .92218 m
.50671 .8446 L
s
.56 1 0 r
.48132 .86019 m
.49329 .8446 L
s
.49329 .8446 m
.4736 .92218 L
s
1 .36 0 r
.44229 .98699 m
.44866 .93994 L
s
0 1 .88 r
.5666 .98765 m
.55771 .98699 L
s
.55771 .98699 m
.5264 .92218 L
s
.59861 1.04195 m
.55771 .98699 L
s
.56 1 0 r
.4334 .98765 m
.44229 .98699 L
s
.44229 .98699 m
.40139 1.04195 L
s
.4736 .92218 m
.44229 .98699 L
s
0 .4 1 r
.5431 .96019 m
.54939 .95699 L
s
.5431 .96019 m
.56102 .98717 L
s
1 .72 0 r
.4569 .96019 m
.45061 .95699 L
s
.43898 .98717 m
.4569 .96019 L
s
0 .76 1 r
.77022 1.20171 m
.77867 1.21053 L
s
.81344 1.20475 m
.77867 1.21053 L
s
.92 1 0 r
.22978 1.20171 m
.22133 1.21053 L
s
.22133 1.21053 m
.18656 1.20475 L
s
0 1 .88 r
.53718 .92791 m
.5264 .92218 L
s
.56 1 0 r
.46282 .92791 m
.4736 .92218 L
s
0 .76 1 r
.52206 .89026 m
.51135 .86938 L
s
.51135 .86938 m
.53523 .87796 L
s
.92 1 0 r
.47794 .89026 m
.48865 .86938 L
s
.46477 .87796 m
.48865 .86938 L
s
0 .4 1 r
.59519 1.04014 m
.60732 1.04658 L
s
.58557 1.01594 m
.59519 1.04014 L
s
1 .72 0 r
.40481 1.04014 m
.39268 1.04658 L
s
.40481 1.04014 m
.41443 1.01594 L
s
0 .4 1 r
.57468 1.012 m
.58557 1.01594 L
s
.56102 .98717 m
.57468 1.012 L
s
1 .72 0 r
.42532 1.012 m
.41443 1.01594 L
s
.42532 1.012 m
.43898 .98717 L
s
0 .76 1 r
.68894 1.1337 m
.69484 1.14334 L
s
.71908 1.14632 m
.69484 1.14334 L
s
.92 1 0 r
.31106 1.1337 m
.30516 1.14334 L
s
.30516 1.14334 m
.28092 1.14632 L
s
1 .36 0 r
.49001 .85244 m
.47926 .86274 L
s
.47277 .91936 m
.49001 .85244 L
s
.47277 .91936 m
.46075 .9294 L
s
0 .76 1 r
.63975 1.08188 m
.63943 1.08959 L
s
.65573 1.0984 m
.63943 1.08959 L
s
.92 1 0 r
.36025 1.08188 m
.36057 1.08959 L
s
.36057 1.08959 m
.34427 1.0984 L
s
0 .76 1 r
.59204 1.02401 m
.57992 1.01703 L
s
.57992 1.01703 m
.578 1.00374 L
s
.92 1 0 r
.40796 1.02401 m
.42008 1.01703 L
s
.422 1.00374 m
.42008 1.01703 L
s
0 1 .88 r
.60506 1.03923 m
.59861 1.04195 L
s
.64655 1.08735 m
.59861 1.04195 L
s
.56 1 0 r
.39494 1.03923 m
.40139 1.04195 L
s
.40139 1.04195 m
.35345 1.08735 L
s
0 .4 1 r
.63559 1.08466 m
.64814 1.09258 L
s
.63175 1.05963 m
.63559 1.08466 L
s
1 .72 0 r
.36441 1.08466 m
.35186 1.09258 L
s
.36441 1.08466 m
.36825 1.05963 L
s
0 .4 1 r
.56102 .98717 m
.56993 .98805 L
s
1 .72 0 r
.43898 .98717 m
.43007 .98805 L
s
0 .76 1 r
.76175 1.19278 m
.77022 1.20171 L
s
.80275 1.19649 m
.77022 1.20171 L
s
.92 1 0 r
.23825 1.19278 m
.22978 1.20171 L
s
.22978 1.20171 m
.19725 1.19649 L
s
0 .76 1 r
.62132 1.05839 m
.61482 1.06105 L
s
.61482 1.06105 m
.60461 1.04865 L
s
.62679 1.07234 m
.61482 1.06105 L
s
.92 1 0 r
.37868 1.05839 m
.38518 1.06105 L
s
.38518 1.06105 m
.37321 1.07234 L
s
.39539 1.04865 m
.38518 1.06105 L
s
0 .76 1 r
.61364 1.04912 m
.60461 1.04865 L
s
.60461 1.04865 m
.59684 1.03598 L
s
.92 1 0 r
.38636 1.04912 m
.39539 1.04865 L
s
.40316 1.03598 m
.39539 1.04865 L
s
0 .76 1 r
.65573 1.0984 m
.65864 1.10759 L
s
.67709 1.11408 m
.65864 1.10759 L
s
.92 1 0 r
.34427 1.0984 m
.34136 1.10759 L
s
.34136 1.10759 m
.32291 1.11408 L
s
0 .76 1 r
.578 1.00374 m
.56552 .99347 L
s
.56552 .99347 m
.56828 .98119 L
s
.92 1 0 r
.422 1.00374 m
.43448 .99347 L
s
.43172 .98119 m
.43448 .99347 L
s
0 .76 1 r
.55624 .96775 m
.54423 .95386 L
s
.54423 .95386 m
.55439 .94459 L
s
.92 1 0 r
.44376 .96775 m
.45577 .95386 L
s
.44561 .94459 m
.45577 .95386 L
s
0 .4 1 r
.52873 .91644 m
.532 .90898 L
s
.52873 .91644 m
.55573 .95456 L
s
1 .72 0 r
.47127 .91644 m
.468 .90898 L
s
.44427 .95456 m
.47127 .91644 L
s
0 .76 1 r
.63033 1.06696 m
.62679 1.07234 L
s
.63975 1.08188 m
.62679 1.07234 L
s
.92 1 0 r
.36967 1.06696 m
.37321 1.07234 L
s
.37321 1.07234 m
.36025 1.08188 L
s
0 .76 1 r
.60781 1.03977 m
.59684 1.03598 L
s
.59684 1.03598 m
.59204 1.02401 L
s
.92 1 0 r
.39219 1.03977 m
.40316 1.03598 L
s
.40796 1.02401 m
.40316 1.03598 L
s
0 .76 1 r
.68302 1.12394 m
.68894 1.1337 L
s
.71049 1.13662 m
.68894 1.1337 L
s
.92 1 0 r
.31698 1.12394 m
.31106 1.1337 L
s
.31106 1.1337 m
.28951 1.13662 L
s
0 .76 1 r
.75325 1.18373 m
.76175 1.19278 L
s
.79205 1.18811 m
.76175 1.19278 L
s
.92 1 0 r
.24675 1.18373 m
.23825 1.19278 L
s
.23825 1.19278 m
.20795 1.18811 L
s
0 .76 1 r
.53281 .90966 m
.52206 .89026 L
s
.52206 .89026 m
.54409 .89787 L
s
.92 1 0 r
.46719 .90966 m
.47794 .89026 L
s
.45591 .89787 m
.47794 .89026 L
s
0 .4 1 r
.64814 1.09258 m
.66072 1.10039 L
s
.64405 1.06617 m
.64814 1.09258 L
s
1 .72 0 r
.35186 1.09258 m
.33928 1.10039 L
s
.35186 1.09258 m
.35595 1.06617 L
s
0 .4 1 r
.60732 1.04658 m
.61951 1.05309 L
s
.59653 1.02022 m
.60732 1.04658 L
s
1 .72 0 r
.39268 1.04658 m
.38049 1.05309 L
s
.39268 1.04658 m
.40347 1.02022 L
s
0 .4 1 r
.54939 .95699 m
.55573 .95456 L
s
.54939 .95699 m
.56993 .98805 L
s
1 .72 0 r
.45061 .95699 m
.44427 .95456 L
s
.43007 .98805 m
.45061 .95699 L
s
0 1 .88 r
.57556 .98891 m
.5666 .98765 L
s
.5666 .98765 m
.53718 .92791 L
s
.60506 1.03923 m
.5666 .98765 L
s
.56 1 0 r
.42444 .98891 m
.4334 .98765 L
s
.4334 .98765 m
.39494 1.03923 L
s
.46282 .92791 m
.4334 .98765 L
s
0 .76 1 r
.74474 1.17457 m
.75325 1.18373 L
s
.78133 1.1796 m
.75325 1.18373 L
s
.92 1 0 r
.25526 1.17457 m
.24675 1.18373 L
s
.24675 1.18373 m
.21867 1.1796 L
s
1 .72 0 r
.41443 1.01594 m
.40347 1.02022 L
s
.41443 1.01594 m
.43007 .98805 L
s
0 .4 1 r
.58557 1.01594 m
.59653 1.02022 L
s
.56993 .98805 m
.58557 1.01594 L
s
0 .76 1 r
.51754 .82855 m
.50873 .79276 L
s
.50873 .79276 m
.54865 .90758 L
s
.92 1 0 r
.48246 .82855 m
.49127 .79276 L
s
.45135 .90758 m
.49127 .79276 L
s
0 .76 1 r
.64007 1.07429 m
.63975 1.08188 L
s
.65282 1.0892 m
.63975 1.08188 L
s
.92 1 0 r
.35993 1.07429 m
.36025 1.08188 L
s
.36025 1.08188 m
.34718 1.0892 L
s
0 .76 1 r
.65282 1.0892 m
.65573 1.0984 L
s
.67113 1.1041 m
.65573 1.0984 L
s
.92 1 0 r
.34718 1.0892 m
.34427 1.0984 L
s
.34427 1.0984 m
.32887 1.1041 L
s
0 1 .88 r
.54803 .93459 m
.53718 .92791 L
s
.53718 .92791 m
.51868 .86019 L
s
.56 1 0 r
.45197 .93459 m
.46282 .92791 L
s
.48132 .86019 m
.46282 .92791 L
s
0 .76 1 r
.60421 1.03109 m
.59204 1.02401 L
s
.59204 1.02401 m
.59053 1.01387 L
s
.92 1 0 r
.39579 1.03109 m
.40796 1.02401 L
s
.40947 1.01387 m
.40796 1.02401 L
s
0 .76 1 r
.56828 .98119 m
.55624 .96775 L
s
.55624 .96775 m
.56521 .96046 L
s
.92 1 0 r
.43172 .98119 m
.44376 .96775 L
s
.43479 .96046 m
.44376 .96775 L
s
0 .76 1 r
.59053 1.01387 m
.578 1.00374 L
s
.578 1.00374 m
.58035 .99416 L
s
.92 1 0 r
.40947 1.01387 m
.422 1.00374 L
s
.41965 .99416 m
.422 1.00374 L
s
0 .76 1 r
.67709 1.11408 m
.68302 1.12394 L
s
.70187 1.12677 m
.68302 1.12394 L
s
.92 1 0 r
.32291 1.11408 m
.31698 1.12394 L
s
.31698 1.12394 m
.29813 1.12677 L
s
0 1 .88 r
.65015 1.08225 m
.64655 1.08735 L
s
.69866 1.12305 m
.64655 1.08735 L
s
.56 1 0 r
.34985 1.08225 m
.35345 1.08735 L
s
.35345 1.08735 m
.30134 1.12305 L
s
.38845 1.0369 m
.39494 1.03923 L
s
.39494 1.03923 m
.34985 1.08225 L
s
0 1 .88 r
.61155 1.0369 m
.60506 1.03923 L
s
.65015 1.08225 m
.60506 1.03923 L
s
1 .36 0 r
.46075 .9294 m
.44866 .93994 L
s
.46075 .9294 m
.47926 .86274 L
s
0 .76 1 r
.7362 1.16529 m
.74474 1.17457 L
s
.77061 1.17095 m
.74474 1.17457 L
s
.92 1 0 r
.2638 1.16529 m
.25526 1.17457 L
s
.25526 1.17457 m
.22939 1.17095 L
s
0 .76 1 r
.62786 1.05606 m
.62132 1.05839 L
s
.62132 1.05839 m
.61364 1.04912 L
s
.63033 1.06696 m
.62132 1.05839 L
s
.92 1 0 r
.37214 1.05606 m
.37868 1.05839 L
s
.37868 1.05839 m
.36967 1.06696 L
s
.38636 1.04912 m
.37868 1.05839 L
s
0 .76 1 r
.62273 1.04991 m
.61364 1.04912 L
s
.61364 1.04912 m
.60781 1.03977 L
s
.92 1 0 r
.37727 1.04991 m
.38636 1.04912 L
s
.39219 1.03977 m
.38636 1.04912 L
s
0 1 .88 r
.53076 .87733 m
.51868 .86019 L
s
.51868 .86019 m
.51244 .81376 L
s
.56 1 0 r
.46924 .87733 m
.48132 .86019 L
s
.48756 .81376 m
.48132 .86019 L
s
0 .4 1 r
.56993 .98805 m
.57891 .98953 L
s
1 .72 0 r
.43007 .98805 m
.42109 .98953 L
s
0 .4 1 r
.532 .90898 m
.53528 .9024 L
s
.532 .90898 m
.56211 .95301 L
s
1 .72 0 r
.468 .90898 m
.46472 .9024 L
s
.43789 .95301 m
.468 .90898 L
s
0 .4 1 r
.66072 1.10039 m
.67334 1.10807 L
s
.6564 1.07268 m
.66072 1.10039 L
s
1 .72 0 r
.33928 1.10039 m
.32666 1.10807 L
s
.33928 1.10039 m
.3436 1.07268 L
s
0 .76 1 r
.54359 .92771 m
.53281 .90966 L
s
.53281 .90966 m
.55295 .91597 L
s
.92 1 0 r
.45641 .92771 m
.46719 .90966 L
s
.44705 .91597 m
.46719 .90966 L
s
0 .76 1 r
.63388 1.06182 m
.63033 1.06696 L
s
.64007 1.07429 m
.63033 1.06696 L
s
.92 1 0 r
.36612 1.06182 m
.36967 1.06696 L
s
.36967 1.06696 m
.35993 1.07429 L
s
0 .76 1 r
.61883 1.04381 m
.60781 1.03977 L
s
.60781 1.03977 m
.60421 1.03109 L
s
.92 1 0 r
.38117 1.04381 m
.39219 1.03977 L
s
.39579 1.03109 m
.39219 1.03977 L
s
0 .76 1 r
.67113 1.1041 m
.67709 1.11408 L
s
.69324 1.11675 m
.67709 1.11408 L
s
.92 1 0 r
.32887 1.1041 m
.32291 1.11408 L
s
.32291 1.11408 m
.30676 1.11675 L
s
0 .76 1 r
.72765 1.15587 m
.7362 1.16529 L
s
.75987 1.16216 m
.7362 1.16529 L
s
.92 1 0 r
.27235 1.15587 m
.2638 1.16529 L
s
.2638 1.16529 m
.24013 1.16216 L
s
1 .36 0 r
.47926 .86274 m
.4684 .87573 L
s
0 .4 1 r
.61951 1.05309 m
.63175 1.05963 L
s
.60755 1.02478 m
.61951 1.05309 L
s
1 .72 0 r
.38049 1.05309 m
.36825 1.05963 L
s
.38049 1.05309 m
.39245 1.02478 L
s
0 .76 1 r
.58035 .99416 m
.56828 .98119 L
s
.56828 .98119 m
.57603 .97545 L
s
.92 1 0 r
.41965 .99416 m
.43172 .98119 L
s
.42397 .97545 m
.43172 .98119 L
s
0 .76 1 r
.6499 1.07999 m
.65282 1.0892 L
s
.66516 1.09401 m
.65282 1.0892 L
s
.92 1 0 r
.3501 1.07999 m
.34718 1.0892 L
s
.34718 1.0892 m
.33484 1.09401 L
s
0 .76 1 r
.60311 1.02383 m
.59053 1.01387 L
s
.59053 1.01387 m
.59245 1.00666 L
s
.92 1 0 r
.39689 1.02383 m
.40947 1.01387 L
s
.40755 1.00666 m
.40947 1.01387 L
s
0 .76 1 r
.6404 1.06683 m
.64007 1.07429 L
s
.6499 1.07999 m
.64007 1.07429 L
s
.92 1 0 r
.3596 1.06683 m
.35993 1.07429 L
s
.35993 1.07429 m
.3501 1.07999 L
s
0 .4 1 r
.67334 1.10807 m
.68598 1.11563 L
s
.6688 1.07913 m
.67334 1.10807 L
s
1 .72 0 r
.32666 1.10807 m
.31402 1.11563 L
s
.32666 1.10807 m
.3312 1.07913 L
s
0 .76 1 r
.61644 1.03821 m
.60421 1.03109 L
s
.60421 1.03109 m
.60311 1.02383 L
s
.92 1 0 r
.38356 1.03821 m
.39579 1.03109 L
s
.39689 1.02383 m
.39579 1.03109 L
s
0 .76 1 r
.71908 1.14632 m
.72765 1.15587 L
s
.74912 1.15321 m
.72765 1.15587 L
s
.92 1 0 r
.28092 1.14632 m
.27235 1.15587 L
s
.27235 1.15587 m
.25088 1.15321 L
s
0 .4 1 r
.55573 .95456 m
.56211 .95301 L
s
.55573 .95456 m
.57891 .98953 L
s
1 .72 0 r
.44427 .95456 m
.43789 .95301 L
s
.42109 .98953 m
.44427 .95456 L
s
0 .4 1 r
.59653 1.02022 m
.60755 1.02478 L
s
.57891 .98953 m
.59653 1.02022 L
s
1 .72 0 r
.40347 1.02022 m
.39245 1.02478 L
s
.40347 1.02022 m
.42109 .98953 L
s
0 .76 1 r
.55439 .94459 m
.54359 .92771 L
s
.54359 .92771 m
.56181 .93272 L
s
.92 1 0 r
.44561 .94459 m
.45641 .92771 L
s
.43819 .93272 m
.45641 .92771 L
s
0 1 .88 r
.58457 .99076 m
.57556 .98891 L
s
.57556 .98891 m
.54803 .93459 L
s
.61155 1.0369 m
.57556 .98891 L
s
.56 1 0 r
.41543 .99076 m
.42444 .98891 L
s
.42444 .98891 m
.38845 1.0369 L
s
.45197 .93459 m
.42444 .98891 L
s
0 .76 1 r
.66516 1.09401 m
.67113 1.1041 L
s
.68459 1.10655 m
.67113 1.1041 L
s
.92 1 0 r
.33484 1.09401 m
.32887 1.1041 L
s
.32887 1.1041 m
.31541 1.10655 L
s
0 1 .88 r
.65377 1.0774 m
.65015 1.08225 L
s
.69915 1.11634 m
.65015 1.08225 L
s
.56 1 0 r
.34623 1.0774 m
.34985 1.08225 L
s
.34985 1.08225 m
.30085 1.11634 L
s
0 .76 1 r
.59245 1.00666 m
.58035 .99416 L
s
.58035 .99416 m
.58687 .98969 L
s
.92 1 0 r
.40755 1.00666 m
.41965 .99416 L
s
.41313 .98969 m
.41965 .99416 L
s
0 .76 1 r
.71049 1.13662 m
.71908 1.14632 L
s
.73835 1.1441 m
.71908 1.14632 L
s
.92 1 0 r
.28951 1.13662 m
.28092 1.14632 L
s
.28092 1.14632 m
.26165 1.1441 L
s
0 1 .88 r
.55896 .94211 m
.54803 .93459 L
s
.54803 .93459 m
.53076 .87733 L
s
.56 1 0 r
.44104 .94211 m
.45197 .93459 L
s
.46924 .87733 m
.45197 .93459 L
s
0 .4 1 r
.53528 .9024 m
.5386 .89716 L
s
.53528 .9024 m
.56854 .95245 L
s
1 .72 0 r
.46472 .9024 m
.4614 .89716 L
s
.43146 .95245 m
.46472 .9024 L
s
0 1 .88 r
.61809 1.03497 m
.61155 1.0369 L
s
.65377 1.0774 m
.61155 1.0369 L
s
.56 1 0 r
.38191 1.03497 m
.38845 1.0369 L
s
.38845 1.0369 m
.34623 1.0774 L
s
0 .76 1 r
.63444 1.05407 m
.62786 1.05606 L
s
.62786 1.05606 m
.62273 1.04991 L
s
.63388 1.06182 m
.62786 1.05606 L
s
.92 1 0 r
.36556 1.05407 m
.37214 1.05606 L
s
.37214 1.05606 m
.36612 1.06182 L
s
.37727 1.04991 m
.37214 1.05606 L
s
.36813 1.05102 m
.37727 1.04991 L
s
.38117 1.04381 m
.37727 1.04991 L
s
0 .76 1 r
.63187 1.05102 m
.62273 1.04991 L
s
.62273 1.04991 m
.61883 1.04381 L
s
1 .36 0 r
.44866 .93994 m
.4684 .87573 L
s
0 .76 1 r
.64697 1.07078 m
.6499 1.07999 L
s
.65917 1.0838 m
.6499 1.07999 L
s
.92 1 0 r
.35303 1.07078 m
.3501 1.07999 L
s
.3501 1.07999 m
.34083 1.0838 L
s
0 .4 1 r
.68598 1.11563 m
.69866 1.12305 L
s
.68126 1.08552 m
.68598 1.11563 L
s
1 .72 0 r
.31402 1.11563 m
.30134 1.12305 L
s
.31402 1.11563 m
.31874 1.08552 L
s
0 .4 1 r
.57891 .98953 m
.58795 .9916 L
s
1 .72 0 r
.42109 .98953 m
.41205 .9916 L
s
0 .4 1 r
.63175 1.05963 m
.64405 1.06617 L
s
.61864 1.02958 m
.63175 1.05963 L
s
1 .72 0 r
.36825 1.05963 m
.35595 1.06617 L
s
.36825 1.05963 m
.38136 1.02958 L
s
0 .76 1 r
.63747 1.05697 m
.63388 1.06182 L
s
.6404 1.06683 m
.63388 1.06182 L
s
.92 1 0 r
.36253 1.05697 m
.36612 1.06182 L
s
.36612 1.06182 m
.3596 1.06683 L
s
0 .76 1 r
.61572 1.03359 m
.60311 1.02383 L
s
.60311 1.02383 m
.60458 1.01871 L
s
.92 1 0 r
.38428 1.03359 m
.39689 1.02383 L
s
.39542 1.01871 m
.39689 1.02383 L
s
0 .76 1 r
.62992 1.04804 m
.61883 1.04381 L
s
.61883 1.04381 m
.61644 1.03821 L
s
.92 1 0 r
.37008 1.04804 m
.38117 1.04381 L
s
.38356 1.03821 m
.38117 1.04381 L
s
0 .76 1 r
.56521 .96046 m
.55439 .94459 L
s
.55439 .94459 m
.57066 .94842 L
s
.92 1 0 r
.43479 .96046 m
.44561 .94459 L
s
.42934 .94842 m
.44561 .94459 L
s
0 .76 1 r
.70187 1.12677 m
.71049 1.13662 L
s
.72758 1.13482 m
.71049 1.13662 L
s
.92 1 0 r
.29813 1.12677 m
.28951 1.13662 L
s
.28951 1.13662 m
.27242 1.13482 L
s
0 .76 1 r
.52638 .85541 m
.51754 .82855 L
s
.51754 .82855 m
.55486 .90971 L
s
.92 1 0 r
.47362 .85541 m
.48246 .82855 L
s
.44514 .90971 m
.48246 .82855 L
s
0 .76 1 r
.65917 1.0838 m
.66516 1.09401 L
s
.67593 1.09617 m
.66516 1.09401 L
s
.92 1 0 r
.34083 1.0838 m
.33484 1.09401 L
s
.33484 1.09401 m
.32407 1.09617 L
s
0 .76 1 r
.64074 1.05953 m
.6404 1.06683 L
s
.64697 1.07078 m
.6404 1.06683 L
s
.92 1 0 r
.35926 1.05953 m
.3596 1.06683 L
s
.3596 1.06683 m
.35303 1.07078 L
s
0 .76 1 r
.60458 1.01871 m
.59245 1.00666 L
s
.59245 1.00666 m
.59771 1.00327 L
s
.92 1 0 r
.39542 1.01871 m
.40755 1.00666 L
s
.40229 1.00327 m
.40755 1.00666 L
s
0 .76 1 r
.62873 1.04534 m
.61644 1.03821 L
s
.61644 1.03821 m
.61572 1.03359 L
s
.92 1 0 r
.37127 1.04534 m
.38356 1.03821 L
s
.38428 1.03359 m
.38356 1.03821 L
s
0 .76 1 r
.69324 1.11675 m
.70187 1.12677 L
s
.7168 1.12535 m
.70187 1.12677 L
s
.92 1 0 r
.30676 1.11675 m
.29813 1.12677 L
s
.29813 1.12677 m
.2832 1.12535 L
s
0 .4 1 r
.69376 1.09182 m
.69866 1.12305 L
s
1 .72 0 r
.30134 1.12305 m
.30624 1.09182 L
s
0 1 .88 r
.69915 1.11634 m
.69866 1.12305 L
s
.75181 1.14901 m
.69866 1.12305 L
s
.56 1 0 r
.30085 1.11634 m
.30134 1.12305 L
s
.30134 1.12305 m
.24819 1.14901 L
s
0 .76 1 r
.57603 .97545 m
.56521 .96046 L
s
.56521 .96046 m
.57951 .96328 L
s
.92 1 0 r
.42397 .97545 m
.43479 .96046 L
s
.42049 .96328 m
.43479 .96046 L
s
0 1 .88 r
.54294 .89481 m
.53076 .87733 L
s
.53076 .87733 m
.52506 .85156 L
s
.56 1 0 r
.45706 .89481 m
.46924 .87733 L
s
.47494 .85156 m
.46924 .87733 L
s
0 .4 1 r
.60755 1.02478 m
.61864 1.02958 L
s
.58795 .9916 m
.60755 1.02478 L
s
1 .72 0 r
.39245 1.02478 m
.38136 1.02958 L
s
.39245 1.02478 m
.41205 .9916 L
s
0 .4 1 r
.56211 .95301 m
.56854 .95245 L
s
.56211 .95301 m
.58795 .9916 L
s
1 .72 0 r
.43789 .95301 m
.43146 .95245 L
s
.41205 .9916 m
.43789 .95301 L
s
0 .76 1 r
.65316 1.07347 m
.65917 1.0838 L
s
.66724 1.08558 m
.65917 1.0838 L
s
.92 1 0 r
.34684 1.07347 m
.34083 1.0838 L
s
.34083 1.0838 m
.33276 1.08558 L
s
0 .76 1 r
.64403 1.06159 m
.64697 1.07078 L
s
.65316 1.07347 m
.64697 1.07078 L
s
.92 1 0 r
.35597 1.06159 m
.35303 1.07078 L
s
.35303 1.07078 m
.34684 1.07347 L
s
0 .76 1 r
.68459 1.10655 m
.69324 1.11675 L
s
.706 1.11568 m
.69324 1.11675 L
s
.92 1 0 r
.31541 1.10655 m
.30676 1.11675 L
s
.30676 1.11675 m
.294 1.11568 L
s
0 1 .88 r
.59366 .9932 m
.58457 .99076 L
s
.58457 .99076 m
.55896 .94211 L
s
.61809 1.03497 m
.58457 .99076 L
s
.56 1 0 r
.40634 .9932 m
.41543 .99076 L
s
.41543 .99076 m
.38191 1.03497 L
s
.44104 .94211 m
.41543 .99076 L
s
0 1 .88 r
.65743 1.07281 m
.65377 1.0774 L
s
.69965 1.10976 m
.65377 1.0774 L
s
.56 1 0 r
.34257 1.07281 m
.34623 1.0774 L
s
.34623 1.0774 m
.30035 1.10976 L
s
0 .76 1 r
.62838 1.04313 m
.61572 1.03359 L
s
.61572 1.03359 m
.61673 1.03035 L
s
.92 1 0 r
.37162 1.04313 m
.38428 1.03359 L
s
.38327 1.03035 m
.38428 1.03359 L
s
0 .76 1 r
.61673 1.03035 m
.60458 1.01871 L
s
.60458 1.01871 m
.60855 1.01627 L
s
.92 1 0 r
.38327 1.03035 m
.39542 1.01871 L
s
.39145 1.01627 m
.39542 1.01871 L
s
0 .4 1 r
.5386 .89716 m
.54194 .89383 L
s
.5386 .89716 m
.57503 .95295 L
s
1 .72 0 r
.4614 .89716 m
.45806 .89383 L
s
.42497 .95295 m
.4614 .89716 L
s
0 .4 1 r
.64405 1.06617 m
.6564 1.07268 L
s
.6298 1.03456 m
.64405 1.06617 L
s
1 .72 0 r
.35595 1.06617 m
.3436 1.07268 L
s
.35595 1.06617 m
.3702 1.03456 L
s
0 .76 1 r
.58687 .98969 m
.57603 .97545 L
s
.57603 .97545 m
.58834 .97745 L
s
.92 1 0 r
.41313 .98969 m
.42397 .97545 L
s
.41166 .97745 m
.42397 .97545 L
s
0 1 .88 r
.62468 1.03346 m
.61809 1.03497 L
s
.65743 1.07281 m
.61809 1.03497 L
s
.56 1 0 r
.37532 1.03346 m
.38191 1.03497 L
s
.38191 1.03497 m
.34257 1.07281 L
s
0 .76 1 r
.67593 1.09617 m
.68459 1.10655 L
s
.6952 1.10579 m
.68459 1.10655 L
s
.92 1 0 r
.32407 1.09617 m
.31541 1.10655 L
s
.31541 1.10655 m
.3048 1.10579 L
s
0 .76 1 r
.64108 1.05244 m
.63444 1.05407 L
s
.63444 1.05407 m
.63187 1.05102 L
s
.63747 1.05697 m
.63444 1.05407 L
s
.92 1 0 r
.35892 1.05244 m
.36556 1.05407 L
s
.36556 1.05407 m
.36253 1.05697 L
s
.36813 1.05102 m
.36556 1.05407 L
s
0 .76 1 r
.64108 1.05244 m
.63187 1.05102 L
s
.63187 1.05102 m
.62992 1.04804 L
s
.92 1 0 r
.35892 1.05244 m
.36813 1.05102 L
s
.37008 1.04804 m
.36813 1.05102 L
s
0 .76 1 r
.64108 1.05244 m
.63747 1.05697 L
s
.64074 1.05953 m
.63747 1.05697 L
s
.92 1 0 r
.35892 1.05244 m
.36253 1.05697 L
s
.36253 1.05697 m
.35926 1.05953 L
s
0 1 .88 r
.56998 .95027 m
.55896 .94211 L
s
.55896 .94211 m
.54294 .89481 L
s
.56 1 0 r
.43002 .95027 m
.44104 .94211 L
s
.45706 .89481 m
.44104 .94211 L
s
0 .76 1 r
.64108 1.05244 m
.62992 1.04804 L
s
.62992 1.04804 m
.62873 1.04534 L
s
.92 1 0 r
.35892 1.05244 m
.37008 1.04804 L
s
.37127 1.04534 m
.37008 1.04804 L
s
0 .76 1 r
.53523 .87796 m
.52638 .85541 L
s
.52638 .85541 m
.56107 .91499 L
s
.92 1 0 r
.46477 .87796 m
.47362 .85541 L
s
.43893 .91499 m
.47362 .85541 L
s
0 .76 1 r
.64713 1.06302 m
.65316 1.07347 L
s
.65854 1.07478 m
.65316 1.07347 L
s
.92 1 0 r
.35287 1.06302 m
.34684 1.07347 L
s
.34684 1.07347 m
.34146 1.07478 L
s
0 1 .88 r
.52506 .85156 m
.51244 .81376 L
s
.51244 .81376 m
.51945 .90946 L
s
.56 1 0 r
.47494 .85156 m
.48756 .81376 L
s
.48055 .90946 m
.48756 .81376 L
s
0 .4 1 r
.58795 .9916 m
.59706 .99424 L
s
1 .72 0 r
.41205 .9916 m
.40294 .99424 L
s
0 .76 1 r
.59771 1.00327 m
.58687 .98969 L
s
.58687 .98969 m
.59716 .99103 L
s
.92 1 0 r
.40229 1.00327 m
.41313 .98969 L
s
.40284 .99103 m
.41313 .98969 L
s
0 .76 1 r
.64108 1.05244 m
.64074 1.05953 L
s
.64403 1.06159 m
.64074 1.05953 L
s
.92 1 0 r
.35892 1.05244 m
.35926 1.05953 L
s
.35926 1.05953 m
.35597 1.06159 L
s
0 .76 1 r
.66724 1.08558 m
.67593 1.09617 L
s
.68439 1.09567 m
.67593 1.09617 L
s
.92 1 0 r
.33276 1.08558 m
.32407 1.09617 L
s
.32407 1.09617 m
.31561 1.09567 L
s
0 .76 1 r
.64108 1.05244 m
.62873 1.04534 L
s
.62873 1.04534 m
.62838 1.04313 L
s
.92 1 0 r
.35892 1.05244 m
.37127 1.04534 L
s
.37162 1.04313 m
.37127 1.04534 L
s
0 .76 1 r
.62889 1.04158 m
.61673 1.03035 L
s
.61673 1.03035 m
.6194 1.02876 L
s
.92 1 0 r
.37111 1.04158 m
.38327 1.03035 L
s
.3806 1.02876 m
.38327 1.03035 L
s
0 .76 1 r
.64108 1.05244 m
.64403 1.06159 L
s
.64713 1.06302 m
.64403 1.06159 L
s
.92 1 0 r
.35892 1.05244 m
.35597 1.06159 L
s
.35597 1.06159 m
.35287 1.06302 L
s
0 1 .88 r
.69965 1.10976 m
.69915 1.11634 L
s
.74912 1.14131 m
.69915 1.11634 L
s
.56 1 0 r
.30035 1.10976 m
.30085 1.11634 L
s
.30085 1.11634 m
.25088 1.14131 L
s
0 .76 1 r
.60855 1.01627 m
.59771 1.00327 L
s
.59771 1.00327 m
.60597 1.0041 L
s
.92 1 0 r
.39145 1.01627 m
.40229 1.00327 L
s
.39403 1.0041 m
.40229 1.00327 L
s
0 .76 1 r
.64108 1.05244 m
.62838 1.04313 L
s
.62838 1.04313 m
.62889 1.04158 L
s
.92 1 0 r
.35892 1.05244 m
.37162 1.04313 L
s
.37111 1.04158 m
.37162 1.04313 L
s
0 .76 1 r
.65854 1.07478 m
.66724 1.08558 L
s
.67357 1.0853 m
.66724 1.08558 L
s
.92 1 0 r
.34146 1.07478 m
.33276 1.08558 L
s
.33276 1.08558 m
.32643 1.0853 L
s
.19725 1.19649 m
.18656 1.20475 L
s
.18656 1.20475 m
.16266 1.19174 L
s
0 .76 1 r
.80275 1.19649 m
.81344 1.20475 L
s
.83734 1.19174 m
.81344 1.20475 L
s
.64108 1.05244 m
.64713 1.06302 L
s
.64982 1.06374 m
.64713 1.06302 L
s
.92 1 0 r
.35892 1.05244 m
.35287 1.06302 L
s
.35287 1.06302 m
.35018 1.06374 L
s
0 .4 1 r
.61864 1.02958 m
.6298 1.03456 L
s
.59706 .99424 m
.61864 1.02958 L
s
1 .72 0 r
.38136 1.02958 m
.3702 1.03456 L
s
.38136 1.02958 m
.40294 .99424 L
s
.92 1 0 r
.3806 1.02876 m
.39145 1.01627 L
s
.38523 1.01673 m
.39145 1.01627 L
s
0 .76 1 r
.6194 1.02876 m
.60855 1.01627 L
s
.60855 1.01627 m
.61477 1.01673 L
s
0 .4 1 r
.6564 1.07268 m
.6688 1.07913 L
s
.64102 1.03967 m
.6564 1.07268 L
s
1 .72 0 r
.3436 1.07268 m
.3312 1.07913 L
s
.3436 1.07268 m
.35898 1.03967 L
s
0 .76 1 r
.64982 1.06374 m
.65854 1.07478 L
s
.66275 1.07466 m
.65854 1.07478 L
s
.92 1 0 r
.35018 1.06374 m
.34146 1.07478 L
s
.34146 1.07478 m
.33725 1.07466 L
s
0 .76 1 r
.64108 1.05244 m
.62889 1.04158 L
s
.62889 1.04158 m
.63024 1.0408 L
s
.92 1 0 r
.35892 1.05244 m
.37111 1.04158 L
s
.36976 1.0408 m
.37111 1.04158 L
s
0 .76 1 r
.79205 1.18811 m
.80275 1.19649 L
s
.82504 1.18437 m
.80275 1.19649 L
s
.92 1 0 r
.20795 1.18811 m
.19725 1.19649 L
s
.19725 1.19649 m
.17496 1.18437 L
s
0 .76 1 r
.54409 .89787 m
.53523 .87796 L
s
.53523 .87796 m
.56728 .92264 L
s
.92 1 0 r
.45591 .89787 m
.46477 .87796 L
s
.43272 .92264 m
.46477 .87796 L
s
0 1 .88 r
.66111 1.0685 m
.65743 1.07281 L
s
.70017 1.10333 m
.65743 1.07281 L
s
.56 1 0 r
.33889 1.0685 m
.34257 1.07281 L
s
.34257 1.07281 m
.29983 1.10333 L
s
0 .76 1 r
.78133 1.1796 m
.79205 1.18811 L
s
.81274 1.17687 m
.79205 1.18811 L
s
.92 1 0 r
.21867 1.1796 m
.20795 1.18811 L
s
.20795 1.18811 m
.18726 1.17687 L
s
0 .76 1 r
.63024 1.0408 m
.6194 1.02876 L
s
.6194 1.02876 m
.62356 1.02897 L
s
.92 1 0 r
.36976 1.0408 m
.3806 1.02876 L
s
.37644 1.02897 m
.3806 1.02876 L
s
0 .4 1 r
.56854 .95245 m
.57503 .95295 L
s
.56854 .95245 m
.59706 .99424 L
s
1 .72 0 r
.43146 .95245 m
.42497 .95295 L
s
.40294 .99424 m
.43146 .95245 L
s
0 1 .88 r
.60281 .99616 m
.59366 .9932 L
s
.59366 .9932 m
.56998 .95027 L
s
.62468 1.03346 m
.59366 .9932 L
s
.56 1 0 r
.39719 .99616 m
.40634 .9932 L
s
.40634 .9932 m
.37532 1.03346 L
s
.43002 .95027 m
.40634 .9932 L
s
0 .76 1 r
.64108 1.05244 m
.64982 1.06374 L
s
.65192 1.06371 m
.64982 1.06374 L
s
.92 1 0 r
.35892 1.05244 m
.35018 1.06374 L
s
.35018 1.06374 m
.34808 1.06371 L
s
0 .76 1 r
.77061 1.17095 m
.78133 1.1796 L
s
.80044 1.16923 m
.78133 1.1796 L
s
.92 1 0 r
.22939 1.17095 m
.21867 1.1796 L
s
.21867 1.1796 m
.19956 1.16923 L
s
0 .76 1 r
.64108 1.05244 m
.63024 1.0408 L
s
.63024 1.0408 m
.63233 1.04086 L
s
.92 1 0 r
.35892 1.05244 m
.36976 1.0408 L
s
.36767 1.04086 m
.36976 1.0408 L
s
0 .4 1 r
.54194 .89383 m
.54534 .89312 L
s
.54194 .89383 m
.58158 .95454 L
s
1 .72 0 r
.45806 .89383 m
.45466 .89312 L
s
.41842 .95454 m
.45806 .89383 L
s
0 .76 1 r
.75987 1.16216 m
.77061 1.17095 L
s
.78814 1.16144 m
.77061 1.17095 L
s
.92 1 0 r
.24013 1.16216 m
.22939 1.17095 L
s
.22939 1.17095 m
.21186 1.16144 L
s
.56 1 0 r
.36868 1.03239 m
.37532 1.03346 L
s
.37532 1.03346 m
.33889 1.0685 L
s
0 1 .88 r
.63132 1.03239 m
.62468 1.03346 L
s
.66111 1.0685 m
.62468 1.03346 L
s
.92 1 0 r
.25088 1.15321 m
.24013 1.16216 L
s
.24013 1.16216 m
.22415 1.1535 L
s
0 .76 1 r
.74912 1.15321 m
.75987 1.16216 L
s
.77585 1.1535 m
.75987 1.16216 L
s
.64108 1.05244 m
.65381 1.06151 L
s
.64108 1.05244 m
.64143 1.04558 L
s
.64108 1.05244 m
.64108 1.05244 L
s
.64108 1.05244 m
.65348 1.05947 L
s
.64108 1.05244 m
.6523 1.05696 L
s
.64108 1.05244 m
.65035 1.05414 L
s
.64108 1.05244 m
.64776 1.05117 L
s
.64108 1.05244 m
.64472 1.04825 L
s
.64108 1.05244 m
.63812 1.04335 L
s
.64108 1.05244 m
.63501 1.04174 L
s
.64108 1.05244 m
.63233 1.04086 L
s
.64108 1.05244 m
.65192 1.06371 L
s
.64108 1.05244 m
.65328 1.06295 L
s
.92 1 0 r
.35892 1.05244 m
.36767 1.04086 L
s
.35892 1.05244 m
.36499 1.04174 L
s
.35892 1.05244 m
.36188 1.04335 L
s
.35892 1.05244 m
.35528 1.04825 L
s
.35892 1.05244 m
.35224 1.05117 L
s
.35892 1.05244 m
.34965 1.05414 L
s
.35892 1.05244 m
.3477 1.05696 L
s
.35892 1.05244 m
.34652 1.05947 L
s
.35892 1.05244 m
.34672 1.06295 L
s
.35892 1.05244 m
.34808 1.06371 L
s
.35892 1.05244 m
.35892 1.05244 L
s
.35892 1.05244 m
.35857 1.04558 L
s
.35892 1.05244 m
.34619 1.06151 L
s
0 .76 1 r
.55295 .91597 m
.54409 .89787 L
s
.54409 .89787 m
.57349 .93189 L
s
.92 1 0 r
.44705 .91597 m
.45591 .89787 L
s
.42651 .93189 m
.45591 .89787 L
s
.26165 1.1441 m
.25088 1.15321 L
s
.25088 1.15321 m
.23644 1.14539 L
s
0 .76 1 r
.73835 1.1441 m
.74912 1.15321 L
s
.76356 1.14539 m
.74912 1.15321 L
s
0 1 .88 r
.55523 .91172 m
.54294 .89481 L
s
.54294 .89481 m
.53779 .87841 L
s
.56 1 0 r
.44477 .91172 m
.45706 .89481 L
s
.46221 .87841 m
.45706 .89481 L
s
0 .76 1 r
.65192 1.06371 m
.66275 1.07466 L
s
.65328 1.06295 m
.65192 1.06371 L
s
.92 1 0 r
.34808 1.06371 m
.33725 1.07466 L
s
.34808 1.06371 m
.34672 1.06295 L
s
0 .76 1 r
.72758 1.13482 m
.73835 1.1441 L
s
.75128 1.13711 m
.73835 1.1441 L
s
.92 1 0 r
.27242 1.13482 m
.26165 1.1441 L
s
.26165 1.1441 m
.24872 1.13711 L
s
0 .76 1 r
.66275 1.07466 m
.67357 1.0853 L
s
.66549 1.07314 m
.66275 1.07466 L
s
.92 1 0 r
.33725 1.07466 m
.32643 1.0853 L
s
.33725 1.07466 m
.33451 1.07314 L
s
0 .76 1 r
.7168 1.12535 m
.72758 1.13482 L
s
.739 1.12864 m
.72758 1.13482 L
s
.92 1 0 r
.2832 1.12535 m
.27242 1.13482 L
s
.27242 1.13482 m
.261 1.12864 L
s
0 .76 1 r
.63233 1.04086 m
.62356 1.02897 L
s
.63233 1.04086 m
.63501 1.04174 L
s
.92 1 0 r
.36767 1.04086 m
.37644 1.02897 L
s
.36499 1.04174 m
.36767 1.04086 L
s
0 .76 1 r
.67357 1.0853 m
.68439 1.09567 L
s
.67772 1.08303 m
.67357 1.0853 L
s
.92 1 0 r
.32643 1.0853 m
.31561 1.09567 L
s
.32643 1.0853 m
.32228 1.08303 L
s
0 .76 1 r
.706 1.11568 m
.7168 1.12535 L
s
.72673 1.11998 m
.7168 1.12535 L
s
.92 1 0 r
.294 1.11568 m
.2832 1.12535 L
s
.2832 1.12535 m
.27327 1.11998 L
s
0 .76 1 r
.68439 1.09567 m
.6952 1.10579 L
s
.68996 1.09264 m
.68439 1.09567 L
s
.92 1 0 r
.31561 1.09567 m
.3048 1.10579 L
s
.31561 1.09567 m
.31004 1.09264 L
s
0 .76 1 r
.6952 1.10579 m
.706 1.11568 L
s
.71446 1.1111 m
.706 1.11568 L
s
.92 1 0 r
.3048 1.10579 m
.294 1.11568 L
s
.294 1.11568 m
.28554 1.1111 L
s
0 .76 1 r
.70221 1.10199 m
.6952 1.10579 L
s
.92 1 0 r
.3048 1.10579 m
.29779 1.10199 L
s
0 .4 1 r
.59706 .99424 m
.60623 .9974 L
s
1 .72 0 r
.40294 .99424 m
.39377 .9974 L
s
0 1 .88 r
.70017 1.10333 m
.69965 1.10976 L
s
.74641 1.13367 m
.69965 1.10976 L
s
.56 1 0 r
.29983 1.10333 m
.30035 1.10976 L
s
.30035 1.10976 m
.25359 1.13367 L
s
0 1 .88 r
.58108 .95884 m
.56998 .95027 L
s
.56998 .95027 m
.55523 .91172 L
s
.56 1 0 r
.41892 .95884 m
.43002 .95027 L
s
.44477 .91172 m
.43002 .95027 L
s
0 .76 1 r
.62356 1.02897 m
.61477 1.01673 L
s
.62356 1.02897 m
.62893 1.03091 L
s
.92 1 0 r
.37644 1.02897 m
.38523 1.01673 L
s
.37107 1.03091 m
.37644 1.02897 L
s
0 .76 1 r
.56181 .93272 m
.55295 .91597 L
s
.55295 .91597 m
.5797 .94211 L
s
.92 1 0 r
.43819 .93272 m
.44705 .91597 L
s
.4203 .94211 m
.44705 .91597 L
s
0 .76 1 r
.65328 1.06295 m
.66549 1.07314 L
s
.65381 1.06151 m
.65328 1.06295 L
s
.92 1 0 r
.34672 1.06295 m
.33451 1.07314 L
s
.34672 1.06295 m
.34619 1.06151 L
s
0 .4 1 r
.6688 1.07913 m
.68126 1.08552 L
s
.65231 1.04487 m
.6688 1.07913 L
s
1 .72 0 r
.3312 1.07913 m
.31874 1.08552 L
s
.3312 1.07913 m
.34769 1.04487 L
s
0 .76 1 r
.63501 1.04174 m
.62893 1.03091 L
s
.63501 1.04174 m
.63812 1.04335 L
s
.92 1 0 r
.36499 1.04174 m
.37107 1.03091 L
s
.36188 1.04335 m
.36499 1.04174 L
s
0 .76 1 r
.61477 1.01673 m
.60597 1.0041 L
s
.61477 1.01673 m
.62283 1.01996 L
s
.92 1 0 r
.38523 1.01673 m
.39403 1.0041 L
s
.37717 1.01996 m
.38523 1.01673 L
s
0 .76 1 r
.57066 .94842 m
.56181 .93272 L
s
.56181 .93272 m
.5859 .95291 L
s
.92 1 0 r
.42934 .94842 m
.43819 .93272 L
s
.4141 .95291 m
.43819 .93272 L
s
0 .76 1 r
.60597 1.0041 m
.59716 .99103 L
s
.60597 1.0041 m
.61671 1.0089 L
s
.92 1 0 r
.39403 1.0041 m
.40284 .99103 L
s
.38329 1.0089 m
.39403 1.0041 L
s
0 .4 1 r
.6298 1.03456 m
.64102 1.03967 L
s
.60623 .9974 m
.6298 1.03456 L
s
1 .72 0 r
.3702 1.03456 m
.35898 1.03967 L
s
.3702 1.03456 m
.39377 .9974 L
s
0 .76 1 r
.65381 1.06151 m
.66658 1.07034 L
s
.65348 1.05947 m
.65381 1.06151 L
s
.92 1 0 r
.34619 1.06151 m
.33342 1.07034 L
s
.34619 1.06151 m
.34652 1.05947 L
s
0 .76 1 r
.57951 .96328 m
.57066 .94842 L
s
.57066 .94842 m
.59209 .964 L
s
.92 1 0 r
.42049 .96328 m
.42934 .94842 L
s
.40791 .964 m
.42934 .94842 L
s
0 .76 1 r
.59716 .99103 m
.58834 .97745 L
s
.59716 .99103 m
.61058 .99773 L
s
.92 1 0 r
.40284 .99103 m
.41166 .97745 L
s
.38942 .99773 m
.40284 .99103 L
s
.2 1 0 r
.45212 .89441 m
.4586 .88684 L
s
.4586 .88684 m
.40966 .96085 L
s
0 1 .52 r
.54788 .89441 m
.5414 .88684 L
s
.59034 .96085 m
.5414 .88684 L
s
0 .76 1 r
.58834 .97745 m
.57951 .96328 L
s
.57951 .96328 m
.59827 .97524 L
s
.92 1 0 r
.41166 .97745 m
.42049 .96328 L
s
.40173 .97524 m
.42049 .96328 L
s
0 .76 1 r
.58834 .97745 m
.60443 .9865 L
s
.92 1 0 r
.39557 .9865 m
.41166 .97745 L
s
0 .76 1 r
.63812 1.04335 m
.63515 1.03436 L
s
.63812 1.04335 m
.64143 1.04558 L
s
.92 1 0 r
.36188 1.04335 m
.36485 1.03436 L
s
.35857 1.04558 m
.36188 1.04335 L
s
0 .76 1 r
.66549 1.07314 m
.67772 1.08303 L
s
.66658 1.07034 m
.66549 1.07314 L
s
.92 1 0 r
.33451 1.07314 m
.32228 1.08303 L
s
.33451 1.07314 m
.33342 1.07034 L
s
0 1 .88 r
.66482 1.0645 m
.66111 1.0685 L
s
.70069 1.09708 m
.66111 1.0685 L
s
.56 1 0 r
.33518 1.0645 m
.33889 1.0685 L
s
.33889 1.0685 m
.29931 1.09708 L
s
0 .76 1 r
.65348 1.05947 m
.66593 1.06641 L
s
.6523 1.05696 m
.65348 1.05947 L
s
.92 1 0 r
.34652 1.05947 m
.33407 1.06641 L
s
.34652 1.05947 m
.3477 1.05696 L
s
0 .76 1 r
.62893 1.03091 m
.62283 1.01996 L
s
.62893 1.03091 m
.63515 1.03436 L
s
.92 1 0 r
.37107 1.03091 m
.37717 1.01996 L
s
.36485 1.03436 m
.37107 1.03091 L
s
0 .76 1 r
.64143 1.04558 m
.6418 1.03901 L
s
.64143 1.04558 m
.64472 1.04825 L
s
.92 1 0 r
.35857 1.04558 m
.3582 1.03901 L
s
.35528 1.04825 m
.35857 1.04558 L
s
0 1 .52 r
.51786 .86231 m
.50884 .82513 L
s
.50884 .82513 m
.47842 .90945 L
s
.54788 .89441 m
.50884 .82513 L
s
.2 1 0 r
.48214 .86231 m
.49116 .82513 L
s
.49116 .82513 m
.45212 .89441 L
s
.52158 .90945 m
.49116 .82513 L
s
0 1 .88 r
.74912 1.14131 m
.75181 1.14901 L
s
.80278 1.16539 m
.75181 1.14901 L
s
.56 1 0 r
.25088 1.14131 m
.24819 1.14901 L
s
.24819 1.14901 m
.19722 1.16539 L
s
0 1 .88 r
.61203 .99961 m
.60281 .99616 L
s
.60281 .99616 m
.58108 .95884 L
s
.63132 1.03239 m
.60281 .99616 L
s
.56 1 0 r
.38797 .99961 m
.39719 .99616 L
s
.39719 .99616 m
.36868 1.03239 L
s
.41892 .95884 m
.39719 .99616 L
s
0 .76 1 r
.6523 1.05696 m
.66358 1.06157 L
s
.65035 1.05414 m
.6523 1.05696 L
s
.92 1 0 r
.3477 1.05696 m
.33642 1.06157 L
s
.3477 1.05696 m
.34965 1.05414 L
s
0 .4 1 r
.57503 .95295 m
.58158 .95454 L
s
.57503 .95295 m
.60623 .9974 L
s
1 .72 0 r
.42497 .95295 m
.41842 .95454 L
s
.39377 .9974 m
.42497 .95295 L
s
0 .76 1 r
.67772 1.08303 m
.68996 1.09264 L
s
.67939 1.07893 m
.67772 1.08303 L
s
.92 1 0 r
.32228 1.08303 m
.31004 1.09264 L
s
.32228 1.08303 m
.32061 1.07893 L
s
0 .76 1 r
.64472 1.04825 m
.6484 1.04444 L
s
.64472 1.04825 m
.64776 1.05117 L
s
.92 1 0 r
.35528 1.04825 m
.3516 1.04444 L
s
.35224 1.05117 m
.35528 1.04825 L
s
0 1 .88 r
.63802 1.03175 m
.63132 1.03239 L
s
.66482 1.0645 m
.63132 1.03239 L
s
.56 1 0 r
.36198 1.03175 m
.36868 1.03239 L
s
.36868 1.03239 m
.33518 1.0645 L
s
0 .76 1 r
.65035 1.05414 m
.65968 1.05608 L
s
.64776 1.05117 m
.65035 1.05414 L
s
.92 1 0 r
.34965 1.05414 m
.34032 1.05608 L
s
.34965 1.05414 m
.35224 1.05117 L
s
0 .76 1 r
.64776 1.05117 m
.6545 1.05026 L
s
.92 1 0 r
.35224 1.05117 m
.3455 1.05026 L
s
0 .4 1 r
.68126 1.08552 m
.69376 1.09182 L
s
.66366 1.0501 m
.68126 1.08552 L
s
1 .72 0 r
.31874 1.08552 m
.30624 1.09182 L
s
.31874 1.08552 m
.33634 1.0501 L
s
0 1 .88 r
.70069 1.09708 m
.70017 1.10333 L
s
.74371 1.1261 m
.70017 1.10333 L
s
.56 1 0 r
.29931 1.09708 m
.29983 1.10333 L
s
.29983 1.10333 m
.25629 1.1261 L
s
0 .4 1 r
.54534 .89312 m
.54878 .89559 L
s
.54534 .89312 m
.5882 .95717 L
s
1 .72 0 r
.45466 .89312 m
.45122 .89559 L
s
.4118 .95717 m
.45466 .89312 L
s
0 .76 1 r
.66658 1.07034 m
.67939 1.07893 L
s
.66593 1.06641 m
.66658 1.07034 L
s
.92 1 0 r
.33342 1.07034 m
.32061 1.07893 L
s
.33342 1.07034 m
.33407 1.06641 L
s
0 .76 1 r
.68996 1.09264 m
.70221 1.10199 L
s
.69222 1.0873 m
.68996 1.09264 L
s
.92 1 0 r
.31004 1.09264 m
.29779 1.10199 L
s
.31004 1.09264 m
.30778 1.0873 L
s
0 .76 1 r
.62283 1.01996 m
.61671 1.0089 L
s
.62283 1.01996 m
.63218 1.02551 L
s
.92 1 0 r
.37717 1.01996 m
.38329 1.0089 L
s
.36782 1.02551 m
.37717 1.01996 L
s
0 .76 1 r
.63515 1.03436 m
.63218 1.02551 L
s
.63515 1.03436 m
.6418 1.03901 L
s
.92 1 0 r
.36485 1.03436 m
.36782 1.02551 L
s
.3582 1.03901 m
.36485 1.03436 L
s
0 .4 1 r
.60623 .9974 m
.61548 1.001 L
s
1 .72 0 r
.39377 .9974 m
.38452 1.001 L
s
0 1 .88 r
.59226 .96761 m
.58108 .95884 L
s
.58108 .95884 m
.5676 .9276 L
s
.56 1 0 r
.40774 .96761 m
.41892 .95884 L
s
.4324 .9276 m
.41892 .95884 L
s
0 1 .16 r
.5 .86523 m
.5 .82864 L
s
.5 .82864 m
.45052 .90729 L
s
.54948 .90729 m
.5 .82864 L
s
0 .4 1 r
.64102 1.03967 m
.65231 1.04487 L
s
.61548 1.001 m
.64102 1.03967 L
s
1 .72 0 r
.35898 1.03967 m
.34769 1.04487 L
s
.35898 1.03967 m
.38452 1.001 L
s
0 .76 1 r
.70221 1.10199 m
.71446 1.1111 L
s
.70509 1.09544 m
.70221 1.10199 L
s
.92 1 0 r
.29779 1.10199 m
.28554 1.1111 L
s
.29779 1.10199 m
.29491 1.09544 L
s
0 1 .88 r
.5676 .9276 m
.55523 .91172 L
s
.55523 .91172 m
.55061 .9 L
s
.56 1 0 r
.4324 .9276 m
.44477 .91172 L
s
.44939 .9 m
.44477 .91172 L
s
0 .76 1 r
.66593 1.06641 m
.67844 1.07324 L
s
.66358 1.06157 m
.66593 1.06641 L
s
.92 1 0 r
.33407 1.06641 m
.32156 1.07324 L
s
.33407 1.06641 m
.33642 1.06157 L
s
0 1 .88 r
.74641 1.13367 m
.74912 1.14131 L
s
.79699 1.15726 m
.74912 1.14131 L
s
.56 1 0 r
.25359 1.13367 m
.25088 1.14131 L
s
.25088 1.14131 m
.20301 1.15726 L
s
0 1 .88 r
.66857 1.06083 m
.66482 1.0645 L
s
.70122 1.09103 m
.66482 1.0645 L
s
.56 1 0 r
.33143 1.06083 m
.33518 1.0645 L
s
.33518 1.0645 m
.29878 1.09103 L
s
0 .76 1 r
.61671 1.0089 m
.61058 .99773 L
s
.61671 1.0089 m
.6292 1.01684 L
s
.92 1 0 r
.38329 1.0089 m
.38942 .99773 L
s
.3708 1.01684 m
.38329 1.0089 L
s
0 1 .88 r
.53779 .87841 m
.52506 .85156 L
s
.52506 .85156 m
.53188 .91282 L
s
.56 1 0 r
.46221 .87841 m
.47494 .85156 L
s
.46812 .91282 m
.47494 .85156 L
s
0 .76 1 r
.67939 1.07893 m
.69222 1.0873 L
s
.67844 1.07324 m
.67939 1.07893 L
s
.92 1 0 r
.32061 1.07893 m
.30778 1.0873 L
s
.32061 1.07893 m
.32156 1.07324 L
s
0 .76 1 r
.6418 1.03901 m
.64217 1.03275 L
s
.6418 1.03901 m
.6484 1.04444 L
s
.92 1 0 r
.3582 1.03901 m
.35783 1.03275 L
s
.3516 1.04444 m
.3582 1.03901 L
s
0 .76 1 r
.71446 1.1111 m
.72673 1.11998 L
s
.71799 1.10336 m
.71446 1.1111 L
s
.92 1 0 r
.28554 1.1111 m
.27327 1.11998 L
s
.28554 1.1111 m
.28201 1.10336 L
s
0 .4 1 r
.67508 1.05533 m
.69376 1.09182 L
s
1 .72 0 r
.30624 1.09182 m
.32492 1.05533 L
s
0 .76 1 r
.66358 1.06157 m
.67493 1.06623 L
s
.65968 1.05608 m
.66358 1.06157 L
s
.92 1 0 r
.33642 1.06157 m
.32507 1.06623 L
s
.33642 1.06157 m
.34032 1.05608 L
s
0 .76 1 r
.6484 1.04444 m
.65211 1.04102 L
s
.6484 1.04444 m
.6545 1.05026 L
s
.92 1 0 r
.3516 1.04444 m
.34789 1.04102 L
s
.3455 1.05026 m
.3516 1.04444 L
s
0 1 .88 r
.70122 1.09103 m
.70069 1.09708 L
s
.74099 1.11863 m
.70069 1.09708 L
s
.56 1 0 r
.29878 1.09103 m
.29931 1.09708 L
s
.29931 1.09708 m
.25901 1.11863 L
s
0 .76 1 r
.72673 1.11998 m
.739 1.12864 L
s
.73092 1.11108 m
.72673 1.11998 L
s
.92 1 0 r
.27327 1.11998 m
.261 1.12864 L
s
.27327 1.11998 m
.26908 1.11108 L
s
0 .76 1 r
.63218 1.02551 m
.6292 1.01684 L
s
.63218 1.02551 m
.64217 1.03275 L
s
.92 1 0 r
.36782 1.02551 m
.3708 1.01684 L
s
.35783 1.03275 m
.36782 1.02551 L
s
0 .76 1 r
.65968 1.05608 m
.66908 1.05825 L
s
.6545 1.05026 m
.65968 1.05608 L
s
.92 1 0 r
.34032 1.05608 m
.33092 1.05825 L
s
.34032 1.05608 m
.3455 1.05026 L
s
0 .76 1 r
.61058 .99773 m
.60443 .9865 L
s
.61058 .99773 m
.62621 1.00842 L
s
.92 1 0 r
.38942 .99773 m
.39557 .9865 L
s
.37379 1.00842 m
.38942 .99773 L
s
0 1 .88 r
.62132 1.00345 m
.61203 .99961 L
s
.61203 .99961 m
.59226 .96761 L
s
.63802 1.03175 m
.61203 .99961 L
s
.56 1 0 r
.37868 1.00345 m
.38797 .99961 L
s
.38797 .99961 m
.36198 1.03175 L
s
.40774 .96761 m
.38797 .99961 L
s
0 1 .88 r
.64477 1.03154 m
.63802 1.03175 L
s
.66857 1.06083 m
.63802 1.03175 L
s
.56 1 0 r
.35523 1.03154 m
.36198 1.03175 L
s
.36198 1.03175 m
.33143 1.06083 L
s
0 .76 1 r
.6545 1.05026 m
.66129 1.0497 L
s
.92 1 0 r
.3455 1.05026 m
.33871 1.0497 L
s
1 .72 0 r
.41842 .95454 m
.4118 .95717 L
s
.38452 1.001 m
.41842 .95454 L
s
0 .4 1 r
.58158 .95454 m
.5882 .95717 L
s
.58158 .95454 m
.61548 1.001 L
s
0 .76 1 r
.739 1.12864 m
.75128 1.13711 L
s
.74387 1.1186 m
.739 1.12864 L
s
.92 1 0 r
.261 1.12864 m
.24872 1.13711 L
s
.261 1.12864 m
.25613 1.1186 L
s
0 .76 1 r
.69222 1.0873 m
.70509 1.09544 L
s
.691 1.07993 m
.69222 1.0873 L
s
.92 1 0 r
.30778 1.0873 m
.29491 1.09544 L
s
.30778 1.0873 m
.309 1.07993 L
s
.2 1 0 r
.44555 .90429 m
.45212 .89441 L
s
.45212 .89441 m
.40605 .96036 L
s
0 1 .52 r
.55445 .90429 m
.54788 .89441 L
s
.59395 .96036 m
.54788 .89441 L
s
0 .76 1 r
.67844 1.07324 m
.691 1.07993 L
s
.67493 1.06623 m
.67844 1.07324 L
s
.92 1 0 r
.32156 1.07324 m
.309 1.07993 L
s
.32156 1.07324 m
.32507 1.06623 L
s
0 1 .88 r
.74371 1.1261 m
.74641 1.13367 L
s
.79118 1.14915 m
.74641 1.13367 L
s
.56 1 0 r
.25629 1.1261 m
.25359 1.13367 L
s
.25359 1.13367 m
.20882 1.14915 L
s
0 .76 1 r
.75128 1.13711 m
.76356 1.14539 L
s
.75685 1.12593 m
.75128 1.13711 L
s
.92 1 0 r
.24872 1.13711 m
.23644 1.14539 L
s
.24872 1.13711 m
.24315 1.12593 L
s
0 .76 1 r
.60443 .9865 m
.59827 .97524 L
s
.60443 .9865 m
.62322 1.00033 L
s
.92 1 0 r
.39557 .9865 m
.40173 .97524 L
s
.37678 1.00033 m
.39557 .9865 L
s
0 .4 1 r
.65231 1.04487 m
.66366 1.0501 L
s
.6248 1.00497 m
.65231 1.04487 L
s
1 .72 0 r
.34769 1.04487 m
.33634 1.0501 L
s
.34769 1.04487 m
.3752 1.00497 L
s
0 .4 1 r
.61548 1.001 m
.6248 1.00497 L
s
1 .72 0 r
.38452 1.001 m
.3752 1.00497 L
s
0 .4 1 r
.54878 .89559 m
.55229 .90122 L
s
.54878 .89559 m
.59488 .96072 L
s
1 .72 0 r
.45122 .89559 m
.44771 .90122 L
s
.40512 .96072 m
.45122 .89559 L
s
0 .76 1 r
.64217 1.03275 m
.64256 1.02688 L
s
.64217 1.03275 m
.65211 1.04102 L
s
.92 1 0 r
.35783 1.03275 m
.35744 1.02688 L
s
.34789 1.04102 m
.35783 1.03275 L
s
0 .76 1 r
.76356 1.14539 m
.77585 1.1535 L
s
.76985 1.13308 m
.76356 1.14539 L
s
.92 1 0 r
.23644 1.14539 m
.22415 1.1535 L
s
.23644 1.14539 m
.23015 1.13308 L
s
0 1 .88 r
.67235 1.0575 m
.66857 1.06083 L
s
.70177 1.0852 m
.66857 1.06083 L
s
.56 1 0 r
.32765 1.0575 m
.33143 1.06083 L
s
.33143 1.06083 m
.29823 1.0852 L
s
0 .76 1 r
.6292 1.01684 m
.62621 1.00842 L
s
.6292 1.01684 m
.64256 1.02688 L
s
.92 1 0 r
.3708 1.01684 m
.37379 1.00842 L
s
.35744 1.02688 m
.3708 1.01684 L
s
0 1 .88 r
.60352 .9764 m
.59226 .96761 L
s
.59226 .96761 m
.58006 .94232 L
s
.56 1 0 r
.39648 .9764 m
.40774 .96761 L
s
.41994 .94232 m
.40774 .96761 L
s
0 .76 1 r
.70509 1.09544 m
.71799 1.10336 L
s
.70361 1.08649 m
.70509 1.09544 L
s
.92 1 0 r
.29491 1.09544 m
.28201 1.10336 L
s
.29491 1.09544 m
.29639 1.08649 L
s
0 .76 1 r
.77585 1.1535 m
.78814 1.16144 L
s
.78288 1.14006 m
.77585 1.1535 L
s
.92 1 0 r
.22415 1.1535 m
.21186 1.16144 L
s
.22415 1.1535 m
.21712 1.14006 L
s
0 .76 1 r
.67493 1.06623 m
.68634 1.07091 L
s
.66908 1.05825 m
.67493 1.06623 L
s
.92 1 0 r
.32507 1.06623 m
.31366 1.07091 L
s
.32507 1.06623 m
.33092 1.05825 L
s
0 .76 1 r
.59827 .97524 m
.59209 .964 L
s
.59827 .97524 m
.62023 .99265 L
s
.92 1 0 r
.40173 .97524 m
.40791 .964 L
s
.37977 .99265 m
.40173 .97524 L
s
0 1 .88 r
.70177 1.0852 m
.70122 1.09103 L
s
.73827 1.11125 m
.70122 1.09103 L
s
.56 1 0 r
.29823 1.0852 m
.29878 1.09103 L
s
.29878 1.09103 m
.26173 1.11125 L
s
0 1 .88 r
.58006 .94232 m
.5676 .9276 L
s
.5676 .9276 m
.56349 .91837 L
s
.56 1 0 r
.41994 .94232 m
.4324 .9276 L
s
.43651 .91837 m
.4324 .9276 L
s
0 .76 1 r
.78814 1.16144 m
.80044 1.16923 L
s
.79594 1.14687 m
.78814 1.16144 L
s
.92 1 0 r
.21186 1.16144 m
.19956 1.16923 L
s
.21186 1.16144 m
.20406 1.14687 L
s
0 .76 1 r
.65211 1.04102 m
.65585 1.03803 L
s
.65211 1.04102 m
.66129 1.0497 L
s
.92 1 0 r
.34789 1.04102 m
.34415 1.03803 L
s
.33871 1.0497 m
.34789 1.04102 L
s
0 .76 1 r
.691 1.07993 m
.70361 1.08649 L
s
.68634 1.07091 m
.691 1.07993 L
s
.92 1 0 r
.309 1.07993 m
.29639 1.08649 L
s
.309 1.07993 m
.31366 1.07091 L
s
0 .76 1 r
.66908 1.05825 m
.67854 1.06061 L
s
.66129 1.0497 m
.66908 1.05825 L
s
.92 1 0 r
.33092 1.05825 m
.32146 1.06061 L
s
.33092 1.05825 m
.33871 1.0497 L
s
0 1 .88 r
.74099 1.11863 m
.74371 1.1261 L
s
.78536 1.14104 m
.74371 1.1261 L
s
.56 1 0 r
.25901 1.11863 m
.25629 1.1261 L
s
.25629 1.1261 m
.21464 1.14104 L
s
0 .76 1 r
.80044 1.16923 m
.81274 1.17687 L
s
.80902 1.15353 m
.80044 1.16923 L
s
.92 1 0 r
.19956 1.16923 m
.18726 1.17687 L
s
.19956 1.16923 m
.19098 1.15353 L
s
0 .76 1 r
.66129 1.0497 m
.66814 1.04948 L
s
.92 1 0 r
.33871 1.0497 m
.33186 1.04948 L
s
0 1 .88 r
.65157 1.03173 m
.64477 1.03154 L
s
.64477 1.03154 m
.62132 1.00345 L
s
.67235 1.0575 m
.64477 1.03154 L
s
.56 1 0 r
.34843 1.03173 m
.35523 1.03154 L
s
.35523 1.03154 m
.32765 1.0575 L
s
.37868 1.00345 m
.35523 1.03154 L
s
0 1 .88 r
.63068 1.00761 m
.62132 1.00345 L
s
.62132 1.00345 m
.60352 .9764 L
s
.56 1 0 r
.36932 1.00761 m
.37868 1.00345 L
s
.39648 .9764 m
.37868 1.00345 L
s
0 .76 1 r
.71799 1.10336 m
.73092 1.11108 L
s
.71627 1.09291 m
.71799 1.10336 L
s
.92 1 0 r
.28201 1.10336 m
.26908 1.11108 L
s
.28201 1.10336 m
.28373 1.09291 L
s
0 .76 1 r
.59209 .964 m
.5859 .95291 L
s
.59209 .964 m
.61723 .98551 L
s
.92 1 0 r
.40791 .964 m
.4141 .95291 L
s
.38277 .98551 m
.40791 .964 L
s
0 .76 1 r
.81274 1.17687 m
.82504 1.18437 L
s
.82212 1.16004 m
.81274 1.17687 L
s
.92 1 0 r
.18726 1.17687 m
.17496 1.18437 L
s
.18726 1.17687 m
.17788 1.16004 L
s
0 1 .52 r
.59395 .96036 m
.59034 .96085 L
s
.64365 1.01367 m
.59034 .96085 L
s
.2 1 0 r
.40605 .96036 m
.40966 .96085 L
s
.40966 .96085 m
.35635 1.01367 L
s
0 .76 1 r
.62621 1.00842 m
.62322 1.00033 L
s
.62621 1.00842 m
.64296 1.02145 L
s
.92 1 0 r
.37379 1.00842 m
.37678 1.00033 L
s
.35704 1.02145 m
.37379 1.00842 L
s
0 .76 1 r
.82504 1.18437 m
.83734 1.19174 L
s
.83524 1.1664 m
.82504 1.18437 L
s
.92 1 0 r
.17496 1.18437 m
.16266 1.19174 L
s
.17496 1.18437 m
.16476 1.1664 L
s
0 1 .88 r
.55061 .9 m
.53779 .87841 L
s
.53779 .87841 m
.54431 .9191 L
s
.56 1 0 r
.44939 .9 m
.46221 .87841 L
s
.45569 .9191 m
.46221 .87841 L
s
0 .4 1 r
.66366 1.0501 m
.67508 1.05533 L
s
.63419 1.00922 m
.66366 1.0501 L
s
1 .72 0 r
.33634 1.0501 m
.32492 1.05533 L
s
.33634 1.0501 m
.36581 1.00922 L
s
.4118 .95717 m
.40512 .96072 L
s
.3752 1.00497 m
.4118 .95717 L
s
0 .4 1 r
.5882 .95717 m
.59488 .96072 L
s
.5882 .95717 m
.6248 1.00497 L
s
0 .76 1 r
.64256 1.02688 m
.64296 1.02145 L
s
.64256 1.02688 m
.65585 1.03803 L
s
.92 1 0 r
.35744 1.02688 m
.35704 1.02145 L
s
.34415 1.03803 m
.35744 1.02688 L
s
0 .76 1 r
.84838 1.17264 m
.83734 1.19174 L
s
.92 1 0 r
.16266 1.19174 m
.15162 1.17264 L
s
0 .4 1 r
.6248 1.00497 m
.63419 1.00922 L
s
1 .72 0 r
.3752 1.00497 m
.36581 1.00922 L
s
0 .76 1 r
.5859 .95291 m
.5797 .94211 L
s
.5859 .95291 m
.61424 .97904 L
s
.92 1 0 r
.4141 .95291 m
.4203 .94211 L
s
.38576 .97904 m
.4141 .95291 L
s
0 1 .88 r
.67617 1.05453 m
.67235 1.0575 L
s
.70232 1.0796 m
.67235 1.0575 L
s
.56 1 0 r
.32383 1.05453 m
.32765 1.0575 L
s
.32765 1.0575 m
.29768 1.0796 L
s
0 .76 1 r
.73092 1.11108 m
.74387 1.1186 L
s
.72897 1.09917 m
.73092 1.11108 L
s
.92 1 0 r
.26908 1.11108 m
.25613 1.1186 L
s
.26908 1.11108 m
.27103 1.09917 L
s
0 .76 1 r
.68634 1.07091 m
.69781 1.07557 L
s
.67854 1.06061 m
.68634 1.07091 L
s
.92 1 0 r
.31366 1.07091 m
.30219 1.07557 L
s
.31366 1.07091 m
.32146 1.06061 L
s
0 1 .88 r
.70232 1.0796 m
.70177 1.0852 L
s
.73554 1.104 m
.70177 1.0852 L
s
.56 1 0 r
.29768 1.0796 m
.29823 1.0852 L
s
.29823 1.0852 m
.26446 1.104 L
s
0 .76 1 r
.70361 1.08649 m
.71627 1.09291 L
s
.69781 1.07557 m
.70361 1.08649 L
s
.92 1 0 r
.29639 1.08649 m
.28373 1.09291 L
s
.29639 1.08649 m
.30219 1.07557 L
s
0 1 .88 r
.73827 1.11125 m
.74099 1.11863 L
s
.77951 1.13295 m
.74099 1.11863 L
s
.56 1 0 r
.26173 1.11125 m
.25901 1.11863 L
s
.25901 1.11863 m
.22049 1.13295 L
s
0 1 .88 r
.61486 .98506 m
.60352 .9764 L
s
.60352 .9764 m
.5926 .95591 L
s
.56 1 0 r
.38514 .98506 m
.39648 .9764 L
s
.4074 .95591 m
.39648 .9764 L
s
.20301 1.15726 m
.19722 1.16539 L
s
.19722 1.16539 m
.15162 1.17264 L
s
0 1 .88 r
.79699 1.15726 m
.80278 1.16539 L
s
.84838 1.17264 m
.80278 1.16539 L
s
0 .76 1 r
.65585 1.03803 m
.65964 1.03547 L
s
.65585 1.03803 m
.66814 1.04948 L
s
.92 1 0 r
.34415 1.03803 m
.34036 1.03547 L
s
.33186 1.04948 m
.34415 1.03803 L
s
.2 1 0 r
.4389 .91529 m
.44555 .90429 L
s
.44555 .90429 m
.4024 .96096 L
s
.48214 .86231 m
.44555 .90429 L
s
0 1 .52 r
.5611 .91529 m
.55445 .90429 L
s
.55445 .90429 m
.51786 .86231 L
s
.5976 .96096 m
.55445 .90429 L
s
0 .76 1 r
.5797 .94211 m
.57349 .93189 L
s
.5797 .94211 m
.61125 .97337 L
s
.92 1 0 r
.4203 .94211 m
.42651 .93189 L
s
.38875 .97337 m
.4203 .94211 L
s
0 .76 1 r
.62322 1.00033 m
.62023 .99265 L
s
.62322 1.00033 m
.64338 1.0165 L
s
.92 1 0 r
.37678 1.00033 m
.37977 .99265 L
s
.35662 1.0165 m
.37678 1.00033 L
s
0 .76 1 r
.67854 1.06061 m
.68807 1.06311 L
s
.66814 1.04948 m
.67854 1.06061 L
s
.92 1 0 r
.32146 1.06061 m
.31193 1.06311 L
s
.32146 1.06061 m
.33186 1.04948 L
s
.25613 1.1186 m
.24315 1.12593 L
s
.25613 1.1186 m
.25827 1.10527 L
s
0 .76 1 r
.74387 1.1186 m
.75685 1.12593 L
s
.74173 1.10527 m
.74387 1.1186 L
s
0 1 .88 r
.5926 .95591 m
.58006 .94232 L
s
.58006 .94232 m
.57642 .93453 L
s
.56 1 0 r
.4074 .95591 m
.41994 .94232 L
s
.42358 .93453 m
.41994 .94232 L
s
0 .4 1 r
.55229 .90122 m
.60164 .96501 L
s
1 .72 0 r
.39836 .96501 m
.44771 .90122 L
s
0 .76 1 r
.66814 1.04948 m
.67504 1.04958 L
s
.92 1 0 r
.33186 1.04948 m
.32496 1.04958 L
s
.2 1 0 r
.473 .88725 m
.48214 .86231 L
s
.51046 .91278 m
.48214 .86231 L
s
0 1 .52 r
.527 .88725 m
.51786 .86231 L
s
.51786 .86231 m
.48954 .91278 L
s
0 1 .88 r
.65843 1.0323 m
.65157 1.03173 L
s
.65157 1.03173 m
.63068 1.00761 L
s
.67617 1.05453 m
.65157 1.03173 L
s
.56 1 0 r
.34157 1.0323 m
.34843 1.03173 L
s
.34843 1.03173 m
.32383 1.05453 L
s
.36932 1.00761 m
.34843 1.03173 L
s
0 1 .88 r
.64012 1.01199 m
.63068 1.00761 L
s
.63068 1.00761 m
.61486 .98506 L
s
.56 1 0 r
.35988 1.01199 m
.36932 1.00761 L
s
.38514 .98506 m
.36932 1.00761 L
s
0 .4 1 r
.64365 1.01367 m
.67508 1.05533 L
s
1 .72 0 r
.32492 1.05533 m
.35635 1.01367 L
s
0 .76 1 r
.64296 1.02145 m
.64338 1.0165 L
s
.64296 1.02145 m
.65964 1.03547 L
s
.92 1 0 r
.35704 1.02145 m
.35662 1.0165 L
s
.34036 1.03547 m
.35704 1.02145 L
s
.56 1 0 r
.20882 1.14915 m
.20301 1.15726 L
s
.20301 1.15726 m
.16023 1.16459 L
s
0 1 .88 r
.79118 1.14915 m
.79699 1.15726 L
s
.83977 1.16459 m
.79699 1.15726 L
s
0 .76 1 r
.71627 1.09291 m
.72897 1.09917 L
s
.70935 1.0802 m
.71627 1.09291 L
s
.92 1 0 r
.28373 1.09291 m
.27103 1.09917 L
s
.28373 1.09291 m
.29065 1.0802 L
s
0 .76 1 r
.57349 .93189 m
.56728 .92264 L
s
.57349 .93189 m
.60826 .96864 L
s
.92 1 0 r
.42651 .93189 m
.43272 .92264 L
s
.39174 .96864 m
.42651 .93189 L
s
0 1 .52 r
.5976 .96096 m
.59395 .96036 L
s
.6441 1.00963 m
.59395 .96036 L
s
.2 1 0 r
.4024 .96096 m
.40605 .96036 L
s
.40605 .96036 m
.3559 1.00963 L
s
.56 1 0 r
.26446 1.104 m
.26173 1.11125 L
s
.26173 1.11125 m
.22635 1.1249 L
s
0 1 .88 r
.73554 1.104 m
.73827 1.11125 L
s
.77365 1.1249 m
.73827 1.11125 L
s
0 .76 1 r
.75685 1.12593 m
.76985 1.13308 L
s
.75452 1.11122 m
.75685 1.12593 L
s
.92 1 0 r
.24315 1.12593 m
.23015 1.13308 L
s
.24315 1.12593 m
.24548 1.11122 L
s
0 .76 1 r
.69781 1.07557 m
.70935 1.0802 L
s
.68807 1.06311 m
.69781 1.07557 L
s
.92 1 0 r
.30219 1.07557 m
.29065 1.0802 L
s
.30219 1.07557 m
.31193 1.06311 L
s
0 1 .88 r
.7029 1.07427 m
.70232 1.0796 L
s
.73281 1.09689 m
.70232 1.0796 L
s
.56 1 0 r
.2971 1.07427 m
.29768 1.0796 L
s
.29768 1.0796 m
.26719 1.09689 L
s
0 1 .88 r
.68002 1.05193 m
.67617 1.05453 L
s
.7029 1.07427 m
.67617 1.05453 L
s
.56 1 0 r
.31998 1.05193 m
.32383 1.05453 L
s
.32383 1.05453 m
.2971 1.07427 L
s
0 .4 1 r
.59488 .96072 m
.60164 .96501 L
s
.59488 .96072 m
.63419 1.00922 L
s
1 .72 0 r
.40512 .96072 m
.39836 .96501 L
s
.36581 1.00922 m
.40512 .96072 L
s
0 .4 1 r
.63419 1.00922 m
.64365 1.01367 L
s
1 .72 0 r
.36581 1.00922 m
.35635 1.01367 L
s
0 1 .88 r
.56349 .91837 m
.55061 .9 L
s
.55061 .9 m
.55678 .92737 L
s
.56 1 0 r
.43651 .91837 m
.44939 .9 L
s
.44322 .92737 m
.44939 .9 L
s
0 .76 1 r
.62023 .99265 m
.61723 .98551 L
s
.62023 .99265 m
.64382 1.01209 L
s
.92 1 0 r
.37977 .99265 m
.38277 .98551 L
s
.35618 1.01209 m
.37977 .99265 L
s
0 1 .88 r
.78536 1.14104 m
.79118 1.14915 L
s
.83113 1.15651 m
.79118 1.14915 L
s
.56 1 0 r
.21464 1.14104 m
.20882 1.14915 L
s
.20882 1.14915 m
.16887 1.15651 L
s
0 .76 1 r
.76985 1.13308 m
.78288 1.14006 L
s
.76737 1.11702 m
.76985 1.13308 L
s
.92 1 0 r
.23015 1.13308 m
.21712 1.14006 L
s
.23015 1.13308 m
.23263 1.11702 L
s
0 .76 1 r
.56728 .92264 m
.56107 .91499 L
s
.56728 .92264 m
.60528 .96499 L
s
.92 1 0 r
.43272 .92264 m
.43893 .91499 L
s
.39472 .96499 m
.43272 .92264 L
s
0 1 .88 r
.62628 .99349 m
.61486 .98506 L
s
.61486 .98506 m
.6052 .96845 L
s
.56 1 0 r
.37372 .99349 m
.38514 .98506 L
s
.3948 .96845 m
.38514 .98506 L
s
0 .76 1 r
.65964 1.03547 m
.66346 1.03336 L
s
.65964 1.03547 m
.67504 1.04958 L
s
.92 1 0 r
.34036 1.03547 m
.33654 1.03336 L
s
.32496 1.04958 m
.34036 1.03547 L
s
0 .76 1 r
.68807 1.06311 m
.69766 1.06573 L
s
.67504 1.04958 m
.68807 1.06311 L
s
.92 1 0 r
.31193 1.06311 m
.30234 1.06573 L
s
.31193 1.06311 m
.32496 1.04958 L
s
0 1 .16 r
.5 .88913 m
.5 .86523 L
s
.5 .86523 m
.45359 .91227 L
s
.54641 .91227 m
.5 .86523 L
s
.92 1 0 r
.27103 1.09917 m
.25827 1.10527 L
s
.27103 1.09917 m
.27906 1.08478 L
s
0 .76 1 r
.72897 1.09917 m
.74173 1.10527 L
s
.72094 1.08478 m
.72897 1.09917 L
s
.67504 1.04958 m
.682 1.04996 L
s
.92 1 0 r
.32496 1.04958 m
.318 1.04996 L
s
0 1 .88 r
.73281 1.09689 m
.73554 1.104 L
s
.76777 1.11689 m
.73554 1.104 L
s
.56 1 0 r
.26719 1.09689 m
.26446 1.104 L
s
.26446 1.104 m
.23223 1.11689 L
s
0 1 .88 r
.6052 .96845 m
.5926 .95591 L
s
.5926 .95591 m
.58941 .94908 L
s
.56 1 0 r
.3948 .96845 m
.4074 .95591 L
s
.41059 .94908 m
.4074 .95591 L
s
0 .76 1 r
.64338 1.0165 m
.64382 1.01209 L
s
.64338 1.0165 m
.66346 1.03336 L
s
.92 1 0 r
.35662 1.0165 m
.35618 1.01209 L
s
.33654 1.03336 m
.35662 1.0165 L
s
.56 1 0 r
.33464 1.03322 m
.34157 1.0323 L
s
.34157 1.0323 m
.31998 1.05193 L
s
.35988 1.01199 m
.34157 1.0323 L
s
0 1 .88 r
.66536 1.03322 m
.65843 1.0323 L
s
.65843 1.0323 m
.64012 1.01199 L
s
.68002 1.05193 m
.65843 1.0323 L
s
0 .76 1 r
.78288 1.14006 m
.79594 1.14687 L
s
.78026 1.12267 m
.78288 1.14006 L
s
.92 1 0 r
.21712 1.14006 m
.20406 1.14687 L
s
.21712 1.14006 m
.21974 1.12267 L
s
0 .76 1 r
.70935 1.0802 m
.72094 1.08478 L
s
.69766 1.06573 m
.70935 1.0802 L
s
.92 1 0 r
.29065 1.0802 m
.27906 1.08478 L
s
.29065 1.0802 m
.30234 1.06573 L
s
0 1 .88 r
.64963 1.01652 m
.64012 1.01199 L
s
.64012 1.01199 m
.62628 .99349 L
s
.56 1 0 r
.35037 1.01652 m
.35988 1.01199 L
s
.37372 .99349 m
.35988 1.01199 L
s
0 1 .88 r
.70349 1.06923 m
.7029 1.07427 L
s
.73008 1.08995 m
.7029 1.07427 L
s
.56 1 0 r
.29651 1.06923 m
.2971 1.07427 L
s
.2971 1.07427 m
.26992 1.08995 L
s
.22049 1.13295 m
.21464 1.14104 L
s
.21464 1.14104 m
.17752 1.14839 L
s
0 1 .88 r
.77951 1.13295 m
.78536 1.14104 L
s
.82248 1.14839 m
.78536 1.14104 L
s
0 .76 1 r
.61723 .98551 m
.61424 .97904 L
s
.61723 .98551 m
.64428 1.00828 L
s
.92 1 0 r
.38277 .98551 m
.38576 .97904 L
s
.35572 1.00828 m
.38277 .98551 L
s
.43893 .91499 m
.44514 .90971 L
s
.39769 .96249 m
.43893 .91499 L
s
0 .76 1 r
.56107 .91499 m
.55486 .90971 L
s
.56107 .91499 m
.60231 .96249 L
s
0 1 .88 r
.68391 1.04969 m
.68002 1.05193 L
s
.70349 1.06923 m
.68002 1.05193 L
s
.56 1 0 r
.31609 1.04969 m
.31998 1.05193 L
s
.31998 1.05193 m
.29651 1.06923 L
s
.2 1 0 r
.3987 .96259 m
.4024 .96096 L
s
.4024 .96096 m
.35543 1.0062 L
s
0 1 .52 r
.6013 .96259 m
.5976 .96096 L
s
.64457 1.0062 m
.5976 .96096 L
s
0 1 .16 r
.45052 .90729 m
.44744 .90521 L
s
.54948 .90729 m
.55256 .90521 L
s
.44744 .90521 m
.39663 .96448 L
s
.60337 .96448 m
.55256 .90521 L
s
0 1 .52 r
.56782 .9264 m
.5611 .91529 L
s
.5611 .91529 m
.527 .88725 L
s
.6013 .96259 m
.5611 .91529 L
s
.2 1 0 r
.43218 .9264 m
.4389 .91529 L
s
.4389 .91529 m
.3987 .96259 L
s
.473 .88725 m
.4389 .91529 L
s
0 .76 1 r
.79594 1.14687 m
.80902 1.15353 L
s
.79319 1.12817 m
.79594 1.14687 L
s
.92 1 0 r
.20406 1.14687 m
.19098 1.15353 L
s
.20406 1.14687 m
.20681 1.12817 L
s
0 .76 1 r
.74173 1.10527 m
.75452 1.11122 L
s
.7326 1.08928 m
.74173 1.10527 L
s
.92 1 0 r
.25827 1.10527 m
.24548 1.11122 L
s
.25827 1.10527 m
.2674 1.08928 L
s
0 1 .88 r
.57642 .93453 m
.56349 .91837 L
s
.56349 .91837 m
.56927 .93681 L
s
.56 1 0 r
.42358 .93453 m
.43651 .91837 L
s
.43073 .93681 m
.43651 .91837 L
s
0 .4 1 r
.60164 .96501 m
.64365 1.01367 L
s
1 .72 0 r
.35635 1.01367 m
.39836 .96501 L
s
0 1 .52 r
.6441 1.00963 m
.64365 1.01367 L
s
.69809 1.05176 m
.64365 1.01367 L
s
.2 1 0 r
.3559 1.00963 m
.35635 1.01367 L
s
.35635 1.01367 m
.30191 1.05176 L
s
0 1 .88 r
.73008 1.08995 m
.73281 1.09689 L
s
.76188 1.10894 m
.73281 1.09689 L
s
.56 1 0 r
.26992 1.08995 m
.26719 1.09689 L
s
.26719 1.09689 m
.23812 1.10894 L
s
0 .76 1 r
.66346 1.03336 m
.66732 1.03168 L
s
.66346 1.03336 m
.682 1.04996 L
s
.92 1 0 r
.33654 1.03336 m
.33268 1.03168 L
s
.318 1.04996 m
.33654 1.03336 L
s
0 1 .88 r
.77365 1.1249 m
.77951 1.13295 L
s
.8138 1.14025 m
.77951 1.13295 L
s
.56 1 0 r
.22635 1.1249 m
.22049 1.13295 L
s
.22049 1.13295 m
.1862 1.14025 L
s
0 .76 1 r
.69766 1.06573 m
.70732 1.06844 L
s
.682 1.04996 m
.69766 1.06573 L
s
.92 1 0 r
.30234 1.06573 m
.29268 1.06844 L
s
.30234 1.06573 m
.318 1.04996 L
s
0 1 .88 r
.63777 1.00162 m
.62628 .99349 L
s
.62628 .99349 m
.61787 .98007 L
s
.56 1 0 r
.36223 1.00162 m
.37372 .99349 L
s
.38213 .98007 m
.37372 .99349 L
s
0 .76 1 r
.80902 1.15353 m
.82212 1.16004 L
s
.80617 1.13352 m
.80902 1.15353 L
s
.92 1 0 r
.19098 1.15353 m
.17788 1.16004 L
s
.19098 1.15353 m
.19383 1.13352 L
s
0 .76 1 r
.64382 1.01209 m
.64428 1.00828 L
s
.64382 1.01209 m
.66732 1.03168 L
s
.92 1 0 r
.35618 1.01209 m
.35572 1.00828 L
s
.33268 1.03168 m
.35618 1.01209 L
s
0 .76 1 r
.682 1.04996 m
.68901 1.05061 L
s
.92 1 0 r
.318 1.04996 m
.31099 1.05061 L
s
0 .76 1 r
.61424 .97904 m
.61125 .97337 L
s
.61424 .97904 m
.64476 1.00508 L
s
.92 1 0 r
.38576 .97904 m
.38875 .97337 L
s
.35524 1.00508 m
.38576 .97904 L
s
0 .76 1 r
.72094 1.08478 m
.7326 1.08928 L
s
.70732 1.06844 m
.72094 1.08478 L
s
.92 1 0 r
.27906 1.08478 m
.2674 1.08928 L
s
.27906 1.08478 m
.29268 1.06844 L
s
.44514 .90971 m
.45135 .90758 L
s
.40067 .96115 m
.44514 .90971 L
s
0 .76 1 r
.55486 .90971 m
.54865 .90758 L
s
.55486 .90971 m
.59933 .96115 L
s
0 1 .88 r
.61787 .98007 m
.6052 .96845 L
s
.6052 .96845 m
.60245 .96237 L
s
.56 1 0 r
.38213 .98007 m
.3948 .96845 L
s
.39755 .96237 m
.3948 .96845 L
s
0 1 .88 r
.70409 1.06449 m
.70349 1.06923 L
s
.72734 1.08319 m
.70349 1.06923 L
s
.56 1 0 r
.29591 1.06449 m
.29651 1.06923 L
s
.29651 1.06923 m
.27266 1.08319 L
s
0 1 .88 r
.67234 1.03442 m
.66536 1.03322 L
s
.66536 1.03322 m
.64963 1.01652 L
s
.68391 1.04969 m
.66536 1.03322 L
s
.56 1 0 r
.32766 1.03442 m
.33464 1.03322 L
s
.33464 1.03322 m
.31609 1.04969 L
s
.35037 1.01652 m
.33464 1.03322 L
s
0 .76 1 r
.75452 1.11122 m
.76737 1.11702 L
s
.74432 1.0937 m
.75452 1.11122 L
s
.92 1 0 r
.24548 1.11122 m
.23263 1.11702 L
s
.24548 1.11122 m
.25568 1.0937 L
s
0 .76 1 r
.82212 1.16004 m
.83524 1.1664 L
s
.81918 1.13874 m
.82212 1.16004 L
s
.92 1 0 r
.17788 1.16004 m
.16476 1.1664 L
s
.17788 1.16004 m
.18082 1.13874 L
s
0 1 .88 r
.65921 1.02111 m
.64963 1.01652 L
s
.64963 1.01652 m
.63777 1.00162 L
s
.56 1 0 r
.34079 1.02111 m
.35037 1.01652 L
s
.36223 1.00162 m
.35037 1.01652 L
s
.2 1 0 r
.46376 .9063 m
.473 .88725 L
s
.49928 .91858 m
.473 .88725 L
s
0 1 .52 r
.53624 .9063 m
.527 .88725 L
s
.527 .88725 m
.50072 .91858 L
s
0 1 .88 r
.76777 1.11689 m
.77365 1.1249 L
s
.8051 1.13208 m
.77365 1.1249 L
s
.56 1 0 r
.23223 1.11689 m
.22635 1.1249 L
s
.22635 1.1249 m
.1949 1.13208 L
s
0 1 .88 r
.68784 1.04781 m
.68391 1.04969 L
s
.70409 1.06449 m
.68391 1.04969 L
s
.56 1 0 r
.31216 1.04781 m
.31609 1.04969 L
s
.31609 1.04969 m
.29591 1.06449 L
s
0 1 .88 r
.72734 1.08319 m
.73008 1.08995 L
s
.75596 1.10106 m
.73008 1.08995 L
s
.56 1 0 r
.27266 1.08319 m
.26992 1.08995 L
s
.26992 1.08995 m
.24404 1.10106 L
s
0 1 .52 r
.64457 1.0062 m
.6441 1.00963 L
s
.69529 1.04581 m
.6441 1.00963 L
s
.2 1 0 r
.35543 1.0062 m
.3559 1.00963 L
s
.3559 1.00963 m
.30471 1.04581 L
s
0 1 .88 r
.58941 .94908 m
.57642 .93453 L
s
.57642 .93453 m
.5818 .94684 L
s
.56 1 0 r
.41059 .94908 m
.42358 .93453 L
s
.4182 .94684 m
.42358 .93453 L
s
0 .76 1 r
.83524 1.1664 m
.84838 1.17264 L
s
.83224 1.14382 m
.83524 1.1664 L
s
.92 1 0 r
.16476 1.1664 m
.15162 1.17264 L
s
.16476 1.1664 m
.16776 1.14382 L
s
0 1 .52 r
.60505 .96508 m
.6013 .96259 L
s
.64507 1.0034 m
.6013 .96259 L
s
.2 1 0 r
.39495 .96508 m
.3987 .96259 L
s
.3987 .96259 m
.35493 1.0034 L
s
0 1 .16 r
.45359 .91227 m
.45052 .90729 L
s
.54641 .91227 m
.54948 .90729 L
s
.45052 .90729 m
.40282 .96112 L
s
.59718 .96112 m
.54948 .90729 L
s
0 .76 1 r
.70732 1.06844 m
.71704 1.0712 L
s
.68901 1.05061 m
.70732 1.06844 L
s
.92 1 0 r
.29268 1.06844 m
.28296 1.0712 L
s
.29268 1.06844 m
.31099 1.05061 L
s
0 .76 1 r
.66732 1.03168 m
.67122 1.03043 L
s
.66732 1.03168 m
.68901 1.05061 L
s
.92 1 0 r
.33268 1.03168 m
.32878 1.03043 L
s
.31099 1.05061 m
.33268 1.03168 L
s
0 .76 1 r
.76737 1.11702 m
.78026 1.12267 L
s
.75609 1.09801 m
.76737 1.11702 L
s
.92 1 0 r
.23263 1.11702 m
.21974 1.12267 L
s
.23263 1.11702 m
.24391 1.09801 L
s
0 .76 1 r
.61125 .97337 m
.60826 .96864 L
s
.61125 .97337 m
.64526 1.00252 L
s
.92 1 0 r
.38875 .97337 m
.39174 .96864 L
s
.35474 1.00252 m
.38875 .97337 L
s
0 .76 1 r
.7326 1.08928 m
.74432 1.0937 L
s
.71704 1.0712 m
.7326 1.08928 L
s
.92 1 0 r
.2674 1.08928 m
.25568 1.0937 L
s
.2674 1.08928 m
.28296 1.0712 L
s
0 1 .88 r
.76188 1.10894 m
.76777 1.11689 L
s
.79638 1.12389 m
.76777 1.11689 L
s
.56 1 0 r
.23812 1.10894 m
.23223 1.11689 L
s
.23223 1.11689 m
.20362 1.12389 L
s
0 1 .88 r
.64933 1.00942 m
.63777 1.00162 L
s
.63777 1.00162 m
.6306 .99087 L
s
.56 1 0 r
.35067 1.00942 m
.36223 1.00162 L
s
.3694 .99087 m
.36223 1.00162 L
s
0 .76 1 r
.64428 1.00828 m
.64476 1.00508 L
s
.64428 1.00828 m
.67122 1.03043 L
s
.92 1 0 r
.35572 1.00828 m
.35524 1.00508 L
s
.32878 1.03043 m
.35572 1.00828 L
s
0 .76 1 r
.84534 1.14876 m
.84838 1.17264 L
s
.92 1 0 r
.15162 1.17264 m
.15466 1.14876 L
s
0 1 .88 r
.83977 1.16459 m
.84838 1.17264 L
s
.88559 1.1715 m
.84838 1.17264 L
s
.56 1 0 r
.16023 1.16459 m
.15162 1.17264 L
s
.15162 1.17264 m
.11441 1.1715 L
s
.92 1 0 r
.45135 .90758 m
.45757 .90891 L
s
.40364 .9609 m
.45135 .90758 L
s
0 .76 1 r
.54865 .90758 m
.54243 .90891 L
s
.54865 .90758 m
.59636 .9609 L
s
0 1 .88 r
.70471 1.06007 m
.70409 1.06449 L
s
.72459 1.07663 m
.70409 1.06449 L
s
.56 1 0 r
.29529 1.06007 m
.29591 1.06449 L
s
.29591 1.06449 m
.27541 1.07663 L
s
0 1 .88 r
.6306 .99087 m
.61787 .98007 L
s
.61787 .98007 m
.61553 .97465 L
s
.56 1 0 r
.3694 .99087 m
.38213 .98007 L
s
.38447 .97465 m
.38213 .98007 L
s
.92 1 0 r
.31099 1.05061 m
.30392 1.05148 L
s
0 .76 1 r
.68901 1.05061 m
.69608 1.05148 L
s
0 1 .88 r
.72459 1.07663 m
.72734 1.08319 L
s
.75004 1.09326 m
.72734 1.08319 L
s
.56 1 0 r
.27541 1.07663 m
.27266 1.08319 L
s
.27266 1.08319 m
.24996 1.09326 L
s
.2 1 0 r
.42538 .93699 m
.43218 .9264 L
s
.43218 .9264 m
.39495 .96508 L
s
.46376 .9063 m
.43218 .9264 L
s
0 1 .52 r
.57462 .93699 m
.56782 .9264 L
s
.56782 .9264 m
.53624 .9063 L
s
.60505 .96508 m
.56782 .9264 L
s
0 1 .88 r
.67937 1.03588 m
.67234 1.03442 L
s
.67234 1.03442 m
.65921 1.02111 L
s
.68784 1.04781 m
.67234 1.03442 L
s
.56 1 0 r
.32063 1.03588 m
.32766 1.03442 L
s
.32766 1.03442 m
.31216 1.04781 L
s
.34079 1.02111 m
.32766 1.03442 L
s
0 1 .88 r
.83113 1.15651 m
.83977 1.16459 L
s
.8746 1.16397 m
.83977 1.16459 L
s
.56 1 0 r
.16887 1.15651 m
.16023 1.16459 L
s
.16023 1.16459 m
.1254 1.16397 L
s
0 1 .88 r
.66885 1.0257 m
.65921 1.02111 L
s
.65921 1.02111 m
.64933 1.00942 L
s
.56 1 0 r
.33115 1.0257 m
.34079 1.02111 L
s
.35067 1.00942 m
.34079 1.02111 L
s
0 1 .88 r
.69181 1.04628 m
.68784 1.04781 L
s
.70471 1.06007 m
.68784 1.04781 L
s
.56 1 0 r
.30819 1.04628 m
.31216 1.04781 L
s
.31216 1.04781 m
.29529 1.06007 L
s
0 1 .88 r
.60245 .96237 m
.58941 .94908 L
s
.58941 .94908 m
.59435 .9571 L
s
.56 1 0 r
.39755 .96237 m
.41059 .94908 L
s
.40565 .9571 m
.41059 .94908 L
s
0 .76 1 r
.78026 1.12267 m
.79319 1.12817 L
s
.76793 1.10222 m
.78026 1.12267 L
s
.92 1 0 r
.21974 1.12267 m
.20681 1.12817 L
s
.21974 1.12267 m
.23207 1.10222 L
s
.56 1 0 r
.24404 1.10106 m
.23812 1.10894 L
s
.23812 1.10894 m
.21236 1.11568 L
s
0 1 .88 r
.75596 1.10106 m
.76188 1.10894 L
s
.78764 1.11568 m
.76188 1.10894 L
s
0 1 .16 r
.5 .90692 m
.5 .88913 L
s
.5 .88913 m
.45668 .91909 L
s
.54332 .91909 m
.5 .88913 L
s
.2 1 0 r
.35493 1.0034 m
.35543 1.0062 L
s
.35543 1.0062 m
.30751 1.04023 L
s
0 1 .52 r
.64507 1.0034 m
.64457 1.0062 L
s
.69249 1.04023 m
.64457 1.0062 L
s
0 1 .88 r
.82248 1.14839 m
.83113 1.15651 L
s
.86359 1.15638 m
.83113 1.15651 L
s
.56 1 0 r
.17752 1.14839 m
.16887 1.15651 L
s
.16887 1.15651 m
.13641 1.15638 L
s
0 .76 1 r
.74432 1.0937 m
.75609 1.09801 L
s
.72682 1.07397 m
.74432 1.0937 L
s
.92 1 0 r
.25568 1.0937 m
.24391 1.09801 L
s
.25568 1.0937 m
.27318 1.07397 L
s
.39174 .96864 m
.39472 .96499 L
s
.35422 1.00059 m
.39174 .96864 L
s
0 .76 1 r
.60826 .96864 m
.60528 .96499 L
s
.60826 .96864 m
.64578 1.00059 L
s
.71704 1.0712 m
.72682 1.07397 L
s
.69608 1.05148 m
.71704 1.0712 L
s
.92 1 0 r
.28296 1.0712 m
.27318 1.07397 L
s
.28296 1.0712 m
.30392 1.05148 L
s
0 .76 1 r
.67122 1.03043 m
.67517 1.02958 L
s
.67122 1.03043 m
.69608 1.05148 L
s
.92 1 0 r
.32878 1.03043 m
.32483 1.02958 L
s
.30392 1.05148 m
.32878 1.03043 L
s
0 1 .88 r
.70535 1.05599 m
.70471 1.06007 L
s
.72185 1.07032 m
.70471 1.06007 L
s
.56 1 0 r
.29465 1.05599 m
.29529 1.06007 L
s
.29529 1.06007 m
.27815 1.07032 L
s
0 .76 1 r
.64476 1.00508 m
.64526 1.00252 L
s
.64476 1.00508 m
.67517 1.02958 L
s
.92 1 0 r
.35524 1.00508 m
.35474 1.00252 L
s
.32483 1.02958 m
.35524 1.00508 L
s
0 1 .88 r
.72185 1.07032 m
.72459 1.07663 L
s
.74409 1.08558 m
.72459 1.07663 L
s
.56 1 0 r
.27815 1.07032 m
.27541 1.07663 L
s
.27541 1.07663 m
.25591 1.08558 L
s
0 1 .88 r
.66095 1.01686 m
.64933 1.00942 L
s
.64933 1.00942 m
.64338 1.00095 L
s
.56 1 0 r
.33905 1.01686 m
.35067 1.00942 L
s
.35662 1.00095 m
.35067 1.00942 L
s
0 1 .88 r
.64338 1.00095 m
.6306 .99087 L
s
.6306 .99087 m
.62865 .9861 L
s
.56 1 0 r
.35662 1.00095 m
.3694 .99087 L
s
.37135 .9861 m
.3694 .99087 L
s
0 1 .88 r
.75004 1.09326 m
.75596 1.10106 L
s
.77887 1.10748 m
.75596 1.10106 L
s
.56 1 0 r
.24996 1.09326 m
.24404 1.10106 L
s
.24404 1.10106 m
.22113 1.10748 L
s
0 1 .52 r
.60885 .96824 m
.60505 .96508 L
s
.64558 1.00124 m
.60505 .96508 L
s
.2 1 0 r
.39115 .96824 m
.39495 .96508 L
s
.39495 .96508 m
.35442 1.00124 L
s
0 .76 1 r
.79319 1.12817 m
.80617 1.13352 L
s
.77982 1.10632 m
.79319 1.12817 L
s
.92 1 0 r
.20681 1.12817 m
.19383 1.13352 L
s
.20681 1.12817 m
.22018 1.10632 L
s
0 1 .88 r
.8138 1.14025 m
.82248 1.14839 L
s
.85258 1.14871 m
.82248 1.14839 L
s
.56 1 0 r
.1862 1.14025 m
.17752 1.14839 L
s
.17752 1.14839 m
.14742 1.14871 L
s
0 .76 1 r
.54243 .90891 m
.59338 .9616 L
s
.92 1 0 r
.40662 .9616 m
.45757 .90891 L
s
0 .76 1 r
.69608 1.05148 m
.70321 1.05253 L
s
.92 1 0 r
.30392 1.05148 m
.29679 1.05253 L
s
0 1 .88 r
.61553 .97465 m
.60245 .96237 L
s
.60245 .96237 m
.60692 .96737 L
s
.56 1 0 r
.38447 .97465 m
.39755 .96237 L
s
.39308 .96737 m
.39755 .96237 L
s
0 1 .16 r
.54332 .91909 m
.54641 .91227 L
s
.59098 .95896 m
.54641 .91227 L
s
.45668 .91909 m
.45359 .91227 L
s
.45359 .91227 m
.40902 .95896 L
s
0 1 .52 r
.54556 .92176 m
.53624 .9063 L
s
.53624 .9063 m
.51197 .92584 L
s
.2 1 0 r
.45444 .92176 m
.46376 .9063 L
s
.48803 .92584 m
.46376 .9063 L
s
0 1 .88 r
.68647 1.03752 m
.67937 1.03588 L
s
.67937 1.03588 m
.66885 1.0257 L
s
.69181 1.04628 m
.67937 1.03588 L
s
.56 1 0 r
.31353 1.03752 m
.32063 1.03588 L
s
.32063 1.03588 m
.30819 1.04628 L
s
.33115 1.0257 m
.32063 1.03588 L
s
0 1 .88 r
.8051 1.13208 m
.8138 1.14025 L
s
.84154 1.14098 m
.8138 1.14025 L
s
.56 1 0 r
.1949 1.13208 m
.1862 1.14025 L
s
.1862 1.14025 m
.15846 1.14098 L
s
.2 1 0 r
.30471 1.04581 m
.30191 1.05176 L
s
.30191 1.05176 m
.24968 1.07748 L
s
0 1 .52 r
.69529 1.04581 m
.69809 1.05176 L
s
.75032 1.07748 m
.69809 1.05176 L
s
0 1 .88 r
.69583 1.04508 m
.69181 1.04628 L
s
.70535 1.05599 m
.69181 1.04628 L
s
.56 1 0 r
.30417 1.04508 m
.30819 1.04628 L
s
.30819 1.04628 m
.29465 1.05599 L
s
0 1 .88 r
.67857 1.03024 m
.66885 1.0257 L
s
.66885 1.0257 m
.66095 1.01686 L
s
.56 1 0 r
.32143 1.03024 m
.33115 1.0257 L
s
.33905 1.01686 m
.33115 1.0257 L
s
0 .76 1 r
.75609 1.09801 m
.76793 1.10222 L
s
.73667 1.07675 m
.75609 1.09801 L
s
.92 1 0 r
.24391 1.09801 m
.23207 1.10222 L
s
.24391 1.09801 m
.26333 1.07675 L
s
0 1 .52 r
.64558 1.00124 m
.64507 1.0034 L
s
.68968 1.03504 m
.64507 1.0034 L
s
.2 1 0 r
.35442 1.00124 m
.35493 1.0034 L
s
.35493 1.0034 m
.31032 1.03504 L
s
0 1 .88 r
.74409 1.08558 m
.75004 1.09326 L
s
.77009 1.09927 m
.75004 1.09326 L
s
.56 1 0 r
.25591 1.08558 m
.24996 1.09326 L
s
.24996 1.09326 m
.22991 1.09927 L
s
0 .76 1 r
.80617 1.13352 m
.81918 1.13874 L
s
.79177 1.11031 m
.80617 1.13352 L
s
.92 1 0 r
.19383 1.13352 m
.18082 1.13874 L
s
.19383 1.13352 m
.20823 1.11031 L
s
0 .76 1 r
.60528 .96499 m
.60231 .96249 L
s
.60528 .96499 m
.64632 .99927 L
s
.92 1 0 r
.39472 .96499 m
.39769 .96249 L
s
.35368 .99927 m
.39472 .96499 L
s
0 1 .88 r
.7191 1.06426 m
.72185 1.07032 L
s
.73813 1.07802 m
.72185 1.07032 L
s
.56 1 0 r
.2809 1.06426 m
.27815 1.07032 L
s
.27815 1.07032 m
.26187 1.07802 L
s
0 .76 1 r
.72682 1.07397 m
.73667 1.07675 L
s
.70321 1.05253 m
.72682 1.07397 L
s
.92 1 0 r
.27318 1.07397 m
.26333 1.07675 L
s
.27318 1.07397 m
.29679 1.05253 L
s
0 1 .88 r
.79638 1.12389 m
.8051 1.13208 L
s
.83049 1.13318 m
.8051 1.13208 L
s
.56 1 0 r
.20362 1.12389 m
.1949 1.13208 L
s
.1949 1.13208 m
.16951 1.13318 L
s
0 1 .52 r
.58147 .9468 m
.57462 .93699 L
s
.57462 .93699 m
.54556 .92176 L
s
.60885 .96824 m
.57462 .93699 L
s
.2 1 0 r
.41853 .9468 m
.42538 .93699 L
s
.42538 .93699 m
.39115 .96824 L
s
.45444 .92176 m
.42538 .93699 L
s
0 1 .88 r
.70601 1.05225 m
.70535 1.05599 L
s
.7191 1.06426 m
.70535 1.05599 L
s
.56 1 0 r
.29399 1.05225 m
.29465 1.05599 L
s
.29465 1.05599 m
.2809 1.06426 L
s
0 1 .88 r
.65622 1.0104 m
.64338 1.00095 L
s
.64338 1.00095 m
.64181 .99687 L
s
.56 1 0 r
.34378 1.0104 m
.35662 1.00095 L
s
.35819 .99687 m
.35662 1.00095 L
s
0 1 .88 r
.62865 .9861 m
.61553 .97465 L
s
.61553 .97465 m
.61952 .97754 L
s
.56 1 0 r
.37135 .9861 m
.38447 .97465 L
s
.38048 .97754 m
.38447 .97465 L
s
0 .76 1 r
.64526 1.00252 m
.64578 1.00059 L
s
.64526 1.00252 m
.67916 1.02909 L
s
.92 1 0 r
.35474 1.00252 m
.35422 1.00059 L
s
.32084 1.02909 m
.35474 1.00252 L
s
0 .76 1 r
.67517 1.02958 m
.67916 1.02909 L
s
.67517 1.02958 m
.70321 1.05253 L
s
.92 1 0 r
.32483 1.02958 m
.32084 1.02909 L
s
.29679 1.05253 m
.32483 1.02958 L
s
.56 1 0 r
.32735 1.02395 m
.33905 1.01686 L
s
.34378 1.0104 m
.33905 1.01686 L
s
0 1 .88 r
.67265 1.02395 m
.66095 1.01686 L
s
.66095 1.01686 m
.65622 1.0104 L
s
0 1 .52 r
.47842 .90945 m
.46734 .90946 L
s
.46734 .90946 m
.44549 .95511 L
s
.2 1 0 r
.52158 .90945 m
.53266 .90946 L
s
.55451 .95511 m
.53266 .90946 L
s
0 1 .88 r
.78764 1.11568 m
.79638 1.12389 L
s
.81943 1.12531 m
.79638 1.12389 L
s
.56 1 0 r
.21236 1.11568 m
.20362 1.12389 L
s
.20362 1.12389 m
.18057 1.12531 L
s
0 1 .88 r
.73813 1.07802 m
.74409 1.08558 L
s
.76129 1.09108 m
.74409 1.08558 L
s
.56 1 0 r
.26187 1.07802 m
.25591 1.08558 L
s
.25591 1.08558 m
.23871 1.09108 L
s
0 .76 1 r
.70321 1.05253 m
.7104 1.05373 L
s
.92 1 0 r
.29679 1.05253 m
.2896 1.05373 L
s
0 1 .52 r
.69249 1.04023 m
.69529 1.04581 L
s
.74436 1.07061 m
.69529 1.04581 L
s
.2 1 0 r
.30751 1.04023 m
.30471 1.04581 L
s
.30471 1.04581 m
.25564 1.07061 L
s
0 .76 1 r
.81918 1.13874 m
.83224 1.14382 L
s
.80377 1.11417 m
.81918 1.13874 L
s
.92 1 0 r
.18082 1.13874 m
.16776 1.14382 L
s
.18082 1.13874 m
.19623 1.11417 L
s
.2 1 0 r
.38731 .97185 m
.39115 .96824 L
s
.39115 .96824 m
.35388 .9997 L
s
0 1 .52 r
.61269 .97185 m
.60885 .96824 L
s
.64612 .9997 m
.60885 .96824 L
s
0 .76 1 r
.76793 1.10222 m
.77982 1.10632 L
s
.74658 1.0795 m
.76793 1.10222 L
s
.92 1 0 r
.23207 1.10222 m
.22018 1.10632 L
s
.23207 1.10222 m
.25342 1.0795 L
s
0 1 .88 r
.69362 1.03932 m
.68647 1.03752 L
s
.68647 1.03752 m
.67857 1.03024 L
s
.69583 1.04508 m
.68647 1.03752 L
s
.56 1 0 r
.30638 1.03932 m
.31353 1.03752 L
s
.31353 1.03752 m
.30417 1.04508 L
s
.32143 1.03024 m
.31353 1.03752 L
s
0 1 .88 r
.77887 1.10748 m
.78764 1.11568 L
s
.80835 1.11738 m
.78764 1.11568 L
s
.56 1 0 r
.22113 1.10748 m
.21236 1.11568 L
s
.21236 1.11568 m
.19165 1.11738 L
s
0 1 .88 r
.71635 1.05849 m
.7191 1.06426 L
s
.73215 1.07062 m
.7191 1.06426 L
s
.56 1 0 r
.28365 1.05849 m
.2809 1.06426 L
s
.2809 1.06426 m
.26785 1.07062 L
s
0 1 .88 r
.69988 1.04418 m
.69583 1.04508 L
s
.70601 1.05225 m
.69583 1.04508 L
s
.56 1 0 r
.30012 1.04418 m
.30417 1.04508 L
s
.30417 1.04508 m
.29399 1.05225 L
s
0 1 .88 r
.64181 .99687 m
.62865 .9861 L
s
.62865 .9861 m
.63213 .98754 L
s
.56 1 0 r
.35819 .99687 m
.37135 .9861 L
s
.36787 .98754 m
.37135 .9861 L
s
0 1 .88 r
.68835 1.03468 m
.67857 1.03024 L
s
.67857 1.03024 m
.67265 1.02395 L
s
.56 1 0 r
.31165 1.03468 m
.32143 1.03024 L
s
.32735 1.02395 m
.32143 1.03024 L
s
0 1 .52 r
.64612 .9997 m
.64558 1.00124 L
s
.68688 1.03026 m
.64558 1.00124 L
s
.2 1 0 r
.35388 .9997 m
.35442 1.00124 L
s
.35442 1.00124 m
.31312 1.03026 L
s
.56 1 0 r
.46812 .91282 m
.48055 .90946 L
s
.45569 .9191 m
.46812 .91282 L
s
.44904 .95267 m
.46812 .91282 L
s
0 1 .88 r
.53188 .91282 m
.51945 .90946 L
s
.54431 .9191 m
.53188 .91282 L
s
.53188 .91282 m
.55096 .95267 L
s
.2 1 0 r
.51046 .91278 m
.52158 .90945 L
s
.54182 .95243 m
.52158 .90945 L
s
0 1 .52 r
.48954 .91278 m
.47842 .90945 L
s
.47842 .90945 m
.45818 .95243 L
s
0 .76 1 r
.60231 .96249 m
.59933 .96115 L
s
.60231 .96249 m
.64688 .99851 L
s
.92 1 0 r
.39769 .96249 m
.40067 .96115 L
s
.35312 .99851 m
.39769 .96249 L
s
.56 1 0 r
.44322 .92737 m
.45569 .9191 L
s
.43777 .9543 m
.45569 .9191 L
s
0 1 .88 r
.55678 .92737 m
.54431 .9191 L
s
.54431 .9191 m
.56223 .9543 L
s
.73215 1.07062 m
.73813 1.07802 L
s
.75247 1.08291 m
.73813 1.07802 L
s
.56 1 0 r
.26785 1.07062 m
.26187 1.07802 L
s
.26187 1.07802 m
.24753 1.08291 L
s
0 1 .88 r
.66912 1.01929 m
.65622 1.0104 L
s
.65622 1.0104 m
.655 1.00703 L
s
.56 1 0 r
.33088 1.01929 m
.34378 1.0104 L
s
.345 1.00703 m
.34378 1.0104 L
s
.92 1 0 r
.26333 1.07675 m
.25342 1.0795 L
s
.26333 1.07675 m
.2896 1.05373 L
s
0 .76 1 r
.73667 1.07675 m
.74658 1.0795 L
s
.7104 1.05373 m
.73667 1.07675 L
s
0 1 .16 r
.5 .92097 m
.5 .90692 L
s
.5 .90692 m
.4598 .92672 L
s
.5402 .92672 m
.5 .90692 L
s
.56 1 0 r
.48055 .90946 m
.49297 .90964 L
s
.46035 .95226 m
.48055 .90946 L
s
0 1 .88 r
.51945 .90946 m
.50703 .90964 L
s
.51945 .90946 m
.53965 .95226 L
s
0 1 .16 r
.4598 .92672 m
.45668 .91909 L
s
.5402 .92672 m
.54332 .91909 L
s
.45668 .91909 m
.41524 .95796 L
s
.58476 .95796 m
.54332 .91909 L
s
0 1 .88 r
.70669 1.04887 m
.70601 1.05225 L
s
.71635 1.05849 m
.70601 1.05225 L
s
.56 1 0 r
.29331 1.04887 m
.29399 1.05225 L
s
.29399 1.05225 m
.28365 1.05849 L
s
0 .76 1 r
.83224 1.14382 m
.84534 1.14876 L
s
.81584 1.11792 m
.83224 1.14382 L
s
.92 1 0 r
.16776 1.14382 m
.15466 1.14876 L
s
.16776 1.14382 m
.18416 1.11792 L
s
0 1 .88 r
.77009 1.09927 m
.77887 1.10748 L
s
.79726 1.10937 m
.77887 1.10748 L
s
.56 1 0 r
.22991 1.09927 m
.22113 1.10748 L
s
.22113 1.10748 m
.20274 1.10937 L
s
0 1 .88 r
.56927 .93681 m
.55678 .92737 L
s
.55678 .92737 m
.57349 .95716 L
s
.56 1 0 r
.43073 .93681 m
.44322 .92737 L
s
.42651 .95716 m
.44322 .92737 L
s
0 1 .88 r
.6844 1.03068 m
.67265 1.02395 L
s
.67265 1.02395 m
.66912 1.01929 L
s
.56 1 0 r
.3156 1.03068 m
.32735 1.02395 L
s
.33088 1.01929 m
.32735 1.02395 L
s
0 .76 1 r
.64578 1.00059 m
.64632 .99927 L
s
.64578 1.00059 m
.68318 1.02892 L
s
.92 1 0 r
.35422 1.00059 m
.35368 .99927 L
s
.31682 1.02892 m
.35422 1.00059 L
s
0 1 .52 r
.68968 1.03504 m
.69249 1.04023 L
s
.73838 1.06395 m
.69249 1.04023 L
s
.2 1 0 r
.31032 1.03504 m
.30751 1.04023 L
s
.30751 1.04023 m
.26162 1.06395 L
s
0 1 .52 r
.55497 .93474 m
.54556 .92176 L
s
.54556 .92176 m
.5233 .93374 L
s
.2 1 0 r
.44503 .93474 m
.45444 .92176 L
s
.4767 .93374 m
.45444 .92176 L
s
0 .76 1 r
.67916 1.02909 m
.68318 1.02892 L
s
.67916 1.02909 m
.7104 1.05373 L
s
.92 1 0 r
.32084 1.02909 m
.31682 1.02892 L
s
.2896 1.05373 m
.32084 1.02909 L
s
.56 1 0 r
.4717 .95298 m
.49297 .90964 L
s
0 1 .88 r
.50703 .90964 m
.5283 .95298 L
s
.5818 .94684 m
.56927 .93681 L
s
.56927 .93681 m
.58473 .96119 L
s
.56 1 0 r
.4182 .94684 m
.43073 .93681 L
s
.41527 .96119 m
.43073 .93681 L
s
0 .76 1 r
.77982 1.10632 m
.79177 1.11031 L
s
.75655 1.08221 m
.77982 1.10632 L
s
.92 1 0 r
.22018 1.10632 m
.20823 1.11031 L
s
.22018 1.10632 m
.24345 1.08221 L
s
0 1 .88 r
.655 1.00703 m
.64181 .99687 L
s
.64181 .99687 m
.64476 .99734 L
s
.56 1 0 r
.345 1.00703 m
.35819 .99687 L
s
.35524 .99734 m
.35819 .99687 L
s
0 1 .88 r
.76129 1.09108 m
.77009 1.09927 L
s
.78616 1.10129 m
.77009 1.09927 L
s
.56 1 0 r
.23871 1.09108 m
.22991 1.09927 L
s
.22991 1.09927 m
.21384 1.10129 L
s
0 1 .88 r
.7136 1.05304 m
.71635 1.05849 L
s
.72616 1.0634 m
.71635 1.05849 L
s
.56 1 0 r
.2864 1.05304 m
.28365 1.05849 L
s
.28365 1.05849 m
.27384 1.0634 L
s
0 .76 1 r
.7104 1.05373 m
.71764 1.05503 L
s
.92 1 0 r
.2896 1.05373 m
.28236 1.05503 L
s
0 1 .88 r
.72616 1.0634 m
.73215 1.07062 L
s
.74363 1.07479 m
.73215 1.07062 L
s
.56 1 0 r
.27384 1.0634 m
.26785 1.07062 L
s
.26785 1.07062 m
.25637 1.07479 L
s
0 1 .88 r
.59435 .9571 m
.5818 .94684 L
s
.5818 .94684 m
.59597 .96624 L
s
.56 1 0 r
.40565 .9571 m
.4182 .94684 L
s
.40403 .96624 m
.4182 .94684 L
s
0 .76 1 r
.82796 1.12154 m
.84534 1.14876 L
s
.92 1 0 r
.15466 1.14876 m
.17204 1.12154 L
s
0 1 .52 r
.58838 .95573 m
.58147 .9468 L
s
.58147 .9468 m
.55497 .93474 L
s
.61269 .97185 m
.58147 .9468 L
s
.2 1 0 r
.41162 .95573 m
.41853 .9468 L
s
.41853 .9468 m
.38731 .97185 L
s
.44503 .93474 m
.41853 .9468 L
s
.49928 .91858 m
.51046 .91278 L
s
.52912 .95096 m
.51046 .91278 L
s
0 1 .52 r
.50072 .91858 m
.48954 .91278 L
s
.48954 .91278 m
.47088 .95096 L
s
0 1 .88 r
.68206 1.02767 m
.66912 1.01929 L
s
.66912 1.01929 m
.66823 1.01669 L
s
.56 1 0 r
.31794 1.02767 m
.33088 1.01929 L
s
.33177 1.01669 m
.33088 1.01929 L
s
0 1 .88 r
.75247 1.08291 m
.76129 1.09108 L
s
.77504 1.09315 m
.76129 1.09108 L
s
.56 1 0 r
.24753 1.08291 m
.23871 1.09108 L
s
.23871 1.09108 m
.22496 1.09315 L
s
0 1 .88 r
.70084 1.04121 m
.69362 1.03932 L
s
.69362 1.03932 m
.68835 1.03468 L
s
.69988 1.04418 m
.69362 1.03932 L
s
.56 1 0 r
.29916 1.04121 m
.30638 1.03932 L
s
.30638 1.03932 m
.30012 1.04418 L
s
.31165 1.03468 m
.30638 1.03932 L
s
0 1 .88 r
.70397 1.04355 m
.69988 1.04418 L
s
.70669 1.04887 m
.69988 1.04418 L
s
.56 1 0 r
.29603 1.04355 m
.30012 1.04418 L
s
.30012 1.04418 m
.29331 1.04887 L
s
.39308 .96737 m
.40565 .9571 L
s
.3928 .97217 m
.40565 .9571 L
s
0 1 .88 r
.60692 .96737 m
.59435 .9571 L
s
.59435 .9571 m
.6072 .97217 L
s
.69819 1.03899 m
.68835 1.03468 L
s
.68835 1.03468 m
.6844 1.03068 L
s
.56 1 0 r
.30181 1.03899 m
.31165 1.03468 L
s
.3156 1.03068 m
.31165 1.03468 L
s
0 1 .52 r
.61657 .97572 m
.61269 .97185 L
s
.64667 .99873 m
.61269 .97185 L
s
.2 1 0 r
.38343 .97572 m
.38731 .97185 L
s
.38731 .97185 m
.35333 .99873 L
s
0 1 .88 r
.8746 1.16397 m
.88559 1.1715 L
s
.9117 1.16304 m
.88559 1.1715 L
s
.56 1 0 r
.1254 1.16397 m
.11441 1.1715 L
s
.11441 1.1715 m
.0883 1.16304 L
s
0 1 .52 r
.64667 .99873 m
.64612 .9997 L
s
.68408 1.02594 m
.64612 .9997 L
s
.2 1 0 r
.35333 .99873 m
.35388 .9997 L
s
.35388 .9997 m
.31592 1.02594 L
s
0 .76 1 r
.74658 1.0795 m
.75655 1.08221 L
s
.71764 1.05503 m
.74658 1.0795 L
s
.92 1 0 r
.25342 1.0795 m
.24345 1.08221 L
s
.25342 1.0795 m
.28236 1.05503 L
s
0 .76 1 r
.59933 .96115 m
.59636 .9609 L
s
.59933 .96115 m
.64746 .99824 L
s
.92 1 0 r
.40067 .96115 m
.40364 .9609 L
s
.35254 .99824 m
.40067 .96115 L
s
.56 1 0 r
.33177 1.01669 m
.345 1.00703 L
s
.34259 1.00692 m
.345 1.00703 L
s
0 1 .88 r
.66823 1.01669 m
.655 1.00703 L
s
.655 1.00703 m
.65741 1.00692 L
s
.70739 1.04584 m
.70669 1.04887 L
s
.7136 1.05304 m
.70669 1.04887 L
s
.56 1 0 r
.29261 1.04584 m
.29331 1.04887 L
s
.29331 1.04887 m
.2864 1.05304 L
s
0 1 .16 r
.40282 .96112 m
.39663 .96448 L
s
.39663 .96448 m
.35133 .99884 L
s
.59718 .96112 m
.60337 .96448 L
s
.64867 .99884 m
.60337 .96448 L
s
0 1 .88 r
.86359 1.15638 m
.8746 1.16397 L
s
.89897 1.1564 m
.8746 1.16397 L
s
.56 1 0 r
.13641 1.15638 m
.1254 1.16397 L
s
.1254 1.16397 m
.10103 1.1564 L
s
0 1 .52 r
.68688 1.03026 m
.68968 1.03504 L
s
.73238 1.05753 m
.68968 1.03504 L
s
.2 1 0 r
.31312 1.03026 m
.31032 1.03504 L
s
.31032 1.03504 m
.26762 1.05753 L
s
0 1 .88 r
.72016 1.05639 m
.72616 1.0634 L
s
.73478 1.06672 m
.72616 1.0634 L
s
.56 1 0 r
.27984 1.05639 m
.27384 1.0634 L
s
.27384 1.0634 m
.26522 1.06672 L
s
0 1 .88 r
.74363 1.07479 m
.75247 1.08291 L
s
.76391 1.08494 m
.75247 1.08291 L
s
.56 1 0 r
.25637 1.07479 m
.24753 1.08291 L
s
.24753 1.08291 m
.23609 1.08494 L
s
0 1 .88 r
.69622 1.03708 m
.6844 1.03068 L
s
.6844 1.03068 m
.68206 1.02767 L
s
.56 1 0 r
.30378 1.03708 m
.3156 1.03068 L
s
.31794 1.02767 m
.3156 1.03068 L
s
0 1 .88 r
.61952 .97754 m
.60692 .96737 L
s
.60692 .96737 m
.61843 .97881 L
s
.56 1 0 r
.38048 .97754 m
.39308 .96737 L
s
.38157 .97881 m
.39308 .96737 L
s
0 .76 1 r
.79177 1.11031 m
.80377 1.11417 L
s
.76659 1.08485 m
.79177 1.11031 L
s
.92 1 0 r
.20823 1.11031 m
.19623 1.11417 L
s
.20823 1.11031 m
.23341 1.08485 L
s
0 1 .88 r
.85258 1.14871 m
.86359 1.15638 L
s
.88623 1.14966 m
.86359 1.15638 L
s
.56 1 0 r
.14742 1.14871 m
.13641 1.15638 L
s
.13641 1.15638 m
.11377 1.14966 L
s
0 1 .88 r
.71086 1.04791 m
.7136 1.05304 L
s
.72016 1.05639 m
.7136 1.05304 L
s
.56 1 0 r
.28914 1.04791 m
.2864 1.05304 L
s
.2864 1.05304 m
.27984 1.05639 L
s
0 .76 1 r
.64632 .99927 m
.64688 .99851 L
s
.64632 .99927 m
.68725 1.02903 L
s
.92 1 0 r
.35368 .99927 m
.35312 .99851 L
s
.31275 1.02903 m
.35368 .99927 L
s
0 1 .88 r
.84154 1.14098 m
.85258 1.14871 L
s
.8735 1.14283 m
.85258 1.14871 L
s
.56 1 0 r
.15846 1.14098 m
.14742 1.14871 L
s
.14742 1.14871 m
.1265 1.14283 L
s
0 .76 1 r
.68318 1.02892 m
.68725 1.02903 L
s
.68318 1.02892 m
.71764 1.05503 L
s
.92 1 0 r
.31682 1.02892 m
.31275 1.02903 L
s
.28236 1.05503 m
.31682 1.02892 L
s
0 1 .88 r
.63213 .98754 m
.61952 .97754 L
s
.61952 .97754 m
.62965 .986 L
s
.56 1 0 r
.36787 .98754 m
.38048 .97754 L
s
.37035 .986 m
.38048 .97754 L
s
0 1 .88 r
.73478 1.06672 m
.74363 1.07479 L
s
.75277 1.07668 m
.74363 1.07479 L
s
.56 1 0 r
.26522 1.06672 m
.25637 1.07479 L
s
.25637 1.07479 m
.24723 1.07668 L
s
0 1 .88 r
.68149 1.02589 m
.66823 1.01669 L
s
.66823 1.01669 m
.67007 1.01629 L
s
.56 1 0 r
.31851 1.02589 m
.33177 1.01669 L
s
.32993 1.01629 m
.33177 1.01669 L
s
0 1 .88 r
.83049 1.13318 m
.84154 1.14098 L
s
.86076 1.13591 m
.84154 1.14098 L
s
.56 1 0 r
.16951 1.13318 m
.15846 1.14098 L
s
.15846 1.14098 m
.13924 1.13591 L
s
0 1 .88 r
.69506 1.03561 m
.68206 1.02767 L
s
.68206 1.02767 m
.68149 1.02589 L
s
.56 1 0 r
.30494 1.03561 m
.31794 1.02767 L
s
.31851 1.02589 m
.31794 1.02767 L
s
0 .76 1 r
.71764 1.05503 m
.72494 1.05642 L
s
.92 1 0 r
.28236 1.05503 m
.27506 1.05642 L
s
0 1 .16 r
.53705 .9344 m
.5402 .92672 L
s
.57852 .95801 m
.5402 .92672 L
s
.46295 .9344 m
.4598 .92672 L
s
.4598 .92672 m
.42148 .95801 L
s
0 1 .52 r
.51197 .92584 m
.50072 .91858 L
s
.50072 .91858 m
.4836 .95074 L
s
.2 1 0 r
.48803 .92584 m
.49928 .91858 L
s
.5164 .95074 m
.49928 .91858 L
s
0 1 .88 r
.81943 1.12531 m
.83049 1.13318 L
s
.84803 1.12888 m
.83049 1.13318 L
s
.56 1 0 r
.18057 1.12531 m
.16951 1.13318 L
s
.16951 1.13318 m
.15197 1.12888 L
s
0 1 .88 r
.64476 .99734 m
.63213 .98754 L
s
.63213 .98754 m
.64087 .99361 L
s
.56 1 0 r
.35524 .99734 m
.36787 .98754 L
s
.35913 .99361 m
.36787 .98754 L
s
0 1 .88 r
.71414 1.04963 m
.72016 1.05639 L
s
.7259 1.05874 m
.72016 1.05639 L
s
.56 1 0 r
.28586 1.04963 m
.27984 1.05639 L
s
.27984 1.05639 m
.2741 1.05874 L
s
0 1 .88 r
.80835 1.11738 m
.81943 1.12531 L
s
.83529 1.12174 m
.81943 1.12531 L
s
.56 1 0 r
.19165 1.11738 m
.18057 1.12531 L
s
.18057 1.12531 m
.16471 1.12174 L
s
0 1 .88 r
.7259 1.05874 m
.73478 1.06672 L
s
.74162 1.06836 m
.73478 1.06672 L
s
.56 1 0 r
.2741 1.05874 m
.26522 1.06672 L
s
.26522 1.06672 m
.25838 1.06836 L
s
.2 1 0 r
.43555 .94591 m
.44503 .93474 L
s
.46528 .94177 m
.44503 .93474 L
s
0 1 .52 r
.56445 .94591 m
.55497 .93474 L
s
.55497 .93474 m
.53472 .94177 L
s
0 1 .88 r
.7081 1.04315 m
.70084 1.04121 L
s
.70084 1.04121 m
.69819 1.03899 L
s
.70397 1.04355 m
.70084 1.04121 L
s
.56 1 0 r
.2919 1.04315 m
.29916 1.04121 L
s
.29916 1.04121 m
.29603 1.04355 L
s
.30181 1.03899 m
.29916 1.04121 L
s
0 1 .88 r
.7081 1.04315 m
.70397 1.04355 L
s
.70739 1.04584 m
.70397 1.04355 L
s
.56 1 0 r
.2919 1.04315 m
.29603 1.04355 L
s
.29603 1.04355 m
.29261 1.04584 L
s
.92 1 0 r
.24345 1.08221 m
.23341 1.08485 L
s
.24345 1.08221 m
.27506 1.05642 L
s
0 .76 1 r
.75655 1.08221 m
.76659 1.08485 L
s
.72494 1.05642 m
.75655 1.08221 L
s
0 1 .16 r
.59098 .95896 m
.59718 .96112 L
s
.63965 .99383 m
.59718 .96112 L
s
.40902 .95896 m
.40282 .96112 L
s
.40282 .96112 m
.36035 .99383 L
s
0 1 .88 r
.79726 1.10937 m
.80835 1.11738 L
s
.82256 1.1145 m
.80835 1.11738 L
s
.56 1 0 r
.20274 1.10937 m
.19165 1.11738 L
s
.19165 1.11738 m
.17744 1.1145 L
s
0 1 .88 r
.65741 1.00692 m
.64476 .99734 L
s
.64476 .99734 m
.65209 1.00152 L
s
.56 1 0 r
.34259 1.00692 m
.35524 .99734 L
s
.34791 1.00152 m
.35524 .99734 L
s
0 1 .88 r
.7081 1.04315 m
.69819 1.03899 L
s
.69819 1.03899 m
.69622 1.03708 L
s
.56 1 0 r
.2919 1.04315 m
.30181 1.03899 L
s
.30378 1.03708 m
.30181 1.03899 L
s
.2 1 0 r
.31592 1.02594 m
.31312 1.03026 L
s
.31312 1.03026 m
.27363 1.05137 L
s
0 1 .52 r
.68408 1.02594 m
.68688 1.03026 L
s
.72637 1.05137 m
.68688 1.03026 L
s
0 .76 1 r
.80377 1.11417 m
.81584 1.11792 L
s
.77669 1.08743 m
.80377 1.11417 L
s
.92 1 0 r
.19623 1.11417 m
.18416 1.11792 L
s
.19623 1.11417 m
.22331 1.08743 L
s
0 1 .16 r
.5 .93246 m
.5 .92097 L
s
.5 .92097 m
.46295 .9344 L
s
.53705 .9344 m
.5 .92097 L
s
.2 1 0 r
.25564 1.07061 m
.24968 1.07748 L
s
.24968 1.07748 m
.20294 1.09231 L
s
0 1 .52 r
.74436 1.07061 m
.75032 1.07748 L
s
.79706 1.09231 m
.75032 1.07748 L
s
0 1 .88 r
.7081 1.04315 m
.70739 1.04584 L
s
.71086 1.04791 m
.70739 1.04584 L
s
.56 1 0 r
.2919 1.04315 m
.29261 1.04584 L
s
.29261 1.04584 m
.28914 1.04791 L
s
0 1 .88 r
.69478 1.0347 m
.68149 1.02589 L
s
.68149 1.02589 m
.68274 1.02545 L
s
.56 1 0 r
.30522 1.0347 m
.31851 1.02589 L
s
.31726 1.02545 m
.31851 1.02589 L
s
0 1 .52 r
.64725 .99828 m
.64667 .99873 L
s
.68128 1.02206 m
.64667 .99873 L
s
.2 1 0 r
.35275 .99828 m
.35333 .99873 L
s
.35333 .99873 m
.31872 1.02206 L
s
0 1 .88 r
.78616 1.10129 m
.79726 1.10937 L
s
.80983 1.10713 m
.79726 1.10937 L
s
.56 1 0 r
.21384 1.10129 m
.20274 1.10937 L
s
.20274 1.10937 m
.19017 1.10713 L
s
0 1 .88 r
.7081 1.04315 m
.69622 1.03708 L
s
.69622 1.03708 m
.69506 1.03561 L
s
.56 1 0 r
.2919 1.04315 m
.30378 1.03708 L
s
.30494 1.03561 m
.30378 1.03708 L
s
0 .76 1 r
.59636 .9609 m
.59338 .9616 L
s
.59636 .9609 m
.64806 .99837 L
s
.92 1 0 r
.40364 .9609 m
.40662 .9616 L
s
.35194 .99837 m
.40364 .9609 L
s
0 1 .88 r
.7081 1.04315 m
.71086 1.04791 L
s
.71414 1.04963 m
.71086 1.04791 L
s
.56 1 0 r
.2919 1.04315 m
.28914 1.04791 L
s
.28914 1.04791 m
.28586 1.04963 L
s
0 1 .88 r
.67007 1.01629 m
.65741 1.00692 L
s
.65741 1.00692 m
.6633 1.00965 L
s
.56 1 0 r
.32993 1.01629 m
.34259 1.00692 L
s
.3367 1.00965 m
.34259 1.00692 L
s
0 1 .88 r
.77504 1.09315 m
.78616 1.10129 L
s
.7971 1.09964 m
.78616 1.10129 L
s
.56 1 0 r
.22496 1.09315 m
.21384 1.10129 L
s
.21384 1.10129 m
.2029 1.09964 L
s
0 1 .52 r
.59535 .96379 m
.58838 .95573 L
s
.58838 .95573 m
.56445 .94591 L
s
.61657 .97572 m
.58838 .95573 L
s
.2 1 0 r
.40465 .96379 m
.41162 .95573 L
s
.41162 .95573 m
.38343 .97572 L
s
.43555 .94591 m
.41162 .95573 L
s
0 1 .88 r
.71701 1.05088 m
.7259 1.05874 L
s
.73046 1.05999 m
.7259 1.05874 L
s
.56 1 0 r
.28299 1.05088 m
.2741 1.05874 L
s
.2741 1.05874 m
.26954 1.05999 L
s
.2 1 0 r
.37952 .97968 m
.38343 .97572 L
s
.38343 .97572 m
.35275 .99828 L
s
0 1 .52 r
.62048 .97968 m
.61657 .97572 L
s
.64725 .99828 m
.61657 .97572 L
s
0 1 .88 r
.7081 1.04315 m
.69506 1.03561 L
s
.69506 1.03561 m
.69478 1.0347 L
s
.56 1 0 r
.2919 1.04315 m
.30494 1.03561 L
s
.30522 1.0347 m
.30494 1.03561 L
s
0 1 .88 r
.76391 1.08494 m
.77504 1.09315 L
s
.78437 1.09202 m
.77504 1.09315 L
s
.56 1 0 r
.23609 1.08494 m
.22496 1.09315 L
s
.22496 1.09315 m
.21563 1.09202 L
s
0 1 .88 r
.7081 1.04315 m
.71414 1.04963 L
s
.71701 1.05088 m
.71414 1.04963 L
s
.56 1 0 r
.2919 1.04315 m
.28586 1.04963 L
s
.28586 1.04963 m
.28299 1.05088 L
s
0 1 .88 r
.68274 1.02545 m
.67007 1.01629 L
s
.67007 1.01629 m
.67451 1.01793 L
s
.56 1 0 r
.31726 1.02545 m
.32993 1.01629 L
s
.32549 1.01793 m
.32993 1.01629 L
s
0 1 .88 r
.75277 1.07668 m
.76391 1.08494 L
s
.77165 1.08427 m
.76391 1.08494 L
s
.56 1 0 r
.24723 1.07668 m
.23609 1.08494 L
s
.23609 1.08494 m
.22835 1.08427 L
s
0 .76 1 r
.64688 .99851 m
.64746 .99824 L
s
.64688 .99851 m
.69136 1.02936 L
s
.92 1 0 r
.35312 .99851 m
.35254 .99824 L
s
.30864 1.02936 m
.35312 .99851 L
s
0 1 .88 r
.7081 1.04315 m
.69478 1.0347 L
s
.69478 1.0347 m
.69542 1.0344 L
s
.56 1 0 r
.2919 1.04315 m
.30522 1.0347 L
s
.30458 1.0344 m
.30522 1.0347 L
s
0 .76 1 r
.68725 1.02903 m
.69136 1.02936 L
s
.68725 1.02903 m
.72494 1.05642 L
s
.92 1 0 r
.31275 1.02903 m
.30864 1.02936 L
s
.27506 1.05642 m
.31275 1.02903 L
s
0 1 .88 r
.74162 1.06836 m
.75277 1.07668 L
s
.75893 1.07637 m
.75277 1.07668 L
s
.56 1 0 r
.25838 1.06836 m
.24723 1.07668 L
s
.24723 1.07668 m
.24107 1.07637 L
s
0 1 .52 r
.73838 1.06395 m
.74436 1.07061 L
s
.7882 1.08523 m
.74436 1.07061 L
s
.2 1 0 r
.26162 1.06395 m
.25564 1.07061 L
s
.25564 1.07061 m
.2118 1.08523 L
s
0 1 .88 r
.7081 1.04315 m
.71701 1.05088 L
s
.71929 1.05158 m
.71701 1.05088 L
s
.56 1 0 r
.2919 1.04315 m
.28299 1.05088 L
s
.28299 1.05088 m
.28071 1.05158 L
s
0 1 .88 r
.69542 1.0344 m
.68274 1.02545 L
s
.68274 1.02545 m
.68572 1.02629 L
s
.56 1 0 r
.30458 1.0344 m
.31726 1.02545 L
s
.31428 1.02629 m
.31726 1.02545 L
s
0 1 .52 r
.5233 .93374 m
.51197 .92584 L
s
.51197 .92584 m
.49634 .95173 L
s
.2 1 0 r
.4767 .93374 m
.48803 .92584 L
s
.50366 .95173 m
.48803 .92584 L
s
0 1 .88 r
.73046 1.05999 m
.74162 1.06836 L
s
.74622 1.06831 m
.74162 1.06836 L
s
.56 1 0 r
.26954 1.05999 m
.25838 1.06836 L
s
.25838 1.06836 m
.25378 1.06831 L
s
0 .76 1 r
.72494 1.05642 m
.73229 1.05784 L
s
.92 1 0 r
.27506 1.05642 m
.26771 1.05784 L
s
0 .76 1 r
.81584 1.11792 m
.82796 1.12154 L
s
.78684 1.08991 m
.81584 1.11792 L
s
.92 1 0 r
.18416 1.11792 m
.17204 1.12154 L
s
.18416 1.11792 m
.21316 1.08991 L
s
0 1 .88 r
.71929 1.05158 m
.73046 1.05999 L
s
.73351 1.0601 m
.73046 1.05999 L
s
.56 1 0 r
.28071 1.05158 m
.26954 1.05999 L
s
.26954 1.05999 m
.26649 1.0601 L
s
0 1 .16 r
.41524 .95796 m
.40902 .95896 L
s
.40902 .95896 m
.3694 .98943 L
s
.58476 .95796 m
.59098 .95896 L
s
.6306 .98943 m
.59098 .95896 L
s
0 1 .88 r
.7081 1.04315 m
.69542 1.0344 L
s
.69542 1.0344 m
.69692 1.03471 L
s
.56 1 0 r
.2919 1.04315 m
.30458 1.0344 L
s
.30308 1.03471 m
.30458 1.0344 L
s
0 1 .52 r
.68128 1.02206 m
.68408 1.02594 L
s
.72035 1.0455 m
.68408 1.02594 L
s
.2 1 0 r
.31872 1.02206 m
.31592 1.02594 L
s
.31592 1.02594 m
.27965 1.0455 L
s
0 .76 1 r
.76659 1.08485 m
.77669 1.08743 L
s
.73229 1.05784 m
.76659 1.08485 L
s
.92 1 0 r
.23341 1.08485 m
.22331 1.08743 L
s
.23341 1.08485 m
.26771 1.05784 L
s
0 1 .88 r
.7081 1.04315 m
.71929 1.05158 L
s
.7208 1.05171 m
.71929 1.05158 L
s
.56 1 0 r
.2919 1.04315 m
.28071 1.05158 L
s
.28071 1.05158 m
.2792 1.05171 L
s
0 1 .88 r
.7081 1.04315 m
.72145 1.05128 L
s
.7081 1.04315 m
.7212 1.05032 L
s
.7081 1.04315 m
.72005 1.04891 L
s
.7081 1.04315 m
.71808 1.04714 L
s
.7081 1.04315 m
.71543 1.04511 L
s
.7081 1.04315 m
.71228 1.04295 L
s
.7081 1.04315 m
.70884 1.04079 L
s
.7081 1.04315 m
.70535 1.03876 L
s
.7081 1.04315 m
.70206 1.03699 L
s
.7081 1.04315 m
.69918 1.0356 L
s
.7081 1.04315 m
.69692 1.03471 L
s
.7081 1.04315 m
.7208 1.05171 L
s
.7081 1.04315 m
.7081 1.04315 L
s
.56 1 0 r
.2919 1.04315 m
.30308 1.03471 L
s
.2919 1.04315 m
.30082 1.0356 L
s
.2919 1.04315 m
.29794 1.03699 L
s
.2919 1.04315 m
.29465 1.03876 L
s
.2919 1.04315 m
.29116 1.04079 L
s
.2919 1.04315 m
.28772 1.04295 L
s
.2919 1.04315 m
.28457 1.04511 L
s
.2919 1.04315 m
.28192 1.04714 L
s
.2919 1.04315 m
.27995 1.04891 L
s
.2919 1.04315 m
.2788 1.05032 L
s
.2919 1.04315 m
.27855 1.05128 L
s
.2919 1.04315 m
.2792 1.05171 L
s
.2919 1.04315 m
.2919 1.04315 L
s
0 1 .88 r
.69692 1.03471 m
.68572 1.02629 L
s
.69692 1.03471 m
.69918 1.0356 L
s
.56 1 0 r
.30308 1.03471 m
.31428 1.02629 L
s
.30082 1.0356 m
.30308 1.03471 L
s
0 1 .88 r
.7208 1.05171 m
.73351 1.0601 L
s
.72145 1.05128 m
.7208 1.05171 L
s
.56 1 0 r
.2792 1.05171 m
.26649 1.0601 L
s
.2792 1.05171 m
.27855 1.05128 L
s
0 1 .16 r
.53386 .94172 m
.53705 .9344 L
s
.57224 .95897 m
.53705 .9344 L
s
.46614 .94172 m
.46295 .9344 L
s
.46295 .9344 m
.42776 .95897 L
s
0 1 .52 r
.64784 .99828 m
.64725 .99828 L
s
.67848 1.01866 m
.64725 .99828 L
s
.2 1 0 r
.35216 .99828 m
.35275 .99828 L
s
.35275 .99828 m
.32152 1.01866 L
s
.26762 1.05753 m
.26162 1.06395 L
s
.26162 1.06395 m
.22068 1.07826 L
s
0 1 .52 r
.73238 1.05753 m
.73838 1.06395 L
s
.77932 1.07826 m
.73838 1.06395 L
s
0 1 .88 r
.68572 1.02629 m
.67451 1.01793 L
s
.68572 1.02629 m
.69024 1.02828 L
s
.56 1 0 r
.31428 1.02629 m
.32549 1.01793 L
s
.30976 1.02828 m
.31428 1.02629 L
s
0 .76 1 r
.59338 .9616 m
.64867 .99884 L
s
.92 1 0 r
.35133 .99884 m
.40662 .9616 L
s
.2 1 0 r
.42599 .95567 m
.43555 .94591 L
s
.45379 .94964 m
.43555 .94591 L
s
0 1 .52 r
.57401 .95567 m
.56445 .94591 L
s
.56445 .94591 m
.54621 .94964 L
s
0 1 .88 r
.67451 1.01793 m
.6633 1.00965 L
s
.67451 1.01793 m
.68129 1.02122 L
s
.56 1 0 r
.32549 1.01793 m
.3367 1.00965 L
s
.31871 1.02122 m
.32549 1.01793 L
s
0 1 .88 r
.73351 1.0601 m
.74622 1.06831 L
s
.73483 1.05912 m
.73351 1.0601 L
s
.56 1 0 r
.26649 1.0601 m
.25378 1.06831 L
s
.26649 1.0601 m
.26517 1.05912 L
s
0 1 .88 r
.69918 1.0356 m
.69024 1.02828 L
s
.69918 1.0356 m
.70206 1.03699 L
s
.56 1 0 r
.30082 1.0356 m
.30976 1.02828 L
s
.29794 1.03699 m
.30082 1.0356 L
s
0 1 .88 r
.72145 1.05128 m
.73483 1.05912 L
s
.7212 1.05032 m
.72145 1.05128 L
s
.56 1 0 r
.27855 1.05128 m
.26517 1.05912 L
s
.27855 1.05128 m
.2788 1.05032 L
s
0 1 .88 r
.6633 1.00965 m
.65209 1.00152 L
s
.6633 1.00965 m
.67232 1.0145 L
s
.56 1 0 r
.3367 1.00965 m
.34791 1.00152 L
s
.32768 1.0145 m
.3367 1.00965 L
s
0 1 .88 r
.74622 1.06831 m
.75893 1.07637 L
s
.74823 1.0667 m
.74622 1.06831 L
s
.56 1 0 r
.25378 1.06831 m
.24107 1.07637 L
s
.25378 1.06831 m
.25177 1.0667 L
s
0 .76 1 r
.79706 1.09231 m
.82796 1.12154 L
s
.92 1 0 r
.17204 1.12154 m
.20294 1.09231 L
s
0 1 .88 r
.65209 1.00152 m
.64087 .99361 L
s
.65209 1.00152 m
.66333 1.00816 L
s
.56 1 0 r
.34791 1.00152 m
.35913 .99361 L
s
.33667 1.00816 m
.34791 1.00152 L
s
0 .76 1 r
.64746 .99824 m
.64806 .99837 L
s
.64746 .99824 m
.6955 1.02987 L
s
.92 1 0 r
.35254 .99824 m
.35194 .99837 L
s
.3045 1.02987 m
.35254 .99824 L
s
.2 1 0 r
.37557 .98359 m
.37952 .97968 L
s
.37952 .97968 m
.35216 .99828 L
s
.40465 .96379 m
.37952 .97968 L
s
0 1 .52 r
.62443 .98359 m
.62048 .97968 L
s
.62048 .97968 m
.59535 .96379 L
s
.64784 .99828 m
.62048 .97968 L
s
0 1 .88 r
.75893 1.07637 m
.77165 1.08427 L
s
.76166 1.07404 m
.75893 1.07637 L
s
.56 1 0 r
.24107 1.07637 m
.22835 1.08427 L
s
.24107 1.07637 m
.23834 1.07404 L
s
0 1 .88 r
.70206 1.03699 m
.696 1.03118 L
s
.70206 1.03699 m
.70535 1.03876 L
s
.56 1 0 r
.29794 1.03699 m
.304 1.03118 L
s
.29465 1.03876 m
.29794 1.03699 L
s
0 1 .52 r
.53472 .94177 m
.5233 .93374 L
s
.5233 .93374 m
.50911 .95379 L
s
.2 1 0 r
.46528 .94177 m
.4767 .93374 L
s
.49089 .95379 m
.4767 .93374 L
s
0 .76 1 r
.69136 1.02936 m
.6955 1.02987 L
s
.69136 1.02936 m
.73229 1.05784 L
s
.92 1 0 r
.30864 1.02936 m
.3045 1.02987 L
s
.26771 1.05784 m
.30864 1.02936 L
s
0 1 .52 r
.60237 .97106 m
.59535 .96379 L
s
.59535 .96379 m
.57401 .95567 L
s
.2 1 0 r
.39763 .97106 m
.40465 .96379 L
s
.42599 .95567 m
.40465 .96379 L
s
0 1 .88 r
.7212 1.05032 m
.73434 1.05717 L
s
.72005 1.04891 m
.7212 1.05032 L
s
.56 1 0 r
.2788 1.05032 m
.26566 1.05717 L
s
.2788 1.05032 m
.27995 1.04891 L
s
0 1 .88 r
.64087 .99361 m
.62965 .986 L
s
.64087 .99361 m
.65433 1.00227 L
s
.56 1 0 r
.35913 .99361 m
.37035 .986 L
s
.34567 1.00227 m
.35913 .99361 L
s
.2 1 0 r
.32152 1.01866 m
.31872 1.02206 L
s
.31872 1.02206 m
.28569 1.03995 L
s
0 1 .52 r
.67848 1.01866 m
.68128 1.02206 L
s
.71431 1.03995 m
.68128 1.02206 L
s
0 .76 1 r
.73229 1.05784 m
.7397 1.05927 L
s
.92 1 0 r
.26771 1.05784 m
.2603 1.05927 L
s
0 1 .16 r
.42148 .95801 m
.41524 .95796 L
s
.41524 .95796 m
.37847 .98568 L
s
.57852 .95801 m
.58476 .95796 L
s
.62153 .98568 m
.58476 .95796 L
s
0 1 .88 r
.77165 1.08427 m
.78437 1.09202 L
s
.77512 1.08116 m
.77165 1.08427 L
s
.56 1 0 r
.22835 1.08427 m
.21563 1.09202 L
s
.22835 1.08427 m
.22488 1.08116 L
s
0 1 .16 r
.5 .94204 m
.5 .93246 L
s
.5 .93246 m
.46614 .94172 L
s
.53386 .94172 m
.5 .93246 L
s
0 1 .88 r
.69024 1.02828 m
.68129 1.02122 L
s
.69024 1.02828 m
.696 1.03118 L
s
.56 1 0 r
.30976 1.02828 m
.31871 1.02122 L
s
.304 1.03118 m
.30976 1.02828 L
s
0 .76 1 r
.77669 1.08743 m
.78684 1.08991 L
s
.7397 1.05927 m
.77669 1.08743 L
s
.92 1 0 r
.22331 1.08743 m
.21316 1.08991 L
s
.22331 1.08743 m
.2603 1.05927 L
s
.2 1 0 r
.27363 1.05137 m
.26762 1.05753 L
s
.26762 1.05753 m
.22957 1.07143 L
s
0 1 .52 r
.72637 1.05137 m
.73238 1.05753 L
s
.77043 1.07143 m
.73238 1.05753 L
s
0 1 .88 r
.70535 1.03876 m
.7026 1.03474 L
s
.70535 1.03876 m
.70884 1.04079 L
s
.56 1 0 r
.29465 1.03876 m
.2974 1.03474 L
s
.29116 1.04079 m
.29465 1.03876 L
s
0 1 .88 r
.62965 .986 m
.61843 .97881 L
s
.62965 .986 m
.64531 .9969 L
s
.56 1 0 r
.37035 .986 m
.38157 .97881 L
s
.35469 .9969 m
.37035 .986 L
s
0 1 .88 r
.73483 1.05912 m
.74823 1.0667 L
s
.73434 1.05717 m
.73483 1.05912 L
s
.56 1 0 r
.26517 1.05912 m
.25177 1.0667 L
s
.26517 1.05912 m
.26566 1.05717 L
s
.27995 1.04891 m
.26795 1.05438 L
s
.27995 1.04891 m
.28192 1.04714 L
s
0 1 .88 r
.72005 1.04891 m
.73205 1.05438 L
s
.71808 1.04714 m
.72005 1.04891 L
s
.78437 1.09202 m
.7971 1.09964 L
s
.78859 1.08807 m
.78437 1.09202 L
s
.56 1 0 r
.21563 1.09202 m
.2029 1.09964 L
s
.21563 1.09202 m
.21141 1.08807 L
s
0 1 .88 r
.70884 1.04079 m
.70959 1.03873 L
s
.70884 1.04079 m
.71228 1.04295 L
s
.56 1 0 r
.29116 1.04079 m
.29041 1.03873 L
s
.28772 1.04295 m
.29116 1.04079 L
s
0 1 .88 r
.7971 1.09964 m
.80983 1.10713 L
s
.8021 1.09479 m
.7971 1.09964 L
s
.56 1 0 r
.2029 1.09964 m
.19017 1.10713 L
s
.2029 1.09964 m
.1979 1.09479 L
s
0 1 .88 r
.71808 1.04714 m
.72812 1.05094 L
s
.71543 1.04511 m
.71808 1.04714 L
s
.56 1 0 r
.28192 1.04714 m
.27188 1.05094 L
s
.28192 1.04714 m
.28457 1.04511 L
s
0 1 .88 r
.61843 .97881 m
.6072 .97217 L
s
.61843 .97881 m
.63628 .99211 L
s
.56 1 0 r
.38157 .97881 m
.3928 .97217 L
s
.36372 .99211 m
.38157 .97881 L
s
0 1 .88 r
.71228 1.04295 m
.71649 1.04291 L
s
.71228 1.04295 m
.71543 1.04511 L
s
.56 1 0 r
.28772 1.04295 m
.28351 1.04291 L
s
.28457 1.04511 m
.28772 1.04295 L
s
0 1 .88 r
.71543 1.04511 m
.72281 1.04705 L
s
.56 1 0 r
.28457 1.04511 m
.27719 1.04705 L
s
0 1 .88 r
.80983 1.10713 m
.82256 1.1145 L
s
.81562 1.10134 m
.80983 1.10713 L
s
.56 1 0 r
.19017 1.10713 m
.17744 1.1145 L
s
.19017 1.10713 m
.18438 1.10134 L
s
0 1 .88 r
.68129 1.02122 m
.67232 1.0145 L
s
.68129 1.02122 m
.68993 1.02575 L
s
.56 1 0 r
.31871 1.02122 m
.32768 1.0145 L
s
.31007 1.02575 m
.31871 1.02122 L
s
.17744 1.1145 m
.16471 1.12174 L
s
.17744 1.1145 m
.17083 1.10773 L
s
0 1 .88 r
.82256 1.1145 m
.83529 1.12174 L
s
.82917 1.10773 m
.82256 1.1145 L
s
.6072 .97217 m
.59597 .96624 L
s
.6072 .97217 m
.62723 .98795 L
s
.56 1 0 r
.3928 .97217 m
.40403 .96624 L
s
.37277 .98795 m
.3928 .97217 L
s
0 1 .88 r
.74823 1.0667 m
.76166 1.07404 L
s
.74752 1.06371 m
.74823 1.0667 L
s
.56 1 0 r
.25177 1.0667 m
.23834 1.07404 L
s
.25177 1.0667 m
.25248 1.06371 L
s
0 1 .88 r
.696 1.03118 m
.68993 1.02575 L
s
.696 1.03118 m
.7026 1.03474 L
s
.56 1 0 r
.304 1.03118 m
.31007 1.02575 L
s
.2974 1.03474 m
.304 1.03118 L
s
0 1 .52 r
.64844 .99863 m
.64784 .99828 L
s
.67567 1.01571 m
.64784 .99828 L
s
.2 1 0 r
.35156 .99863 m
.35216 .99828 L
s
.35216 .99828 m
.32433 1.01571 L
s
0 1 .88 r
.83529 1.12174 m
.84803 1.12888 L
s
.84273 1.11396 m
.83529 1.12174 L
s
.56 1 0 r
.16471 1.12174 m
.15197 1.12888 L
s
.16471 1.12174 m
.15727 1.11396 L
s
0 1 .88 r
.73434 1.05717 m
.74752 1.06371 L
s
.73205 1.05438 m
.73434 1.05717 L
s
.56 1 0 r
.26566 1.05717 m
.25248 1.06371 L
s
.26566 1.05717 m
.26795 1.05438 L
s
0 1 .88 r
.84803 1.12888 m
.86076 1.13591 L
s
.85632 1.12004 m
.84803 1.12888 L
s
.56 1 0 r
.15197 1.12888 m
.13924 1.13591 L
s
.15197 1.12888 m
.14368 1.12004 L
s
0 1 .52 r
.72035 1.0455 m
.72637 1.05137 L
s
.76151 1.06474 m
.72637 1.05137 L
s
.2 1 0 r
.27965 1.0455 m
.27363 1.05137 L
s
.27363 1.05137 m
.23849 1.06474 L
s
0 1 .88 r
.59597 .96624 m
.58473 .96119 L
s
.59597 .96624 m
.61815 .98446 L
s
.56 1 0 r
.40403 .96624 m
.41527 .96119 L
s
.38185 .98446 m
.40403 .96624 L
s
0 1 .88 r
.86076 1.13591 m
.8735 1.14283 L
s
.86993 1.126 m
.86076 1.13591 L
s
.56 1 0 r
.13924 1.13591 m
.1265 1.14283 L
s
.13924 1.13591 m
.13007 1.126 L
s
.1265 1.14283 m
.11377 1.14966 L
s
.1265 1.14283 m
.11644 1.13182 L
s
0 1 .88 r
.8735 1.14283 m
.88623 1.14966 L
s
.88356 1.13182 m
.8735 1.14283 L
s
0 1 .52 r
.67567 1.01571 m
.67848 1.01866 L
s
.70826 1.03474 m
.67848 1.01866 L
s
.2 1 0 r
.32433 1.01571 m
.32152 1.01866 L
s
.32152 1.01866 m
.29174 1.03474 L
s
0 1 .88 r
.67232 1.0145 m
.66333 1.00816 L
s
.67232 1.0145 m
.68384 1.02075 L
s
.56 1 0 r
.32768 1.0145 m
.33667 1.00816 L
s
.31616 1.02075 m
.32768 1.0145 L
s
0 1 .88 r
.88623 1.14966 m
.89897 1.1564 L
s
.89722 1.13753 m
.88623 1.14966 L
s
.56 1 0 r
.11377 1.14966 m
.10103 1.1564 L
s
.11377 1.14966 m
.10278 1.13753 L
s
0 1 .52 r
.54621 .94964 m
.53472 .94177 L
s
.53472 .94177 m
.52192 .95676 L
s
.2 1 0 r
.45379 .94964 m
.46528 .94177 L
s
.47808 .95676 m
.46528 .94177 L
s
0 1 .88 r
.76166 1.07404 m
.77512 1.08116 L
s
.76075 1.06998 m
.76166 1.07404 L
s
.56 1 0 r
.23834 1.07404 m
.22488 1.08116 L
s
.23834 1.07404 m
.23925 1.06998 L
s
0 1 .52 r
.58364 .96429 m
.57401 .95567 L
s
.57401 .95567 m
.55778 .95721 L
s
.2 1 0 r
.41636 .96429 m
.42599 .95567 L
s
.44222 .95721 m
.42599 .95567 L
s
0 1 .16 r
.53064 .94849 m
.53386 .94172 L
s
.56593 .96062 m
.53386 .94172 L
s
.46936 .94849 m
.46614 .94172 L
s
.46614 .94172 m
.43407 .96062 L
s
.56 1 0 r
.10103 1.1564 m
.0883 1.16304 L
s
.10103 1.1564 m
.08911 1.14312 L
s
0 1 .88 r
.89897 1.1564 m
.9117 1.16304 L
s
.91089 1.14312 m
.89897 1.1564 L
s
0 .76 1 r
.78684 1.08991 m
.79706 1.09231 L
s
.74716 1.0607 m
.78684 1.08991 L
s
.92 1 0 r
.21316 1.08991 m
.20294 1.09231 L
s
.21316 1.08991 m
.25284 1.0607 L
s
0 1 .88 r
.7026 1.03474 m
.69985 1.03111 L
s
.7026 1.03474 m
.70959 1.03873 L
s
.56 1 0 r
.2974 1.03474 m
.30015 1.03111 L
s
.29041 1.03873 m
.2974 1.03474 L
s
0 1 .88 r
.73205 1.05438 m
.74411 1.05958 L
s
.72812 1.05094 m
.73205 1.05438 L
s
.56 1 0 r
.26795 1.05438 m
.25589 1.05958 L
s
.26795 1.05438 m
.27188 1.05094 L
s
0 1 .16 r
.57224 .95897 m
.57852 .95801 L
s
.61244 .98262 m
.57852 .95801 L
s
.42776 .95897 m
.42148 .95801 L
s
.42148 .95801 m
.38756 .98262 L
s
0 .76 1 r
.64806 .99837 m
.64867 .99884 L
s
.64806 .99837 m
.69969 1.0305 L
s
.92 1 0 r
.35194 .99837 m
.35133 .99884 L
s
.30031 1.0305 m
.35194 .99837 L
s
0 .76 1 r
.6955 1.02987 m
.69969 1.0305 L
s
.6955 1.02987 m
.7397 1.05927 L
s
.92 1 0 r
.3045 1.02987 m
.30031 1.0305 L
s
.2603 1.05927 m
.3045 1.02987 L
s
0 .76 1 r
.7397 1.05927 m
.74716 1.0607 L
s
.92 1 0 r
.2603 1.05927 m
.25284 1.0607 L
s
.56 1 0 r
.0883 1.16304 m
.07543 1.1486 L
s
0 1 .88 r
.92457 1.1486 m
.9117 1.16304 L
s
.56 1 0 r
.41527 .96119 m
.42651 .95716 L
s
.39095 .98166 m
.41527 .96119 L
s
0 1 .88 r
.58473 .96119 m
.57349 .95716 L
s
.58473 .96119 m
.60905 .98166 L
s
.2 1 0 r
.37158 .98737 m
.37557 .98359 L
s
.37557 .98359 m
.35156 .99863 L
s
.39763 .97106 m
.37557 .98359 L
s
0 1 .52 r
.62842 .98737 m
.62443 .98359 L
s
.62443 .98359 m
.60237 .97106 L
s
.64844 .99863 m
.62443 .98359 L
s
0 1 .88 r
.74752 1.06371 m
.76075 1.06998 L
s
.74411 1.05958 m
.74752 1.06371 L
s
.56 1 0 r
.25248 1.06371 m
.23925 1.06998 L
s
.25248 1.06371 m
.25589 1.05958 L
s
0 1 .88 r
.68993 1.02575 m
.68384 1.02075 L
s
.68993 1.02575 m
.69985 1.03111 L
s
.56 1 0 r
.31007 1.02575 m
.31616 1.02075 L
s
.30015 1.03111 m
.31007 1.02575 L
s
0 1 .88 r
.72812 1.05094 m
.73821 1.05457 L
s
.72281 1.04705 m
.72812 1.05094 L
s
.56 1 0 r
.27188 1.05094 m
.26179 1.05457 L
s
.27188 1.05094 m
.27719 1.04705 L
s
0 1 .88 r
.70959 1.03873 m
.71036 1.03695 L
s
.70959 1.03873 m
.71649 1.04291 L
s
.56 1 0 r
.29041 1.03873 m
.28964 1.03695 L
s
.28351 1.04291 m
.29041 1.03873 L
s
0 1 .88 r
.77512 1.08116 m
.78859 1.08807 L
s
.77402 1.07599 m
.77512 1.08116 L
s
.56 1 0 r
.22488 1.08116 m
.21141 1.08807 L
s
.22488 1.08116 m
.22598 1.07599 L
s
.2 1 0 r
.39056 .97759 m
.39763 .97106 L
s
.41636 .96429 m
.39763 .97106 L
s
0 1 .52 r
.60944 .97759 m
.60237 .97106 L
s
.60237 .97106 m
.58364 .96429 L
s
0 1 .88 r
.66333 1.00816 m
.65433 1.00227 L
s
.66333 1.00816 m
.67774 1.0162 L
s
.56 1 0 r
.33667 1.00816 m
.34567 1.00227 L
s
.32226 1.0162 m
.33667 1.00816 L
s
.2 1 0 r
.28569 1.03995 m
.27965 1.0455 L
s
.27965 1.0455 m
.24742 1.05822 L
s
0 1 .52 r
.71431 1.03995 m
.72035 1.0455 L
s
.75258 1.05822 m
.72035 1.0455 L
s
0 1 .88 r
.57349 .95716 m
.56223 .9543 L
s
.57349 .95716 m
.59992 .97954 L
s
.56 1 0 r
.42651 .95716 m
.43777 .9543 L
s
.40008 .97954 m
.42651 .95716 L
s
0 1 .88 r
.72281 1.04705 m
.73024 1.04895 L
s
.71649 1.04291 m
.72281 1.04705 L
s
.56 1 0 r
.27719 1.04705 m
.26976 1.04895 L
s
.27719 1.04705 m
.28351 1.04291 L
s
0 1 .88 r
.71649 1.04291 m
.72074 1.04299 L
s
.56 1 0 r
.28351 1.04291 m
.27926 1.04299 L
s
0 1 .88 r
.78859 1.08807 m
.8021 1.09479 L
s
.78734 1.08177 m
.78859 1.08807 L
s
.56 1 0 r
.21141 1.08807 m
.1979 1.09479 L
s
.21141 1.08807 m
.21266 1.08177 L
s
0 1 .16 r
.5 .95015 m
.5 .94204 L
s
.5 .94204 m
.46936 .94849 L
s
.53064 .94849 m
.5 .94204 L
s
.2 1 0 r
.35094 .99926 m
.35156 .99863 L
s
.35156 .99863 m
.32713 1.0132 L
s
0 1 .52 r
.64906 .99926 m
.64844 .99863 L
s
.67287 1.0132 m
.64844 .99863 L
s
0 1 .88 r
.56223 .9543 m
.55096 .95267 L
s
.56223 .9543 m
.59076 .97808 L
s
.56 1 0 r
.43777 .9543 m
.44904 .95267 L
s
.40924 .97808 m
.43777 .9543 L
s
0 1 .52 r
.67287 1.0132 m
.67567 1.01571 L
s
.70219 1.02989 m
.67567 1.01571 L
s
.2 1 0 r
.32713 1.0132 m
.32433 1.01571 L
s
.32433 1.01571 m
.29781 1.02989 L
s
0 1 .88 r
.74411 1.05958 m
.75623 1.06451 L
s
.73821 1.05457 m
.74411 1.05958 L
s
.56 1 0 r
.25589 1.05958 m
.24377 1.06451 L
s
.25589 1.05958 m
.26179 1.05457 L
s
0 1 .88 r
.65433 1.00227 m
.64531 .9969 L
s
.65433 1.00227 m
.67162 1.01212 L
s
.56 1 0 r
.34567 1.00227 m
.35469 .9969 L
s
.32838 1.01212 m
.34567 1.00227 L
s
0 1 .88 r
.76075 1.06998 m
.77402 1.07599 L
s
.75623 1.06451 m
.76075 1.06998 L
s
.56 1 0 r
.23925 1.06998 m
.22598 1.07599 L
s
.23925 1.06998 m
.24377 1.06451 L
s
0 1 .88 r
.69985 1.03111 m
.69709 1.02786 L
s
.69985 1.03111 m
.71036 1.03695 L
s
.56 1 0 r
.30015 1.03111 m
.30291 1.02786 L
s
.28964 1.03695 m
.30015 1.03111 L
s
0 .76 1 r
.75468 1.06209 m
.79706 1.09231 L
s
.92 1 0 r
.20294 1.09231 m
.24532 1.06209 L
s
0 1 .52 r
.7882 1.08523 m
.79706 1.09231 L
s
.83518 1.09761 m
.79706 1.09231 L
s
.2 1 0 r
.2118 1.08523 m
.20294 1.09231 L
s
.20294 1.09231 m
.16482 1.09761 L
s
.44222 .95721 m
.45379 .94964 L
s
.46521 .96046 m
.45379 .94964 L
s
0 1 .52 r
.55778 .95721 m
.54621 .94964 L
s
.54621 .94964 m
.53479 .96046 L
s
0 1 .88 r
.68384 1.02075 m
.67774 1.0162 L
s
.68384 1.02075 m
.69709 1.02786 L
s
.56 1 0 r
.31616 1.02075 m
.32226 1.0162 L
s
.30291 1.02786 m
.31616 1.02075 L
s
.1979 1.09479 m
.18438 1.10134 L
s
.1979 1.09479 m
.1993 1.08734 L
s
0 1 .88 r
.8021 1.09479 m
.81562 1.10134 L
s
.8007 1.08734 m
.8021 1.09479 L
s
0 1 .16 r
.43407 .96062 m
.42776 .95897 L
s
.42776 .95897 m
.39667 .98025 L
s
.56593 .96062 m
.57224 .95897 L
s
.60333 .98025 m
.57224 .95897 L
s
0 1 .52 r
.70826 1.03474 m
.71431 1.03995 L
s
.74362 1.0519 m
.71431 1.03995 L
s
.2 1 0 r
.29174 1.03474 m
.28569 1.03995 L
s
.28569 1.03995 m
.25638 1.0519 L
s
0 .76 1 r
.74716 1.0607 m
.75468 1.06209 L
s
.69969 1.0305 m
.74716 1.0607 L
s
.92 1 0 r
.25284 1.0607 m
.24532 1.06209 L
s
.25284 1.0607 m
.30031 1.0305 L
s
0 .76 1 r
.69969 1.0305 m
.70391 1.03122 L
s
.92 1 0 r
.30031 1.0305 m
.29609 1.03122 L
s
0 .76 1 r
.64867 .99884 m
.70391 1.03122 L
s
.92 1 0 r
.29609 1.03122 m
.35133 .99884 L
s
0 1 .16 r
.36035 .99383 m
.35133 .99884 L
s
.63965 .99383 m
.64867 .99884 L
s
.35133 .99884 m
.31477 1.01784 L
s
.68523 1.01784 m
.64867 .99884 L
s
0 1 .52 r
.59334 .97199 m
.58364 .96429 L
s
.58364 .96429 m
.56943 .96443 L
s
.2 1 0 r
.40666 .97199 m
.41636 .96429 L
s
.43057 .96443 m
.41636 .96429 L
s
0 1 .88 r
.73821 1.05457 m
.74837 1.058 L
s
.73024 1.04895 m
.73821 1.05457 L
s
.56 1 0 r
.26179 1.05457 m
.25163 1.058 L
s
.26179 1.05457 m
.26976 1.04895 L
s
0 1 .88 r
.55096 .95267 m
.53965 .95226 L
s
.55096 .95267 m
.58155 .97723 L
s
.56 1 0 r
.44904 .95267 m
.46035 .95226 L
s
.41845 .97723 m
.44904 .95267 L
s
0 1 .88 r
.71036 1.03695 m
.71115 1.03543 L
s
.71036 1.03695 m
.72074 1.04299 L
s
.56 1 0 r
.28964 1.03695 m
.28885 1.03543 L
s
.27926 1.04299 m
.28964 1.03695 L
s
0 1 .52 r
.77932 1.07826 m
.7882 1.08523 L
s
.82389 1.09088 m
.7882 1.08523 L
s
.2 1 0 r
.22068 1.07826 m
.2118 1.08523 L
s
.2118 1.08523 m
.17611 1.09088 L
s
0 1 .88 r
.64531 .9969 m
.63628 .99211 L
s
.64531 .9969 m
.66549 1.00851 L
s
.56 1 0 r
.35469 .9969 m
.36372 .99211 L
s
.33451 1.00851 m
.35469 .9969 L
s
.18438 1.10134 m
.17083 1.10773 L
s
.18438 1.10134 m
.18589 1.0927 L
s
0 1 .88 r
.81562 1.10134 m
.82917 1.10773 L
s
.81411 1.0927 m
.81562 1.10134 L
s
0 1 .16 r
.47262 .95465 m
.46936 .94849 L
s
.52738 .95465 m
.53064 .94849 L
s
.46936 .94849 m
.44043 .96278 L
s
.55957 .96278 m
.53064 .94849 L
s
0 1 .88 r
.77402 1.07599 m
.78734 1.08177 L
s
.7684 1.06921 m
.77402 1.07599 L
s
.56 1 0 r
.22598 1.07599 m
.21266 1.08177 L
s
.22598 1.07599 m
.2316 1.06921 L
s
.2 1 0 r
.36757 .99095 m
.37158 .98737 L
s
.37158 .98737 m
.35094 .99926 L
s
.39056 .97759 m
.37158 .98737 L
s
0 1 .52 r
.63243 .99095 m
.62842 .98737 L
s
.62842 .98737 m
.60944 .97759 L
s
.64906 .99926 m
.62842 .98737 L
s
0 1 .88 r
.73024 1.04895 m
.73773 1.05077 L
s
.72074 1.04299 m
.73024 1.04895 L
s
.56 1 0 r
.26976 1.04895 m
.26227 1.05077 L
s
.26976 1.04895 m
.27926 1.04299 L
s
0 1 .88 r
.72074 1.04299 m
.72502 1.04316 L
s
.56 1 0 r
.27926 1.04299 m
.27498 1.04316 L
s
0 1 .52 r
.45818 .95243 m
.44549 .95511 L
s
.44549 .95511 m
.43699 .97709 L
s
.2 1 0 r
.54182 .95243 m
.55451 .95511 L
s
.56301 .97709 m
.55451 .95511 L
s
0 1 .52 r
.61656 .98346 m
.60944 .97759 L
s
.60944 .97759 m
.59334 .97199 L
s
.2 1 0 r
.38344 .98346 m
.39056 .97759 L
s
.40666 .97199 m
.39056 .97759 L
s
0 1 .88 r
.75623 1.06451 m
.7684 1.06921 L
s
.74837 1.058 m
.75623 1.06451 L
s
.56 1 0 r
.24377 1.06451 m
.2316 1.06921 L
s
.24377 1.06451 m
.25163 1.058 L
s
.32226 1.0162 m
.32838 1.01212 L
s
.30566 1.02498 m
.32226 1.0162 L
s
0 1 .88 r
.67774 1.0162 m
.67162 1.01212 L
s
.67774 1.0162 m
.69434 1.02498 L
s
0 1 .16 r
.6306 .98943 m
.63965 .99383 L
s
.67384 1.01251 m
.63965 .99383 L
s
.3694 .98943 m
.36035 .99383 L
s
.36035 .99383 m
.32616 1.01251 L
s
0 1 .88 r
.82917 1.10773 m
.84273 1.11396 L
s
.82755 1.09787 m
.82917 1.10773 L
s
.56 1 0 r
.17083 1.10773 m
.15727 1.11396 L
s
.17083 1.10773 m
.17245 1.09787 L
s
.2 1 0 r
.22957 1.07143 m
.22068 1.07826 L
s
.22068 1.07826 m
.18742 1.0842 L
s
0 1 .52 r
.77043 1.07143 m
.77932 1.07826 L
s
.81258 1.0842 m
.77932 1.07826 L
s
.70219 1.02989 m
.70826 1.03474 L
s
.73465 1.0458 m
.70826 1.03474 L
s
.2 1 0 r
.29781 1.02989 m
.29174 1.03474 L
s
.29174 1.03474 m
.26535 1.0458 L
s
.52912 .95096 m
.54182 .95243 L
s
.54954 .97433 m
.54182 .95243 L
s
0 1 .52 r
.47088 .95096 m
.45818 .95243 L
s
.45818 .95243 m
.45046 .97433 L
s
.2 1 0 r
.32995 1.01111 m
.32713 1.0132 L
s
.32713 1.0132 m
.30389 1.02542 L
s
0 1 .52 r
.67005 1.01111 m
.67287 1.0132 L
s
.69611 1.02542 m
.67287 1.0132 L
s
0 1 .88 r
.69709 1.02786 m
.69434 1.02498 L
s
.69709 1.02786 m
.71115 1.03543 L
s
.56 1 0 r
.30291 1.02786 m
.30566 1.02498 L
s
.28885 1.03543 m
.30291 1.02786 L
s
0 1 .88 r
.53965 .95226 m
.5283 .95298 L
s
.53965 .95226 m
.57231 .97692 L
s
.56 1 0 r
.46035 .95226 m
.4717 .95298 L
s
.42769 .97692 m
.46035 .95226 L
s
0 1 .52 r
.6497 1.00009 m
.64906 .99926 L
s
.67005 1.01111 m
.64906 .99926 L
s
.2 1 0 r
.3503 1.00009 m
.35094 .99926 L
s
.35094 .99926 m
.32995 1.01111 L
s
0 1 .88 r
.63628 .99211 m
.62723 .98795 L
s
.63628 .99211 m
.65934 1.00538 L
s
.56 1 0 r
.36372 .99211 m
.37277 .98795 L
s
.34066 1.00538 m
.36372 .99211 L
s
0 1 .52 r
.56943 .96443 m
.55778 .95721 L
s
.55778 .95721 m
.5477 .96471 L
s
.2 1 0 r
.43057 .96443 m
.44222 .95721 L
s
.4523 .96471 m
.44222 .95721 L
s
0 1 .52 r
.4836 .95074 m
.47088 .95096 L
s
.47088 .95096 m
.46391 .97215 L
s
.2 1 0 r
.5164 .95074 m
.52912 .95096 L
s
.53609 .97215 m
.52912 .95096 L
s
0 1 .88 r
.84273 1.11396 m
.85632 1.12004 L
s
.84104 1.10287 m
.84273 1.11396 L
s
.56 1 0 r
.15727 1.11396 m
.14368 1.12004 L
s
.15727 1.11396 m
.15896 1.10287 L
s
0 1 .88 r
.78734 1.08177 m
.8007 1.08734 L
s
.78063 1.07367 m
.78734 1.08177 L
s
.56 1 0 r
.21266 1.08177 m
.1993 1.08734 L
s
.21266 1.08177 m
.21937 1.07367 L
s
0 1 .16 r
.44043 .96278 m
.43407 .96062 L
s
.43407 .96062 m
.40583 .97855 L
s
.55957 .96278 m
.56593 .96062 L
s
.59417 .97855 m
.56593 .96062 L
s
0 .76 1 r
.70391 1.03122 m
.75468 1.06209 L
s
.92 1 0 r
.24532 1.06209 m
.29609 1.03122 L
s
0 1 .52 r
.76151 1.06474 m
.77043 1.07143 L
s
.80126 1.07756 m
.77043 1.07143 L
s
.2 1 0 r
.23849 1.06474 m
.22957 1.07143 L
s
.22957 1.07143 m
.19874 1.07756 L
s
0 1 .88 r
.74837 1.058 m
.75859 1.06124 L
s
.73773 1.05077 m
.74837 1.058 L
s
.56 1 0 r
.25163 1.058 m
.24141 1.06124 L
s
.25163 1.058 m
.26227 1.05077 L
s
0 1 .16 r
.37847 .98568 m
.3694 .98943 L
s
.3694 .98943 m
.33757 1.00752 L
s
.62153 .98568 m
.6306 .98943 L
s
.66243 1.00752 m
.6306 .98943 L
s
0 1 .52 r
.49634 .95173 m
.4836 .95074 L
s
.4836 .95074 m
.47735 .97062 L
s
.2 1 0 r
.50366 .95173 m
.5164 .95074 L
s
.52265 .97062 m
.5164 .95074 L
s
0 1 .16 r
.5 .95708 m
.5 .95015 L
s
.5 .95015 m
.47262 .95465 L
s
.52738 .95465 m
.5 .95015 L
s
0 1 .88 r
.71115 1.03543 m
.71195 1.03412 L
s
.71115 1.03543 m
.72502 1.04316 L
s
.56 1 0 r
.28885 1.03543 m
.28805 1.03412 L
s
.27498 1.04316 m
.28885 1.03543 L
s
0 1 .88 r
.85632 1.12004 m
.86993 1.126 L
s
.85457 1.10771 m
.85632 1.12004 L
s
.56 1 0 r
.14368 1.12004 m
.13007 1.126 L
s
.14368 1.12004 m
.14543 1.10771 L
s
0 1 .52 r
.60311 .9789 m
.59334 .97199 L
s
.59334 .97199 m
.58116 .97126 L
s
.2 1 0 r
.39689 .9789 m
.40666 .97199 L
s
.41884 .97126 m
.40666 .97199 L
s
0 1 .88 r
.67162 1.01212 m
.66549 1.00851 L
s
.67162 1.01212 m
.69157 1.02245 L
s
.56 1 0 r
.32838 1.01212 m
.33451 1.00851 L
s
.30843 1.02245 m
.32838 1.01212 L
s
0 1 .88 r
.7684 1.06921 m
.78063 1.07367 L
s
.75859 1.06124 m
.7684 1.06921 L
s
.56 1 0 r
.2316 1.06921 m
.21937 1.07367 L
s
.2316 1.06921 m
.24141 1.06124 L
s
0 1 .88 r
.5283 .95298 m
.56301 .97709 L
s
.56 1 0 r
.43699 .97709 m
.4717 .95298 L
s
0 1 .88 r
.62723 .98795 m
.61815 .98446 L
s
.62723 .98795 m
.65316 1.00271 L
s
.56 1 0 r
.37277 .98795 m
.38185 .98446 L
s
.34684 1.00271 m
.37277 .98795 L
s
0 1 .52 r
.69611 1.02542 m
.70219 1.02989 L
s
.72566 1.03995 m
.70219 1.02989 L
s
.2 1 0 r
.30389 1.02542 m
.29781 1.02989 L
s
.29781 1.02989 m
.27434 1.03995 L
s
0 1 .88 r
.73773 1.05077 m
.74527 1.05251 L
s
.72502 1.04316 m
.73773 1.05077 L
s
.56 1 0 r
.26227 1.05077 m
.25473 1.05251 L
s
.26227 1.05077 m
.27498 1.04316 L
s
0 1 .52 r
.75258 1.05822 m
.76151 1.06474 L
s
.78993 1.071 m
.76151 1.06474 L
s
.2 1 0 r
.24742 1.05822 m
.23849 1.06474 L
s
.23849 1.06474 m
.21007 1.071 L
s
0 1 .88 r
.72502 1.04316 m
.72934 1.04338 L
s
.56 1 0 r
.27498 1.04316 m
.27066 1.04338 L
s
.2 1 0 r
.49089 .95379 m
.50366 .95173 L
s
.50922 .96977 m
.50366 .95173 L
s
0 1 .52 r
.50911 .95379 m
.49634 .95173 L
s
.49634 .95173 m
.49078 .96977 L
s
0 1 .88 r
.8007 1.08734 m
.81411 1.0927 L
s
.79292 1.07792 m
.8007 1.08734 L
s
.56 1 0 r
.1993 1.08734 m
.18589 1.0927 L
s
.1993 1.08734 m
.20708 1.07792 L
s
0 1 .88 r
.86993 1.126 m
.88356 1.13182 L
s
.86814 1.11239 m
.86993 1.126 L
s
.56 1 0 r
.13007 1.126 m
.11644 1.13182 L
s
.13007 1.126 m
.13186 1.11239 L
s
0 1 .88 r
.69434 1.02498 m
.69157 1.02245 L
s
.69434 1.02498 m
.71195 1.03412 L
s
.56 1 0 r
.30566 1.02498 m
.30843 1.02245 L
s
.28805 1.03412 m
.30566 1.02498 L
s
.2 1 0 r
.33277 1.0094 m
.32995 1.01111 L
s
.32995 1.01111 m
.30999 1.02135 L
s
0 1 .52 r
.66723 1.0094 m
.67005 1.01111 L
s
.69001 1.02135 m
.67005 1.01111 L
s
.63648 .99429 m
.63243 .99095 L
s
.63243 .99095 m
.61656 .98346 L
s
.6497 1.00009 m
.63243 .99095 L
s
.2 1 0 r
.36352 .99429 m
.36757 .99095 L
s
.36757 .99095 m
.3503 1.00009 L
s
.38344 .98346 m
.36757 .99095 L
s
0 1 .16 r
.47593 .9602 m
.47262 .95465 L
s
.52407 .9602 m
.52738 .95465 L
s
.47262 .95465 m
.44683 .96525 L
s
.55317 .96525 m
.52738 .95465 L
s
.38756 .98262 m
.37847 .98568 L
s
.37847 .98568 m
.349 1.00291 L
s
.61244 .98262 m
.62153 .98568 L
s
.651 1.00291 m
.62153 .98568 L
s
0 1 .52 r
.58116 .97126 m
.56943 .96443 L
s
.56943 .96443 m
.56066 .96935 L
s
.2 1 0 r
.41884 .97126 m
.43057 .96443 L
s
.43934 .96935 m
.43057 .96443 L
s
0 1 .52 r
.62374 .98873 m
.61656 .98346 L
s
.61656 .98346 m
.60311 .9789 L
s
.2 1 0 r
.37626 .98873 m
.38344 .98346 L
s
.39689 .9789 m
.38344 .98346 L
s
0 1 .88 r
.88356 1.13182 m
.89722 1.13753 L
s
.88175 1.11692 m
.88356 1.13182 L
s
.56 1 0 r
.11644 1.13182 m
.10278 1.13753 L
s
.11644 1.13182 m
.11825 1.11692 L
s
0 1 .52 r
.52192 .95676 m
.50911 .95379 L
s
.50911 .95379 m
.50421 .96963 L
s
.2 1 0 r
.47808 .95676 m
.49089 .95379 L
s
.49579 .96963 m
.49089 .95379 L
s
0 1 .52 r
.74362 1.0519 m
.75258 1.05822 L
s
.77859 1.06452 m
.75258 1.05822 L
s
.2 1 0 r
.25638 1.0519 m
.24742 1.05822 L
s
.24742 1.05822 m
.22141 1.06452 L
s
0 1 .52 r
.65033 1.00103 m
.6497 1.00009 L
s
.66723 1.0094 m
.6497 1.00009 L
s
.2 1 0 r
.34967 1.00103 m
.3503 1.00009 L
s
.3503 1.00009 m
.33277 1.0094 L
s
0 1 .88 r
.61815 .98446 m
.60905 .98166 L
s
.61815 .98446 m
.64696 1.00049 L
s
.56 1 0 r
.38185 .98446 m
.39095 .98166 L
s
.35304 1.00049 m
.38185 .98446 L
s
0 1 .88 r
.75859 1.06124 m
.76888 1.0643 L
s
.74527 1.05251 m
.75859 1.06124 L
s
.56 1 0 r
.24141 1.06124 m
.23112 1.0643 L
s
.24141 1.06124 m
.25473 1.05251 L
s
0 1 .88 r
.81411 1.0927 m
.82755 1.09787 L
s
.80527 1.08196 m
.81411 1.0927 L
s
.56 1 0 r
.18589 1.0927 m
.17245 1.09787 L
s
.18589 1.0927 m
.19473 1.08196 L
s
0 1 .16 r
.44683 .96525 m
.44043 .96278 L
s
.44043 .96278 m
.41501 .97748 L
s
.55317 .96525 m
.55957 .96278 L
s
.58499 .97748 m
.55957 .96278 L
s
.2 1 0 r
.30999 1.02135 m
.30389 1.02542 L
s
.30389 1.02542 m
.28335 1.03438 L
s
0 1 .52 r
.69001 1.02135 m
.69611 1.02542 L
s
.71665 1.03438 m
.69611 1.02542 L
s
.56 1 0 r
.33451 1.00851 m
.34066 1.00538 L
s
.3112 1.02024 m
.33451 1.00851 L
s
0 1 .88 r
.66549 1.00851 m
.65934 1.00538 L
s
.66549 1.00851 m
.6888 1.02024 L
s
.78063 1.07367 m
.79292 1.07792 L
s
.76888 1.0643 m
.78063 1.07367 L
s
.56 1 0 r
.21937 1.07367 m
.20708 1.07792 L
s
.21937 1.07367 m
.23112 1.0643 L
s
0 1 .88 r
.89722 1.13753 m
.91089 1.14312 L
s
.8954 1.12132 m
.89722 1.13753 L
s
.56 1 0 r
.10278 1.13753 m
.08911 1.14312 L
s
.10278 1.13753 m
.1046 1.12132 L
s
0 1 .88 r
.71195 1.03412 m
.71277 1.033 L
s
.71195 1.03412 m
.72934 1.04338 L
s
.56 1 0 r
.28805 1.03412 m
.28723 1.033 L
s
.27066 1.04338 m
.28805 1.03412 L
s
0 1 .52 r
.53479 .96046 m
.52192 .95676 L
s
.52192 .95676 m
.51764 .97022 L
s
.2 1 0 r
.46521 .96046 m
.47808 .95676 L
s
.48236 .97022 m
.47808 .95676 L
s
0 1 .52 r
.73465 1.0458 m
.74362 1.0519 L
s
.76723 1.05813 m
.74362 1.0519 L
s
.2 1 0 r
.26535 1.0458 m
.25638 1.0519 L
s
.25638 1.0519 m
.23277 1.05813 L
s
0 1 .16 r
.39667 .98025 m
.38756 .98262 L
s
.38756 .98262 m
.36044 .99872 L
s
.60333 .98025 m
.61244 .98262 L
s
.63956 .99872 m
.61244 .98262 L
s
0 1 .88 r
.91089 1.14312 m
.92457 1.1486 L
s
.90909 1.12559 m
.91089 1.14312 L
s
.56 1 0 r
.08911 1.14312 m
.07543 1.1486 L
s
.08911 1.14312 m
.09091 1.12559 L
s
.2 1 0 r
.38705 .98514 m
.39689 .9789 L
s
.40705 .97771 m
.39689 .9789 L
s
0 1 .52 r
.61295 .98514 m
.60311 .9789 L
s
.60311 .9789 m
.59295 .97771 L
s
0 1 .88 r
.74527 1.05251 m
.75286 1.05415 L
s
.72934 1.04338 m
.74527 1.05251 L
s
.56 1 0 r
.25473 1.05251 m
.24714 1.05415 L
s
.25473 1.05251 m
.27066 1.04338 L
s
0 1 .88 r
.69157 1.02245 m
.6888 1.02024 L
s
.69157 1.02245 m
.71277 1.033 L
s
.56 1 0 r
.30843 1.02245 m
.3112 1.02024 L
s
.28723 1.033 m
.30843 1.02245 L
s
0 1 .88 r
.72934 1.04338 m
.7337 1.04363 L
s
.56 1 0 r
.27066 1.04338 m
.2663 1.04363 L
s
0 1 .88 r
.60905 .98166 m
.59992 .97954 L
s
.60905 .98166 m
.64073 .99867 L
s
.56 1 0 r
.39095 .98166 m
.40008 .97954 L
s
.35927 .99867 m
.39095 .98166 L
s
0 1 .52 r
.6644 1.00802 m
.66723 1.0094 L
s
.68389 1.01768 m
.66723 1.0094 L
s
.2 1 0 r
.3356 1.00802 m
.33277 1.0094 L
s
.33277 1.0094 m
.31611 1.01768 L
s
0 1 .88 r
.82755 1.09787 m
.84104 1.10287 L
s
.81767 1.08581 m
.82755 1.09787 L
s
.56 1 0 r
.17245 1.09787 m
.15896 1.10287 L
s
.17245 1.09787 m
.18233 1.08581 L
s
.2 1 0 r
.40705 .97771 m
.41884 .97126 L
s
.42632 .97425 m
.41884 .97126 L
s
0 1 .52 r
.59295 .97771 m
.58116 .97126 L
s
.58116 .97126 m
.57368 .97425 L
s
0 1 .16 r
.5 .96302 m
.5 .95708 L
s
.5 .95708 m
.47593 .9602 L
s
.52407 .9602 m
.5 .95708 L
s
0 1 .88 r
.92282 1.12974 m
.92457 1.1486 L
s
.56 1 0 r
.07543 1.1486 m
.07718 1.12974 L
s
.2 1 0 r
.27434 1.03995 m
.26535 1.0458 L
s
.26535 1.0458 m
.24414 1.05187 L
s
0 1 .52 r
.72566 1.03995 m
.73465 1.0458 L
s
.75586 1.05187 m
.73465 1.0458 L
s
.68389 1.01768 m
.69001 1.02135 L
s
.70762 1.0291 m
.69001 1.02135 L
s
.2 1 0 r
.31611 1.01768 m
.30999 1.02135 L
s
.30999 1.02135 m
.29238 1.0291 L
s
0 1 .52 r
.5477 .96471 m
.53479 .96046 L
s
.53479 .96046 m
.53108 .9715 L
s
.2 1 0 r
.4523 .96471 m
.46521 .96046 L
s
.46892 .9715 m
.46521 .96046 L
s
0 1 .88 r
.79292 1.07792 m
.80527 1.08196 L
s
.77922 1.06718 m
.79292 1.07792 L
s
.56 1 0 r
.20708 1.07792 m
.19473 1.08196 L
s
.20708 1.07792 m
.22078 1.06718 L
s
0 1 .52 r
.64055 .99736 m
.63648 .99429 L
s
.63648 .99429 m
.62374 .98873 L
s
.65033 1.00103 m
.63648 .99429 L
s
.2 1 0 r
.35945 .99736 m
.36352 .99429 L
s
.36352 .99429 m
.34967 1.00103 L
s
.37626 .98873 m
.36352 .99429 L
s
0 1 .88 r
.65934 1.00538 m
.65316 1.00271 L
s
.65934 1.00538 m
.68602 1.01833 L
s
.56 1 0 r
.34066 1.00538 m
.34684 1.00271 L
s
.31398 1.01833 m
.34066 1.00538 L
s
0 1 .88 r
.76888 1.0643 m
.77922 1.06718 L
s
.75286 1.05415 m
.76888 1.0643 L
s
.56 1 0 r
.23112 1.0643 m
.22078 1.06718 L
s
.23112 1.0643 m
.24714 1.05415 L
s
0 1 .16 r
.40583 .97855 m
.39667 .98025 L
s
.59417 .97855 m
.60333 .98025 L
s
.39667 .98025 m
.3719 .99499 L
s
.6281 .99499 m
.60333 .98025 L
s
0 1 .52 r
.63096 .99347 m
.62374 .98873 L
s
.62374 .98873 m
.61295 .98514 L
s
.2 1 0 r
.36904 .99347 m
.37626 .98873 L
s
.38705 .98514 m
.37626 .98873 L
s
0 1 .52 r
.65098 1.00203 m
.65033 1.00103 L
s
.6644 1.00802 m
.65033 1.00103 L
s
.2 1 0 r
.34902 1.00203 m
.34967 1.00103 L
s
.34967 1.00103 m
.3356 1.00802 L
s
0 1 .16 r
.47926 .96515 m
.47593 .9602 L
s
.47593 .9602 m
.45329 .9679 L
s
.52074 .96515 m
.52407 .9602 L
s
.54671 .9679 m
.52407 .9602 L
s
0 1 .88 r
.84104 1.10287 m
.85457 1.10771 L
s
.83013 1.08948 m
.84104 1.10287 L
s
.56 1 0 r
.15896 1.10287 m
.14543 1.10771 L
s
.15896 1.10287 m
.16987 1.08948 L
s
0 1 .16 r
.54671 .9679 m
.55317 .96525 L
s
.57576 .97698 m
.55317 .96525 L
s
.45329 .9679 m
.44683 .96525 L
s
.44683 .96525 m
.42424 .97698 L
s
0 1 .88 r
.59992 .97954 m
.59076 .97808 L
s
.59992 .97954 m
.63447 .99722 L
s
.56 1 0 r
.40008 .97954 m
.40924 .97808 L
s
.36553 .99722 m
.40008 .97954 L
s
0 1 .52 r
.71665 1.03438 m
.72566 1.03995 L
s
.74448 1.04574 m
.72566 1.03995 L
s
.2 1 0 r
.28335 1.03438 m
.27434 1.03995 L
s
.27434 1.03995 m
.25552 1.04574 L
s
0 1 .88 r
.71277 1.033 m
.7136 1.03203 L
s
.71277 1.033 m
.7337 1.04363 L
s
.56 1 0 r
.28723 1.033 m
.2864 1.03203 L
s
.2663 1.04363 m
.28723 1.033 L
s
0 1 .52 r
.56066 .96935 m
.5477 .96471 L
s
.5477 .96471 m
.54453 .97345 L
s
.2 1 0 r
.43934 .96935 m
.4523 .96471 L
s
.45547 .97345 m
.4523 .96471 L
s
0 1 .88 r
.6888 1.02024 m
.68602 1.01833 L
s
.6888 1.02024 m
.7136 1.03203 L
s
.56 1 0 r
.3112 1.02024 m
.31398 1.01833 L
s
.2864 1.03203 m
.3112 1.02024 L
s
0 1 .88 r
.75286 1.05415 m
.7605 1.05568 L
s
.7337 1.04363 m
.75286 1.05415 L
s
.56 1 0 r
.24714 1.05415 m
.2395 1.05568 L
s
.24714 1.05415 m
.2663 1.04363 L
s
.2 1 0 r
.39518 .98379 m
.40705 .97771 L
s
.41324 .97932 m
.40705 .97771 L
s
0 1 .52 r
.60482 .98379 m
.59295 .97771 L
s
.59295 .97771 m
.58676 .97932 L
s
.2 1 0 r
.37715 .99079 m
.38705 .98514 L
s
.39518 .98379 m
.38705 .98514 L
s
0 1 .52 r
.62285 .99079 m
.61295 .98514 L
s
.61295 .98514 m
.60482 .98379 L
s
.67775 1.0144 m
.68389 1.01768 L
s
.69857 1.02415 m
.68389 1.01768 L
s
.2 1 0 r
.32225 1.0144 m
.31611 1.01768 L
s
.31611 1.01768 m
.30143 1.02415 L
s
0 1 .52 r
.66156 1.00693 m
.6644 1.00802 L
s
.67775 1.0144 m
.6644 1.00802 L
s
.2 1 0 r
.33844 1.00693 m
.3356 1.00802 L
s
.3356 1.00802 m
.32225 1.0144 L
s
0 1 .88 r
.7337 1.04363 m
.73809 1.04387 L
s
.56 1 0 r
.2663 1.04363 m
.26191 1.04387 L
s
0 1 .88 r
.80527 1.08196 m
.81767 1.08581 L
s
.78962 1.06987 m
.80527 1.08196 L
s
.56 1 0 r
.19473 1.08196 m
.18233 1.08581 L
s
.19473 1.08196 m
.21038 1.06987 L
s
.2 1 0 r
.17611 1.09088 m
.16482 1.09761 L
s
.16482 1.09761 m
.1381 1.09483 L
s
0 1 .52 r
.82389 1.09088 m
.83518 1.09761 L
s
.8619 1.09483 m
.83518 1.09761 L
s
0 1 .88 r
.85457 1.10771 m
.86814 1.11239 L
s
.84264 1.09298 m
.85457 1.10771 L
s
.56 1 0 r
.14543 1.10771 m
.13186 1.11239 L
s
.14543 1.10771 m
.15736 1.09298 L
s
0 1 .88 r
.65316 1.00271 m
.64696 1.00049 L
s
.65316 1.00271 m
.68323 1.01667 L
s
.56 1 0 r
.34684 1.00271 m
.35304 1.00049 L
s
.31677 1.01667 m
.34684 1.00271 L
s
0 1 .16 r
.41501 .97748 m
.40583 .97855 L
s
.40583 .97855 m
.38337 .99174 L
s
.58499 .97748 m
.59417 .97855 L
s
.61663 .99174 m
.59417 .97855 L
s
.2 1 0 r
.29238 1.0291 m
.28335 1.03438 L
s
.28335 1.03438 m
.26692 1.03978 L
s
0 1 .52 r
.70762 1.0291 m
.71665 1.03438 L
s
.73308 1.03978 m
.71665 1.03438 L
s
.57368 .97425 m
.56066 .96935 L
s
.56066 .96935 m
.55799 .976 L
s
.2 1 0 r
.42632 .97425 m
.43934 .96935 L
s
.44201 .976 m
.43934 .96935 L
s
0 1 .52 r
.81258 1.0842 m
.82389 1.09088 L
s
.84882 1.0889 m
.82389 1.09088 L
s
.2 1 0 r
.18742 1.0842 m
.17611 1.09088 L
s
.17611 1.09088 m
.15118 1.0889 L
s
0 1 .88 r
.77922 1.06718 m
.78962 1.06987 L
s
.7605 1.05568 m
.77922 1.06718 L
s
.56 1 0 r
.22078 1.06718 m
.21038 1.06987 L
s
.22078 1.06718 m
.2395 1.05568 L
s
0 1 .88 r
.59076 .97808 m
.58155 .97723 L
s
.59076 .97808 m
.62818 .9961 L
s
.56 1 0 r
.40924 .97808 m
.41845 .97723 L
s
.37182 .9961 m
.40924 .97808 L
s
0 1 .52 r
.80126 1.07756 m
.81258 1.0842 L
s
.83574 1.08296 m
.81258 1.0842 L
s
.2 1 0 r
.19874 1.07756 m
.18742 1.0842 L
s
.18742 1.0842 m
.16426 1.08296 L
s
0 1 .16 r
.5 .96814 m
.5 .96302 L
s
.5 .96302 m
.47926 .96515 L
s
.52074 .96515 m
.5 .96302 L
s
0 1 .52 r
.64465 1.00015 m
.64055 .99736 L
s
.64055 .99736 m
.63096 .99347 L
s
.65098 1.00203 m
.64055 .99736 L
s
.2 1 0 r
.35535 1.00015 m
.35945 .99736 L
s
.35945 .99736 m
.34902 1.00203 L
s
.36904 .99347 m
.35945 .99736 L
s
0 1 .88 r
.86814 1.11239 m
.88175 1.11692 L
s
.85521 1.09631 m
.86814 1.11239 L
s
.56 1 0 r
.13186 1.11239 m
.11825 1.11692 L
s
.13186 1.11239 m
.14479 1.09631 L
s
0 1 .52 r
.65163 1.00304 m
.65098 1.00203 L
s
.66156 1.00693 m
.65098 1.00203 L
s
.2 1 0 r
.34837 1.00304 m
.34902 1.00203 L
s
.34902 1.00203 m
.33844 1.00693 L
s
0 1 .52 r
.63824 .99771 m
.63096 .99347 L
s
.63096 .99347 m
.62285 .99079 L
s
.2 1 0 r
.36176 .99771 m
.36904 .99347 L
s
.37715 .99079 m
.36904 .99347 L
s
.30143 1.02415 m
.29238 1.0291 L
s
.29238 1.0291 m
.27832 1.034 L
s
0 1 .52 r
.69857 1.02415 m
.70762 1.0291 L
s
.72168 1.034 m
.70762 1.0291 L
s
0 1 .16 r
.4598 .97061 m
.45329 .9679 L
s
.5402 .97061 m
.54671 .9679 L
s
.45329 .9679 m
.43352 .97698 L
s
.56648 .97698 m
.54671 .9679 L
s
0 1 .52 r
.78993 1.071 m
.80126 1.07756 L
s
.82266 1.07702 m
.80126 1.07756 L
s
.2 1 0 r
.21007 1.071 m
.19874 1.07756 L
s
.19874 1.07756 m
.17734 1.07702 L
s
0 1 .88 r
.7136 1.03203 m
.71444 1.03117 L
s
.7136 1.03203 m
.73809 1.04387 L
s
.56 1 0 r
.2864 1.03203 m
.28556 1.03117 L
s
.26191 1.04387 m
.2864 1.03203 L
s
0 1 .88 r
.81767 1.08581 m
.83013 1.08948 L
s
.80008 1.07239 m
.81767 1.08581 L
s
.56 1 0 r
.18233 1.08581 m
.16987 1.08948 L
s
.18233 1.08581 m
.19992 1.07239 L
s
.2 1 0 r
.32841 1.0115 m
.32225 1.0144 L
s
.32225 1.0144 m
.31051 1.01955 L
s
0 1 .52 r
.67159 1.0115 m
.67775 1.0144 L
s
.68949 1.01955 m
.67775 1.0144 L
s
.61675 .98954 m
.60482 .98379 L
s
.60482 .98379 m
.59989 .98446 L
s
.2 1 0 r
.38325 .98954 m
.39518 .98379 L
s
.40011 .98446 m
.39518 .98379 L
s
0 1 .52 r
.58676 .97932 m
.57368 .97425 L
s
.57368 .97425 m
.57148 .97908 L
s
.2 1 0 r
.41324 .97932 m
.42632 .97425 L
s
.42852 .97908 m
.42632 .97425 L
s
0 1 .16 r
.48263 .96956 m
.47926 .96515 L
s
.47926 .96515 m
.4598 .97061 L
s
.51737 .96956 m
.52074 .96515 L
s
.5402 .97061 m
.52074 .96515 L
s
.42424 .97698 m
.41501 .97748 L
s
.41501 .97748 m
.39487 .98898 L
s
.57576 .97698 m
.58499 .97748 L
s
.60513 .98898 m
.58499 .97748 L
s
0 1 .88 r
.68602 1.01833 m
.68323 1.01667 L
s
.68602 1.01833 m
.71444 1.03117 L
s
.56 1 0 r
.31398 1.01833 m
.31677 1.01667 L
s
.28556 1.03117 m
.31398 1.01833 L
s
0 1 .52 r
.77859 1.06452 m
.78993 1.071 L
s
.80958 1.07108 m
.78993 1.071 L
s
.2 1 0 r
.22141 1.06452 m
.21007 1.071 L
s
.21007 1.071 m
.19042 1.07108 L
s
0 1 .88 r
.7605 1.05568 m
.7682 1.05709 L
s
.73809 1.04387 m
.7605 1.05568 L
s
.56 1 0 r
.2395 1.05568 m
.2318 1.05709 L
s
.2395 1.05568 m
.26191 1.04387 L
s
0 1 .88 r
.64696 1.00049 m
.64073 .99867 L
s
.64696 1.00049 m
.68043 1.01524 L
s
.56 1 0 r
.35304 1.00049 m
.35927 .99867 L
s
.31957 1.01524 m
.35304 1.00049 L
s
0 1 .52 r
.65871 1.00608 m
.66156 1.00693 L
s
.67159 1.0115 m
.66156 1.00693 L
s
.2 1 0 r
.34129 1.00608 m
.33844 1.00693 L
s
.33844 1.00693 m
.32841 1.0115 L
s
.36718 .99594 m
.37715 .99079 L
s
.38325 .98954 m
.37715 .99079 L
s
0 1 .52 r
.63282 .99594 m
.62285 .99079 L
s
.62285 .99079 m
.61675 .98954 L
s
0 1 .88 r
.73809 1.04387 m
.74251 1.0441 L
s
.56 1 0 r
.26191 1.04387 m
.25749 1.0441 L
s
0 1 .88 r
.88175 1.11692 m
.8954 1.12132 L
s
.86783 1.09949 m
.88175 1.11692 L
s
.56 1 0 r
.11825 1.11692 m
.1046 1.12132 L
s
.11825 1.11692 m
.13217 1.09949 L
s
0 1 .52 r
.76723 1.05813 m
.77859 1.06452 L
s
.79651 1.06515 m
.77859 1.06452 L
s
.2 1 0 r
.23277 1.05813 m
.22141 1.06452 L
s
.22141 1.06452 m
.20349 1.06515 L
s
0 1 .16 r
.32616 1.01251 m
.31477 1.01784 L
s
.67384 1.01251 m
.68523 1.01784 L
s
.31477 1.01784 m
.28976 1.0257 L
s
.71024 1.0257 m
.68523 1.01784 L
s
0 1 .88 r
.58155 .97723 m
.57231 .97692 L
s
.58155 .97723 m
.62185 .99525 L
s
.56 1 0 r
.41845 .97723 m
.42769 .97692 L
s
.37815 .99525 m
.41845 .97723 L
s
0 1 .52 r
.68949 1.01955 m
.69857 1.02415 L
s
.71026 1.02844 m
.69857 1.02415 L
s
.2 1 0 r
.31051 1.01955 m
.30143 1.02415 L
s
.30143 1.02415 m
.28974 1.02844 L
s
0 1 .88 r
.78962 1.06987 m
.80008 1.07239 L
s
.7682 1.05709 m
.78962 1.06987 L
s
.56 1 0 r
.21038 1.06987 m
.19992 1.07239 L
s
.21038 1.06987 m
.2318 1.05709 L
s
0 1 .52 r
.75586 1.05187 m
.76723 1.05813 L
s
.78344 1.05924 m
.76723 1.05813 L
s
.2 1 0 r
.24414 1.05187 m
.23277 1.05813 L
s
.23277 1.05813 m
.21656 1.05924 L
s
0 1 .52 r
.59989 .98446 m
.58676 .97932 L
s
.58676 .97932 m
.58499 .98262 L
s
.2 1 0 r
.40011 .98446 m
.41324 .97932 L
s
.41501 .98262 m
.41324 .97932 L
s
0 1 .16 r
.33757 1.00752 m
.32616 1.01251 L
s
.32616 1.01251 m
.30287 1.0208 L
s
.66243 1.00752 m
.67384 1.01251 L
s
.69713 1.0208 m
.67384 1.01251 L
s
0 1 .88 r
.83013 1.08948 m
.84264 1.09298 L
s
.8106 1.07475 m
.83013 1.08948 L
s
.56 1 0 r
.16987 1.08948 m
.15736 1.09298 L
s
.16987 1.08948 m
.1894 1.07475 L
s
0 1 .52 r
.74448 1.04574 m
.75586 1.05187 L
s
.77037 1.05337 m
.75586 1.05187 L
s
.2 1 0 r
.25552 1.04574 m
.24414 1.05187 L
s
.24414 1.05187 m
.22963 1.05337 L
s
0 1 .52 r
.6654 1.00897 m
.67159 1.0115 L
s
.6804 1.01531 m
.67159 1.0115 L
s
.2 1 0 r
.3346 1.00897 m
.32841 1.0115 L
s
.32841 1.0115 m
.3196 1.01531 L
s
0 1 .16 r
.56648 .97698 m
.57576 .97698 L
s
.5936 .98674 m
.57576 .97698 L
s
.43352 .97698 m
.42424 .97698 L
s
.42424 .97698 m
.4064 .98674 L
s
0 1 .88 r
.8954 1.12132 m
.90909 1.12559 L
s
.88051 1.10253 m
.8954 1.12132 L
s
.56 1 0 r
.1046 1.12132 m
.09091 1.12559 L
s
.1046 1.12132 m
.11949 1.10253 L
s
.2 1 0 r
.37125 .99495 m
.38325 .98954 L
s
.38693 .98963 m
.38325 .98954 L
s
0 1 .52 r
.62875 .99495 m
.61675 .98954 L
s
.61675 .98954 m
.61307 .98963 L
s
0 1 .16 r
.349 1.00291 m
.33757 1.00752 L
s
.651 1.00291 m
.66243 1.00752 L
s
.33757 1.00752 m
.31598 1.01609 L
s
.68402 1.01609 m
.66243 1.00752 L
s
0 1 .52 r
.64879 1.00267 m
.64465 1.00015 L
s
.64465 1.00015 m
.63824 .99771 L
s
.65163 1.00304 m
.64465 1.00015 L
s
.2 1 0 r
.35121 1.00267 m
.35535 1.00015 L
s
.35535 1.00015 m
.34837 1.00304 L
s
.36176 .99771 m
.35535 1.00015 L
s
.3196 1.01531 m
.31051 1.01955 L
s
.31051 1.01955 m
.30118 1.02312 L
s
0 1 .52 r
.6804 1.01531 m
.68949 1.01955 L
s
.69882 1.02312 m
.68949 1.01955 L
s
0 1 .16 r
.46636 .97328 m
.4598 .97061 L
s
.53364 .97328 m
.5402 .97061 L
s
.4598 .97061 m
.44284 .97739 L
s
.55716 .97739 m
.5402 .97061 L
s
0 1 .52 r
.73308 1.03978 m
.74448 1.04574 L
s
.7573 1.04753 m
.74448 1.04574 L
s
.2 1 0 r
.26692 1.03978 m
.25552 1.04574 L
s
.25552 1.04574 m
.2427 1.04753 L
s
0 1 .88 r
.71444 1.03117 m
.71529 1.0304 L
s
.71444 1.03117 m
.74251 1.0441 L
s
.56 1 0 r
.28556 1.03117 m
.28471 1.0304 L
s
.25749 1.0441 m
.28556 1.03117 L
s
0 1 .52 r
.65229 1.00401 m
.65163 1.00304 L
s
.65871 1.00608 m
.65163 1.00304 L
s
.2 1 0 r
.34771 1.00401 m
.34837 1.00304 L
s
.34837 1.00304 m
.34129 1.00608 L
s
0 1 .88 r
.64073 .99867 m
.63447 .99722 L
s
.64073 .99867 m
.67761 1.014 L
s
.56 1 0 r
.35927 .99867 m
.36553 .99722 L
s
.32239 1.014 m
.35927 .99867 L
s
0 1 .88 r
.68323 1.01667 m
.68043 1.01524 L
s
.68323 1.01667 m
.71529 1.0304 L
s
.56 1 0 r
.31677 1.01667 m
.31957 1.01524 L
s
.28471 1.0304 m
.31677 1.01667 L
s
.2 1 0 r
.35443 1.00151 m
.36176 .99771 L
s
.36718 .99594 m
.36176 .99771 L
s
0 1 .52 r
.64557 1.00151 m
.63824 .99771 L
s
.63824 .99771 m
.63282 .99594 L
s
0 1 .16 r
.5 .97255 m
.5 .96814 L
s
.5 .96814 m
.48263 .96956 L
s
.51737 .96956 m
.5 .96814 L
s
.56 1 0 r
.42769 .97692 m
.43699 .97709 L
s
.38451 .99463 m
.42769 .97692 L
s
0 1 .88 r
.57231 .97692 m
.56301 .97709 L
s
.57231 .97692 m
.61549 .99463 L
s
0 1 .52 r
.61307 .98963 m
.59989 .98446 L
s
.59989 .98446 m
.59852 .98656 L
s
.2 1 0 r
.38693 .98963 m
.40011 .98446 L
s
.40148 .98656 m
.40011 .98446 L
s
0 1 .88 r
.7682 1.05709 m
.77594 1.05837 L
s
.74251 1.0441 m
.7682 1.05709 L
s
.56 1 0 r
.2318 1.05709 m
.22406 1.05837 L
s
.2318 1.05709 m
.25749 1.0441 L
s
0 1 .16 r
.36044 .99872 m
.349 1.00291 L
s
.63956 .99872 m
.651 1.00291 L
s
.349 1.00291 m
.32909 1.01159 L
s
.67091 1.01159 m
.651 1.00291 L
s
.2 1 0 r
.34416 1.00542 m
.34129 1.00608 L
s
.34129 1.00608 m
.3346 1.00897 L
s
0 1 .52 r
.65584 1.00542 m
.65871 1.00608 L
s
.6654 1.00897 m
.65871 1.00608 L
s
.72168 1.034 m
.73308 1.03978 L
s
.74424 1.04176 m
.73308 1.03978 L
s
.2 1 0 r
.27832 1.034 m
.26692 1.03978 L
s
.26692 1.03978 m
.25576 1.04176 L
s
0 1 .52 r
.64285 1.00062 m
.63282 .99594 L
s
.63282 .99594 m
.62875 .99495 L
s
.2 1 0 r
.35715 1.00062 m
.36718 .99594 L
s
.37125 .99495 m
.36718 .99594 L
s
0 1 .88 r
.90909 1.12559 m
.92282 1.12974 L
s
.89324 1.10542 m
.90909 1.12559 L
s
.56 1 0 r
.09091 1.12559 m
.07718 1.12974 L
s
.09091 1.12559 m
.10676 1.10542 L
s
0 1 .88 r
.80008 1.07239 m
.8106 1.07475 L
s
.77594 1.05837 m
.80008 1.07239 L
s
.56 1 0 r
.19992 1.07239 m
.1894 1.07475 L
s
.19992 1.07239 m
.22406 1.05837 L
s
0 1 .16 r
.48604 .97345 m
.48263 .96956 L
s
.51396 .97345 m
.51737 .96956 L
s
.48263 .96956 m
.46636 .97328 L
s
.53364 .97328 m
.51737 .96956 L
s
0 1 .88 r
.74251 1.0441 m
.74697 1.04428 L
s
.56 1 0 r
.25749 1.0441 m
.25303 1.04428 L
s
.15736 1.09298 m
.14479 1.09631 L
s
.15736 1.09298 m
.17882 1.07694 L
s
0 1 .88 r
.84264 1.09298 m
.85521 1.09631 L
s
.82118 1.07694 m
.84264 1.09298 L
s
.2 1 0 r
.28974 1.02844 m
.27832 1.034 L
s
.27832 1.034 m
.26881 1.03607 L
s
0 1 .52 r
.71026 1.02844 m
.72168 1.034 L
s
.73119 1.03607 m
.72168 1.034 L
s
.2 1 0 r
.49579 .96963 m
.50922 .96977 L
s
.48236 .97022 m
.49579 .96963 L
s
.49063 .98018 m
.49579 .96963 L
s
0 1 .52 r
.50421 .96963 m
.49078 .96977 L
s
.51764 .97022 m
.50421 .96963 L
s
.50421 .96963 m
.50937 .98018 L
s
.2 1 0 r
.32873 1.01146 m
.3196 1.01531 L
s
.3196 1.01531 m
.31262 1.01808 L
s
0 1 .52 r
.67127 1.01146 m
.6804 1.01531 L
s
.68738 1.01808 m
.6804 1.01531 L
s
.49078 .96977 m
.47735 .97062 L
s
.49078 .96977 m
.49622 .98082 L
s
.2 1 0 r
.50922 .96977 m
.52265 .97062 L
s
.50378 .98082 m
.50922 .96977 L
s
0 1 .52 r
.53108 .9715 m
.51764 .97022 L
s
.51764 .97022 m
.5225 .98 L
s
.2 1 0 r
.46892 .9715 m
.48236 .97022 L
s
.4775 .98 m
.48236 .97022 L
s
0 1 .16 r
.3719 .99499 m
.36044 .99872 L
s
.6281 .99499 m
.63956 .99872 L
s
.36044 .99872 m
.34219 1.00734 L
s
.65781 1.00734 m
.63956 .99872 L
s
0 1 .52 r
.47735 .97062 m
.46391 .97215 L
s
.47735 .97062 m
.48303 .98187 L
s
.2 1 0 r
.52265 .97062 m
.53609 .97215 L
s
.51697 .98187 m
.52265 .97062 L
s
0 1 .16 r
.44284 .97739 m
.43352 .97698 L
s
.55716 .97739 m
.56648 .97698 L
s
.43352 .97698 m
.41796 .985 L
s
.58204 .985 m
.56648 .97698 L
s
.2 1 0 r
.45547 .97345 m
.46892 .9715 L
s
.4644 .9803 m
.46892 .9715 L
s
0 1 .52 r
.54453 .97345 m
.53108 .9715 L
s
.53108 .9715 m
.5356 .9803 L
s
.2 1 0 r
.34081 1.00678 m
.3346 1.00897 L
s
.3346 1.00897 m
.32873 1.01146 L
s
0 1 .52 r
.65919 1.00678 m
.6654 1.00897 L
s
.67127 1.01146 m
.6654 1.00897 L
s
.46391 .97215 m
.45046 .97433 L
s
.46391 .97215 m
.4698 .98331 L
s
.2 1 0 r
.53609 .97215 m
.54954 .97433 L
s
.5302 .98331 m
.53609 .97215 L
s
0 1 .52 r
.62631 .99478 m
.61307 .98963 L
s
.61307 .98963 m
.61209 .99081 L
s
.2 1 0 r
.37369 .99478 m
.38693 .98963 L
s
.38791 .99081 m
.38693 .98963 L
s
.35918 1.00007 m
.37125 .99495 L
s
.37369 .99478 m
.37125 .99495 L
s
0 1 .52 r
.64082 1.00007 m
.62875 .99495 L
s
.62875 .99495 m
.62631 .99478 L
s
.55799 .976 m
.54453 .97345 L
s
.54453 .97345 m
.54868 .98112 L
s
.2 1 0 r
.44201 .976 m
.45547 .97345 L
s
.45132 .98112 m
.45547 .97345 L
s
0 1 .52 r
.45046 .97433 m
.43699 .97709 L
s
.45046 .97433 m
.45654 .98507 L
s
.2 1 0 r
.54954 .97433 m
.56301 .97709 L
s
.54346 .98507 m
.54954 .97433 L
s
0 1 .52 r
.69882 1.02312 m
.71026 1.02844 L
s
.71813 1.03047 m
.71026 1.02844 L
s
.2 1 0 r
.30118 1.02312 m
.28974 1.02844 L
s
.28974 1.02844 m
.28187 1.03047 L
s
0 1 .88 r
.90603 1.10818 m
.92282 1.12974 L
s
.56 1 0 r
.07718 1.12974 m
.09397 1.10818 L
s
0 1 .52 r
.57148 .97908 m
.55799 .976 L
s
.55799 .976 m
.56174 .98245 L
s
.2 1 0 r
.42852 .97908 m
.44201 .976 L
s
.43826 .98245 m
.44201 .976 L
s
0 1 .88 r
.56301 .97709 m
.60908 .99419 L
s
.56 1 0 r
.39092 .99419 m
.43699 .97709 L
s
.2 1 0 r
.55677 .98713 m
.56301 .97709 L
s
0 1 .52 r
.43699 .97709 m
.44323 .98713 L
s
0 1 .88 r
.63447 .99722 m
.62818 .9961 L
s
.63447 .99722 m
.67478 1.01291 L
s
.56 1 0 r
.36553 .99722 m
.37182 .9961 L
s
.32522 1.01291 m
.36553 .99722 L
s
0 1 .16 r
.61663 .99174 m
.6281 .99499 L
s
.6447 1.00336 m
.6281 .99499 L
s
.38337 .99174 m
.3719 .99499 L
s
.3719 .99499 m
.3553 1.00336 L
s
0 1 .52 r
.58499 .98262 m
.57148 .97908 L
s
.57148 .97908 m
.57479 .98429 L
s
.2 1 0 r
.41501 .98262 m
.42852 .97908 L
s
.42521 .98429 m
.42852 .97908 L
s
0 1 .88 r
.68043 1.01524 m
.67761 1.014 L
s
.68043 1.01524 m
.71615 1.02969 L
s
.56 1 0 r
.31957 1.01524 m
.32239 1.014 L
s
.28385 1.02969 m
.31957 1.01524 L
s
0 1 .52 r
.68738 1.01808 m
.69882 1.02312 L
s
.70509 1.025 m
.69882 1.02312 L
s
.2 1 0 r
.31262 1.01808 m
.30118 1.02312 L
s
.30118 1.02312 m
.29491 1.025 L
s
0 1 .88 r
.71529 1.0304 m
.71615 1.02969 L
s
.71529 1.0304 m
.74697 1.04428 L
s
.56 1 0 r
.28471 1.0304 m
.28385 1.02969 L
s
.25303 1.04428 m
.28471 1.0304 L
s
0 1 .16 r
.47298 .97587 m
.46636 .97328 L
s
.46636 .97328 m
.45222 .97815 L
s
.52702 .97587 m
.53364 .97328 L
s
.54778 .97815 m
.53364 .97328 L
s
0 1 .52 r
.66213 1.00799 m
.67127 1.01146 L
s
.67592 1.01335 m
.67127 1.01146 L
s
.2 1 0 r
.33787 1.00799 m
.32873 1.01146 L
s
.32873 1.01146 m
.32408 1.01335 L
s
0 1 .88 r
.85521 1.09631 m
.86783 1.09949 L
s
.83182 1.07897 m
.85521 1.09631 L
s
.56 1 0 r
.14479 1.09631 m
.13217 1.09949 L
s
.14479 1.09631 m
.16818 1.07897 L
s
0 1 .52 r
.65295 1.00491 m
.64879 1.00267 L
s
.64879 1.00267 m
.64557 1.00151 L
s
.65229 1.00401 m
.64879 1.00267 L
s
.2 1 0 r
.34705 1.00491 m
.35121 1.00267 L
s
.35121 1.00267 m
.34771 1.00401 L
s
.35443 1.00151 m
.35121 1.00267 L
s
0 1 .52 r
.65295 1.00491 m
.65229 1.00401 L
s
.65584 1.00542 m
.65229 1.00401 L
s
.2 1 0 r
.34705 1.00491 m
.34771 1.00401 L
s
.34771 1.00401 m
.34416 1.00542 L
s
0 1 .88 r
.77594 1.05837 m
.78374 1.05952 L
s
.74697 1.04428 m
.77594 1.05837 L
s
.56 1 0 r
.22406 1.05837 m
.21626 1.05952 L
s
.22406 1.05837 m
.25303 1.04428 L
s
0 1 .52 r
.59852 .98656 m
.58499 .98262 L
s
.58499 .98262 m
.58782 .98664 L
s
.2 1 0 r
.40148 .98656 m
.41501 .98262 L
s
.41218 .98664 m
.41501 .98262 L
s
0 1 .52 r
.65295 1.00491 m
.64557 1.00151 L
s
.64557 1.00151 m
.64285 1.00062 L
s
.2 1 0 r
.34705 1.00491 m
.35443 1.00151 L
s
.35715 1.00062 m
.35443 1.00151 L
s
0 1 .88 r
.8106 1.07475 m
.82118 1.07694 L
s
.78374 1.05952 m
.8106 1.07475 L
s
.56 1 0 r
.1894 1.07475 m
.17882 1.07694 L
s
.1894 1.07475 m
.21626 1.05952 L
s
0 1 .52 r
.6396 .99988 m
.62631 .99478 L
s
.62631 .99478 m
.62568 .99532 L
s
.2 1 0 r
.3604 .99988 m
.37369 .99478 L
s
.37432 .99532 m
.37369 .99478 L
s
0 1 .52 r
.65295 1.00491 m
.65584 1.00542 L
s
.65919 1.00678 m
.65584 1.00542 L
s
.2 1 0 r
.34705 1.00491 m
.34416 1.00542 L
s
.34416 1.00542 m
.34081 1.00678 L
s
0 1 .16 r
.39487 .98898 m
.38337 .99174 L
s
.60513 .98898 m
.61663 .99174 L
s
.38337 .99174 m
.3684 .99969 L
s
.6316 .99969 m
.61663 .99174 L
s
.2 1 0 r
.34705 1.00491 m
.35715 1.00062 L
s
.35918 1.00007 m
.35715 1.00062 L
s
0 1 .52 r
.65295 1.00491 m
.64285 1.00062 L
s
.64285 1.00062 m
.64082 1.00007 L
s
.2 1 0 r
.32408 1.01335 m
.31262 1.01808 L
s
.31262 1.01808 m
.30795 1.01967 L
s
0 1 .52 r
.67592 1.01335 m
.68738 1.01808 L
s
.69205 1.01967 m
.68738 1.01808 L
s
.61209 .99081 m
.59852 .98656 L
s
.59852 .98656 m
.60085 .98947 L
s
.2 1 0 r
.38791 .99081 m
.40148 .98656 L
s
.39915 .98947 m
.40148 .98656 L
s
0 1 .16 r
.45222 .97815 m
.44284 .97739 L
s
.54778 .97815 m
.55716 .97739 L
s
.44284 .97739 m
.42955 .98375 L
s
.57045 .98375 m
.55716 .97739 L
s
.5 .97634 m
.5 .97255 L
s
.5 .97255 m
.48604 .97345 L
s
.51396 .97345 m
.5 .97255 L
s
0 1 .88 r
.74697 1.04428 m
.75147 1.04441 L
s
.56 1 0 r
.25303 1.04428 m
.24853 1.04441 L
s
0 1 .52 r
.65295 1.00491 m
.65919 1.00678 L
s
.66213 1.00799 m
.65919 1.00678 L
s
.2 1 0 r
.34705 1.00491 m
.34081 1.00678 L
s
.34081 1.00678 m
.33787 1.00799 L
s
0 1 .52 r
.65295 1.00491 m
.64082 1.00007 L
s
.64082 1.00007 m
.6396 .99988 L
s
.2 1 0 r
.34705 1.00491 m
.35918 1.00007 L
s
.3604 .99988 m
.35918 1.00007 L
s
0 1 .52 r
.62568 .99532 m
.61209 .99081 L
s
.61209 .99081 m
.61387 .99275 L
s
.2 1 0 r
.37432 .99532 m
.38791 .99081 L
s
.38613 .99275 m
.38791 .99081 L
s
0 1 .16 r
.51052 .97687 m
.51396 .97345 L
s
.52702 .97587 m
.51396 .97345 L
s
.48948 .97687 m
.48604 .97345 L
s
.48604 .97345 m
.47298 .97587 L
s
.2 1 0 r
.33556 1.00894 m
.32408 1.01335 L
s
.32408 1.01335 m
.32099 1.01453 L
s
0 1 .52 r
.66444 1.00894 m
.67592 1.01335 L
s
.67901 1.01453 m
.67592 1.01335 L
s
.65295 1.00491 m
.66213 1.00799 L
s
.66444 1.00894 m
.66213 1.00799 L
s
.2 1 0 r
.34705 1.00491 m
.33787 1.00799 L
s
.33787 1.00799 m
.33556 1.00894 L
s
0 1 .16 r
.5936 .98674 m
.60513 .98898 L
s
.61849 .99636 m
.60513 .98898 L
s
.4064 .98674 m
.39487 .98898 L
s
.39487 .98898 m
.38151 .99636 L
s
.2 1 0 r
.34705 1.00491 m
.3604 .99988 L
s
.3607 1.00004 m
.3604 .99988 L
s
0 1 .52 r
.65295 1.00491 m
.6396 .99988 L
s
.6396 .99988 m
.6393 1.00004 L
s
0 1 .88 r
.62818 .9961 m
.62185 .99525 L
s
.62818 .9961 m
.67193 1.01193 L
s
.56 1 0 r
.37182 .9961 m
.37815 .99525 L
s
.32807 1.01193 m
.37182 .9961 L
s
0 1 .52 r
.6393 1.00004 m
.62568 .99532 L
s
.62568 .99532 m
.6269 .99645 L
s
.2 1 0 r
.3607 1.00004 m
.37432 .99532 L
s
.3731 .99645 m
.37432 .99532 L
s
0 1 .88 r
.86783 1.09949 m
.88051 1.10253 L
s
.84251 1.08085 m
.86783 1.09949 L
s
.56 1 0 r
.13217 1.09949 m
.11949 1.10253 L
s
.13217 1.09949 m
.15749 1.08085 L
s
0 1 .52 r
.65295 1.00491 m
.66444 1.00894 L
s
.66598 1.00959 m
.66444 1.00894 L
s
.2 1 0 r
.34705 1.00491 m
.33556 1.00894 L
s
.33556 1.00894 m
.33402 1.00959 L
s
0 1 .88 r
.67761 1.014 m
.67478 1.01291 L
s
.67761 1.014 m
.71702 1.02901 L
s
.56 1 0 r
.32239 1.014 m
.32522 1.01291 L
s
.28298 1.02901 m
.32239 1.014 L
s
.2 1 0 r
.34705 1.00491 m
.3607 1.00004 L
s
.36008 1.00051 m
.3607 1.00004 L
s
0 1 .52 r
.65295 1.00491 m
.6393 1.00004 L
s
.6393 1.00004 m
.63992 1.00051 L
s
0 1 .88 r
.82118 1.07694 m
.83182 1.07897 L
s
.79159 1.06054 m
.82118 1.07694 L
s
.56 1 0 r
.17882 1.07694 m
.16818 1.07897 L
s
.17882 1.07694 m
.20841 1.06054 L
s
0 1 .88 r
.71615 1.02969 m
.71702 1.02901 L
s
.71615 1.02969 m
.75147 1.04441 L
s
.56 1 0 r
.28385 1.02969 m
.28298 1.02901 L
s
.24853 1.04441 m
.28385 1.02969 L
s
0 1 .16 r
.41796 .985 m
.4064 .98674 L
s
.58204 .985 m
.5936 .98674 L
s
.4064 .98674 m
.39462 .99339 L
s
.60538 .99339 m
.5936 .98674 L
s
0 1 .88 r
.78374 1.05952 m
.79159 1.06054 L
s
.75147 1.04441 m
.78374 1.05952 L
s
.56 1 0 r
.21626 1.05952 m
.20841 1.06054 L
s
.21626 1.05952 m
.24853 1.04441 L
s
0 1 .16 r
.47965 .97833 m
.47298 .97587 L
s
.52035 .97833 m
.52702 .97587 L
s
.47298 .97587 m
.46166 .97917 L
s
.53834 .97917 m
.52702 .97587 L
s
.2 1 0 r
.26881 1.03607 m
.25576 1.04176 L
s
.28187 1.03047 m
.26881 1.03607 L
s
.26881 1.03607 m
.26456 1.0356 L
s
0 1 .52 r
.73119 1.03607 m
.74424 1.04176 L
s
.71813 1.03047 m
.73119 1.03607 L
s
.73544 1.0356 m
.73119 1.03607 L
s
.70509 1.025 m
.71813 1.03047 L
s
.72162 1.03042 m
.71813 1.03047 L
s
.2 1 0 r
.29491 1.025 m
.28187 1.03047 L
s
.28187 1.03047 m
.27838 1.03042 L
s
.25576 1.04176 m
.2427 1.04753 L
s
.25576 1.04176 m
.25072 1.04076 L
s
0 1 .52 r
.74424 1.04176 m
.7573 1.04753 L
s
.74928 1.04076 m
.74424 1.04176 L
s
.69205 1.01967 m
.70509 1.025 L
s
.70783 1.02525 m
.70509 1.025 L
s
.2 1 0 r
.30795 1.01967 m
.29491 1.025 L
s
.29491 1.025 m
.29217 1.02525 L
s
.2427 1.04753 m
.22963 1.05337 L
s
.2427 1.04753 m
.23685 1.0459 L
s
0 1 .52 r
.7573 1.04753 m
.77037 1.05337 L
s
.76315 1.0459 m
.7573 1.04753 L
s
.67901 1.01453 m
.69205 1.01967 L
s
.69407 1.02009 m
.69205 1.01967 L
s
.2 1 0 r
.32099 1.01453 m
.30795 1.01967 L
s
.30795 1.01967 m
.30593 1.02009 L
s
.22963 1.05337 m
.21656 1.05924 L
s
.22963 1.05337 m
.22295 1.05101 L
s
0 1 .52 r
.77037 1.05337 m
.78344 1.05924 L
s
.77705 1.05101 m
.77037 1.05337 L
s
0 1 .16 r
.46166 .97917 m
.45222 .97815 L
s
.53834 .97917 m
.54778 .97815 L
s
.45222 .97815 m
.44117 .98296 L
s
.55883 .98296 m
.54778 .97815 L
s
.2 1 0 r
.21656 1.05924 m
.20349 1.06515 L
s
.21656 1.05924 m
.20904 1.05609 L
s
0 1 .52 r
.78344 1.05924 m
.79651 1.06515 L
s
.79096 1.05609 m
.78344 1.05924 L
s
.66598 1.00959 m
.67901 1.01453 L
s
.68033 1.01497 m
.67901 1.01453 L
s
.2 1 0 r
.33402 1.00959 m
.32099 1.01453 L
s
.32099 1.01453 m
.31967 1.01497 L
s
.20349 1.06515 m
.19042 1.07108 L
s
.20349 1.06515 m
.19509 1.06113 L
s
0 1 .52 r
.79651 1.06515 m
.80958 1.07108 L
s
.80491 1.06113 m
.79651 1.06515 L
s
.80958 1.07108 m
.82266 1.07702 L
s
.81887 1.06612 m
.80958 1.07108 L
s
.2 1 0 r
.19042 1.07108 m
.17734 1.07702 L
s
.19042 1.07108 m
.18113 1.06612 L
s
0 1 .52 r
.65295 1.00491 m
.66598 1.00959 L
s
.66662 1.00989 m
.66598 1.00959 L
s
.2 1 0 r
.34705 1.00491 m
.33402 1.00959 L
s
.33402 1.00959 m
.33338 1.00989 L
s
.17734 1.07702 m
.16426 1.08296 L
s
.17734 1.07702 m
.16714 1.07107 L
s
0 1 .52 r
.82266 1.07702 m
.83574 1.08296 L
s
.83286 1.07107 m
.82266 1.07702 L
s
.2 1 0 r
.16426 1.08296 m
.15118 1.0889 L
s
.16426 1.08296 m
.15312 1.07598 L
s
0 1 .52 r
.83574 1.08296 m
.84882 1.0889 L
s
.84688 1.07598 m
.83574 1.08296 L
s
.2 1 0 r
.15118 1.0889 m
.1381 1.09483 L
s
.15118 1.0889 m
.13909 1.08083 L
s
0 1 .52 r
.84882 1.0889 m
.8619 1.09483 L
s
.86091 1.08083 m
.84882 1.0889 L
s
.65295 1.00491 m
.66662 1.00989 L
s
.65295 1.00491 m
.65361 1.00571 L
s
.65295 1.00491 m
.65295 1.00491 L
s
.2 1 0 r
.34705 1.00491 m
.34639 1.00571 L
s
.34705 1.00491 m
.33338 1.00989 L
s
.34705 1.00491 m
.34705 1.00491 L
s
0 1 .52 r
.65295 1.00491 m
.66634 1.00985 L
s
.65295 1.00491 m
.66514 1.00948 L
s
.65295 1.00491 m
.66311 1.00882 L
s
.65295 1.00491 m
.66038 1.00793 L
s
.65295 1.00491 m
.65713 1.00687 L
s
.65295 1.00491 m
.65004 1.0045 L
s
.65295 1.00491 m
.64667 1.00331 L
s
.65295 1.00491 m
.64374 1.00221 L
s
.65295 1.00491 m
.64143 1.00125 L
s
.65295 1.00491 m
.63992 1.00051 L
s
.2 1 0 r
.34705 1.00491 m
.36008 1.00051 L
s
.34705 1.00491 m
.35857 1.00125 L
s
.34705 1.00491 m
.35626 1.00221 L
s
.34705 1.00491 m
.35333 1.00331 L
s
.34705 1.00491 m
.34996 1.0045 L
s
.34705 1.00491 m
.34287 1.00687 L
s
.34705 1.00491 m
.33962 1.00793 L
s
.34705 1.00491 m
.33689 1.00882 L
s
.34705 1.00491 m
.33486 1.00948 L
s
.34705 1.00491 m
.33366 1.00985 L
s
.1381 1.09483 m
.12503 1.08563 L
s
0 1 .52 r
.87497 1.08563 m
.8619 1.09483 L
s
.63992 1.00051 m
.6269 .99645 L
s
.63992 1.00051 m
.64143 1.00125 L
s
.2 1 0 r
.36008 1.00051 m
.3731 .99645 L
s
.35857 1.00125 m
.36008 1.00051 L
s
0 1 .52 r
.6269 .99645 m
.61387 .99275 L
s
.6269 .99645 m
.6299 .99801 L
s
.2 1 0 r
.3731 .99645 m
.38613 .99275 L
s
.3701 .99801 m
.3731 .99645 L
s
0 1 .88 r
.75147 1.04441 m
.75599 1.04446 L
s
.56 1 0 r
.24853 1.04441 m
.24401 1.04446 L
s
0 1 .88 r
.88051 1.10253 m
.89324 1.10542 L
s
.85327 1.08259 m
.88051 1.10253 L
s
.56 1 0 r
.11949 1.10253 m
.10676 1.10542 L
s
.11949 1.10253 m
.14673 1.08259 L
s
0 1 .52 r
.61387 .99275 m
.60085 .98947 L
s
.61387 .99275 m
.61834 .99518 L
s
.2 1 0 r
.38613 .99275 m
.39915 .98947 L
s
.38166 .99518 m
.38613 .99275 L
s
.33338 1.00989 m
.31967 1.01497 L
s
.33338 1.00989 m
.33366 1.00985 L
s
0 1 .52 r
.66662 1.00989 m
.68033 1.01497 L
s
.66634 1.00985 m
.66662 1.00989 L
s
0 1 .16 r
.42955 .98375 m
.41796 .985 L
s
.57045 .98375 m
.58204 .985 L
s
.41796 .985 m
.40774 .99082 L
s
.59226 .99082 m
.58204 .985 L
s
0 1 .52 r
.60085 .98947 m
.58782 .98664 L
s
.60085 .98947 m
.60676 .99278 L
s
.2 1 0 r
.39915 .98947 m
.41218 .98664 L
s
.39324 .99278 m
.39915 .98947 L
s
.35857 1.00125 m
.3701 .99801 L
s
.35626 1.00221 m
.35857 1.00125 L
s
0 1 .52 r
.64143 1.00125 m
.6299 .99801 L
s
.64143 1.00125 m
.64374 1.00221 L
s
0 1 .88 r
.62185 .99525 m
.61549 .99463 L
s
.62185 .99525 m
.66906 1.01104 L
s
.56 1 0 r
.37815 .99525 m
.38451 .99463 L
s
.33094 1.01104 m
.37815 .99525 L
s
0 1 .16 r
.5 .97959 m
.5 .97634 L
s
.5 .97634 m
.48948 .97687 L
s
.51052 .97687 m
.5 .97634 L
s
0 1 .52 r
.58782 .98664 m
.57479 .98429 L
s
.58782 .98664 m
.59514 .9908 L
s
.2 1 0 r
.41218 .98664 m
.42521 .98429 L
s
.40486 .9908 m
.41218 .98664 L
s
0 1 .52 r
.68033 1.01497 m
.69407 1.02009 L
s
.67979 1.0147 m
.68033 1.01497 L
s
.2 1 0 r
.31967 1.01497 m
.30593 1.02009 L
s
.31967 1.01497 m
.32021 1.0147 L
s
.33366 1.00985 m
.32021 1.0147 L
s
.33366 1.00985 m
.33486 1.00948 L
s
0 1 .52 r
.66634 1.00985 m
.67979 1.0147 L
s
.66514 1.00948 m
.66634 1.00985 L
s
0 1 .16 r
.50704 .97986 m
.51052 .97687 L
s
.52035 .97833 m
.51052 .97687 L
s
.49296 .97986 m
.48948 .97687 L
s
.48948 .97687 m
.47965 .97833 L
s
0 1 .52 r
.64374 1.00221 m
.63449 .99988 L
s
.64374 1.00221 m
.64667 1.00331 L
s
.2 1 0 r
.35626 1.00221 m
.36551 .99988 L
s
.35333 1.00331 m
.35626 1.00221 L
s
0 1 .88 r
.83182 1.07897 m
.84251 1.08085 L
s
.79949 1.06143 m
.83182 1.07897 L
s
.56 1 0 r
.16818 1.07897 m
.15749 1.08085 L
s
.16818 1.07897 m
.20051 1.06143 L
s
0 1 .52 r
.57479 .98429 m
.56174 .98245 L
s
.57479 .98429 m
.58349 .98924 L
s
.2 1 0 r
.42521 .98429 m
.43826 .98245 L
s
.41651 .98924 m
.42521 .98429 L
s
0 1 .88 r
.67478 1.01291 m
.67193 1.01193 L
s
.67478 1.01291 m
.71789 1.02834 L
s
.56 1 0 r
.32522 1.01291 m
.32807 1.01193 L
s
.28211 1.02834 m
.32522 1.01291 L
s
0 1 .16 r
.47115 .98038 m
.46166 .97917 L
s
.46166 .97917 m
.45284 .98261 L
s
.52885 .98038 m
.53834 .97917 L
s
.54716 .98261 m
.53834 .97917 L
s
0 1 .52 r
.6299 .99801 m
.61834 .99518 L
s
.6299 .99801 m
.63449 .99988 L
s
.2 1 0 r
.3701 .99801 m
.38166 .99518 L
s
.36551 .99988 m
.3701 .99801 L
s
.30593 1.02009 m
.29217 1.02525 L
s
.30593 1.02009 m
.30672 1.01944 L
s
0 1 .52 r
.69407 1.02009 m
.70783 1.02525 L
s
.69328 1.01944 m
.69407 1.02009 L
s
.66514 1.00948 m
.6774 1.01381 L
s
.66311 1.00882 m
.66514 1.00948 L
s
.2 1 0 r
.33486 1.00948 m
.3226 1.01381 L
s
.33486 1.00948 m
.33689 1.00882 L
s
0 1 .16 r
.44117 .98296 m
.42955 .98375 L
s
.42955 .98375 m
.42087 .98866 L
s
.55883 .98296 m
.57045 .98375 L
s
.57913 .98866 m
.57045 .98375 L
s
0 1 .88 r
.79159 1.06054 m
.79949 1.06143 L
s
.75599 1.04446 m
.79159 1.06054 L
s
.56 1 0 r
.20841 1.06054 m
.20051 1.06143 L
s
.20841 1.06054 m
.24401 1.04446 L
s
0 1 .52 r
.56174 .98245 m
.54868 .98112 L
s
.56174 .98245 m
.57181 .98808 L
s
.2 1 0 r
.43826 .98245 m
.45132 .98112 L
s
.42819 .98808 m
.43826 .98245 L
s
0 1 .52 r
.64667 1.00331 m
.64036 1.00196 L
s
.64667 1.00331 m
.65004 1.0045 L
s
.2 1 0 r
.35333 1.00331 m
.35964 1.00196 L
s
.34996 1.0045 m
.35333 1.00331 L
s
0 1 .88 r
.71702 1.02901 m
.71789 1.02834 L
s
.71702 1.02901 m
.75599 1.04446 L
s
.56 1 0 r
.28298 1.02901 m
.28211 1.02834 L
s
.24401 1.04446 m
.28298 1.02901 L
s
0 1 .88 r
.89324 1.10542 m
.90603 1.10818 L
s
.86409 1.08418 m
.89324 1.10542 L
s
.56 1 0 r
.10676 1.10542 m
.09397 1.10818 L
s
.10676 1.10542 m
.13591 1.08418 L
s
0 1 .16 r
.48638 .98062 m
.47965 .97833 L
s
.51362 .98062 m
.52035 .97833 L
s
.47965 .97833 m
.47115 .98038 L
s
.52885 .98038 m
.52035 .97833 L
s
0 1 .52 r
.66311 1.00882 m
.67333 1.0124 L
s
.66038 1.00793 m
.66311 1.00882 L
s
.2 1 0 r
.33689 1.00882 m
.32667 1.0124 L
s
.33689 1.00882 m
.33962 1.00793 L
s
0 1 .52 r
.70783 1.02525 m
.72162 1.03042 L
s
.70682 1.02408 m
.70783 1.02525 L
s
.2 1 0 r
.29217 1.02525 m
.27838 1.03042 L
s
.29217 1.02525 m
.29318 1.02408 L
s
.34996 1.0045 m
.35289 1.00415 L
s
.34639 1.00571 m
.34996 1.0045 L
s
0 1 .52 r
.65004 1.0045 m
.64711 1.00415 L
s
.65004 1.0045 m
.65361 1.00571 L
s
.2 1 0 r
.32021 1.0147 m
.30672 1.01944 L
s
.32021 1.0147 m
.3226 1.01381 L
s
0 1 .52 r
.67979 1.0147 m
.69328 1.01944 L
s
.6774 1.01381 m
.67979 1.0147 L
s
.54868 .98112 m
.5356 .9803 L
s
.54868 .98112 m
.56008 .98729 L
s
.2 1 0 r
.45132 .98112 m
.4644 .9803 L
s
.43992 .98729 m
.45132 .98112 L
s
0 1 .52 r
.66038 1.00793 m
.66786 1.01062 L
s
.65713 1.00687 m
.66038 1.00793 L
s
.2 1 0 r
.33962 1.00793 m
.33214 1.01062 L
s
.33962 1.00793 m
.34287 1.00687 L
s
.34639 1.00571 m
.34573 1.00639 L
s
.34287 1.00687 m
.34639 1.00571 L
s
0 1 .52 r
.65361 1.00571 m
.65427 1.00639 L
s
.65361 1.00571 m
.65713 1.00687 L
s
.2 1 0 r
.38166 .99518 m
.39324 .99278 L
s
.37479 .99791 m
.38166 .99518 L
s
0 1 .52 r
.61834 .99518 m
.60676 .99278 L
s
.61834 .99518 m
.62521 .99791 L
s
.65713 1.00687 m
.66135 1.00857 L
s
.2 1 0 r
.34287 1.00687 m
.33865 1.00857 L
s
0 1 .88 r
.75599 1.04446 m
.76055 1.04444 L
s
.56 1 0 r
.24401 1.04446 m
.23945 1.04444 L
s
0 1 .52 r
.72162 1.03042 m
.73544 1.0356 L
s
.72042 1.02862 m
.72162 1.03042 L
s
.2 1 0 r
.27838 1.03042 m
.26456 1.0356 L
s
.27838 1.03042 m
.27958 1.02862 L
s
0 1 .16 r
.45284 .98261 m
.44117 .98296 L
s
.44117 .98296 m
.43401 .98693 L
s
.54716 .98261 m
.55883 .98296 L
s
.56599 .98693 m
.55883 .98296 L
s
0 1 .52 r
.63449 .99988 m
.62521 .99791 L
s
.63449 .99988 m
.64036 1.00196 L
s
.2 1 0 r
.36551 .99988 m
.37479 .99791 L
s
.35964 1.00196 m
.36551 .99988 L
s
0 1 .52 r
.5356 .9803 m
.5225 .98 L
s
.5356 .9803 m
.54832 .98684 L
s
.2 1 0 r
.4644 .9803 m
.4775 .98 L
s
.45168 .98684 m
.4644 .9803 L
s
0 1 .88 r
.61549 .99463 m
.60908 .99419 L
s
.61549 .99463 m
.66617 1.0102 L
s
.56 1 0 r
.38451 .99463 m
.39092 .99419 L
s
.33383 1.0102 m
.38451 .99463 L
s
0 1 .88 r
.84251 1.08085 m
.85327 1.08259 L
s
.80744 1.06218 m
.84251 1.08085 L
s
.56 1 0 r
.15749 1.08085 m
.14673 1.08259 L
s
.15749 1.08085 m
.19256 1.06218 L
s
.2 1 0 r
.3226 1.01381 m
.31028 1.0179 L
s
.3226 1.01381 m
.32667 1.0124 L
s
0 1 .52 r
.6774 1.01381 m
.68972 1.0179 L
s
.67333 1.0124 m
.6774 1.01381 L
s
.2 1 0 r
.26456 1.0356 m
.25072 1.04076 L
s
.26456 1.0356 m
.26595 1.03305 L
s
0 1 .52 r
.73544 1.0356 m
.74928 1.04076 L
s
.73405 1.03305 m
.73544 1.0356 L
s
0 1 .88 r
.87497 1.08563 m
.90603 1.10818 L
s
.56 1 0 r
.09397 1.10818 m
.12503 1.08563 L
s
0 1 .16 r
.5193 .98174 m
.52885 .98038 L
s
.53544 .98265 m
.52885 .98038 L
s
.4807 .98174 m
.47115 .98038 L
s
.47115 .98038 m
.46456 .98265 L
s
.2 1 0 r
.39324 .99278 m
.40486 .9908 L
s
.38412 .99626 m
.39324 .99278 L
s
0 1 .52 r
.60676 .99278 m
.59514 .9908 L
s
.60676 .99278 m
.61588 .99626 L
s
.2 1 0 r
.4775 .98 m
.49063 .98018 L
s
.4635 .98672 m
.4775 .98 L
s
0 1 .52 r
.5225 .98 m
.50937 .98018 L
s
.5225 .98 m
.5365 .98672 L
s
.69328 1.01944 m
.70682 1.02408 L
s
.68972 1.0179 m
.69328 1.01944 L
s
.2 1 0 r
.30672 1.01944 m
.29318 1.02408 L
s
.30672 1.01944 m
.31028 1.0179 L
s
0 1 .16 r
.30287 1.0208 m
.28976 1.0257 L
s
.28976 1.0257 m
.27854 1.02536 L
s
.69713 1.0208 m
.71024 1.0257 L
s
.72146 1.02536 m
.71024 1.0257 L
s
.5 .98234 m
.5 .97959 L
s
.5 .97959 m
.49296 .97986 L
s
.50704 .97986 m
.5 .97959 L
s
.31598 1.01609 m
.30287 1.0208 L
s
.68402 1.01609 m
.69713 1.0208 L
s
.30287 1.0208 m
.29254 1.02137 L
s
.70746 1.02137 m
.69713 1.0208 L
s
0 1 .88 r
.67193 1.01193 m
.66906 1.01104 L
s
.67193 1.01193 m
.71878 1.02765 L
s
.56 1 0 r
.32807 1.01193 m
.33094 1.01104 L
s
.28122 1.02765 m
.32807 1.01193 L
s
0 1 .16 r
.32909 1.01159 m
.31598 1.01609 L
s
.67091 1.01159 m
.68402 1.01609 L
s
.31598 1.01609 m
.30652 1.01746 L
s
.69348 1.01746 m
.68402 1.01609 L
s
.2 1 0 r
.35964 1.00196 m
.36599 1.00081 L
s
.35289 1.00415 m
.35964 1.00196 L
s
0 1 .52 r
.64036 1.00196 m
.63401 1.00081 L
s
.64036 1.00196 m
.64711 1.00415 L
s
0 1 .16 r
.50354 .98245 m
.50704 .97986 L
s
.51362 .98062 m
.50704 .97986 L
s
.49646 .98245 m
.49296 .97986 L
s
.49296 .97986 m
.48638 .98062 L
s
.34219 1.00734 m
.32909 1.01159 L
s
.32909 1.01159 m
.32047 1.01366 L
s
.65781 1.00734 m
.67091 1.01159 L
s
.67953 1.01366 m
.67091 1.01159 L
s
.2 1 0 r
.25072 1.04076 m
.23685 1.0459 L
s
.25072 1.04076 m
.25226 1.03737 L
s
0 1 .52 r
.74928 1.04076 m
.76315 1.0459 L
s
.74774 1.03737 m
.74928 1.04076 L
s
0 1 .16 r
.53544 .98265 m
.54716 .98261 L
s
.55284 .98563 m
.54716 .98261 L
s
.46456 .98265 m
.45284 .98261 L
s
.45284 .98261 m
.44716 .98563 L
s
0 1 .88 r
.79949 1.06143 m
.80744 1.06218 L
s
.76055 1.04444 m
.79949 1.06143 L
s
.56 1 0 r
.20051 1.06143 m
.19256 1.06218 L
s
.20051 1.06143 m
.23945 1.04444 L
s
0 1 .16 r
.3553 1.00336 m
.34219 1.00734 L
s
.34219 1.00734 m
.33439 1.00997 L
s
.6447 1.00336 m
.65781 1.00734 L
s
.66561 1.00997 m
.65781 1.00734 L
s
.2 1 0 r
.49063 .98018 m
.50378 .98082 L
s
.47536 .98687 m
.49063 .98018 L
s
0 1 .52 r
.50937 .98018 m
.49622 .98082 L
s
.50937 .98018 m
.52464 .98687 L
s
.2 1 0 r
.32667 1.0124 m
.31638 1.01568 L
s
.32667 1.0124 m
.33214 1.01062 L
s
0 1 .52 r
.67333 1.0124 m
.68362 1.01568 L
s
.66786 1.01062 m
.67333 1.0124 L
s
0 1 .88 r
.71789 1.02834 m
.71878 1.02765 L
s
.71789 1.02834 m
.76055 1.04444 L
s
.56 1 0 r
.28211 1.02834 m
.28122 1.02765 L
s
.23945 1.04444 m
.28211 1.02834 L
s
0 1 .16 r
.3684 .99969 m
.3553 1.00336 L
s
.6316 .99969 m
.6447 1.00336 L
s
.3553 1.00336 m
.3483 1.00643 L
s
.6517 1.00643 m
.6447 1.00336 L
s
0 1 .52 r
.62521 .99791 m
.61588 .99626 L
s
.62521 .99791 m
.63401 1.00081 L
s
.2 1 0 r
.37479 .99791 m
.38412 .99626 L
s
.36599 1.00081 m
.37479 .99791 L
s
0 1 .16 r
.49316 .98274 m
.48638 .98062 L
s
.50684 .98274 m
.51362 .98062 L
s
.48638 .98062 m
.4807 .98174 L
s
.5193 .98174 m
.51362 .98062 L
s
0 1 .52 r
.59514 .9908 m
.58349 .98924 L
s
.59514 .9908 m
.60651 .99491 L
s
.2 1 0 r
.40486 .9908 m
.41651 .98924 L
s
.39349 .99491 m
.40486 .9908 L
s
0 1 .16 r
.38151 .99636 m
.3684 .99969 L
s
.3684 .99969 m
.36218 1.00306 L
s
.61849 .99636 m
.6316 .99969 L
s
.63782 1.00306 m
.6316 .99969 L
s
0 1 .52 r
.76315 1.0459 m
.77705 1.05101 L
s
.76147 1.04158 m
.76315 1.0459 L
s
.2 1 0 r
.23685 1.0459 m
.22295 1.05101 L
s
.23685 1.0459 m
.23853 1.04158 L
s
.35289 1.00415 m
.35584 1.00384 L
s
.34573 1.00639 m
.35289 1.00415 L
s
0 1 .52 r
.64711 1.00415 m
.64416 1.00384 L
s
.64711 1.00415 m
.65427 1.00639 L
s
.70682 1.02408 m
.72042 1.02862 L
s
.7021 1.02178 m
.70682 1.02408 L
s
.2 1 0 r
.29318 1.02408 m
.27958 1.02862 L
s
.29318 1.02408 m
.2979 1.02178 L
s
0 1 .16 r
.39462 .99339 m
.38151 .99636 L
s
.60538 .99339 m
.61849 .99636 L
s
.38151 .99636 m
.37604 .99988 L
s
.62396 .99988 m
.61849 .99636 L
s
.2 1 0 r
.33214 1.01062 m
.32461 1.01299 L
s
.33214 1.01062 m
.33865 1.00857 L
s
0 1 .52 r
.66786 1.01062 m
.67539 1.01299 L
s
.66135 1.00857 m
.66786 1.01062 L
s
.2 1 0 r
.50378 .98082 m
.51697 .98187 L
s
.48727 .98727 m
.50378 .98082 L
s
0 1 .52 r
.49622 .98082 m
.48303 .98187 L
s
.49622 .98082 m
.51273 .98727 L
s
0 1 .88 r
.60908 .99419 m
.66326 1.00939 L
s
.56 1 0 r
.33674 1.00939 m
.39092 .99419 L
s
0 1 .52 r
.65427 1.00639 m
.65494 1.00693 L
s
.65427 1.00639 m
.66135 1.00857 L
s
.2 1 0 r
.34573 1.00639 m
.34506 1.00693 L
s
.33865 1.00857 m
.34573 1.00639 L
s
0 1 .88 r
.76055 1.04444 m
.76514 1.04432 L
s
.56 1 0 r
.23945 1.04444 m
.23486 1.04432 L
s
0 1 .16 r
.40774 .99082 m
.39462 .99339 L
s
.39462 .99339 m
.38987 .99693 L
s
.59226 .99082 m
.60538 .99339 L
s
.61013 .99693 m
.60538 .99339 L
s
0 1 .52 r
.68972 1.0179 m
.7021 1.02178 L
s
.68362 1.01568 m
.68972 1.0179 L
s
.2 1 0 r
.31028 1.0179 m
.2979 1.02178 L
s
.31028 1.0179 m
.31638 1.01568 L
s
0 1 .52 r
.66135 1.00857 m
.6656 1.01002 L
s
.2 1 0 r
.33865 1.00857 m
.3344 1.01002 L
s
0 1 .52 r
.77705 1.05101 m
.79096 1.05609 L
s
.77525 1.0457 m
.77705 1.05101 L
s
.2 1 0 r
.22295 1.05101 m
.20904 1.05609 L
s
.22295 1.05101 m
.22475 1.0457 L
s
0 1 .88 r
.85327 1.08259 m
.86409 1.08418 L
s
.81545 1.0628 m
.85327 1.08259 L
s
.56 1 0 r
.14673 1.08259 m
.13591 1.08418 L
s
.14673 1.08259 m
.18455 1.0628 L
s
0 1 .16 r
.47632 .98303 m
.46456 .98265 L
s
.52368 .98303 m
.53544 .98265 L
s
.46456 .98265 m
.46033 .98477 L
s
.53967 .98477 m
.53544 .98265 L
s
.49032 .98318 m
.4807 .98174 L
s
.4807 .98174 m
.47632 .98303 L
s
.50968 .98318 m
.5193 .98174 L
s
.52368 .98303 m
.5193 .98174 L
s
.42087 .98866 m
.40774 .99082 L
s
.40774 .99082 m
.40369 .99423 L
s
.57913 .98866 m
.59226 .99082 L
s
.59631 .99423 m
.59226 .99082 L
s
0 1 .52 r
.58349 .98924 m
.57181 .98808 L
s
.58349 .98924 m
.5971 .99384 L
s
.2 1 0 r
.41651 .98924 m
.42819 .98808 L
s
.4029 .99384 m
.41651 .98924 L
s
.51697 .98187 m
.5302 .98331 L
s
.49923 .98788 m
.51697 .98187 L
s
0 1 .52 r
.48303 .98187 m
.4698 .98331 L
s
.48303 .98187 m
.50077 .98788 L
s
.2 1 0 r
.20904 1.05609 m
.19509 1.06113 L
s
.20904 1.05609 m
.21093 1.04972 L
s
0 1 .52 r
.79096 1.05609 m
.80491 1.06113 L
s
.78907 1.04972 m
.79096 1.05609 L
s
.2 1 0 r
.27958 1.02862 m
.26595 1.03305 L
s
.27958 1.02862 m
.28545 1.02547 L
s
0 1 .52 r
.72042 1.02862 m
.73405 1.03305 L
s
.71455 1.02547 m
.72042 1.02862 L
s
0 1 .16 r
.43401 .98693 m
.42087 .98866 L
s
.42087 .98866 m
.41749 .9918 L
s
.56599 .98693 m
.57913 .98866 L
s
.58251 .9918 m
.57913 .98866 L
s
0 1 .52 r
.63401 1.00081 m
.62762 .99984 L
s
.63401 1.00081 m
.64416 1.00384 L
s
.2 1 0 r
.36599 1.00081 m
.37238 .99984 L
s
.35584 1.00384 m
.36599 1.00081 L
s
0 1 .52 r
.61588 .99626 m
.60651 .99491 L
s
.61588 .99626 m
.62762 .99984 L
s
.2 1 0 r
.38412 .99626 m
.39349 .99491 L
s
.37238 .99984 m
.38412 .99626 L
s
0 1 .88 r
.66906 1.01104 m
.66617 1.0102 L
s
.66906 1.01104 m
.71967 1.02694 L
s
.56 1 0 r
.33094 1.01104 m
.33383 1.0102 L
s
.28033 1.02694 m
.33094 1.01104 L
s
0 1 .88 r
.80744 1.06218 m
.81545 1.0628 L
s
.76514 1.04432 m
.80744 1.06218 L
s
.56 1 0 r
.19256 1.06218 m
.18455 1.0628 L
s
.19256 1.06218 m
.23486 1.04432 L
s
0 1 .52 r
.80491 1.06113 m
.81887 1.06612 L
s
.80294 1.05364 m
.80491 1.06113 L
s
.2 1 0 r
.19509 1.06113 m
.18113 1.06612 L
s
.19509 1.06113 m
.19706 1.05364 L
s
0 1 .16 r
.44716 .98563 m
.43401 .98693 L
s
.55284 .98563 m
.56599 .98693 L
s
.43401 .98693 m
.43127 .98969 L
s
.56873 .98969 m
.56599 .98693 L
s
0 1 .52 r
.68362 1.01568 m
.69397 1.01867 L
s
.67539 1.01299 m
.68362 1.01568 L
s
.2 1 0 r
.31638 1.01568 m
.30603 1.01867 L
s
.31638 1.01568 m
.32461 1.01299 L
s
.5302 .98331 m
.54346 .98507 L
s
.51125 .98868 m
.5302 .98331 L
s
0 1 .52 r
.4698 .98331 m
.45654 .98507 L
s
.4698 .98331 m
.48875 .98868 L
s
0 1 .16 r
.5 .98466 m
.5 .98234 L
s
.5 .98234 m
.49646 .98245 L
s
.50354 .98245 m
.5 .98234 L
s
.48813 .98372 m
.47632 .98303 L
s
.51187 .98372 m
.52368 .98303 L
s
.47632 .98303 m
.47353 .98433 L
s
.52647 .98433 m
.52368 .98303 L
s
.5 .98466 m
.49646 .98245 L
s
.5 .98466 m
.50354 .98245 L
s
.49646 .98245 m
.49316 .98274 L
s
.50684 .98274 m
.50354 .98245 L
s
0 1 .88 r
.71878 1.02765 m
.71967 1.02694 L
s
.71878 1.02765 m
.76514 1.04432 L
s
.56 1 0 r
.28122 1.02765 m
.28033 1.02694 L
s
.23486 1.04432 m
.28122 1.02765 L
s
0 1 .52 r
.57181 .98808 m
.56008 .98729 L
s
.57181 .98808 m
.58764 .993 L
s
.2 1 0 r
.42819 .98808 m
.43992 .98729 L
s
.41236 .993 m
.42819 .98808 L
s
0 1 .16 r
.46033 .98477 m
.44716 .98563 L
s
.53967 .98477 m
.55284 .98563 L
s
.44716 .98563 m
.44503 .98792 L
s
.55497 .98792 m
.55284 .98563 L
s
.2 1 0 r
.2979 1.02178 m
.28545 1.02547 L
s
.2979 1.02178 m
.30603 1.01867 L
s
0 1 .52 r
.7021 1.02178 m
.71455 1.02547 L
s
.69397 1.01867 m
.7021 1.02178 L
s
.81887 1.06612 m
.83286 1.07107 L
s
.81686 1.05746 m
.81887 1.06612 L
s
.2 1 0 r
.18113 1.06612 m
.16714 1.07107 L
s
.18113 1.06612 m
.18314 1.05746 L
s
0 1 .16 r
.5 .98466 m
.49316 .98274 L
s
.5 .98466 m
.50684 .98274 L
s
.49316 .98274 m
.49032 .98318 L
s
.50968 .98318 m
.50684 .98274 L
s
0 1 .52 r
.73405 1.03305 m
.74774 1.03737 L
s
.72705 1.02896 m
.73405 1.03305 L
s
.2 1 0 r
.26595 1.03305 m
.25226 1.03737 L
s
.26595 1.03305 m
.27295 1.02896 L
s
.35584 1.00384 m
.35882 1.00353 L
s
.34506 1.00693 m
.35584 1.00384 L
s
0 1 .52 r
.64416 1.00384 m
.64118 1.00353 L
s
.64416 1.00384 m
.65494 1.00693 L
s
0 1 .88 r
.86409 1.08418 m
.87497 1.08563 L
s
.8235 1.06328 m
.86409 1.08418 L
s
.56 1 0 r
.13591 1.08418 m
.12503 1.08563 L
s
.13591 1.08418 m
.1765 1.06328 L
s
.2 1 0 r
.32461 1.01299 m
.31703 1.01506 L
s
.32461 1.01299 m
.3344 1.01002 L
s
0 1 .52 r
.67539 1.01299 m
.68297 1.01506 L
s
.6656 1.01002 m
.67539 1.01299 L
s
.2 1 0 r
.54346 .98507 m
.55677 .98713 L
s
.52333 .98962 m
.54346 .98507 L
s
0 1 .52 r
.45654 .98507 m
.44323 .98713 L
s
.45654 .98507 m
.47667 .98962 L
s
0 1 .16 r
.5 .98466 m
.49032 .98318 L
s
.5 .98466 m
.50968 .98318 L
s
.49032 .98318 m
.48813 .98372 L
s
.51187 .98372 m
.50968 .98318 L
s
.47353 .98433 m
.46033 .98477 L
s
.52647 .98433 m
.53967 .98477 L
s
.46033 .98477 m
.45878 .98651 L
s
.54122 .98651 m
.53967 .98477 L
s
.2 1 0 r
.16714 1.07107 m
.15312 1.07598 L
s
.16714 1.07107 m
.16919 1.06119 L
s
0 1 .52 r
.83286 1.07107 m
.84688 1.07598 L
s
.83081 1.06119 m
.83286 1.07107 L
s
.56 1 0 r
.23486 1.04432 m
.23024 1.0441 L
s
0 1 .88 r
.76514 1.04432 m
.76976 1.0441 L
s
0 1 .52 r
.60651 .99491 m
.5971 .99384 L
s
.60651 .99491 m
.6212 .99901 L
s
.2 1 0 r
.39349 .99491 m
.4029 .99384 L
s
.3788 .99901 m
.39349 .99491 L
s
.34506 1.00693 m
.3444 1.00734 L
s
.3344 1.01002 m
.34506 1.00693 L
s
0 1 .52 r
.65494 1.00693 m
.6556 1.00734 L
s
.65494 1.00693 m
.6656 1.01002 L
s
.6656 1.01002 m
.66987 1.01122 L
s
.2 1 0 r
.3344 1.01002 m
.33013 1.01122 L
s
0 1 .52 r
.56008 .98729 m
.54832 .98684 L
s
.56008 .98729 m
.57813 .99237 L
s
.2 1 0 r
.43992 .98729 m
.45168 .98684 L
s
.42187 .99237 m
.43992 .98729 L
s
0 1 .16 r
.5 .98466 m
.48813 .98372 L
s
.5 .98466 m
.51187 .98372 L
s
.48813 .98372 m
.48675 .9843 L
s
.51325 .9843 m
.51187 .98372 L
s
.48675 .9843 m
.47353 .98433 L
s
.51325 .9843 m
.52647 .98433 L
s
.47353 .98433 m
.47253 .98549 L
s
.52747 .98549 m
.52647 .98433 L
s
.2 1 0 r
.37238 .99984 m
.3788 .99901 L
s
.35882 1.00353 m
.37238 .99984 L
s
0 1 .52 r
.62762 .99984 m
.6212 .99901 L
s
.62762 .99984 m
.64118 1.00353 L
s
.84688 1.07598 m
.86091 1.08083 L
s
.84481 1.06484 m
.84688 1.07598 L
s
.2 1 0 r
.15312 1.07598 m
.13909 1.08083 L
s
.15312 1.07598 m
.15519 1.06484 L
s
.25226 1.03737 m
.23853 1.04158 L
s
.25226 1.03737 m
.26038 1.03227 L
s
0 1 .52 r
.74774 1.03737 m
.76147 1.04158 L
s
.73962 1.03227 m
.74774 1.03737 L
s
.2 1 0 r
.53546 .99069 m
.55677 .98713 L
s
0 1 .52 r
.44323 .98713 m
.46454 .99069 L
s
0 1 .88 r
.66617 1.0102 m
.66326 1.00939 L
s
.66617 1.0102 m
.72056 1.02618 L
s
.56 1 0 r
.33383 1.0102 m
.33674 1.00939 L
s
.27944 1.02618 m
.33383 1.0102 L
s
0 1 .52 r
.71455 1.02547 m
.72705 1.02896 L
s
.70438 1.02141 m
.71455 1.02547 L
s
.2 1 0 r
.28545 1.02547 m
.27295 1.02896 L
s
.28545 1.02547 m
.29562 1.02141 L
s
0 1 .88 r
.81545 1.0628 m
.8235 1.06328 L
s
.76976 1.0441 m
.81545 1.0628 L
s
.56 1 0 r
.18455 1.0628 m
.1765 1.06328 L
s
.18455 1.0628 m
.23024 1.0441 L
s
0 1 .52 r
.69397 1.01867 m
.70438 1.02141 L
s
.68297 1.01506 m
.69397 1.01867 L
s
.2 1 0 r
.30603 1.01867 m
.29562 1.02141 L
s
.30603 1.01867 m
.31703 1.01506 L
s
.13909 1.08083 m
.12503 1.08563 L
s
.13909 1.08083 m
.14114 1.0684 L
s
0 1 .52 r
.86091 1.08083 m
.87497 1.08563 L
s
.85886 1.0684 m
.86091 1.08083 L
s
0 1 .16 r
.5 .98466 m
.48675 .9843 L
s
.5 .98466 m
.51325 .9843 L
s
.48675 .9843 m
.48627 .98487 L
s
.51373 .98487 m
.51325 .9843 L
s
0 1 .88 r
.83161 1.06364 m
.87497 1.08563 L
s
.56 1 0 r
.12503 1.08563 m
.16839 1.06364 L
s
0 1 .52 r
.87294 1.07188 m
.87497 1.08563 L
s
.2 1 0 r
.12503 1.08563 m
.12706 1.07188 L
s
0 1 .52 r
.54832 .98684 m
.5365 .98672 L
s
.54832 .98684 m
.56856 .99192 L
s
.2 1 0 r
.45168 .98684 m
.4635 .98672 L
s
.43144 .99192 m
.45168 .98684 L
s
0 1 .88 r
.71967 1.02694 m
.72056 1.02618 L
s
.71967 1.02694 m
.76976 1.0441 L
s
.56 1 0 r
.28033 1.02694 m
.27944 1.02618 L
s
.23024 1.0441 m
.28033 1.02694 L
s
0 1 .52 r
.76147 1.04158 m
.77525 1.0457 L
s
.75224 1.03542 m
.76147 1.04158 L
s
.2 1 0 r
.23853 1.04158 m
.22475 1.0457 L
s
.23853 1.04158 m
.24776 1.03542 L
s
.4029 .99384 m
.41236 .993 L
s
.38528 .99828 m
.4029 .99384 L
s
0 1 .52 r
.5971 .99384 m
.58764 .993 L
s
.5971 .99384 m
.61472 .99828 L
s
0 1 .16 r
.5 .98466 m
.51373 .98487 L
s
.5 .98466 m
.51328 .98539 L
s
.5 .98466 m
.51192 .98582 L
s
.5 .98466 m
.50974 .98616 L
s
.5 .98466 m
.50689 .9864 L
s
.5 .98466 m
.50357 .98654 L
s
.5 .98466 m
.5 .98659 L
s
.5 .98466 m
.49643 .98654 L
s
.5 .98466 m
.49311 .9864 L
s
.5 .98466 m
.49026 .98616 L
s
.5 .98466 m
.48808 .98582 L
s
.5 .98466 m
.48672 .98539 L
s
.5 .98466 m
.48627 .98487 L
s
.5 .98466 m
.5 .98466 L
s
.51373 .98487 m
.52747 .98549 L
s
.51328 .98539 m
.51373 .98487 L
s
.48627 .98487 m
.47253 .98549 L
s
.48627 .98487 m
.48672 .98539 L
s
0 1 .52 r
.64118 1.00353 m
.63818 1.0032 L
s
.64118 1.00353 m
.6556 1.00734 L
s
.2 1 0 r
.35882 1.00353 m
.36182 1.0032 L
s
.3444 1.00734 m
.35882 1.00353 L
s
0 1 .16 r
.52747 .98549 m
.54122 .98651 L
s
.47253 .98549 m
.45878 .98651 L
s
.5266 .98644 m
.52747 .98549 L
s
.47253 .98549 m
.4734 .98644 L
s
.45878 .98651 m
.44503 .98792 L
s
.45878 .98651 m
.46005 .98779 L
s
.54122 .98651 m
.55497 .98792 L
s
.53995 .98779 m
.54122 .98651 L
s
.55497 .98792 m
.56873 .98969 L
s
.44503 .98792 m
.43127 .98969 L
s
.55334 .98941 m
.55497 .98792 L
s
.44503 .98792 m
.44666 .98941 L
s
0 1 .52 r
.68297 1.01506 m
.6906 1.01687 L
s
.66987 1.01122 m
.68297 1.01506 L
s
.2 1 0 r
.31703 1.01506 m
.3094 1.01687 L
s
.31703 1.01506 m
.33013 1.01122 L
s
0 1 .88 r
.76976 1.0441 m
.77441 1.04379 L
s
.56 1 0 r
.23024 1.0441 m
.22559 1.04379 L
s
0 1 .16 r
.56873 .98969 m
.58251 .9918 L
s
.43127 .98969 m
.41749 .9918 L
s
.56678 .99126 m
.56873 .98969 L
s
.43127 .98969 m
.43322 .99126 L
s
.51328 .98539 m
.5266 .98644 L
s
.48672 .98539 m
.4734 .98644 L
s
.51192 .98582 m
.51328 .98539 L
s
.48672 .98539 m
.48808 .98582 L
s
0 1 .52 r
.6212 .99901 m
.61472 .99828 L
s
.6212 .99901 m
.63818 1.0032 L
s
.2 1 0 r
.3788 .99901 m
.38528 .99828 L
s
.36182 1.0032 m
.3788 .99901 L
s
0 1 .16 r
.58251 .9918 m
.59631 .99423 L
s
.41749 .9918 m
.40369 .99423 L
s
.58025 .9933 m
.58251 .9918 L
s
.41749 .9918 m
.41975 .9933 L
s
0 1 .52 r
.72705 1.02896 m
.73962 1.03227 L
s
.71486 1.02391 m
.72705 1.02896 L
s
.2 1 0 r
.27295 1.02896 m
.26038 1.03227 L
s
.27295 1.02896 m
.28514 1.02391 L
s
0 1 .52 r
.6556 1.00734 m
.65627 1.00759 L
s
.6556 1.00734 m
.66987 1.01122 L
s
.2 1 0 r
.3444 1.00734 m
.34373 1.00759 L
s
.33013 1.01122 m
.3444 1.00734 L
s
0 1 .52 r
.66987 1.01122 m
.67417 1.01218 L
s
.2 1 0 r
.33013 1.01122 m
.32583 1.01218 L
s
0 1 .52 r
.5365 .98672 m
.52464 .98687 L
s
.5365 .98672 m
.55894 .99161 L
s
.2 1 0 r
.4635 .98672 m
.47536 .98687 L
s
.44106 .99161 m
.4635 .98672 L
s
0 1 .52 r
.77525 1.0457 m
.78907 1.04972 L
s
.76493 1.03841 m
.77525 1.0457 L
s
.2 1 0 r
.22475 1.0457 m
.21093 1.04972 L
s
.22475 1.0457 m
.23507 1.03841 L
s
0 1 .16 r
.59631 .99423 m
.61013 .99693 L
s
.40369 .99423 m
.38987 .99693 L
s
.59377 .99552 m
.59631 .99423 L
s
.40369 .99423 m
.40623 .99552 L
s
0 1 .52 r
.70438 1.02141 m
.71486 1.02391 L
s
.6906 1.01687 m
.70438 1.02141 L
s
.2 1 0 r
.29562 1.02141 m
.28514 1.02391 L
s
.29562 1.02141 m
.3094 1.01687 L
s
0 1 .16 r
.51192 .98582 m
.5239 .98715 L
s
.48808 .98582 m
.4761 .98715 L
s
.50974 .98616 m
.51192 .98582 L
s
.48808 .98582 m
.49026 .98616 L
s
.38987 .99693 m
.37604 .99988 L
s
.38987 .99693 m
.39266 .99788 L
s
.61013 .99693 m
.62396 .99988 L
s
.60734 .99788 m
.61013 .99693 L
s
0 1 .88 r
.8235 1.06328 m
.83161 1.06364 L
s
.77441 1.04379 m
.8235 1.06328 L
s
.56 1 0 r
.1765 1.06328 m
.16839 1.06364 L
s
.1765 1.06328 m
.22559 1.04379 L
s
0 1 .88 r
.66326 1.00939 m
.72146 1.02536 L
s
.56 1 0 r
.27854 1.02536 m
.33674 1.00939 L
s
0 1 .16 r
.4734 .98644 m
.46005 .98779 L
s
.4734 .98644 m
.4761 .98715 L
s
.5266 .98644 m
.53995 .98779 L
s
.5239 .98715 m
.5266 .98644 L
s
0 1 .52 r
.58764 .993 m
.57813 .99237 L
s
.58764 .993 m
.60821 .99763 L
s
.2 1 0 r
.41236 .993 m
.42187 .99237 L
s
.39179 .99763 m
.41236 .993 L
s
0 1 .16 r
.62396 .99988 m
.63782 1.00306 L
s
.37604 .99988 m
.36218 1.00306 L
s
.62095 1.00036 m
.62396 .99988 L
s
.37604 .99988 m
.37905 1.00036 L
s
.50974 .98616 m
.51955 .98764 L
s
.50689 .9864 m
.50974 .98616 L
s
.49026 .98616 m
.48045 .98764 L
s
.49026 .98616 m
.49311 .9864 L
s
.36218 1.00306 m
.3483 1.00643 L
s
.36218 1.00306 m
.3654 1.00293 L
s
.63782 1.00306 m
.6517 1.00643 L
s
.6346 1.00293 m
.63782 1.00306 L
s
.2 1 0 r
.21093 1.04972 m
.19706 1.05364 L
s
.21093 1.04972 m
.22233 1.04125 L
s
0 1 .52 r
.78907 1.04972 m
.80294 1.05364 L
s
.77767 1.04125 m
.78907 1.04972 L
s
0 1 .88 r
.72056 1.02618 m
.72146 1.02536 L
s
.72056 1.02618 m
.77441 1.04379 L
s
.56 1 0 r
.27944 1.02618 m
.27854 1.02536 L
s
.22559 1.04379 m
.27944 1.02618 L
s
0 1 .52 r
.52464 .98687 m
.51273 .98727 L
s
.52464 .98687 m
.54926 .99141 L
s
.2 1 0 r
.47536 .98687 m
.48727 .98727 L
s
.45074 .99141 m
.47536 .98687 L
s
0 1 .16 r
.53995 .98779 m
.55334 .98941 L
s
.46005 .98779 m
.44666 .98941 L
s
.53594 .98862 m
.53995 .98779 L
s
.46005 .98779 m
.46406 .98862 L
s
.50689 .9864 m
.51384 .98794 L
s
.50357 .98654 m
.50689 .9864 L
s
.49311 .9864 m
.48616 .98794 L
s
.49311 .9864 m
.49643 .98654 L
s
0 1 .52 r
.73962 1.03227 m
.75224 1.03542 L
s
.72539 1.02618 m
.73962 1.03227 L
s
.2 1 0 r
.26038 1.03227 m
.24776 1.03542 L
s
.26038 1.03227 m
.27461 1.02618 L
s
0 1 .52 r
.63818 1.0032 m
.63515 1.00283 L
s
.63818 1.0032 m
.65627 1.00759 L
s
.2 1 0 r
.36182 1.0032 m
.36485 1.00283 L
s
.34373 1.00759 m
.36182 1.0032 L
s
0 1 .16 r
.6517 1.00643 m
.66561 1.00997 L
s
.6483 1.00558 m
.6517 1.00643 L
s
.3483 1.00643 m
.33439 1.00997 L
s
.3483 1.00643 m
.3517 1.00558 L
s
.50357 .98654 m
.50717 .9881 L
s
.49643 .98654 m
.49283 .9881 L
s
.5 .98659 m
.50357 .98654 L
s
.49643 .98654 m
.5 .98659 L
s
.5 .98659 m
.5 .98815 L
s
0 1 .52 r
.6906 1.01687 m
.69829 1.01842 L
s
.67417 1.01218 m
.6906 1.01687 L
s
.2 1 0 r
.3094 1.01687 m
.30171 1.01842 L
s
.3094 1.01687 m
.32583 1.01218 L
s
0 1 .16 r
.5239 .98715 m
.53594 .98862 L
s
.4761 .98715 m
.46406 .98862 L
s
.51955 .98764 m
.5239 .98715 L
s
.4761 .98715 m
.48045 .98764 L
s
0 1 .52 r
.61472 .99828 m
.60821 .99763 L
s
.61472 .99828 m
.63515 1.00283 L
s
.2 1 0 r
.38528 .99828 m
.39179 .99763 L
s
.36485 1.00283 m
.38528 .99828 L
s
0 1 .16 r
.66561 1.00997 m
.67953 1.01366 L
s
.66204 1.00828 m
.66561 1.00997 L
s
.33439 1.00997 m
.32047 1.01366 L
s
.33439 1.00997 m
.33796 1.00828 L
s
0 1 .88 r
.77441 1.04379 m
.77909 1.04336 L
s
.56 1 0 r
.22559 1.04379 m
.22091 1.04336 L
s
0 1 .16 r
.55334 .98941 m
.56678 .99126 L
s
.54803 .99019 m
.55334 .98941 L
s
.44666 .98941 m
.43322 .99126 L
s
.44666 .98941 m
.45197 .99019 L
s
.2 1 0 r
.19706 1.05364 m
.18314 1.05746 L
s
.19706 1.05364 m
.20952 1.04394 L
s
0 1 .52 r
.80294 1.05364 m
.81686 1.05746 L
s
.79048 1.04394 m
.80294 1.05364 L
s
0 1 .16 r
.67953 1.01366 m
.69348 1.01746 L
s
.32047 1.01366 m
.30652 1.01746 L
s
.67584 1.01103 m
.67953 1.01366 L
s
.32047 1.01366 m
.32416 1.01103 L
s
0 1 .52 r
.57813 .99237 m
.56856 .99192 L
s
.57813 .99237 m
.60165 .99704 L
s
.2 1 0 r
.42187 .99237 m
.43144 .99192 L
s
.39835 .99704 m
.42187 .99237 L
s
0 1 .52 r
.71486 1.02391 m
.72539 1.02618 L
s
.69829 1.01842 m
.71486 1.02391 L
s
.2 1 0 r
.28514 1.02391 m
.27461 1.02618 L
s
.28514 1.02391 m
.30171 1.01842 L
s
0 1 .52 r
.65627 1.00759 m
.65694 1.00769 L
s
.65627 1.00759 m
.67417 1.01218 L
s
.2 1 0 r
.34373 1.00759 m
.34306 1.00769 L
s
.32583 1.01218 m
.34373 1.00759 L
s
0 1 .52 r
.67417 1.01218 m
.67851 1.01292 L
s
.2 1 0 r
.32583 1.01218 m
.32149 1.01292 L
s
0 1 .88 r
.77909 1.04336 m
.83161 1.06364 L
s
.56 1 0 r
.16839 1.06364 m
.22091 1.04336 L
s
0 1 .52 r
.51273 .98727 m
.50077 .98788 L
s
.51273 .98727 m
.53953 .99131 L
s
.2 1 0 r
.48727 .98727 m
.49923 .98788 L
s
.46047 .99131 m
.48727 .98727 L
s
0 1 .16 r
.69348 1.01746 m
.70746 1.02137 L
s
.68967 1.0138 m
.69348 1.01746 L
s
.30652 1.01746 m
.29254 1.02137 L
s
.30652 1.01746 m
.31033 1.0138 L
s
.51955 .98764 m
.52942 .98908 L
s
.48045 .98764 m
.47058 .98908 L
s
.51384 .98794 m
.51955 .98764 L
s
.48045 .98764 m
.48616 .98794 L
s
.56678 .99126 m
.58025 .9933 L
s
.43322 .99126 m
.41975 .9933 L
s
.56019 .99184 m
.56678 .99126 L
s
.43322 .99126 m
.43981 .99184 L
s
.2 1 0 r
.24776 1.03542 m
.23507 1.03841 L
s
.24776 1.03542 m
.26401 1.02825 L
s
0 1 .52 r
.75224 1.03542 m
.76493 1.03841 L
s
.73599 1.02825 m
.75224 1.03542 L
s
0 1 .16 r
.70746 1.02137 m
.72146 1.02536 L
s
.29254 1.02137 m
.27854 1.02536 L
s
.70356 1.0166 m
.70746 1.02137 L
s
.29254 1.02137 m
.29644 1.0166 L
s
.46406 .98862 m
.45197 .99019 L
s
.46406 .98862 m
.47058 .98908 L
s
.53594 .98862 m
.54803 .99019 L
s
.52942 .98908 m
.53594 .98862 L
s
.2 1 0 r
.18314 1.05746 m
.16919 1.06119 L
s
.18314 1.05746 m
.19666 1.04651 L
s
0 1 .52 r
.81686 1.05746 m
.83081 1.06119 L
s
.80334 1.04651 m
.81686 1.05746 L
s
0 1 .88 r
.72146 1.02536 m
.77909 1.04336 L
s
.56 1 0 r
.22091 1.04336 m
.27854 1.02536 L
s
0 1 .16 r
.71749 1.0194 m
.72146 1.02536 L
s
.27854 1.02536 m
.28251 1.0194 L
s
.48616 .98794 m
.47915 .98929 L
s
.48616 .98794 m
.49283 .9881 L
s
.51384 .98794 m
.52085 .98929 L
s
.50717 .9881 m
.51384 .98794 L
s
0 1 .52 r
.63515 1.00283 m
.6321 1.00241 L
s
.63515 1.00283 m
.65694 1.00769 L
s
.2 1 0 r
.36485 1.00283 m
.3679 1.00241 L
s
.34306 1.00769 m
.36485 1.00283 L
s
0 1 .16 r
.58025 .9933 m
.59377 .99552 L
s
.5724 .99354 m
.58025 .9933 L
s
.41975 .9933 m
.40623 .99552 L
s
.41975 .9933 m
.4276 .99354 L
s
0 1 .52 r
.50077 .98788 m
.48875 .98868 L
s
.50077 .98788 m
.52974 .99128 L
s
.2 1 0 r
.49923 .98788 m
.51125 .98868 L
s
.47026 .99128 m
.49923 .98788 L
s
0 1 .52 r
.60821 .99763 m
.60165 .99704 L
s
.60821 .99763 m
.6321 1.00241 L
s
.2 1 0 r
.39179 .99763 m
.39835 .99704 L
s
.3679 1.00241 m
.39179 .99763 L
s
0 1 .52 r
.56856 .99192 m
.55894 .99161 L
s
.56856 .99192 m
.59504 .99647 L
s
.2 1 0 r
.43144 .99192 m
.44106 .99161 L
s
.40496 .99647 m
.43144 .99192 L
s
0 1 .52 r
.69829 1.01842 m
.70602 1.01974 L
s
.67851 1.01292 m
.69829 1.01842 L
s
.2 1 0 r
.30171 1.01842 m
.29398 1.01974 L
s
.30171 1.01842 m
.32149 1.01292 L
s
0 1 .16 r
.50717 .9881 m
.51081 .98936 L
s
.5 .98815 m
.50717 .9881 L
s
.49283 .9881 m
.48919 .98936 L
s
.49283 .9881 m
.5 .98815 L
s
0 1 .52 r
.83081 1.06119 m
.84481 1.06484 L
s
.81626 1.04894 m
.83081 1.06119 L
s
.2 1 0 r
.16919 1.06119 m
.15519 1.06484 L
s
.16919 1.06119 m
.18374 1.04894 L
s
.27461 1.02618 m
.26401 1.02825 L
s
.27461 1.02618 m
.29398 1.01974 L
s
0 1 .52 r
.72539 1.02618 m
.73599 1.02825 L
s
.70602 1.01974 m
.72539 1.02618 L
s
0 1 .16 r
.5 .98815 m
.5 .98937 L
s
0 1 .52 r
.76493 1.03841 m
.77767 1.04125 L
s
.74666 1.03012 m
.76493 1.03841 L
s
.2 1 0 r
.23507 1.03841 m
.22233 1.04125 L
s
.23507 1.03841 m
.25334 1.03012 L
s
0 1 .16 r
.54803 .99019 m
.56019 .99184 L
s
.45197 .99019 m
.43981 .99184 L
s
.53936 .99046 m
.54803 .99019 L
s
.45197 .99019 m
.46064 .99046 L
s
.59377 .99552 m
.60734 .99788 L
s
.40623 .99552 m
.39266 .99788 L
s
.58468 .99528 m
.59377 .99552 L
s
.40623 .99552 m
.41532 .99528 L
s
.52942 .98908 m
.53936 .99046 L
s
.47058 .98908 m
.46064 .99046 L
s
.52085 .98929 m
.52942 .98908 L
s
.47058 .98908 m
.47915 .98929 L
s
0 1 .52 r
.65694 1.00769 m
.65761 1.00764 L
s
.65694 1.00769 m
.67851 1.01292 L
s
.2 1 0 r
.34306 1.00769 m
.34239 1.00764 L
s
.32149 1.01292 m
.34306 1.00769 L
s
0 1 .52 r
.67851 1.01292 m
.68287 1.01345 L
s
.2 1 0 r
.32149 1.01292 m
.31713 1.01345 L
s
.51125 .98868 m
.52333 .98962 L
s
.48011 .99129 m
.51125 .98868 L
s
0 1 .52 r
.48875 .98868 m
.47667 .98962 L
s
.48875 .98868 m
.51989 .99129 L
s
.84481 1.06484 m
.85886 1.0684 L
s
.82925 1.05125 m
.84481 1.06484 L
s
.2 1 0 r
.15519 1.06484 m
.14114 1.0684 L
s
.15519 1.06484 m
.17075 1.05125 L
s
0 1 .16 r
.60734 .99788 m
.62095 1.00036 L
s
.59702 .99703 m
.60734 .99788 L
s
.39266 .99788 m
.37905 1.00036 L
s
.39266 .99788 m
.40298 .99703 L
s
0 1 .52 r
.55894 .99161 m
.54926 .99141 L
s
.55894 .99161 m
.58839 .99592 L
s
.2 1 0 r
.44106 .99161 m
.45074 .99141 L
s
.41161 .99592 m
.44106 .99161 L
s
.39835 .99704 m
.40496 .99647 L
s
.37097 1.00191 m
.39835 .99704 L
s
0 1 .52 r
.60165 .99704 m
.59504 .99647 L
s
.60165 .99704 m
.62903 1.00191 L
s
0 1 .16 r
.52085 .98929 m
.52791 .99044 L
s
.51081 .98936 m
.52085 .98929 L
s
.47915 .98929 m
.47209 .99044 L
s
.47915 .98929 m
.48919 .98936 L
s
.56019 .99184 m
.5724 .99354 L
s
.54936 .99178 m
.56019 .99184 L
s
.43981 .99184 m
.4276 .99354 L
s
.43981 .99184 m
.45064 .99178 L
s
0 1 .52 r
.77767 1.04125 m
.79048 1.04394 L
s
.75738 1.0318 m
.77767 1.04125 L
s
.2 1 0 r
.22233 1.04125 m
.20952 1.04394 L
s
.22233 1.04125 m
.24262 1.0318 L
s
0 1 .52 r
.6321 1.00241 m
.62903 1.00191 L
s
.6321 1.00241 m
.65761 1.00764 L
s
.2 1 0 r
.3679 1.00241 m
.37097 1.00191 L
s
.34239 1.00764 m
.3679 1.00241 L
s
.26401 1.02825 m
.25334 1.03012 L
s
.26401 1.02825 m
.28619 1.02083 L
s
0 1 .52 r
.73599 1.02825 m
.74666 1.03012 L
s
.71381 1.02083 m
.73599 1.02825 L
s
.2 1 0 r
.29398 1.01974 m
.28619 1.02083 L
s
.29398 1.01974 m
.31713 1.01345 L
s
0 1 .52 r
.70602 1.01974 m
.71381 1.02083 L
s
.68287 1.01345 m
.70602 1.01974 L
s
.85886 1.0684 m
.87294 1.07188 L
s
.84229 1.05345 m
.85886 1.0684 L
s
.2 1 0 r
.14114 1.0684 m
.12706 1.07188 L
s
.14114 1.0684 m
.15771 1.05345 L
s
0 1 .16 r
.62095 1.00036 m
.6346 1.00293 L
s
.60942 .99878 m
.62095 1.00036 L
s
.37905 1.00036 m
.3654 1.00293 L
s
.37905 1.00036 m
.39058 .99878 L
s
.2 1 0 r
.52333 .98962 m
.53546 .99069 L
s
.49003 .99133 m
.52333 .98962 L
s
0 1 .52 r
.47667 .98962 m
.46454 .99069 L
s
.47667 .98962 m
.50997 .99133 L
s
0 1 .16 r
.46064 .99046 m
.45064 .99178 L
s
.46064 .99046 m
.47209 .99044 L
s
.53936 .99046 m
.54936 .99178 L
s
.52791 .99044 m
.53936 .99046 L
s
.48919 .98936 m
.48553 .99034 L
s
.48919 .98936 m
.5 .98937 L
s
.51081 .98936 m
.51447 .99034 L
s
.5 .98937 m
.51081 .98936 L
s
.5 .98937 m
.5 .99029 L
s
0 1 .52 r
.65761 1.00764 m
.65828 1.00742 L
s
.65761 1.00764 m
.68287 1.01345 L
s
.2 1 0 r
.34239 1.00764 m
.34172 1.00742 L
s
.31713 1.01345 m
.34239 1.00764 L
s
0 1 .52 r
.85539 1.05553 m
.87294 1.07188 L
s
.2 1 0 r
.12706 1.07188 m
.14461 1.05553 L
s
0 1 .52 r
.68287 1.01345 m
.68726 1.01376 L
s
.2 1 0 r
.31713 1.01345 m
.31274 1.01376 L
s
.45074 .99141 m
.46047 .99131 L
s
.41832 .99535 m
.45074 .99141 L
s
0 1 .52 r
.54926 .99141 m
.53953 .99131 L
s
.54926 .99141 m
.58168 .99535 L
s
0 1 .16 r
.5724 .99354 m
.58468 .99528 L
s
.4276 .99354 m
.41532 .99528 L
s
.55943 .99301 m
.5724 .99354 L
s
.4276 .99354 m
.44057 .99301 L
s
.3654 1.00293 m
.3517 1.00558 L
s
.3654 1.00293 m
.37812 1.00052 L
s
.6346 1.00293 m
.6483 1.00558 L
s
.62188 1.00052 m
.6346 1.00293 L
s
.2 1 0 r
.20952 1.04394 m
.19666 1.04651 L
s
.20952 1.04394 m
.23183 1.03332 L
s
0 1 .52 r
.79048 1.04394 m
.80334 1.04651 L
s
.76817 1.03332 m
.79048 1.04394 L
s
.46454 .99069 m
.5 .99139 L
s
.2 1 0 r
.5 .99139 m
.53546 .99069 L
s
0 1 .52 r
.59504 .99647 m
.58839 .99592 L
s
.59504 .99647 m
.62592 1.00133 L
s
.2 1 0 r
.40496 .99647 m
.41161 .99592 L
s
.37408 1.00133 m
.40496 .99647 L
s
0 1 .52 r
.74666 1.03012 m
.75738 1.0318 L
s
.72165 1.02171 m
.74666 1.03012 L
s
.2 1 0 r
.25334 1.03012 m
.24262 1.0318 L
s
.25334 1.03012 m
.27835 1.02171 L
s
0 1 .16 r
.52791 .99044 m
.53502 .99142 L
s
.47209 .99044 m
.46498 .99142 L
s
.51447 .99034 m
.52791 .99044 L
s
.47209 .99044 m
.48553 .99034 L
s
.6483 1.00558 m
.66204 1.00828 L
s
.6344 1.00223 m
.6483 1.00558 L
s
.3517 1.00558 m
.33796 1.00828 L
s
.3517 1.00558 m
.3656 1.00223 L
s
0 1 .52 r
.62903 1.00191 m
.62592 1.00133 L
s
.62903 1.00191 m
.65828 1.00742 L
s
.2 1 0 r
.37097 1.00191 m
.37408 1.00133 L
s
.34172 1.00742 m
.37097 1.00191 L
s
0 1 .16 r
.54936 .99178 m
.55943 .99301 L
s
.45064 .99178 m
.44057 .99301 L
s
.53502 .99142 m
.54936 .99178 L
s
.45064 .99178 m
.46498 .99142 L
s
0 1 .52 r
.71381 1.02083 m
.72165 1.02171 L
s
.68726 1.01376 m
.71381 1.02083 L
s
.2 1 0 r
.28619 1.02083 m
.27835 1.02171 L
s
.28619 1.02083 m
.31274 1.01376 L
s
0 1 .16 r
.58468 .99528 m
.59702 .99703 L
s
.56956 .99417 m
.58468 .99528 L
s
.41532 .99528 m
.40298 .99703 L
s
.41532 .99528 m
.43044 .99417 L
s
.2 1 0 r
.19666 1.04651 m
.18374 1.04894 L
s
.19666 1.04651 m
.22098 1.03466 L
s
0 1 .52 r
.80334 1.04651 m
.81626 1.04894 L
s
.77902 1.03466 m
.80334 1.04651 L
s
.53953 .99131 m
.52974 .99128 L
s
.53953 .99131 m
.57493 .99477 L
s
.2 1 0 r
.46047 .99131 m
.47026 .99128 L
s
.42507 .99477 m
.46047 .99131 L
s
0 1 .16 r
.48553 .99034 m
.48183 .99107 L
s
.48553 .99034 m
.5 .99029 L
s
.51447 .99034 m
.51817 .99107 L
s
.5 .99029 m
.51447 .99034 L
s
.66204 1.00828 m
.67584 1.01103 L
s
.33796 1.00828 m
.32416 1.01103 L
s
.64699 1.00392 m
.66204 1.00828 L
s
.33796 1.00828 m
.35301 1.00392 L
s
.5 .99029 m
.5 .99092 L
s
0 1 .52 r
.65828 1.00742 m
.65895 1.00705 L
s
.65828 1.00742 m
.68726 1.01376 L
s
.2 1 0 r
.34172 1.00742 m
.34105 1.00705 L
s
.31274 1.01376 m
.34172 1.00742 L
s
0 1 .52 r
.68726 1.01376 m
.69168 1.01388 L
s
.2 1 0 r
.31274 1.01376 m
.30832 1.01388 L
s
0 1 .52 r
.58839 .99592 m
.58168 .99535 L
s
.58839 .99592 m
.62279 1.00066 L
s
.2 1 0 r
.41161 .99592 m
.41832 .99535 L
s
.37721 1.00066 m
.41161 .99592 L
s
0 1 .52 r
.75738 1.0318 m
.76817 1.03332 L
s
.72954 1.02239 m
.75738 1.0318 L
s
.2 1 0 r
.24262 1.0318 m
.23183 1.03332 L
s
.24262 1.0318 m
.27046 1.02239 L
s
0 1 .16 r
.67584 1.01103 m
.68967 1.0138 L
s
.65964 1.00557 m
.67584 1.01103 L
s
.32416 1.01103 m
.31033 1.0138 L
s
.32416 1.01103 m
.34036 1.00557 L
s
.59702 .99703 m
.60942 .99878 L
s
.40298 .99703 m
.39058 .99878 L
s
.57976 .99523 m
.59702 .99703 L
s
.40298 .99703 m
.42024 .99523 L
s
.44057 .99301 m
.43044 .99417 L
s
.44057 .99301 m
.45781 .99221 L
s
.55943 .99301 m
.56956 .99417 L
s
.54219 .99221 m
.55943 .99301 L
s
.53502 .99142 m
.54219 .99221 L
s
.46498 .99142 m
.45781 .99221 L
s
.51817 .99107 m
.53502 .99142 L
s
.46498 .99142 m
.48183 .99107 L
s
0 1 .52 r
.81626 1.04894 m
.82925 1.05125 L
s
.78994 1.03586 m
.81626 1.04894 L
s
.2 1 0 r
.18374 1.04894 m
.17075 1.05125 L
s
.18374 1.04894 m
.21006 1.03586 L
s
0 1 .52 r
.62592 1.00133 m
.62279 1.00066 L
s
.62592 1.00133 m
.65895 1.00705 L
s
.2 1 0 r
.37408 1.00133 m
.37721 1.00066 L
s
.34105 1.00705 m
.37408 1.00133 L
s
0 1 .52 r
.72165 1.02171 m
.72954 1.02239 L
s
.69168 1.01388 m
.72165 1.02171 L
s
.2 1 0 r
.27835 1.02171 m
.27046 1.02239 L
s
.27835 1.02171 m
.30832 1.01388 L
s
0 1 .52 r
.52974 .99128 m
.51989 .99129 L
s
.52974 .99128 m
.56813 .99415 L
s
.2 1 0 r
.47026 .99128 m
.48011 .99129 L
s
.43187 .99415 m
.47026 .99128 L
s
0 1 .16 r
.68967 1.0138 m
.70356 1.0166 L
s
.67234 1.00718 m
.68967 1.0138 L
s
.31033 1.0138 m
.29644 1.0166 L
s
.31033 1.0138 m
.32766 1.00718 L
s
.51817 .99107 m
.52189 .99154 L
s
.48183 .99107 m
.47811 .99154 L
s
.5 .99092 m
.51817 .99107 L
s
.48183 .99107 m
.5 .99092 L
s
.60942 .99878 m
.62188 1.00052 L
s
.39058 .99878 m
.37812 1.00052 L
s
.59002 .99619 m
.60942 .99878 L
s
.39058 .99878 m
.40998 .99619 L
s
.2 1 0 r
.23183 1.03332 m
.22098 1.03466 L
s
.23183 1.03332 m
.26252 1.02289 L
s
0 1 .52 r
.76817 1.03332 m
.77902 1.03466 L
s
.73748 1.02289 m
.76817 1.03332 L
s
.82925 1.05125 m
.84229 1.05345 L
s
.80091 1.0369 m
.82925 1.05125 L
s
.2 1 0 r
.17075 1.05125 m
.15771 1.05345 L
s
.17075 1.05125 m
.19909 1.0369 L
s
0 1 .16 r
.5 .99092 m
.5 .99129 L
s
.70356 1.0166 m
.71749 1.0194 L
s
.29644 1.0166 m
.28251 1.0194 L
s
.68511 1.00874 m
.70356 1.0166 L
s
.29644 1.0166 m
.31489 1.00874 L
s
.2 1 0 r
.30832 1.01388 m
.30387 1.01381 L
s
.30832 1.01388 m
.34105 1.00705 L
s
0 1 .52 r
.69168 1.01388 m
.69613 1.01381 L
s
.65895 1.00705 m
.69168 1.01388 L
s
.65895 1.00705 m
.65963 1.00652 L
s
.2 1 0 r
.34105 1.00705 m
.34037 1.00652 L
s
0 1 .52 r
.58168 .99535 m
.57493 .99477 L
s
.58168 .99535 m
.61963 .99989 L
s
.2 1 0 r
.41832 .99535 m
.42507 .99477 L
s
.38037 .99989 m
.41832 .99535 L
s
0 1 .16 r
.56956 .99417 m
.57976 .99523 L
s
.54941 .99283 m
.56956 .99417 L
s
.43044 .99417 m
.42024 .99523 L
s
.43044 .99417 m
.45059 .99283 L
s
0 1 .52 r
.51989 .99129 m
.50997 .99133 L
s
.51989 .99129 m
.56127 .99348 L
s
.2 1 0 r
.48011 .99129 m
.49003 .99133 L
s
.43873 .99348 m
.48011 .99129 L
s
0 1 .16 r
.54219 .99221 m
.54941 .99283 L
s
.52189 .99154 m
.54219 .99221 L
s
.45781 .99221 m
.45059 .99283 L
s
.45781 .99221 m
.47811 .99154 L
s
0 1 .52 r
.72954 1.02239 m
.73748 1.02289 L
s
.69613 1.01381 m
.72954 1.02239 L
s
.2 1 0 r
.27046 1.02239 m
.26252 1.02289 L
s
.27046 1.02239 m
.30387 1.01381 L
s
0 1 .52 r
.62279 1.00066 m
.61963 .99989 L
s
.62279 1.00066 m
.65963 1.00652 L
s
.2 1 0 r
.37721 1.00066 m
.38037 .99989 L
s
.34037 1.00652 m
.37721 1.00066 L
s
0 1 .16 r
.69795 1.01025 m
.71749 1.0194 L
s
.28251 1.0194 m
.30205 1.01025 L
s
.37812 1.00052 m
.3656 1.00223 L
s
.37812 1.00052 m
.39965 .99706 L
s
.62188 1.00052 m
.6344 1.00223 L
s
.60035 .99706 m
.62188 1.00052 L
s
0 1 .52 r
.84229 1.05345 m
.85539 1.05553 L
s
.81195 1.0378 m
.84229 1.05345 L
s
.2 1 0 r
.15771 1.05345 m
.14461 1.05553 L
s
.15771 1.05345 m
.18805 1.0378 L
s
0 1 .52 r
.77902 1.03466 m
.78994 1.03586 L
s
.74548 1.0232 m
.77902 1.03466 L
s
.2 1 0 r
.22098 1.03466 m
.21006 1.03586 L
s
.22098 1.03466 m
.25452 1.0232 L
s
0 1 .16 r
.52189 .99154 m
.52565 .99179 L
s
.47811 .99154 m
.47435 .99179 L
s
.5 .99129 m
.52189 .99154 L
s
.47811 .99154 m
.5 .99129 L
s
.42024 .99523 m
.40998 .99619 L
s
.42024 .99523 m
.44331 .99328 L
s
.57976 .99523 m
.59002 .99619 L
s
.55669 .99328 m
.57976 .99523 L
s
0 1 .52 r
.57493 .99477 m
.56813 .99415 L
s
.57493 .99477 m
.61644 .99903 L
s
.2 1 0 r
.42507 .99477 m
.43187 .99415 L
s
.38356 .99903 m
.42507 .99477 L
s
0 1 .52 r
.50997 .99133 m
.5 .99139 L
s
.50997 .99133 m
.55437 .99276 L
s
.2 1 0 r
.49003 .99133 m
.5 .99139 L
s
.44563 .99276 m
.49003 .99133 L
s
0 1 .52 r
.69613 1.01381 m
.70061 1.01355 L
s
.65963 1.00652 m
.69613 1.01381 L
s
.2 1 0 r
.30387 1.01381 m
.29939 1.01355 L
s
.30387 1.01381 m
.34037 1.00652 L
s
0 1 .16 r
.6344 1.00223 m
.64699 1.00392 L
s
.3656 1.00223 m
.35301 1.00392 L
s
.61074 .99784 m
.6344 1.00223 L
s
.3656 1.00223 m
.38926 .99784 L
s
0 1 .52 r
.65963 1.00652 m
.6603 1.00584 L
s
.2 1 0 r
.34037 1.00652 m
.3397 1.00584 L
s
0 1 .16 r
.5 .99129 m
.5 .99141 L
s
.54941 .99283 m
.55669 .99328 L
s
.45059 .99283 m
.44331 .99328 L
s
.52565 .99179 m
.54941 .99283 L
s
.45059 .99283 m
.47435 .99179 L
s
0 1 .52 r
.82306 1.03857 m
.85539 1.05553 L
s
.2 1 0 r
.14461 1.05553 m
.17694 1.03857 L
s
0 1 .52 r
.73748 1.02289 m
.74548 1.0232 L
s
.70061 1.01355 m
.73748 1.02289 L
s
.2 1 0 r
.26252 1.02289 m
.25452 1.0232 L
s
.26252 1.02289 m
.29939 1.01355 L
s
0 1 .52 r
.61963 .99989 m
.61644 .99903 L
s
.61963 .99989 m
.6603 1.00584 L
s
.2 1 0 r
.38037 .99989 m
.38356 .99903 L
s
.3397 1.00584 m
.38037 .99989 L
s
0 1 .52 r
.78994 1.03586 m
.80091 1.0369 L
s
.75353 1.02334 m
.78994 1.03586 L
s
.2 1 0 r
.21006 1.03586 m
.19909 1.0369 L
s
.21006 1.03586 m
.24647 1.02334 L
s
0 1 .16 r
.64699 1.00392 m
.65964 1.00557 L
s
.6212 .99851 m
.64699 1.00392 L
s
.35301 1.00392 m
.34036 1.00557 L
s
.35301 1.00392 m
.3788 .99851 L
s
.40998 .99619 m
.39965 .99706 L
s
.40998 .99619 m
.43598 .99356 L
s
.59002 .99619 m
.60035 .99706 L
s
.56402 .99356 m
.59002 .99619 L
s
0 1 .52 r
.5 .99139 m
.54742 .99198 L
s
.2 1 0 r
.45258 .99198 m
.5 .99139 L
s
0 1 .52 r
.56813 .99415 m
.56127 .99348 L
s
.56813 .99415 m
.61323 .99806 L
s
.2 1 0 r
.43187 .99415 m
.43873 .99348 L
s
.38677 .99806 m
.43187 .99415 L
s
0 1 .16 r
.52565 .99179 m
.52944 .99182 L
s
.47435 .99179 m
.47056 .99182 L
s
.5 .99141 m
.52565 .99179 L
s
.47435 .99179 m
.5 .99141 L
s
0 1 .52 r
.70061 1.01355 m
.70512 1.01311 L
s
.6603 1.00584 m
.70061 1.01355 L
s
.2 1 0 r
.29939 1.01355 m
.29488 1.01311 L
s
.29939 1.01355 m
.3397 1.00584 L
s
0 1 .52 r
.6603 1.00584 m
.66098 1.00501 L
s
.2 1 0 r
.3397 1.00584 m
.33902 1.00501 L
s
0 1 .16 r
.5 .99141 m
.5 .99129 L
s
.55669 .99328 m
.56402 .99356 L
s
.44331 .99328 m
.43598 .99356 L
s
.52944 .99182 m
.55669 .99328 L
s
.44331 .99328 m
.47056 .99182 L
s
0 1 .52 r
.74548 1.0232 m
.75353 1.02334 L
s
.70512 1.01311 m
.74548 1.0232 L
s
.2 1 0 r
.25452 1.0232 m
.24647 1.02334 L
s
.25452 1.0232 m
.29488 1.01311 L
s
0 1 .16 r
.65964 1.00557 m
.67234 1.00718 L
s
.63173 .99908 m
.65964 1.00557 L
s
.34036 1.00557 m
.32766 1.00718 L
s
.34036 1.00557 m
.36827 .99908 L
s
0 1 .52 r
.80091 1.0369 m
.81195 1.0378 L
s
.76163 1.02333 m
.80091 1.0369 L
s
.2 1 0 r
.19909 1.0369 m
.18805 1.0378 L
s
.19909 1.0369 m
.23837 1.02333 L
s
.38356 .99903 m
.38677 .99806 L
s
.33902 1.00501 m
.38356 .99903 L
s
0 1 .52 r
.61644 .99903 m
.61323 .99806 L
s
.61644 .99903 m
.66098 1.00501 L
s
0 1 .16 r
.60035 .99706 m
.61074 .99784 L
s
.57141 .99368 m
.60035 .99706 L
s
.39965 .99706 m
.38926 .99784 L
s
.39965 .99706 m
.42859 .99368 L
s
0 1 .52 r
.56127 .99348 m
.55437 .99276 L
s
.56127 .99348 m
.60998 .99698 L
s
.2 1 0 r
.43873 .99348 m
.44563 .99276 L
s
.39002 .99698 m
.43873 .99348 L
s
0 1 .16 r
.67234 1.00718 m
.68511 1.00874 L
s
.64232 .99956 m
.67234 1.00718 L
s
.32766 1.00718 m
.31489 1.00874 L
s
.32766 1.00718 m
.35768 .99956 L
s
.52944 .99182 m
.53326 .99164 L
s
.47056 .99182 m
.46674 .99164 L
s
.5 .99129 m
.52944 .99182 L
s
.47056 .99182 m
.5 .99129 L
s
0 1 .52 r
.70512 1.01311 m
.70966 1.01251 L
s
.66098 1.00501 m
.70512 1.01311 L
s
.2 1 0 r
.29488 1.01311 m
.29034 1.01251 L
s
.29488 1.01311 m
.33902 1.00501 L
s
0 1 .16 r
.56402 .99356 m
.57141 .99368 L
s
.53326 .99164 m
.56402 .99356 L
s
.43598 .99356 m
.42859 .99368 L
s
.43598 .99356 m
.46674 .99164 L
s
0 1 .52 r
.66098 1.00501 m
.66165 1.00403 L
s
.2 1 0 r
.33902 1.00501 m
.33835 1.00403 L
s
0 1 .52 r
.81195 1.0378 m
.82306 1.03857 L
s
.76979 1.02315 m
.81195 1.0378 L
s
.2 1 0 r
.18805 1.0378 m
.17694 1.03857 L
s
.18805 1.0378 m
.23021 1.02315 L
s
0 1 .52 r
.75353 1.02334 m
.76163 1.02333 L
s
.70966 1.01251 m
.75353 1.02334 L
s
.2 1 0 r
.24647 1.02334 m
.23837 1.02333 L
s
.24647 1.02334 m
.29034 1.01251 L
s
0 1 .16 r
.5 .99129 m
.5 .99095 L
s
.61074 .99784 m
.6212 .99851 L
s
.38926 .99784 m
.3788 .99851 L
s
.57885 .99365 m
.61074 .99784 L
s
.38926 .99784 m
.42115 .99365 L
s
.2 1 0 r
.38677 .99806 m
.39002 .99698 L
s
.33835 1.00403 m
.38677 .99806 L
s
0 1 .52 r
.61323 .99806 m
.60998 .99698 L
s
.61323 .99806 m
.66165 1.00403 L
s
0 1 .16 r
.68511 1.00874 m
.69795 1.01025 L
s
.31489 1.00874 m
.30205 1.01025 L
s
.65297 .99994 m
.68511 1.00874 L
s
.31489 1.00874 m
.34703 .99994 L
s
.2 1 0 r
.44563 .99276 m
.45258 .99198 L
s
.39329 .99579 m
.44563 .99276 L
s
0 1 .52 r
.55437 .99276 m
.54742 .99198 L
s
.55437 .99276 m
.60671 .99579 L
s
.778 1.02283 m
.82306 1.03857 L
s
.2 1 0 r
.17694 1.03857 m
.222 1.02283 L
s
0 1 .16 r
.53326 .99164 m
.53711 .99127 L
s
.46674 .99164 m
.46289 .99127 L
s
.5 .99095 m
.53326 .99164 L
s
.46674 .99164 m
.5 .99095 L
s
.57141 .99368 m
.57885 .99365 L
s
.42859 .99368 m
.42115 .99365 L
s
.53711 .99127 m
.57141 .99368 L
s
.42859 .99368 m
.46289 .99127 L
s
0 1 .52 r
.70966 1.01251 m
.71423 1.01174 L
s
.66165 1.00403 m
.70966 1.01251 L
s
.2 1 0 r
.29034 1.01251 m
.28577 1.01174 L
s
.29034 1.01251 m
.33835 1.00403 L
s
0 1 .16 r
.6212 .99851 m
.63173 .99908 L
s
.58634 .99348 m
.6212 .99851 L
s
.3788 .99851 m
.36827 .99908 L
s
.3788 .99851 m
.41366 .99348 L
s
.66369 1.00022 m
.69795 1.01025 L
s
.30205 1.01025 m
.33631 1.00022 L
s
0 1 .52 r
.76163 1.02333 m
.76979 1.02315 L
s
.71423 1.01174 m
.76163 1.02333 L
s
.2 1 0 r
.23837 1.02333 m
.23021 1.02315 L
s
.23837 1.02333 m
.28577 1.01174 L
s
0 1 .52 r
.66165 1.00403 m
.66233 1.00291 L
s
.2 1 0 r
.33835 1.00403 m
.33767 1.00291 L
s
0 1 .16 r
.5 .99095 m
.5 .9904 L
s
0 1 .52 r
.60998 .99698 m
.60671 .99579 L
s
.60998 .99698 m
.66233 1.00291 L
s
.2 1 0 r
.39002 .99698 m
.39329 .99579 L
s
.33767 1.00291 m
.39002 .99698 L
s
.39659 .99449 m
.45258 .99198 L
s
0 1 .52 r
.54742 .99198 m
.60341 .99449 L
s
0 1 .16 r
.63173 .99908 m
.64232 .99956 L
s
.36827 .99908 m
.35768 .99956 L
s
.59389 .99315 m
.63173 .99908 L
s
.36827 .99908 m
.40611 .99315 L
s
.57885 .99365 m
.58634 .99348 L
s
.42115 .99365 m
.41366 .99348 L
s
.54099 .99071 m
.57885 .99365 L
s
.42115 .99365 m
.45901 .99071 L
s
.46289 .99127 m
.45901 .99071 L
s
.46289 .99127 m
.5 .9904 L
s
.53711 .99127 m
.54099 .99071 L
s
.5 .9904 m
.53711 .99127 L
s
0 1 .52 r
.76979 1.02315 m
.778 1.02283 L
s
.71884 1.01082 m
.76979 1.02315 L
s
.2 1 0 r
.23021 1.02315 m
.222 1.02283 L
s
.23021 1.02315 m
.28116 1.01082 L
s
.28577 1.01174 m
.28116 1.01082 L
s
.28577 1.01174 m
.33767 1.00291 L
s
0 1 .52 r
.71423 1.01174 m
.71884 1.01082 L
s
.66233 1.00291 m
.71423 1.01174 L
s
.2 1 0 r
.33767 1.00291 m
.33699 1.00164 L
s
0 1 .52 r
.66233 1.00291 m
.66301 1.00164 L
s
0 1 .16 r
.5 .9904 m
.5 .98965 L
s
0 1 .52 r
.60671 .99579 m
.60341 .99449 L
s
.60671 .99579 m
.66301 1.00164 L
s
.2 1 0 r
.39329 .99579 m
.39659 .99449 L
s
.33699 1.00164 m
.39329 .99579 L
s
0 1 .16 r
.64232 .99956 m
.65297 .99994 L
s
.35768 .99956 m
.34703 .99994 L
s
.6015 .99269 m
.64232 .99956 L
s
.35768 .99956 m
.3985 .99269 L
s
.58634 .99348 m
.59389 .99315 L
s
.5449 .98996 m
.58634 .99348 L
s
.41366 .99348 m
.40611 .99315 L
s
.41366 .99348 m
.4551 .98996 L
s
0 1 .52 r
.72347 1.00974 m
.778 1.02283 L
s
.2 1 0 r
.222 1.02283 m
.27653 1.00974 L
s
0 1 .16 r
.54099 .99071 m
.5449 .98996 L
s
.45901 .99071 m
.4551 .98996 L
s
.5 .98965 m
.54099 .99071 L
s
.45901 .99071 m
.5 .98965 L
s
0 1 .52 r
.71884 1.01082 m
.72347 1.00974 L
s
.66301 1.00164 m
.71884 1.01082 L
s
.2 1 0 r
.28116 1.01082 m
.27653 1.00974 L
s
.28116 1.01082 m
.33699 1.00164 L
s
0 1 .52 r
.66301 1.00164 m
.66369 1.00022 L
s
.2 1 0 r
.33699 1.00164 m
.33631 1.00022 L
s
0 1 .52 r
.60341 .99449 m
.66369 1.00022 L
s
.2 1 0 r
.33631 1.00022 m
.39659 .99449 L
s
0 1 .16 r
.5 .98965 m
.5 .98871 L
s
.34703 .99994 m
.33631 1.00022 L
s
.34703 .99994 m
.39084 .9921 L
s
.65297 .99994 m
.66369 1.00022 L
s
.60916 .9921 m
.65297 .99994 L
s
.59389 .99315 m
.6015 .99269 L
s
.40611 .99315 m
.3985 .99269 L
s
.54885 .98905 m
.59389 .99315 L
s
.40611 .99315 m
.45115 .98905 L
s
.5449 .98996 m
.54885 .98905 L
s
.4551 .98996 m
.45115 .98905 L
s
.5 .98871 m
.5449 .98996 L
s
.4551 .98996 m
.5 .98871 L
s
0 1 .52 r
.66369 1.00022 m
.72347 1.00974 L
s
.2 1 0 r
.27653 1.00974 m
.33631 1.00022 L
s
0 1 .16 r
.33631 1.00022 m
.38313 .99137 L
s
.61687 .99137 m
.66369 1.00022 L
s
.5 .98871 m
.5 .98758 L
s
.3985 .99269 m
.39084 .9921 L
s
.3985 .99269 m
.44718 .98797 L
s
.6015 .99269 m
.60916 .9921 L
s
.55282 .98797 m
.6015 .99269 L
s
.54885 .98905 m
.55282 .98797 L
s
.45115 .98905 m
.44718 .98797 L
s
.5 .98758 m
.54885 .98905 L
s
.45115 .98905 m
.5 .98758 L
s
.5 .98758 m
.5 .98629 L
s
.60916 .9921 m
.61687 .99137 L
s
.39084 .9921 m
.38313 .99137 L
s
.55683 .98673 m
.60916 .9921 L
s
.39084 .9921 m
.44317 .98673 L
s
.55282 .98797 m
.55683 .98673 L
s
.44718 .98797 m
.44317 .98673 L
s
.5 .98629 m
.55282 .98797 L
s
.44718 .98797 m
.5 .98629 L
s
.5 .98629 m
.5 .98482 L
s
.56087 .98534 m
.61687 .99137 L
s
.38313 .99137 m
.43913 .98534 L
s
.55683 .98673 m
.56087 .98534 L
s
.44317 .98673 m
.43913 .98534 L
s
.5 .98482 m
.55683 .98673 L
s
.44317 .98673 m
.5 .98482 L
s
.5 .98482 m
.5 .9832 L
s
.5 .9832 m
.56087 .98534 L
s
.43913 .98534 m
.5 .9832 L
s
0 g
.25 Mabswid
.096 0 m
0 .99889 L
s
0 .99889 m
1 .99889 L
s
1 .99889 m
.904 0 L
s
.904 0 m
.096 0 L
s
0 .99889 m
.08264 1.47515 L
s
.00235 1.01241 m
.01172 1.01241 L
s
gsave
-0.01639 1.01241 -71.5625 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02465 1.14096 m
.03402 1.14096 L
s
gsave
.00591 1.14096 -71.3125 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.438 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.04505 1.25847 m
.05441 1.25847 L
s
gsave
.02631 1.25847 -68.0625 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.06376 1.36632 m
.07313 1.36632 L
s
gsave
.04502 1.36632 -67.875 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.081 1.46565 m
.09037 1.46565 L
s
gsave
.06226 1.46565 -68.125 -7.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.00697 1.03907 m
.0126 1.03907 L
s
.01152 1.06525 m
.01714 1.06525 L
s
.01597 1.09094 m
.0216 1.09094 L
s
.02035 1.11618 m
.02597 1.11618 L
s
.02888 1.16529 m
.0345 1.16529 L
s
.03303 1.1892 m
.03865 1.1892 L
s
.0371 1.2127 m
.04272 1.2127 L
s
.04111 1.23578 m
.04673 1.23578 L
s
.04892 1.28078 m
.05454 1.28078 L
s
.05272 1.3027 m
.05834 1.3027 L
s
.05646 1.32427 m
.06208 1.32427 L
s
.06014 1.34547 m
.06576 1.34547 L
s
.06732 1.38684 m
.07294 1.38684 L
s
.07082 1.40702 m
.07644 1.40702 L
s
.07427 1.42688 m
.07989 1.42688 L
s
.07766 1.44642 m
.08328 1.44642 L
s
gsave
-0.06739 1.25847 -68 -7.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 15.375 translate 1 -1 scale
63.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
66.000 9.000 moveto
%%IncludeResource: font Futura-Oblique
%%IncludeFont: Futura-Oblique
/Futura-Oblique findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  FormatType->StandardForm,
  ImageSize->{157, 231.562},
  ImageMargins->{{75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002M0000ia000`40O003h00OWGoo002MOol009eo
o`00WGoo002MOol009eoo`00WGoo002MOol009eoo`00WGoo002MOol009eoo`00WGoo002MOol009eo
o`00WGoo000]OomT000<Ool002eoo`03001oogoo061oo`03001oogoo00Yoo`008goo0`0000=oo`00
Ool017oo0P00HGoo00<007ooOol02Woo000WOol00`00Oomoo`03Ool00`00Oomoo`1POol00`00Oomo
o`0:Ool002Moo`03001oogoo00=oo`03001oogoo061oo`03001oogoo00Yoo`009goo00<007ooOol0
0goo00<007ooOol0H7oo00<007ooOol02Woo000/Ool3001POol00`00Ool0000;Ool002aoo`03001o
o`00061oo`03001oo`0000]oo`00;7oo00<007oo0000H7oo00<007oo00002goo000/Ool00`00Ool0
001POol00`00Ool0000;Ool002aoo`03001oo`00061oo`03001oo`0000]oo`00;7oo0`00H7oo00<0
07oo00002goo000/Ool00`00Ool0001POol00`00Ool0000;Ool002aoo`03001oo`00061oo`03001o
o`0000]oo`00;7oo00<007oo0000H7oo00<007oo00002goo000/Ool200000goo001oo`1MOol01000
Oomoo`002goo000/Ool01000Oomoo`00GWoo00D007ooOomoo`0000Yoo`00:goo00D007ooOomoo`00
05ioo`05001oogooOol0000:Ool002]oo`05001oogooOol0001NOol01@00Oomoogoo00002Woo000[
Ool20002Ool00`00Oomoo`1LOol01@00Oomoogoo00002Woo000[Ool01@00Oomoogoo0000GWoo00D0
07ooOomoo`0000Yoo`00:goo00D007ooOomoo`0005ioo`05001oogooOol0000:Ool002]oo`05001o
ogooOol0001NOol01@00Oomoogoo00002Woo000LOol50002Ool30005Ool01@00Oomoogoo0000GWoo
00D007ooOomoo`0000Yoo`007goo00<007oo00000goo00<007ooOol00goo0P000goo00<007ooOol0
FWoo00<007ooOol00Woo00<007ooOol027oo000OOol00`00Ool00002Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`1JOol00`00Oomoo`02Ool00`00Oomoo`08Ool0021oo`8000=oo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo05Yoo`03001oogoo00=oo`03001oogoo00Moo`00:goo
00<007ooOol00Woo00<007ooOol0FWoo00<007ooOol00goo00<007ooOol01goo000ZOol20004Ool0
0`00Oomoo`1JOol00`00Oomoo`03Ool00`00Oomoo`07Ool002Yoo`03001oogoo00=oo`03001oogoo
05Yoo`03001oogoo00=oo`03001oogoo00Moo`00:Woo00<007ooOol00goo00<007ooOol0FWoo00<0
07ooOol00goo00<007ooOol01goo000ZOol00`00Oomoo`03Ool00`00Oomoo`1JOol00`00Oomoo`03
Ool00`00Oomoo`07Ool002Yoo`03001oogoo00=oo`03001oogoo05Yoo`03001oogoo00=oo`03001o
ogoo00Moo`00:Woo0P001Goo00<007ooOol0F7oo00<007ooOol017oo00<007ooOol01goo000ZOol0
0`00Oomoo`04Ool00`00Oomoo`1HOol00`00Oomoo`04Ool00`00Oomoo`07Ool002Yoo`03001oogoo
00Aoo`03001oogoo05Qoo`03001oogoo00Aoo`03001oogoo00Moo`00:Woo00<007ooOol017oo00<0
07ooOol0F7oo00<007ooOol01Goo00<007ooOol01Woo000ZOol00`00Oomoo`04Ool00`00Oomoo`0[
Ool00bDYOomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`06Ool002Yoo`03001oogoo00Aoo`03001o
ogoo02]oo`039BUoogoo02Yoo`03001oogoo00Eoo`03001oogoo00Ioo`00:Goo00<007ooOol01Goo
00<007ooOol0:goo00<U:GooOol0:Woo00<007ooOol01Goo00<007ooOol01Woo000YOol00`00Oomo
o`05Ool00`00Oomoo`0[Ool00bDYOomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`06Ool002Uoo`03
001oogoo00Eoo`03001oogoo02]oo`039BUoogoo02Yoo`03001oogoo00Eoo`03001oogoo00Ioo`00
:Goo00<007ooOol01Goo00<007ooOol0:goo00<U:GooOol0:Woo00<007ooOol01Goo00<007ooOol0
1Woo000YOol20007Ool00`00Oomoo`0ZOol00bDYOomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`06
Ool002Uoo`03001oogoo00Ioo`03001oogoo02Yoo`039BUoogoo02Uoo`03001oogoo00Ioo`03001o
ogoo00Ioo`00:Goo00<007ooOol01Woo00<007ooOol0:Woo00<U:GooOol0:Goo00<007ooOol01Woo
00<007ooOol01Woo000YOol00`00Oomoo`06Ool00`00Oomoo`0ZOol00bDYOomoo`0YOol00`00Oomo
o`07Ool00`00Oomoo`05Ool0029oo`8000Eoo`03001oogoo00Ioo`03001oogoo02Yoo`039BUoogoo
02Uoo`03001oogoo00Moo`03001oogoo00Eoo`008Woo00<007oo000017oo0P001goo00<007ooOol0
:Woo00<U:GooOol0:Goo00<007ooOol01goo00<007ooOol01Goo000ROol00`00Ool00004Ool00`00
Oomoo`06Ool00`00Oomoo`0ZOol00bDYOomoo`0YOol00`00Oomoo`07Ool00`00Oomoo`05Ool002=o
o`8000=oo`03001oogoo00Moo`03001oogoo02Yoo`039BUoogoo02Uoo`03001oogoo00Moo`03001o
ogoo00Eoo`0017oo00<007ooOol08Goo00<007ooOol01goo00<007ooOol0:Woo00<U:GooOol02goo
27`05Woo00<007ooOol01goo00<007ooOol01Goo0003Ool2000<Ool00`00Oomoo`0DOol20009Ool0
0`00Oomoo`0YOol00bDYOomoo`07Ool4O003Ool00g`0Oomoo`02Ool4O00AOol00`00Oomoo`08Ool0
0`00Oomoo`05Ool000=oo`80009oo`8000=oo`03001oogoo00=oo`04001oogoo000BOol00`00Oomo
o`08Ool00`00Oomoo`0YOol00bDYOomoo`05Ool2O0000gooO01oo`02Ool7O002Ool017`0Ooml07`0
3goo00<007ooOol027oo00<007ooOol01Goo0004Ool01@00Oomoogoo00000goo00<007ooOol00Woo
0P000Woo00<007ooOol047oo00<007ooOol027oo00<007ooOol0:Goo00<U:GooOol017oo00Al07oo
Oomoo`Al00=oo`04O01oogooOol4O002Ool2O00=Ool00`00Oomoo`08Ool00`00Oomoo`05Ool0009o
o`@000Ioo`03001oogoo01Uoo`03001oogoo00Qoo`03001oogoo02Uoo`039BUoogoo00=oo`9l0005
Ooml07`0Ooml0003Ool6O002Ool00g`0Ooml0002O0000gooO01l000;Ool00`00Oomoo`08Ool00`00
Oomoo`05Ool000Aoo`80029oo`03001oogoo00Qoo`03001oogoo02Uoo`039BUoogoo009oo`04O01o
ogooO003Ool4O002Ool017`0Oomoogoo17`00goo0W`000=oog`0O0002Goo00<007ooOol02Goo00<0
07ooOol017oo0004Ool2000ROol00`00Oomoo`08Ool00`00Oomoo`0YOol01BDYOomoogooO0000Woo
0W`000Eoog`0O01oog`0009oo`il0004Ooml07ooOol2O007Ool00`00Oomoo`09Ool00`00Oomoo`04
Ool000=oo`800003Ool0000000l0015oo`8000Uoo`03001oogoo02Uoo`049BUoogooO002Ool017`0
Oomoog`00goo0g`00Woo00=l07ooOol00Woo00=l07ooOol01G`000=oog`0O0000Woo00=l07ooOol0
17oo00<007ooOol02Goo00<007ooOol017oo000XOol00`00Oomoo`08Ool00`00Oomoo`0YOol01RDY
Oomoog`0Ooml009oo`9l0004Ooml07`0Ool;O004Ool4O00017ooO01oog`01Woo00<007ooOol02Goo
00<007ooOol017oo000XOol00`00Oomoo`08Ool00`00Oomoo`0YOol01BDYOoml07ooO0000Woo00Al
07ooOoml009oo`9l00Aoo`06O01oogooOoml07oo0g`000Yoog`0Ooml07ooO01oog`0Ooml00Eoo`03
001oogoo00Uoo`03001oogoo00Aoo`009goo00<007ooOol02Woo00<007ooOol0:7oo00LU:GooO01o
og`0Ooml0003Ool00g`0Ooml0002Ool<O0000gooO01l0002Ool01g`0Ooml07ooO01oog`000=oo`03
001oogoo00Yoo`03001oogoo00Aoo`009goo00<007ooOol02Woo00<007ooOol0:7oo00HU:G`0Ooml
07ooO003Ool00g`0Ooml0002Ool2O002Ool6O003Ool4O002Ool01g`0Ooml07ooO01oog`0009oo`03
001oogoo00Yoo`03001oogoo00Aoo`009goo0P002goo00<007ooOol0:7oo00DU:G`0Ooml07oo009l
0008Ooml07ooOoml07ooO01oo`=l009oo`03O01oogoo00=l009oo`05O01oog`0O01oo`02O00027oo
O01oog`0Ooml07oo000<Ool00`00Oomoo`04Ool002Moo`03001oogoo00Yoo`03001oogoo02Qoo`03
O01oogoo009l009oo`0:O01oogooO01oog`0Ooml07ooO002Ool5O002Ool3O002Ool3O0001GooO01o
og`0Ool00W`000=oo`00Ool02goo00<007ooOol017oo000WOol00`00Oomoo`0:Ool[0003O0002`00
O0000000O00007`0001l0000O0000P000g`000@007`0000000=l0003001l0000009l0007001l0000
O00007`000000W`000<007`0000037oo00<007ooOol017oo000WOol00`00Oomoo`0:Ool00`00Oomo
o`0XOol02g`0Ooml07ooO01oog`0Ooml07ooO0000Woo00Il07ooO01oog`0Ool:O002Ool01W`0Ooml
07ooO01oo`9l0004Ooml07ooO00<Ool00`00Oomoo`04Ool002Moo`03001oogoo00Yoo`03001oogoo
02Qoo`04O01oog`0O002Ool017`0Ooml07`00Woo00=l07ooO0000Woo0W`000Eoog`0Oomoog`0009o
o`9l0003Ooml07oo009l0003Ooml07oo009l0003Ooml07oo009l00eoo`03001oogoo00=oo`009goo
0P002goo00<007ooOol0:7oo00Al07ooO01l009oo`9l0004Ooml07ooO002Ool017`0Ooml07`00Woo
1g`000Aoog`0Ooml009oo`07O01oog`0O01oog`0Ool00W`000<007`0Ool02goo00<007ooOol00goo
000WOol00`00Oomoo`0:Ool00`00Oomoo`0XOol00g`0Ooml0003O0000gooO01oo`02O002Ool00g`0
Ooml0002Ool2O00017ooO01oog`00Woo0W`000Aoog`0Ooml009oo`9l0003Ooml07oo009l0004Ooml
07ooO00;Ool00`00Oomoo`03Ool002Moo`03001oogoo00Yoo`03001oogoo02Qoo`09O01oog`0O01o
og`0Ooml07oo00=l0005Ooml07ooO01oo`02O0000gooO01l0005O0002gooO01l07`0Ooml07ooO01o
og`0Ool00W`000=oog`0O0000W`02goo00<007ooOol00goo000WOol00`00Oomoo`0:Ool00`00Oomo
o`0XOol01G`0Ooml07`0Ool00W`000=oog`0OF000WeP00=l07ePO0000geP00Ioog`0Ooml07ooO002
Ool2O0001gooO01oog`0Ooml07oo009l0003Ooml07oo009l0004001l07ooO00:Ool00`00Oomoo`03
Ool002Ioo`03001oogoo00]oo`03001oogoo02Qoo`05O01oog`0O01oo`04O0000gooOF1oo`02O002
Ool01G`0Ooml07`0Ool017`000Moog`0Ooml07ooO01oo`02O0000gooO01oo`04O0000gooO01oo`02
O00:Ool00`00Oomoo`03Ool001]oo`80009oo`<000Aoo`<000Yoo`03001oogoo02Uoo`04O01oog`0
O002OF003G`0Ooml07`0Ooml07ooO01oog`0OF1l07oo00=l0003Ooml07oo009l0004Ooml07`0Ool2
O0000gooO01oo`02O0000gooO01oo`02O0000`00O01l000:Ool00`00Oomoo`03Ool001]oo`03001o
o`0000=oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo02Uoo`05O01oog`0O01mH002O000
1WooO01l07ePO01mH0=l009mH003O01mH7`000El0003Ooml07oo00=l0003Ooml07oo009l0004Ooml
07`0Ool2O0001000O01oog`02Goo00<007ooOol00goo000KOol00`00Ool00002Ool00`00Oomoo`03
Ool00`00Oomoo`0:Ool00`00Oomoo`0YOol2O0001WooOF1oogePO01mH09l000;Ooml07`0Ooml07oo
OF1oog`0Ooml0002OF002G`0OF1mH7`0Ooml07ooO01oo`04O00017ooO01l07oo0W`000=oog`0O000
0W`02Goo00<007ooOol00goo000LOol20003Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomo
o`0YOol2O0000gooOF1oo`02OF001GooO01l07`0OF000W`00geP00Al07ePO01oo`Al0006OommH7`0
Ooml07oo0W`000Aoog`0O01oo`9l0003Ooml07`0009l0003Ooml07`000Uoo`03001oogoo00=oo`00
9Woo00<007ooOol02Woo00<007ooOol0:Goo0W`000ImH7`0O01mH7`0Ool2OF000g`0OF1l0003O000
17ePO01l07oo0W`000MmH7`0O01l07ooO01mH004O002Ool6O00017ooO01l07oo0W`02Woo00<007oo
Ool00Woo000VOol00`00Oomoo`0:Ool00`00Oomoo`0YOol2O00017ePO01mH7oo0WeP00Aoog`0O01m
H09l0008OF1l07ePOF1l07ePO01oo`El0005Ooml07ePO01oo`05O0001GooO01l07`0Ool00W`000=o
og`0O0002Woo00<007ooOol00Woo000VOol2000;Ool00`00Oomoo`0YOol2O0001GePO01mH7ooOF00
0W`000IoogePOF1mH7`0Ool;O002OF000g`0Ooml0003O00017ooO01l07oo0g`000Moog`0O01oog`0
Ooml0009Ool00`00Oomoo`02Ool002Ioo`03001oogoo00Yoo`03001oogoo02Uoo`07O01mH7ooO01m
H7ooOF000W`000MmH7`0OF1oog`0OF1l0003OF000g`0Ooml0005O0001GePO01l07`0OF000W`000Ao
og`0O01oo`9l0004Ooml07`00002O0000gooO01oo`08Ool00`00Oomoo`02Ool002Ioo`03001oogoo
00Yoo`03001oogoo02Uoo`07O01mH7ooOF1l07ePO0000WeP00Aoog`0OF1mH09l0004Ooml07`0Ool9
O0000gePO01mH003O00017ooO01l07oo0W`000Aoog`0O000009l0003Ooml07oo00Qoo`03001oogoo
009oo`009Woo00<007ooOol02Woo00<007ooOol0:7oo00@1W`?UO^1nh0Al0003OF1l07`002Il00Uo
o`03001oogoo009oo`009Goo00<007ooOol02goo00<007ooOol09Goo0`6O00Aoo`?UO01oo`=nh004
O01mH7`0Ool2O00017ePO01l07oo1G`000EmH7`0O01l07eP00Al0005OF1l07ePO01oo`02O00017oo
O01l07oo0W`000D007`0O01oog`000Uoo`03001oogoo009oo`009Goo0P0037oo00<007ooOol08Woo
0`6O0goo00@37`?UO01mH09l0006Oomnh7ePO01oog`00WeP00=l07ooO0000W`000=oog`0O0001g`0
00Aoog`0O01mH0=l0003Ooml07oo009l0004Ooml07`00002O0000gooO01oo`08Ool00`00Oomoo`02
Ool002Eoo`03001oogoo00]oo`03001oogoo021oo`81W`03Ool1Wgoo00=oo`<3i@06OF1l07`0Oomn
h7eP0WkP00=mH7ooOF001G`000=mH7`0OF000g`000=mH7`0Ool00W`000=oogePOF001W`000Yoog`0
O01l07ooO01oog`0Ooml00Uoo`03001oogoo009oo`009Goo00<007ooOol02goo00<007ooOol07Woo
0P6O0goo00<1WgooOol00Woo0`?U00ImH7`0O01nh7ePO002OF0037kPOommH7`0Ooml07ePOoml07oo
O01oo`9l0004OF1l07`0Ool2O0001WePO01mH7`0OF1oo`Il0005Ooml07`0Ooml000:Ool00`00Oomo
o`02Ool002Eoo`03001oogoo00Yoo`03001oogoo01ioo`030Imoogoo009oo`<1W`9oo`050al3i@?U
OF1oo`02O00017kPOF1nh7eP0W`000Anh7`0O01oo`9mH004O01mH7`0OF03O0001gePO01oog`0Oomm
H7oo009l009mH004OommH7ePOol6O0000gooO01oo`0:Ool00`00Oomoo`01Ool002Eoo`03001oogoo
00Yoo`03001oogoo01eoo`81W`0:Ool1W`6O0Imoo`6OOol1Wgoo0al20nD00gePOoml0002O^000geP
OommH003O^0017`0OF1mH7oo0W`000=oog`0OF000W`000EmH7`0Ooml07oo009mH007O01oog`0O01o
ogePOol00W`000Aoog`0O01oo`Al00]oo`03001oogoo005oo`009Goo00<007ooOol02Woo00<007oo
Ool077oo00@1WgooOol1W`Aoo`070Imoogoo0Il3iA_P0nD00WeP00Unh7ePO^1l07ePO01mH7`0O^00
0WeP0W`00WeP00=l07ePO0001W`000QmH7`0O01mH7`0OF1l07eP0W`000Yoog`0O01l07ooO01oog`0
Ooml00]oo`03001oogoo005oo`009Goo00<007ooOol02Woo00<007ooOol06goo00<1WgooOol00P6O
0goo0P6O0Woo00P37`6O6n1mH1_POF1l07eP0WkP0W`000AmH7ooO^1oo`9l000:OommH7`0O01mH7`0
OommH7`0Ool4O0000gePO01oo`02OF0017`0Ooml07oo0g`000Eoog`0O00007`000aoo`03001oogoo
005oo`009Goo00<007ooOol02Woo00<007ooOol06Woo00D1WgooOol1Wgoo00@1W`09Ool1W`6OOol3
7`?U0ImmH7kP009mH00;Oomnh7`0O^1l07kPOF1l07ePO01oo`02OF001W`0OF1mH7ePO01mH0=l000:
OF1l07ePOF1l07ePOoml07ooOF03O0000gooO01oo`02O0000`00O01oo`0;Ool00`00Oomoo`01Ool0
02Eoo`03001oogoo00Yoo`03001oogoo01Uoo`050Imoogoo0Imoo`020Il5Ool20Il01P<O0nDKh7kP
OF03i@9mH00<O^1l07ooO01oogePO01oog`0OF1oog`00Woo0W`000AmH7ooO01l009mH00:O01mH7`0
OF1l07ooO01oog`0OF05O0000gooO01l000=Ool00`00Oomoo`01Ool002Eoo`03001oogoo00Yoo`03
001oogoo01Uoo`070Imoo`6OOol1Wgoo0Il00goo0`6O00L37`6O6n0Kh7kPOF03i@02OF001WkPO01n
h7`0OF1nh09l0004OommH7ePO004OF03O0000gePO01oo`02O00027ePO01oog`0Ooml07ePO003OF00
1GooO01l07ooO0003Goo00<007ooOol00Goo000TOol00`00Oomoo`0;Ool00`00Oomoo`0HOol01@6O
Ool1Wgoo0Il00Woo106O0Woo00D1W`<O0nD1WgkP0081W`08OF1gh7ePO^1oog`0O^1l009mH00=O01n
h7ePO01mH7kPO01mH7ooOF1oogePOol00W`00WeP00Ml07ooO01mH7`0OF1l0002OF000g`0OF1oo`03
O0000`00Oomoo`0;Ool00`00Oomoo`01Ool002Aoo`03001oogoo00]oo`03001oogoo01Moo`030Imo
ogoo0081W`9oo`030Imoo`6O00Aoo`050Il37`?U6n1nh0020Il00gePO01nh002OF002G`0OF1l07`0
OF1oogePO^1l0002OF000g`0OF1l0002OF02O00017ooOF1l07eP0W`000EmH7`0Ooml07oo009l0004
OommH7`0Ool2O0000`00Oomoo`0;Ool00`00Oomoo`01Ool002Aoo`8000aoo`03001oogoo01Ioo`08
0Imoogoo0Imoo`6OOol1W`=oo`030Imoo`6O0081W`837`060o1gh7kP0amgh7`00WkP0WeP00Inh7`0
OF1l07ePOol2O0002WePO01mH7`0OF1oogePO01oogeP0g`000=mH7`0O0000geP00Il07ePO01oog`0
Ool2O0000goo001oo`0<Ool00`00Oomoo`01Ool002Aoo`03001oogoo00]oo`03001oogoo01Eoo`08
0Imoogoo0Imoo`6OOol1W`=oo`<1W`9oo`81W`090amnh7OPO^037`6OOF1nh7oo009mH09l0008OF1o
ogePO^1l07kPOF1l009mH005O01mH7`0O01mH002O003OF002W`0Ooml07ePO01oog`0OF1l07eP0W`0
0Woo00<007ooOol037oo0@000Goo0Goo000TOol00`00Oomoo`0;Ool00`00Oomoo`0EOol20Il00goo
0Il1W`02Ool01P6OOol1W`6OOol1W`=oo`030Il3i@<O009gh0030Il37`<O009nh008OF1l07ooO01m
H7`0OF1oo`AmH005O01mH7ePO^1oo`02OF001W`0OommH7ePO01mH09l000:OF1l07ooO01mH7`0OF1l
07ooO002Ool00`00Oomoo`0<Ool10001Ool1Ool002Aoo`03001oogoo00]oo`03001oogoo01Eoo`09
0Imoo`6OOol1Wgoo0Imoo`6O00=oo`H1W`0<6n17h7kP0Il3o0<OMn1nh7OPOF1l07kP0WeP00Al07kP
O01nh09mH005O01nh7kPO01mH002O0000gooOF1mH003O0001GePO01l07ooO0000WeP00Aoog`0OF1l
00=oo`03001oogoo00aoo`40005oo`5oo`0097oo00<007ooOol02goo00<007ooOol057oo00<1Wgoo
Ool00P6O00Ioo`6OOomoo`6OOol20Il04goo0Imoogoo0Il37gkPAn0Kh06O0o037`6OO^1gh7ePO01n
h7`0009mH006O01mH7ooOF1l07kP0WeP00Al07ePO01l009mH09l0003OF1l07`0009mH003O01mH7eP
00=mH003O01oogoo009oo`03001oogoo00aoo`40005oo`5oo`007Woo00<007ooOol00goo00<007oo
Ool02goo00<007ooOol057oo00@1Wgoo0Imoo`81W`9oo`030Imoo`6O009oo`<1W`0;0al3i@6OMn17
h1_P0nD3l0?l0ammH002O0001gkPOF1mH7`0OF1l07kP009mH004O01mH7ePO003OF02O008OF000goo
O01mH002O002OF04Ool00`00Oomoo`0<Ool10001Ool1Ool001ioo`03001oogoo00=oo`8000]oo`03
001oogoo01Eoo`080Imoo`6O0Imoo`6OOol1W`9oo`060Imoo`6OOol1Wgoo0P<O00D1WdOP6n0Kh0?U
0083l0050ammH7ePMn1nh003OF001W`0OF1mH7kPOF1nh0AmH003O01mH7`000=mH005O01mH7ePO01m
H002O00017ePO01l07oo0WeP1Goo00<007ooOol02goo0@000Goo0Goo000NOol00`00Oomoo`03Ool0
0`00Oomoo`0:Ool00`00Oomoo`0DOol00`6OOomoo`030Il01goo0Il1Wgoo0Imoo`6O009oo`<1W`04
0amnh4OP6n030nD00`?`0o`1W`03OF000gooOF1mH004OF0017`0OF1mH7kP17eP0g`000=mH7`0OF00
0g`000ImH7`0O01l07ePOol2OF05Ool00`00Oomoo`0;Ool10001Ool1Ool001ioo`03001oogoo00=o
o`03001oogoo00Yoo`03001oogoo01Aoo`<1W`07Ool1W`6OOol1Wgoo0Il00Woo00D1Wgoo0Imoo`6O
00837`09Mn17h0?UAn03i@?l0nD3o0<O00=mH003O01mH7`0009mH003O01mH7eP00AmH005O01mH7kP
O01oo`02OF03O0000gePO01l0002O00017ooOF1mH7eP1Woo00<007ooOol02goo0@000Goo0Goo000S
Ool00`00Oomoo`0;Ool00`00Oomoo`0DOol03P6OOol1W`6OOol1Wgoo0Imoo`6OOol1Wgoo0Il3Ool0
406O0am7h1_P0nD3l0?U0al3l0?l0ammH7kPOommH7`00geP00=nh7`0OF001GeP00=nh7ePOF0017eP
00El07ePOF1mH7`0009mH004OommH7ePOF06Ool00`00Oomoo`0;Ool10001Ool1Ool002=oo`03001o
ogoo00]oo`03001oogoo01Aoo`030Imoo`6O00@1W`05Ool1Wgoo0Imoo`020Il2Ool01P<O0Imgh4OP
6n1gh083i@066n03l0?l0o`1WgkP0WeP00=l07kPOF000WeP00Al07ePOF1mH09l009mH004O^1mH7`0
OF03O002OF000g`0OommH005OF06Ool00`00Oomoo`0;Ool10001Ool1Ool002=oo`03001oogoo00]o
o`03001oogoo01Aoo`030Imoo`6O0081W`05Ool1Wgoo0Imoo`020Il2Ool20Il01`<O0Im7h1_PAn03
iGeP0083i@070o`3l0?l0amnh7OPO0000WeP00=nh7ePO0000geP00Anh7ePOF1oo`9mH008O01mH7eP
O01oogePOoml009mH003OommH7oo00=mH0Ioo`03001oogoo00aoo`40005oo`008goo0P0037oo00<0
07ooOol04goo00<1WgooOol00`6O00=oo`6O0Il00P6O00Qoo`6OOol1Wgoo0Il37dOP0a_P00<3l0?U
0nD00P?U0P?`00@3o7ePMn1l009mH003O^1mH7`000AmH09l0004OF1nh7ePO003OF001GooOF1l07eP
Ool00WeP00AoogePOF1mH0Moo`03001oogoo00aoo`40005oo`008goo00<007ooOol02goo00<007oo
Ool04goo00L1Wgoo0Il1Wgoo0Imoo`020Il017oo0Il1Wgoo0P6O01Qoo`6OAn0Kh4OP6n17h0?U6n03
i@6O0nD3l0?l0o03o7OPO^1mH7kPOF1l07ePO^03OF0017`0OF1nh7eP0W`000=oogePO00017eP00Eo
ogePOF1mH7oo009mH0Moo`03001oogoo00aoo`40005oo`008goo00<007ooOol02goo00<007ooOol0
4goo106O00Ioo`6O0Imoo`6OOol20Il01Goo0Imoo`6OOol00WOP00<Kh0?`An000TOP00D3i@?l0o`3
o1_P00837`06OF1oogkPO^1mH7`017eP0W`000EmH7kPOF1mH7`0009mH003OommH7oo00=mH004Oomm
H7ePOol2OF07Ool00`00Oomoo`0<Ool10001Ool002=oo`03001oogoo00]oo`03001oogoo01=oo`03
0Imoo`6O00@1W`03Ool1Wgoo00@1W`09Ool1Wa_P6n03iDOP0nE7h0?`00<Kh0030o`3i@?U0083i@04
0o1mH7ePOol2OF002W`0OF1mH7ePO01mH7kPOF1nh7oo0WeP00EoogePOommH7oo00MmH0Qoo`03001o
ogoo00aoo`40005oo`008goo00<007ooOol02goo00<007ooOol04goo00D1Wgoo0Il1Wgoo00D1W`07
Ool1W`6OOol1Wa_PMn000`?U00<Kh7kP6n000P?U00@3l0?U0o`3l0<3i@040o1oogePO^04OF02O^00
1WePO^1mH7kPOF1nh09mH003OommH7oo009mH004OommH7ePOol2OF08Ool00`00Oomoo`0<Ool10001
Ool002=oo`03001oogoo00]oo`03001oogoo01=oo`050Imoo`6O0Imoo`020Il00goo0Il1W`030Il0
0gooAn0Kh0026n020nD26n050nD00`?`0nD3i@030o000`?lO^1mH002OF03O^02OF02O^001gePOomm
H7ePOommH7oo009mH003OommH7eP009oo`9mH0Qoo`03001oogoo00aoo`40005oo`008Woo0P003Goo
00<007ooOol057oo0`6O00Aoo`6O0Imoo`81W`04Ool1W`6O0Il26n020nD00dOP0nD3i@0;0nD20o00
0`?lO^1nh004OF000gkPOF1nh004OF000gooOF1oo`02OF000gooOF1mH002Ool2OF09Ool00`00Oomo
o`0<Ool10001Ool002=oo`03001oogoo00]oo`03001oogoo01Aoo`030Imoo`6O0081W`05Ool1W`6O
0Imoo`020Il66n000`?U0o03l0050nD26n060o001`?lOF1mH7ePOommH7oo00EmH005OommH7ooOF1o
o`02OF000gooOF1oo`02OF0:Ool00`00Oomoo`0<Ool10001Ool0029oo`03001oogoo00]oo`03001o
ogoo01Eoo`030Imoo`6O0081W`04Ool1W`6OOol20Il40nD26n000dOP0nDKh0026n040nD00`?`0nD3
i@020o050nD00gkPOF1mH002OF000gkPOF1mH002O^0017ePOommH7oo0WeP00IoogePOommH7ooOF0;
Ool00`00Oomoo`0;Ool10001Ool0029oo`03001oogoo00]oo`03001oogoo01Eoo`T1W`036n17h1_P
008Kh083i@036n03i@?U00d3i@<3l0030o`3iGkP00Qnh09mH009OommH7ePOommH7ooOF1oogeP00ao
o`03001oogoo00aoo`4000008Woo00<007ooOol02goo00<007ooOol05Goo00<1Wgoo0Il00P6O00=o
o`6O0Il02A_P00<3l0?U0nD020?U00<3l1_P0o0020?`0WeP00=nh7ePOol00WeP00MoogePOF1mH7oo
OF1oo`03OF0=Ool00`00Oomoo`0<Ool10000029oo`03001oogoo00]oo`03001oogoo01Ioo`030Imo
o`6O0081W`03Oom7h4OP00DKh0@3i@030o03i@?U00/3i@D3l083o0030o1nh7eP00MmH003OommH7oo
009mH0moo`03001oogoo00aoo`4000008Woo0P0037oo00<007ooOol05Woo00D1Wgoo0Il1WdOP02<3
i@07O^1mH7ePOF1oogePOol00WeP00=oogePOF0047oo00<007ooOol037oo0@00000ROomk000001Mo
o`<00003Ool0000000Eoo`03001oogoo00]oo`03001oogoo019oo`XKh0070nDKh7kPAn1nh4OPMn00
0TOP00=gh7kPOF0017kP1P6O00H37`6O0Il37`?l0Il20o`20o000`?U0o03l0070o02OF0BOol00`00
Oomoo`0<Ool1000001aoo`03001oogoo00=oo`8000aoo`03001oogoo00eoo`TKh0050nDKh4OPAn0K
h004An03O^002TOPO^1nh7OPO^1mH7OPO^1gh7kP0`6O00D37`6O0Il37`6O00837`030Il37`6O00<3
o0040Il3l0?l0o`20nD90o0?Ool00`00Oomoo`0<Ool1000001eoo`03001oogoo009oo`03001oogoo
00]oo`03001oogoo00Uoo`PKh083i@8Kh003An0Kh4OP0097h003Mn1nh4OP00=gh0=7h003O^1gh7OP
009nh09gh09nh081W`040al1W`6O0Il40al20o`20al0106O0o`3o0<O0`?l0P?`00@3i@?`0o03i@T3
l0Yoo`03001oogoo00aoo`40000077oo0P001Goo00<007ooOol02Woo00<007ooOol01Woo31_P00=7
h0?UAn0014OP0WOP00A7h7OPO^1gh0=7h004O^1gh7OPMn02O^02Mn03O^00106O0al1W`6O0`<O00<1
W`<O0al00`?l00<1W`<O0o`00P<O0P?l00H37`?l0o`3o0?U0o`<0o07Ool00`00Oomoo`0;Ool10001
Ool002=oo`03001oogoo00Yoo`03001oogoo00=oo`/Kh097h08Kh0=7h0086n17h4OPAn1gh7kPMn1n
h097h0=gh006O^1gh7kPMn1nh7OP0WkP00H1WgOPO^037`6O0al20Il00`<O0Il37`030al30o`00`6O
0al1W`020al60o`20o020o`;0o05Ool00`00Oomoo`0;Ool10001Ool002=oo`03001oogoo00Yoo`04
001oogooOol86n0<An02Mn000dOPO^1nh004Mn02O^02Mn03O^02Mn000gkPOF1nh002Mn000`<O0Il3
7`040al00`6O0al37`080al01@6O0al1W`?l0al030?l20?`0goo00<007ooOol02goo0@000Goo000S
Ool00`00Oomoo`0:Ool00`00Oomoo`066n04An026n000dOP6n17h005An001A_PMn17h7OPAn0017OP
00Anh4OPMn1nh0Igh003O^1gh7kP009gh0<37`81W`<37`040Il37`<O0Il20al20Il30al010?l0al3
o0?l0`<O1@?l00<3l0?l0o0010?l1P?`0Woo00<007ooOol02goo0@000Goo000SOol2000;Ool01000
OolKh7oo0a_P0dOP00@Kh4OP6n0Kh097h09gh0=7h0036n17h7OP009gh003An1gh7OP009gh003O^1g
h7OP009nh005Mn1nh7ooMn01W`02Mn001GkPMn1gh7OPO^000P<O00L1W`<O0amnh06O0amnh0020al0
0`6O0al37`050al00`?l0al37`070o`01@<O0o`3o0?l0o000P?l00<3l0?l0o`00`?`00Aoo`?`Ool0
00eoo`40005oo`008goo00<007ooOol02Goo00<007oo6n000Q_P00=7h1_P6n000TOP00<Kh4OPAn00
1dOP00=gh4OPMn000TOP0gOP00=7h7kPMn000WOP00Anh7OPMn1gh09nh005Mn1nh7OPMn1nh003Mn02
O^020al20Il20al017kP0Il37`6O0P<O00<1W`<O0al00`<O00<3o0<O0al00P<O00@3o0<O0al37`T3
o0030o03o0?l0083l0060o`3l0?`0o1oo`002goo0@000Goo0Goo000TOol00`00Oomoo`08Ool01000
OolKh4OP0Q_P0TOP00@Kh4OPAn0Kh097h0046n1gh4OPAn02Mn02An0027OPAn1gh7kPMn1nh7OPAn02
Mn02O^000gOP0Imnh002Mn0017kPMn1gh7kP0WOP0WkP00Igh7kP0al1W`<O0Il30al20Il01@<O0Il1
W`<OOol00P6O00T37`?l0al1W`<O0Il37`?l0al00P?l0P<O0P?l00H37`?l0o03o0?`0o`20o020o`2
0o0010?l0o1oo`002goo0@000Goo0Goo000TOol00`00Oomoo`08Ool00`00An0Kh002An026n03An00
1A_PAn0Kh1_PMn000TOP00Agh4OPMn17h0Agh09nh0=gh004An1nh7OPMn02O^001GOPO^1gh7OPO^00
0WOP00Anh7OPO^1gh09nh0070Il37`<O0al1W`<O0Il00P<O00@1W`<O0al1W`837`030Il3o0<O00<3
7`040Il37`<O0al20o`010<O0o`37`?l0`<O00<3l0?l0o`00`?l0`?`00@3o0?`0o`000]oo`40005o
o`5oo`0097oo00<007ooOol027oo14OP00@Kh4OPAn0Kh0Q7h004Mn17h7OPAn04Mn000gkPMn1gh003
Mn0017kPMn1gh7kP0WOP00Anh7OP0Imnh09gh005O^1gh06OMn1nh0020Il00gkP0al1W`020al01P6O
0al1WgkP0al1W`837`040Imoo`<O0al20Il30al00`6O0o`37`020al010?l0al3o0<O20?l00D3l0?l
0o`3o0?`00<3o0]oo`40005oo`5oo`0097oo00<007ooOol01goo0dOP00=oodOPAn000TOP00=oodOP
An0014OP0WOP0TOP00Egh4OPMn1gh4OP00Egh005O^1gh7OPMn1nh002Mn0017ooO^1oogkP17OP00=n
h7OP0Il00gkP0P6O00<37`6O0al00`<O00<1W`<O0Il00`<O0P6O00<37`6O0Il020<O00@3o0<O0al3
o0837`/3o004Ool3o0?l0o`:Ool10001Ool1Ool002Aoo`03001oogoo00Ioo`03An1oodOP00Q7h09g
h004An1gh4OPMn02An000gOPAn17h003Mn000dOPO^1gh002O^02Mn0017kPMn1gh7kP0WOP00Inh7OP
Mn1gh06OO^02Mn05O^030Il20al01`6O0al37`<O0Il37`6O00<37`08Ool1W`<O0amoo`6O0al1W`83
o0030al3o0<O0083o0030al3o0?l00837`030o`37`?l00L3o004Ool3o0?l0o`8Ool00`00Oomoo`01
Ool002Aoo`8000Ioo`03An1oodOP0097h004Oom7h4OPOol2An02Mn03An02Mn02An02Mn001DOPMn17
h7OPAn001GOP00=nh7OPMn000WOP00Qnh7OPMn1nh7OPOomnh7OP17kP00D1WgkPO^01WgkP00<1W`06
0al1W`6O0al1Wgoo0P<O00D1W`<O0al37`6O00D37`030o`37`?l00D37`83o0837`83o0837`83o004
Ool3o0?lOol50o`7Ool00`00Oomoo`01Ool002Eoo`03001oogoo00=oo`=7h003Oom7h4OP0097h004
Oom7h4OPOol2An000gOPAn1gh002An02Mn02An000gOPAn1gh002Mn000gooMn1nh005Mn000gkPMn1g
h003Mn0017kPMn1nh7kP0P6O1GkP106O0WkP00<37`6O0al00`<O00=oo`<O0Il01`<O00Aoo`<O0al3
7`@3o0837`83o0837`040o`37`?l0al30o`00goo0o`3o0050o`6Ool00`00Oomoo`01Ool001Yoo`<0
009oo`03001oogoo00=oo`03001oogoo00=oo`07An1oodOPAn0004OPOol00dOP00=oodOPMn000WOP
14OP00=gh4OPMn000TOP3gOP00Anh7OPO^1gh0Ynh0T1W`837`030Il37`<O00H37`81W`H37`030o`3
7`?l00837`<3o0<37`030o`37goo0083o003Ool3o0000083o003Ool3o7oo00Eoo`03001oogoo005o
o`007goo00<007ooOol00goo0P0017oo0dOP00=oodOPOol01DOP00=gh4OPMn000gOP0TOP0WOP00=7
h7OPMn001GOP00=nh7OPMn000WOP00Anh7OPMn1gh09nh09gh003Oomnh7oo00Qnh0P1W`04Ool37`<O
0al20Il?0al20o`010<O0o`3o0?l0`<O00<3o0<O0o`01@?l00<000?l0o`00P?l1Woo00<007ooOol0
0Goo000OOol00`00Oomoo`03Ool00`00Oomoo`04Ool00dOPOom7h008An03Mn03An0017OPAn17h4OP
2gOP00Qnh7OPMn1nh7ooO^1gh7oo37kP2P6O00Eoo`<O0Il37`6O00837`030Il37`6O00T37`<3o083
7`83o0<37`X3o003Ool3o7oo00Aoo`03001oogoo009oo`007goo00<007ooOol00goo00<007ooOol0
1Goo0dOP00=oodOPAn000dOP0WOP0dOP0WOP0TOP0gOP00=oogOPMn001WOP00=nh7OPMn000WOP00=n
h7OPO^002gkP17oo2P6O00<37`6O0al00`<O00<1W`<O0al01P<O0Woo0`<O0P?l00@37`?l0o`3o083
7`H3o004001oo`?l0o`6Ool00`00Oomoo`02Ool002Eoo`8000Qoo`030017h4OP00=7h09gh0E7h003
Oomgh7OP009gh003Oomgh7OP00Igh003O^1gh7OP009gh0anh0Yoo`X1W`@37`030Il37`<O00L37`06
Ool37`<O0amoo`<O10?l0P<O1`?l27oo00<007ooOol00Woo000VOol00`00Oomoo`06Ool00`00Oomo
o`02Ool017OPOomgh7oo0gOP00AoogOPMn1gh09oo`Igh003Oomgh7OP00Egh0Mnh1=oo`H1W`P37`03
Ool37`<O00@37`04Ool37`<O0al2Ool20al017oo0amoo`<O17oo00<007ooOol01goo00<007ooOol0
0Woo000VOol00`00Oomoo`05Ool00`00Oomoo`04Ool00gOPOomgh002Mn001GooMn1gh7OPOol00gOP
0Woo2GOP9Goo20<O0Woo0`<O0Woo0`<O00=oo`<O0al00P<O1Woo00<007ooOol01Woo00<007ooOol0
0Woo000VOol00`00Oomoo`05Ool00`00Oomoo`05Ool2Mn000gooMn1gh002Mn000gooMn1gh00:Mn0[
Ool<0al017oo0al37`<O0Woo0P<O1Woo00<007ooOol01Woo00<007ooOol00Woo000VOol00`00Oomo
o`05Ool00`00Oomoo`07Ool4Mn000gooMn1gh008Mn0aOol:0al00goo0al37`020al8Ool00`00Oomo
o`05Ool00`00Oomoo`03Ool002Ioo`8000Ioo`03001oogoo00]oo`Qgh3Moo`P37`aoo`03001oogoo
00Eoo`03001oogoo00=oo`009goo00<007ooOol017oo00<007ooOol0GWoo00<007ooOol01Goo00<0
07ooOol00goo000WOol00`00Oomoo`04Ool00`00Oomoo`1NOol00`00Oomoo`05Ool00`00Oomoo`03
Ool002Moo`03001oogoo00Aoo`03001oogoo05ioo`03001oogoo00Eoo`03001oogoo00=oo`009goo
00<007ooOol017oo00<007ooOol0GWoo00<007ooOol017oo00<007ooOol017oo000EOol00`00Oomo
o`08Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`1NOol00`00Oomoo`04Ool00`00Oomoo`04Ool0
01Ioo`03001oogoo00Moo`03001oo`0000Aoo`8000Eoo`03001oogoo05ioo`03001oogoo00Aoo`03
001oogoo00Aoo`005Goo0P002Goo00<007oo00001Goo00<007ooOol00goo00<007ooOol0GWoo00<0
07ooOol017oo00<007ooOol017oo000QOol20005Ool00`00Oomoo`03Ool00`00Oomoo`1NOol00`00
Oomoo`04Ool00`00Oomoo`04Ool002Qoo`03001oogoo00=oo`03001oogoo05ioo`03001oogoo00=o
o`03001oogoo00Eoo`00:7oo00<007ooOol00goo00<007ooOol0GWoo00<007ooOol00goo00<007oo
Ool01Goo000XOol20004Ool00`00Oomoo`1NOol00`00Oomoo`03Ool00`00Oomoo`05Ool002Qoo`03
001oogoo009oo`03001oogoo061oo`03001oogoo009oo`03001oogoo00Eoo`00:Goo00D007ooOomo
o`00069oo`03001oogoo009oo`03001oogoo00Eoo`00:Goo00D007ooOomoo`00069oo`03001oogoo
009oo`03001oogoo00Eoo`00:Goo00D007ooOomoo`00069oo`05001oogooOol00008Ool002Uoo`80
009oo`03001oogoo061oo`05001oogooOol00008Ool002Uoo`05001oogooOol0001ROol01@00Oomo
ogoo000027oo000SOol00`00Oomoo`04Ool01000Oomoo`00HWoo00D007ooOomoo`0000Qoo`008goo
00<007ooOol017oo0P0000=oo`00Ool0HGoo00D007ooOomoo`0000Qoo`008goo00<007ooOol017oo
00@007ooOol0069oo`04001oogoo0009Ool002=oo`03001oogoo00Aoo`800003Ool007oo065oo`04
001oogoo0009Ool002Yoo`04001oogoo001ROol01000Oomoo`002Goo000ZOol01000Oomoo`00HWoo
00@007ooOol000Uoo`00:Woo0P0000=oo`00Ool0HGoo00@007ooOol000Uoo`00:goo00<007oo0000
HWoo00<007oo00002Woo000[Ool2001TOol2000:Ool002]oo`8006Aoo`8000Yoo`00:goo0P00I7oo
0P002Woo000[Ool2001TOol2000:Ool002aoo`03001oogoo069oo`03001oogoo00Uoo`0097oo0P00
1Woo0`005goo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol05Goo00<007oo00002goo000U
Ool00`00Oomoo`04OomV000;Ool002Ioo`03001oogoo07Aoo`009Goo0P00MWoo002MOol009eoo`00
;7oo0`0000Aoo`000000015oo`D002aoo`8001Moo`03001oogoo00aoo`00<Woo00<007ooOol04goo
00<007ooOol047oo0`000Woo00<007ooOol04Woo00<007oo00005Woo00<007ooOol037oo000bOol0
0`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0BOol00`00Ool0000FOol00`00Oomoo`0<Ool0
035oo`8001Eoo`8001Ioo`03001oogoo01=oo`8001Ioo`03001oogoo00aoo`00H7oo00<007ooOol0
>Woo002MOol009eoo`00WGoo002MOol009eoo`00WGoo002MOol005eoo`8003ioo`00GWoo00<007oo
Ool0?7oo002MOol009eoo`00WGoo002MOol009eoo`00WGoo002MOol009eoo`00WGoo002MOol009eo
o`00WGoo002MOol009eoo`00WGoo002MOol009eoo`00\
\>"],
  ImageRangeCache->{{{0, 156}, {230.562, 0}} -> {-0.0214262, -0.070268, \
0.00548048, 0.00548048}}]
}, Closed]],

Cell[TextData[{
  "Note that we now have two different values for the function at the point \
",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)],
    FormatType->StandardForm],
  ". Our first value, taken straight from the original definition, was ",
  Cell[BoxData[
      \(TraditionalForm\`f(0) = 0\)],
    FormatType->StandardForm],
  ", the center of the original disk. Eight successive applications of \
analytic continuation bring us smoothly to another value for ",
  Cell[BoxData[
      \(TraditionalForm\`f(0)\)],
    FormatType->StandardForm],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\^\(2/3\)\)\)],
    FormatType->StandardForm],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[{cubeRoot[0, 0], cubeRoot[8, 0]}]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({1, \((\(-1\))\)\^\(2/3\)}\)], "Output",
  CellLabel->"Out[19]="]
}, Closed]],

Cell["\<\
By continuing the circle chain we could eventually cover all three \
sheets of the Riemann surface, returning us to our starting position.\
\>", \
"Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Singular Integrals", "Title"],

Cell[TextData[{
  "Suppose ",
  StyleBox["L",
    FontSlant->"Italic"],
  " is a closed, smooth contour enclosing the region ",
  Cell[BoxData[
      \(TraditionalForm\`\(D\^+\)\)],
    FormatType->StandardForm],
  " on the complex plane, that the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi](z)\)],
    FormatType->StandardForm],
  " is analytic over ",
  Cell[BoxData[
      \(TraditionalForm\`\(D\^+\)\)],
    FormatType->StandardForm],
  ", and that ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi](z)\)],
    FormatType->StandardForm],
  " is continuous over ",
  Cell[BoxData[
      \(TraditionalForm\`\(D\^+\) \[Union] L\)],
    FormatType->StandardForm],
  ". Then we know from the ",
  StyleBox["Cauchy integral formula",
    FontSlant->"Italic"],
  ", a basic result in the theory of functions, that"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \
\(\[ContourIntegral]\_L\(\( \[CurlyPhi] \((\[Tau])\)\)\/\(\[Tau] - 
                    z\)\) \[DifferentialD]\[Tau]\)\), "=", 
        RowBox[{
          StyleBox["{",
            SpanMinSize->4], GridBox[{
              {\(\(\[CurlyPhi] \((z)\)\)\(,\)\), \(z \[Element] \(D\^+\);\)},
              {\(\(0\)\(,\)\), \(\(z \[Element] \(D\^-\)\)\(,\)\)}
              }]}]}], TraditionalForm]], "DisplayFormula",
  ShowAutoStyles->False,
  TextAlignment->Center,
  FormatType->StandardForm,
  ZeroWidthTimes->True],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(D\^-\)\)],
    FormatType->StandardForm],
  " represents the region outside ",
  StyleBox["L",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "A more general form of this integral, removing the requirement that the \
curve ",
  StyleBox["L",
    FontSlant->"Italic"],
  " be closed, is the ",
  StyleBox["Cauchy-type integral",
    FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[CapitalPhi](
        z) = \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_L\(\( \
\[CurlyPhi] \((\[Tau])\)\)\/\(\[Tau] - 
                  z\)\) \[DifferentialD]\[Tau]\)\)\(,\)\)\)], "DisplayFormula",\

  TextAlignment->Center,
  FormatType->StandardForm,
  ZeroWidthTimes->True],

Cell[TextData[{
  "where the ",
  StyleBox["density function",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi](\[Tau])\)],
    FormatType->StandardForm],
  " is defined on the piecewise smooth contour ",
  StyleBox["L.",
    FontSlant->"Italic"],
  " The function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi](\[Tau])\)],
    FormatType->StandardForm],
  " must be continuous along ",
  StyleBox["L",
    FontSlant->"Italic"],
  ", but it must also meet a more stringent test known as the ",
  StyleBox["H\[ODoubleDot]lder condition",
    FontSlant->"Italic"],
  ". A function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi](t)\)],
    FormatType->StandardForm],
  " satisfies the H\[ODoubleDot]lder condition if, for two arbitrary points \
",
  Cell[BoxData[
      \(TraditionalForm\`t\_1, \ t\_2\)],
    FormatType->StandardForm],
  " on the curve, ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\[CurlyPhi](t\_2) - \[CurlyPhi](
              t\_1)\[RightBracketingBar] \[LessEqual] 
        A \[LeftBracketingBar]t\_2 - t\_1\[RightBracketingBar]\^\[Lambda]\)],
    FormatType->StandardForm],
  " for some positive real constants ",
  StyleBox["A",
    FontSlant->"Italic"],
  " and \[Lambda], ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Lambda] \[LessEqual] 1\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[TextData[{
  "The Cauchy-type integral is analytic everywhere on the complex plane \
except on the contour ",
  StyleBox["L",
    FontSlant->"Italic"],
  " itself, which is a ",
  StyleBox["singular line ",
    FontSlant->"Italic"],
  "for this integral. Since the integral contains a factor (called the ",
  StyleBox["kernel",
    FontSlant->"Italic"],
  ") in the form of ",
  Cell[BoxData[
      \(TraditionalForm\`1/\((\[Tau] - z)\)\)],
    FormatType->StandardForm],
  ", it diverges at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = z\)],
    FormatType->StandardForm],
  " for any ",
  StyleBox["z",
    FontSlant->"Italic"],
  " on ",
  StyleBox["L",
    FontSlant->"Italic"],
  ". Because of the nonintegrable singularity it contains, this improper \
integral is a ",
  StyleBox["singular integral",
    FontSlant->"Italic"],
  ". It can be evaluated, however, if we remove from the path of integration \
a small neighborhood around the singularity. Then the limit of the evaluation \
as the size of the neighborhood shrinks to zero is the ",
  StyleBox["Cauchy principal value ",
    FontSlant->"Italic"],
  "of this singular integral. "
}], "Text"],

Cell[TextData[{
  "For example, suppose that ",
  Cell[BoxData[
      \(TraditionalForm\`L\)],
    FormatType->StandardForm],
  " is simply a straight segment on the real axis from ",
  StyleBox["a",
    FontSlant->"Italic"],
  " to ",
  StyleBox["b",
    FontSlant->"Italic"],
  ". Rather than integrating from ",
  StyleBox["a",
    FontSlant->"Italic"],
  " through the singular point ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_0 \[Element] L\)],
    FormatType->StandardForm],
  " to the point ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", we can integrate on the intervals ",
  Cell[BoxData[
      \(TraditionalForm\`\((a, \[Tau]\_0 - \[CurlyEpsilon])\)\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Tau]\_0 + \[CurlyEpsilon], b)\)\)],
    FormatType->StandardForm],
  " for some arbitrarily small \[CurlyEpsilon], and then add these results to \
arrive at an evaluation. By taking the limit of this calculation as ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyEpsilon] \[Rule] 0\)],
    FormatType->StandardForm],
  ", we can state the principal value as"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalP]\ \(\[Integral]\_a\%b\(\( \[CurlyPhi]\
\ \((\[Tau])\)\)\/\(\[Tau] - \[Tau]\_0\)\) \[DifferentialD]\[Tau]\) = 
      lim\+\(\[CurlyEpsilon] \[Rule] \(+0\)\)\ \((\[Integral]\_a\%\(\[Tau]\_0 \
- \[CurlyEpsilon]\)\(\(\[CurlyPhi] \((\[Tau])\)\)\/\(\[Tau] - \[Tau]\_0\)\) \
\[DifferentialD]\[Tau] + \[Integral]\_\(\[CurlyEpsilon] + \[Tau]\_0\)\%b\(\( \
\[CurlyPhi] \((\[Tau])\)\)\/\(\[Tau] - \[Tau]\_0\)\) \
\[DifferentialD]\[Tau])\)\)], "DisplayFormula",
  TextAlignment->Center,
  FormatType->StandardForm,
  ZeroWidthTimes->True],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`a < \[Tau]\_0 < b\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[TextData[{
  "Here ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP] \[Integral]\)],
    FormatType->StandardForm],
  " represents the Cauchy principal value; other symbols used in the \
mathematical literature include ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\^\[Prime], \)],
    FormatType->StandardForm],
  " vp \[Integral], and the ordinary integration sign. The result can be \
generalized to singular curvilinear integrals by considering the curve ",
  StyleBox["L",
    FontSlant->"Italic"],
  " with a circular neighborhood ",
  StyleBox["l",
    FontSlant->"Italic"],
  ", with ",
  StyleBox["l",
    FontSlant->"Italic"],
  " ",
  "centered on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_0\)],
    FormatType->StandardForm],
  " and of radius \[CurlyRho], removed; then the value of the Cauchy \
principal value is"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[ScriptCapitalP]", 
        RowBox[{
          SubscriptBox["\[Integral]", 
            StyleBox["L",
              
              FontSlant->
                "Italic"]], \(\(\(\[CurlyPhi] \((\[Tau])\)\)\/\(\[Tau] - \
\[Tau]\_0\)\) \[DifferentialD]\[Tau]\)}]}], "=", 
      RowBox[{\(lim\+\(\[CurlyRho] \[Rule] 0\)\), 
        RowBox[{
          SubscriptBox["\[Integral]", 
            RowBox[{
              StyleBox["L",
                FontSlant->"Italic"], "-", 
              "l"}]], \(\(\(\[CurlyPhi] \((\[Tau])\)\)\/\(\[Tau] - \
\[Tau]\_0\)\) \[DifferentialD]\[Tau]\)}]}]}]], "DisplayFormula",
  TextAlignment->Center,
  ZeroWidthTimes->True,
  FontFamily->"Janson Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_0 \[Element] L\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["The Sokhotskii Formulas", "Section"],

Cell[TextData[{
  "When ",
  StyleBox["L",
    FontSlant->"Italic"],
  " is a closed contour and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_0 \[Element] L\)],
    FormatType->StandardForm],
  ", we define ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi](z)\)],
    FormatType->StandardForm],
  " as a piecewise analytic function where"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[CapitalPhi](z)\), "=", 
        RowBox[{
          StyleBox["{",
            SpanMaxSize->Infinity], GridBox[{
              {\(\(\(\[CapitalPhi]\^+\) \((z)\)\)\(,\)\), \(z \[Element] \
\(D\^+\);\)},
              {\(\(\(\[CapitalPhi]\^-\) \((z)\)\)\(,\)\), \(\(z \[Element] \
\(D\^-\)\)\(,\)\)}
              }]}]}], TraditionalForm]], "DisplayFormula",
  AutoStyleOptions->{"UnmatchedBracketStyle"->None},
  FormatType->StandardForm,
  FontFamily->"Janson Text"],

Cell[TextData[{
  "with a jump discontinuity as ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] \[Tau]\_0\  \[Element] L\)],
    FormatType->StandardForm],
  ". Then"
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              
              RowBox[{\(\(\[CapitalPhi]\^+\) \((\[Tau]\_0)\)\), 
                "\[AlignmentMarker]", "=", 
                RowBox[{
                  RowBox[{
                    UnderscriptBox["lim", \(z \[Rule] \[Tau]\_0\),
                      
                      LimitsPositioning->
                        False], \(\[CapitalPhi] \
\((z)\)\ \ \ \ when\ \ \ \ z\)}], "\[Element]", \(D\^+\)}]}], ";"}]},
          {
            
            RowBox[{\(\(\[CapitalPhi]\^-\) \((\[Tau]\_0)\)\), 
              "\[AlignmentMarker]", "=", 
              RowBox[{
                RowBox[{
                  UnderscriptBox["lim", \(z \[Rule] \[Tau]\_0\),
                    
                    LimitsPositioning->
                      False], \(\[CapitalPhi] \
\((z)\)\ \ \ \ when\ \ \ \ z\)}], "\[Element]", \(\(D\^-\)\(.\)\)}]}]}
          }], TraditionalForm]], "DisplayFormula",
  CellMargins->{{Inherited, 72.625}, {Inherited, Inherited}},
  TextAlignment->Center,
  FormatType->StandardForm],

Cell[TextData[{
  "If ",
  StyleBox["L",
    FontSlant->"Italic"],
  " is an open contour with endpoints ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", we can add a new arbitrary curve segment connecting ",
  StyleBox["b",
    FontSlant->"Italic"],
  " to ",
  StyleBox["a",
    FontSlant->"Italic"],
  " (with the sense that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^+\)(\[Tau])\)],
    FormatType->StandardForm],
  " corresponds to the limiting value from the left) and assign ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi](\[Tau]) = 0\)],
    FormatType->StandardForm],
  " along this new segment. This extension allows us to apply the above \
definitions for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^+\)\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^-\)\)],
    FormatType->StandardForm],
  " to open contours."
}], "Text"],

Cell[TextData[{
  "Then, according to the ",
  StyleBox["Sokhotskii formulas",
    FontSlant->"Italic"],
  ","
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\(\[CapitalPhi]\^+\)(\[Tau]\_0)\[AlignmentMarker] \
= \(\[CurlyPhi] \((\[Tau]\_0)\)\)\/2 + \(1\/\(2  \[Pi]\ \ \[ImaginaryI]\)\) \
\[ScriptCapitalP] \(\[Integral]\_L\(\( \[CurlyPhi] \((\[Tau])\)\)\/\(\[Tau] - \
\[Tau]\_0\)\) \[DifferentialD]\[Tau]\); \ \ \ \ \
\(\[CapitalPhi]\^-\)(\[Tau]\_0)\[AlignmentMarker] = \(-\(\(\[CurlyPhi] \((\
\[Tau]\_0)\)\)\/2\)\) + \(1\/\(2  \[Pi]\ \ \[ImaginaryI]\)\) \
\[ScriptCapitalP] \(\[Integral]\_L\(\( \[CurlyPhi] \((\[Tau])\)\)\/\(\[Tau] - \
\[Tau]\_0\)\) \[DifferentialD]\[Tau]\)\)\(,\)\)\)], "DisplayFormula",
  FormatType->StandardForm],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP] \[Integral]\)],
    FormatType->StandardForm],
  " represents the Cauchy principal value of the integral, as described \
above."
}], "Text"],

Cell["By adding and subtracting these two formulas, we get", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[CapitalPhi]\^+\)(\[Tau]\_0) + \
\(\[CapitalPhi]\^-\)(\[Tau]\_0)\[AlignmentMarker] = \(1\/\(\(\ \)\(\[Pi]\
\ \ \[ImaginaryI]\)\)\) \[ScriptCapitalP] \(\[Integral]\_L\(\( \[CurlyPhi] \
\((\[Tau])\)\)\/\(\[Tau] - \[Tau]\_0\)\) \[DifferentialD]\[Tau]\); \ \ \ \(\
\[CapitalPhi]\^+\)(\[Tau]\_0) - \(\[CapitalPhi]\^-\)(\[Tau]\_0) = \(\(\
\[CurlyPhi](\[Tau]\_0)\)\(.\)\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "In particular, if ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi](z)\)],
    FormatType->StandardForm],
  " is analytic over ",
  Cell[BoxData[
      \(TraditionalForm\`\(D\^+\)\)],
    FormatType->StandardForm],
  " and continuous over ",
  Cell[BoxData[
      \(TraditionalForm\`\(D\^+\)\&_\)],
    FormatType->StandardForm],
  " (that is, over ",
  Cell[BoxData[
      \(TraditionalForm\`\(D\^+\)\)],
    FormatType->StandardForm],
  " and ",
  StyleBox["L",
    FontSlant->"Italic"],
  "), then ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^+\)(\[Tau]\_0) = \[CurlyPhi](\[Tau]\
\_0)\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^-\)(\[Tau]\_0) = 0\)],
    FormatType->StandardForm],
  ". If the contour ",
  Cell[BoxData[
      \(TraditionalForm\`L\)],
    FormatType->StandardForm],
  " is a finite or infinite segment of the real axis, ",
  Cell[BoxData[
      \(TraditionalForm\`L = \((a, b)\)\)],
    FormatType->StandardForm],
  ", these formulas hold for all ",
  Cell[BoxData[
      \(TraditionalForm\`a < \[Tau]\_0 < b\)],
    FormatType->StandardForm],
  ", and so "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(\[CapitalPhi]\^+\)(\[Tau]\_0)\), 
          "\[AlignmentMarker]\[AlignmentMarker]", "=", 
          RowBox[{
            UnderscriptBox["lim", \(\[CurlyEpsilon] \[Rule] \(+0\)\),
              
              LimitsPositioning->
                False], \(\[CapitalPhi](\[Tau]\_0 + \[ImaginaryI]\
\ \ \[CurlyEpsilon])\)}]}], ",", "   ", 
        RowBox[{\(\(\[CapitalPhi]\^-\)(\[Tau]\_0)\), 
          "\[AlignmentMarker]\[AlignmentMarker]", "=", 
          RowBox[{
            UnderscriptBox["lim", \(\[CurlyEpsilon] \[Rule] \(+0\)\),
              
              LimitsPositioning->
                False], \(\(\[CapitalPhi](\[Tau]\_0 - \[ImaginaryI]\
\ \ \[CurlyEpsilon])\)\(.\)\)}]}]}], TraditionalForm]], "DisplayFormula",
  TextAlignment->Center,
  FormatType->StandardForm],

Cell[TextData[{
  "Thus ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi](z)\)],
    FormatType->StandardForm],
  " is an analytic function with a jump discontinuity at ",
  StyleBox["L",
    FontSlant->"Italic"],
  ", and the size of the jump can be determined by the Sokhotskii formulas."
}], "Text"],

Cell["\<\
The Sokhotskii formulas play a basic role in solving boundary value \
problems, problems in function theory, and singular integral equations. They \
were first derived by Yulian-Karl Sokhotskii in 1873; because they were later \
given a more rigorous treatment by J. Plemelj in 1908, they are often \
referred to as the Plemelj formulas.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Example 1", "Subsection"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[CapitalPhi](z)\), "=", 
        RowBox[{\(\(1\/\(2\ \[Pi]\ \ \[ImaginaryI]\)\) \(\[Integral]\_0\%\
\[Infinity]\( \[ExponentialE]\^\(-\[Tau]\)\/\(\[Tau] - 
                      z\)\) \[DifferentialD]\[Tau]\)\), "=", 
          
          RowBox[{\(\[ExponentialE]\^\(-z\)\/\(2\ \[Pi]\ \ \[ImaginaryI]\)\), 
            
            RowBox[{
              StyleBox["{",
                SpanMinSize->5,
                SpanMaxSize->1], GridBox[{
                  {\(\(\[Pi]\ \ \[ImaginaryI] - 
                      Ei \((z)\)\)\(,\)\), \(\(Im \((z)\) > 0\)\(,\)\)},
                  {\(\(\(-\[Pi]\)\ \ \[ImaginaryI] - 
                      Ei \((z)\)\)\(,\)\), \(\(Im \((z)\) < 0\)\(,\)\)},
                  {\(\(\(-Ei\) \((z)\)\)\(,\)\), \(Im \((z)\) = 0. \)}
                  }]}]}]}]}], TraditionalForm]], "DisplayFormula",
  Evaluatable->False,
  AutoStyleOptions->{"UnmatchedBracketStyle"->None},
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "For arbitrary ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)],
    FormatType->StandardForm],
  ", the Sokhotskii formulas give us the following:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[CapitalPhi]\^+\)(
        x)\[AlignmentMarker] = \(\(\(\[ExponentialE]\^\(-x\)\) \((\[Pi]\ \
\[ImaginaryI] - Ei \((x)\))\)\)\/\(2  \[DoubledPi]\[ImaginaryI]\) = \
\[ExponentialE]\^\(-x\)\/2 + \(\(-\[ExponentialE]\^\(-x\)\) Ei \((x)\)\)\/\(2 \
 \[Pi]\[ImaginaryI]\)\), \[IndentingNewLine]\(\[CapitalPhi]\^-\)(
        x)\[AlignmentMarker] = \(\(\(\[ExponentialE]\^\(-x\)\) \((\(-\[Pi]\)\ \
\[ImaginaryI] - Ei \((x)\))\)\)\/\(2  \[DoubledPi]\[ImaginaryI]\) = \(-\(\
\[ExponentialE]\^\(-x\)\/2\)\) + \(\(-\[ExponentialE]\^\(-x\)\) Ei \
\((x)\)\)\/\(2  \[Pi]\[ImaginaryI]\)\), \[IndentingNewLine]\(\[CapitalPhi]\^+\
\)(x) + \(\[CapitalPhi]\^-\)(
          x)\[AlignmentMarker] = \(\(1\/\[Pi]\[ImaginaryI]\) \
\[ScriptCapitalP] \(\[Integral]\_0\%\[Infinity]\( \
\[ExponentialE]\^\(-\[Tau]\)\/\(\[Tau] - 
                    x\)\) \[DifferentialD]\[Tau]\) = \
\(\(-\[ExponentialE]\^\(-x\)\) Ei \((x)\)\)\/\[Pi]\[ImaginaryI]\), \
\[IndentingNewLine]\(\[CapitalPhi]\^+\)(x) - \(\[CapitalPhi]\^-\)(
          x)\[AlignmentMarker] = \(\(\[ExponentialE]\^\(-x\)\)\(.\)\)\)], \
"DisplayFormula",
  CellMargins->{{150.562, Inherited}, {Inherited, Inherited}},
  TextAlignment->AlignmentMarker,
  FormatType->StandardForm,
  FontFamily->"Janson Text"],

Cell[TextData[{
  "Note that in this example the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi](z)\)],
    FormatType->StandardForm],
  " is analytic for ",
  Cell[BoxData[
      \(TraditionalForm\`z < 0\)],
    FormatType->StandardForm],
  ", and therefore its limit values taken from either side of the real axis \
agree with each other. This gives us"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            UnderscriptBox["lim", \(\[CurlyEpsilon] \[Rule] \(+0\)\),
              LimitsPositioning->False],
            ScriptLevel->0], 
          RowBox[{
            TagBox["",
              
              Beta], \((\[Pi]\ \ \[ImaginaryI] - 
                Ei(x + \[ImaginaryI]\ \ \[CurlyEpsilon]))\)}]}], "=", 
        RowBox[{
          RowBox[{
            StyleBox[
              UnderscriptBox["lim", \(\[CurlyEpsilon] \[Rule] \(+0\)\),
                LimitsPositioning->False],
              ScriptLevel->0], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    TagBox["",
                      Beta]}], "\[Pi]", "  ", "\[ImaginaryI]"}], 
                "-", \(Ei(x - \[ImaginaryI]\ \ \[CurlyEpsilon])\)}], ")"}]}], 
          "=", \(-\(\(Ei(x)\)\(.\)\)\)}]}], 
      TraditionalForm]], "DisplayFormula",
  Evaluatable->False,
  FormatType->StandardForm,
  FontFamily->"Janson Text",
  FontWeight->"Plain"],

Cell[TextData[{
  "This leads to the following behavior for ",
  Cell[BoxData[
      \(TraditionalForm\`Ei(x)\)],
    FormatType->StandardForm],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              UnderscriptBox["lim", \(\[CurlyEpsilon] \[Rule] \(+0\)\),
                LimitsPositioning->False],
              ScriptLevel->0], 
            RowBox[{
              TagBox["",
                Beta], \(Ei(x + \[ImaginaryI]\ \ \[CurlyEpsilon])\)}]}], 
          "=", \(Ei(x) + \[Pi]\ \ \[ImaginaryI]\)}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
            StyleBox[
              UnderscriptBox["lim", \(\[CurlyEpsilon] \[Rule] \(+0\)\),
                LimitsPositioning->False],
              ScriptLevel->0], 
            RowBox[{
              TagBox["",
                Beta], \(Ei(x - \[ImaginaryI]\ \ \[CurlyEpsilon])\)}]}], 
          "=", \(Ei(x) - \[Pi]\ \ \(\(\[ImaginaryI]\)\(.\)\)\)}]}], 
      TraditionalForm]], "DisplayFormula",
  Evaluatable->False,
  FormatType->StandardForm,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "Subsection"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[CapitalPhi](z)\), "\[AlignmentMarker]", "=", 
        RowBox[{\(\(1\/\(2  \[Pi]\ \ \[ImaginaryI]\)\) \(\[Integral]\_0\%\
\[Infinity]\( \[Tau]\^\(\[Alpha] - 1\)\/\(\[Tau] - 
                      z\)\) \[DifferentialD]\[Tau]\)\), " \[AlignmentMarker]",
           "=", 
          RowBox[{\(1\/\(2\ \[Pi]\ \ \[ImaginaryI]\)\), 
            RowBox[{
              StyleBox["{",
                SpanMinSize->4], GridBox[{
                  {\(\(\[Pi]\ \(\((\(-z\))\)\^\(\[Alpha] - 1\)\) 
                      csc \((\[Alpha]\ \ \[Pi])\)\)\(,\)\), \(0 < 
                      Re \((\[Alpha])\) < 
                      1, \(Arg \((z)\) \[NotEqual] 0;\)\)},
                  {\(\(\(-\[Pi]\)\ \ z\^\(\[Alpha] - 1\)\ cot \((\[Alpha]\
\ \ \[Pi])\)\)\(,\)\), \(0 < Re \((\[Alpha])\) < 1, z > 0. \)}
                  }]}]}]}]}], TraditionalForm]], "DisplayFormula",
  CellMargins->{{95.5, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  AutoStyleOptions->{"UnmatchedBracketStyle"->None},
  TextAlignment->AlignmentMarker,
  FormatType->StandardForm,
  ZeroWidthTimes->True,
  FontWeight->"Plain"],

Cell[TextData[{
  "For arbitrary ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)],
    FormatType->StandardForm],
  ", the Sokhotskii formulas give us the following results when we take into \
account the fact that, as ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyEpsilon] \[Rule] \(+0\)\)],
    FormatType->StandardForm],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-z\))\)\^\(\[Alpha] - 1\)\)],
    Evaluatable->False,
    FormatType->StandardForm,
    FontWeight->"Plain"],
  " is continuous for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-z\) = \(-x\) + \[ImaginaryI]\ \[CurlyEpsilon]\)],
    Evaluatable->False,
    FormatType->StandardForm,
    FontWeight->"Plain"],
  " but has a jump of size ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Alpha]\ \
\[Pi]\)\)],
    FormatType->StandardForm],
  " compared to when approached from the other side, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-z\) = \(-x\) - \[ImaginaryI]\ \[CurlyEpsilon]\)],
    FormatType->StandardForm],
  "."
}], "Text",
  Evaluatable->False,
  AutoStyleOptions->{"UnmatchedBracketStyle"->None},
  ZeroWidthTimes->True,
  FontWeight->"Plain"],

Cell[BoxData[
    \(TraditionalForm\`\(\[CapitalPhi]\^+\)(
        x)\[AlignmentMarker] = \(lim\+\(\[CurlyEpsilon] \[Rule] \
\(+0\)\)\(\(\((\(-x\) - \[ImaginaryI]\[CurlyEpsilon])\)\^\(\[Alpha] - 1\)\) \
csc \((\[Alpha]\[Pi])\)\)\/\(2  \[ImaginaryI]\) = \(\(-\(\(\(x\^\(\[Alpha] - 
                        1\)\) \(\[ExponentialE]\^\(-\[ImaginaryI]\[Alpha]\[Pi]\
\)\) csc \((\[Alpha]\[Pi])\)\)\/\(2  \[ImaginaryI]\)\)\) = 
          x\^\(\[Alpha] - 1\)\/2 + \(\(\[ImaginaryI]x\^\(\[Alpha] - 1\)\) cot \
\((\[Alpha]\[Pi])\)\)\/2\)\), \[IndentingNewLine]\(\[CapitalPhi]\^-\)(
        x)\[AlignmentMarker] = \(lim\+\(\[CurlyEpsilon] \[Rule] \
\(+0\)\)\(\(\((\(-x\) + \[ImaginaryI]\[CurlyEpsilon])\)\^\(\[Alpha] - 1\)\) \
csc \((\[Alpha]\[Pi])\)\)\/\(2  \[ImaginaryI]\) = \(\(-\(\(\(x\^\(\[Alpha] - 
                        1\)\) \(\[ExponentialE]\^\[ImaginaryI]\[Alpha]\[Pi]\) 
                  csc \((\[Alpha]\[Pi])\)\)\/\(2  \[ImaginaryI]\)\)\) = \
\(-\(x\^\(\[Alpha] - 1\)\/2\)\) + \(\(\[ImaginaryI]x\^\(\[Alpha] - 1\)\) cot \
\((\[Alpha]\[Pi])\)\)\/2\)\), \[IndentingNewLine]\(\[CapitalPhi]\^+\)(
          x) + \(\[CapitalPhi]\^-\)(
          x)\[AlignmentMarker] = \(\(-\(\(\(x\^\(\[Alpha] - 
                        1\)\) \(\[ExponentialE]\^\(-\[ImaginaryI]\[Alpha]\[Pi]\
\)\) csc \((\[Alpha]\[Pi])\)\)\/\(2  \[ImaginaryI]\)\)\) - \(\(x\^\(\[Alpha] \
- 1\)\) \(\[ExponentialE]\^\[ImaginaryI]\[Alpha]\[Pi]\) csc \((\[Alpha]\[Pi])\
\)\)\/\(2  \[ImaginaryI]\) = \(\(\[ImaginaryI]x\^\(\[Alpha] - 
                  1\)\) \(cot(\[Alpha]\[Pi])\) = \(1\/\[Pi]\[ImaginaryI]\) \(\
\[Integral]\_0\%\[Infinity]\( \[Tau]\^\(\[Alpha] - 1\)\/\(\[Tau] - 
                      x\)\) \[DifferentialD]\[Tau]\)\)\), \[IndentingNewLine]\
\(\[CapitalPhi]\^+\)(x) - \(\[CapitalPhi]\^-\)(
          x)\[AlignmentMarker] = \(\(-\(\(\(x\^\(\[Alpha] - 
                        1\)\) \(\[ExponentialE]\^\(-\[ImaginaryI]\[Alpha]\[Pi]\
\)\) csc \((\[Alpha]\[Pi])\)\)\/\(2  \[ImaginaryI]\)\)\) + \(\(x\^\(\[Alpha] \
- 1\)\) \(\[ExponentialE]\^\[ImaginaryI]\[Alpha]\[Pi]\) csc \((\[Alpha]\[Pi])\
\)\)\/\(2  \[ImaginaryI]\) = \(\(x\^\(\[Alpha] - 
                1\)\)\(.\)\)\)\)], "DisplayFormula",
  CellMargins->{{92.8125, 20.625}, {Inherited, Inherited}},
  TextAlignment->AlignmentMarker,
  FormatType->StandardForm]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Specifying Equalities for Functions with Branch Cuts ", "Title"],

Cell[TextData[{
  "The implementations of all the special functions in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " are based, internally, on a very small set of complex elementary \
functions\[LongDash]log, power, and polynomial. Great care was taken that \
these basic building blocks treated branch cut information properly. \
Functions such as ",
  StyleBox["Power", "MR"],
  " and the inverse trigonometric functions have been designed so that the \
treatment of branch cuts will be consistent with these basic functions. \
(These functions are built using the building blocks mentioned above, the \
arithmetical operations ",
  StyleBox["Plus", "MR"],
  " and ",
  StyleBox["Times", "MR"],
  ", and limit procedures such as infinite summation and integration; these \
operations and procedures do not introduce new difficulties into the branch \
cut behavior.) This consistency gives us the opportunity to find results that \
previously have been overlooked because they have been masked by the \
intricacies of branch cut behavior."
}], "Text"],

Cell[TextData[{
  "For example, ",
  StyleBox["Log[z]", "MR"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is defined on the complex ",
  StyleBox["z",
    FontSlant->"Italic"],
  "-plane as a single-valued function such that its branch points ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0, \ \[Infinity]\)],
    FormatType->StandardForm],
  " are connected by the branch cut line ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < z < 0\)],
    FormatType->StandardForm],
  ". Values for ",
  StyleBox["Log[z]", "MR"],
  " on the branch cut itself are continued from above: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              UnderscriptBox["lim", \(\[CurlyEpsilon] \[Rule] \(+0\)\),
                LimitsPositioning->False],
              ScriptLevel->0], 
            StyleBox["\[ThinSpace]",
              ScriptLevel->0], 
            RowBox[{
              TagBox["",
                Beta], 
              RowBox[{"log", "(", \(x + \[ImaginaryI]\ \[CurlyEpsilon]\), 
                StyleBox[")",
                  ScriptLevel->0]}]}]}], 
          StyleBox["=",
            ScriptLevel->0], 
          StyleBox[\(log(x)\),
            ScriptLevel->0]}], TraditionalForm]],
    PageBreakWithin->False,
    FormatType->StandardForm],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`x < 0\)],
    FormatType->StandardForm],
  ". This treatment of the branch cut corresponds to convention, and has \
always been used by the ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "system. As a direct consequence of this definition, however, we have the \
same branch cut and similar behavior for the ",
  StyleBox["Power", "MR"],
  " function, since its definition involves ",
  StyleBox["Log", "MR"],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`z\^a = e\^\(a\ \ \(log(z)\)\)\)],
    PageBreakWithin->False,
    FormatType->StandardForm],
  ". In the same manner, more complicated inverse trigonometric functions and \
hypergeometric functions are built from the previously defined logarithmic \
and power functions, and as a result they have corresponding branch cuts and \
behave consistently on these lines. "
}], "Text"],

Cell[TextData[{
  "We will consider some examples of extended formulas found with the help of \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". They are closely related to formulas familiar to the mathematical \
literature, with one important difference: they are correct over the entire \
complex plane, including the relevant branch cut lines."
}], "Text"],

Cell[TextData[{
  "These formulas generally include terms involving the ",
  StyleBox["Floor", "MR"],
  " function ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftFloor]x\[RightFloor]\)],
    FormatType->StandardForm],
  ", which is defined as the largest integer such that ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftFloor]x\[RightFloor] \[LessEqual] x\)],
    FormatType->StandardForm],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Power Expansion Formulas for the Power Function",
  FontWeight->"Bold"]], "Subsection"],

Cell[TextData[{
  "The power expansion formula ",
  Cell[BoxData[
      \(TraditionalForm\`\@z\^2 = \(\(\@z\) \@z = z\)\)],
    FormatType->StandardForm],
  " is correct only for real  ",
  Cell[BoxData[
      \(TraditionalForm\`z > 0\)],
    FormatType->StandardForm],
  " or for complex ",
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(\[Pi]\/2\)\) < Arg(z) \[LessEqual] \[Pi]\/2\)],
    FormatType->StandardForm],
  ". If we want a result that is valid for ",
  StyleBox["all z",
    FontSlant->"Italic"],
  ", we must use these formulas:   "
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\@z\^2 = \@\(\(-\[ImaginaryI]\)\ z\)\ \
\@\(\[ImaginaryI]\ z\); \ \ \ \ \@\(-z\^2\) = \@\(\(\ \)\(z\)\)\ \@\(-\ z\); \
\ \ \ \ \ \((z\^2)\)\^a = \((\(-\[ImaginaryI]\)\ z)\)\^a\ \((\[ImaginaryI]\ \
z)\)\^a; \ \ \ \ \ \((\(-z\^2\))\)\^a = 
      z\^a\ \(\(\((\(-\ z\))\)\^a\)\(.\)\(\ \ \)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontFamily->"Janson Text",
  FontWeight->"Plain"],

Cell[TextData[{
  "In some cases we can use more general formulas, under the restriction ",
  Cell[BoxData[
      \(TraditionalForm\`z\_1 + z\_2 \[GreaterEqual] 0\)],
    FormatType->StandardForm],
  ":"
}], "Text"],

Cell[BoxData[{
    \(TraditionalForm\`\(\@\(z\_1\ z\_2\) = \@z\_1\ \@\(\(z\_2\)\(\ \
\)\)\ \ \ when\ \ \ \ z\_1 + z\_2 \[GreaterEqual] 
          0;\)\), "\[IndentingNewLine]", 
    \(TraditionalForm\`\ \((z\_1\ z\_2)\)\^a = 
      z\_1\%a\ z\_2\%a\ \ \ \ when\ \ \ \ z\_1 + z\_2 \[GreaterEqual] 
        0. \)}], "DisplayFormula"],

Cell["In particular, we have", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\@\(1 - z\^2\) = \@\(1 - z\)\ \@\(1 + z\); \ \ \ \ \ \ \
\ \ \ \((1 - z\^2)\)\^a = \ \((1 - z)\)\^a\ \(\(\((1 + 
                  z)\)\^a\)\(.\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontFamily->"Janson Text",
  FontWeight->"Plain"],

Cell[TextData[{
  "Similar equalities with ",
  Cell[BoxData[
      \(TraditionalForm\`z\^2 - 1\)],
    FormatType->StandardForm],
  " will be correct under the restriction ",
  Cell[BoxData[
      \(TraditionalForm\`Re(z) > 0\)],
    FormatType->StandardForm],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\@\(z\^2 - 1\) = \@\(z - 1\)\ \@\(z + 1\)\ \ \ \ when\
\ \ \ \ \ \(Re(z)\) > 
        0\ ; \ \ \ \ \((z\^2 - 1)\)\^a = \ \((z - 1)\)\^a\ \((z + \
1)\)\^a\ \ \ \ \ when\ \ \ \ \(Re(
            z)\) > \(\(0\)\(\ \)\(.\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontFamily->"Janson Text",
  FontWeight->"Plain"],

Cell[TextData[{
  "The restrictions can be removed as long as we factor in a correction \
including the ",
  StyleBox["Floor", "MR"],
  " function:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\@\(z\_1\ z\_2\) = \@z\_1\ \@z\_2\ \(exp(\[Pi]\ \[ImaginaryI]\
\ \[LeftFloor]\(\[Pi] - Arg(z\_1) - Arg(z\_2)\)\/\(2\ \[Pi]\)\[RightFloor])\)\
\), 
        AdjustmentBox[";",
          BoxMargins->{{0.0909091, -0.0909091}, {0, 
          0}}], \(\((z\_1\ z\_2)\)\^a = 
          z\_1\%a\ z\_2\%a\ \(exp(
              2\ \[Pi]\ \[ImaginaryI]\ a\ \[LeftFloor]\(\[Pi] - Arg(z\_1) - \
Arg(z\_2)\)\/\(2\ \[Pi]\)\[RightFloor])\)\), 
        AdjustmentBox[";",
          BoxMargins->{{0.20202, -0.20202}, {0, 0}}], "\[IndentingNewLine]", 
        RowBox[{\(\((z\^a\_1)\)\^a\_2\), "=", 
          RowBox[{\(z\^\(a\_1\ a\_2\)\), " ", 
            
            RowBox[{\(exp(
                2\ \[Pi]\ \[ImaginaryI]\ a\_2\ \[LeftFloor]\(\[Pi] - Im(a\_1\ \
\(log(z)\))\)\/\(2\ \[Pi]\)\[RightFloor])\), 
              AdjustmentBox[".",
                BoxMargins->{{0.0909091, -0.0909091}, {0, 0}}]}]}]}]}], 
      TraditionalForm]], "DisplayFormula",
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "P",
  StyleBox["ower Expansion Formulas for the Logarithmic Function",
    FontWeight->"Bold"]
}], "Subsection"],

Cell["We can create similar formulas for the logarithmic function:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`log(z\^2) = 
      log(\(-\[ImaginaryI]\)\ z) + 
        log(\[ImaginaryI]\ z); \ \ \ log(\(-z\^2\)) = 
      log(z) + log(\(-z\));\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "or a more general formula valid under the restriction ",
  Cell[BoxData[
      \(TraditionalForm\`z\_1 + z\_2 \[GreaterEqual] 0\)],
    FormatType->StandardForm],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(log(z\_1\ z\_2) = 
      log(z\_1) + \(\(log(z\_2)\)\(.\)\)\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell["In particular, we have ", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(log(1 - z\^2) = 
      log(1 - z) + \(\(log(1 + z)\)\(.\)\)\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "More general relations involving ",
  StyleBox["Floor", "MR"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "have the following form:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(log(z\_1\ z\_2) = 
          log(z\_1) + log(z\_2) + 
            2\ \[ImaginaryI]\ \[Pi]\ \[LeftFloor]\(\[Pi] - Arg \((z\_1)\) - \
Arg \((z\_2)\)\)\/\(2\ \[Pi]\)\[RightFloor]\), 
        AdjustmentBox[";",
          BoxMargins->{{0.0909091, -0.0909091}, {0, 0}}], 
        RowBox[{\(log(z\^w)\), "=", 
          RowBox[{\(w\ \(log(z)\)\), "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
              
              RowBox[{\(\[LeftFloor]\(\[Pi] - Im \((w\ log \((z)\))\)\)\/\(2\ \
\[Pi]\)\[RightFloor]\), 
                AdjustmentBox[".",
                  BoxMargins->{{0.0909091, -0.0909091}, {0, 0}}]}]}]}]}]}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Re",
  StyleBox["lations between Exponential and Logarithmic Functions",
    FontWeight->"Bold"]
}], "Subsection"],

Cell[TextData[{
  "The logarithmic function is the inverse function to the exponential \
function; in other words, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(log(z)\) = z\)],
    FormatType->StandardForm],
  ". However, it is not always the case that ",
  Cell[BoxData[
      \(TraditionalForm\`log(\[ExponentialE]\^z) = z\)],
    FormatType->StandardForm],
  "; this relationship is correct only for the horizontal strip ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Pi]\) < Im(z) \[LessEqual] \[Pi]\)],
    FormatType->StandardForm],
  ". We can, however, introduce a correcting term, again using  ",
  StyleBox["Floor", "MR"],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(log(\[ExponentialE]\^z)\), "=", 
        RowBox[{"z", "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
            
            RowBox[{\(\[LeftFloor]\(\[Pi] - Im(z)\)\/\(2\ \
\[Pi]\)\[RightFloor]\), 
              AdjustmentBox[".",
                BoxMargins->{{0.0909091, -0.0909091}, {0, 0}}]}]}]}]}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "P",
  StyleBox["ower Expansion Formulas of Ratios",
    FontWeight->"Bold"]
}], "Subsection"],

Cell["\<\
The following general power expansion formulas can be useful: \
\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\@\(\(a + z\)\/\(b - z\)\) = \@\(\(a + z\)\/\(a + \
b\)\)\ \@\(\(a + b\)\/\(b - z\)\)\ \ \ \ when\ \ \ \ \ a + 
          b \[Element] \[DoubleStruckCapitalR]; \@\(\(a + z\)\/\(b + z\)\) = \
\@\(\(a + z\)\/\(b - a\)\)\/\@\(\(b + z\)\/\(b - a\)\)\ \ \ when\ \ \ \ a - 
          b \[Element] \[DoubleStruckCapitalR], \(a \[NotEqual] 
        b;\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{\(\((\(a + z\)\/\(b - z\))\)\^c\), "=", 
            
            RowBox[{\(\((\(a + z\)\/\(a + b\))\)\^c\ \((\(a + b\)\/\(b - z\))\
\)\^c\ \ \ when\ \ \ \ a + b\), "\[Element]", 
              TagBox["\[DoubleStruckCapitalR]",
                (Reals&)]}]}], ";", "  ", 
          RowBox[{\(\((\(a + z\)\/\(b + z\))\)\^c\), "=", 
            
            RowBox[{\(\((\(a + z\)\/\(b - a\))\)\^c\/\((\(b + z\)\/\(b - a\))\
\)\^c\ \ \ when\ \ \ \ a - b\), "\[Element]", 
              TagBox["\[DoubleStruckCapitalR]",
                (Reals&)]}]}]}], ",", \(a \[NotEqual] b;\)}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{\(log(\(a + z\)\/\(b - z\))\), "=", 
          
          RowBox[{\(log(\(a + z\)\/\(a + b\)) + \(log(\(a + b\)\/\(b - \
z\))\)\ \ \ \ when\ \ \ \ a + b\), "\[Element]", 
            TagBox["\[DoubleStruckCapitalR]",
              (Reals&)]}]}], ";"}], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{\(log(\(a + z\)\/\(b + z\))\), "=", 
          
          RowBox[{\(log(\(a + z\)\/\(b - a\)) - \(log(\(b + z\)\/\(b - \
a\))\)\ \ \ \ \ when\ \ \ \ a - b\), "\[Element]", 
            TagBox["\[DoubleStruckCapitalR]",
              (Reals&)]}]}], ",", \(a \[NotEqual] \(\(b\)\(.\)\)\)}], 
      TraditionalForm]}], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "We can vary these formulas a bit to remove some restrictions. These \
formulas will not be correct everywhere in the complex ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontSlant->"Italic"], TraditionalForm]],
    FormatType->StandardForm],
  "-plane. For example, the following relation is correct only when ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(z \[NotElement] \((\(-1\), 1)\)\)\)\)],
    FormatType->StandardForm],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`log(\(z + 1\)\/\(z - 1\)) = 
      log(z + 1) - \(\(log(z - 1)\)\(.\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell["\<\
If we want to remove this restriction, we have to use the \
relation\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`log(\(z + 1\)\/\(z - 1\)) = 
      log(\(-z\) - 1) - \(\(log(1 - z)\)\(.\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "R",
  StyleBox["elations between ArcTan and Tan",
    FontWeight->"Bold"]
}], "Subsection"],

Cell[TextData[{
  "We know that ",
  Cell[BoxData[
      \(TraditionalForm\`tan(\(tan\^\(-1\)\)(z)) = z\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(tan\^\(-1\)\)(tan(z)) = z\)],
    FormatType->StandardForm],
  " only under some restrictions on ",
  Cell[BoxData[
      \(TraditionalForm\`z\)],
    FormatType->StandardForm],
  ". For example, the second formula is correct for ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]Re(
            z)\[RightBracketingBar] < \[Pi]/2\)],
    FormatType->StandardForm],
  ". Outside of this vertical strip, a more complicated formula applies, \
discovered with the help of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\(tan\^\(-1\)\)(tan(z)) = 
      z - \[Pi]\ \[LeftFloor]\(Re \((z)\)\)\/\[Pi] + 1\/2\[RightFloor] + 
        1\/2\ \((1 + \((\(-1\))\)\^\(\[LeftFloor]\(Re \((z)\)\)\/\[Pi] - 1\/2\
\[RightFloor] + \[LeftFloor]1\/2 - \(Re \((z)\)\)\/\[Pi]\[RightFloor]\))\)\ \
\[Pi]\ \(\[Theta](Im(z))\)\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "DisplayFormula",
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "when ",
  Cell[BoxData[
      \(TraditionalForm\`z/\[Pi] - 
          1/2 \[NotElement] \[DoubleStruckCapitalZ]\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](z)\)],
    FormatType->StandardForm],
  " represents the Heaviside unit step function."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "R",
  StyleBox["elation between ArcCos and Log",
    FontWeight->"Bold"]
}], "Subsection"],

Cell[TextData[{
  "Often the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(cos\^\(-1\)\)(z)\)],
    FormatType->StandardForm],
  " is defined as ",
  Cell[BoxData[
      \(TraditionalForm\`\(-i\)\ \(log(z + \@\(z\^2 - 1\))\)\)],
    FormatType->StandardForm],
  ". ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses a slightly different definition,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\(cos\^\(-1\)\)(
        z) = \@\(1 - z\)\/\@\(z - 1\)\ \(log(
          z + \@\(z - 1\)\ \@\(z + 1\))\)\)\(,\)\)\)], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "that coincides with the first one when ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(Re(z)\)\ \(Im(z)\)\)\(>\)\(0\)\(\ \)\)\)],
    FormatType->StandardForm],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`Re(z) = 0. \)],
    FormatType->StandardForm],
  " This definition supports the important formula ",
  Cell[BoxData[
      \(TraditionalForm\`\(cos\^\(-1\)\)(z) + \(sin\^\(-1\)\)(z) = \[Pi]/2\)],
    
    FormatType->StandardForm],
  " over the complex ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontSlant->"Italic"], TraditionalForm]],
    FormatType->StandardForm],
  "-plane."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "R",
  StyleBox["elations between ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox[\(J\_\[Nu]\),
            FontFamily->"CB Futura CondensedBold"]}], TraditionalForm]],
    FormatType->StandardForm],
  StyleBox["(z) and ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(I\_\[Nu]\),
          FontFamily->"CB Futura CondensedBold"], TraditionalForm]],
    FormatType->StandardForm],
  StyleBox["(z), ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(Y\_\[Nu]\),
          FontFamily->"CB Futura CondensedBold"], TraditionalForm]],
    FormatType->StandardForm],
  StyleBox["(z) and ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(K\_\[Nu]\),
          FontFamily->"CB Futura CondensedBold"], TraditionalForm]],
    FormatType->StandardForm],
  StyleBox["(z)",
    FontWeight->"Bold"]
}], "Subsection"],

Cell["\<\
Many well-known formulas for special functions should also be \
modified to ensure their correctness on branch cut lines. For example, \
relations between Bessel functions and their modified versions can be \
rewritten in the form\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(z\^\[Nu]\ \(\(I\_\[Nu]\)(\[ImaginaryI]\ z)\)\), "=", 
          RowBox[{\(\((\[ImaginaryI]\ z)\)\^\[Nu]\), 
            RowBox[{
              SubscriptBox[
                StyleBox["J",
                  FontFamily->"Times"], "\[Nu]"], "(", "z", ")"}]}]}], ";"}], 
      TraditionalForm]], "DisplayFormula",
  FormatType->StandardForm,
  FontWeight->"Plain"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(K\_\[Nu]\)(z)\), "=", 
        RowBox[{
          StyleBox["{",
            SpanMaxSize->Infinity,
            FontSize->16], GridBox[{
              {
                RowBox[{
                  RowBox[{
                    
                    RowBox[{\(\[Pi]\/2\), \((\(\((\[ImaginaryI]\ \
z)\)\^\[Nu]\/z\^\[Nu]\) cos \((\[Pi]\ \[Nu])\) - 
                          z\^\[Nu]\/\((\[ImaginaryI]\ z)\)\^\[Nu])\), " ", 
                      "csc", \((\[Pi]\ \[Nu])\), " ", 
                      SubscriptBox[
                        StyleBox["J",
                          FontFamily->"Times"], 
                        "\[Nu]"], \((\[ImaginaryI]\ z)\)}], 
                    "-", \(\(\[Pi]\ \((\[ImaginaryI]\ z)\)\^\[Nu]\)\/\(2\ z\^\
\[Nu]\)\ \(Y\_\[Nu]\) \((\[ImaginaryI]\ z)\)\)}], ","}], 
                RowBox[{
                  RowBox[{"\[Nu]", "\[NotElement]", 
                    TagBox["\[DoubleStruckCapitalZ]",
                      (Integers&)]}], ";"}]},
              {\(\(\((\(-1\))\)\^\[Nu]\ \((log \((\[ImaginaryI]\ z)\) - 
                        log \((z)\))\)\ \(I\_\[Nu]\) \((z)\) - \(\[Pi]\ \
\[ImaginaryI]\^\[Nu]\)\/2\ \(Y\_\[Nu]\) \((\[ImaginaryI]\ z)\)\)\(,\)\), 
                RowBox[{"\[Nu]", "\[Element]", 
                  RowBox[{
                    TagBox["\[DoubleStruckCapitalZ]",
                      (Integers&)], "."}]}]}
              }]}]}], TraditionalForm]], "DisplayFormula",
  AutoStyleOptions->{"UnmatchedBracketStyle"->None},
  FormatType->StandardForm],

Cell[TextData[{
  "For an example showing the process of deriving formulas like these for the \
complex plane, see",
  StyleBox[" Extending a Well-Known Trigonometric Identity to the Complex \
Plane ",
    FontWeight->"Bold"],
  "on this panel."
}], "Text"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
ScreenStyleEnvironment->"Production",
PrintingStyleEnvironment->"Production",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{947, 836},
WindowMargins->{{Automatic, 146}, {29, Automatic}},
PrintingCopies->1,
PrintingPageRange->{4, 4},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
PageHeaderLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{18, 1134}, {432, 144}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False},
CellLabelAutoDelete->False,
ScriptMinSize->8,
Magnification->1,
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 96, 4, 100, "Title"],

Cell[CellGroupData[{
Cell[1897, 61, 31, 0, 75, "Section"],
Cell[1931, 63, 707, 11, 86, "Text"],
Cell[2641, 76, 646, 13, 86, "Text"],
Cell[3290, 91, 811, 12, 104, "Text"],
Cell[4104, 105, 579, 9, 68, "Text"],
Cell[4686, 116, 963, 17, 104, "Text"],
Cell[5652, 135, 377, 6, 68, "Text"],
Cell[6032, 143, 415, 7, 68, "Text"],
Cell[6450, 152, 256, 7, 32, "Text"],
Cell[6709, 161, 232, 7, 32, "Text"],
Cell[6944, 170, 380, 7, 50, "Text"],
Cell[7327, 179, 281, 6, 32, "Text"],
Cell[7611, 187, 323, 6, 50, "Text"],
Cell[7937, 195, 610, 17, 68, "Text"],
Cell[8550, 214, 334, 6, 50, "Text"],
Cell[8887, 222, 632, 11, 86, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9556, 238, 53, 0, 45, "Section"],
Cell[9612, 240, 256, 5, 50, "Text"],
Cell[9871, 247, 899, 17, 104, "Text"],
Cell[10773, 266, 676, 13, 86, "Text"],
Cell[11452, 281, 475, 9, 68, "Text"],
Cell[11930, 292, 804, 14, 86, "Text"],
Cell[12737, 308, 1071, 22, 86, "Text"],
Cell[13811, 332, 917, 18, 104, "Text"],
Cell[14731, 352, 777, 15, 104, "Text"],
Cell[15511, 369, 492, 10, 68, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[16040, 384, 38, 0, 45, "Section"],
Cell[16081, 386, 670, 14, 86, "Text"],
Cell[16754, 402, 2618, 92, 104, "Text"],
Cell[19375, 496, 1850, 56, 68, "Text"],
Cell[21228, 554, 276, 10, 32, "Text"],
Cell[21507, 566, 304, 9, 33, "Text"],
Cell[21814, 577, 754, 22, 50, "Text"],
Cell[22571, 601, 269, 7, 32, "Text"],
Cell[22843, 610, 482, 14, 39, "DisplayFormula"],
Cell[23328, 626, 704, 24, 50, "Text"],
Cell[24035, 652, 338, 9, 32, "Text"],
Cell[24376, 663, 613, 18, 41, "DisplayFormula"],
Cell[24992, 683, 735, 22, 50, "Text"],
Cell[25730, 707, 753, 24, 51, "Text"],
Cell[26486, 733, 516, 13, 32, "DisplayFormula"],
Cell[27005, 748, 1468, 41, 104, "Text"],
Cell[28476, 791, 288, 6, 58, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[28801, 802, 93, 4, 45, "Section"],
Cell[28897, 808, 744, 14, 86, "Text"],
Cell[29644, 824, 547, 16, 50, "Text"],
Cell[30194, 842, 1455, 41, 104, "Text"],
Cell[31652, 885, 137, 4, 32, "Text"],
Cell[31792, 891, 492, 16, 50, "Text"],
Cell[32287, 909, 535, 15, 41, "DisplayFormula"],
Cell[32825, 926, 330, 8, 50, "Text"],
Cell[33158, 936, 462, 11, 43, "DisplayFormula"],
Cell[33623, 949, 284, 10, 32, "Text"],
Cell[33910, 961, 477, 12, 50, "Text"],
Cell[34390, 975, 1058, 29, 86, "Text"],
Cell[35451, 1006, 469, 13, 50, "Text"],
Cell[35923, 1021, 836, 19, 86, "Text"],
Cell[36762, 1042, 239, 5, 43, "DisplayFormula"],
Cell[37004, 1049, 1188, 32, 68, "Text"],
Cell[38195, 1083, 441, 14, 50, "Text"],
Cell[38639, 1099, 336, 8, 48, "DisplayFormula"],
Cell[38978, 1109, 328, 11, 32, "Text"],
Cell[39309, 1122, 1049, 28, 58, "DisplayFormula"],
Cell[40361, 1152, 630, 21, 50, "Text"],
Cell[40994, 1175, 1015, 27, 68, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42058, 1208, 23, 0, 98, "Title"],

Cell[CellGroupData[{
Cell[42106, 1212, 31, 0, 75, "Section"],
Cell[42140, 1214, 768, 22, 68, "Text"],
Cell[42911, 1238, 904, 23, 86, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[43852, 1266, 51, 0, 45, "Section"],

Cell[CellGroupData[{
Cell[43928, 1270, 39, 0, 38, "Subsection"],
Cell[43970, 1272, 350, 11, 32, "Text"],
Cell[44323, 1285, 364, 8, 48, "DisplayFormula"],
Cell[44690, 1295, 911, 30, 68, "Text"],
Cell[45604, 1327, 241, 5, 47, "DisplayFormula"],
Cell[45848, 1334, 391, 15, 32, "Text"],
Cell[46242, 1351, 948, 30, 50, "Text"],
Cell[47193, 1383, 661, 18, 50, "Text"],
Cell[47857, 1403, 1330, 32, 86, "Text"],
Cell[49190, 1437, 595, 17, 58, "DisplayFormula"],
Cell[49788, 1456, 146, 3, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[49971, 1464, 47, 0, 38, "Subsection"],
Cell[50021, 1466, 1058, 33, 32, "Text"],
Cell[51082, 1501, 1823, 35, 355, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[52942, 1541, 101, 2, 38, "Subsection"],
Cell[53046, 1545, 1814, 34, 197, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[54897, 1584, 47, 0, 38, "Subsection"],
Cell[54947, 1586, 832, 17, 56, "DisplayFormula"],
Cell[55782, 1605, 212, 7, 32, "Text"],
Cell[55997, 1614, 877, 16, 114, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[56911, 1635, 36, 0, 38, "Subsection"],
Cell[56950, 1637, 346, 12, 32, "Text"],
Cell[57299, 1651, 455, 8, 48, "DisplayFormula"],
Cell[57757, 1661, 1683, 60, 50, "Text"],
Cell[59443, 1723, 1277, 44, 50, "Text"],
Cell[60723, 1769, 491, 17, 50, "Text"],
Cell[61217, 1788, 314, 6, 58, "DisplayFormula"],
Cell[61534, 1796, 699, 23, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[62270, 1824, 36, 0, 38, "Subsection"],
Cell[62309, 1826, 2089, 63, 68, "Text"],
Cell[64401, 1891, 280, 6, 48, "DisplayFormula"],
Cell[64684, 1899, 886, 32, 51, "Text"],
Cell[65573, 1933, 444, 7, 68, "Text"],
Cell[66020, 1942, 654, 21, 51, "Text"],
Cell[66677, 1965, 728, 17, 58, "DisplayFormula"],
Cell[67408, 1984, 451, 14, 32, "Text"],
Cell[67862, 2000, 737, 17, 58, "DisplayFormula"],
Cell[68602, 2019, 404, 11, 32, "Text"],
Cell[69009, 2032, 339, 12, 32, "Text"],
Cell[69351, 2046, 252, 6, 58, "DisplayFormula"],
Cell[69606, 2054, 341, 12, 32, "Text"],
Cell[69950, 2068, 533, 18, 50, "Text"],
Cell[70486, 2088, 1169, 25, 105, "DisplayFormula"],
Cell[71658, 2115, 390, 11, 50, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[72097, 2132, 36, 0, 45, "Section"],
Cell[72136, 2134, 208, 8, 32, "Text"],
Cell[72347, 2144, 265, 6, 48, "DisplayFormula"],
Cell[72615, 2152, 469, 15, 50, "Text"],
Cell[73087, 2169, 239, 5, 42, "DisplayFormula"],
Cell[73329, 2176, 469, 10, 50, "Text"],
Cell[73801, 2188, 436, 16, 32, "Text"],
Cell[74240, 2206, 497, 9, 48, "DisplayFormula"],
Cell[74740, 2217, 1350, 42, 70, "Text"],
Cell[76093, 2261, 3170, 83, 48, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[79300, 2349, 34, 0, 45, "Section"],

Cell[CellGroupData[{
Cell[79359, 2353, 45, 0, 38, "Subsection"],
Cell[79407, 2355, 383, 14, 32, "Text"],
Cell[79793, 2371, 494, 12, 60, "DisplayFormula"],
Cell[80290, 2385, 570, 22, 32, "Text"],
Cell[80863, 2409, 552, 13, 48, "DisplayFormula"],
Cell[81418, 2424, 1048, 35, 55, "Text"],
Cell[82469, 2461, 340, 11, 32, "Text"],
Cell[82812, 2474, 61, 0, 32, "Text"],
Cell[82876, 2476, 257, 5, 48, "DisplayFormula"],
Cell[83136, 2483, 161, 6, 32, "Text"],
Cell[83300, 2491, 344, 6, 42, "DisplayFormula"],
Cell[83647, 2499, 324, 8, 50, "Text"],
Cell[83974, 2509, 676, 20, 50, "Text"],
Cell[84653, 2531, 361, 7, 48, "DisplayFormula"],
Cell[85017, 2540, 161, 6, 32, "Text"],
Cell[85181, 2548, 472, 10, 42, "DisplayFormula"],
Cell[85656, 2560, 271, 10, 32, "Text"],
Cell[85930, 2572, 1127, 32, 69, "Text"],
Cell[87060, 2606, 299, 12, 32, "Text"],
Cell[87362, 2620, 553, 10, 48, "DisplayFormula"],
Cell[87918, 2632, 675, 20, 51, "Text"],
Cell[88596, 2654, 247, 4, 48, "DisplayFormula"],
Cell[88846, 2660, 166, 6, 32, "Text"],
Cell[89015, 2668, 934, 21, 40, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[89986, 2694, 42, 0, 38, "Subsection"],
Cell[90031, 2696, 158, 5, 32, "Text"],
Cell[90192, 2703, 581, 11, 42, "DisplayFormula"],
Cell[90776, 2716, 421, 15, 32, "Text"],
Cell[91200, 2733, 267, 10, 32, "Text"],
Cell[91470, 2745, 716, 16, 42, "DisplayFormula"],
Cell[92189, 2763, 151, 3, 32, "Text"],
Cell[92343, 2768, 1926, 54, 57, "DisplayFormula"],
Cell[94272, 2824, 320, 9, 50, "Text"],
Cell[94595, 2835, 642, 15, 59, "DisplayFormula"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[95298, 2857, 46, 0, 72, "Title"],
Cell[95347, 2859, 634, 16, 68, "Text"],
Cell[95984, 2877, 26613, 1229, 129, 18329, 1121, "GraphicsData", \
"PostScript", "Graphics"],
Cell[122600, 4108, 1740, 58, 86, "Text"],
Cell[124343, 4168, 1878, 58, 86, "Text"],

Cell[CellGroupData[{
Cell[126246, 4230, 278, 5, 29, "Input"],
Cell[126527, 4237, 217819, 10896, 181, 198562, 10653, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[344361, 15136, 1690, 52, 83, "Text"],

Cell[CellGroupData[{
Cell[346076, 15192, 294, 6, 29, "Input"],
Cell[346373, 15200, 135308, 6563, 148, 115481, 6312, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[481696, 21766, 862, 19, 83, "Text"],

Cell[CellGroupData[{
Cell[482583, 21789, 311, 6, 44, "Input"],
Cell[482897, 21797, 135501, 6569, 153, 115689, 6319, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[618413, 28369, 672, 17, 65, "Text"],
Cell[619088, 28388, 523, 15, 51, "Text"],

Cell[CellGroupData[{
Cell[619636, 28407, 244, 5, 29, "Input"],
Cell[619883, 28414, 79989, 3278, 175, 55413, 2969, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[699887, 31695, 757, 26, 48, "Text"],

Cell[CellGroupData[{
Cell[700669, 31725, 337, 7, 80, "Input"],
Cell[701009, 31734, 89076, 2627, 120, 56035, 2214, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[790100, 34364, 692, 20, 66, "Text"],
Cell[790795, 34386, 3477, 112, 105, "Text"],

Cell[CellGroupData[{
Cell[794297, 34502, 249, 5, 29, "Input"],
Cell[794549, 34509, 133428, 5953, 175, 107493, 5627, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[927992, 40465, 269, 6, 29, "Text"],

Cell[CellGroupData[{
Cell[928286, 40475, 79, 2, 27, "Input"],
Cell[928368, 40479, 127, 3, 52, "Output"]
}, Closed]],
Cell[928510, 40485, 331, 11, 29, "Text"],

Cell[CellGroupData[{
Cell[928866, 40500, 260, 6, 77, "Input"],
Cell[929129, 40508, 108, 2, 27, "Output"]
}, Closed]],
Cell[929252, 40513, 393, 16, 29, "Text"],
Cell[929648, 40531, 831, 17, 86, "Text"],
Cell[930482, 40550, 805, 23, 70, "Text"],

Cell[CellGroupData[{
Cell[931312, 40577, 165, 4, 36, "Input"],
Cell[931480, 40583, 74234, 2109, 154, 47956, 1779, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1005729, 42695, 96, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[1005850, 42702, 554, 11, 114, "Input"],
Cell[1006407, 42715, 91456, 3939, 154, 68333, 3648, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1097912, 46660, 38, 0, 72, "Title"],
Cell[1097953, 46662, 357, 8, 50, "Text"],
Cell[1098313, 46672, 68, 0, 24, "SectionFirst"],
Cell[1098384, 46674, 858, 22, 68, "Text"],
Cell[1099245, 46698, 1614, 47, 50, "Text"],
Cell[1100862, 46747, 113, 3, 32, "Text"],
Cell[1100978, 46752, 1183, 29, 58, "DisplayFormula"],
Cell[1102164, 46783, 599, 17, 32, "Text"],
Cell[1102766, 46802, 463, 12, 50, "Text"],

Cell[CellGroupData[{
Cell[1103254, 46818, 51, 0, 75, "Section"],
Cell[1103308, 46820, 904, 28, 50, "Text"],
Cell[1104215, 46850, 214, 4, 49, "DisplayFormula"],
Cell[1104432, 46856, 1151, 39, 68, "Text"],
Cell[1105586, 46897, 205, 4, 48, "DisplayFormula"],
Cell[1105794, 46903, 370, 11, 32, "Text"],
Cell[1106167, 46916, 422, 11, 50, "DisplayFormula"],
Cell[1106592, 46929, 1545, 43, 73, "Text"],

Cell[CellGroupData[{
Cell[1108162, 46976, 90, 2, 36, "Input"],
Cell[1108255, 46980, 433, 12, 46, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1108725, 46997, 138, 3, 52, "Input"],
Cell[1108866, 47002, 78, 2, 29, "Output"]
}, Closed]],
Cell[1108959, 47007, 308, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[1109292, 47018, 131, 3, 44, "Input"],
Cell[1109426, 47023, 77, 2, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1109540, 47030, 131, 3, 44, "Input"],
Cell[1109674, 47035, 117, 3, 27, "Output"]
}, Closed]],
Cell[1109806, 47041, 1169, 25, 104, "Text"],
Cell[1110978, 47068, 27918, 952, 154, 11917, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1138899, 48022, 1326, 44, 87, "Text"],
Cell[1140228, 48068, 191, 6, 32, "Text"],
Cell[1140422, 48076, 498, 11, 72, "Input"],
Cell[1140923, 48089, 196, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[1141144, 48099, 170, 5, 27, "Input"],
Cell[1141317, 48106, 189, 3, 66, "Output"]
}, Closed]],
Cell[1141521, 48112, 468, 11, 53, "Text"],

Cell[CellGroupData[{
Cell[1142014, 48127, 254, 4, 68, "Input"],
Cell[1142271, 48133, 77, 2, 27, "Output"]
}, Closed]],
Cell[1142363, 48138, 340, 11, 34, "Text"],

Cell[CellGroupData[{
Cell[1142728, 48153, 73, 2, 34, "Input"],
Cell[1142804, 48157, 77, 2, 27, "Output"]
}, Closed]],
Cell[1142896, 48162, 390, 10, 50, "Text"],

Cell[CellGroupData[{
Cell[1143311, 48176, 108, 2, 32, "Input"],
Cell[1143422, 48180, 421, 7, 66, "Output"]
}, Closed]],
Cell[1143858, 48190, 1012, 29, 68, "Text"],
Cell[1144873, 48221, 331, 6, 67, "InputOnly"],
Cell[1145207, 48229, 130, 4, 32, "Text"],
Cell[1145340, 48235, 160, 3, 54, "InputOnly"],
Cell[1145503, 48240, 153, 3, 29, "InputOnly"],
Cell[1145659, 48245, 116, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[1145800, 48252, 101, 2, 27, "Input"],
Cell[1145904, 48256, 294, 5, 47, "Output"]
}, Closed]],
Cell[1146213, 48264, 292, 7, 33, "Text"],

Cell[CellGroupData[{
Cell[1146530, 48275, 113, 2, 27, "Input"],
Cell[1146646, 48279, 430, 7, 47, "Output"]
}, Closed]],
Cell[1147091, 48289, 499, 12, 52, "Text"],
Cell[1147593, 48303, 139, 3, 37, "InputOnly"],
Cell[1147735, 48308, 346, 9, 50, "Text"],
Cell[1148084, 48319, 177, 4, 29, "InputOnly"],
Cell[1148264, 48325, 547, 10, 109, "InputOnly"],
Cell[1148814, 48337, 178, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[1149017, 48345, 340, 7, 43, "Input"],
Cell[1149360, 48354, 375144, 30477, 240, 349148, 30151, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1524519, 78834, 674, 20, 50, "Text"],

Cell[CellGroupData[{
Cell[1525218, 78858, 104, 2, 27, "Input"],
Cell[1525325, 78862, 85, 2, 29, "Output"]
}, Closed]],
Cell[1525425, 78867, 164, 4, 32, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1525638, 78877, 35, 0, 72, "Title"],
Cell[1525676, 78879, 849, 28, 50, "Text"],
Cell[1526528, 78909, 593, 14, 49, "DisplayFormula"],
Cell[1527124, 78925, 209, 9, 32, "Text"],
Cell[1527336, 78936, 240, 8, 32, "Text"],
Cell[1527579, 78946, 325, 8, 42, "DisplayFormula"],
Cell[1527907, 78956, 1394, 44, 68, "Text"],
Cell[1529304, 79002, 1170, 35, 86, "Text"],
Cell[1530477, 79039, 1137, 35, 68, "Text"],
Cell[1531617, 79076, 580, 10, 44, "DisplayFormula"],
Cell[1532200, 79088, 139, 6, 32, "Text"],
Cell[1532342, 79096, 876, 27, 68, "Text"],
Cell[1533221, 79125, 722, 20, 41, "DisplayFormula"],
Cell[1533946, 79147, 144, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[1534115, 79157, 42, 0, 75, "Section"],
Cell[1534160, 79159, 365, 13, 32, "Text"],
Cell[1534528, 79174, 509, 13, 41, "DisplayFormula"],
Cell[1535040, 79189, 184, 6, 32, "Text"],
Cell[1535227, 79197, 1085, 28, 59, "DisplayFormula"],
Cell[1536315, 79227, 989, 34, 50, "Text"],
Cell[1537307, 79263, 122, 5, 32, "Text"],
Cell[1537432, 79270, 617, 9, 42, "DisplayFormula"],
Cell[1538052, 79281, 227, 7, 32, "Text"],
Cell[1538282, 79290, 68, 0, 32, "Text"],
Cell[1538353, 79292, 524, 10, 42, "DisplayFormula",
  Evaluatable->False],
Cell[1538880, 79304, 1191, 42, 50, "Text"],
Cell[1540074, 79348, 841, 20, 31, "DisplayFormula"],
Cell[1540918, 79370, 310, 9, 32, "Text"],
Cell[1541231, 79381, 361, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[1541617, 79391, 31, 0, 38, "Subsection"],
Cell[1541651, 79393, 1001, 22, 59, "DisplayFormula",
  Evaluatable->False],
Cell[1542655, 79417, 182, 6, 32, "Text"],
Cell[1542840, 79425, 1278, 22, 132, "DisplayFormula"],
Cell[1544121, 79449, 386, 11, 32, "Text"],
Cell[1544510, 79462, 1074, 31, 30, "DisplayFormula",
  Evaluatable->False],
Cell[1545587, 79495, 162, 6, 32, "Text"],
Cell[1545752, 79503, 967, 27, 57, "DisplayFormula",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[1546756, 79535, 31, 0, 38, "Subsection"],
Cell[1546790, 79537, 1147, 24, 49, "DisplayFormula",
  Evaluatable->False],
Cell[1547940, 79563, 1181, 36, 50, "Text",
  Evaluatable->False],
Cell[1549124, 79601, 2293, 34, 160, "DisplayFormula"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1551478, 79642, 70, 0, 130, "Title"],
Cell[1551551, 79644, 1065, 21, 122, "Text"],
Cell[1552619, 79667, 2233, 64, 127, "Text"],
Cell[1554855, 79733, 370, 8, 50, "Text"],
Cell[1555228, 79743, 414, 12, 32, "Text"],

Cell[CellGroupData[{
Cell[1555667, 79759, 111, 1, 38, "Subsection"],
Cell[1555781, 79762, 647, 21, 52, "Text"],
Cell[1556431, 79785, 427, 8, 33, "DisplayFormula"],
Cell[1556861, 79795, 215, 6, 32, "Text"],
Cell[1557079, 79803, 331, 6, 45, "DisplayFormula"],
Cell[1557413, 79811, 38, 0, 32, "Text"],
Cell[1557454, 79813, 286, 6, 33, "DisplayFormula"],
Cell[1557743, 79821, 279, 10, 32, "Text"],
Cell[1558025, 79833, 359, 8, 33, "DisplayFormula"],
Cell[1558387, 79843, 160, 5, 32, "Text"],
Cell[1558550, 79850, 1006, 22, 77, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[1559593, 79877, 131, 4, 30, "Subsection"],
Cell[1559727, 79883, 76, 0, 32, "Text"],
Cell[1559806, 79885, 241, 6, 25, "DisplayFormula"],
Cell[1560050, 79893, 199, 6, 32, "Text"],
Cell[1560252, 79901, 183, 4, 24, "DisplayFormula"],
Cell[1560438, 79907, 39, 0, 32, "Text"],
Cell[1560480, 79909, 183, 4, 25, "DisplayFormula"],
Cell[1560666, 79915, 163, 6, 32, "Text"],
Cell[1560832, 79923, 781, 18, 40, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[1561650, 79946, 133, 4, 30, "Subsection"],
Cell[1561786, 79952, 670, 17, 50, "Text"],
Cell[1562459, 79971, 465, 12, 40, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[1562961, 79988, 112, 4, 30, "Subsection"],
Cell[1563076, 79994, 88, 3, 32, "Text"],
Cell[1563167, 79999, 455, 8, 61, "DisplayFormula"],
Cell[1563625, 80009, 750, 18, 52, "DisplayFormula"],
Cell[1564378, 80029, 782, 19, 77, "DisplayFormula"],
Cell[1565163, 80050, 492, 13, 50, "Text"],
Cell[1565658, 80065, 181, 4, 40, "DisplayFormula"],
Cell[1565842, 80071, 92, 3, 32, "Text"],
Cell[1565937, 80076, 186, 4, 40, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[1566160, 80085, 110, 4, 30, "Subsection"],
Cell[1566273, 80091, 747, 23, 50, "Text"],
Cell[1567023, 80116, 519, 10, 59, "DisplayFormula"],
Cell[1567545, 80128, 326, 11, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1567908, 80144, 109, 4, 30, "Subsection"],
Cell[1568020, 80150, 383, 13, 33, "Text"],
Cell[1568406, 80165, 227, 5, 49, "DisplayFormula"],
Cell[1568636, 80172, 647, 21, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1569320, 80198, 956, 33, 30, "Subsection"],
Cell[1570279, 80233, 254, 5, 50, "Text"],
Cell[1570536, 80240, 419, 11, 24, "DisplayFormula"],
Cell[1570958, 80253, 1551, 34, 57, "DisplayFormula"],
Cell[1572512, 80289, 257, 7, 50, "Text"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

